(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  10473205,     267979]*)
(*NotebookOutlinePosition[  10474496,     268020]*)
(*  CellTagsIndexPosition[  10474452,     268016]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Chapter 3. Color Image Processing",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm,
  FontFamily->"Century",
  FontSize->24,
  FontWeight->"Bold"]], "Title",
  TextAlignment->Left,
  TextJustification->0,
  FormatType->InputForm],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.1 Introduction",
  FormatType->InputForm,
  FontFamily->"Times New Roman",
  FontWeight->"Bold"]], "Section",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In chapter 2, we have described the basic principle and practical examples \
of the field theory of computer graphics. This chapter extends the basic \
principles of the field theory to the color graphics images. In the \
monochrome images, we have only a set of numerical values representing an \
monochrome image. Thereby, in order to derive the image vectors, it is \
essential to use the partial derivative operators, such as gradient and curl. \
However, in the color graphics image, we have three independent components, \
i.e., red, green and blue color components. Thereby, it is possible to derive \
the image vectors without any spatial derivations. The first part of this \
chapter devotes to describe the nature and applications of these color image \
vectors.\n\tIn the second part, we describe the image processing techniques \
to generate the sketch and painted images. Two methodologies are considered \
for a monochrome image generation. One is to utilize a magnitude distribution \
of the color image vectors and the other is based on a distribution of the \
inner products between the unit directional and color image vectors. \
Combining the sketches of red, green and blue components generates a sketch \
image drawn by the color pencils. Each of the sketch components is generated \
by means of the characteristic vectors described in chapter 2. Combination of \
the painted red, green and blue component also generates a painted color \
image.\n\tIn third part, the high-resolution color images are generated from \
a low-resolution color image. The image governing equations of the red, green \
and blue components in a color graphic image are independently solved with \
higher resolution. Consequently, a composition of the solutions leads to the \
high-resolution color images. A correlation analysis between the generated \
and exact image data reveals that good high-resolution image can be generated \
by means of the differential equations.\n\tFinally, similar to that of \
monochrome image, we generate the two-types of three-dimensional images. One \
is a shadowed lighting color image, and the other is an illusive image. Both \
images are based on the two-dimensional red, green and blue color \
characteristic vectors. The inner products between the unit directional and \
the color component characteristic vectors generate the shadowed lighting \
images of the red, green and blue color components. The convolutions between \
the shadowed and original color component images generate the shadowed \
lighting color images. The solutions of image governing equation regarding \
each of the shadowed lighting color component images as the source densities \
generate the illusive images. Because of the color effects, the impressive \
three-dimensional images can be obtained.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["3.2 ",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Preparation of ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"]
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["3.2.1 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontSlant->"Italic"],
  StyleBox[" utilities and packages",
    FontFamily->"Times New Roman",
    FontSize->12]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Before to move on the practical image processing, we have to install the \
memory conserve utilities and the warning message suppress command.  In \
addition, the \[OpenCurlyDoubleQuote]LinearAlgebra`MatrixManipulation\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]Graphics`PlotField\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]Graphics`PlotField3D\
\[CloseCurlyDoubleQuote] packages have to be installed. The last one is added \
in this chapter in order to plot the three-dimensional vectors [1]. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" utilities and add-on packages",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell["\<\
<<Utilities`MemoryConserve`
$MemoryIncrement=100000;
Off[General::spell1,MemoryConserve::start,MemoryConserve::end];
<< LinearAlgebra`MatrixManipulation`;
<<Graphics`PlotField3D`;\
\>", "Input",
  CellLabel->"In[1]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["3.2.2 ",
    FontFamily->"Times New Roman",
    FontSize->12],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" functions",
    FontFamily->"Times New Roman",
    FontSize->10.5]
}], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Here, we define several functions that have been described and used in the \
previous chapters. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function rgbBMP",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The function \[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] \
converts the numerical data representing color image into a RGB form. This \
makes it possible to visualize the color images on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook. The parameter \[OpenCurlyDoubleQuote]colorData\
\[CloseCurlyDoubleQuote] refers to a list including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(rgbBMP[colorFile_] := \n\t
      Module[{i = 0, j = 0, k = 0, dim = {0}, input = {{{0. }}}}, \n\t\t
        link = Install["\<RGBsplit.exe\>"]; Pause[0.01]; \n\t\t
        input = RGBsplit[colorFile]; \n\t\tUninstall[link]; \n\t\t
        Off[General::spell1]; \n\t\tdim = Dimensions[input]; \n\t\t
        Table[input[\([i, j, k]\)], {k, 3}, \n
          \t\t\t{i, dim[\([1]\)]}, {j, dim[\([2]\)]}]]; \)\)], "Input",
  CellLabel->"In[6]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function convertRGB",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The function \[OpenCurlyDoubleQuote]convertRGB\[CloseCurlyDoubleQuote] \
converts the numerical data representing color image into a RGB form. This is \
used to visualize the image on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " notebook. The parameter \[OpenCurlyDoubleQuote]colorData\
\[CloseCurlyDoubleQuote] refers to a list including the numerical values.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(convertRGB[colorData_] := \n\t
      Module[{i = 0, j = 0, dim = {0}, out}, \n\t\t
        dim = Dimensions[colorData]; \n\t\ \ 
        Graphics[\n\t\t\t
          RasterArray[\n\t\t\t\t
            Table[RGBColor[colorData[\([1, i, j]\)], \n\t\t\t\t\t
                colorData[\([2, i, j]\)], colorData[\([3, i, j]\)]], \n
              \t\t\t{i, \ dim[\([2]\)]}, \ {j, \ dim[\([3]\)]}]]]]; \)\)], 
  "Input",
  CellLabel->"In[7]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function grad2D",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox[
  "The function \[OpenCurlyDoubleQuote]grad2D\[CloseCurlyDoubleQuote] \
computes the divergent vectors of a monochrome image. The parameter \
\[OpenCurlyDoubleQuote]data2D\[CloseCurlyDoubleQuote] refers to a \
two-dimensional list including the numerical values regarded as the scalar \
potentials.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
grad2D=Compile[{{data2D,_Real,2}},
\tModule[{i=0,j=0,dim=Dimensions[data2D],
\t\tc1={Table[data2D[[1,j]],{j,dim[[2]]}]},
\t\tc2=Transpose[{Join[{data2D[[1,1]]},
\t\t\tTable[data2D[[i,1]],{i,dim[[1]]}]]}],
\t\te2D=AppendRows[c2,AppendColumns[c1,data2D]]},
\tTable[{-0.5(e2D[[i,j]]+e2D[[i+1,j]])+
\t\t\t0.5(e2D[[i,j+1]]+e2D[[i+1,j+1]]),
\t\t\t-0.5(e2D[[i,j]]+e2D[[i,j+1]])+
\t\t\t0.5(e2D[[i+1,j]]+e2D[[i+1,j+1]])},
\t\t\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]];\
\>", "Input",
  CellLabel->"In[8]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function curl2D",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The \[OpenCurlyDoubleQuote]curl2D\[CloseCurlyDoubleQuote] function \
generates the rotational vectors. A parameter \[OpenCurlyDoubleQuote]darta2D\
\[CloseCurlyDoubleQuote] refers to a two-dimensional list containing one of \
the vector potential components Both of the functions \
\[OpenCurlyDoubleQuote]grad2D\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]curl2D\[CloseCurlyDoubleQuote] are based on the \
central finite differences.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
curl2D=Compile[{{data2D,_Real,2}},
\tModule[{i=0,j=0,dim=Dimensions[data2D],
\t\tc1={Table[data2D[[1,j]],{j,dim[[2]]}]},
\t\tc2=Transpose[{Join[{data2D[[1,1]]},
\t\t\tTable[data2D[[i,1]],{i,dim[[1]]}]]}],
\t\te2D=AppendRows[c2,AppendColumns[c1,data2D]]},
\tTable[{-0.5(e2D[[i,j]]+e2D[[i,j+1]])+
\t\t0.5(e2D[[i+1,j]]+e2D[[i+1,j+1]]),
\t\t0.5(e2D[[i,j]]+e2D[[i+1,j]])-
\t\t0.5(e2D[[i,j+1]]+e2D[[i+1,j+1]])},
\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]];\
\>", "Input",
  CellLabel->"In[9]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function eigen2DVect",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The \[OpenCurlyDoubleQuote]eigen2DVect\[CloseCurlyDoubleQuote] function is \
given by a summation of divergent and rotational vectors. The parameter \
\[OpenCurlyDoubleQuote]monoSample\[CloseCurlyDoubleQuote] is a \
two-dimensional list regarded as either scalar or one component of vector \
potentials.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
eigen2DVect[monoSample_]:=Module[{out},
\tout=-grad2D[monoSample]+curl2D[monoSample];out]\
\>", "Input",
  CellLabel->"In[10]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function vectorMag2D",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The \[OpenCurlyDoubleQuote]vectorMag2D\[CloseCurlyDoubleQuote] function \
computes the magnitudes of the two-dimensional vectors including a list \
\[OpenCurlyDoubleQuote]vector2D\[CloseCurlyDoubleQuote].",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
vectorMag2D=Compile[{{vector2D,_Real,3}},
\tModule[{i=0,j=0,dim=Dimensions[vector2D]},
\t\tSqrt[Table[vector2D[[i,j,1]]^2+vector2D[[i,j,2]]^2,
\t\t{i,dim[[1]],1,-1},{j,dim[[2]]}]]]];\
\>", "Input",
  CellLabel->"In[11]:=",
  FormatType->InputForm]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function laplace2D",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The \[OpenCurlyDoubleQuote]laplace2D\[CloseCurlyDoubleQuote] function \
carries out the Laplacian operation to the input data listed in \
\[OpenCurlyDoubleQuote]data2D\[CloseCurlyDoubleQuote]. This operation is \
based on the 9 points finite difference formula assuming the zero Dirichlet \
boundary condition along with an image enclosing line.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
laplace2D=Compile[{{data2D,_Real,2}},
\tModule[{e2D={{0.}},out={{0.}},dim={0},
\t\tmax=0.,i=0,j=0,nx=0,ny=0},
\t\t\tdim=Dimensions[data2D];
\t\t\tny=dim[[1]]+1;nx=dim[[2]]+1;
\t\t\te2D=Table[0.,{ny+1},{nx+1}];
\t\t\tDo[e2D[[i,j]]=data2D[[i-1,j-1]],
\t\t\t\t{i,2,ny},{j,2,nx}];
\t\t\tTable[e2D[[i+1,j-1]]+4.*e2D[[i+1,j]]+
\t\t\t\te2D[[i+1,j+1]]+4.*e2D[[i,j-1]]-
\t\t\t\t20.*e2D[[i,j]]+4.*e2D[[i,j+1]]+
\t\t\t\te2D[[i-1,j-1]]+4.*e2D[[i-1,j]]+
\t\t\t\te2D[[i-1,j+1]],
\t\t\t{i,2,ny},{j,2,nx}]/6.]];\
\>", "Input",
  CellLabel->"In[12]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function poissonSOR2D",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox[
  "\tThe \[OpenCurlyDoubleQuote]poissonSOR2D\[CloseCurlyDoubleQuote] function \
gives an iterative solution of the Poisson's equation. A discretizing \
strategy used in this code is a 9 point finite difference formula, and an \
over relaxation method solves a system of linear equations. In order to get a \
solution as soon as possible, a MathLink utility is employed. A command \
\[OpenCurlyDoubleQuote]Pause\[CloseCurlyDoubleQuote] is essential for \
establishing a reliable linkage between the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " kernel and external object.\n\tThe function \
\[OpenCurlyDoubleQuote]poissonSOR2D has two parameters. One is the source \
density. Also, the other is a one-dimensional list including the desired \
number of pixels; the first and second integers of this list refer to the \
number of pixels in the directions of x- and y-axes, respectively. ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\t",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSize->10.5]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
poissonSOR2D[source2D_,size_]:= 
\tModule[{i,j,relax = 1.8,link,in,out,dim,
\t\tdx,dy,interP}, 
    dim= Dimensions[source2D];
    dx=(1.*(dim[[2]]-1))/(size[[2]]-1); 
    dy=(1.*(dim[[1]]-1))/(size[[1]]-1);
    interP=ListInterpolation[source2D]; 
    in=Table[interP[i,j],
    \t{i,1,dim[[1]],dy},{j,1,dim[[2]],dx}];
    link = Install[\"Sor04.exe\"];Pause[0.01];
    out=Sor[in,relax];
    Uninstall[link];
    out]; \
\>", "Input",
  CellLabel->"In[13]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function imageNormalize",
  FontFamily->"Century",
  FontSize->10.5,
  FontWeight->"Bold"]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  StyleBox[
  "This function \
\[OpenCurlyDoubleQuote]imageNormalize\[CloseCurlyDoubleQuote] converts the \
two-dimensional image data between the values 0 and 1. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[BoxData[
    \(\(imageNormalize = 
      Compile[{{data2D, _Real, 2}}, \n\t\t
        Module[{minimum = Min[data2D]}, \n\t\t\t
          \((data2D - minimum)\)/Max[data2D - minimum]]]; \)\)], "Input",
  CellLabel->"In[14]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Function hueColor",
  FontFamily->"Century",
  FontSize->10.5]], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The \[OpenCurlyDoubleQuote]hueColor\[CloseCurlyDoubleQuote] function \
provides a customized hue color function. This function gives a color pattern \
only depending on an absolute value of \[OpenCurlyDoubleQuote]z\
\[CloseCurlyDoubleQuote]. The graphics objects \
\[OpenCurlyDoubleQuote]colorBar10\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]colorBar5\[CloseCurlyDoubleQuote] are the color \
tables.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
hueColor[z_]:=Hue[Abs[z],Abs[z],1];
colorBar10=ListDensityPlot[Table[i,{2},{i,0.,1,0.1}],
\tFrame->False,Mesh->False,AspectRatio->0.1,
\tColorFunction->hueColor,DisplayFunction->Identity];
colorBar5=ListDensityPlot[Table[i,{2},{i,0.,1,0.2}],
\tFrame->False,Mesh->False,AspectRatio->0.1,
\tColorFunction->hueColor,DisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[15]:="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["3.3 ",
    FormatType->InputForm,
    FontFamily->"Times New Roman",
    FontWeight->"Bold"],
  StyleBox["Sample color image",
    FontFamily->"Times New Roman"]
}], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In this section, we have to input a sample color image. To demonstrate a \
distribution of color characteristic vectors and its applicability to a \
nondestructive testing of the concrete cracks, we read a color image file \
\[OpenCurlyDoubleQuote]Wall-A-128.bmp\[CloseCurlyDoubleQuote] by the function \
rgbBMP.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["sample=rgbBMP[\"Wall-A-128.bmp\"];", "Input",
  CellLabel->"In[18]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After computing a resolution of the input image, we construct its color \
image.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
dim=Dimensions[sample];
sampleG=Show[convertRGB[sample],
\tPlotLabel->\"Sample color image\",
\tAspectRatio->dim[[2]]/dim[[3]],
\tDisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[19]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Further we construct the monochrome images of red, green and blue \
components. Figure 1 shows the input color image and its components.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
color={\"Red\",\"Green\",\"Blue\"};
colorCompG=Table[ListDensityPlot[sample[[i]],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"`1`\",color[[i]]],
\tAspectRatio->dim[[2]]/dim[[3]],
\tDisplayFunction->Identity],{i,3}];
Show[
\tGraphicsArray[
\t\t{{sampleG,colorCompG[[1]]},
\t\t{colorCompG[[2]],colorCompG[[3]]}}],
\tPlotLabel->\"Fig.1. Sample and its color components\"];\
\>", "Input",
  CellLabel->"In[21]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[.5 1.0125 -116 0 ]
[.5 1.0125 116 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sample) show
147.000000 12.812500 moveto
(and) show
171.000000 12.812500 moveto
(its) show
195.000000 12.812500 moveto
(color) show
231.000000 12.812500 moveto
(components) show
291.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Green) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CAC4C8B3C0B6C2C0BCC4BEC6BEB8ABAFAFBABABEB4AFB6A9
D1ABADBAB8B1BCB8BAC0CFBEC0C4C4C0BCC2C298C8B8C8B8
BCA9BACCBEC2C8BCB4CA9D8AC0C0B39F90B4BEC6BAC2CCB8
94C8C6BAC0CACCD1CAC0CCC0C4BCB3C4CCC8C6C8BEC4C8AB
B4BCC4CAC4C2BAC8BACFC8C4C4C4BEC6C8C6C8CFB6BECABA
B3C8BCBABAC6C8C2
B6BCC2AFC4BAC2C0CDC2D3CCBCC8B8ADBAB3C0B6BAB6C045
D1B8B1B8ADB3BABCADBEDFBEC4BEAFB4CDC4C4CCB3BEBCBE
BABCA5B3CD88B6CCADD3B19BBCB6AFCFC0A7BE7DB1BEABBE
C0AFBACCCDB6BEC8C0C8C0C2C0B1B8BAC2CCD1BCCDB1CAC2
C0C0B1BECABECCBEBCCDCFCCCFC6B1C6C2CCC6B6CCAFCACF
9FB8CACAC6B6B6CD
BEC0BAB3B8A7B4C8C8CCC6B1B8B1B6BAC2C6B6BCBAC4BEA5
BCBAB6ADBAB4B4B6CCA9C6C0B4BEA1C8C4C8CDC4B8ABC8C8
BAB4CAC6C6BCC8BAC8AFA99BB4A7B6C4BABCCCAFB1A7C4BE
BCC2C2C4C4D1C0C8C6BAB3C6CCC0C0C4C8C8CCC6C2C6C6AD
ADBECDBCC4B8C2C2BEC4CCCAB3C4B6BAC6BED5D1C2B3D5C8
B1C4BEC6BEC8B3C6
B6B6C8B3AFABB4BEBCB4CAAFC6C0BEBACCBEBEC4C4BEC4C0
A1AFBAB6BEB6BEA5B8D1D7C2C2BEC4C0C4A9BAB1C2CABCB3
B6BA92BCAFC6CCC8C8B39077BAADB6C49FB1B6A7AFD1BEB8
C8C0BEC4C4B3C6C4BAB1A7CCBCA7CDC4C4BEC2CAC0D7C4B8
BEBAC8C8BCC2C8C2BED1C6CAC8D3B3C0B8C0BEBEE3C4E6C6
B6CAB8A3BEA9C2BE
C4C2BAC8B8B8C0BCB1D7CFB4AFB6B6B1C0BEC4C4B8B6C4C8
BEC2BE96B3B6A5C0C0C4CCB8B6C8B3BAC4C2C6B6B8A1B3A7
C6B1CACABAC0BCA7C4A98E84B3ABB6D3A1B3C2B3C233BAB8
C0C4AFB6BAADB8BCBEB1B6C0B4C6C4C8C0B6CACDBAC0B6B6
CFC6CFC8CAC2C6B6C2B3B8C0D3B1C8C2C6C8C4D1B8A3C0AB
CABEC0B4BAB6B1B3
B3C0BAB6CFCABABEBEC6C4CDB8BEC6B8C6BEC8B4B8B8B8DF
968AA7A77FA5B3B8BCBED1C6CDCCC0D1CCBCAFB8A3BED1AB
BEBEAFB8ABC2B8B8BCC68688A9C89FB1C0B8BABCBCC8BCC0
B4ABB3C2BCC8BEC8C2C0C4BEC6C0D1C0C0C0C4A3C0B6BEBE
B6C4C2A7C2CACCC0CCC6C8C6CABCC4C4D1C0D1AFB4C4BCB1
C4C4C4BEBAC2C2BC
C2A9BAC2BABCB8BE88ABA9C8C4C2BABABEC0A1C8B8D5ADD5
C8B8C6BCABBAA9A1C8A5D7C2CAC8B3C4BCC0CDCCC6ADCAB6
C0C6C4D1B3ABA5CDC8BE8688B3B499AFB6A7B6D360ADCDB4
BABCBEBEBCB3A9C0C8BCC0BCBEC2C2BEC8CDBACACFB8A9B4
C4BAC4CDC4C8B6C4CCD1C8C8BEC6C0C0CACDD3CCCDC6D3BE
C4B6C0C2CABECDC4
C499B6CABCB1C8C8ADCABCC6C6C2C2C6C8BCB8B3ADB1B1BC
AFBEA1C2B4B4B6B6AFB6CAC8C4CAB3BCC2BCC6C4C0B8C8C4
B4C2C8DBA3B6BECDC4BE9F8CCFABC2B4A1A7B8C4CABECFA9
BAC8CDBCC0B6B3C0C2C8C0C6C2B1ABC4C8C4CAC0BCA9B3C6
CFD3CDC8C2BE9DC6D1C8CCCCCDC6C8C2CD8CBABEB4B1B8C0
C6BCB1ADC4C4BCCD
AFABBEA7BAC8B3A9ABB8B1D1C8C6BEABAFC6B6C2ABBABEB6
B499B6C6B3C0C4B6A9A3BCBCC6BCC0BED1CACDC6C0CCB6C6
C2C0B4B6A9C8D3C4C0B899ADA3B4B3C0A9ADBECAABA9BEC0
BCB3AFBAB6C6BABEBCABB8C0C6ABBEBACCBCBCBABAC6C8B3
CCCCC8BAC6CAD1CFC0CDC8ABC2B3B6CFC2CABEBAC2D3B3C2
C4C2C6C6CFC6CAA5
C4BCBCBCBEBAB6BEBCCAC2C2CACAC0BAC0BCB6BABCB6C2B8
AFBEBEC4C2C2C6B4A973C0B6C0BCD1CAD7D3C8BAC2CCC4C6
B6B3D1ABCCC8C2BCB8AD8E888CC4B1C0C8ABD1D1C2B6CCCA
C6CAC0B4C6C2B8A7BCC6B4B3C4B8AFCDB8BCC0C4B4BAAFB4
A9C6C4D7B6C8CCB8BACFCCC8CDC2CAC2CFC6BAB8BCC8C4C8
BCCCC2BEBEBEBECC
C8C2C4BCB4B4C0BEC2B4BEC0C6BAC2BCBEC4CDC2BCC8C4B1
BCC0BCC2C2B8BCBEA1BAA7BEC2BECCB4C2C0B3C8CDC4BCC0
CFCABEC2C4C4C2C2CDB3889898B898B3A7AFC0BAB4AFA1BE
BCB3B1CDAFC6B6B4B3E3B8BAB1B3CFC2C6C6B1D5DDC8CDCC
C0BABEB3CFBEC0CDC8BEC8CFC0C4CDC6B6CFD3CDC8B4C0B4
C0CFC2D758C2DB79
C0BAB6B6C8C0C2B3BACF86CDC8BCBEC4C0A5BECDBEB8C4D1
C6C6B8B8B8BCB3C0C4C2CD80CAC8CDA7C4B4C8BCCDD7C8B8
BEBAB3B1BAC2C0B6BEA7324588C4A9BCA5BCB8AFC4C8BCA3
B1ABB6C8ADBCCABCCDC6C2CCB4BACCB6CDBEBCDDC0BA9BAF
B6C0AFC6C2B8C2E6D1CAC0BEC8B8BEC8BEBAC4C8CDC2B8C6
B3C8C0CDC4C4BABE
BCC8B6B3B3BAB3C2BECAC6CAC4C6B8BAC0C2C4B6B6BCDBC6
B6CAB3BAC4C2BCB8C6BED7C69BB6C8C4CACCC6D1BABA86FA
BAC6BEB6C4C2BEB3B14EA9B1E5C8C0C0C6C0C6C6ADAFB4BE
B4C0C0C2C6C4B6BCB8C0C8B4BCC6C4C6C2C6C2D1D9CFBEBC
B8C2C4CAC0B6C2C8BAC4CCC8C2C6C4B8BEBACCCAC8BEC4C6
C8BEC2C0EAC4E1C8
CABEB8C2C2B6CABEB3BCB4BCC0BCC6C2B6B6C4BEC4BAB6BA
C2BEB6C4B8BECAB4C0C6D7C2CCB1A5CACABCC2C8BEC2CAB4
BEC0BCBABABCBEB6A7BAA5B886B8C6BACDAFB8C2ADBCA5B8
BEB6C2C8C4CCC4B6B6C4CCB8ADA1CFC6CCC8BEB6B3A3BAC2
BEB6C4CAC4C4C2CABACCB8C4BAC2CFC0C6C2C0C8C8CCC8C0
B8C8B4C0C0C6B4B4
BEC0AFA1B8BAC2BEA5ABA7BEB4C0BEBAC0C6C8C0C2C8BCC8
84B6C4C4C0BEBCB8CDBEBCB8CAC2C099C8CCC6CAC4BAAFBA
C0C0B6CCC0C8B8B6B1E1D1DFC6B4B3C299A7B4C8C0C2B6AD
C4C6D5C8C0C8C0C2C6CABCC6A9C0C8BEC2C6B6B3B6B8A1C6
CDCDC4C6ADBAC6C8BAC8C2C4CCC4CDC4C2D3CDC8D1D7DBC8
B8B69FC6B8C6B8C8
B3B886BAC4C4BEADB6C2C0BABEC4B4C8C4BAC4CAC0B8C6C4
C0B8C6B8BAC0C4BCC8BEC4CDC8BCC2C6B6CCC8CAC6B3CFC4
C6CFCCCAC8B3ADBACCBAC2B6B4BCB6B3B4A9CDCDCDB8C6CF
C2D9BECABCBAC0A7C2CCB6B1AFBEB4BCC4CDB8B8BCB4BEC6
C2BEC2C6B8C8B3D5C8C6C6B8BEC8C6C2B6BCBCADABB8B6C6
DFC8D5C0C2CACDBA
BEB8A7B8BAB3BEBECCC4C6CAC2BABCCCC8C0C6C8C0C4BECC
C4BCB4BAC0C4C8BAC2BACAB4C8C0CFB8BECCCFBACFC8D1DB
D1BCC2B4C8C4C6D3D3CAC6ABBAC4ADC69B98BEBEC6C09DC4
B1CDC6A7C6C2B4AFCDB6C4BC9DBEC0BABCC2B6B6AFB4BEBA
C2C8E5D3D5CCBEAFBCA9C8C4D1C8E8B1C49FC6BCC6B8BECA
BEBECDD5CDCCCAD1
BAB1BAB8BAB4C2B8CCC6C2C8B8BAC0B6B6BAB8C0C4BABACD
C2B8ADBAB4BCC0BEC2A9CAB6BCC2AFCDB8A5B1B89BBCBCA7
CDD9CDC2C4CFD7A7ABC2C4B1C2A3B8BEBEB6BCBCB6B8B1BE
BEC4BCB8CABCCACABEC4C2B3AFBEBEB4C0B6B4B4C4BCC2C0
B4C8BEC4BABCBACCCDD1BECFCFC0BABAC0B1CFCFC4C2BCC2
BAC6C8C4CDCCBECA
B6C69FC49BC4C0A9BEC6CAC8CAB8B8B8BAC890C4C2BEC0C8
CFB1B8C4B4BABECABEB3BAB1C0C6DBC4BCE3D9A9BCBCADBC
CAB4B1C6CABCB4CCC0BAB6C0CDBAB8B4B1BCB4BEB1ADBE90
BACAB4C2C6C6C0B1C6C6CDB690C2C6BCC0C6A7B8B8C6C2C6
C8D3D1D1BEC4B3CDB8AFBEBCC6C4B1C2B4C6CDB3D3B6C2C0
BCC0C2CCBAC8C2BC
BABCC4B6B8B3B8C0C4C2BEC0C6C6C2B6B6C8CCCCC0C2B4C2
C4ADAFC8BECCE1A7BEC6B4B696C2B1B8DF98EAB8B8BE9DAD
A9B1B1C4C6CFCDABC6BCB6BCB1CDB8B8BEB4C0C2BEC8B4C4
C8B4B6CDBEADAFC2BEC8D1C09BB6C0C0BAB8ADB4BEADB6BA
B3B3C2CFCDCDCDA7B8C6BECFBCB6BACDC4D3CCB8C8BACDD9
BCC4D1B1B4C6BCCC
C8BAB1ADBEC4D5E3C4B4B3C0BAC4C2C6BCBEC6C4C0C6BCBA
CDD1CCC0C2C8BAB6B6CACCBABEB398ABBCABB39F8C9B9F84
94C0C0CDCAD1C4C4C0B8A9A5BCBCB8BECCA7ADC0CDB4C2C8
B1B4B4BCCACCCDCAA1AFC8B6ADC4BCB8C0BAB3B3A9ADB1B8
A9C0C0B4BEBEBCCCCAA9C8CDCCC8C233B3D3C0C6AFCDC0A7
CCC0CFCDC6CCCDBE
B3C2B4C4B8B4A180CAC2A5ADBEA3D9B3C2C0F2CDCABEC0BE
BCBEB6BCB8C0D1BC9BC4C0C6C4C8C8BCBEB1B3C6E1C2B1C4
B1C2A3969898B3CAC4B3B8C0B1C2BCB3CCADC2B1AFB6BEB4
C8AFBCC2D9C8B3A1BEB6BAB4ADB6B8B4C6D1C6B8CCC4C8B4
C6C8C8D5C0C6BABCCAC6CDC4CAC8C2B8B6BCB3BCB8B8CDE1
CFB8C694B1CFAFBE
BABAB6BCBABABAC2D9BECFBAB8C0FCB8BCCDA9BEBEBEBAA9
BCC0BEBEC8D1BAA7ADB6C6CCC6C0BEBEB4C0B4ADC2BACFBA
C2C2A9B8CAD1D3B8B386BCC46BB1BAB6A1ADD7C2BAB4B4C0
C4BAE3C4C4CAB3CFD7B8C6C4A5BCBEBCBEB4A7C0C2C4C4BE
C2C0B3BED7D1C0B6C8C6CFCCC0C8C0CCCFBEBCC4C0B3ABCA
BEB8B8B4BCC8CCB4
CCC8C4B1C4CCB8ABB8CFC6CAC2CAC0BAC6C4C6C0C29FABC6
CCB8B1C2C2C4B898E1C2C4C0C6CAC2BAC4C2C0BAA5CDB8C4
C4C6B6BCCCB4D5C87BBEAFB1C8BEBAB1B6A5D3C2A7C0CDA7
B3D7B4BCCAB1C6C4A9BEC4BAA5BAC4B6CAC8C6C2C2D3C4C0
C2C6C8C4D3BCA1A9C2CCC2D1C8CFD3C0CCCCC6C0C8B4C6CD
CDC488BCBEC4C8C4
B3A9BAB1C0BCB6C0C8C6BE94C8B4C4B8C2A7B8C4C0CCBEB4
C2B6C8CDDFBCA9ADB6BEC4B4BC99B6CCC0B8CCCF99B3C2BA
B8C6CCB4B6C6C2B382B8BEC6B3BAC0C2BAB4C2C2CFBCC0B3
D7B8CCE3D1CCCDCFBECACDB4ADA3C2BED3BAB8C2B1B3B4BA
B1C6BCC2CCBECDCFADCCCACDC4C8C4B899CCB3B8C2CCB8C2
9BA9C6CAAFABB8B3
C6C4ABAFB3A5B4C8C0C6C0B6CACCC2C2BCBEC8BEC6BABEB8
BCBEC0C2ADCFB4BABABECCC0BCABB4CAD1C8BCDFBABCB6B4
BEC8C4B1ADBA8EB447BECAD9BEBEB3A9CAB8CDAFADBCBADD
C8B6C2A7BACAD1CFC2C6C0C6B3C0C6BEDDC4C2CAA5C6C0B6
BEBCB1C8CCB4C0D7D5ADC8C0CCC6CACDCDB8C6BCABB4B4BA
BCB6BCBEC4BCC8C2
D1BECAC4BAB3BCCDCACFBCC6C8B8CABCBCC6BEBAC4B6BABA
BECCC8C0B8C6ABBEAFBACCB3C8B8CCBEC0BACFDBC8BECD99
AFB3BAA3B3B4B1D1D1CAA7CFBCADBCB4AF888CABCDB4B1AD
C6CDC2C0CAB8BECFCCBEC8C0B4C6CCC4BEADC0C0BAB3B6B1
BABCC8BCC2BED9D3B4B3BCCACCC6D1BECFBEC2AFCCD9B6CA
AFA5BAB8C4BAC2B6
CDC4C0C2B3ADCFBAC8CAC4BCCFB3BCB4BABAC4C2CFB6CAD3
C8CCBCC8C0BEB8BACABAD5C2C2C0C6D3D3C8D7D7C4B6BCB1
AFCFA5B3D196BEB3BAC4C0C0BC94B6C8B8ABB6BCC8C4B8E6
C4C0C6C0C4C6C6C6C8B8CAB6B3C2C8B8BAB6A3C2C4C8C6B4
C2CCBCC0C0ADC0CDC8CFCADBBEC8CFBCC8C8C4B1BCC0C4D5
BAA3C6C2B3BCC4C0
BEBAAFCCC2C6C2CAC0BEC2B1C6BAC2B4CCC0C8BCCFBEC4C2
CCCCCFBC9BC4C6C0ABBEC8D1BEC0C0C6A9BEAF9FB1B8C2DF
C6B6ABB88CBCCFB4C2B1C6C8AFC0E1A5C2B8B8BACAC6B6CA
BAB4BCCAC8C4D1C4A3BACAC4B1BEE6B3C8CFB6C2C0C4C6C0
9FBECAC0A9C6B3CACACDB6D1CDD3BCAFC2C6B4C8D7C896A5
B4D3B1B1C4ABC0C2
B8BAB3B6ABB8C0D7C2C2BEB4C0ABC0BCCACAC8AFBEC4C8C8
C2C0AFB6CCCDCDC89FB8C6BAC6CABAA5BEC4B1A5ADA5A5B8
BEB6AFBABAC6C4CCB8C0B3C8DDBACCB488BCC4CAC0C2C8C6
CCB6B8C4B6D3C2CCC4C6D1D9BAC8B8BAC0A9B3ADCA9DCABA
B4BAB6D5ADB8C0CDB8BAB1C0CCD3ABCCCA80CFC0C4B6C8AD
C0C6CDBABEC4CDCA
C8BCB8BAC8C0A3B6B3C6BCBCCAB4C2C2C8BEBEB1BEC8CFC0
BCB6C2C2C8CCCFCFABB8B8BEB3C0B6C0CAC4C6A3B4ABB1B4
BEC698ADBAABC0BCC8C0A7B8C0C8B6B1B6B4C6BEBAC0BEBC
C6C0C2C2CF7DCDABCACDD5B6B4C2CA9BBED1B8BCBEC0C4CD
D3CABAC4CAB8CDBCC6CDC4BEC0B1A9C0C4CDCFD1CFB3AFB6
B6BCB4C0CACDD5C6
BAC2B1BABCBCBCC0BEC2B8A5C6B8BEC8BECAC8A9C6A1C4BE
B3C2CCBEB8BEBABA9DCDA7B6CACAB6B4C6ADC6C8C0C6B8C4
C4C2CDA9BCAFB3DFA99FADB6BEC4B8C8BAA9B3BCCCC4CACD
D1CDD9C8CAC4CCD3C2BCC4C0BECCC2CAD3C4C0B4C0A5B3AD
C8C4BCC6B4CFBCD1C2CDCABCD7CFC6B4B4C2E6C2B3B8C8A3
C0C2D3B4CCC8B8CC
AFB8CCC0B8C8C8C8C4ABABC0C2B4C8C0C2BECABEC4CFCFBA
BEC0C8BCC6C4C8B8A9B3C6C2B8BEB6CCCFBCA5C0BEB4D5D1
B3C8CFAFB6ADD3B4C6A5B8C0D9B6B3CDBEA7B4C4BA7BC8D3
CADFC0B1B1ABCDAFCAD3D3BABACAB1A7C4C4ABB1B8BEADA5
B1BAADCAA9C2ABC4C4B8C8C2BEC0C8BCC0BACDC6C8CAB1D5
C2C4C6CCBEBACCDF
C0B4ADC2C2C4B4C6B6B1B1C8CCBCC6C2B4C4C4BACABCC0BE
C6BEC2CDCABEC2BCB8C4C4B1B8C8C0BAC4BAC8A9A5BAB8C0
B3CA90C2C0BEADBAB4B1BEB8C0B4C2C0A9B3C4C0C4C4E1D7
CAB4BABAADBCABC4DBB8B6CCBCC2C8BEC8BEADC4C2CAC0D3
C6C0CDC6CCBCC6A7CFCFCFC8C0BCC6C4BECAD1AFD1CCB8CC
CFCDC6BACDBCCDCA
BEABBAC6C4B6C4CDB6B8C2C0C8BEC4B4B8BEB8BABEC2C2B8
C8CDBEC88EBEC2BCABB6C6C6C0C0C6B8C0CCC0C4BEC2BEBA
C2C2A3AF98ADB3A3BAC899B1BAC2B3BCCCA564BAC09973BE
C6B6CCC2ADCDC0ADD7B6ABC4BCB8AFB4C4BCC8BECFCFB6C4
C2CDBEC2C0DDC2A1CCD1C2CCBAC6B1C8C4BCBEE1D39FB4CF
C2AF9BB8C2B3C6CF
C4C4C6ADB8B1BCB8B8BCC0C8C4C0CCBEBAC0CDBCC0C8C0CC
BAB1BED3B6BAB6B6B8BACAC6C0C8B4CABEC6C8CAC0CACDB6
B8B6C2CFC8C6A5C2D59DAFBEB8BEBCBAB4C2B6BCDFAFB4C6
B8CCC6CACDC4CDC0B1C2BEC6B4BEBAC6ADC4C0B6C4BCC69F
C8CDC4C2CFD3C4B6BCC4D5D5C6C6C6C0B4C2C8B3C8C0D1B6
C4C2B4C4BCBCCFB8
BAB8A5C4C0D5CAB3C8B3C2D1B4BEBCB1A9BECACACABEC2B4
BEBECAC2BED3C4B4BCC8CDBCBEC6C2C2BA94CCB1C0CFB4BC
BAB8B4C2A1C6C4CD998EB8BAC0BEA9C89FB4B6B8B8B6BED7
CCB3C0C0D3CAB1C4C2BCB8CDC2BAC0C4CAC4B1C0C2C2BADD
C8B4C2BEBEA5A5C8BCA7C6CDCACFD7D1C89FCABAC6ADC6D5
CCC2DBDDC6C8CFC2
BCC2C6B8C2BCCDB3A7BABEC6BCC0C2BEC8C4BCC4CFC4C6C8
C6CCB1B8CCCABAAFB6B4B6C0B1BAC8CACCBCC8B6C4CFB6C4
B1C2CAB39FB6B6C292A7A7A7B6CAC6B3BEB3A1B6C4BEC8A9
BAB4B6CCB8D5CFCFC6BAC2BEB3AFD1C6ADBCC0D1C0A3BAC0
C6BEBCC8D5BABEC8CAC8CCC0C2CDCDC8BECAC4A5C4EABCC6
C8C6BCCCA773B6C8
B1B8DBB4BEC8C4C2CFC6B4BEC2C2BABCCDC6C8C2BAC4B3BC
C4BCBAB6C4CAB6C6BCB8CCB8CAC4BCC4B1C2C0B4C8B8C0CC
ADBAC6C2A1CFBAC69DBCA7B4BAC2C0ADB6A9B4C4CDBACCB1
D1C4BAC2C0B6C6C2C4DFCDBEB8C6B1BCABB1D5A9CCE1D1D3
C0B8BCCDCFB1BAB8BAB4D3C6C8CCC0CCBED1CCD5CDADB3B3
C2ADCCC2BABACCC4
BCC8CAB8BCC2B1C0BCC2BECFC0C8CAC4C6C0CDC6C6C8BEC2
C6C2C0CFBABCC4B1D3B6CCBABEB3C8A5BEC8CDC6C8C0BEC0
B1B4CFC69FBECACABAC4AF96ABA7A1B8AFB8CFCF9DAFBEBE
AFB4C0C6BCB6BCC8C0C6CACDC8BCCFD1C0BAB8D3C6C8AFB1
B8CACDCCC4CC9DCDD3C6CFD3C8C8D5B6C2B1B666C6C8C0BC
B6C6C6C0C8C4CDB8
B8BAB3C0BCABB8CAC6BCBCD1C0BCAFC6BEC0B6B8B4C0CFCF
CAD5C2C8C0C0ADC2BEBCC2C0C0B8CAAFC2B1B8C8BAB8BEC2
B3C4B3BED7C2BCB64EBCBEAF98B6BCAFB388C6B8B894C4CA
CCCAB3ABC4C2CACCC8C0C6B3BE84D1BCC6C4BAB1CDB4C6B6
CDCFCFC6D1C0CAC2D1C2CDB3CAC4C6BEA9BAD1CCB3B6ADBE
C4A9C8B6C096D3AD
C4ADC0CCC0CCDBD1CDBAC4C6CABCC4B4CAC4C4D1BAC6BACA
C2B3C0B6C2C8C6BEC4CACAC4C0B8BED1B4B1BE84BCB4C8D1
C2CDD3D7C2C2C0B6C4B6B1C4C28098A7ABABA3C6C29FC0CC
C2C0C8C6C8C4CAC2C2B3CCB6B6B4C0D7BAC2B3BCCAC2CAD1
CDC0D5D7D1C8BAD7CCD1CFC4CFC8ADBAB6A7ADCDDBDFD3CF
A3CADBC4D3C6C6CD
B1B3C2BCAFB3C0B6ABD3C2BABCC2C6BCB3B3C6C2C2BCBECC
C4BEC4BCB6B4C0BCC0D1CACFC0CCB8BAB3A5BECAC0CDC8D1
CDC4DBD3B3C2C8C4CDC4B4BEB19D75BEA1B6C6D1BABCBEAF
C8CACCCAA9BEBCB8BAD9C8C2BA99C8CABAC0CDC0CCECABC4
C4C8CDA5CAD3CAC4BECAC2C8C4D5CDCCCFC0CAE5CF99B1C2
CFC2C8C8B6AFC2B6
C0C0C2AD9FCFB8C0BCC0BABCC8A9CABAB1C8BCCDC0B8CAB8
BECACCB8C0C6BAC8BCBCC6C0C6C6CAA1BEABB4D7CFD3AFE1
DDEAD1B3C8B4B4C2B6BAC0BEC2C0B8A590B8BA9FD39DABBA
AFCCCACDC8B8C6C87BC0DBB1C8A9D1BAC4BCB3B3D7C0B8BE
C4C2C6A5DBADC6D1CFC6BCC2C2BCBCB3B8E1CAB4C2BCC2C8
CAC8DBC8A5A3B8D3
C0CDC2B6A9C2CCC4CCBAB6C0C2C2BCB1C4BAC0CCCDCCBEC8
C0B6AFABBAC8C6ADB6ABC8C0CFCDC8BAAFBEBECABAA9BECA
DDCFCDBAC8C6CAB6D3BCC6C2BAB1AB96A39BADBAB1ABB8A1
CAC6C2CABAB4CACAB3D3C6B8B1C2BEBC94C0C8C8C0BCCAC2
B6BAD5CFA1CCC8C8D3BCB1B4C4A5CFC2BECCC0CC96C8999F
A9ADCAB6C6B8CDD9
BCBEBECDAB96BAB8B8C4C0C0B8BAC6BCC4CCC8BEC4CAC8C2
CCC0AF92AFBEB1C8C8AFCCBACFCDC0BEA5C0BED1D3DDB8CD
CAAFAFB4CAC0C0C6B6C6BCC6C2AFC2ABA9ADBA9DB8B6A5C2
CAADC0B4C89FCDC0C8CA9BC6B1D7CFBEBEB8A9C0AFBCC2B6
CABACCC4CCC8BAD1C0D9B6C4ADBECCCFD1BEB6B4BCCCBAC2
F0C4BEC2B8C0C6CD
BCC4BAB4C6D1CCB3B6BACFB1CCBCD1C4C0BCBECDB1BEB4C0
C8B4B39F8ECABEB8BAC6C2B8C0C2B4C2B6B4C2C4C2CDA986
8C8E90CFB4CFC8BCBECFD39DC2B6C0C2B6ABCCC6C0ABC4C4
D7C4CAC2DFC4D1B6D5CCC2D3B1C4CAD3D1B8C8A5C8BACACF
EAB1D9C2D7CFC4CACDD5CCB8B1C8CAA3C2B3C898C0BCB4BE
C8BCCCD1CFC8D9D7
CABEC6C6B1B3B8C8CCCCCCC0C2BCD1BECCC6CCBEC0CCB6CA
B3C4C2C2D5BEBEBAC0CCCFCFC4B1B4C4B6CAC6947F989FA7
7FB3C0C8CAD5BEBECDC0C6C2C4B4C0BABEC096B3AFB1A5B1
B8C8C6A9CCCDCABAC8C0C6CFC0CFA5C4BABECABCC4CAC8BC
BEC2EACDBEC0C6B8D1CCC4B6C6C4B8B3A5C0B6CAC0AFBAC8
C8C0C0CFBCB8CFB8
B3BEC6B3B4CAC8C4BEB8BEC4BCB4C2C4C2C4CCC2BAB4B3CD
C8B8BCC8CDA9BABAC0BCCCCDC8C2C0C2CDB1CAC4B4989DB6
BCBCB6C4C6B8CCC6BAB6B1BEC8BCC4BEA7BAC6CDBAA1C2C6
BAC0CAB8AFC2C0BACACCC6D1B6BCBEA3B6B3B1CACDCCCDC2
C4BAAFC8CDCCC6C8DFC8B6B8CCBCCDBEBCCDB8D3BCD1B6B6
BABEC2B4CACACCCD
BEC6BABEB1AFC6B4B3C8B4B6AFCFB4B6BAB6C0ABC6B8C2CC
C6B6C2CDB8B4C2BCC4C8C4CCCDB3CAB3BEBEAFB3B49BC4CC
B1B8C8B4B4C2BEC2D5BAB4B1B4B1BAB3B6B3DD90D1CCB4CA
C0ADE1C4B4BAB8AFC2D9C4CAC0B3C4CAD3BAC0D5BCC0D3A5
B3C4ABC8C8C6CFCDB6CABCC6C2CCCDBEA5A3CAC2C2C2B6C4
C0CCD3CDBCBAB8C4
BCC6C882928AAFA3CCC4B3BCBEABB6C2A9B6CABCB3C8B8B8
CAC2C8BECCC0CCBEC2ABC4C4D5CDBCCCCFB6C2DBC8A3CCB8
BAD1D3C8C4C6C4C8C2C0CFBEB6B1B8B8C8ADB8B1B898B3CA
C0D9C0B8CDC6CDBAB4C6C6AFBCA3C2AFCDA5B6C0C8C6BEC4
C8C2CAC6AFCAB6B4CAC6BCB8C8CAC6C6C2C0ADD3C4BEE5C0
D5B69DBED1BAB8D5
ABBEA9B6C0D7BEC8C4BEC0BCC0C0C2A9B4C6B3B6CCBABACF
C0C6B3CDB4CCC0C6AFBCC6C4C8B4C0C0B6B3BEBAA9A7BAAD
C0C0C4B8CCBACFC8BED1BECCB6C4B1C2AFA5B8B8C4A3B8CD
B3D5B8DBBCB6C8BABEC2C4C8C09BBECCADBEA7BCBCBEC6CC
C2D7C2B8ADB6C0C2CCB3BED5CCC4B6B6BCB8D1BEA7C8CCC2
C6CDD9CCB1C4D3D5
C2C4B8BACACFBCC4D3C0ADB6B6AFC2BECDBEC6C8C4BAA7BC
CAC6C4C6C4BACAC4BAB6C4CABEC4C4C6C0B3C6C6B880D1A3
ADB6C0BCC6C4BEC2B8CDA7C0A9CCAFBCC0ADB6AFC0CCA1CD
BEC2C0A7B3A9BCC6C4CFCFC6C2CABAB1BEB1BEC0C0C0D5C0
C6B6C6BAB4C6C4C6BED5CCD7CACFB3C8B8C2CCB6BEC8ABB3
DDDBCDCCCCBEC4C4
C0CAC2C8BAB3BAC6D1BEC6BCBAB6B8C6AFBACFB6C2C2C4B6
B8BEA9C0C4C2CDCAB1C4BEC4ABB3E5CCC8D1DBDDDFC8C6AD
CAC6CCD3C2B6BCC0B4C6CCBABAB4B3A7BAB1ADC0D7BE9FA7
9FB6C8BEBCC4C6CAB6A7BCC6C0BAC8BEA9BEBEBAC4C0C0B6
C6C8C6C4BABEC8E3BCD1CABCCAADC2CFBEC2C0B4E6CABAA3
7FB8C8C4C0C4D5C8
B6BABEBAABB6C0CFD3B6B4B6C8C8C8C0D7DBCDAFCDBAB6C8
C2B8CAC6B4BCADC0BCC8C6D1CFC4CCEAC0D1AFCDCFBAB1CA
A7ADDBC2BAB4C8B6CAB498C8B3BCCACAA7B8BEBAC6B6BAAF
D1B4C4B8C0BEB4BABCC0C2C0ADABCFB4A9B1BCBCBCABB4BE
CFD1C2C6ADB8AFC2AFD526CDB8B4CFC6C8A1C2B8B8A5C8AF
C0CCD9C8CFCDC6C4
C0BEC6C2CAB4CFB3C0BCCCCCBABEC0B1BECDB4B6C2C6C6BC
C4C8B8BCBAB3C2BED3C8CCCAC0F6BEB3C4C2BAA7DBB4D9C8
92CFBCBCC4B6C0CCB3B8C2BCD5ADC4B3B6B3C09D6F9DABC6
E3C8B6B3BEBEDBC4D3D9BEB4B8B3ABBCB4BAB4C4BEC2C8CC
C2C2B6BEBAC4CAC4C4C4A1CAC8BEA9C8C0D3C6B4DBC0E3E1
C8DFC4CDCDCDC8E1
B1CCBEB8B3CAD3BCC0C2ABCCC4C2B4BEC6BCADC0BCBEB4C0
C2BEBCBEC4C4CFCDCACFC6C6AFABB4BEC4C2A5D3BE94C2B6
ADCCBAC6BECAC8D7B3B8C6C2C6A3C0C0B6B6B4B1C6C6D59D
90ADB8BCB3BEBAC4BAB8CAC6C4B8C2BEBCADB3C8A3ABCCC2
C8B8D7C8C2B8D7D7D1ADCCC4C0BCBABAD1C8B8ABB1B6D1AB
C0D5CDD3C4D1D1B8
ABCDC2BEB3C6BCBEC0B4C8CFC6BABAB4C0BCC8B6B1BEB1C2
C6C6BCC8BCBECCC6CABEB8D5D9BCA9B6CD8EC899B6ADD1D3
B4D1B3B6BEDBC0BAA5BCAFB3C2BCBAB6B3ADC4CAC6BAC6C4
BABCB3BCBCB3BCB6BC90C6C4C0D5BEC6BEC4C0CAC2C6BCC2
CCCAD5CAABD3C6BAC8C2B1B8CFC0C8D7C6D3DBD1BCB6CDCF
E1D7C8C2D1A9B4CA
B4B1B3ADB3BEB6C2C2CCAFCDBEC2C0B4C0BAADB4C4C6C0C4
BED1BAB3C0CAD1B8B3BED1CCC0BCC6B4C0B6B8BCDBCAC6C2
CCC0B6C0D3BAC6CAB3BAC2BCC4C0C2DDC0AD949DD5B4B8C6
CDB4BCBEC0BCBEC0C8CDA1CDC8BCC2C4B6CDD7C6BECDD1CA
AFAFBAC4B3CDBECFC09FD5ADBCD9D7CCC8C2CABABAC6BCB1
8CBEC0B8D3CA9FFE
D18EC0CAB8BEC8C0B6C4B8BAC6BEC4C0BAB4C8CCC2A5C6B6
C4C0C6BCA1C8C2C4C4C6C4D1B4CA92C2C0D1CFD3C6A5C273
CCC8BEBAB4C8C8D7CAC2C4B8AFC0BAB4B3ADBAC2BABCC6BC
CAAFBEBCCDBEC4D7D1CAADD7BABEB3C2B6ADA7A9B1CFBEC4
CDD5CFC6CAC2C4B4B4BCCDB4CACCD9B1CAC4D5CD7FBAC2C0
CCB3B6D1BAC0C49B
C6CDCABABCB6C0C2C0B4A7B4C0B3BEC0CDB3CDB3C0BACFC4
BABAC8C49FB6C2C8C4C6CAD9BED3B8D7BABAD1C0C2AFC8C6
B4CCCDB1B8CFD3A9BABEB4ABB3ADB4B34EB3B4C2CDB4B4AD
BCB6BCE5A5C0B8BCB1BEC2C0C6C2C8CAC2B8CAABBAAFABA3
BEAFC4CAADC4C4CAD1BAC4D5CAC4BCCDADCFB6B3CACFB399
C2D5C2B4D9A1B8A9
BAC2C4B4B4BEBACDCCCFCAC4C2C2C0CAD1B8B3B4D1C0C2C0
C2B4BCCAC4BEBCC4CAB6CFC8B6BEB8BCB3C8C0BA9BBC86CD
B6CABEC8C2B1C0B4B899BCBCBEB8C4B698B6CFA1C4CDBEA5
B4DBAFC0D3A5B6B4B6D9CAA5CCD3B3D38EBEBCCCB8CCB4B8
BCCFF8C2BABCCCCDBACFB1BEC2C6C2CFD7B3D9A3CFCCC0C2
B1C8D3D5C447B6D1
D1C2B3E5B8C8BAC2BEC8C4BEC0C8BEBEC4C6BCB1CAC4CCC6
B6C2C4CFBCBEC8CABCBACAC2C6D5B1B8B8CFB4BECCB8C6C8
A9C8C6B1CAC4BAB89D9FABC0C4B4B6B1A7ABAFC4C4C0CDA9
D9BEC8CAD1BCD3C8CFBAD9D9CAC8CABED1BCC4D5C0B1C2CA
C2C4C0C0C6CCDBC2BCB1C2BACCA7C8C4B4CABCCAC2CFB8B8
B3B6C6AF5C7FC4C4
BCBAB6BCBCCAB4B3BCCCB8BCCDBEBACDD1C6AFB6B6CFC4C0
C4BEC0C4CCBACAD3BABAD3CCBC9FC6CAB4CCC2C8D1CACCA5
B6CDBEBEADBCC0BAB6BAB6BEBCB4AFC2CC9FBCB6C4BAC2D5
C8BED5ABC4DBAFB4D1CFBAD1BA9DC4C2A9ADBABAC2B8C8DB
D1C8CFB4C6B6C8BEC0BAB3B1BACFC0CAC8A5C0CCD1B8ABAD
B4D3B8B1BEB4BEC0
B6C0C8BEB8C2C6BAC6D3C4D5CAC0C8CCD1C2BCC4BEC8B8C2
BAC4BCBCC6BAAFCAC6D1C8C6CFB6D1B4BECAA3BEB1B6CAC2
AFA590BAADA3B4BABAC2BE92C6CDB6B4B8B4C0C6B1CACAB1
B3C0D1D1B4BEC2B4C4BCCAC6BCB3AFADE3C2BA98CAA7C4DB
C699C8C6BABEC6B6A7B6B3BECCD1B3BCC879C2D1B6B6CDC0
B8C0BCD9CFB6BEB1
B8ADC6AFC6C8A9C2C4BCBACDCABECCCAC0A7CFC6BCBCBEC4
C4C4BCB6C8B1B8BEB6BEC8CACDB3C8C4BCD9C4C6B4CAD1BC
BABECDCABCBABEC4B8C4CACCC2BABED3C0B1A9AFC6C8B8BE
B6D1C4BCB1C2C0CFD1C4BCCCC8B6BADFA9B4B4CAD9CAB6C4
CCC2C8C4CACDBCCACACAD5C0D5BAADC0C2D1D5E8C8D5C6D7
B4A9C8C8C0C6C2C0
BEC6C4C2B4BCB3CCC8B1B4C0BEC2BABEC6CCC2C6A7C0C6C6
B6D1BCB3C2BEC2BCBCBEC4D3C8C2A7BEAFC0B4C2B1C6B8C4
BAB6BECCC2A5C6ABB4BCC4BCCCABC6CFC280B6B3ADB8A1CD
C0B8B8A3CAC8BACCBCD3A9BEC2C0A9ADA9C6B8BEC8B699CC
CDA1ADCCCDC4D9BEC2CDB6CFCCD3C2E6C2B3BCCACDCFB8C6
D3B6C2C8CCB8C8BA
BAD7CABEB8C6CAC4C6B8BEB1A9BAC2B6CAB8BCC0BCAFB8C2
C8C6C0CAC8CAC8BAADB6B6C0CFC296CA9BBCC0C4C6CDB3B8
C8C4BCA79FB4B8BA9DC4BEC0BAC6C2B4B8C6B8D3C4A7D1CA
C4BCB4CABEC8C8C2D5CFC2C6C4BEB6B6C4BCB8B8C4B6ADB6
9DB1C4C0BCC6D3D5CC82D5CFC6BCBECCCF9FB39BADC0BEC0
BEC4BACFB8C4CAD7
B8CDB6B4C4C0C0C2B3C0BCC0ABB8B4BAADBEB3D1C6CFAFB3
BECCBCB8C4C0B3BCBCB3CCCCB8C6BACCD9BAD1CFD9C2ABBE
C6BABCB6ADB8B1BABCC4B4C0C8C2C0C6C4C2A5ADC6CAB1D1
BEB8B8BAD3D1BABAC4CFB4CDC0BABCCA7BBAB8B6C4E3CDD5
BAC4C0CABED1BCDDB1B1CCAD99C6C6C6BAC8CABCB6C0CDCD
BAB8C4BAC0C4DDC4
B1C6BAC0A9C0C4BEBEB6C0B8C6B8CAB3C8C8C2B6C2C8CDCA
B4CDC4C2C6CFC0BCB3C2BEC0C8CDC2BAC8BEBEADB1CF9F7F
CDA9B8AFC8B1C4C8C2C4BEB6BCBCCCB8C6C8BEBEB4C2BEC4
BEBCB3B8AFC6C4CAAFD5C4B6C6C0C0AFC0B8BECCCDC0CFCC
C2C4C8BEBEBAB8D1BEC2BAC4CA84C8D3B862B6BEC0CCC484
AFA7B4C2CDC4B3D1
C4AFC6AFCAB4C4C4CCC0B6AFBCB4C4B6C6B8B6B1C2B6CDB8
BEBABECACAC2D3CDC0D1CFC8BEBCC4CCBECAD1C8A5CDA9AD
B1B1B1B8ADC4A5CFC8BEC0BCC4CDCAD3D1C0ABB8B4C6BCAF
C4C09FC6C6BEC8D3C4CCC0C2C4BCCDC2BCBCC0CAC8D1C4CA
B1B4C4CDBECCBCB3B6CAC4CACCCCC4C8CCC0D3CFD3B8C8C6
ADFCB6C4CDBCC8B4
CCB6B8BABEC6C8C4C0C6C0B8BCA9BABEC2B1A7B4CCB4BEBC
B1C0A1BACAB4C4CDB6BEC8CFBEBCD1B8B6C0B8BA82BABEAD
ADC0E3C4B8C6C0ADAFB3B6C0D3CABAC8AD92A7B8B4BCA5CD
C4B3C4A9C8B1B6E1BAD1B49FAFB8E5C4CFD7C0D5B3B6C2CF
B6B3CCD3D9CFCCC6C0CFCACAE1CFD1BEBECACAB4CACDCCAF
C8B3C0C8CCC4CACA
B1B4B1CCC6C4C0B8C2C6BCBCBCCCAFB8B8BCBAB6B3B6BAC4
C6B6B4CCBE9FBEB3BACACCC8C4CDC6BAB6C4CCA9AFC8B6B3
C0CCCACDC8C6BEA3B3C4D9CFBCB4C8A5A5A78EA5B4B3C4AD
CFC6CACFB4B6A3C2DDABC0C2C6BAC2C6B1C0C6C6C6BEB3BC
B1CAAF9FCAC2C4CFC2BAC0D5C4CACFCAC2B4D5B4AFBAC8CF
BACAC4BEC4BCCFC2
B4C6B1B8B8D7CABACCBCC2C0C2BCC8C6BEBCC6C4B1C6BED3
BEC4C4C2CDBEBCC2BCC2C4CDC4C2CDB1BECCBEBCB3A7CDBE
A5ADBAB3ADB6AD9FCCC8CAB686B1BECCB3B3B8C0AFB8C4CA
CAB8C2B1B8B3C6CDB6C0BEDDCCBCC0D5B6C8A9C6BCD5CAE1
C4C2CAD1CACFC8CAC4D5CCC2CDBADFD1D1C2DBB4CCB8C2AF
84B3C6BCC0CAD5BA
ABBAB8C2C0C0CCBEC0BECABABCCCCDB6BEC2C0C2C8C8C6BC
C4AFC8D5C6CCC8C4BAC4C8D3BAC6C4D3C0BCB1C6CCCAB4C4
DDD3C2BAC4AFC0CDCCC4CC90BAC8C0BCBCB8AFC0C4BEC4C2
B3C2C2C0C096BED5C0C8AFD3B19DC0C6CDCACCCACAC0C0C0
D1C6B8BED1BEB3B6B8BEC8CAC2CDD7D7D5CFD5ABC4B4BCB6
B4DDCCC0CDCCCABE
B6ADA9BEB3BCAFBEC4C0B4B4C4BEC4B4B8C4B1BEC2CCB6CA
D1B3B4B4C2CDC0CAC0C0CCC2C8C4D3AFBCBAD1C2B8D5D7C4
B4D3D3C0D3BCABB8C2D3C2BCB6C0D1C0BCB4B3B4CAC4C8B1
CFC4C6DBC2B8CFCDD5CFCDCFC0BABEB3D3DFB8CDB6BCB8B8
C2C6C4D5D5BEB8B8CAE1CDC4D7D3A5C8CABCD5C8CAC6C4CC
CD86B6C4CFBCC4BE
B1AFC4BABAC6C4C4C0C4C8C6CDCACDC6C2B6BCCAC2CCC8AF
C4BAC4B1CCCCB49FBCD9C2D1C0D184C8C294CDB8A7CDD7B1
B4BCCCADB6CCA7B3C0CFB6BAB8BEC8B8C0AFB4B6C2C2B8BE
B4CFCFC0C8CF94CAB4C2C2B4AFA9B4B6BEB6B6C0B6CCB8BE
CAC0A9BCCCD5C6D5BABCBCCCD1CDAFC0BEC6AFBCCDEE8EC0
C0C8C6B4C2CDCAB6
C8C0C0C8C4ADC4C6B6BCCAB6C2BEC8C8BACAC0B3AF7BBAC0
BECCBCC6C2C4B6C0BABED1BAC0CAC4CAC2A1D3CDB8BACAD5
8CC4CAB8C2ABA9B6B199B6B8CABAB8C0C0B8A1BCC6C0C0BA
BCD5B6CACD98CFADA1C0B1D3BAB6C6BCC6C8C2BEC4C2BEC2
D1CCC2D1CCC4C0D5D3C8CFCDC2CDCDC4CABCD7CCC6CCD3C8
BCCCC8B8CDC4CAC2
AFB1AFBEBA9DBAC2B3BAAFB3C2BEB8AFB6C0C8CABAA7C8C4
CCCAC6CF96B6ADBECDC6C8C6BAC8CCC8AFB8CFB4CAB8A19F
A9B3C0A3B8BCB8B6BACDC0C6B1C6BEA9BABA94C0ADD3B6D5
BEC2D7ADCDB3CDB3A7B6B390C8BEAFB1C2B6ADABB6D3C0D3
CCB6C6CACACDD1CCB6C2C0AFBAC4A3CAC2D7C6C2B3BCECAF
C2B6B8E1D9C2C0BA
BAC8CAC0C8C0CDCCC8CAC2C6C0C0BABCBCA1BABEC4C4B6C6
C8B8CAC6C4C8B8BAB8CCD3C2B8CCBCD5C6BCC0A3C6A9BCC0
A7BEB6D3C8BCC4BEC0C8B6BCBAABC6BEB8B8B3B6DBCFB6C4
BCC0CCC4B6CCD1C0A31AC4C6CDB6C4CCC2B6CDC0C4CAB6CC
CAC8CDCAC4BEBCD1C6DBD3C699C0CCBCD1C4C2B4A9BA9FCF
CCC4ECD3B6A7C4CA
AFB6C2B1CAC0C0D7C2BEC2CCB4C0B8CDC4BEBAB6B1C2C4BA
D1CCC6B6CAC4BABECCC0CDBCC4C2DFCACABECACCD7CDC4B8
C8C2BEB6B1C6C4B6A3B4ABC4D3AFC2C2B6B8A5CCB3EAA9BA
C0B4B4C6CFC4E8CA99C2C2A9C2C6B3BAB3BCC0C4CDBCBED9
C2C4BEBEC6C6CFA7ABCCC2BEC4B1C6C2C4D3C8C0B3D7BECC
C4D3AFCAB3CACAAF
A7BCC0BCBAC2BEC8BEBCB3CCC2D7C2B3C2CAC4BEBEC6B4C6
B6C4C6C8C2C6BEC4C6C4CCD1C8D3BCC8BCBCB1B6C4ABC2A7
AFD5C0BAC6BAC4C4BCCAC2D1B4C4BCD9B8ABD3BCE1ADBAB3
BECDABCDC6E1CDBAC2A7E1CDB6C2BEC8C8C6BEDDB3BCBAC2
D1CC96CCD5B6B4C4CCCCB3C4AFC6CABCD1CDBCB1C0CF77B3
B8C2C6B1BCADB1BC
A7CAC0A7C0C8BAC6CDB8C6C8CCC0B8A5BEBEA7BEBEC2BABA
CFBEB8BCC4C0B8BAC0ADC2CCC0C8B6DFC2C0CAD1C6ADC0CA
C0D5C6CCC8D3B1ADB8C2C0B1C2CFBCC8C2B3B4BAA3CABCCC
A9C8D7E8CDC4BAC4C8C8BCC8C4BCAB86B3CAC4A3C2BABECD
C6C0C6D9DFDBCCCFBACCCACDCCBCC8BECCC4A9A9D3BEC0C2
A7A7D9C0D1C2C4B8
B4B3BCD1BCC8B8B8D3B6BCD3B4BCBAB6B8B3BCC8C6C6BAC2
C8BEB3BCC4C2BCCACDC4BEC4C8CCDDD9C6C0C2CDCDC0CCBE
CCBECCC0C0C2D3D5ADC4A9C4CDC4B3B8B3BAB6B3B3BABAC4
C2ADD3C6C0B4BACCC6BCC2B8B8A7C6B8B8B6B1BCC0C2C4D3
CCCDC0BCCCD9CDBAC2C4D5C8CCD3CFC6C4B8B6A9C6C0C0BA
D3C8B4BCCAD5BEC4
B3C2C4C4C0CABECAC0D3BABEC8BABCCCB3BCC2BCC4BEB3B8
C8CAB8C4BEB8AFBEA7B8D1C2BACAB6C4BAB4CFC0D5C6C4AD
CAD3BAC6CAC4CCCAC8CFBAC8C0A3BADD92A3A5B8C2B3CFC8
C8CDB8CCB3C6C4B4B8C4C4BCCDBAC4B8C2BACCC6D7BCCACA
C0CABAC8CFC0C2A7CAC8C8BCB3C4CFD5CFC8BEC0CDD1D9BE
BAC4C0BCB1BAC8BC
A9B6C2CAC6B8BABEC4B6C2C0C4BEBEBEB6BAC6C8C6C6B4D9
CDC6A3CCC8B4CACFBCC8C2C6B8C4CFC0B6C4B3ADCCC4B8C0
BEC8C4B4B8C0B4A1D3B3ADC6C8C6C6B89FADB1B6C4C0C8BE
C0BCC8A1CCC8C6C0BCCCB6C8BAB1BECCCFBAB4C6C2C0C2C2
CCC2B6B6B8B6BCC2D5C0B6CDDFC8C4C6C8B1BABCC4A7BCCC
DDD1D9CCC6C2CABC
B8C2BCCACFB4BACAC8C0BEBCC2AFBEC2B3C4BEC6BE9BA7B1
B3BAC2BAB4CCBCC4BAAFCABCC6D5CDD1B6B1C4C4C2C0C2BC
C2B6CDCDCACCA7BED1BECFC6C0B1BEB3B6C0ABC8C4C6B6B6
C6E1CCBAE6C0B1C2D7D3C6C6BCB1C6ABBA92C2EEC2AFB8CD
C4CFBCC6CACDCACAD7A7AFD1C8CDCFCFBCD1C2CDCCCABAC4
B4C2C0E3CFC8D7C8
BEAFC2C2C8C8C0C4D3CCB8B8B6B8BEB6B6C0C2C6CFD3BEBC
A7C2C2BCCCB8B6C4B8BECDC8BCBCC0C2B8D1B3B6C6EAB8B8
BABCBECAB4BCB4BECABEBCC8B1B6B3BEC2C2B4C0BEC4BEC2
CCBCB6BEAFCCBAC4DBB3C8D5D1CFC4BEC6CDD7CCD3B6C0BC
CAC0B4C0CAC4CCCCCCCFD3C6CFD3C2CCB6CFB1A19BC0C6D3
C4C6CCC0ABC6A1BC
ABCDC0B4C4C0ABB6C0A7B3C6BAB8C8C0B6C6B1C6B1BABCCC
C6C2AFB6C6B4C0BEADB8DBC0B1C698BAB6CDDFDDB8D1BCBA
B4C4A7B6C8CDC0B4B6BAB3CAB4B3C2C0C6B1BCC6AFC2D1B4
9BB8CA9DD9C6C8C4BED3B1D3B1CFC4CCD1C0C0C4C68EBAB6
B4CDBCC0CFCAC0E8CCA3CCCAC8C8CDCAC8C8BEABB8B8A784
C4C2CCB1B3A3C4B6
C6CAC2CAC4C2CACAC6BEBAC0AFC2C6B8CAC6CAC4CAB1C2B1
D3BEA9B8C0B8BCCCBEC4BEB4BACCC8D3C0C6B6BCC0A7ABBE
C8CFD1C8C0CCCCC0BAB1C6CAB8B8C6C6B4BAA9ADC4CAC2CF
BECCCAB8ABCFCCD3CDD3CCC2CFC8C8ADDDCDA3B1C0B89BA3
C2D3D7CFCAC2B6C682CDD3BCADC6CCB8D1A9A1BE7DB1D5D3
BA8EC2C8B8C48CDB
C0BCBCC4CAC2BEC6B8BAB4BEC2BCC8BAB3C0C2C2ABD1C4CA
C8BCBEC0CCC8CCC6AFA3B4BEBCC8C0B696CAD5CAB8C2C8CA
D5C6C2B4C2C8B8A9CAB6CDD3B1C0BAC4C8B4B3C6C0BAC4A5
B4B4B8B6CAD1CAC4D1DBB6CABEB4C4D1BAC0C4CFCCB89BB1
C4C2C6CDC6C0C8CFADBCA9AFC8C8BECA629BB6D9A390D7C0
B3A7B899BCB3C0C4
B6C4BACCD1B4A5BACABAD5B8BCC0BEADBCB6B3C0AFCCB8BC
C6C4B6C4C8C2B8C8D9B3CAB8B1D1C6AFD96FC6B3C8BED5D9
C0D1BCCCB1D9B4CCC8CADDB1C8BEBEC0BAABC4C8B3B3D7CA
BEC6CABEC2BCC6D3D9B8B3C4D5C6CFCCA9ADC6C0B6BED7C0
C2B6ABADBEBAC4D1B4BAB8C8C6E1C0BAABCFB19DA3A7ABCA
C2B4ABD9CCF6CAFC
C0C0BCBABEC0BEC6C2CFC4B3CABEC2BCB1B1BCC4C2C4CCC2
BACFCDC8C6BAC2CFC0B1CFCAC8CCB1D5B3B3CDADD3CAC2CD
D9E1C8ABC0D1B4A3B1C2C8C4BACDC0C4C4C0A9BAB6C2C2CC
C6C2CCB1C6D9CCBECABAADC0A5C0C8C2BEC6D5BABAC6BECF
C0C0CCC4BCCFB8B8B6CCC8CAB6BEB6C2C2B6B1B186C0A7B6
A5CAC2C8CAC6CD94
B6C0CDADBCC8C6CAC8CDBEBACAA7BEC8B6B1BAB4C2C0C8BE
C2BCB4A9D5CABABCC2BACCBEBACCC2C89BC0CDB3BEC4CABC
C8E5D1D7A3D7B6B4B6BAD1BECFB6BEDDBCB3AFB3C6BAC2A9
B3CAB6E5D1CCDBBAC0C8D3DDC0ABC4C6CABEC6C0CFCDC2D1
C2CFCAC2C0C2B4C6C6CAC0BCD1C8C8B6B3BCB6B6C6CDB8C8
C0BECDCCC4BCBACA
B8AFC2BA9DBAC6ABCFC2BEABC8C8BEABB6CAD7C2C29BC4C4
BEB1A9CA00AFB8C2BAB6C8CCCDCABABCBE92B8A3C2C4BEA9
8ABEC2BAAFD1D1C8BCCAC8C4CFC2B4AFC8C6ABBECCCCCFC4
C8C8BAB16FC6B8C6B1C6C6B6B8BCB6C4D5C8D1BCB3CDC2D9
BCCDE1A1BCB6CABCC8CACACAB1CDB4CABEB6AFB6B8D7A5C0
B3A1CCD3B3ABD5D9
CCB6C4C4C8BECCC6CDC2CFC6B4A7C0BCBAC8C0C6CDC2B4B4
B3C4C0C8A3BCBEB4BAB6BCBECDC6D9BED1C8B69DB8B6C8C6
E3C8D1B6C2D7B1D1A9C6B1ADC4C4C4B8CABEA3AFC2CAC2B1
B6C2BA67B3BEB1DBB6BEC2B6D5C8D1CFD7B6CCB8CAC2BECF
B8C0B1BEBEC2D1C4CDD3B4C8D1B3A9B1B3C2B6B4CFC2BCBE
C2C8B6C2BED9BCA1
C0C2C6B3CCC8C2D5BEBAB8BEBEBAB6B6BAC2BCC0B6C0B4B4
C6A9BABAC6C2BABCD1ABCCC0D3CFCFB8BECDD5CDE5B1A3A7
C4B4B4C8CCC4CFB8DBCDD3C0C6CAB8BAC8C6A5AFC2C2B4C6
B1B3CCD1D7CFD3C4C8C0DFC0B1B6CCCAC4C0B4B1C2B3D3C0
C8D1C0C2D5E3C8ADBEB8D1B6C6B39BAFCFCDB6AFF2B1C2B8
A7CCBEDFCABAA7BE
BCC2C6B8ABB1BCD3CFCFC8C4BCC2CCCDB8B6B8C8C4B8C8C2
B6C2C2BEC4CAB8C8BCCCC0ABC2C8D5BABCBCBCB6AFC2BAC2
B3AFB3CCE3C4A5B4C4E1C0C2CAB8AFCCCAB4ABC8B6B1CCC2
B4D1C8C8C4C0C6C2BCC0D9C6C6C89FC6BAC4CFC0C4C6C4D1
CDB4C6BACCCD96B8B1ADC8DDBAADCDC4CDCAEEDDBADBC4AF
BCBEB6BECABCCFC2
C0B8B3BAC0C4B8B8B4C6B1C6C8BABACCC0BAB6C8B3CAC4C0
C2C8BAC0BEBAA7C0C2B1CCC0ABB8B8C0CACCCAF6DFDBBCC6
CAB1B8CDC4C8C0CDB8C2DBC6D7C0B4C8CABCB8BAADCFBEB8
CAC0C4C6CAB4C0BCB3CDCDC4B3C0A7C0C2C0CCB3B1A9B6C0
BEBEDDD3BE96D3B6AFAFC8CAC2D3B8CAABB4A7BCAFC8C8CA
D1C4CDB4C4B6C2B1
BEADC8A3B8B6C8BEC2B8ABD1C6B3C4C6BEBCC6C8C2C8CACD
B6C6C4ABB8B3C4D1B3C2BCB8BAC8C0B4C8C0CACDA7C2CAAB
B4CDCCB6C6C6ABC4BEBAADC0C8CFC0ADCCB3A3BCCCBCBEBE
BECCAFD1CFCCCDBCD9CDCDBC9DBEB3BC9BC6A5CCCCB6B8BA
C0C0F8A5A1BE86C8BAC2B6D3DBBCB4BCCACCBA98DFC4B8A9
C4CFB6C8CDC6CCB8
C8CABCC8B4BCC0B6B4B8C0BCC0BCBEA1B8C8C8CAC0CCCAC6
C2C8BEBCB3BAB3A3C6B1CCC8C0BEBAD3C0D7D1BEB3AFCDBC
C8C2C2ABC6CABED1B8B8A5CFB6BCA97DC6C0A5BAD7D5CDCD
BAAF99DBBCCABCBCB8C4DBB1BAC4B3B8C6C0B4B8C4BEB6D5
CDCCBAABCFC2BCCAA3B4CDCCC2B4BEC2C8C6C6B8C8AFD1C6
D1E5D3C4C0CDB4B4
C2ABC8C4BEC4C29FC6B3A1C6BCCFBEB8CCC6B4A1BEB1BCCA
BACDC0BAA5B1C8C4BAB3B3D1CFD7A79DC6C6BCB6BCC8CDC2
BEB8C6CDD7E8C2C2B69DD9B6D3D1B4BEC8AFB4A9E3B6ADBC
C6ADBEC8BEB4B3C4CCC4B4A7AFC4CDE1B6D5B1BED9A7D1BE
B8CAE1ABCDCACCB8CFC4C8C2CDB6B4CCBEB4C8BEC2CCBACF
B6C0C094C4C6CDAF
BCBECCC2C8C4C0BEBCC2C0CCCABCC6CDB8ADCAC0C0C4BEB8
B8B1CAB6C0C0BECABCB6C4CACABAB3C2AFB6CFBAB3ABC8C4
CDCFCDC6D1D5BEB6A9D7ADC2BEBACAC2CCC2BEC8D1AFC2B3
BCA3B6CC9FC0B6A5C2BCDDA5D1C4BAC4C6B3CAC8C4C2C2AF
ADA5C2BABEB3CFCACAB1ABBAC4A3B394C0B6B6B4C8C8AFBC
CDBEC6C0A7ADBC7B
B6BAADBAB4C6C0C8CABCC6CCC4C2ADCDC0ABADCCC4C2C8C6
B8C0CABEC8CDB1B1B6C8C8D1CCC0CFC8C8C4D1B4A9D3BEB4
CDAFD38ACCB3C6A1C2C0CAB6BECCC6C2C4A9BED9C0D9C8CA
B8C4A7C2B471B6C4C8E1E1C2BCC2D7CACCBAC6C6BAD7CAA3
BECDC8CACABCBADFC28CB3C6ADBAB18CB89BC0CDC6C8C2CA
C0D5CFCCB4C4B3AB
B6BAD9B3B8B8C2BEB6C6C4CABCC6C6B6B8CABAC6BACDC8C0
B1ADCCD79BCCC4BABAABCCBEC8CDCAD1C4B6CDB8AFCACACC
CDCCC2BAC6ABA7D9CDC4B8CDCCCCC8C0B3BAAFBACAC4C8BE
BCB4CF82C4A3ABCFD3CFCCBACDCAC6B4BEC8BABCB8BAAD92
CCB6C4BCB6C2A1B1CACD9BB4CABAC8AFB3C2C6CACDC6C0BE
C6CAC0CFD1D7C4AB
B3C2C4C2C4C4C6B3C2C2C6C4BCB3B3BAB6B6C4BEA9B8B6C4
B8C0C2B899B3BEBEC4BACABEBECFB6CDC4D3B6CFBEA9CFC6
CFC8C2C0C8C2BCC2D3C0C6B3C4D1B4BECCCAB6C6BEC6BCCC
CCC6A7BCBA96BACAC0CDBEBACABAC0B4B8C0C4AFBCBCB3B4
E3BAABC4C2D3C0A3CAA7AFB8C4CFCAC0DDEED3B1C0B3B1BC
C4BEC0AFD3BAC0AD
ADB3C09DB4B8A7B8C6C2BAB4D3CAC8CDA9BEA7BCCCBCB4B4
B8C6C8BABCCCB6C0BAA7B3C2C6CCB6B3CCC4C4C0BACDCCB4
B6D5C2CAC6A7D9ADC0E5B4C4CDB6C4C2ABBECFB6ADC6CCC8
D7C2C6C2B49BCAC2C4B698EAC0C2B4ADD1BCBEC4BACAC698
AFB3C2BCCCC2E3C6A1C0C2C0CABEBEC2BCC0C6B8CFC2D1C2
C4C6BCAFD1A3C0C8
B8B6C2BACAC4BEB4BCC4BEA3CAB6C6D5ABA5B8B4B4C0C8BC
D7C2C0C0B4C4BCBEC4B4C6B4B4D3CCC8B8B1C69DBEB3C6CC
F837A396C0CAC2BEB1CAD1CCB8C2B3C4C2A5C8B8C8BAA9BE
BCCAC0BEC4A3BA92D7BAABC2C6B3C8BCA3C6C2BCC8BABAC0
C6C2CCAFB6C0CCC4B6A796ADC2D5C4AFBCADC8C8B4C6BCBC
BECACDDBCCB8B4A3
C0B6BEC2BEC2B8BEC2CDCCCDC0BACABCAF847DC0A7D5C4C0
C8C0C4D7AFCFB6B6C0DBCAC8CFC4CCC4BABCB4C2CABEBAAB
B392CCB6ADD7C2BEC8C2C0C6B3CDC0DBD1B899ADC2C0C6C2
CDCCC6C299BAA1A5B1BEB3DDD1CF92A7CCADC4CFCCBCB3B6
C8B399D7BCC088C0A9B3AFD19BA79DBED7C2B6B8CAC6B1C8
D5CDCAC6C6C0BEA9
C0B6BAB8B3CDB8C6C2CAC8CAB4BCB6B8C8B1C0C2B4C0B4B4
C4DBBABABEADB8D3BCA9C4C6BC9FCFC2C8ADB3C2CDD3C0C0
BEC6C4A9BEB6C4C0B6E1A5C2AF9DB3C6BCB4B3C8B6C8C6C2
BECFC6ABCABC90B1CCAFCFBABCB4B4CDC6C0BACAB8B4A3CA
D7B1BCBECCC2C8BAB48ABABECDC8B1CA84BACAC6BEC8C8C4
C2C894B4C8C0BAA5
ABB8B4BABCC6B4A3C2C2BCBAA3C8B1C2BCC8C0CDC2BEC6CA
CDBCB8BEBACFC2BCBECABAB3CAC6B6B4BEABB8BEB8B6C4B6
C4CAC4DDDDCFC0B4BACAD9A3AFA5BCDDC6BEC8B4B4C8CCCD
C2AD98D5CCC8B6A9C6B8D3C8B6CDBAC0A5D3BCAFA7B1CAD7
B6C0B1A9C09F98C0B3B8C0C4A599BCBEC6C8BCBCCCCAC6CA
CDD5C6E8B1B39F9B
B1B6A7B6C4BEBEC2B6BAB3BCA1A5C6C0C8B8C2B3C6CFCAAD
CDC2C6C2C8CAC2C4CAC2B6BABEB3BAC8D5C0C4AFBEC4CDCF
CCBEC0C2D7B4B4CAB6C8C8BEB8D5C2B8CDBCC6B6BCA5BAC0
C4C8B3BAD5C6BEA5ADD3C2ECADD3B8B8B1C4BA9688B4B4C4
BAC4CDA5B4BAABBEABC6C6BCBAC4C8BAB8CFCDD3CFD3BEC6
CAC8BECAB8C0DFAF
B3B3B1C0AFADBCBABEC8C8AFBAAFC6C2BEBEC4CAC8A3BECC
BAAFC6CABEB6BAC6C4C0C0D9D9D9D9C2B4C2C6B8BEABB4C8
C2CDAFC8C4CFB6B3CFD3C2C0A1AFC0C4CDB4A5B8C2CABEBC
CCBCBEC2D7C4CFAFCFC6CAAFBEC89BC288D3C8ABA1B6B8B3
C4BEB6C2B1A1B6B8A9BAC4B6C8CFB4BAC8C6CCB1C8B34EBC
BEC4CAC4BECCC8C4
C4AFB1C0C8CCC09FC8B4C4B8C0B4B6BEC0BEC0C6BAABE8AF
BCC073B8BEBEBAB8B3ADD1CDD9D3C4B4C4BCBCC8C0B4D3BC
CCDBE6D1A3BCB4C4CAD3C0CACFCDBCB3969FB3A7BCC2C6C0
C8CDCAABB4BEC8BAC0CFA598BCBEA99F9496B67F9DC4BABC
C0C2DFBCBEC69B98A5C4C6C6B6BECCC2D7C6C2D1C6BCB6B8
C0ABB8C8CCC6B6CA
B4A7B8A9B6B3B4B8D5CFC6ABB3BCB8C49BBCBAA79BC2AFC4
B4B8ADC0C2C2CAAFC4DBC8B88666A5BAC6C4B4B8C8C4B6C2
C6C6B8C8CFCFAD9BB3A7C8B8BEC8C6BAC0BCC6C4CCABBCC8
C8CFC6CA94B3BCC2CAB1AFADBEC2B4CDB1A9C08684A9CCD3
9BC0A9B8ABCFB4BEBAC498C0C2BEDFBACAB4B6C0C2B6CFC2
B3DBBABCD1BEE1A1
A9BAB4B6ABB6B4BEC4C6C6A9B4C6BAADB4BCB6BAB6D1CDB1
ABBEB6BEB6A9A7BCCAAFBA94C4CDCDB3D5B4D5AFC4AFCDE3
B8B8C4B6B6C8CAB4CDC2C0CACCC4C2CCC8B3ADA7BEC2BCCF
BAC4C0B1CFB4BAC4C6B699CABAA7BCC0ABC28C98B1C8BCC2
B8B6CCC0B4BCC2B6CCC6B8B8CFC2BAB6CDBAE3C2BACDBCC2
C4C8C4DBCFC0B8C8
B4C4B3A9B6D7CDBABEB6BEB6A7CCBAC4B3C8C0BCB8C4B8AF
BEB3C4CDBAB1BCBEB49D9D84B4BCD1B8C4B8B1C8C0CDCDC8
9FC2D1CDC2BACAD1B4D3CFCACAE1CFB3BAC4A9B8D3BECAC4
BEB6BCC09DD7A9B1CDEA7BD59DCAB4BABEB6A99DE1CAC49B
ADBABAD3B1D7DDC4BCB1C6D7CDCFE3B3B4B89FA9C0B6BECC
BCCCCFA3CC94CAC0
BAB6BCC896ADB6BABEBAD7B1AFBCB3B1CCC0BEC6C0B1BEC8
C4CAC6BCBCCAC0CDC6A7ADCCC8B6C2CAB4CCB8CCC6C0C0B6
BAD1CCC8CDCABEC8BAC8CCC0B8D78CBCD1AF98AFC8CDC0C0
C69BB1C4C4C0CDC0ABA99BD7C0DDB6BC9FD5C4A788C0CC9B
CCBCE5D5B3C6B6CDAFC2C0C4BCCDBAB8A9CACC9FA9C0C0B4
BECFB3BEC2C6C2AF
B6BAC4C4C6A5A9BAC0C6C69FB4B3C4C6C6C6C8C2B3C4C4C4
B1D9C2B6A9C49DC4CDC2B8B8C2C4B8B1B6BEBACCC0C8B8C8
CAA3CCC4CDCDC8CD9DC0C0AB77A7ADB8CCADC0C4BECDB6BA
C0A7B89BD1CDBAC0D3B8C08C99A3B3B39B88A9A1B3CFC6C6
B8E5A1B3B6C4B1A5B1B4D3ADCDABB6C2C8C0D7CCC4CFBCB8
B6C4C4B8B1BAB4B4
B8C4C2B4C2C2A7B4C2BAB8C0A9C4BCBAC4B1BEBEB8BAC0C4
C6B3C4C0C2BCA5B4C896CCB1CAC8C0BECCC8C2C2CCCFC6CF
A3F4C6C4C2B4CFC4CFE8B3DBA1D3ABB3C4BABEB4C6B4C4B6
C0C2B1A5B3BACA9B9FB4B38AB8C0C8ABB1A7B69BA3DDADB1
C0B1CFA3CCB4B8C09DBCB1C6B3B4BCB8B6BCC4C2C0C2C8BC
C2CAC4CDBEC0C2B4
C2BED7C2C6B3C0B8B3CAABB4B6B8AFBAC6C4A3B6C2B4C6D5
C0C2BEBCBAB6ADB6BEABB8A9C8CDC8C2BEBAC0C6C2BEC4CC
C2A5BCBED5CAA1BAB8BAC4BAB8C8C2CAC8BEB1B1C6C8C6CC
C2ADC8AFA9C0DDC0CAB4C0ABD5CA8AB6BEB8C4C0B3B3B898
D5BEC6C0B4C6ABC69BCAD1C6D3CDD3CFD1C0B1B1BEBABEBC
C6C4CCC0BCB3B3C0
BAA9C0B8BAB4C4CAB1BCC29FA5BEBEB6BCB1ABBECAD1A3B6
C2C6B3C6BAB4C2BCBCC4B4CDB4AFCDA3C0C266C4C6B8BCA7
C2D3BCD3D5BCAFDBCCB1BACAB3CCB8CCC8BCA7B4B8AFCABE
BCC6BCC0CFA5C8CAC0C0C09FC6CCAFA9C2B8A3BEC8A5BEB3
BEAFB69FCCBAB3C8C2BCCCC4BCCDDFA7B8A3AFA3B6ADCDCD
C8BAA9CDC2ADC2CF
BAB6BABAC0C4CFC2C0C2BEB6A3B3B3C0B4BCB4BEA7B894B3
BECABACABAB4A9B8BEC0CAB8DBC0BA00C2C4BC94B6C8C2CD
AFB3CCB8AFCD9D99B4C0C2CAC0C89FBABEB8B484B4F0D5C0
CCBCAFC6C0B8C2CCD9A1BCB8DBD3D3C6BECABEAB9B948CC8
9BB6D5ABCDA9D9BEA3CFD1D9CAADB8BEB8C2B8BCBCAFBABC
C8B4CAC6A3C2C4B6
BAB6BEADBEB6BCBCBEBAC2B6AFB6B4B6B3B8C2C2BAB8C6AD
C6C8D9C4C6FFBCD1B4B4C6D1BCC6B6C0CACDBEABC4C4CAB4
CDC6B4D5B1C2AFB8B8C8CDD3C4C0C8C6BAAFAFB8C6AFC2B1
C4B8C4D9BAC2CABAB8CAC0C4AFC8BAC4B1A78CA7C8B8BEB1
C2B8CFC4DBADB4D3C8CDB6A3A9B4CC9BB8B4C2A5C4C4C4C8
B4C2C6BCB8AFC0BC
BAB8A9C4B8B4BCD3BCC2BEC8A5B4C6AFAFBABCC0B8C2A3C6
B6B6B1BCC47FAFC2C8B4BEC4C8D5C2C0B1C0B3C4BEC2DBC8
D1C0C6B3C8B3C4C2ABC2DFB6B1C0BCABCDC0C6C6B6B3CFC6
BCD3D5C8BACAB3D5AFBEB8CFCADBD1C4B6BEB3C2B8C4ADC6
AFCCCAC6D3D7CFCDC4BCB49FC4CFC0BCB8CABABCC2DBCCC8
BEC6AFC6CAC4CAC6
C8D9CDCABAAFBAB1BEB4C2AFABBAB1BCC4C2B6BEBEA3BCAB
C645BEBCCFBCB4C4C4C8C0CCCAC2C4C2BAC4C4C0BAC8C2CA
BCBEBEC0A1CCC4C0BCB4C8C2BCCFB8C2CFC4ADA1AFBABABE
BECD90BACABAC8B3BECAB8CDD3C4C2B69B9FB1B6AFC28CC4
B4BABCDB9FB3B6C4B6C8C2CFD9C8CFBA8EBAC4C6D5B8C4C0
C69FB8AFD3C0B6C4
BEB8BCC6B6CCA1C8BAB1C0AD98A3C4BCBAC0C8B1AFC8C6BA
CFC0C4C4A5C6A39DA1B1CFC4B6C4CDC2C4B1BACDC4C6B8CA
CDBEA5C6CCD19FB4C0C2AFC4BECCC2AFD3BE7DAFD1CCCDBE
C8C4C2CFCDCDCCBCB6CAA9B4B8CABABCAFA3BCCA98BCA5BE
CCCCA3B4A1CCB4BACFCFD9CAC4DBCCC4D5C4BAD3BEC4BE96
CCCFCDC6D7D3BCC4
B8C0BEB8B8C4BCBCA5BCC2BA9098BABACAAFB6C6C4D5BCB6
C0C2D1BEB1B4BCC0BCC6CCC6CDC4BCC2C8C4C8CFB6D1CFAF
CDB3CACCD7BCBCB3B8B3CDBACAE1DFC4C8ADBCB8C4D7DFC0
D1CACACFC2ADABC8ADB3C8BCBEC2CFA9B3AFCFC4A7BCB3D1
D1B4B8D1BEC8BCCCC8C8D9C4C8B8CDC0BECCA39BC2B4BAC0
CFDDD3CABEC6B6BE
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -14 0 ]
[.5 1.0125 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Blue) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CFC5C9BCC9C0C7C5B9C3C7CEC7BCB2B7B2BCBCC0B7ADBBAD
D1B0AFB7B9B2BCC2BEC5D1C0BCC5CCC7BBC3C398C3B9C7BB
C5ADBCCABEC0C5BBB7D1AB8CBEC3B6A192B2BEBCBCC0C7BC
9CC5C7C2C9CAC9CEC7C2CCBBC2BEB6C5C5C3C2C3BBC7C5AA
BBC0C2C7C9C3B9C7BBCEC5C2C5C9C7C5CAC9CCD6B6BCC5B9
B6CAC0BCBBC3C9C3
BBCACCB0CCCCC7C5D3C9D8CEC2CAC0B7BEB7C3BBBEBBC348
CCC0B4BBAFB7C3C9B7B6D8CAC5BBA8B6DAC5C7CFB9C3BEC0
BCBEAABBD392BBCEB4D6AAA1BEB7B0CCBEA8C58EAFBEB0B7
C7B2C3D5CEB9BCC7C2C3BCC5C3B6BBBEC3CCD1BECEB0CACA
C2C3B0BECABECAC7C3CFD1CECFC7B4C9C5C7C2B4CCB2C9CE
A3C0CFCCC9BBB4C9
C2C9C5C2C2ADBBCCC5C9C3BCC2BBBEC0C3C7C0C5C3C7C2AF
BEBCB9B0BBB9BEC0CFADCAC9BEC9A8C9C9CCCFC7BCB0C7C7
B9B4C7C3C3C0CABEC9B2ADA1B2AAB7C2B9BBD5BEB7AFC9C2
BEBEC0C5CAD6BEC7C7BEB6CACFC5C5C7C9C9CCC7C3D3CAAF
B4C2CABCC5BBC3C7C2C5CECCB6C5B9BEC9BCD1CEC3B6D8CC
B7C2BCC9C2CAB4C3
BCB9C9B6B2AFB7BEBCB7CEB4CAC2C0BCCCC2C5C9C9C5CCC7
AAB0C9BCBEB9BBAABBD3D5C2C7C2C9C2C5ADBEB4C3CCBEB6
BCBE98C3B9C7CCC9CAB7977BBBADB9C9A8B7BBADB4D1C0B6
C7C3C2C7C5B4CEC7BEB6ADC9BBA8CCC3CAC2C3C7BED6C3B7
C0BCCACAC0C5CAC3C0D1C7CACCD6B9C2B9C2BEB9DDC9DFC3
B7CEBEABC0ADC2BC
C9C3BCCEBEC0C2BEB4D6D3B7B4BCBEBBC3C5C3C5BBB7C3C7
BEC2C39CB7BBABBCC0C5CCBBB9C9B7BEC7CACABEBBA1B7AD
C9B6C7CFBCC2BEABCCB09287B7AFBBD1A4B4C5B9CF36B7BC
C3C9B6BCBCB0B9BCBEB6B9C3B7C7D1CEC0B7C9CAB9C2B9B9
D1C9D1CAC5C2C5BBC7BBBBC0CFB4CEC2C3CFCACFB4A4C2AF
CABCBEB6BBB7B0B2
B6C9C3BED5CFBEC2BECECCCFBCC2CAC0C9C2C5B6BBBEBCEB
A389ABAB89ABB6BCBCC0CFC3CCC9BBCFD3C2B2B6A4BED5B2
C5BEB2BCB0C5C2C5BCCE8E8EAAC3A1B7BCB7B7BBB7C9C2C7
B7ADB4C2C0CCBEC7C2C0C3BCC3BED1C3C2C0C2AFC0B6BCBC
B6C3BBABCAC7CAC0C9C2CFCECFC3C9C7D3BCCCADB7C7B7B6
CFC0C5BBBCBEC5C0
C3B2C2C3BCBEC0C586ABB9CAC7C3BCBEBEC0A1C9C2D5B0D1
C3B4C3BBADBBABA3C7ABD8C5CECCB4C5C0BCD1D3C5ABC2BE
BEC9CCCEB7B0AAC9C3C28990BBB99FBCB7B2B9CE67ADD5B7
BBC2C3C3C0B7AFC3CABEC5BEC5CCC2C2C3C9B7C9CEBCAFB9
CCBEC3CCC3C5B7C3C7CEC7C7BEC5C0C2CACECECACFC7CABE
CCB9C2C7CAC2CAC2
C39FB9CEC2B7CECEB9CFC3C9C9CECACACCC2C5B6ABBBB6BC
AFBBABC9B6B6B7B6B0BBCCCAC3C9B2BCC3C9C7C5BEC3D3CA
C2C3C3DBA8B9BEC9CEC5A190CFADC0B99EAABBC0CAC3D6AA
BBCACFC0BCB4B7C3C5C7C2CCC3B2B2C5C5C2C7C0BCA8B0C2
D5D5CCC7C2BCA1C7CCC7CACACCC5C7C3CE92B9C7B9B4C7C5
C7C5BBB4C5C7BECE
AFADC0B2C7CFBBB2ADB9B2D5CCCAC2B2AFC3BEC9B4BCC0B9
BB9EBCCAB6C2C5BEB9A4BCC7C7BEC3C2D1CACEC7C2CCC3D1
CAC9BEB6ABC9CEC3C2B99CADA3B6B4C0ABAFC2CAADADC2C0
B9B6B2BEBBC9BEC2C0ADB9C5C9ADBEBBCABCBCBCB9C5C7B4
CACAC9BCC7C5CCD1C2CECEB6C2B4B7CFC3C9BEBBC2D1B7C5
C7C5C9C2CAC7C9A8
C5BEBEC0C0BCB9C0BECCC9C2C9CCC2BEC2BEB9BCBEC0CABC
B2BCC2C5C3C5CABCAD7DC2BBC5C2D3CAD6D5CCBCC5C9C7C9
B9B6D1AFCCC9C3BEB7B7908693C5B4B9C2AACFD3C0B4C3C7
C2C9C2BCC9C5B7AFCAC7B7B2C3BBB4CFC2BEBCC3B6B9B0B7
AAC3C5D6B9C9CCBBBBCCCCC9CFC5CCC3CFC7BEBCC0C9C7CA
C0D3C5BCBEC0BCC9
C9C3C9BEB7B7BEBCC3B7C0BEC7C2C9C3C0C5CCC0B9C9C2B2
BCC0C3C9BEBEC2C7AABCAFC7CAC2CCBBCABEB2C9CEC5C5C9
CFCAC3CACCC7C5C5CEB28B9A9FC2A4BCB2B6BCB7B6B0A4C0
C0B9B7D1B2C5B9B7B6E1BBBBB2B4CFC3C9C9B6CED5C3CACE
C2BCBEB4CEC2C5CFCAC2C9CAC5C9D1C3B6CCCFCAC9B7C2B7
C2CCC3DB6CCADB7D
C9C3C0B6C5BEC3B6B9CF90CEC5C5BEBCC3ABC0CEC0B6C2D3
C9C9C2BBBBC0B2BEC2C5CE89C5CEDDB4C5B9CABECED6C9BB
BEBBB4B4BCC9C7BEBEB9384390CCB7C0ABC0BBB6C5C9BEA6
B2AFB9C9ADBBCABCCAC5C2CCB7BCCAB9CABCBBDAC0B7A3B2
B7C0AFC3C0BBC2E7D3CAC3C2C9BBC0C5BCBCC5C9C9BEBBC7
B6C9C2CCC3C3BCC0
C3CCBCB4B4BBBBC3C2CAC5CAC7CEBEBCC9CAC5B9B9BEDACC
BECFBCBCC3C3B9C0CCC2D6C7A8B7D1CACACCC7CFBCC08EF9
C3CEC7B9C5C7C3B9B6579FB2DFCCC7C3C9C3C9C5ABADB2BE
B6C0C0C2C3C2B9BCB7C9CFB7BEC7C3C3C3C7C3D5D5C3BEBE
BBC3C2C7BEB7C0CABEC7CCC9C3C7C5BBC0BCCCCAC7BEC5C7
C9C0C3C5EBC9E6CC
D1C0BBC3C3BBCAC0BCC5BEC2C5C3CCC9BCBCC5C0C5C7C0C3
CAC7BECABEC0CABCC2C7D6C3CCB4AACECAC2C7C9C0C3CAAD
C0C2BEC5C5BEC0B9A6B4ABBB8EBBC9BECFADADBEB7C5B0B9
BEB9C2C5C5CCC0B4B4C5CCBEB4AACFC5CCC9C0BCB6A1BBC5
C7B7C7CFC5CCCAC9BBCABCC7BCC3D1C3C9C3C2C9CFCAC9C2
BBC3B6B7BBC3BEB6
BEC2B2A6B9B9C3C0ADB2AFC5BCC7C5C2C2C7CCC5C7CEC3D1
93BBC7C7C5C2BEB7CABEBCB9CCC5C09EC7CEC9CAC5BCB9BB
C0C0B7D3C5C3BBB9B6E1D8E2CAB7B6C29EAABBCCC3C9C3AF
C0CED3C7B9CABCBEC2CABEC3ABC2C5BCCECEB4B4B9B9A6C5
CCCCC5C7B0BBC5C9BCC9C3C5CEC7CFCCCADAD5CFD1D6D8C9
BEB7A3C5B9C5B9C7
BCBE8EB9C5C0C0B0B9C3C2BEC2C5B9C5CAC2C5CAC2BEC9C3
C2BEC7BEC0C2C5BBC3C3C5CCC9BEC3C7B9D3CECFC9B6D3C5
C7D1D3C9C7B6B0BCCFC0C3B9BCBCB7B2B6B0CECECAB7C3CA
BED3BBC5B9BEC2ABC7CAB7BEB4C0B6C0C2CCBBB7BBB6BEC5
C0BCC2C5B9C9B6CFC7C7C7BBBEC7C5C2B7BCC0B7ABB7B6C3
DAC3D1BEC5C9CEBB
C2B6AAC0BEB6C0C0CAC2C2CAC3C2C3D1CEC7CCCEC3C2BCCE
C7C0B4BBC2C5C9BEC5BCC5B7CAC2D6BEBBCCD5B9CCC5D1DA
CEBBC0B6CAC7BECFCEC5C2AFC2C2ADC39E9ABEBEC7C2A3CC
B4C9C2A6C2C3BCA8CCB4C2B9A1C2C3BEC5C5B4B7B0B4BCB9
C2C5E2D3D5C7BEB6BEAAC7C7D1D1F3B4C5A4C7BEC5B9BEC9
BEBECCD1CAC9C7CE
BCB6BCBBBEBBC0B7CECACACABCC0C5BCBCC0C0C7C7BCBCCF
C5BCAFBCBBC2C5C2C5ADC5B9C0C3B2CFC0AAAFB79EBBBCAA
CCD6CCC2C7CECCB0ABC2CAB7C2A8BBC0C0B9BCBCB9BBB4C0
C5C5BEBBCFBBD5C7C3C0C0B9B2BBBEB6C0B9C0B6C3BBC0BE
B6C5BCC2B9BEBBC9CACEC3CFD1BEBBB7BCB4CFCFC3C2BEC3
BCC5C7C2CAC9BCC7
BEC7A4C2A1C9C2AFC0C7CAC3C5B9BBBEBCC992C0BEBEC0CA
CEB4B7C2B6BBBECABEBBBEB4C0C5D6C7C5DDDAA8BCC0ADC3
C9B7B6C3C9BCB6C7C2BBBBC2C9B7BBB2AFB9B4C0B2AFBE97
BCC7B4C0C3C3C2B2C3C3CAB795C2C9BCC0C5AAB9B9C2BEC2
C9CECFCFBECCBCCEBBB2C0BBCAC9B9C2B6CACFB4CEB6C3C2
BEC2BECABBC7C2BC
BCB9C0B9BBB6B6BEC7C5C2C3C7CAC7BEC0CACCCABEC3B7C9
C5ADB2C9BEC9DAABC0C3BEC098C5B7BCDD95E9B4B6C09EAB
ABB2B2C0C5CACAABC7BEB9BEB4D8BBBBBEB4BEC0C0C9B7C3
C5B9B9CEBCB6B2C3C0C9D1C09FB9BEBEB7B9B0B6BEAFB7BB
B6B4BECECECCCCADBCC9C2CCBBB6B9D8C0D1CAB9C7BBCCD6
BCC7CFB4B7C7BECA
C7BCB6AFBCC0D8E1C5B9BBC7C2C7C3C7BCC3C7C5C2C7C9BB
CCD3C7BEC3C5BEB6BECAD1C5BBB49EAFC2B6BC9E8E9CA387
9AC9C0CCC7CFC2C0BBB6ADA6B9C0B7C2CAABABC2CAB7C3C2
AFB7B7BEC7C9C9C5A1B2C3B9AFC2BEB9C9B7B6B0ABAFB2B9
A8BEC0B6BEBEBCC9C7AAC9CFCEC3BE30B0D1C2C7B0CCC3AD
CEC0CECEC7CECFC2
B6C0B2C0B7B7AA82CCC5ABAFC0A4D8C0C3C2F2D3C2BEC0BC
BEC7B9BEC0C2CECA9FC3C0C5C3CFBEBBC5AFB2C3DBC0B0C2
B0C0A49C989EB6CACABCBEC3AFC5C0B0C7ADC3B4B2B9C0B4
C5B2BCBED3C3BBABC5B9BCB9AFB9B7ADC2CCC2B4C7C2C5B4
C9CAC5D3C2C7BBBECAC7D5CCC9C7C2B7B6BCB4BCBBBECCDD
CEBCC595AFCAB2C3
BCC0BBB9B9BCBEC3D8C0CFBEBBC9FFC2BECEADC5C0C3C0AD
C2C9C0C0C9D1BCABADB7C5CACFC3C7C3B4C2B4B0C3BCCCB9
C3C3ADB9C9CCCEB6B28CC3C371AFB7BCA4A8D1C0BCB7B7C2
C5BEE1C5C2C7B7D1D8BBC7C5A4BCC0B7BEB6AAC2C2C2C2BC
C2C0B7C0D1CCC2B9C9C7D1CEC0C7C0CCCFBEBCC3BBB2ADC9
BEBCB9B6BCC7C9B7
CCCCC5B7C9CFC2B4B7CCC3CAC3CECABCBEC3C2BCBEA4AFC2
CCC2B4C7C5C5BB9FDBC5C5C2C9CCC3BBC2C3C2BCAACEBBC7
C3C5B7BCCCB6D5CF82C0B2B4C9C0BCB2B7A8DAC2ABC2CEA8
B4D6B7BEBCB4C2C2ABBBC5BBA8BBC5B9CAC7C3BEC2CFC0BC
C5C9C5C2CFBCA6AAC0C9C2CEC9CFD3C2CAC9C3BEC7B6C5CC
CCC38EBCBEC3C7C3
BCADBCB4C2BEBEC5C9C7C09CCABEC7BBC2AAC0C7C2CCC0B4
C2B7C5CADBBEB0B0B7C0C0B6BBA1B7CAC0BCCED6AAC0C5BE
BBC7CCB7B9C7C0B687BCBEC5B4B7BCBEB7B6C3C3CEBCC0B2
D5B4C9E7D1CCCCCEBEC7CAB7B0A6C2BECFB9B7C3B4B0B2B7
AFC3BCC2CAC3CCCAAFCEC9CCBEC2BEB79EC9B4BEC3CCB7C0
9EA4C5C9B2AFBEB6
C7C3AAB0B4A8B9CAC0C5C0C0C2D3C7C3BEC0CAC2C9BCC0BC
C0C2C2C3A6CEC0BEBEBCC9BEC5B2B7CAD1C9BED8B9BEB9B9
BBC3C0B9B2BC97B454C3C9D6BEB9B2AAC7B7CEB2B9C3BCD6
C3BCC2A1BCC9CFCEC2C5C0C5B4C0C9C2D6C2C2CCA8C3C0B9
BEBBB9CCCEB7C3D6D5B0C3BCCCC7C9CECEB7C3BBADB6B7BC
C0BBC0C0C5BEC9C3
D8C0CAC5BCB7BECFC7D5CAC7C9BCCCC0BECFC2BEC7BCBCBB
BECAC2C5B9C5ADBEB0BCC7B6C5B7CFC2C2C0C7D8C9C5CCA6
B0B6C0A8ABB4B2D1CEC7A6CAB9AABBB2AD8B92ADCCB6B2AF
C5CFC7C7C9B9C0CEC7BBC5C0B6C5CAC3BBABBCC2BCB6B6AF
B9BBC9BBC0C3D8CEB2B0BBC5CCC7D1BBCAC0C2A8CCD5C0CE
B2AABBB9C3BBC3B9
C9C5C2C3B6B2CFBED1CCC3BECFB6BEB7C0BCC5C3CFBBCAD3
C9CCC9CAC5C3BEBBC9BCCFC3C3BCCAD5D3CAD5E2CCBEC0B0
ADCCA8B0DD98BEB6B9C2C2C2BE97BECABCB0BBC0C7C3B9E2
C3B9C0BCC3C5C7C5C5B6C7B7B4C2C7B9BBB7A6C3C5C7C3B2
C7CFBEC2C2B0C0C9C3CACADABCC5CCBEC3C7C3AAB9C0C9D5
BBADCAC3B6BECCC9
C7BCB2C7BEC2CACCC3C0C3B2C7BBC2B6CAC0CAC0D1C0C3C9
CCC9CFBE9CBEBCC2AFC5C9D5BEC0C7C7ADC2B29FB0B7B7DF
C2B9ABBB93BBCCB4C5B4CEC9B0C5DDAAC2B6BBBBC5C7B6C9
BBB6BCC9C7C3CFC3A6BCC5C0B0BEE2B4C9CFB9C3C2C0C2BC
A4C0C7BEAAC7B6C7C7CAB9D1CCD1BCAFC0C5B6C7D1C39EAB
B9CFB0B2C3ADC0C2
B9BCBCB4ABBBC2D5BEBEBBB9C2AFC2BECCC5CAB4C2C7CAC9
C3C2B4BECCCECEC7A3B7C3B9C5C9C2AFC2C3B2A1B0B0B0C2
BCB6AFB7B7C9C7C7B6C3B7C9DBC5CAB690BEC5CAC0C2C9C3
C9B7B9C3B9D3C3CAC0CED8D6BBC7B0B6BEABB6AFC9A1C9BB
B6BBBCD6B0B9C0CCBBC2B4C2CAD1ADCACA87CEC0C5BBC5AD
BEC7C9BBBEC3CCCA
C9C9C0BECAC3A6B9BBCCC3BECCB7C3C3C9C0C5B9C5C9CFC0
C0C3C0C3C9CCCFD6B4BBB7BBB0C2BBC3CCC7C9A6B6ADB4B7
C5C99EAFBBABBEBBC7BCABBBBEC3B4B4B9B7C5BEBCC2C0C2
CAC2C3C3CF82C9ADCCCAD3B7B6C2C99FBCCFBBBCBEC0C3CC
D1C7BEC7CCBECABCC5CCC5C0C2B4ADBCC7CCCECFCCB2B0B9
B9BEB7C2CACED3C7
C3C3B4B7BCC7C2C3C2C5BCA8C7BBC0C9C0CAC9ADC7ABC5C0
B6C3D3C5B9C0BEBB9EC9AABBCCCCB7B7CAB7C9CFC2C7B7C2
BEBECCA4BBAFB2DAB2AAADB6BCC0B6C7BBABB6C3C9C2C7CA
CEC9D6C9CCCCC9CFC0C5D1BCBBC7C3C5D3C3BCB4C5AAB6B0
CAC3B9C5B7CEBCCFC2CCC5C0D6CEC3B6B6C3E4C3B6BBC7A6
C0BED6B0CCCFBBCC
B2BBCCCCB9C5C9C9C7B0B0C2C0B7C9C2C3C0CAC0C5CCD5BC
C0C2CCBEC2C2C9C2ABB0C5C5BCC2BCCCCFC0ABC9C0B7D5D1
BBCACFB9B9B0D3B7C3A6B7BED5B7B4CCBEAABEC3B980C5D3
CADAC0B4BEADCEB2CAD6D5BBBBC9B4A6C0C3AFB0BEC0B0AA
B0BCB0C9AAC3AFC3C3B9C3C5C0C0C5BCC0BCCEC7C9CAB2D3
C2C2C5D3C3B9C9DA
C0B2AFC3C3C5B4C9B7B2B2C7CABCC5C2B7C5CCB7CCC5C9C7
C9C2BCC7C9BEC2C0B9C3C3B2B7C5C7BCC2B6C3ABA8B9BBC2
B9CC97BEBBBEAFBBB7B4C0B6C0B6C0BCA8B0C3BBCFCADAD6
C9B2B9BBB0BEAFC5DAC2C0CABCC2C9C0C5BCADC3C2C5BCCE
C7C2CFC9C7BCC5AFCFCAD3C9C0BCC5C3BEC7CEAFCFCAB9CA
CEC5C3BBCCBCCAC7
BEAFBBC3C2B6C3D6B4B9C3C5C9C2C7B9BBC2BBBBBCC2C2B7
C7CEBEC992BCC0BBADB7C5C5C2C2C7B9BEC7BCC3BEC2BEB9
C0C2A8B49EAFB4A6BCC79EB4BCBEB0BCC7A66ABBC29E7BB9
C5B6C7BEB0CAC2B0D6B6ABC5BEBBB0B4C0BBC5BCCCD1B9C5
BCCCC3C3C2D8C0A1C7CCC0C9BBC5B2C5C2C0C2E1CA9FB7CE
C0ADA3B6C5B7C3CC
C0C5C7B0C0C0C5BEBCBEC2D1C7C0CEC7BCBEC9B9BCCCC5CC
BCB4BCD3BBBEBBB7B9BCCCCCC0C7B7CCC5C7C9C7C2CACCB7
BCBBBECFC9C3A6C0CF9FB0BEB9C0BEB9AFBEB9BEDBB0B6C7
BBC7C2C5CEC3C9BEB2BEBBC5B6BEB9C3AFC2BCB9C5BEC7A4
C3CFC3C2CED3C5B9BCC2D1D1C7C7C2BCB2C0C7B6C3BCCFB7
C3C2B6C7C0C0CEB9
BCB6AFC2BED1CAB6C5B4C7CABEC2C2B9ADC0CCCCCCBBC0BB
C3C3CEC9C2D5C7B7BECACFC0BEC5C3C3BB98CAB7C5CCB4BC
BCBCBEC3A8C7C5CEA698BCBEBCC0ADC5A1B4B7B9B6B4BBD8
CCB2BEBED3CAB4C5C3BCB9C9BEBCBEC0C3BEADBEC0C0B9D8
C5B4C3C0C0AAAAC7BEABC3CCD5D6D5CFC7A1C9C0C5AFCEDB
D3CEE4DBC2C9CCC0
BECCC7B7C0BBCEB6AFBEC2C9B9C7C7C3C9C5BEC5CFC0C3C7
C5CAB7C0C7C5B7B2B9B9BBC3B2BBC7C7C7C5CFB7C9CFB6C3
B6C3C5B2A3B4B4BE93AFADADB4C7C3B2BCB2A4B7C0BBC3A8
B6B7B9CCB9D3CCCCC3BBC2BEB2ADCCC0B0BEC2CEBEA8BCC2
C7C0BEC9D5BCC0C3C7C7C9C0C2C9C5C7BED3C7A3C3E6BCC5
C7C7BECAA479B6C5
B6BBDABBC3CCC2C0CFC7B7C5C9C5BCBECAC3C9C3BCCAB6C0
C3BCB9B6C5CAB9CAC0BBC7BBCAC0BCC3B2C3C2B6C7B9BECC
ADBBC7C7A6CEBBC59CB7A8B4B9BEBCADB6AAB7C5CCBBCAB2
CFC3BBC2C2B9C5C0C2DFCFBEB9C5B2B9ABB0D1ABCADDCFD1
C0B9BBCCCFB4BBBCBBB6CFC3C7CAC0C9BCCCC7CFCCAFB6B0
C3B2CEC2BBBBC7B9
C2CCC5B9B9BEB6C2BEC3C0CABCC9CAC7C5C0CEC7C7C5BCC2
C5C2B9CAB7BEC2B4D3B9CAB9BEB4CAABC2C2CFC5C7C0C0C2
B4B6CCC29FBCC9CAB9C3B09AADABA6B7AFB7CECCA1B0BEBE
B0B6C0C9BCB9BEC9C2C2C5CCC7BCCACCBCBBBCD1C5C9B0B4
B9C9CCCAC3CCA3CCD1C5CED1C7C7D3B9C3B4B971C5C7BCB9
B7C5C5C2C7C2CAB9
BBBCB6C2BEAFB9C7C7BEBED1C2BEB2C7C0C3BEB6B7C2CFCA
C9D6C5CAC2C2B4C7C0C0C5C3C3BCCAB2C3B4BBCABEBCBBBE
B6C5B7C5D5BEB9B457B9BBAD98B4B9AFB28CC2B6B797C2C7
C9C9B4ADC5C2C9CAC7BEC3B6C08CCEB9C3C3BCB0CAB6C5B7
CACCC9C2D1BEC7BECEC2CCB4C9C3C5C0ABC3D3C7B2B6B0C0
C5AAC7B9BC9CD5B4
C5B0C0CABEC7DAD1C7BCC5C7CABEC2BBC9C3C2CEB9C7BCCA
C3B6C2B9C7C9C5C0C5C5C5C0C0B9BCCEB4B2BE89BBB4BCCC
C5CFD5D1BEC3C2B7C3B7B2C3C2899CA6AAAA9EC2C7A6C2CA
C2C2C9C7C9C3C9C5CAB0CCBBBBB9BCD1BBC2B4BCC9C2C9CF
CFC2D3D5CFC7BBD5CACFD1C7CFC7ADBBB7ABB0CECFDDDDCA
AFCADAC2D1C7C3CA
B4B6C2BCAFB0C2B9B2CEC0BEC0C7C5BEB4B4CCC9C9C2C2CF
C9C3C5BEBCB7C0BEC2D1CACFC0CAC0C2BBB0C7CAC2CECACC
CFC7DBD3B7C2C5C0CCC3B6BEB2A37DBBA1B4C3D6C0C0C0B6
CCCACCCAADBEBCBCC3DAC7C2BB9ECACCBBC0CCC0CAE7ADC3
C5C7CCA8C9D1C9C3BEC9C5CAC5D3CACACEBEC7DFCF9CADCA
CAC0C5CAB9ADC0B6
C0C2C3B0A4CFB7C5BEC2BCBEC9B0CEC0B0C5C0CEC2B9C9BE
C3CED1BBBEC3B9C5BBBCC5C0C5C5C5A6BCADB6D3CCCFB0D6
DBE7CFBBCAB7B2C3B7BBC0C0C3C2B9A695B7BCA4CE9FADBC
B2C9C9CCC7B9C5C782C3D5B2C7ABCFBBC3BCB4B6CCC0B9BE
C5C3C7AADAB0C5CECEC7BCC2C3C0BBB4B9DDC9B6C3BEC2C7
C9C3D8C9AAA8BBCF
C0CEC3BCB0C7C7C3CCBCB4BEC5C3BEB6C7BCC3CECFCABEC9
C2B9B2B0C0CAC7B2B9B0CAC3CECFC9BEB4C0BECFBEAABBCA
DBCFCEB9C5C5C9B7CFBCC5C2BBADAF9CA8A1B0B7B4AFBBA3
C7CAC5CABCB7C7C7B2CEC3BBB4C2BCBB9AC0C5C3BCBCC9C2
BBBED1CEA6CCC5C5CFBEAFB2C3A8CEC5BEC7C9CA97C39FA4
ABB2C0BCC7B4CED8
BBC3C2CEB69CBBBBBEC7C2C3B9BCC7BEC5CCC5BCC2C9C7C0
C9BEB09EAFBEB4C9C9B0CABBCECCBEBCA6BEBCCFD1DABBCC
C9B0B4B2CAC0C0C5B9C5BBC3C0AFC2AAA8AFB69CB7B6A6C2
C9AFC0B6C39FCCC2C9C99CC5B0D1CCBEC2BBA8B7AFBBC0B6
CABCC9C3CCC5B9CFC0D6B7C3AFBECACCCEBEB7B6B7C7BCBE
F0C7BEC9B0C2C9CF
C0D1C2B7CAD1CFB9B9B9C9B9D1C5CCC7C3BEC2CFB6BCB4C2
C9B7B4A495C7C0BBBCC7C3B7C2C3B6C2B7B6C2C9C0CEB290
929395CEB6CAC3B9C0CFD3A3C0B7BCC3B9AFCEC9C5B2C9C5
D1CCD1C9DAC2C5B4D6CAC2D3B4C5C9D1CFBBC9A8C7B9C7CC
E6B2D8C3D6CEC3C5CCD5CABCB2C7C99FC2B4C79CC0BCB7B9
C9BEC9CECCC5D5D3
CABBC3C3B6B9B6C3C9C7C7C7C9C5CCC2CFC9CEC2C3C9B6C5
B0C0C3C5D6BCC0B9BEC9CACAC2B0B6C3B7C9C59E849E9FAB
82B0BCC7C9D5C0C0CEC2CCC7C7B2C2BBBEC09AB4AFB0A6B0
BBCCC9ADCCCED5C3C7C0C5CCBECCA8C3BBC0CABCC3CAC9BE
BEC2EDD3C5C0C5BBCFC9C2B7C5C3B9ADA8C0B7C9C0B0C2C7
CAC0BECCBBB7CFBB
B6C0C7BBB9C9C7C5C9C3C9C5BEB6C2C3C2C3CCC3BCB9B7C9
C5BBBCC7C9A8B7BCC2C0C9CCC9C3C2C2C9B6CAC7B9989EB9
BCBCB7C0C3B9CAC5BEBBB2BBC0BCC3C0ABBBC9CEBBA4C2C7
BCC0C9B9B0C2C3BECCC9C3D1B6BBBCA4B4B2B0C9CCC9CCC3
C3BBB2C9CEC7C7CADFCAB9BBCCBECEBEBCCCB9D1BCCFB9BB
C2C2C2B4CACEC9CC
C3C3B9BEB4B6C7B7B2C5B4B9B2CAB6C0C3BCC3AFC5BCC5CA
C5B7BEC9B9B6C2BCC3C7C3CACEB7C7B6BBBCB2B4B6A1C0CC
B2B9C7B6B9C2BEC2D6BCB9B6B9B4BCB6B9B4DA95CFCAB6C9
C0AFDDC3B9BEB9B2C3D6C3C7BEB6C0C7CEB9BED5BEC0D1A8
B4C3AFC9C9C2CACEB9CAC2C7C2CACCC2ABA4C9C3BEC0B7C3
C0C9D1CEBEB9B9C3
BCC7C78B9890B2A8CCC5B9C0C2B0B9C0ADB9CABEB6CCBBBC
CCC5C9BECCC2CCC3C5B2C9C9D8D1BECCCFB2C7D5C7AACAB9
B9CECFC5C0C3C5CCC2C0CABEB9AFB6BBC9B0BBB2B69EB7CE
C3D6C2BBCEC7CEBCB7C5C5B2BEA8BEADC5A4B2C0C5C5BEC3
C9C3C9C3B0C7B7B7CAC7BEBBC9CCC5C2C3BCB2D5C5C0DDC0
D6B69FC3D1B6B9D3
AABBADBCC3D5BBC5C7C2C3C0C3C2C3ADB4C5BBBCCAB9B9CE
C0C5B6CEB9CEC3C5B0BCC5C3C9B9C2C2B9B6C0B2AAAFBEB2
BCC2C2B7C9BBCEC7BECFBECAB7C3B2C3B2AAB4B6C2A4B7CE
B6D5BBDABEB9C7BBBEC0C9C9C2A1BECAADC0ADBEBEC3CACF
BCD1C2B9AFB7C0BEC7B0C0D3CCC5B9BBBEBBCCC0A6CAC7BE
C2CCD5CAB4C7D1D1
C3CAC3BECACFB9C2D3C2B0BBBBB2C3C0CEC3C2C3C0B9A8BC
C9C5C0C5C7BECCC3BBB7C3C9BBC0C5C7C2B6C7CABB82CCA3
AFBCC2BBC3C3BEC2B9CCAAC0ABCAB0BEC2B0B9AFBEC9A3CE
C0C3C2ABB6ADBCC5C3D6CFC7C3CABBB2C0B4BCC2C2BBCEBB
C7B7C5BBB6C5C3C5BED3CCD5CACFB6C3B7C3C7B9C9C9ADB4
DAD8CACACCC2C7C5
C2CFC5CCBCB6BEC9D1C0C7C3BEBBBCC9B0BBCCB6C0BEC5B9
BBC0AAC5C3C2CCC9B2C7C2C7AFB4E2CCC9CED5DDDFC3C7B0
CAC7CCD3C0B6BCC2B6C5C9BBBCB6B4A8B9B0B0C2D6C0A4A8
A1B7C5BBBCC5C5C9B7ABBEC7C2BCC9BEADC0C0BBC3C2C2B9
C2C5C5C5BCC0C9E1BECFC9BCC9B0C3CABCC3C3BBE1C5B7AD
82B9C7C5C0C2CFC5
BEBEC2BBAFB9C5D1D3B9B7B7C5C5C9C9D5D8CFB0C9BBB7C3
C2BBD1C5B7BEB0C0BCC9C5CECFC2CCE7C2CEB0CCCEBBB4C9
ADB2D5C0B9B4C7B9CCB99CC7B4BCC9C9ABBBB0BCC9BBBBB9
D3B7C5BBC0BEB6BBBCC2C2C0B0AFCFB0AAAFC0BEBEADB6BE
CFD1BCC3B2BBB0BEAFD32ED1BCBBCEC7C9A4C2B9B2A8CEB7
C7CCD6C3CECEC7C3
C0BEC7C3C5B6CEB6C3C0CECFC0C2C2B4BECEB7B9C3C7C7C2
C9CCB9BCBCB6C2BBCEC7CAC9C0F0BEB4C3C2BBA6D6B7D8C9
93CAB9BBC2B7BEC7B9BCC0BBD1B0C5B6B9B6C0A178A1ADCC
E1C9B7B2BEBED6C3D3D5C2B2B6B0ABBBB6B9B2C0BBC0C5C9
C2C2BBC3BBC2C7C3C3C3A4C9CFC2A8C7C0CEC2B2D6BCDBDA
C3DAC2CFCFCFC5DD
C0CEC2BBB6CCD3BBC5C7B2CEC7C7BBC3C7BCAFBEB9C3BBC2
C3C0B9C5C3C3CECFD1C9C7CAB4AFB6BEC3C7AAD3BE97C0B6
B0CCBBC3BCCCCAD8B6B6C5C2C5ABC5BEB6B6B2B4C0C2D39E
97B7C3BBB7C2B7C3BEBECAC7C3B6BEBBBBADB2C7A6ADCAC2
CABCD1C5C5BBD6D6D1B0CCC2C0BCBBBBCFCABCAAB6BBD1AF
C2D3CCCEC3D8CCB9
ADCFC5C0B6C9C5C5C0B6C7D1C9BBBBB6C2BCC7B6AFC2B6C3
C7C7B9C9BCBECAC2C7C0C0D6D1BBABB7CC93C59FB7ADCECF
B4CCB0B6BCDBC3BEA6BEB0B4C2BBB9B9B6B0C3C7C5B7C2C9
B9C2B0B9C0B7B9B7C09AC7CAC2CABBC2BBC0BCC9C2C5BCC2
CECCD3C9ADCFC3BCC9C3B6BBCABCC3D5C5D5DBCCB9B4C9CA
DAD5C7C2CCA1B4C9
B9B6B6B2B7C2BBC5C2CAB0CFC2C9C7BCC2BBABB6C7C7C7C0
C0CEBBB4BCCACEBBB4BCCFCCC0BCC5B6C0B9B7B9D5C5C9C5
CAC0B7BED5BCC7CAB4BBC2BCC3BEC3D1B9AB93A1D1B6BBC7
CEB7BEC0C2BCC0C2C9CEA4CCC7BCBEC0B6CAD3C3BCC9CCC5
B2B0B9C2B2C9BCCCC0A8CFAFBCD6D5C9C5C3CABCB9C3C0B6
95C0C0B7D1CC9FF3
D195C2CABBC0C3C2B6C2B7BBC5BCC2BEBCB7C7CAC5A8C5B9
C0C2CAC09CC3C0C2C7C5C3CFB6C995C0BECECCD3CCA6C07F
CAC7BEB7B2C3C7D8C9C2C0B7B0C0BBB6B4AFBCC3BBBCC5BE
C9B2BBBECABCC3D5D5CAB2D3B9BCB2C0B7B0ABAAB0CABBC0
D3DBCEC5C9C2C3B6B6BCCCB6C7C9D5B2C9C3D3CC84BEC2C0
CAB6B7CEBBC2CE97
C3CAC7BBBCB7C5C7C9B9AAB4BEB2BEC7CFB7CCB4C0BBCFC3
BBBBC5C5A8BCC7C7C3C5C9D6BED1BBD1BBBBCFC2C2AFC3C9
B6CACCAFBBC9CFADBBBEB4AFB6B0B7B057B0B6C2C9B2B2AF
BCB6BBDFA6BEB7BBB0BEC2BCC2C0C3C5C2B7C5ADBBAFABA4
BCB2BEC5ADC5C5CACFB9C0D1CAC5BECEAFCFB9B6C5CAB49E
C2D3C2B0D89AB9A8
BEC3C0B7B7C2BECECCCFCACCC5C3C2CAD3BCB6B6CEBCBEBE
C3BCC3CEC3BEBCC3C9B7CEC7B6BCB9BCB4C7C0BB9FBC90CF
B9C9BCCAC5B2C0B6B4A4BBBBBCB7C2B99FB6CFA4C2CABCA4
B9DBB4C3D3AAB7B4B4D5C7A4C9D1B0CF95BEB9C7BBCCB7BB
C2D1EEC3B9C3CECEBCCFB0BCCACCC7CFD6B6D6A4CACACEC5
AAC3D5DBAB54BCCC
D3C2B2E2BBCAC2C5C2CAC7C7C3CEC5C5C7C9BEB2C7C7CEC5
B7C2C7CFBCBEC7C9BCBBC9C2C3D1B2B9B9CEB6BECAB9C9CA
ADC7C3B6CCC3BBB99CA6AFC2C5B7B9B4ADABB6C7C3C0CCAB
D8C2CACCCEBBD3C9CEBCD5D3C7C7CAC0CCBCC5D3C0B4C3CA
C7C7BEC2C5D1DBC0BBB0C0B9CCABC7C5B7CABCC7C0CEBBB9
B6C0C5AB5989CEC2
BEBEB9C5BECEB7B6BECCBBBECEBEBCD3D3C9B0B7B7CFC5C0
C3BEBEC2CCBCCAD3BCBED3CCC0A3C9CCBBCAC2C5CEC7C9A8
B6CCC0C0B0BEC2BCB6B7AFB7B7B6B0C3CEA1BEB9C5BCC2CF
C3BCD1ABC2D5B0B6CFCEBBCFBCA3C3C2ADB6B7B9C0BBC7D6
CFC7D3B9C7B6C7C0C0B7B2B6BBCEC0CAC9A8C2CCD1BBAAB0
BBD1B7BEBCB4C0C0
B9C2C9C0BBC3C2B7C7D3C5D5CAC2C9CECABEBEC3BCC5B7C5
BCC5BEBEC9BEB4C9C5CCC5C7CEB7CFB6BECAA8C2B4B4CAC3
B2AA97BBAFA6B6BBBBC2BB97C9CCB7B2B6B2C2C7B4C5C9B2
B4BCCFD1B2C0C3B7C5BECAC5BCB4B0AFDFC2BB9ECAAFC5D8
C39FC9C9B9C0C5B7AAB9BCBEC7D1B2BBC979C3D3B7B7CEC2
BBBCB7CFCAB7C3B2
B9B0C7B2C7C9A8C7CCC5C5CFCAC0CCCAC2AFCFC7BEBBBCC2
C2C2B9B6C5B6B9BEBBBEC7C9CEBBC9C5BED8C5C7B9CED3BE
BBBECCC9BCB4BBC7B9C3C7C9C0BBBED5C0AFA8B2C5C7B9C0
B9CAC3B9AFC2C2CFD1C3BBC7C3B4B7D8ADB7B7C5D6CAB0C5
C5BEC7C3C9CCBBC5C7C9D1BED5BCB0C9CACCD3DFC7D3C3D3
B4ADC9C3C0C7C0C3
C2C7C5C3B7BEB6CAC5B4B9C5C0C3BEBCBCCCBEC7A6C7CCC7
B9D1C5B9C5C2C5C3BEC2C5D3C9C3ABC0B2C0B6BEAFC2B7C2
B9B6BCCEC2B4CEAFB4BBBCBCD3ABC5CAC289B4B6B0BBA6CA
BEB9B9A6C5C3B9CABED3ADBCC0BEADAFA8C3BCB9C5B99CC7
C9A1ABCACFC2D5C2C5CFB7CECCD3C0E1C0BBBCC2C9CAB6C2
CEB6C0C7CAB9C9BC
BCD6CAC0BBC7C5C5CCBCC0B9AABCC5B6CAB7BEBCBCB2BBC3
C9C7C9CCC9CAC9C2B0BBB9C2CCC098C79EBCC0C5C7CEB2B7
C5C2BBADA3B4BBC3A3C5CAC5BCC3C2B7B9C3BCCEC2A8CECA
C5BCB6C9BBC3C5C2D5CFC3C3C2BCB9B7C3BCB9C3C5B6B0B9
9FB0C0C0C0C3CFCFC786D3CECAC3C0C9CCA3B69FAFC0C0C2
C0C2B9CEB9C3CAD6
BBCCBBB7C5BCC2C3BCC3BCBCABC2B2BCB0C0BBD1C3CEB0B7
C2CEBCB9C5C2B6BCBCB6CCCCBBC7BCCCD8C9DBCED6C2AABB
C2B7B9B9B0B9B2BBBCC3B9C3CAC2C0C2C5BEA4B0CACEB7D8
C7BBBBBCD3D1BCBCC5CAB4CCC0BBBBC782BBB9C0CCDDC9CF
BBC3C3CAC0CCC0DBB4B4C7AF9EC5C5C5BBC7C9BCB7C0CCCC
BBB6C0BBC0C3D6C0
B4C7BCC2ADC2C5C0C0B9C2BBC7B9C9B4C9C7CABBC2C3CECA
BCCFC3C2C7D1C7BCB4C2BEC0C9CEC3BCC9BEBEAFB2CE9E80
CEABB7B0C7AFC3CAC2C3C2BBC0BCCAB7C3C5BEBEB7C3C0C3
BEBCB4B9B9CEC2C7AFD1C3BBC7C2BEB0C3BBBBC9CCBCCAC7
C0C2C9C0C0BBB9CFBEC2BCC3C98BC7CFB071B9BEC2CCC587
B0AAB6C2CCC2B4CF
C5ADC7B4CCB9C5C3D3C9C0B9C5B7C0B9C9BCBCB7C7B6C9C0
C5C2C0CACAC3D3CEC2D3D1CABEBCC7CEBBC7CED39FD1ABAF
AFAFADB9AFC9ADCCC5BCBEBBC2C9CCD5D3C3B0BCB6C5BCB6
C5C2A1C2C3BCC5CFC2CCC0C3C5C0CEC3B9B9BCC7C3CFC3C9
B2B6C7D1BECEC0B4B7C9C2C7CCCCC5C9CCC0D1CECEBBC9C7
B0F2B4C5CFC2C9B7
CAB9BBBCC0C7C9C5BEC3BEB9BCAAB9BCC3B4AAB7CCB7BEC2
B7C5A6BCC5B2C0C9B6BEC5CAC2C0D1BBB9C0BCB98BC0BBAF
ADBCD8C2B9C5C0AFB2B6B7C0D1C9B9BCAD9EA4B6B2BCAAC9
C0B4C3ABC7B2B9DFBBDBB9A4B2BBE1C3CAD1BCCFB2B6C0CC
B4BBC9D5DACCC9C2BCCAC9C9DDCCCCC0BEC7C7B4CAC3CAB0
C7B4C2C5C9C2C9C9
B7B4B0CCC7C5C2BBC0C3BBBCBCC9AFB7BBBEB7B6B4B9BBC7
C9BBB4C9BCA4C5B6BCCACCC7C5CEC3B9B6C3CEB0B2C9BBB9
C3CCCACECAC5BEA6B6C5D6CEBCB7C9ABAAA695A6B7B4C2AB
CAC5C9CEB6B7A6C0D6B0C2C3C7BCC2C5B2C0C5C5C3C0B6BE
BECAB0A4C5C0C2CCC0B9C0D3C3C7CACAC2B4D1B4ADC2C7CE
BBC9C5C0C5BECEC2
B7C9B6C5C5E1CABCCCBEC3C0C2BEC9CAC0BEC7C5B4C7C0D3
C3C5C9C3D3C5C3C5BEC3C5CEC9C3CEB4C0CABEC0B7ADCEC2
B2B7C3B9B2B9B6A6CCCAC9B78CB2BECAB4B4B9C0B0B9C3C7
C7B9C2B2BBB6C9CFBBC2BED6C9BCBCD3B9C3ADC7BED1C9DF
C5C3CCD3CCCECAC7C2D1CCC3D1BCDACCD3CAE1C0CEBCC5B2
8CBBC7BEC0C5D6BE
B4BEB9C2C0C0CEC2C2C0CABCBCCCCEB9C0C3B9BECAC9C7BE
C5B2C7D5C7CCC9C9C2C7C9D3BCC2C5D3C2BEB4C2C7C5B4C3
DDD1C2BCC3AFBCC7C7C7CA95BBC5C3B7B9B7B0C0C5BEC2C2
B4C2C2C0C39EBED3C2C9B2D6B79FC0C5C5C9D3C5C7C0C0C0
CFC5B9BECFBEB4B7B9BEC9C9BECADBD6CFCFD3ABC3B6BEBB
BCD6C7C0CCCAC5BB
BBB0ADC0B6BEAFBCC5C2B7B7C9C7C9BEBEBEBBC7CACCB6CA
D8BCB4B2C3CEC2D1C9C2CCC3CFC7CFADB9B7CCC7BBCED6C5
B7D3D3BECFBBADBBC2D1BEBBB7BED1C2B9B7B7B6C5C2C7B4
CFC5C9D6C2B9CCCAD3CFCECAC0BCBBB2CFDBBBCEB9BBB7B7
C2C5C0D1D5BEBEB7C7DBCEC9D3D3A8BCC9BED5C9CCC9C5CC
CE8BB4BBCFCAC5C0
B4B4C7BCBCC7C2C2C3C7CAC7CECACEC7C3B9C0CAC3CCC7B2
C5BCC5B4CCCCB7A8BED5C3D6C2D389C5C09ACFC7B2C9D5B2
B4BCCCAFB9C9A8B2C0CFB2B7BBBBC7B7BEAFB4B6C9C7B7B9
B2CCCCBEC9CF9ACAB7BEC0B6B0ABB2B7BEB6B4C0B7CAB9BE
C5C2AABBC9D5C7D3BBBCC3C9D1CAAAC2C0CCB2C2D5E784C9
C7C9C5B9C5CFC7BB
CAC2C2C9C5B0CACCBBC0CCBEC9C0C9C9BCCAC3B6B284BBC2
C0CCBEC7C3C5B9C5BCBCD1C2C2CCC2C7C0A8D8D3BEB7CED8
90C3CAB9C0ABAAB6AF9CB6B7C7B9B9BEBEB7A6BEC9C0BEC0
C0D5B9CACA9ACFB0A6BCB0D1BBB7C9BEC9C9C3BEC3C2BEC2
CCCCC0CEC9C7C3D3D1C7CFCCC3CED5C5CABCCFC9C2C9D8C2
C3C9C7BCCFC7CEC3
B6B7B4C0BBA1BEC3BCC2B4B7C5C3BBB4B7C0C7C9BBADC7C5
CAC7C5CE9AB7AFC2CFC9CAC9BCC9CAC7B0BBCFB7CAB9A4A3
ADB6C2A6B9C0BBB6BBCCBCC2AFC3BCABB7B797BEB0D3B9CC
BBC2D5AFCAB2CEB6ABB9B695C7BEB4B2BBB4B2AFB9D1BCCE
CCB9C5C9C9C9CCCCB9C3C2B2BBC3A6CAC2D6C5C2B9B9E4AD
BEBBB7DDD6C2C0B9
BCC5CAC2C9C2CECCC9CAC3C9C2C2BCBEBBA6BCBCC0C0B4C7
C9BBCAC5C5C9BBBCC0CCD3C3BCCEBED5C7BEC2A8C2ABC0C9
AABCB9CECABCC3BEBCC3B9BEBCADC5BEB9B9B0B4DACFB9CF
C5BBD3C0B9C9D5C2A430CCC9CFB4C3CABEB4C9C0C3C5B4C7
CAC7C7C5C3C0BCCEC3D6D3C39FC0C9BCCFC5C3B7ABBCA4CF
CCC3E7D1B7AAC3C9
BEC0CAB4C7BCC3D8C3C0C3CCB7C5BBC9C7C2B7B6B4C3C5BE
D1CCC9B7CAC5BEBECCC0CFC5C5C3DDCACCC0C9CCD6CEC3B9
CEC9BCB6B0CCC9B7A6B6ABC3D3B0C2C3BEB6A6CABBE6A3BC
C0B6B6C5CECCE6CC9CC3C0AAC2C7B2BBB6BEC2C2CAC0C2DA
BEC0B9C0C7C3CFABADC9C2C2C2B2C7C2C2CEC9BCB6D6BCC9
C2CEADC7B6CECAB0
B0BBBEB9B9C3C7C9C0BEB6CAC2DDC7B6C7C7C2BEC0C3B4C9
BBC7C7C9C0CAC0C0C9C3CCD3C5CFBEC9C0C0B2A8C7B4C9AB
B0D3C0BBCABCC5C7BEC9C2CFB6C3BED5B9AFD1BBDFB2BBBC
C7C9AFD5C3DBCFBCC3AADDCAB6C0C3CCC9C5B9E1BCBEBBC0
CAC795C5CEB7B6C0C7C7B4C3ADC2C5B6C9CABBB0C9D373B6
B9C3C9B2BCAFB2BC
AAC7BEB2C7CCC2CCCEBBC7C9CCC7BCAAC0BCA8BEC0C9C2BE
D1C2BBBEC5BEBBC3C0B6C7CEBEC5B9DDC5C2C5D8C3ADC5CA
C0D3C5D3C5CEB0AFBBC2C0B2C2CEBBC7C3B7B7BCB4CEBCCF
ADCAD6E1CEC5BBC2C3C5BBC5C2BBAF8EB6C9BEAAC9BCBECA
C7C0C5D6DBD8CACFBCCCC9CCC9BBC5BECAC2AAAAD3C5C9BE
AAABDAC0CFC2C3B9
B6B7C0CCBBC7BCC0D3B9BCD3B2C2C0BCB9B6BEC9C9C9BEC3
C9C0B6BEC3C2BCC7CAC2BCC2C5CAD8D6C7C2C3CFCCC5CCC0
CCC0CCC3C3C0CFD1AFC3A8C0C9CAB6BCB7BEB9B4B2BBBCC5
BBAFD1C5C0B7BBCAC5BEC3BCBBA8C3B9B9B6B0BCC0C2C3D1
CACCC5B9CFD8CCB7C2C7D5C3CCD3CFC7C3B7B6AAC7C2BCC3
D1C9B6C0CAD1BCC2
B4C9C5C3C2CEC3CAC7D3B9BEC9BCBECCB9BEC0BEC7C0B6BB
C7CABBC5C0BBB2BEAABBD3C9BCCAB9C5BCB6CEC0D3C5C7AA
C9D1BBC3C7C7CECCC5CCBBC7C0A6B9D393A4A4B6BEB0CAC7
C7CCB9CAB2C3C5B2B6C5C5BECEBCC2B7BEB7C7C2D1BCC9C9
C0C9BCC9CFC9CAADCAC9C0B7B9C5CAD1CCC7C0BCCED1D6C0
C3C2C0BEB4BCC9BC
ABB9C3C9C7BCC2C5C2B6C0C2C5BEBEBEB9BCC5C7C5C2B2D3
C9C0A4C9C7B7D1CAB9C7C2C5B7C2C7C0B4C2B2ABC7C0B6BC
C0C9C5B7BCC5B9A6D1B2AFC5C7C3C3B9A3AFB4B9C7C0C3C0
C0C2CCAAC9C7C7BEBEC9B7C9C2C0C0CCCABBB9C7C3C0C3C5
C7C2B9B7B7B4B9C3D6BEB7CCD8C5C3C2C7B2B7BEC7ADBCCA
DACCD3CAC5C2C9B9
B6C3C7CACFB7B7C3C5C0C0BCC2B0BEC2B7C7C0C9C5A4AFBB
BCC3C9C2B7CCBEC9BCADC7BEC3D3C9CEB9BCC5C9C3C0CAC3
C0B7CECFCACCABC0D1BECCC5C2B2BEB0B4BCAFC9C3C3B4B9
C5D3C7BEE4C7B4C2D3CEC2C3BBB0C2B0B995C0E1BEB2BBCE
C2CCBEC7CACEC7CFD39EB0D1C3C9CCCAB9C7C3CFC3C5B9BE
B7C3C2DDD1D1D1C9
C3ADC0CACFCFBCC2D6CEBBBBB9B9BEB7BBC3C2C2CAD5C2BE
ABC3C7C2CCBBB9C7BBBCCECCC2BEBCC0B9CEB6B4C3E6B7B9
B9BCC0CAB4BCB6BECABEBBC7B4B7B4BEC2C2B7C2BBC0BBBE
C7C9C0BEAFC5BCC3D6B0C3D1CECCC3C0C3CAD3CFCFB4BCB9
CAC2B7C2CAC5C9CACACFD3C7CCD1C3CAB7C3B0A3A1C0C3D3
BCC2C7BBAAC3A4B9
B0C9C2B7C5C2ABBCC7ADB6C3B9B9C9C5B9C7B6C9B6BBBCC9
C7BEB6B9C2B6C3BCABBBDDC2B0C39EBCB9C9DDDBBBCFBEB9
BBC7ABBBCACAC0B7B9BEB4C9B6BCC5C5C7AFB9C2B0C3D1B7
9FB7CA9ED5C5CAC7BBD3B2CEAFCCC0C7CEBEBEC2C390BBB4
B4CABCC0CECAC2E1C7A6CACAC9CAD3CCC7C5BEAFBBBB9F7F
C3C5CFB0B2A4C5B6
C7C5C2CAC5C3CACAC9C0B9C2B2C5C7BBCCCCC2BEC5B0BEB4
D1C2B0BEBCB7BCCCC0C2BCB4B9C9CAD3C2CABCC3C3AAAABB
C7CECFCAC2D3C7C2BBB2C5C9B9B6C2C3B4B9AAADC0C5BECC
BCCCCCB7AFD1CAD1CACFC9C7C9C5C3ABD6CAA8B4C2BBA4A4
BCCEDACFCCC9BCC782D6CEBCB7C7CEBCD1ABA6C079B0D8D5
C293C2C9C7C397D5
C2C3C2C5CAC3C0C7B6B9B6BCBEBEC9BCB2BEC7C3AFD1C5C5
C7C0C7C9D1CED1C2B2AAB9C2BEC9BEB698CCD6CFC0C9C9CA
D5C7C3B4C5C9BBADC9B7C9CEAFC2BCC2C5B4B2C3BEB9C2A1
B6B6B9B7CAD1CAC5D1D6B7C7BBB2C9D1B9BEC2CFCCB49EB7
C3C2C3CCC7C0C7CEB2C9ADB2CFCFC7C361A3B7D39F95DDC3
B0A6BBA6BEB6C5C5
BBC3BCC7D1C0AABCCABCD6BCBEC2C0B0BBB6B9C5B6CCBBC3
CCCABCC9C9C3BBC5D3B4C9B9B4D1C7B6D879C7B6C7BCD3D8
C2D1BEC9B0CEB2CCC5C7D5B2CEC0C0C2BCAFBBC0B0AFCCCA
C0C7CAC0C2BCC2CED3B4AFC9CAC7CECAABABC3BCB7BCCEC2
C3B4AAAFC3B6C0CCB6BCB7C0C0D3C2BCAFC0ADA3B0AFABC7
C0B6AFE1CEEDC9FE
C7C3BEC5C0BEC0C7C3CFC7B7CAC0C3BEB0B0C0C7C5C5CCC3
BCCFCEC9C9BEC5CAC0B2CEC9C9CCADD1AFB6CEB0D1C7C3CF
D6DDC7ABBEC7AB9EB4C0CAC5BBCABEBEBEBBAABEBCC9C2C9
C2BCC5ADC0D8C7BBC5B9ADB7B2C7C7C2C0C2D3BCBBCEBECF
C0C2CFC7BBCAB6BBB7C9C9C5AFC2BBC0C0BCB4AD8CBEABB9
AAC7C3C2CACAC99C
B9C2CAADBBC5C9C9C7CCBEBCCAB0C0C9B9B4BEB9C5C3CAC0
C3BEB4AAD1CAB7BCC2BCCABCBCC9C2C79FBCCAB6C0C3C9BC
CFE2CEDAABD1B9BCB9BBCFBECEBBBEDBBEB6AFB2C3BBC3B0
B7C7B6DFD5C9D5B7BEC3CED8BEABC5C5CEC0C5C3CACCC0CC
C3CCC9C2C0C2B6C5C7CABCB9CEC7C9B7B2BEB7B6C3CAB9C7
C0BECCC7C0B9BBC9
BEB2C3BEA3BCC5ADCEC2BEB9CFC9C2B4B7C9D3C0C0A1C7C7
C2B6AAC900B2B7C0BBB7C7CACECEBBBCBE95B9A8C2C2C0AB
92C7C2BBB0CCCCC3BCC9C7C3CEC0B4ADC3C3ABBCC7CAD6C2
C3CABBAD74C7BBC7B4C5C2B0B6B9B0BECFC3CFBCB6C9BED6
B9C9DBA4BCB9CABEC9CAC9C9B4CFB4C5BBB7B0B7BBCE9FBB
ADA6CACCB0ADCFD5
CCB9C5C3C7BECAC5CAC2CFC9B9A8BEBBBBC7C2C7CEC3B7BB
B7C5BEC5AFC3BEB4B9B6BBBCCAC3D6BECFC7B7A3BBB9C3C7
DAC3D5B4C3D1ADD5ABC7B0ADC2C3C5BBC5BEA6B0C5C3C3B0
BBBEB273AFBCAFD5AFBBBEB4D1C9CECCD1B4C7B4C9BEBBCA
B6BCB4BBBEC2CFBECECCB2C5CCB2ABB2B2C2B7B6CCBEBEBE
BEC7C0C7C0D5B7A3
C5C0C7B6CAC5C0CFC0BCBBC0C3BCBCC0C9C3B7BEBBC7BCB4
C3AAB7B7C5C2BBBED1ABC7BCDAC9CFB9BBC9D3C9DFB6B2AF
C5B7B7C3C7C0CAB6D6CACAB9BECCBCC2C9C2A8B0C3C2B2C3
B0B7C2CCD1CAC3BBC5BCD8B9BEB7C7C5B2BEB4B4C3AACFC3
C9CFC0C2D3E1C9ADBCB7CCB9CCBBA3B0CECAB6AFE2B2C3BB
ABC3BECCC2BBA6BB
BCC2C7BBADB0BED1CFCFC9C3C0CECCC7BBBBB9C7C3BBC9C0
B6C0C2BEC3C9B9BEB4C7BCAAC3C7CFB9BEC2C0B7B0C2BEC3
B2AFB2C7DBC2A6B4C2DBBCBEC5BBB2CEC9AFADC7B4B0CCC0
B4CCC5C7C3C0BCBCBEBED5C7BBC99CBEBCCCC9BBBEC3C0CE
C7AFC5BBCACC9AB7B0ADC3D6B9ABC9C3CCC7E7D8B4DAC3B0
BCC2B4C0CABECCC0
BCB7B4B9BEC2B9B9B2C3B2C7C9BEBECEC2BCB9C9B6CAC5BE
C0C5B7BCC0BCABBEBEB4CCC2B0B6B6BEC9CAC9EDD8D3BCCE
C7B0B7CCC2C9C0CAB9C2D8C5D5C0B6C3C5BBBBB9B4D3C5B9
C5BEC0C7C9B4BEBBB2CECFC0B0BCA6BEC3BCCAB2B0ABB7C0
BEBEDFD1B69CCFB6B0B2C7C7C9D3B2CEA6B6AABCB2C3C7C9
CCC5CCB6C3B9C2B2
BCADC5ABBEBCC7BEC0B7ABC9C7B7C5CCC3C2C7C9C3C9CAD3
BBC2C3ADB9B4C3CCB2C0BCB9B9C7C2B7C9BCC5D6B2CACFAD
B6CCCAB6C2C7AFC5B7BCB0BCC9CEC0ADC9B6A3BEC9BBBCBC
BCC9AFCECEC9C9BCD3C9C9BB9FBEB2BE9FC5A8C9C5B0B9BC
BEBEF2A1A1C393C3B7BEB9D1D5B9B2BCC9C9B69CDAC2BBAA
C5C5B6C0CAC2CEB9
CAC9BCC7B6BCC2B9B6B9C0BCC0BEBEA3B9C7C5C7BEC7C7C2
BEC3BEBCB6BCB6A6C5AFCCCCC9C7C0D6C5D1C7C0B4AFCCBB
C7C2C2AAC2D1BECCBBB6A8CEB7C3AD80CCBEA6B9D6D5D5C7
B7AB9AD6B9C5C3C0B9CADAB0B9BBB4BBCFC5B2B0C2C9B9CF
C9C9B7ADCFC3BEC7A4B4C9C7C3B2C0C0C5C7C7BBC7ADD1C7
D1DBCFC0CCCCB6B4
C2AFC9C2BCC2C0AAC3B6A8C9C5CEC0BECCC7AFA1BCB2B9C5
B9CCC0BBADB7CCC2B9B4AFCECED6A8A3BEC2BEB4BBC9CCC3
C0BCCEC9D1E2C2C3B6A4DABBD5D3B9BEC7B0B7ADDBB9ADC2
CEADBCC5BEB0B0C0C7BCB9B4B7C5C2D1B2D1AFB9D3B2CCC0
B4C2DAAFD8C3CCB6CFC2C5C9CAB7B9C9BCB4C5BCB9C3C2C5
B4B2BE9EC9CAD8AF
BCC3CEC0C5C2C0C0BCBEBCCCC7BEC7CFBBB0CEC2C2BEBBBB
B9AFC9B7C0C0BEC7BBB7BEC7CAB7B6BCAAB4CFBBB2A6C7C2
CFCFC9C9CFCFBCB9B2D1ABBEBBB7C5C2CAC2BEC7CCB2C0AB
B7A4B6C9A8BCB7A8C2C2D8AACEBBADC0C2B6C7C5C0C5BEBB
B0A8C3B9B7BBCCC5CAB0A8B9C3A8B69AC2B6B6B4C9C9B2C2
CAC2C2C9B0B0BE80
B4C0B4B7B7C5C2C9CCBEC7CEC5C3AFCAC2AFADC9C2C3C9CC
C0C7CAC0CED1B6AFB4C9C9CFCCBECAC2C5C5D1C0B4CFC3B9
C9ADCE8CC7C0C7A4C7C5C7B7C0C9C9C9C5ADBEDABED5C5C9
B9C3A8BEB77BB7C5CCE4DFC2BBBEDBC7CABBBEC3B9D1C5A6
C0CEC5C7C7BBBCDAC393B4C2AFBBB292B797BCCCC2C3C5CC
C3D1CCCAB6C3B6A6
B9C0DBB6BBBBC0BCBBC9C7CABECEC9BBBBCABCC7BCCEC9C5
BBB9CED89CCACAC0C0AAC9BEC2C9CCD1C5B4CFBBB2CACACA
CFCCC3BCCCBBB2D3C3BBBCCECACAC7BEB2B9B0BBC7C2C5BB
B9B4CC87CAAAADCED1CCCAB9CAC7C2B2BBC3B7BBB9B9AD98
CCB9CAC3B6CAAAB0D1C7A4BECABCC9AFB2C3C9C7CCC5BEBB
C2CAC2CACCD1BBA3
B6BEC0C2C3C3CAB7C3C3C7C9C2B9B6BBB9B7C9C0AABBB9C7
BCC2C3BBA1B6C0C2C7C2CCBBBCCEBCCFC5CEB6D5BEABCAC9
CCC9C0C0C7BEBECAD5C7C7B4C2CCB2C2CCC9B4C3BEC5BCCC
CCBCAABEB998BCC5C2CABCB9C9BCC2B4B6C2C0B2BBBCAFB2
E1BCAAC0C5CCBBA6C9AAA8B7C5CEC7C2D6E7CFB0C0B4B2C2
C5BEC0B7CCC2BEAD
ADB6C2A3B7BCABBEC7C7C2B0D1C7C5CAAABEADBECCBBB4B2
B6C2C3B7B7C5B2C2C7A6B4C7C2CAB0B0CEC5C0C0BBCCCCB6
C3E4C9CAC9A6D3ABC2E1BEC3C2BBC3C2ADBECAB7B7CCCEC5
D3C0C3C0AD9FC5BEC0B495E4C2C5AFADCFBCBBC0B7C5C298
A3ADBEBBCABEDBB79FC0BBC2C7BCBCBEB9BBC5ABC3BCC9BE
C2C5BCAAC99FBEC3
B7B9C3BCCAC7C0B7BEC5C2A4CCB6C3D1ABA8B6B2B0BEC5BB
D3C0C3C3B4C2BBC5C0BEC9B2B7D1D5C9B7B4C2A1BEB4C3C5
F336A493BCC5BEBBB0C9CFCAB6BEB6CCCAB0C5B9CFC0ADBB
B9C7BEBCC0A6B793D1B7AAC3C3B0C3B49CC2CABBC5B9B9BE
C3C0C7AFB7BEC9C3B7AA92ADC3D5C5ADB9B4C9C9BBC2BBBC
C0CACED5C7B6AFA8
C2BCC0CAC7CAB7BEC0CECECEC2BCCABCB08786C0AACFC2C0
C5BCC5D6AFCCB4B9C2D6C7C5D8C9CCC5BCBBB4C2C9BEB9AB
B7A1C7B6AFD6C3BBCAC5C2C7B6CCC3D5CCB6A3B0B9BCC7BE
CCC7C3C39FB99AA1B2BEB4DDCFC790ABC9B0C0CAC9BCB2B6
C7B29ED3B9C08CC5ADADABCC98AAA8C0D6C0B6B0CAC7B4C3
CEC9C7C5C5C0C0A6
C2B9BCBBB6CEBBC7C3CAC9CAB7BEB9BBCAB4BEBEB2C0B6BC
C5CFC3C3C2B4C0D1BCAAC2C3BBA1CCC2C9AFB4C7D1D6C9C9
C0C5C5ADBCB2C2BEB6DBB0CAB7A8BBC7BCB4B4C7B7C7C5C0
BCD3CEB6C7B98EABC7ADCABCBCB2B6CCC2BCB7CAB9B6AACE
D1B2C3C0C9BEC5BEB992BCC3B9C5B0C790B9C7C3BCC5C7C3
C2C99CB7CCBEB7AA
AFBCB9BBBCC5B7A8BEBEBBBBA4CCB7C7C0C9BECAC0BCC5CA
CEBEB7BCB6CAC3BBBBC9BBB4CAC7B7B6BEA8B6C2B9C0C5B9
C0C7CADDDFD6C7B9BCC9D8A8ADA8B9DDCABCC7B6B7CAC9CE
C3AD9CD8C7C3B9ADC3B4CEC0B0C5B0BCA1D1B9B0A4B0C7D3
B7BEAFADC9A198BEB2B7BCC2B09EC0BBC3C7BEC5C5C5C7CA
CECFC2E9B0B49F9C
B2B4B0B9C5C2C0C2B6B9B2BEA6AAC7C2C7B9C3B4C0CCC7AF
CABEC2BEC5CEC3C7C5C3B6B7BEB6C5CFD5BCC7B0C0C5C9CA
CABEC0C2D5BCBCCFB6C5BEBCBCCCC0B6C9BBC0B7BEA8B7BC
C0C5AFB0CCC5B9A4AFCEC3DFAFC5B4AFAFC0B7938CB7B7C7
BCC0CAA6B4B0AAC0AAC3B6BBB7CCCCB6B9CCCACFC3CFC5CF
C3C3AFC7B7BED5AD
B4B0B9C2B2B2BEBBBCC5C5AFB9AFC3C0BEBEC2C7C5A4BCC9
BCB2C3C7C5BBC0C7C3BEBCCED8DBD8C2B4C7C2B6BBADB2C3
C2CCB0C7C3D6BBB4CFD3C3C0A1ABC0C0C9B4A3B9BEC9C0B9
C7C2C5CED6C2CEADCAC3C2AFC7C598BE8BCEC3AAA6B7BBB6
C0BCB4BEAFA6B2BBA8B9C5B6C5C0B0B7C9C7CCB4CEAF4FBC
BBC0D1C2BCC9C7C5
C5ADB4B6CACABEA3C7B6C3B9C0B6B4BEC2BCC2C7BCADE2B9
C3C378B6C3C0BEB7B4B6D1CAD8CAC2B4C2BCBCC9C2B7D1BC
CFDAE4CC9FBEB7C5CCD3C0C5CACEBBB79AA1B2AABEC3C7C2
C7D5C9A6B4BCC5B9BED3AA98B9BBAAA1959AB9829AC0B7B9
C2BED6B9BEC29C9CA4BEC3C5B9BBC5C2D1C3C2D1CCC0B9BB
C2ADB7C3C9C5B6C7
B7ABBBABB7B4C2C5D3CEC5ADB4BEBBC5A8C0B2A69CC3B4CE
C0C3AABCC7C5CCB4C5DBCAB69576AABCC7CABEB7C7C5B9C3
C7C7BBC5CFCCAB97B0A8C3B6BBC3C2B4C9BCC3C3CEADB6C5
C5C9C0C39EB4B9C0C7AAA6AFBBC0B6CAADA6BE8987B2CACE
97BEA8B9AFCCB2C0B9C59FC0BBBCDDBBC5B6B7C0C0B4CEC0
B0D1B9BBD3C0DFA1
ABBCB7BCAFBBBEC7C2C5C7AAB6C2B9AFB2C0B4B9B9CACEB4
AFBEB9C0B9A8AABCC9B2BB97C3CACFB7CFB4CFADC0B2CEDD
B9B7C0B7B7C3C7BCCAC2C0C9CAC3C2CCC7B0A4A6BBC3B9CC
B7C0BEB2CFB0BEC5C3BBA1CFB7ABB9BCAFC39397B2C5BBC0
B6B6CCC3BBB9BEBCCEC7BEB7CABEB7B7CCB7E1C3BCC9BBC2
C5C5C5D8CEC0B6C3
BCC9B6AFBBD8D1BEC3BCC3BEADC9B6C0B6C9C2C2C2C3B9B0
BEB4BECEBEB6C0BEB6A3A38CB6BCCFB9C3BBB4CCC3C9CAC5
9FC0D1CEC3BCC7CAB7D5CAC5C5D6C7B2B9C2A3BBD6C2C5C2
BCB9BEC2A1D5AAB0CAE280D1A4D1BEC0B6B7A697D1C3C0A1
ABB2BCCFAFD1D6BCBEB6C7D6C5CAE6BBBEC5A8B2BEB7C0D1
BBC9CCA6CA98C3C0
BCBEBECA9EB2BCBEC0BCD6B9B4C0B4B4CCC2BCC7C7B2BEC7
C3C9CCBBC0CCC3CCC5ABB0CCC7B7BEC5B2C9B7CEC9BCC5B9
C0D1CCC5CACFC5C5C3CECEC2B6D390BED1B29AB2C9CCBEBC
C2A1B4C5C0BCCCC0ADAD9CDBC0DAB9B7A4DAB9A88BC9CC9F
CABCDDD1B4C3B6D1AFC3C5C0C2CCBBBEAAD1CCA4A8C2C2BC
BCCCB2BEC2C5C0B4
BBC3CAC2C7ADADBEBEC3C3A6B2B7C5C7C5C5C9C5B9C5C3C5
B4D8C3B9ADC5A1C7CFC3BBBBC5C5BBB4B9C0BCC7BEC9BBC5
C5A6CCC3CACCCEC9A1C2C0AD7DA8B0BCCAB0C2C5C0CCB6BB
C0B4BC9CD1CAB9C0D3B6BC8E98A4B2B29F8CA8A1B2CEB9C2
B9D6A4B7B9C3B2A8B0B4D1AFCCB0B9C2C7C2D6CCC3CFBCB9
B7C3C5BCB4BCB7B6
B4C5C3B9C5C5AAB7C7C0B7BCA8C0B9B7C5B6BBBBB6C2C7C0
C2B0C3C0BEB9A8BBCC9ACCB4C9C7BBBBCAC7C0C3CCCFC5CE
AFF2C0C2C2B9D1C3CCDDAFD5A4CEABB6C3B7BCB7CEBECCB4
C2C2B0A4B2B9C59C9FBCB787B0C0C5ABB4AFBB9CA6D1ABB2
C0B2CAA6CCABB6BC9EB9B6C9B4B7BCB9B7BBC2C0C0C2C7BC
C2C5C5CCC0C3C0B6
C0C0D6C5C9B7BCB6B4C9ADB7B9B6ADB7C2C0A4BBC2B4C5D3
C0C2BEBCC5BBABB7BEAFB9AAC7CCC9C3C2B9C0C2C0C0C2C9
C2A3C2B7CFC5A1B7BEC3C3B7B2C3C0C7C5BCB7B0C0C0BCC7
BBABC5B0A3BCDBC0C7AFBBADD1C58EB7BBB6C0BBB0B2B79A
D5C0C3BEB4C3ABC09ECAC9BED3CED3CCCEBCB2B4BCBBC0BB
C2C3CABEBCB6B6C2
B9ADC2B7B9B4C5C7B2BCC2A4ABB7BBB7BCB4ABBBC5CFADB4
BEC2B2C3B9B4C0B9C2C0B2C5ADB4CEADC9C26CC2C7C0C0AB
CAD6BECED5BBAFE1C0B4B4C2ADCAC2C0C3BEAFB0BBB0C7C5
C2B6B6C2C7A4BEC9C7C7B797C0CEB7B0B9B2A1B9C9A4BCB4
B7AAAA9FCFB7ADC7C2BCCCC5B4C9DDA8B69FB2A4B9B0C5C9
C5B6AACEBEBCC2CE
B9C0C2B9BEC2CAC0C2C3C0B4A8B2B2BCB6BBBBC2ABB297B6
C0CAB9C7BBB6ABB6C3C5CFB9D3C3C70AC7C5BB98B6C3C2CA
B0B6D1BEB0CC9E9FB2C0C2C9C0CA9FB7C0C0BB86B7EBD1B9
CCC0B2C3C0C2C5CACF9ABEB9D6C9C9C0BBC7BEAB9A9590C7
A1B9CFABC9ABD3BEA6CED1D3C5AFBBC0B7BBBBBBBEB2BBBB
C3B7C5C7B2C7C3B7
BBB9C0B2C0B9BEC0C2BCC3B6AFBCBCB7B4B9C3C3BCBCC5AB
C2C3D3C2C7FABCCFB6B4C3CEB9C2BEBCCAC9BEB0C7C0C5B2
CCC5B6CFB2C2B0B2B6C5C9CEC0C2C5C5BBB0B6BCC5B0BEB7
C2BBC3D3B9C0CABCB2C7C0C3B0C5B9C2AD9C93A8C5B9C0B6
C2B6D6C3CEABB7D3C7CAB9ABABB6CAA1BBB9C5ABC9C9C2C7
B7C0C3B9B7B2BEBE
BBB9ADC3BBBBBED3BCC2BEC7A4B9C9B4AFB9C2C2B9B9A8C7
BBBCB0BBC98CB4C2C7B4BCC2C5D1BEC0B4C0B4C3BEC2D6C5
CCBEC5B2C5B4C3C2B4C7DDB9B4BBB9ADCABCC5C5BCB7CFC7
BCCFCCC3BCCAB2D1AFBBB7CCC7D5D1C0B2BBB4BCB9C3ABC5
B2CCC9C3CED1CAC9C0B9ADA3C0CABCB7B6C5BBC0C5D6C7C3
BBCCB2CACECACFC3
C7D8CECABBAFC2B7BEB7C3B2AABEB7BCC7C5B7BEBEA6BCAF
C752BCBECABBB6C5C3CEC7CCC7C0C2C0B9C5C0C3BECAC3CA
BBBCBCBCA1CCC3BBBEB7C7C0B9CABBC0CCC2ADA6AAB4B4BC
BCC9A1B9C5B7C5B4C0C5B6CCCFC0C3B79F9FAFB2AFC292C3
B7BCBBD3A3AFB4B9B0C3C2CCD3C7D6BC90B2C0C7D1BBC0BC
C2A1B7ABCEBEAFC2
BCB7BBC7B9CEA1C3B9B4C3B298A4C2BBBCC2C0AFAFC3C2B7
CABCC0C0A3C2A69EA1ADCAC5B4C2CCC2C3B4BBC9C0C3B7C5
CCBEA8C7CCC99CAFBEC0B0C2BBCAC3C2CABE79B2DBD3C5C0
C9C3BECFC3C9CCBBB0BBABB0B4C3B7B6ABA1B7D198ABA3C3
CCC7A6B4A1D1B7B6C7C5D3C5C3D8CACACFC0B7CEB9C0B697
CECACAC3D3CFBBC2
B4BEBCBBBBC7C0C0AABBBEB7909AB9B9C7AFB9C5C0D5BEB6
BEC0CEBCB4B6BBBEBBC0C7C7C9C2B9BEC3C5C7CAB4CECFB2
C9B0C5C7D1BCBCB4B9B4CCB9C5D6D8C0CFA8B7BCCED5D3BC
CCC3CACCC7ADADC7ABB4C3B9BBBEC5A8B2AFCCC3A4BCB0CC
CEB2B6CEC0C9BCCFCAC9D8C5C3B6C9BCB7C7A39CC3B9C3C3
C9D6CFCAC0C7B9C0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -56 0 ]
[.5 1.0125 56 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Sample) show
105.000000 12.812500 moveto
(color) show
141.000000 12.812500 moveto
(image) show
171.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B7C7D777977797B797270727977797472747578787477776F7570737976717678777A7C737678\
6D7372696C6C6D6E6F716E6C7174727274727476746F716F6E6E696C7271696B69
7E807E6D6C6B726D6A74746F747370706F6C7675727573756E74737A7777807F7E737674777772\
7E797774797B7677787775717678767678765C625D777B76747370757B78707371
727577696B697774727E7D7A777673767874797B777375716F716F757C7E646568605B56797773\
78777673706E6866625E5E596F716C7776737C7A727B74727A78747D7D786D7372
61605F797B77787A787374757477797A7C7A7B7D797E807C7A7C787477757B7D7B7977717B7975\
78757373706E7C7977797D77797B767A7A757B7B767676717A7978737B776A6C67
7471717675747B79757A7C787679797678767274707C7B78757471807F7C797B777779757C7977\
7C7979797678747A777C7B7A817A797E7B7B7C7F8170726E7476727C7C77727470
6D706E757B7A767574777472757471787A76787B79767876
73727175757A73787B6F6E6B7C797B7B747B7578787477777D7E7F777879808182767D7C727575\
757B7A727374706D6F75747371706F7877767372717574737372717877763E372E
85807B7273746C6F6D7173716E6D6A71706F767476737579706D6F72766E83878274767A7E7977\
707671726E6672716E797E837679777A7978807D7D737070797676737573747674
7774727875736C69676F70717D7E7F5B5A597372717E7D7C6A6D6D7E8181716F676B6462737573\
73726F6F6E6B7D7F7B757773686A667576775A5457696F6A777673736C6B76766F
767778716E6C767476787D80817E7C7572707476727C7B787A77757B7B76757772797877787776\
706F6E7073717574737678767B7D7B7E807E7375737C7E7C716F6B7A7C7A73787A
747775787776716F6B7776737A7C7A7776737E7D7A787678747576787E7D807F7E7E7D7C7D7F7D\
787A786D6F6D7B7A79797877797D78767A756E726D807D7B716E6C7D7C79807F7C
6766637273747B7C7D7D7C7B7B7A7973727172726D7C7E79
7776757277797374777270757573756B6A696E7171787B7B797B777B7D79787A76756F72757375\
726F71717273717474757876777A786F72747275777174767A797877767568696A
7375737274726F72706B6D6B7574717271707371736D72747A7D7D726B697D7A7A747779737173\
7C7679616766797B797C79797E7B7B7F7E7D7A79787473726D6C6B757B78757B78
7274706F716D7A7C78787A76787A767675747C7B7A757473797B796C6E6C686B6969646276716C\
6B6A6773726F7779757274707375717C7D80746E736C6F6F676A6A767979777675
73757378787376787476797778797A7F80817577737C7B787D7A787574736E706E777A7A7A7D7D\
7477777A77777A7978797B79797B797B7D7B787A78767876807A7F7D7A7A6E6D6A
706D6D777675807E7A7675727779777873717D78767B78787776757679777E7D7C7D7C7B6E706E\
7779777072707574737B7A7974767280827E7E807C7B787673706E7F8282787B7B
6C6F6F7779757476727B7A797776757C7B7A71706D787A76
6F7272707270797B796E706E6C6E6C6A6C6A6F716F7076737675726F716F797C7C676E6D777A7A\
7577757476747274727B7D7B77767575767776797976797975767772797B707778
646767736E6B7874796F727277767377727072767167696771737181807F8483807978757B7878\
7776757C7979757775767977686B697574736C6F6D7678767D7C7B7375736E706E
7572727574735D5F5D747576706E70787A787B7D7B797B797C7B7A71706F5C5E5C56514C757471\
6B6D697572707C7979696666726F6F7372716B6A696F6E6D7E807E74767473736E
807B787877767776757A79787C797771706D7C7A7C7A7978757473706F6E6B6A697F7D79777571\
6C6A667F7E7B7A79767F797A7776757578767A7C787577738683817A797671736F
7476747274727C7B7A7C7B7A7675747978777C7B7A7678767476747E807E777A787A7C7A787B7B\
7E81816D70707A77757473707C77757776736E7670878985767979878B86787A76
73726F7F7C7C7673736B6868747674686B69797875747672
7679797578767174727A7B7C707373727374757775737573726F6D8183817C7F7F6E716F6F6E6D\
6F7272717273716F717877767576777379767679777173716C726F737976807B78
7B76737978757976765F615F71706F7372716A69687377727877747779777B7D7B717371707270\
797B7971706F7574737A79787A787A777A7A71727370737163676271706F6B6A69
737A79706F6E7A7C78827C7D717472757775737573686A687C797B6E6B6B5B5D595D585371706F\
6A6C6A73727182817E68676471706D7278776D707073787D382E2472746F747372
7877767C7979716E6E7572727274726B6D6B747370767572777673706F6E6F72707877766F716F\
777A7879797E7A7B7C78777473726F7D7C797C7E7A7274707C7775777270777270
807F7E7B7A79807F7E7C7B7A7C7C777978757B7A777372717B787876707176737178777479817D\
6C6F6D817B7C797875787A76787B7D78797A81807D75736D6668647C7775716C6A
817C7A74767275777372716E75747173726F6D6F6B6E706C
6D706E7A77797674767172737E7F807B7C7D7574737776757076737C7A7C76797B787E7D6D7372\
707675777A7A7273747B7A79777675797B7772716E7873717673737473727D878D
5C61635B5B546D6A686D6A685655546A696873706E74737276757279767481807D787A767F7E7B\
7B7D796F77717A807D7A7D7F7275756C6E6C6F736E6668647776738380806F6C6C
757677707673736E6C7A7372736C6B7F78777673757173777675727C7A7C5C59575B5A57696B67\
7B7B76686662786F6F73777271736F74746F77757177756F7E7B79787575767778
6F716F6D6C6971706D7978756E7574787B7B7776737C7B787978757877747A79767876727C7A76\
7977737E807E7877767C77757877747779756A686A78777470726E747672747672
70726E7A79767E78716D6A6875787A7A7C787E7D7A7877747B7D79767A757D7B7D7C7A7C837C7D\
7B75767C79797A797881807F7377727C807B6A6E696F716F7A797877756F706F6E
77797D777974777977707671777472747873797877767574
767876716B6C6D74757678767274727375737273747576775C5A526E6C686F6B707C7B7A7A7978\
767876727472757473777673787774676762797B797073757982806B6D6B80827E
777B766B736D787A767375716D6C697574716C6B686567637C7B786A6968848382797877797C7C\
787B7B71706D7C79777C75747777727B7E7E7F7D7F747A776B6D68827C75787273
7977737B7A7974797B78807C71706F736C6B6C6967787E79797B766F76755759545D5A58777071\
787170666361706E7273726F6C6A6C7972707D817C4345406B6D69807E8076716F
75747178757579767679767676757471706F6C6B6A7877767C7B7A7375737A7777787573757677\
73787B727875777675777B767A7E7970746F7D7C79807F7C7473726C6B6A727170
76797B7574737A79767F7E7B7A7976797B7773726F7A7976777D787E807C7C7B787C7B78777673\
7B7A777877747577757A7C7A867E7C7F817C7E7D7A7F7E7D777A787A817A707673
74797B7572707A77757B7878797C7A7776757C7E7A777975
7379766063617772707F7C7C787575726F6F7A7B7C7A7B7C6C6D707B7C7D7475767B7A797B7A79\
7A787C75787A717A7A787B7B7275757573776E706E696D68726F71706F6E767572
6C6E6A70767166676877787972716E72716E73726F70726E6F6E6B7372717D7C7B7C7B7A7A7976\
7D7C796E706C7675727D7876777579777A788079777577737973767D7B7F78797A
737175767876777B768685846668667772707776737A7E7978797C7C76776866625A5C587C7F7D\
6D6C697678747271706767606B6A677673717579747A7C7A7376767C7F81696B67
7574717C7B7A7F7E7D76757477777272726D71706F787776797877757B78747775797A7B7B7876\
746F6C6F6C6C777977797B777779757A7C78787774767572706B6675706B7F7A75
7E7F808281807F7E7B7C7B787978757476726665627D7A787C807B7C7B787E7D7A7E7D7A7F7E7B\
7B7A777C7B787678767C7E7C675C597274707176787271706D6F6D7773787A7777
7D7A78777577716F71706D6D7679777A7978787573817E7C
6C6E6A666C69747674656A6C767478787B7D6F70716A6B6C666C696D7370696F6C7D8080787B7B\
6F7A7A7076756F6C6C706E6A7C7A767172737778796B6C6D727472747674707270
7471715D63607572727D7A7A6E706E7577757779777172736B6B706668646F75727B7578787A78\
7375737877767776757E807E7A7C7A7C7E7C787A787577757B7D7B7472767C7A7E
75787A7477796E717370726E6C6B687E7B797D817C7A79767A777574737065635F6B6D69686863\
72716E71706D7877746C6B686E6D6A7776757A7C7A6D6C69706B697D7675787774
7175706D706E6C6E6C7574737372717B7A797574737776757675746D6C697473707A77777B7A79\
666C697776737574717E7D7A7675727675727774727274707B7A777C7B7871706D
7E7D7A7E7D7A807B797974727F7A78787C777C807B807F7E7577757C7E7C747B7C696C6E797875\
71706D73726F7D7F7D7678767D7C7977767375747179787582817E71706F797877
7A79787978777B7A79747A757B7F7A7D7A787D7C796A6966
7779777275737375737675747476747174727072707476747875737D7C7B777879727875767C79\
767C7B7577757B74737577757275737072707274727375736D727473787A6D7372
6B6E6C7476727776757779776F7876717877777A7A707172686B694C4F4D7577757372717A7777\
78757581807F7A7C7A8183818281807E7B7B7174727978777F7D797A79787B7A79
7072706E706E7E807E6A6C6A7B7D7B797B7976787673757371736F686D6F635D585E5A525F5C5A\
7779776D6F6D707770777B756C6C677A807D7A807F7A787472726D767D767A7C78
767A75767C797577757871727B7A7979787775736F6D6A6A79757A777A786E716F72706C7A7976\
7173716F6E6D7F7E7D6E73757375737D77727A797672716E7274706F6E6B74716F
6D6B677C7A76777977818381707270797B797B7D7B7673717574717D7F7B7B7D7B797B797F7E7D\
7978777D7C7B7B7876827F7D787A78757473747372767574787B797A79787C7B7A
7675747F7D7F7978777876727776737476747476727B7D79
797B797578767679797275736E716F6E716F7577737476727678766F716F747674757773787A78\
7374757778797475767376747779777F7E7B7678747175707E7B79777975706F6C
767572787774747576777879747873767373727575717678646767727472676A6A71767873787A\
777675747D7B6E71717B787A7577736E706C797B797C7E7C777977727577747779
7C7F7D7A7C7A7976767A787A7B797B7A79787978777978777C7E7C6E706C585A5560625E636261\
7073756462647370726C6A6C6B6E6E71777270746F72716E6F6E6B6867647B7674
767574737070726F6F817E7E6C6E6C747A777072706F716F6E706E878987707371757471706F6C\
71706D7D7F7D7678767B7A797B7A79706F6E7E827C828680777B767C7E7A7E7D7C
7A777577747277767371706D807F7C7776757A77777F7E7D7C7B7A777675787B797B7F7A747777\
7679797B7E7E787A7670726E7D7F7B7F817D7C7E7A787B796E716F7A777574716F
7A77757D7F7B7678767C838439414369787A7F858450524D
79777976747674727474726E7D7B777977737678766E706E6C74707C7F7D5A59587B7E7C727B77\
7775777776737979727877766A69687476747C7E7C74767471736E7B79757A807F
747A79747A7976737571737171737176757472706C7577737779757978777C7E7C5356547A7C77\
7A7B7C7E7E85696A6D7779777271707C7B7A7375737C7E7C818381787B79717371
77767375747171706D6D6F6D7274727E78797D7778787273777673686A702A2D253C372B585A58\
74797B6D6B6F7675746A6968767574707371716E6E767977787B79727573696865
706F6C6F6C6A7572707E7B796B6D697375717F7C7A7675727C7E7A7B7A777978757B7D7B6F716F\
7274727E7D7A777270807E7A7876727775718086837877747A746F6F6463716E6C
73726F7877746C6E6A787A767678747A73717D78758E8B8B81807F7A7C7A787776777675797B79\
717371747674797B77747672727472777977797B797A7E79747873717371787A78
6E706E797B797577757F7E7B7A79767A7976727472797674
747576787B7B6F727271706D71706D7574717670717678767776757A7C7A747A77797C7A7A7978\
777A7C70737371747274777975787A777977707270707270737573828583797A7B
7172737B7C7D727072727472737976757876737570727374797A7B777675818381777A785F6466\
6C726F7A7B7E78797A7A7C7A7A7D7B777A787A807D727472777474605957929595
7674767C7A7C7876787072707779777B7878797676737070706F6E3A3C37796B61706F6C888A86\
787B7B7677787877767B7A797877767B7A79747A776D6D686E6E6971716C777673
72716E787774787774797875787A7677797575727076757271736F7977797D7B7D6F716F737573\
787A787A7976787A76767876787A78767876838080828480787F767B7673787573
7873717D78767779757A7C7875777373726F7678747C7B7A7574737A79787A7D7B787B79767876\
787A787779777673717976747274727B7D7B7A7C7A7C7B78777673777977787A78
797B797476747678767477778A8D8D76797983888A787B7B
7E7C7E7376747073717578767678767372717A7C7A7376747370727775777371737875757A7777\
747576797A7B777879757272757272777977747674777977767478747274777476
7B787A79767871727378797A767373747674797C7A707172757775787A788183817678767A7D7B\
6C6F6D666967797C7C797C7A727575757878787B797376747578767A7C7A757169
7476747577757375736F74776F74777375737476747072706A6A657A746D6A6968717371565957\
7173717B7A797574737F7E7D6E6E697773697878736F6D6F7775776B696B747370
777673757270797875797B777779777B7D7B7379746C726D6C726D7779777A7D7B767373706D6D\
6A67677D7F7D747A777A7D7B787B7973767475727277706E6A6862757471727877
78767873726F7A79787B7C7D77797774797B75787A7D7C797574717E7D7A7A73728079787C7472\
7B7876797F7E7877767B7A79767876757775797B797D7B7D7E7D7A797B79757775
717371777B7672716E79776F7977717C7A7673717372716E
7076737477756B6E6C6A67657473707274707678767476746C69696F6C6C6D6A6A757677707172\
767778757677737475757775787A78787B7B7477777578787A7B7C7475766F7B7E
50585A7372717A79787A79787A777777767573757371736F7C7E7A7076736F75726D73707D7C7B\
7978777877746463607C7B787E7D7C7B7A797A7C7A777977727472706E70757471
78777478777473726F7F7D7F747777757B76767371757270706F6E898887828082868788777A7A\
6F716F73706E7978756463606B6A676E7171787B7B7177767778797A72766E6D6A
757974757A7C83827F807B787777707C7B7A717772727873747A757A7C7A737573787A766C6B68\
7A7775797B777476727A787C7C7A7C72726D71706D7572707473706A67657B7A77
7F7E7B7F7E7B7C79777D7A78706D6B7574717B7A777E7B797774727E7B797678767779777E7D7C\
7A79787F7E7D74797B73787A7C8183797E80767B7D7E807E8183817F8582797B79
76737373726F6766637B7A777473707B7A777473707C7B78
7270727073735759577274707E79777579747476746B6D6B7072707678767577756E7473707675\
7779777271707D7B7778797A7374757779777A7C7A7577757673737B7A797A7976
757775707373777A78767373777474757775767977737571757B767976767679777F7E7B797B79\
7375737B78767D7A787572707F7D7F7A7B7C827C7D7B7A796E706E7C7F7F7C7977
7F7A78807F7E7A7D7F7D7C797C7B7873706E706D6B777472807D7D7774747D78766F7270707172\
76757273726F72706C72716E686B6B817E7C7C7E7C7C7E7A71736F787A767D7F7A
78787384847F7676717C7C77757570757473747775686A687B78787E7D7A73726F716F736F6E6D\
79767476716E7675747779757F7E7B76737175736F77757172716E7776737B7A77
7A78747876727978757B7A777473707E7B7973706E7E827D7C7B787D7A787D7A78767371777673\
7C7B787B7A7779787573726F7675727675746F6D6F6A6C6871736F70726E787A76
858783777B7680827E7577737F78777D7C79817E7C757471
77767573736E6F6A677973747574736D706E7976747976747E7D7A777975747A75797C7A757876\
7A74757B7576837D7E817B7C7D7778797A7B7A7B7C7177767779757476727E7D7C
7A79787675746F716D757471757775777977797B79757473797877797472787C7774716F7C7B7A\
7477757A7F81707373727671807D7B7E7F807274707D7F7B797B777D807E828583
7E807C73757176787472716E7C7B7A7279787A7A7389817D7F817C7C7C77807A756F6C6A737475\
7B79756F6D697C7A7666646064625E7776737776737D7A787A77756865637C797B
726F6D7E7E797A7A756A6A65787A75767876777172706E667F7E7B72726D7B79757B7570666562\
70767578777675747377757779787772726D73726F6F6E6B73716D787672767470
7D78757D7B77888A887F817F808280797D78777673776E6E7A7573696B67757B787A79787E807E\
7A7B7E8A8C926C6F6D767977646664787A787375737B7A777473707776737D7C79
7776737776737F7E7B80827E7C7E7A7B7D797A7C787E807C
717472706F6E72747270737175747374717176787471736F777D7C777A7A7A787A7C7B7A747372\
7774747A77777572727572727774747273747677787379787774727774727F7E7D
7978777473726E6D6A7774727471717875757A7777777675797877706B69787C77757270767574\
7578766C6E6C787E7D6873746669676D6F6A71736F6264607375717A75726F6A67
7F7E7B8584817F7E7B7978757A7978807F7C80837B696A6B6A6C6879787578797A726F6F7D7875\
666866717371747674747674707270767572767572757270767371726F6D747674
7576777679777275737073717B7C7D7375717E7C807A7C787376767979747A78746D70706B6E6C\
7476717B767376716E7C777477727077717472716E7A79767775717A7874797773
76716E7D7B777876727B79757674707875737574717B7D797C7E7A7E807C7976767D7F7D787F7E\
75777379747174746F7777726D6F6D7D7F7D7D7F7D7A79767978757A75737D7876
7974727B7A777C7B787779757C7E7A7B7D797476727A7C78
787273787A786466647079756164627C79797577756C6B6A747674787A787A7C7A757B76767C77\
6D7370717371767373727472797B79635E597E79747D7873777673787774757B7A
797F7C6C6F6D71736F77797572716E757471777673797C7A7076737670717574736C6F6D787774\
7B7A778385817A79787875778789857E8483656B667675727C75746F6D69747576
767C796E716F706F6E787A767D7C797A757276716E7D7D787577757574717972717A77757A7E79\
72746F7173716D716C696F6A6F75706F716D797674706F6C6E6D6A7776735B5E5C
7174727E7C7873716D7A78747C7A767C7A767A7775706F6C787A76787A767C7E7A73726F5F5E5B\
7978757B7A797675727877747B7A776B6A677473707473707A7A757878737A7A75
7E7B797D817C81807D81807D7776737B797B727072837E7C787371736E6C7476747375717D7A7A\
7C7979756F7079787572716E7D7A7A7F7E7D6A706D7D817C70726E7B78767A7775
7875737A77757278737E7D7A7574717C7B78797875767572
7274727375707779747072707173716E706E6F736E7577737A7978797877777675787776787A78\
777A7A7578787172737472747C7B7A807D7B7E7D7A7577737678766F716F777879
7779776B6D696C6E6C797B797776737B7D79848883686A687476747C7A766C717374727463615D\
797877726F6F74737285878562625B948D8C75736D73736E7376746565606D6D68
6C6B68706F6C706F6C7579747B7A777F7F7A807E7A6E6C68787A787375736F72707275736C6F6D\
767E827073717673717B767373716D7577737678747976747E7B7974716F7A7976
797B777271707072707B7E7C7876726C6D6E6C6E6C767876747674797B797E807E787774656461\
75727075777375777370746F747370726D6B72716E7776736E6D6A73726F757471
73706E71706D747873807F7C817E7C7F7E7B7F7E7B6B6A697473727B7A797776757D7F7B737571\
70726E727470767E8273797482817E7E7D7A7473707C7B787574717F7E7B858481
7675727A797881807D6D6F6D6F716F787A787875737E7D7A
7C7B78727472706F6E726D6A7876727979748582828089877C79777271706F7071767778737475\
7A7978767876777A786F7572797676787A787779777577757D7A78777579797471
7F7E7B7A807F797D78757773767876737B7775747370726E6B72737A7C7A7C7D7E737477747671\
75706D6962606F6C6A727575696C6E6D70726266605C5C576A645F6B6663565853
63605E7277797877747F7E7B7A7C7881807D77797575797473777171736E686B69676965757570\
7C757471736F7D76757E7D7A6F6A68726D687A77757C7E7A74716F7D78767D7B75
746F6A78716F78716F7C75737E7C787F7D797A7E797C7C776D6762736E6C777B767572706E6D6A\
7779757875737473707A777974746F6E706E6C706B6C6B686E6D6A706F6C747370
696B6679777378777472716E7776737776737675727B7D797A7C78696B67797B797F7E7D847D7C\
797B767D78733D2E2075706B7B817E747775787A786F6E6B7F7E7B7877766B6A69
7E7D7C787774807F7C7B7E7C787A787E7D7C7F7E7D777675
73706E7A787471716C77797471736F6F716F6A67676056507D7C7B7978776A6968676D6A747674\
6668648284827270747678767577758491917D7E7F7C7C75777673787774787672
7375737176787072707375737273747577757E807C75757A6964617A79767877747B7A777E7976\
7D7B7D787B73737571757677696F6A6E706C7C7A768A88847A7874716F6B7B7975
716F6B7A78746A68645F615F67625D5F62606D706E797C7A78797A727072707373787776746F6A\
79787776757475706B827D786F6D697578766D6F6D716E6C75727079767473716D
7D7B77756E6C7A757276787380847F777B766F70716667687576777572707774727871706E6D6A\
77727075736F7371697A7A7580807B7A7A756B736D797D78777975797B776F716D
7B7A797C7B7A797B7783827F7A77757D7A787574717875737F7C7A7D7A78807E807B797B7D7C79\
7C7B7879787575736F74726E76757271706D7675727173717673737F7E7B898885
807F7C7473727B7A775C605B6B6F6A7B7F7A736E6C7F7676
7774727774747372717375707274707274727574737B78768184827376747C7F7D757473707371\
7A77799596996C73757375737C7E7C696B697C7677747674737676717474706B69
787575797779747674747674797B797E807E727472686A686B6D6973726F7B7A777E7D7A797A7D\
78777679767879767673716D7A77756F716D6B6D6B7678767274727D7F7B727470
767876767876696B697473707D7C797E807B7F817C71736E6E706C5A59567B75767A7976494B46\
6F6F6A74746F6F7272686764736D6683837E7A787477747274716F74716F757775
7779777574738789877679777779757A7C7871706F807F7E8483827673717D7A787C7977636964\
76757279767477756F7B767376716E6F6A677C7775797875777975777975747672
7D78757C777477706F7976747F837E7C807B7A77757572707E7B797D7A78807F7E7E7D7C787774\
7C7B787877747B7D7B7D7F7D7776737675727A797679777178706C6D6C697D7C79
77767374737274737072716E7675727C7B787B7D7974716F
7B7D7B787B7B7779776C6F6F7679797A7D7D757375726C6D71736F7D7F7B787A767A7C7A767876\
7F7C7C76777A7B7472727A737A7976747A757177727278736366646A6C6A767A75
7B7D7B7573756C6F6D7B78787978777779777073716362618A88847978777779777577757B7A79\
7D7C7B7B78767574717779757678767577757274726769677C7E7C7073717A7978
7A79767B7A7773726F6F75727B7D7B72716E808280787B7D5453507976746B6E6C6C6F6D787B79\
797674777472706F6C73726F6A69667A81837978756D6A687A7775817E7C686A66
71706D86838176716F7A7573797C726D6F6D767A757779756C6B687076717C79777574716A6966\
7574717C79777572707F7C7A7C7B78787A767878737D787583817D797974757772
7978777B7A79797B777779757F817D7A75726E67656D6B677A78747F7D797978757E807C797B79\
7D7F7D7F817F7A77757E7D7A7B7D79787A767577737C7B7872716E7B7A777F7E7B
7F7E7B7A79765B5A577675727776737A79767C7B787A7976
737072706B697274726D6F6D757775737573717273747777797B79787A7874767461605F7C7B7A\
7371737A79787673717D78756F6A677973747A79787477757B7D7B7476746F716D
79787573726F797B777C7E7A8187847375736E6B6B706D6B6C726F7D767479797476716E777571\
6463626C726F777D7A7177747473727E7D7C817F816563676E7074797877757473
7673717D7A78807D7B76716F7572707F7A7876787473706E5957537473727776737B7A7771706D\
74746F77777278787374746F76716E7D78767B7876807F7C7675727877746E706C
84838075736D7B7D7982898B7D807E7A7D7B7F7E7B807F7C7776737E7C78807E7A76716F706D6B\
69686579787577767383817D76747075736F7D7876746F6D76706B77716C7A746F
6F6F6A7C7A767675727978757E7D7A7976767F7E7B7F7F7A6E6D6A7E7D7C7D7C797F7E7B757973\
777B7575797371736F6463607B7D7971706D7673737B7876807D7B71736F767874
6264606B6B647B7A777D7C79716E6C716C6A76737377706E
777A787A7976666C676F6E6B71706D6A69667271707C7B7A717774747A777177747572747C7C75\
787D7F7578787678767375737476747C7B7A7776757B7A79727472747674747372
7675747776757577757678766F6D65807F7C7071747574737574737476727B7D79757773787577\
696C6C6F716F7A7C7A7E807E797B797375738387827274707875736F7270727170
7676717B7B767979746E6F706E6D6C7274725E5D5C73716D3D38357976767D7C79858481777673\
78767072706C696B677A7C7871736F7C7E7C6C6E6C6C6D70747576727472828681
777B766F72727978756C6A627774727D7C7981807D807F7C7978757B7A777877747F7A7775706D\
7C77747B7A797776758286817779757978757D7C7B6A69667C7A767C7774797270
777673737571756F707E7B7B7E7D7C6E716F7877768B83818782806B6D6B7B7B76777772827D7B\
7D7A787D7C79817E7C817E7C71736F787A767375716D6C6972716E74716F797472
7C75747372717675747976747C7977787573807B797B7876
828082747674797C7A76797772747271706F7875737F7E7D7A7C787E7F8075757A787A78797B79\
7473727D7C7B767574737573797A7D7776757574737A79787572727274726E7471
707673777D7A777B757477777473707B7A776D6C697776736F6E6B797472797D7873706E797B77\
71736F807D7D777675757775777474857F788A85827E7B797576777F7E7B666365
6F6E6B6E706E7174746568666D706873716D706F6C7E807E7E807C7A7C786A6A657F7F7A757570\
6F6D677775716F716C6C6E69585A55615C59716C697F7E7B72716E706F6C6E6D6A
7B7A777F7E7D7B78787D77787D7C797473707B7674807F7C797D78727671797B7778777472716E\
7B7A777E7D7A7A79767676716D6D687777727A777577747277706E74726E6D6F6A
767470777571797B797375717A78747F76768784827F817C6F716C6E706B7775717C7C77807D7B\
7D7A7883807E7B7671857F7A7E7674847875706E667B7D7B7C84807472747F7C7C
736E6C7169677974717473707A79767574717D7876777270
7A7E797779777477757578766E706E6E6D6C827F7D757473767B7E767C7B7379767375737D7F7D\
6D706E7275736E716F7774747774727679777578767C7F7D7372717A7C7A7F817F
797B797B7D7B7775797C7B7A7477777376767073737574717D7C797974727E827D7B78767D7876\
7377727D7A7A8281807F817F7C7B7A8483807D838876797B717273767574716F6B
736E69817F7B6A696670706B7B808563615D7776736E706E727470777975747775747775727573\
5E605C7172737C7B7A7473726D6C6B7372717675747C7B787A79767473708C8B88
7A79767777707C7A747C77727A79767B7A777D7A787B7A77797B776F736E7A7C7873726F71706D\
7978757C7B7874737079747177726F6D68657B78767C7977807B787C7A7671716C
7B7878807D7D7A75737C77757C7775706D6B7877747C7E79797B767D7F7A7A7C7A828583747672\
797B777D7F7B737573807B767C7B787E79766C6F677375707C7774767979808280
7574716E68697D7A7A7B787673706E7875737C797B7A7779
7876787274726C6E6C797D78747873767A757A787A7D7C7B787776747674767876706F6C787A78\
75747179787572716E777D7A7177747C7B7A767574807F7E7976747A7976777879
7B7D7B7B7D797D7F7D73757369645F7B7973777A727577756A6C6A7C7677787B79838080777673\
787774767778787A78696B697776756C6E6C6B6661716F6B75736F78786F888786
767A757572706A6C68767371635C5A7375717D7F7B6F716D7978776C6F6D7C7A7C797B79686E6B\
7477778988856E69677978756F736E767371757471787C777F7A7870726E7D7C79
75747172716E7675727D7C797C7B787A797681807D7A7976696865777472787C77797974716F6B\
7B76738C8B8871706D7E7B79827F7D7572707B78767A7775757974767A75737772
6966647976747E7C787977736D6B677F7A7873706E7A7C787A7C787C7E7A77727085807E7F7E7B\
82817E767572706E6A7A78747B7A7772716E7C7B787F837E777B766261606A6968
7271707F817D6D6F6B706F6C7A79766D6C69787774797875
7473707174726D70726C726D6A6C687873717477757D8380767873767873747671727170757775\
6A6C6A757775737573757C7B787C777C7B7A6F6E6D7776757A79787C7B7A797B79
7678767577756F6E6D7872737B7D7B7C7E7C7C7E7C7C7B7867666371736F787A767274707B7A77\
7D7C797B74756F696A7776757A7976706F6C696962706D6B6C696B6C696B767375
74767270726E6C6E6A74746F74746F7B7A797A79787D7D7873736E78777671706F797B79838684\
7374777E7D7A72716E5D5A587875737C79777F7C7A7877747978757E7B79787A76
7B7D7973726F7473707A797677727084817F7B78767E7D7A737974757A7C7D8082858481757471\
7C7B7875736B76746E797773706B6877706E726D6A817C796665627D7C79757471
72716E7574717572728382816B6D6B7473707877747F7E7B7673717A7475726F6D7A77757E7D7A\
82817E6D6C697E7D7A7F7C7A575653807F7C7877747E7977797271797B776B6D69
7577737F7A787A7E797574717776737A79767F7E7B7F7C7A
787B797775797973747574737C7B7A7877766968657072706F7071797A7B7475767875737D7C7B\
6F716F767876767876797B797476747576776E6F70757677797B797D7F7D787774
767574747276767874767876797B797B7D7B7D7F7D7C7F816B6C6D76737171736F7276716C706B\
7A77757372717877767D7C7B7A79787B7A7969686572716E6D6C69726F6D74716F
7576777B7A796562606E6D6A7574716E6C687977737775717C7B787377726F6A68767371757773\
797B7672726D726F6D75727074716F7F7A777B76737774727A7775797674787575
7D7A7A7A77757B78767B78767D7F7D5254507E7E796D6C697D7C7B7C7E7A83827F73726F72716E\
7978757D7C7965646178767281807D7173717675727776737877747A79767F7E7B
82817E7A7C787574737A79787D7C7B767373807E7A7675727B7A777F7E7B7C79777976747A7775\
726F6D6E6B697777727A79787F7E7B807F7C81807D7D7F7B6E706C6F6E6B757270
77727078757374716F7A77757F7C7A817E7C83827F7D7A78
7174767678766D6F6D74746F6F75727475787875757877767776757978777473726A6966787A78\
717371747674797B797476747A7C7A797B79696B69787A786667688079777B7674
75706E7D7876807D7F7C76777873707976747574737574716565607E7E796B6A677372717D7C7B\
7D7C7B6C726F6F716F7D7A7A6F6D6F7B7A797E7B7D7577757F7A7875736F7B7975
757973787873837E7B716B647775716C6E6A6E706C858783716B6C6C66676F6D6974726E787672\
79797473736E7C7B787574716C6B6877706E7B75767B7D797779757A7C787C7E7A
7E807C7A7E79858481807B797D7C7B7B797B7B7D797F817D7678747275777D797E717772707671\
777D787B7876787C7786817F7A797673777273716D7A77776C696773706E706D6B
827B7A7A79767175707B7A7776716F807F7C76757281807D7978757F7E7B7C7C77767574868381\
807F7C787A7676716E76716E7B78768E8B897B787673706E7673717C7B78696865
78777476787384818173716B807D7B7E7B7D767371807D7B
716E6C7173717B7D7B79777B6D7370797B77797B79787B797A79786D6C6B6D6C6B7A7775707874\
6F716F797B797577757678767476747A7C7A7476747779777D7F7B787F80777472
7976747A7775787B7B7375737A7A75777975787B79767375656B6870706B7B7A77797877747372\
7776757572727B7D7B7C7F7D7675746A696879777973767476716F8082807E807E
7670717C7B7A7D7F7D6B6E70707270706D6B84817F74716F7C7A766B696575736F797773868480\
77726F75706D7F7E7B7776736B6A677471737A797672747051534F797B7784817F
7F7C7A858783787774726F6D716F736D6C69817E7C716E6C7F7C7A7E81817A8180757471757471\
7D7C79726F6D666A657579747A79766F6C6A716F6B767373797674706D6B6C6967
6D6F6B777472726D6B7D7C79696B677D7876716C6A7A79767A79767473707B7B76797877797674\
787774797B777A75727C7774777472817E7C7D7A787E7B797F7C7A706F6C83827F
7978757B7975747A77807D7F7976767674707B7D79858783
7877746D716C6E6D6A76787676787677797773716D7B7A7973726F706F6C706F6C7C7B787E7D7A\
7675727B7A777978756F716F77797774797B6E746F767C7B707577747779787678
7B7A797776757A7872807E787D7C797776737978757675747473707A79767A7976706F6C71736F\
797B777677787274727779756C746E777B766C6B686A6966727470717371757775
7370707D7C7B5C5E5C7D78737977717776736E6D6A75747174716F726F6D7976746F736E787774\
76716E7A7874777772696B666E706B7E797673777177797D78797A868883818381
7D7C7976716C767470757471706D6B7875736F6C6A7C79778885837573757472747E7D7A767572\
7978757E7B797976747D7B777876726F6D697A7976797875767C777177727B817C
7D7A787A77757F7E7D7B7A797D7D787675727B7A77676A6A7D7F7D7F7F7A827F7F7E7B79787774\
7675727B7A777A79767776737A7C787E807C6C6E6A81807D7E7D7A7473707E7D7A
807F7C7E7E77827A767574717F7E7B7675727C7E7A7A7C78
7776736A6C6A6E7471787A7677797570726E7A79767D7E816E726D7473707B78767A7777797B79\
7776757A797872717071737177767576737175747174767279787579787575736F
7C7B787C7E7C707673797B795B5D597476727678747375716D6C6973726F7B7A777B7A77757775\
757775777A78747370797773797D787377727A7976777673797875777673727470
7678747978756B6866756E6D6962606E6D6A71706D6968657774727C7B78646360726F6D777472\
7478736E706B7A75727D7D78676965434742757471757775646360544F4C787670
7B7A7774726E7D7D78787873706D6B7C7E7A7577756B6D6B81838174726E6E6C687C7977787573\
7673716F6E6B73716D7979747775717D7B77787672817F7B867F7E7772707C7977
747872837E7B7F76767D78767C77758886827A78746767627D7D7880807B7A78747F7D79757471\
7B7A77706F6C7D7B777B79757675747776758988877A817A64666174716F807F7C
7678746E6E6965646371736E7F787771706F787A767D7F7B
757974777977787A786B6D6B7273746F6F747775777073737473727375737477757A7B7E7A7978\
7877747E7D7C7876787174727577737A7E79717570737772787B7B7477777B7D7B
7274726D6F6D78767284817F73727175747373727173726F7473707774727D7C7B797A7B787774\
7C7B7874716F7D7C7B7576777D7A787E7B79747C787477757A7C7A7F7E7B73726F
7473727372717878737D7F7D797B797C7A766B69657A787480827D6365616F6E6B777673747370\
7976747875737674706A716A7878737772707A75738887846F6E6B72716E7D7A78
7673717D7D787A7A757C7C77817E7C7A79767A7E79757773706F6C7678737676717B7A7772716E\
7776737674707C7A76726D6A7B79757577727772707E7977737573787A78646664
7B7B767F7E7D7A7976797875807F7C7F817F77797775727076757277797580827E80827E777A78\
787A787A7A7577777271716C7678747C7B7873706E7B7B7677777281807D73726F
7A797679787572716E7A7978767574767574807F7C747370
72747271736E68696A77797575777380827E797C7A6D706E727B776A706D7B787878807A6E7173\
7076757275756E6F70696B697476747D7C7B7D7C7B7D7C7B7276717678746E7171
737676737676797C7C7778797776758281807A797874716F7875737C7B7A7F7E7D767574777673\
7B7A777D78767B787675747161605D7E7D7A726F6F7A7777777F7B6F716D767572
7974727473726E7173767876686766787A787779777C7E7C666365665D5D747372757473777772\
7976746E6B697D7B7768666273716D73726F74737073736E72726D767671848382
7B7D7B6E706C75777375777386817F817C7A726F6D7C79777B78767675727473707C7E79787873\
7B74727977737779747E7C767B7973716F697577737678747A7874767470888682
7D7B7773716D7B78767976747976746E69676E69677C7B787875736F6A68787A767F7E7B7E7C80\
817F8184838081807D7C7B786466627D7C797774747B7A776E6D6A7C7A7C848284
7F7D7F7A787C8785898B8684767A757E7B797D7F7B767874
73757377787B787A7871736F7678747375717C7E7C6E706E6D6A6A757473777675747A79737570\
767778757878737676797B797779777275737679777C7F7D757974787A767C7B78
7B7A777E7D7A6C6F6F7273747D7D787C7C7774746F716E6C757270727170737271787776706F6C\
7574717C7B787A7C78797D787775777D7B7D6C726F7C79797D7F7D70726E7A7976
706F6E7D7876827C7772706C6B666370726D70726D7678735D5F5A6D6A6A6B6A696B6A6972726D\
7A7C78787A7672706C78767272706C68676473726F7979747676717B7B76706B66
76746E74716F757270807D7B74737083827F7D7F7B7D7F7B787A767574717978757B767372706C\
6C6E697E807B767A74706D6B7875737A77757E807C757773666866727472757775
7D7A787976747875737E7B79858280777472797674777B767A7C787C7B787B7D79787774797875\
7E7E797E7E777C7B787776737B7C7F7A79786B69637A79768E8D8A7675727B7A77
7C7B787F7A787A7573827D7A666A64514F4B70726E797B77
706F6E7173718385837471717976767E7B7B7779757678747C7F7D777A786F716F7C76777E7879\
7978777274727375737C7E7A787A76797B797678767274727F797A75706E767574
7A797676757272747070726E767977797C7A6F7270777A7A767574787371797D787673717F7C7A\
7379747675727A7976706F6C76787675777572716E7C7B78747370757773807D7B
6B6D697574717D7A787B78786A6765807F7C7574717B7A7767655F77756F686A666F716D727470\
7878737777726F6D6974726E6D6B6776716F7E79777F7E7B7574717E7D7A706F6C
81807D7A79767574717978757C77757572707B7A77767874777975818786787E7D7B7673787370\
7F7A77746F6C7375706E6C68716F6B84827E6C6B687E7D7A8D888585807D86817E
7877747473707375717F7E7B827F7D726F6D75747174737275747172716E7F817D787A767C7B78\
7E7D7A7877747B7D797476727E807B7B7D7880827D7F7E7B6E6D6A75706E6C706B
7B7876746D6C847D7C7978757574717574717B7D78797970
787575787B7B787C776D73706F75707E7873706F6E7577757375737678767476747B7F7A737772\
787B797A7C7A7A79787B7A777877747C7E7C787A78787A78797B77747672797875
7B7A777978757077707B7F7A70746F7875737779756C6F6D7E817F7572707E7D7A727470777673\
71706D7C7B7A6A6968777675777B75777E7D7B7A777C7B78787774747674757775
726F6D72716E7D7F7B7A7A756666617876727D7C797A7C7A7274707A79766F6E6B62615E6D6C69\
716A686E676575736F706E6A75736F847F7C817F7B6665626F6E6B777673777673
6F6E6B72716E7877747B7A797675727572707875737E7B797A7775767A75787C777F7E7B7C7B78\
7675727B7F7A7C807B77777275747174737282817E7B7A77807B796F6E6B6D6F6D
7473707D7C797F7E7B7E7D7A7A7976807D7B6865637F7E7B82817E7B7A77807F7C82817E7C7B78\
7C7B7883827F7572707B7876726F6D7572704B48467B7A777C7B78777772757570
73726F7F7A777F7A777A77757C7B787779757C7E7A747370
7173717274726D706E7577757375736A6C6A7473707A7C78787A787375737375737E807E757775\
7275736B6E6C777A7874767478777671727371736E6F716F7577757D7F7D7F7F7A
7D7C798382817978777C7B7A747775757775706D6D7B7878737674767574797877787776787776\
7473727A7C7A6C6E6C767876726F6D7673717C7B7A757473747372727671747873
6D706E77797771706F75767784838078787375757072726D3C3C377575707676716E6E6962625D\
70726D7375706C6E6A6E706C585A567A7A7573736E75736F62605C7B79757E7C78
7F7D797D7C7971706D6D6C697C79777978757D7C797E7D7A7C7B787977737C7A7673706E797674\
5B585682807C757570787A767A7976777472716F6B807E7A72716E7B7A7773726F
7C7E7A7D7F7B817F797A7A757E807E7577737A7C787478737E807C7978757F7E7B71706D7D7C79\
7A79767B7A77747674706B6876747681807F7D7D7872706C74726E706D6B797674
7C7977696B677C7B7875727073777264615F7B8180706D6D
7779776A6D6B7177747E7D7A757773797D788385837E807E767E787974727C7977777A78797C7A\
7275737179757471717D7C797A79767779757E807C727470787A787174727F7C7A
7B787673706E757775707270757878797B797B7A777476747779777C7C777C7C77797974787774\
7473707476727E807C6F716D706F6C7776735A585477757173716D7B7B7280807B
7978777F7E7D82818081837E7878737D78767A777573726F7A797673726F706F6C7A7976797875\
59565463625F686A656A6C676A6C67656860787A757B7878676665757775827D7A
7D7875757775797B79787A78797B797A79767D7C797978777A787A70706B7B7D7B737271737271\
72717077777283837E75747179787571706D7675727D7C797978757D7C7981807D
857E7D7A777583827F84838081807D7C7B787574718483807E7D7A81807D807F7E7A7978827F7D\
7C7B786B6D6975747173726F6D6A68706D6B817E7C82857D8587858381857F7F7A
6A686A7A7C7A83858377797582817E7D7A78787A767C7E7A
6D6F6D6D706E7278757675726C6E6A6C706B757775707270756C6C7D817C767874757473767574\
7B7878747A7772757371706D71706D797A7B7778797778797875757776757A7D7D
7679797376767779777375736F72726F716F7877747375737577757D807E797C7A7C7F7D787774\
7E7D7A7273747374756F70716B696B7876787A7C7A7577757C7E7C7C7B7A80807B
7F7E7D7A79788685847F817F71706F797875797B777579747F7E7B7A797672716E777673706F6C\
68656351504D74767165676270726D787A767F8081777474767574747674716E6E
7E7B7B7A7C7A7B7D7B7A7C7A696B697776737675727473727674767E84837C7B787D7875797471\
6863607C7B7A7D7C7B7574717877747F7E7B7877747E7D7A8F8E8B6D6C697A7976
7E79777C7B787F7E7B6A69667D7C7982817E7D7C797A79767776737D7C797978777C7B7A7C7977\
83827F7C7E7A7E7D7A807F7C7577737A7C78888A867D7F7D61635F6B6F6975787A
7B7F7A7A78747D7B77827B7A7572706A6E6976787470726E
7177747577757678766A6D6B6466647C7F7D71736F7A7777737573757775727472737573797B79\
6E6B6B7F7C7C7774746D6F6B797B777675747C7E7C7577757473707D7C79767373
7976767F7C7C7C7D7E717371757773787A76727470797B777375717675727B7A777877747B7A77\
7B7A77787C776C67657476726D6C6972716E81837F7D7F7B7F817D686E6B818881
8486848B8D8B7A807D6F70717C7B7A76716F6D716C7B787673726F7574717877747976747D7876\
7A77757473706769655F5E5B71736F7974726B666481817C676561716C69777472
716E6C7B7D797D7C797F7E7B7C7B787473707B7A777C7B78545350787776858580706F6C7C7B78\
6C6B6881807D7574717A797676757271706D75706E87837B787774747370777673
7C79777B78767D7A786C6967888583706D6B7B7A777E807C807F7C7D7A78767572797875767876\
76757477757171706D7473708988857D7C7972716E7F78767C75737978757C7B78
7D7C79757B76868582807B796E69676D68667673717F817D
7877747C7E7C7678767572726E6B6B7B7878797D787A79767B7D7B72747270726D797773797877\
757876737573706F6E7A79787174727877767E7D7C7F7E7D7E7D7A777673797B79
7577757072706B6E6C6D6C6B7774747C7B7A787A786E6D6C7972706D6C6B7C7B7A787776807F7C\
7F7E7D797B797574736F6E6D7976747776737B7C7D7574736D6B677676717A7C7A
8386847C7F7D7B7E7C727470797B777B7A777D7C7973726F7F817D7675727B7A77797875757471\
716F696F6C6A64615F6B6866676462726D6B70746F766F6D736C6A787371696763
7E7C787D7A7A7978777A7C7A7274726F716F7E7C787E7C7872706C81817C7C7A76787371726F6D\
79787578767277757163605E787774797B777B7B767777727675727D7C79797875
73727175747380827E807F7C6A6765807D7B797B77797B777F817D7375736B6F6A6D716C7A7976\
6A6966807F7C7978777776737B7D787977797E7D7A5F615C7B7B766A63616D6664
706B68666D6C797C746F7272787A7875736D7C7E7C828482
737571797676777675817E7C656C6E5E615F7574717173717673737A79787577757877766D7370\
7774727D7A787875737779777B7D7B797B777476727779757D7C797C7B78767874
7B7D797577736F6E6B5E5F60706E6A7776736D6F6D807B797E7B796F6E6B7E7D7A757471807F7C\
7F7E7B75777374767267696579777378767285807D86817E8B86837673717F7E7B
7D7C796F6E6B6F6E6D76716C7A7C7A7877747877747B7A777572707B7A77737571787A76767874\
6C6E6A7978756A6C676B6B66726D6A76746E67655F75736F74726E6B6965797875
7D7C796E6D6A78777472716E7B7B766666617F7E7B7A7775807B797D7C7964645F7F7A77716F6B\
81837E7D7F7B777673777675767371706B667B776F706E6A73757176787470726E
7F7C7A7774727B7D797A7976807D7B797B7772747081807D78777485848173726F7A79766E6D6A\
7776737E7D7A817F7B82807C77767373726F72716E71756F7D7D787B7472727873
8D90907A797877767377787970736B7577757B7A797F7E7D
76757479797E7374756E716F7D7A7A7D807E7A7D7D6D70707972707674707B7F796E6F707C7D7E\
77757780807B7A79787177767375737776757F7E7D706F6E7476726F716D747775
787B796E716F6A706D646664655D5B7E7C787D76747673717774727F7A787B787671736F7A7775\
7B787672716E79787573726F72716E7978757679797A78747B7E7C646B6C5A5958
615C59625D5A635E5B807F7C72716E7D7F7A797B767375707476747D7F7D86817F686563767874\
73726F7177727678767072706A6C6A7E7D7C7B7A797A77776F6C6C7C79797C7977
7F837E7C797B7E7C7E7778798987837B797580807772726D8382817E7D7A79787584817F726F6D\
7C79777D7C7982817E81807D767371807B796A69667C7B787274707A7C787D7F7B
8E8D8A706F6C8784827B7876868381807F7C7A7976787C777F7E7B8782807E7D7A7A7372706F6C\
7C7B787D7C7968686179787571706D7C7B7863625F78777476757276716F807670
827B797875737B7D797E807C7D7F7B797B7782848081837F
797C7A747671787A76717A76706F6E7370706F736E777B767B7D79797D78777D78767778777879\
77757780807B7776757A7D7D7B7A797E7D7C7776757877767B7D7970726E7C7C77
70706B7979747578767978778382816E76727476747274707577737B7D797B7F7A797F7A777975\
6D6F6B72716E7A797673726F7D7C797B7A775D60605755515F62606666616D6A68
55555070706B7777727C7B787D7C798082807476747476747C7E7C757775797A7B757878737978\
6D716C7A777575747177767378777466615E75706D706E6A716F6B6B69656D6F6B
7873717E7B7B7B7A79696B697B7D7B7C7E7C7E7C807674767C7B787877747B7A777D7F7B757773\
7D7F7B6A69667A7976757471797674817C7A7675727A79767F7C7A7E7B79787573
7776737978758C8D8E7D7E7F7576777877747B7A7778737181807D7B7D7977797573726F7B7A77\
7A79767473707070696A696678777473726F7D7C797877746F6E6B737475807B78
7C7B7A7877747577737D7F7B73757171736F827F7D767371
6E706E747674787A78767071727170767C79807B787C7977757679727376757679777977737573\
72716E7978757A79767978757A7976807D7B7B787677747278717077706F7C7E79
797B777173717675727C7B78787E79656B666E746F7774727A77757C75747B7D797F7E7B797B79\
7678767C77757978757A7E79706F6E7A7C7A7A797872717062625D6A6560757270
76757276757273726F737974787A767473707E7D7A7B7A77757473737271706F6C7676717B7B74\
7675727A79767976746D6A68757471817A79817E7C7574716867647978757D7A78
7774727877747D7C797473706F6E6B7978757877767574737D7C7B7B7D79787A767E807E70726E\
7375717876726A686472726D72706C716F6B7D7C797F7E7B7B7D797F7E7B7D7876
7A7976757471716E6C7E7B79817E7C777D787D7A787C7B7A8887867C7B7A757270767371807D7B\
787573817E7C7776737675727F7E7B74737082817E76757281807D757270737271
73747577767579787573716D7F7C7A7F7C7C7B7D797F7E7B
797676787A767274707076736D6F6D716E6E787A786F716F6E706C797B776F716D7072706C6E6C\
7F7F7A72716E7472747674767572727177766A6C6A7B7A777473727978777E7D7A
7B7A7773726F7478737A7E7974737072716E7978757675727A79767C7B787A79767E7D7A7C7E7C\
71706F7A7C786D706E727671747672716E6C71706D72716E626462777974807D7B
706F6C7473707C7B786B716E727170797875777673797875838281777472787170766F6E787170\
726F6D79747273706E75727071706D8786835F5E5B81807D7E7D7A72716E7D7C79
7877746E6D6A8988857A7976727170757473747370716E6C7D78768584817A79767E7C78797773\
73706E7979747E7C7881817C7674707977738782807A757378777482817E6A6966
71706D7A79766F6C6A7E7B797E7B797A7A757F7F7A817E7C7572707F7C7A7875757D7A78797875\
7E7D7A7F7E7B7776756A69686668647D7C797B78767878737A787473726F7A7976
7877747B7D7982817E837E7C7875737274707473707A7976
767572787A78757B785C5755625F5D5C5B58716E6C6668667A7D7B777977737070767574777675\
666C6B6F7270767874696B697072707F7C7A78757373706E7E7B7B767371747372
7D7C7B7978777E7B79777673807D7B7A7775807D7B7976767978776F6C6C7C79797C7979858282\
817E7E7375737B7D7B7D7F7D6E726C7B78788185807C7B786F68677E7D7A747370
76747082807C83817D797B777579747C7A767C79777E7B7B7978757877747B7F7A777673757270\
6F6F6A73736E7673717E7B79706D6B717371706F6C79736E69626077706F7F7C7C
7877768584817A7775767371817E7C7D7A78817E7C77747274716F7B7A777B7A77736E6C7A7573\
6D68667D7873736E697E7E776F696474726C7C77747D7B777B7A777776737A7976
7E7B797B7876767C79787A76736E6B7A7C7873726F74716F7F7C7A7D7A78737573717371787B79\
7D7C7B7F7A777F7A757B7876757772746D6C8281807C79777976748A8A85787774
83828174726E67656179767683807E76746E74737083827F
686C67707671706B697572727877767D8380727671797B777A7978777675787776767574787776\
757775767876696B6969716D747A77777071757272777D7A727470727470807F7C
7877747B7A7775706E817E7C7271707E7D7C7877767B7A776F6E6B7675727B7A777A7976797B79\
7271707A77757A777575727073706E79767476746C6D6B676D6A6A7574736E6D6C
7377727A777577797575736F7F7D79757471807F7C7C7B7877767381807D7776737E7D7A73726F\
7A7976706F6C7B7876716E6C6C696775736D79736E7B79756A686475736F817E7C
73706E8582807673718885837A7573757270807B787974717B76737A78747C79797E7B797A7775\
6764627B7673827D7A6F6D697D7674756A697875737875737976767D7A7A807D7D
74787283837E7978757473706E6D6A73726F7877747878737D7D7870706B74767483827F807D7B\
7C79777572707372717275737873717C807B7976746A6A657C7B7A7D7D78787873
7A7A75837E7B868480827D7A726F6D7A797886817E84827E
7B787678797A7973767574737A7C7A7C7F7D7175707779757E817F7477756A6D6B737271737271\
6C6E6C7678767476747C7E7C7976767A7A757B7B76797974727470686A66767572
7D7C797B7A777379747B7A777A79787574737D7C7B7A797675747173726F7A79767D7C79747671\
7979747C79777D7A787A777573706E7D7A787D7A7A76737158565080807B686863
6E6D6A7B72727A77757775717C7A767A79767776737978757473707F7E7B6B6A677877746C6B68\
7E7D7A6F6E6B7875737A7775706D6B797270706E6A7977737F7D79696763817E7C
7976747B78767A77756D6A6875706E6E6B697A75727F7A777E7976827F81827F7D7D7A787B7876\
7F7C7A797471746F6C7E7674766F6D7876727A77757A777579777184827C797771
817A7877726F7B7A7775747172716E7B7A777A79767F7A777B767387827F7B7D7B8483807F7C7A\
827F7D73706E7B7B7675736F7D7876797D787572707C7679807B79716C6975706D
8B86838A8582807E7A827D7A807D7B7776757A7978777977
7A77757B7C7D7978777E7B7B77747273706E7574737B7A797E807E747674787A78747576757473\
7372717473727B7A796F6E6B7574717D7F7B70726E7678747278737C7977757270
7673717976746D6B677A77777A79767978757F7E7B7D7C79706F6C7A79787776757A79786A6C6A\
71706D8D8A88807D7B7E7B797E807C8185808786858887867B7B767D7A78706D6B
7F7C7A7D7A78807D7B86817F76787470726E7675727A777572716E7B7A777B7D79757471777472\
76716E75706D6C6A66767470716F6B706D6B7A77758683817976746966646C6A66
68666273726F797B777276717675727C79777B7A777D7C7973726F6D6A687875737D7A787A7775\
777472827B797B7673706B697B76747B76747574717A79767A77757A7775757270
7A7A757D7B777B7A777C79777974727976747E7B798E898778757381807D7D7C797675727D7C79\
706D6B7D78767F7F7A787672767876787776747171898B877C7C7779746F6E6869
5A55507473707C7B787C797778777477797582827D7D7B77
7872737574737776756E7471696C6A7072707A7777807F7E7F817F7072706F716F73726F797B77\
797B77797B797977798483808685827F7E7D6F6E6B7E7E7975747173726F777B76
7978757873717E7C7E7B7A7774716F787573706D6B7877747675727E7B797B7A777E807C7D7F7D\
7779757B7D7B8B8D8B7577757E807C6F6E6B7F7E7B807F7C757471726F6D7D7C79
6B6A696E6D6C8585807678747274706F716D7C7B787572707D7C7B72717063625F7C7B7871706D\
7675727D7C797D7C796D6A6878737177766B7774727B7A79737271757471706E70
81807F74716F7C797776737178777477767372716E7574717675727A7775797875787774706D6B\
716C6A827F7D73716B696B676B6F6A7C75747875737875736D6C6972716E777673
827F7D83807E7478727C7A76786D6C7B7371736E6B787873706E6A87827F29271F7B7E7E747372\
747171847F7C7D7A787E7B7968676479787574737073736C6A69667A7B7C6D6E6F
767778827D7B858481777B76807F7C837E7C7D7A787A7976
717774707673787A787B7876787C7772716E807F7C6E706E7877767675747E7D7C7A7D7D717474\
7776757577756C6F6D7776737C7E7C6F716F707270767876787A78787A78727575
767979787B7B74737076757279747273706E79787574767181817C7C7B787E7D7A7D7C79787774\
94939077767371706D7A7976797875757471646A6583858174716F828482797B79
5D5F5A7D7F7A73757073757177797573726F757773797D7873707074737276787473757180827E\
706D6B7C797773706E75727073706E7877746665624E4D4A6665626D6C69807A7B
8E8987827B7977726F72706C7776737776738385817A797684817F86848077767571716C73736E\
70706B6E6C6877757176716E76747071716C797974767671767874797B777B7D79
7978757978757372717976767974717B79757E7C787A79767A79767A79766867647D7C797D7B7D\
7776756B6B667C7B7878777481817C7A7A7571716C838581737772898984888883
7B7B768587837779757F7E7D7F7E7D7F7E7D797B77898885
736F747E7D7C7776757073716E706E7D7C7B7E817F737571747777757878696C6C7E7D7C7A7978\
7578786E71717376767F7A787675726E6D6A757773717570797676747171757775
7678767476747575707C76777A79767A7976807F7C787E7D7E7C7E777F79787A78777A7A756E6D\
716C6A72716E7776737A797675787867696784817F7776735E605C76787470726E
6B6D6B7A7D7B6E7471787A767476727D7C7B7C7B7A84838273706E6F736E7B7A777978757B7A77\
6B68687A777775777370726E70726E6D716C746F6D767A747A7A7587827F6A6560
635E5C686D6F79737673757171706F77767574746F7A79767574737673737F7C7A787A787A7976\
79736E7878737676717775716F6D6972706C7C7B786968656D6C697E7D7A797875
7C7B7A7473727D837E797B777F78777873718883818183817E807E6B6D6B7A7D7B777975787774\
76757275747175747181807D7C7B7A7473726C6C67706F6E7372717E807E6A6C6A
75777583827F7F7E7B81817C7A79768280827C807B747370
6D6C697F7E7D7978777376746E706E7B7A7972757775767778777472716E7C7B78807F7E7B7A79\
75747175747172716E7A77757675727C7B7870726E6B6F6A777675706F6E767876
787A78787A78757570797B797675727776737E7D7A767A757A7C787976747973747C82817C847E\
7375716C6B6873726F7F7E7B5E5D5A7D7B7766636173726F6B6D697E807C7F817D
73716D80807B6E706B70726E7476728685847877767574736769657A75736F6E6B71706D797875\
77757176747075727073706E706D6B7A79767A7C787B7A7770746F747A757C7979
7674707E757570706B7B757076757471706F75757073726F767574615E5E7D7A787F797A7A7775\
7F827A7676717A7A757476717779747577727D7C797978757B7A77767572797875
7E7D7C7D7C7B83827F7D7C796D6C6983817D7C7A76727472797B79767876706F6E7673717B7F7A\
737772777B768483807B7A7782818086858480807B75757072726D7C7E797D7F7A
8688838483807C7B7879787580807B6B6B626F716D7D7C79
787170706F6E6E706E6E6D6C71706F7776757372717978777978757E7D7A6F6E6B7F7E7D777675\
7E78797D77787771727A77757574716D6D6872716E7A7978787A787D7778757974
7B76747E807C75747171706D737772817C7A7E807C76737171706D78767281807D7B7D7B787774\
7675727B7A7772716E78777475727075736F717570818580787C77817A797F7877
7E7D7A78777473726F7977738281807774727D7A787F7C7A71706D7574717978757675727A7976\
7577737B787683867E777770726D6862605A66656280827E72716E7673717D7A78
817E7C74716F7875737976747C77757A75727976747A77757E7B79837E7C6867647F7E7B7C7B78\
76757278787379797474726E807E7A85837F7C7A767876727E7E7980807B7A7C77
6C6E6C6F6E6B7674707B797572706C7C7E797876727D7F7B78777469666680827D726D6A767572\
8584818483807F7D797D7B777B78767F7C7A7774727674707C7A767C7574766F6E
635C5B74767478777475736F82817E7D7C7B6B66619C9792
7E807E5B5D5B7577757A7C7A7173717476747B7B7675777570726E77797571736F6E7471747A77\
7476727779757577737274726F716F7C7B787E7D7A7978776A69667B7A77777270
7579747A77757D7A7A76757464675F7B7B767A78747B79757A79787B7A777A797681807D72716E\
7D7C795D5F5B7678747577737E807C7D7F7B7E817F807A7B6B69657A7874504F4E
7E7D7A7C7B7877767374746F71716C7B7B767C7B788483827D7C7979787579797475736F736E6B\
78777475747176716E75706D726D6A7774727B78767574717675727B7A77787573
7D7C79736E6C7276717875737C7E7A7476727E79768483807D80807A7C7A746D6C85837F767470\
78767272706C7A787477726F746D6B716A686D6B67716F6B7F7F7A767671797974
7D7E7F848284807F7C7B7A777D7C797978757A797672716E72716E7675727F7E7B72716E7A7C78\
7B7D79828480706F6C7D7C797A797683827F7F7E7B575551757473797875787774
7E7D7A73706E73726F7E807C7574717A777578797C68645C
787A767C7E7A7A7C7875747176757273726F7A77777B78787977797271706B6A676F716D757773\
72706C7776737677787F7E7D71706F7F7E7B71706D7877747574717D7F7D7A7976
757471757471797B777C79776966667572727B78787C7B787A79767B7A777D7C79858481777673\
82817E7673717F837E75747175747181807D7C77757978756C6E6A7B7B767B7A79
72716E7E7D7A7F7E7B6B6F6A787371817F7983817D6E6B697574717776736F716D6F6C6A75706E\
726D6B74716F70706B3C3C3770706B72716E7978757C7E796F716C6F716C726D6A
7A757274726E7775718C8A866B696579777371736F7375716D6F6B7776737978757577727A7A75\
7A7874797B767C7C777D787575736F7C7C77716C69797471706E6A6E6C686A6864
787672766E6C7579737C7C776F6D697E79777C7977817C7A81807D72747075797480827E7F7C7A\
7C79777A7573817E7C6E6D6A827F7D75727073706E7C7C777F7F7A71706D646360
79787583827F79787573716B8184826E675E787370706B66
7574737678767379746E716F6F716F7776756E74737B7E7C7A7D7B7C7F7D797C7A7B797B797877\
7B78767A77757F7C7A81807F74737273706E72716E7E807C777772787873797773
7B78767771727475767F7C7C7A79767776737675727A79767D7C7973726F807F7C7C7B7870726E\
74767274737076757271706D7C7B787877747574716564617675725A59587F7E7D
7572707D7C797476727C7B7A797877706F6C78777472716E7B736D696364737571737571747672\
71736F77797570727063626174726E867F7D6C67647779757C7E7A747672676964
7271708685846F6E6D78777684817F6C696773726F6F716D6E726D8284807A7C786969647F7D79\
86817E6A706B7F817D625D5B777673717570777D78767371807D7B74716F767371
787575807F7E90948F7B78767274707475767E7D7C817E7C777472827F7D6D6F6B7476727A787A\
797A7B7578787D7F7D81838173706E858481666864797F7A7E7D7A7D777C797877
6B6F677B7B768281807B82848979683238356772727E807B
81807F7278756E706C878A887173717C7B7A7374757978777776757C7B7A7A7978787678787776\
7A7B7C7576777576777A79787B7A79787573706F6C7A7C787A79787E7D7C7F7A77
73726F7278757379787C7F7D7675727776737C7B787D7C797675727574717D7C79797875787A76\
80827E706F6C747370747370807F7C72716E7776737E7D7A7473707B7A797C7B7A
6E6B697C7B78787A76706F6E7D7C7B7A797675747174737067655F6766656F6C6A7A77757C7977\
74716F7572706D6F6D6B6A696E6C68716E6E7A79787A79767877747F7E7B706B68
8284827776757C7B7A7D7C7B7E807C73757186817F7E7B79807F7C79747282848084847F7E7C78\
807B78817C7A7976747C807B7675727C797783827F787774726F6D7B78767F7C7A
7B78787A79787577737C77757B7A777C7D7E8685847678747375716D6F6B767874727470827D7B\
6D6A687C7B787779776F716F7F7C7A7675727A7C78767874807F7C767371747370
6E706E7472747B7A77766E684E43384E555478797C7B7975
737573757473707270727577787573797C7C6E716F6E706E7375737B7D7B7173717375737C7E7C\
707673727472857E7F81807F7B7A796F6E6B73726F73726F7D7F7D777977787774
7A79767776737577737779757B7D7B7274727A7C7A7E817F7174727574737F817F7A7D7B767574\
6766637B7A797D7C7B7471717E7D7A797875797B777E807C7A7C787B7D796A6966
70726E7F7E7B797674797674706D6B7875737A777577747274726E74746F6F726A76766F77756F\
72716E6F6E6B7578767E7D7C6866627875737572707E79777774727978757C827D
757B7674767280827E6A6C687779758185806F6E6B72716E81807D807F7C75747181807D777472\
6A65637E79767D7875726B696C6D6E74746F7674707A78747673717C7B78838581
81807D7C7B78827F7F727170787A7870726E7C7B787B767478777470746F72706C706F6E757471\
807F7C7877747A7C7A797B796A69667A7775827D7B85807E7873716C6C67706D6B
74717182817E71736F716F737876726F716D747674787774
6F7270757775797B79747674717371767876787A7572746F787A787F817F7779778082807A7C7A\
747775797B797E7D7C7C807A7678737875737A7976747672797B7771736F797877
7274727679777375737375737B7A797574736F6E6D7D7C797B7A777E807B797B77787A78807F7C\
73726F81807D72716E7776737A7C7A6668667776756D6F6D70726D7A7C7A767876
716E6C6C6967615E5C7574716E6D6A69686572716E757471757471797875767671605F5C7B7A79\
7F7E7B73726F6D716C6F736E6D716C7A77757D7A78726F6D787C777D7C79706F6C
71706D73777281807D85807E6F716C7476747B787674716F7C79777375737A7C7A7B7A77767572\
71706D6F6E6B6E6D6A8A89867978757574716562607F7C7A6D6A6A7779777F8582
787A76666361797B797B7A797674707976747B7A7773726F6B6A677572706D7072707673797D78\
85807E6E706C7375717E7B7958524B76787681807F73726F73726F7B7E7C747775
70737175777277756F78847D797F7A73726F797676706F6C
6D73706A6D6B787A786B6E6C777A78787B79676B667B78787B797B7875777A74777F7E7D7A7C7A\
7476747B7D7B7A7C7A7477756D6A6A7D7F7D787A78737573737571747672777975
77797577797571757070726E797B77766F6E7473707776737372717776737C7B787D7C797C7E7C\
767071797B79777977737573818482767977787A787271707F7C7C81807F737573
7574717776737F7E7B7D7C7976757274746D7676717A79787473707A79767A7C787B7D79767874\
7574717776738281807877746F6F6A706B66736E6C7B7A777C7B78747370797674
7572707C807A7E79767375706F6F6A7978757577757D7F7D7E807E7A79767375717D7D787B7B76\
72726D74746F8787826E6B6974716F74716F7A7C777E8481797C7A72726B7C7977
797D777878737C7B787A79767D7C797F7E7B737571787C777A7C787D7C7980827E757773858280\
777472706D6B7977797A787A7C807B83827F848C867C7B7883827F787A7681837F
6F716D696B69797B79777B767877747D7A787A7874787776
777675787A787779777678766F716F73757373706E777D7A737B776C6F6D727170747777797674\
767876757473787672777A727B7D7B7278737D7A78666A65767778797A7B787A78
7072707E807E7875777370707978777776757978777475767375737776757779777E817F7E7B79\
7B78766D6A68797674716E6C78777472716E7678736D6F6A787A7571736F777975
72747070726E7476727E7D7C79787572696D837A7C746C6A73716D7775717979727675727F7D7F\
6A6C687B7A777B7F7A7978755B565477726D75706E6B6D6B7173716567657C7E7A
7577737473707473706968657C7C777B7B767674707E7D7A73757384817F6E6B697876727A7874\
797773706B696E6D6A656B66787A767A73727E76707D7B7775727061635F777D78
7E7E796767626D6D687E7D7A7F7E7D7779758284807776757978777F7E7D73726F807F7C7A7D7B\
7F817F7A78748D8B877A78746F7071767572827C757C7E797D7F7A73736E7A7A75
81817C70726E7678747C7B787E7D7A747370807B79797472
7274728183817A7C7A747674717371787A78787C77767977807A7B747372747674756F70696B67\
72747279787774726E7A7C7A71736F787573717772767572716E6C767371767876
797B79787A787977797D7C7B787B79797C7A787B797374756B6D6B7372717072707477757D7F7B\
7678745F615D7A7C78626460767572787774777977787A787C7E7C6E706C71736F
797B777779757375716B6A6967666373716D76737177747663656377797774767A747777717472\
787A7679787576716F747370787A7674737281817C7B79756C6A6682807C7F7C7A
7C797776757272716E7D7C797676717B7B767D7B77797875808280827F7D7B78767C7A767B7975\
78767275727073726F7A797676757274737072737677797770726E706D6B777270
676561716F6B797974787774767574787A767F817D82827D7D7D7857575283827F807F7C7D7A7A\
7B75767D76747F7D79817F7B67666373706E696461676D6A717774737674747775
737674777975727470807F7C7473707A79767F7C7A868381
707371787E7B73727176716F7C79777377727577757678767270727877767675727377726A6C68\
7573756F716C7174726B6D6B7476746F70717E807E787A76807F7C6F6E6B71706F
7776757E7D7C7675727473707779777577756E706E7675727675726E706E7B7D7B7B7D7B717371\
787A787274727B7D7B828482747479828084807F7C858481797875686C67727671
767A7570746F717570757270706D6B747370706F6C7574717675727A79767271707877767C7B7A\
797875787774787A75807977787873656964706D6B7D7A7A797C7C646F6F7B8082
71767876737176737177747284817F83807E7774727774727C79777B7F7A6F716D7F7E7B787774\
7574717375717A7C785453507574717473707472747B797B8789857A7E797E827D
7574717A79767877767A7C7A73767480807B767574898684726F6D726F6D777D786E6D6A646360\
7B7A777B7A777B7A777574717C7B787D7C7976757273726F7877747F7E7B7F7E7B
75747173736E7979747574717877747A7976868681797974
6D6F6D787A78727472757775696B69757775767977737674747674707270757775717371787A78\
7473707D7C7971706D797B79757B787A787A7372717978757B7B767C7E7C7A7C7A
7771727F7E7D7A7976797875777A78807F7E7D777876757271706D797875777673787774797B79\
7C7E7C767876727472797B797776737776736E6D6A706F6C807F7C68666057554F
817E7C6C6B6871736F6F6E6B7C7B786F6F6A7A79767C7B7A7D78757E7976777675737271767574\
7675727E7D7A71736F787A76797B7777767377767376716F7D78767B76747A7976
77767376757271706D747370716E707C7A7C7779757A7C786C6E6A80827E7A7976737271787A78\
7477757577736F6E6B7E77767673717076717B7D797F7E7B7377727B7F7A797D78
7A78747B79757E7B7979767479767475747174737081807D7776737978757774727A79767D7C79\
5958557C7B787F817D77736B4F46467772707776737A7775807D7B807977565853
736E6B6B6A6772716E7978757F7E7B77797571706D81807D
7779776A6E69777A786F6E6D7D7C7B7271707C79777A79767F7D7F797779747274706E70777577\
76716F7579747572707B7A79747372757272726F6F7B787870726E7A7E79727374
7576777374757376747A7C7A7A7C7A7678767F817F7B7E7C74777581807F807F7E7C7B7A777673\
7675727A79787E7D7C7676717A7C787E807C797B7F6B69617B7E7E706B68726D6A
6F6F6A6D6F6A6B6F697473706E6D6A7C79796C6969817F7B797B777476727977737775717B7975\
7E7E797D7C7B82818081807F7877766D6C6B74737272716E7B7A77767572716E6E
7679777A7775646662767A75787A76747672797B777F817D777975807D7B787774757876777977\
767574817E7C7B78767A75707A75707C77727A7C787B7B7681807D7A79767D7C79
706F6C72716E7A7978817E7E7B76737E7D7C76757471706D73726F7D7C797779757A7C787B7D7B\
7B7D7B777977797B797B7D7B78777482817E807F7C7B817C7873717E7B797D7A78
706D6B96969177726D7679777F7E7D787575797B796F716F
777D7A707270717371727472747674787A78797B79777977757773787A76757773747370767572\
696B677274707476727678766D6F6D6B6A6774716F827D7B74716F777673787575
726F6F7A77776A67657774727C7C776F716C777974787E7970726E7B76737D7B777D7F7A777675\
76757483807E7673717572707877747473727674705A5755777474767671726D6A
6F6D697777728289827B79757873707B7A777877746E6D6A736E6C75706E73726F78777482817E\
7D7C797274707B7B726F6D69655F606C6A6479736E6D716C7675726E69677E7E79
79797471706D7A79766C6B687C7B78706F6C7772708B88867574717E8084727170696664716E6C\
7673718B8A877A79767F7F7A83837E77777280827D72706C74726E7A7874817F7B
72726D6F7071757D798281808584837D7F7B7B7D79787A757577727D7F7A7D7C797D7C79898885\
7D7F7B7C807B7476747776737E7C787E7C7873716D7A7C7A7B7E767E7D7A6F6E6B
7C7B7871706D7A7775797B777B7D797779757D7C797D7C79
726F6F73716D716F6B7B7D7B787A78777977757775717371767874787A76737571767572767572\
7B7D796C6E6A71736F71737173757370746F70726E71706D7572707574717A7978
7B7A797372716F716D7B7D796E76726466647C767775706E7774727A7C7A7A7D7B757B78767977\
7B7E7C787A7672747070726E7A79767E7D7C6E6B6B716E6C7E7B79737271737070
7877767B7D7B797C7A7C7E7C7C7B7A7B7A7777767369686573706E7C7977858481807F7C767572\
76716F7E7B796A69686C69676F6A65645D5B6B696576716F71706D7779756D6D68
7F7F7A7B7A777D7C79807F7C72716E73726F696865767874828681666C6B7477757B78767D7A78\
7774727978757B7A77746F6C7C77747F7A777F7A777C7A767476746E706E737573
716F737A7C7A6F6E6B6B6664787C77767874777975817F7B7A787476747078777483827F7A7976\
7A7C787B7F7A7A7C7A79787573716D84827E73716D6C6E697374757C7B78807F7C
7574717D7C797C79777976747C7977787573807F7C797875
6F716F7B7A79706F6E7573777573778583877A7C7A7274727A7D7B727573757876787774797875\
787573797B79777A7A747674737573787A787779776D6F6D787A787476747E817F
7976767779777C79797678767D7E7F7576777475767978777375737678767779777C7E7C767979\
7678767C7E7C6D6F6D7476747E7D7A77767376757471706F6B6A697B7E7C777675
6F696C706D6F7674767370706E6D6C6F7270736D6E6766657B7D7B7C7B7A7D7C7973726F5A5956\
706F6C7776737E7D7A71706D71706D6D73707177746F6E6B7473707A79767A7C78
7A7C78747370797875706F6C78737175706E7B7A797F7E7D7372717A77757776738286817B7D79\
76757273777283827F777270777B766E6B697D7A7878757384827E7D7C79868886
7E79777D78767D7C7B81807F7D7C7B807F7C7C7B7A7E7C787B797584827E807D7B7B7876877E7E\
79747285878380807B81807F7A787A8885877771747E7D7C7473727F7877736E6C
5D58566F7071787A78787573787774787C77838281757473
6B6C6D7574737473707978757877747877747E7D7C7776757577757476747A7C7A777472767572\
7B7D7B7C7E7C7072707476747678767777707878737C7B7A787B79787A78787573
7C7977716E6C807B787F8280787A787B7D7B797B797C79797A74757A7978797B797E817F777472\
7F7A757779777F817F757775737573726F6D7A7A757D7D787C7C776F716D7A7976
87868582817E7978757774727A7976706E6A7C7772867E787D7D787A79787E7D7A5F5E5B757471\
7D7B7778777671756F75757075736F6F6E6B7877747C7977777673777975797875
71706D79787579787578777478777662616077767383827F7A7775827B79756E6C848181726F6F\
6765617877747B7A777E7E777D7C797F7D7F7C7C777E7C78787774787774787774
81807D7B7A7774737077767381807D77767371706D73726F747370777673797B797D7C79767873\
7C7E7A82838481838180827D827F7D83827F6A6C687A797672716E7C7573797271
7871728686817D7D787877747F7E7B7E7D7A817C777B7671
6C72716B6D6B696B697376746D706E7275736C6E6A7476727779777577756F716F74716F7C7979\
797678767979737173707373757973716F717876787A787A7B7D7B70726E7A7C7A
8380826B707273716D71716C7678767C7E7C7577757F7C7E7977797477757A7D7B7578767D7B7D\
7A797883817D6E6E6973757072746F7E807B7B78787173717E827C818381777977
74716F84817F84817F79777383817D7375716D6C6976737179787582817E78787377757177726F\
7977737D807E7C777571757074716F71706F76716E7A7C777B7975807B78726F6D
827F7D7779777B7A798785817978757473707D7F7B7C7E7A83827F7D7F7D7C7E7C7B7F7A787774\
7774727276716E706C7F817D888784767371817E7C75727077757175736F75736F
7978757B7A7777797480827E80828077767376737371736F7A7C788688847C7E7C7C79797B837F\
7F817F6E69667B7B727D7C797875738582807E7B797D7C7B7B7A797C7977807D7B
817E7C61595570726D7679717D7F7D75757A767977747674
746F6D6F6E6D7A7978727472727472787A787779757779757877767A79787C7B7A7D7A78817E7C\
797C7A7B7E7C777A787678767072707675747A7C7A7578767A7D7B807B786C6E6C
7779777274727779776D6F6D7B7D7B7B7D7B6F716F6366667375738284807678767F8081757775\
81807F565854797B777678745D605E7F7E7D6E73786C6A6C847E79848380706F6C
73716D7675727B7D7B676D6A7072707F7D796C6A6672706C7177747D7F7D6E726C74746F7B7371\
7276717C7B7871736F7577736C6E6A73716D74726E7778797B78787B736F727670
71716C7D7F7B7D7F7B757773797B797D7F7D63605E7F7C7A74716F7678737A787472716E6F6E6B\
6C6B6871716C77726F7B767374726E72726D78777473726F7E7D7A747370777673
7C7C77747775696B677375717B7D797F8280777A7883827F7574717675727C75767B7D797E807E\
807E7A746E677A7775797674807A7B6B6E6C787575807E80918F8B5C5D517A7779
7E7778807B797B7A777271707978777F7E7D7E7C78737271
757B7A747775747775797B797779776B6D6B78797A797A7B7372717675747D7C7B717273777879\
737674787B79787B797274727A7C7A7877766E706E6B6E6C505351797471757775
7476747B7D7B737573787A787678767779777072707477777274727476727E807E737475757775\
7D7C7B7779757A7C78767874686766888182777E7F70737374746F797C7C7F8282
5E5C587A79767A7C7A7873707A78746E6C686D6B6774726E6F6F6A65635F74726E75736F7E7C78\
72747074737075777375777371736F6567657375737B7A79787774797773777474
7675748582807572707F7C7A807E7A64625E827F7D706D6B6A6765777772716F6B82817E757471\
73726F7B7A797375737B7A79797B797578767776737A7976797875777673797875
80807B7A7D7B7678747E807C7B7D797A797878777683827F82817E7C7B787C7F7D7F7E7B7B7876\
7C7E7C7B7E807C79777F7C7A7A75727F837D7F7D797A7A757F7D798781827D7B75
7475767B7D797C7B787473727F7E7D7A7978797C7C7B7876
716E6E726F6F6F6E6D797674757471666562757473767876737072737475686E6D71706F797877\
7976767073716F6E6D73726F7877747C7B787D7C797574716B6A697C7B787C7977
7E7D7A7A7C787B7A77807F7C62615E73726F6E6D6A7776757F7E7D7B7A797C7B7A7B7A79727472\
797B797E7D7A7C7B786F6E6B767371827F7D76716F7F7C7A7473706C6764716663
6E6B6973706E7A77756968657473707C757476737170726E7574717F7E7B7777727A7A756F6F6A\
7C7A767876726C6B6874746F74746F62605C797773706D6B84817F75727082827B
7B76717978758483806E6D6A807E7A72706C817E7C73706E6D6A6877727075706E5F5E5B7C7B78\
7776736F6E6D706F6C78787172726D6E6D6C6F6C6A75727082817E77777281817C
807D7B7572707B7A777D7C797D7C797E7E7980807B807D7B7572707B78767A7775716E6C757471\
7A7976696865817C7A7978758683817B7A77797875737070717570948E89746E69
7D787379727171736F8988858584817978757C7774767470
717472737B77797C7A757775797B797577757C7E7C7B7D7B797B797A7C7A7678767B7A79757775\
7577757274727375736D75716467657774727476727579747379746E726D787A78
797B797173717F7C7A7B7A77777977787B797173717274727973747B7D7B7F817F767876747372\
7E7D7C737573808280787A787875737A77756F68667A7A75706B687C7574707779
6B6A6774767270727081817C7C7B7A7675727A7976777673737772777B76757270787573777472\
6D6C697B7A777776737473707473706E706B70726D888583827F7D75727081797D
7775776F7771787D7F7579747972707F7D797D80807577756A68642221207B797B7B7A797F7E7D\
72726D7A79767E7D7A7478736E726D7A7E797877747A79767C7C7772726D7D7D78
7F7C7A7C7B78767E78787C777A79767B76747675727E807C787A7683858186817F787A76666361\
7877747B7D7976757281807D7C79777B787674716F6C6B687774726466647D7F7D
807D7B7A79768F8E8B82817E73726F6B6A67737976767C79
726E737472747A787A726F6D7A7C787377727877768483827678767476747678767B7D7B6F716F\
7477777073717A7E797A797877767570746F70726E726F6D767876777977757473
7E807E7A7D7B747A7973726F797C7A7779777574737076737A7D7B7877747F7E7D777577777977\
7678768487857A7C7A7D7C7B7B76747D7C797A7D7B8083817B7E7C7A7976747370
7A7B7C77787974767270726E6D6F6B797A7B7C797977726F69686572716E6A6C687A797684817F\
6F6E6B79787576787679727373736E6769657E7D7A6F70718E8D8A6F6B63777472
78777476716E76716E7F7A77807F7C7B797B8A8C8A7D7C7B65635F7678767A78746D6B67797875\
787A786E706C75747173706E7875737A77757779757C7E7A767574777675858483
7878737979746E76707B76747D7A78787A76827F7D6D6A686D6C697B7D797978757D7675777975\
706F6C7D7A787D78757B79757F817C827B797777726E706E8183817476727B7D79
77797586817C736E697E7C7873706E7F7C7C7F7C7A6F6E6B
696A6B7375717577737175707274707D7876797678787B797476747375736E706E777D7A727875\
8583857B787875706E7B78787A7C787B7975777673747674787A766F716D7B7A79
7372717A7978787A78797B796F78747D7A7A7476747979747B7A797379767A7D7B81807F797B77\
7F817D727573797B79767574767574706F6C6F7266727978726C6D7E78796F6A68
6F6E6B83827F7877747974717D7A7A7174727779777A79787875737D7C7979787581807D72716E\
7A79767A7573868480787370746C6A82817E7375718688866E6D6C757471727072
787678847E79716C6A807E807C7A768A88847F7E7D7274727578766F6A678D88857C7E7A70726E\
7678747976767E7B7B797B797B7A77787670858687737072787573757471767874
7C807A7D7D785D615B797D777E827C73726F72716E7779747B7D787B7D7871706D7A79766C6E69\
787A757A7C7775756E808079807E7A777571716F6B7977797C7F7F5B51476E706E
7473707578767B7A79706F6C7675726E6D6A706F6C767572
6B6A677A7C787577736D6A6C767778787B7B737475807A7B7C7E7C717371787A78797B797B7D7B\
7677787473726C69677376747476726C6A66777673747674777879737475757473
807F7E7776757173717375737679776E7773717371767476787774746D6E7B78787E7D7C757773\
797B776F72708587857978777A7775787C777980827C7A766B6D697A77777F7C7A
78777483827F7B7A777F7D7F797B7781817C716F6B726D6A767371797875787774706F6C797875\
807F7C7375717C7B787B787677706F76716F77747262686D797C7C767572807D7D
686B69757B7A8183818C8C877C7E7C7779777974717B79757B7B767D7B77777571797B77777975\
7375716F6C6A5C59576E706E7D7C797B79736968677E78797774727776737C7E7A
7D7A787877747B7A778584818887848685827E7D7A827F7D777472807D7B7D7C797F7E7B7F7D79\
7775717D7B777776737E7D7A7B79756D6B676D6B677E817F7C76777477797E7873
6F6A67686A6885848378777481807D7978757A7976747370
72716E71706F7675747C807B7375717C7B786D73727273747F817F6F72706F75727F817F71716C\
7275757174746F72726D73706E706E727573797B797B7A797B7A79757473767876
797B797476746D706E7275737A79767978757675727A7C787C7E7A7779757476727779757D7B77\
7E7D7A8486828584817D7A787477757578767F7E7D787E7B7A77777B7D7B747674
7B7D7B7476747B7D7B7877767877767678747F817D80827E6E6D6A7A7976676B667579747A7E79\
78797A6E706E74737271706F75747375727071706D6E706C757471777472777977
7878716E6D6A82817E7B7A7778777474716F7574717E7D7A7B7A777375737678766D7372707371\
686A66787A7674737074737070726E6D6F6B7675727877747978757A797682817E
7E7D7A7F7E7B7A77777B75707A7D7D8284827F7E7B74746F7978757A79788082807B7B767B7D7B\
7F817F7D7F7D7D7A787A797675736F74726E6D6B67787A78747775777772767476
82817E7E7B7972716E6F7574797C7A80827E747672777975
6A706D7778797679777A7976757775797C7C7376767A7C7A7D77787F817F6B7470707673797B79\
7274727375737B7D7B7370707375737078747275737A79787376746E706E787371
7C7B78797C7A7173717779777476747173716C6E6C7776736B6A6776737181807F777879717472\
797C7A7072707779777274726B716E797F7C78777483827F7B7A77737978656D67
7D7C7982817E757471787A767A7C78737978777D7C767C7B797B777D7F7B7574717C7B78787774\
6968657274707C867F595F5A66686467696473736E78787370706B7F7F7A7C7B78
7C7B787F7E7B7473707E7D7A6E706C787A768079776F716C73736E7E79777E79777375737C7E7C\
72747277797571736F7278736E746F777D787A7A7583837E7675727D7C797D7C79
7877747D7C797774727E7B79827F7D7977797A787A6B6A697A7C7A797B797B7B7477756F797070\
7C7977797F7A80827E7D7F7B7C7B787B7674737772757E7C83807E898481797674
7174767779757877747375736D6F6D727472797B79767572
6C6B68707270767876767C79787A7874737273747575767777797570726E767874757775777977\
7776737776737776736F7270717472747A77757B78747A77747A7571716C84847F
7C7E79767A746668647B7D797C7B786F716F797C7E797F7A7175707C7B787978757B7A7771736F\
7779757F7F787C77746E726D7B797572706C6B6D687B7D787779746D736E717772
747674797B797779776F716F7473727A777772717065676582817E6E706C6E6D6A7B7A777C7B78\
787A76787A767473706766636E6D6A726F6D7572707A7978787774797B76797674
787774727575787B7B6467677B7D797C7B78787A786F77737375737B7D7973726F797B79737475\
6F6F747376747A7D7B7F7F7A757471727170777A78757876717774757876797877
777D7879787575727073726F71736F70726D7575707678768382817977736C726F787E7B8C8782\
7D7B777A7976767A757C7B78746F6C6E746F7375737A79786B6A697675727E7D7A
87868380807B84847F7E7D7A7B7A777978757D7C79757570
6F736E7678767475787A7C7A7D7F7D6F716F74746F787C76727B777177747476747A75727D7875\
6F6E6B77767379787571706F7A79787376747B7A797C76776764646D6A6A716F71
7270727674767E78797A74756F716F7B7D7B7375737C79797274726C6E697A7C78737573717A76\
7C827F787E797E807C7572706E6F727779777C797976787671777473787A7B7576
7A787473726F7C7E7C787E7D7A7C7A807D7B6D6A6879767485807E7776737D7F7B7B7A777A7775\
706F6C77767370706B72726D777772716C6A807B797E79767C7A7672726D777270
7B7A7788887F7D7D78757473898B897D7778726F6D79787581837F81817C7A7A75787A76737571\
6D6F6B787A756D6C6B7274705D5F5B767874938F877878736B6E6C7073717B7E7C
7779757D7F7B737573787A787A7C7A7C7E7C7A7C787B7C7D85837F746A60796E6B7D807E757B76\
7A7E797D7F7B7F7F7A7575708280787F78767F7E7D7D7D76817C778374707B7973
76716F7578767477758B8985807F7E7A7B7E7F837E7E7B79
7376766C6E6976787473787A767B7D767B7D7177727779758481817E7D7C707371767371757270\
74737077767373726F7372717877767D78757A7A757D7F7A828180777675787573
6D6A687B78767B78787875757B7D7B7173717072707A7978707371787672817E7C7E7B7B787575\
7375737377727678747473707E807C6E706E70726D7C7A76928D8A7B736F747370
767470767572747674817C7A73716D76757272716E7776737F7C7A7776737375717C7B78726F6D\
73726F71706D77767379787579787574716F7A7775747671777974747671727873
797D787775797472747776736C6E6A757D777774727A797683858170706B7B7B7680827E7E807C\
7D7F7B7E7976747674787A767C7E7A81837F7A7D7D7F817D72726D777772757570
7F7C7A7A77756F716F7577757A7C7A7779777B7D797E7D7A7E7D7A7D7F7D7E817F7D7A787D7F7B\
82817E7B78767E7D7A73726F787F76716F6B656763676462787774727A7684817F
7979727A7A757D7D787977716C6C67787A766867646F7570
6D6C6B7E7E797577756E716F7679777477756A6C687B72727677786B6A6973706E787A76727470\
747370797B79747777707270787A78706F6E7B7A79706F6E7574717675727B7D79
7D7A787478736B6E6E6F72707A7A7572716E787776747672696D687073718885857477756D6F6B\
787A766062607274727072707A7E798487858486847173717A807D727573727470
7471717A7978686A687372717C7B7A7C7E7A78777476716F77727075747371706D7D7C7972716E\
727072797877747777777A786B6F6A7575707A7A756F6E6B7B787685807E78716F
65646171736F817C7A6165608284807B7A777C7B7A7A79787676717F817F706F6C7F817C6F6F6A\
817F7B7979747D7D787E807C757773757773777975787A765B5D5879747170726D
6F716D7C7E7A767572787774807F7C7F7C7A7A77758C8C877D7D786968657E7D7A7F7C7A7E7B79\
7C7B7A7D7E7F7D7C7B7C7B787D7B777776736A6C6A767371767371716A6162584E
7A79767F78777A7D7D6D6F6B6E706C66686476797770726E
787A78767C777978757A7C7A7779777678767A7C7A7A7C7A7B7A797476746C74707577756C6E6C\
797877787A787073717D7C7B807A7B757C757579737A7C776D6F6B747873746F6D
7B817E707675686B6B70737377777275736F7A75727B7D7B7476747779757476726F716D727470\
7B7D797C7B7A7F817F7477757D7A7A7572727B7576787776646A67686C67727671
7C7B78807F7C81807D7C7B7A747775807D7F7D7D78747775757471706F6C7B7A777D7C79747370\
6F736E767A757C7A7673716D767470696B676B6D697979747C7C777878737D7F7B
7476727B7D7B7D7C7B75736F6F6C6A807F7E7E7D7A82817E7C7E7A7F817D7B7D797B7878817F79\
797B77797B766B6D688286817C7E7A6D6866746F6D7C77757873716D6464666864
7078727D817C8683837C7F7D7D7C7B7178796F7272817A78575750737E817D817C767572766D6F\
787A787E7D7C6D73727D807E706B686E67657D76745B544B776F6B8582827A8180
7374755E5D5A797875807B797773787A7976595C5C818580
7477757475767275757779777A7C7A767876737674777A786F736E72747072716E747672747873\
737573797B797274726E706C7577737B7878767876696C6A7E807E777977767C77
757B786F75747876787977797C7D7E7A7B7C7C7D7E767A75736E6C696867727170777675737573\
797B7975777370726E5F615D7D7C7B8382817B7C7D727374777879797B797A7C7A
7F8280777A7876787673716D7978777E7B797673716E6B697D7C7973726F7A7E797D817C6B6F6A\
7C7775727472777975797B776F716D6E706C787A767577737274707779756F6962
76716E72716E74737073726F797C7A7D807E7A7C7A7779777E807E83858173726F7E7C78767671\
6F716C7679797E807E7274707577737779757D7F7D7B7D7B75736D666460726F6F
7A7976797875787A767F7E7B7D7A787877747C7B78807F7C6E6D6C7775796E6B69716E6C7D7B7D\
7D7B7D7876787E7C764C463D5D64636C726F82847F6E68615F5E5B808385787776
76706B706A6576737160636573757373706E7A7777777977
6C72717379767274727B7D787E807E707174676967727472797C7A727472838281747372727573\
7577757476746B6D6B73757170726E7370707A7777716E6E7B7D7B717371747576
797A7B78797A7572727C7979787B79757876707371797B7780847F71706D7D7C797473706D6F6D\
7E807E777A78716E6E8184824A4D4B787A7873706E7C7B787476727C827F818482
7577757E807E7375737B7D796D6F6B88847C71716C7A7D7B797B777A7C78888680706F6C7A7B7C\
7476747476747577757274726A6C6A7B79717B7B746A706B6C706A80837B7A7C7A
737674787A787A7C7A7476747278757675727A7A7581817C84847F75736D72706A82797986827A\
787A78807F7C7E7D7A706B686B6D687C7A7673777273726F74767289837C7E7775
7D78766C726D716C676E6D6A73767670746E7979747C807B72716E79747271736F747B74767A74\
8E887F7A77757774726F6C6A7A7F746B6F6962656367686B6D6A6A6A6C687A7C78
76787472716E716C6A7F8487777D7C8D938E7D7C79939698
767778787776727573737477747674757773747674787A787578767D7F7D7A797871706F797C7A\
7476747678767375736D6F6B6D6F6B7675747A79787978777779777B7D7B7B7876
777472827F7D7C7E7C797B797B7A79757473797877797F7A787774706F6C807F7C7D7C79797B79\
7B7D7B6B6F6984827E6C706A6D706E7C7E7C706D6B82817E7A7C787678767F7E7D
7E8481828885757B786A6C68757773828078717168656860746F6D767874757B7A777977797471\
807E7A7977737B79737B79737977716D6B677574736F72727778797978757F7D79
7A7A757A78727F7D77716F697C7A748284827D7D787676717C7C777274706B6D6974776F68696C\
7677787C7B78797875797674767A7583827F7774727574717C7A7C7B76737C7F7D
7877747C77757A7D7D7A79787775717D7F7A73736E78737173726F7B7D79807B797A7C7774726A\
707675737271767874767874757272726F6D716F695A59567977736D6A68757270
6C69677A7C787B7876777B75797C7A777A7A787E7967605F
6F7270747775767E7A6B6D69737571797B777B7A79767C797C7B787F7E7B7776737174727A7C7A\
706A6B737674797B797072706C6F6D7574737271707978777877767C7B7A797674
7B78767875736F716D696B6780827E7F7C7A70746F7675727978757774727E7D7A747672727472\
7B7D797978757C7B786564617577727C7E7A75706E7976747A79767D7C79767572
767B7D918A887E807C8083836568687F837E6F72707071726F727075747181807D777673807F7C\
73727177767389868478757373706E6C6E6A6E706C787A767574717B78766E6B6B
71706F7E7C7870726E828A867D80807B7D7983858074746F7977737B7B7681817C888682797773\
6E6C687C79777B7A77797C7C7476747B7A777877767B7F7A837E7B7A787480807B
7678767D7F7B7D7C7979787578777479787572716E7B7A777D7A78817C7A7777727575707E807C\
7C7B787E7B7973726F72706C7C757377726F74726E7C7A76807E7A7473707C7B78
7877747776737F7E7B7D7D787979747575707974717D7C79
7673736C6E6C7678767574736365637174727B7A776D6C69807F7C7978757776736E6C70767B7D\
727B797076756B6C6D73726F7D7C7981837F7678747678746764627A79787A7978
777675706F6E696B677D7C79191304716E6C71736F76787475747173726F7C7B787E7D7A817E7C\
7F7C7C7574717675727776735D5F5B7473706B68667978757779757B76746C6B68
5E5B597376787978757574716F6E6B80807B80807B7B7B767675727D7C797C7B787A7976807F7C\
7678746F716D6C6E697B7B767C7A766E6C687876727D7D787E7D7A817F81777975
7B7B767C7B7A797471776F69594D487F7A787673717D7A78726F6D7B7A77767A7572726B78736E\
7B757072726B7B797380827D7B7B7685807D7A757277706E7E7E79787873858481
7575707E7E798A88846C67647A75727972707A7C7A737573797B797A7C7A7D7C797D7C796D6F6D\
7F7E7D73716D7C7C7776767173726F6F6E6B73726F7A737189837C6D6961817771
7670696A67657E7D7A83817B70706B6D6C697E827D828480
7A7D7B6F72707679777A79767C7B787776737E7D7A7B7A777C7E7A797875827F7D7B7A79727170\
686A667577737375717574717C7B78757775787A787C7E7C7B787674716F747171
71706F767977757773797B7763686A7475767776736F716D72747070726E7375717476727C7E7A\
787A7685848177767381807D7C7B7873726F6865637673717572707B7B76777A78
858983777B767D808072726D7678767F837E716F697D80806C6B687D7A786D6F6B6B6D69777975\
737976767977767371787C777776736D6865736E6B7F7877747C767D7876716F6B
6C727174787378746C47494768706A7876726B6F6A83858074726A76767178787370726D80827E\
797B797E807C7D7F7B83837E72726D7D7D7875736D7D7C797878737676717F7F7A
73736E7777726D6F6D7C767177767379787581807D7B79737B7E7C83817B77716C797B7780807B\
72706C706B68746F6C72706C79787573726F72716E817F7B767873737573707673
7878737C7B787472747B78787476747C848077756F696763
7477777678747D7A7873706E7E7D7A797B777678747E827D737674717472707371797674797676\
7C74727572726D72746F747976787671756F7577737372717677787071726F716D
787A76696B6779746F79746F7B7A777978757574717375737E807E6E6C687D7D787577727A8183\
7B7F79827F7D7473707076717E7E7987827F787E79888A86766F6E66686C616A6A
7C797774716F74716F7B7B767D7D787779747D7F7A71736E8385817C7E7A7A817A707770737A73\
757C7B6C73727A7475807B797F7A756A69666F6E6B76787679787577716C7C7A76
716F6B7B706F737D757E807B83837E7F7F7A7A8176757971797B777C77728C87827D7770776F73\
7D726F827D78817C777A796C79777373716D6D6F6D76787677706783817D707776
797B797A807D78777479787583827F878987797B796F6D6978767275736F80807B797270817A7B\
7670716564636F6E6B807F7C7C7E7A70726E6C6E6A919188746F6C7F78767A7371
716A687D7D7677767386877B7C7C75757471666A65727671
7675727978757D7A787673716D6C696D6F6B78757382817E7C7F7D7C7F7D787B797A7976767574\
7A787C7B7D7B767E787073717372717873707C7B78737976717371797B79767874
70726E7678747978757776737A79767D7C79747370787B7372756D7D7D787777726C6C677D7876\
7C7B787E827D72747078757378757576757473726F6F6E6B7978757B74737B7876
6E706C6C6E6A6E706C7D7D788989847B79756B696573716D7779758688847777727878737C7C77\
7173716C6E6C7E7D7C7D7C7971716A6D6C697C7B7877726D716F6B7B7D7B7A7874
73716D7E807B7D7B77807B787E79767C77747E7A727A7872787573797773868480787A787A7A71\
807B796C665F807A737774727C797B817F797977717B7973787A7679797482807C
807E7871716A7B7A777574717E7D7A7F7E7B62615E75736F716F6B6F6D69797B768686817C7470\
736D68837E797A79767F7E7B7A7C788D8F8B84868274746D8885837E7976736E6B
7A757277767572726D7D76747F7C7A7275737D7F7B767874
73777271736F71706D7274707577737779757473707473706D716C787A76706F6C787A78787B79\
7574737574737E7D7C7A77757774727572707E7B7973706E7F7C7A7C7977797773
7A78747D7B7770746F7377727976747774726D6A687577737478736D6F6D7B7D7B7577756D6C6B\
73736E6F736E7577737D7C797E7D7A7D7C798D938E85878287857F7A7572777A7C
7E7C78716F6B75736F7F7E7B7779757E7B797877747C7E7A7873707978758A85827F7A77888380\
78777472716E797B767C7C777775717673717674706A6D6D7C7F7F757677747370
7C7C777577737579747D7A78817C7973716D79777377757172706C7B7E7C7F7E7D79797470706B\
7777726F6A657977737678767D77727E7D7A72706C716F6B706B6877726F7C7774
77767377767383868682817E7A766E64615F7F817D74726E736E6B756E6C7C7B787E7C787E7879\
84817F73736C7F7C7C726C6576716E6F6A677A7572716E6C797B767C7B787D7C79
7C807B7C79777F7E7B72716E7A7976777270797875706F6C
7476726B6D69797B776568687073736F72727C7B7877767376787471736F6A6C68808079787A78\
71706F777977797A7B797676787575787A78797B79767876797B797A7C7A7D7E7F
7372717A7A757A79766D6C6974737071706D7A79767A807B6E706C767874767572747370727470\
7C7B787A777574716F7E7B797777727C7C77797E81676A6C75787A7B7C7D6D6C69
72716E7F7E7B7E7D7A70726E7A7A757F7A78716C6A7C797776766F717472706D6B717772797B79\
807F7C7877746F6D697F7D7973706E6868637375737B7D79737571747672747672
7476727F7D79706E6A82807C807F7C7B7D79787E797675727E847F7C7E797C7E79777571676561\
7B767372706C7875736564617B7A776A69667B7D797F7D7778726B787370727472
7577737577739594916F696267676273767658595A7B7B7674746F78787377727082817E858580\
75757071716C7675727D7C797F7D7970746E67625F8987837B7975767371696B67
767977837F7774726E747B74807E7A7A7A757E7D7C747370
7C7B7A7D7C797675727C7B7872716E76757274777570727072716E747370787774767572787774\
7A75737776736567637473707C7B78797B777A7C787577737D7D787E7C787A7A75
7878737B7B7677767376757273706E77747273706E6968657B7A776B6F6A7A7D7B787B7B797779\
7876787174747E81817477777F837E7D807879767471706D6C6E6A7F7E7B777571
7C7B787978757978756A6C67787A757E7C7E77767380807B76737178736E6A6966807F7C73726F\
747576706B695A544F797A7B7977736B6965767470808381808280807E807A7E78
72746F706E6863635E8385817575707C7C777475767675747873707F797A8A85836D6F6B767470\
7D797175706D707371797A7D7A777776716C77736B7B79757C76796F727082827D
7E7E797F7D797A746F716C69827F7D7B78767875737A7C786668646F716D7C7E797D7D787D7876\
6D716C797674767874797B777D7A787D7A78767371807B786E6E697D807E777A78
7D807E828A8483817D7779747F777B7F7E7B76716E73716D
7978756A6C6A787B797779757476727779757A7874656667727A766D706E686766747A79777577\
797F7C7476747673737B7D7B787A786A716A656762787672706F6C717570787C77
7274707F7E7B7877747574716669696C6F6F787B7B77797572747075706D6C706A82807C807F7C\
888381686A666D65637A7A737A7A7573757377726D777571797B79787E7B767876
7B7674747372777A7C7C7E7983837E8A8C887978757B787670726E5F6564858483737271828180\
81807F7271707776737C7B786F6E6B74716F6E6B698589847772706B6D69727575
7C7A7C6F6D697876727D7B777776736D716B76706B7F7974837D78727972727170706A6D746E6F\
7E7977847E758C887E74726C8A827E746F6A72767084847F656A6C80807B7D7674
75736D7C7C758488836A6C6A807E82787C767A7D7B6F736E847F7D777975797B777778797C7E7A\
73726F7871707F7D7978767273716D7D7B777876727A7870757D767A7475817F77
6E726D72776C7977735D6060767979777A7A807E82706E6A
7675727976767E7D7C767874797B777779757877747476747A7572787873757772807D7B7A7C78\
727573787A787F7E7D7173716B6D6B7F7C7C757775747775717973727671787371
747370696F6A7D7C7973726F7877747877747776737A7C7873757177726F7579737E7C78817C7A\
70746F78706E7A7872746E6772726D7D7F7D75747172706C726C65807B787B7975
7F7E7D847F7D847E79817A7981807D82827D787672797270716B6C81837E726D687D78737B7671\
79746F817C777978757E7D7A7978757776737C7B787C807B736E6C767874747068
7F756F6A686474726E7F7D7963666675777277726F6E69667D78757275758486826C696782807C\
7B79717574697979747A7A7577706E7E7C787D7B777979747978777678736D6E71
706D6B6A696675787672747076766F6F70717D7F7B787C77817C7A6D6F6B6E6C667674707A7976\
6B686675706E67605E7E777574726E74726E73716D797B79827B79756E6C6C7575
7C7E7A707675767A75807779706A6B6B6D6B7C757355534F
70726D7174746A6D6D6E746F74716F7B7A77757775797B797D7C7B737573777A78777D7C767977\
7B78766E6D6A7C7E7A7A77756F6C6A6B6D697B7D79777975767876797B79797A7B
7273747677787A7C7A7476747A7B7C7B7E7E696F6E6B6F6A6E726D797B79787B797A807D7A7D7B\
7577737B7F7A737B75797B777779777E807E7071746D6B6D83817D797676727170
7A7E796A6E697D817C5B5B56797D786E70747D7A786867647578787477777A7C7873726F797674\
7F7D797B7A797778797679776E6B697B7673858483757773828480797B777D7C79
7473707A7976686A6674787379716F554E4C73726F777977787B7B818889868886797875737571\
7478738283847A7C787E7D7A7574717A7A73787A7672747083837E7C7C776D6865
7476747C7E7C797B777A7C787A7C787375717274728587837B7876635C5A71706D7F7A75726D6A\
797471746F6C615C5975736F66645C777772787E7B767A75777B767978777D7C7B
78777680827E7D7F7B7E7D7A72716E7A79766E706E6C6C65
7072707174748184846E706E7173717173717678747476727372717B7A797A79787A7C7A737573\
7C7A7C737A796C72717173717A7C7A727472787A787274727B7E7C797B797A7777
726F716C6D707E7D7C84838260645F777D7A72797A777474777474686C677B7D79777673737B75\
7A7E79767C7B7D807E7C797772726D7F7E7D7173716C6E6C7A7C7A7A7C7A7E7D7A
7F7E7D7B7D7B767876717472797A7B706C716C6A6C82847F7A7E767579717473727C7E7C777D7A\
7E7D7A7C7B787577736E706C7274706F6E6B7574717A7C78777975797B77767671
7575706F716D7D7F7B55575378797A6268676D6C69807F7C82817E817F7B7E7D7A7274707C7E7A\
7A7C787A7A7571716C7B7671817B767A746F7775717473707C74706F6D695C5F5D
7A7D7B6F727078797A7C75767A726E7A787A6A67676D6F6B7E7C7E807E786764647371737F7C7A\
7774727E7B796C6E6A6E706C7678767B7A797E7C787F7E7B7B7A77797773767671
787A757A7C7A7577757B7F7A7C807B7F837E767971726C63
6D706E7478737579747978757A79767A79767D7A7A71706F757876757876777A78767979727575\
6D70706E706E75747175727073726F7679797476746D6B677173716F72707A7978
7473727577757678767173716463626E706E7376747776757A79787374757D7C7B767671747672\
807F7C7572727F7E7D7779777D817C70726E7E7F80777673706B68847F7A7B7A79
7D7F7B807B797678747877747C7B7874787372757375787A7B81807677787D7A7871706D777975\
7E807B71716C7776757A7D7B767C796E726D787A767776737B7A777675727B7D7B
7B7D7B7E7A72756A6778757376747063615D797472787C777A7775807E7A7876727274707D7C79\
7774727477756F716D71736E7E77757979746C6E6C7775717675726C706A77716C
868987727472726C6777797479787783817B7977716968657D7C796B6A676B6E6671736F7E7977\
807F7C7A7C787577758486818D8F8B7F817D6D6F6B78777471706D696F6C787575
7679777776737877746D6E6F83817B7A74757577736B6D69
6B6D6975706E7C77756265636F716F747372686A68767373787A787B78787B74756D716B7B817E\
7A7C78797B777C7E7A696B677776736B6A697375737A7D7B7375716F716D6F716C
71736E787A757B7B7674746F77756F7F7D7774726C7477757274786F6A6571706D757878767A75\
7E7D7A72726B70706B7E7D7C7C79777579747877747574717F7E7B847D7B76716E
6372767C82897F78797A7C7A7B7A79646A657E847F676D687A7775968A877371737A79767E7E75\
6B72717A79767978756D6C697776737B7F7A73726F6A6D6F797A7B7E7D7C7D7B77
85837F767874787A76767874757169696461827C777E78737E797477726D62625B8B8D897A7775\
7F787777716A6F6D6981807D7675727676717E797479746F817C777F7A7567625D
756E63767069787873777571827D7A7478738589847B7A6F6967617877747878717A77757A7C78\
7476727476727878737575706F77717F7A777473687F7F768078728680797D7873
7B79757F7A777A75726E6E678080796868616F77737B7B76
71736F7572707B78767174727A7C7A7A79787476746E716F7275737779777776756A68647D7C7B\
70726E787A7680827E6A6C686A696673736E6F716C6D716B757773797B77777571
85837F7A78747877767877766F716D7779757375717576777779747471737B7A796F716C74716F\
82817E7C7D80797B7971736F726F6D767A7566656277767371706D787A76757D77
9C94922D30246A686461615A7C7772787C77747873727671716F6B767C7981807D7E7D7A73736E\
7678736E706E7B797B7A787A6B696B797B777473707D7B7D777474706B69747671
7375707A7C7875777374767273797462686570746F5B5F5A7F837E72746F6C6C677B7876787A76\
6C706B777B7672756D68685F7A7A757A787A7775717D7B77767470767470797773
7C7A767678747D7D78706E6A77726F7577737B7D797E797673726F646A675E61596B6D697B7876\
8582807C79776E6E69757570706D6D787B79807B797A7171767A75777571767572
7476747F7C7A817E7C8585807D7D7873736E71716A6B6866
7477757572727476747A787A7876787A787A71736F7776737678747C7E7C777D7C7B7E7C747775\
727472797C7A6F7572686E6B5E58534B54526B77745D6A677E827D777975787774
797B777377727779778183816C6E6A7D7F7B6E726D6F72707577758385817A7C78797B777E7F82\
767979847D7B7C79777274727375716F716D7978757D7C797776737274706A6C68
69706F5A5F627B7D7874726E6E6D6A808381767876767671827B7A797877757775787A786E706E\
787E7B7877768185807C807B6F736E666363706D6B757870757772787A78727873
7F7E7B7D7D78787A7675787661636172747067675E696962706F6C77767371706D87868581807D\
7F7F785F5F58686A687B7D79726D6B7579747F7F7A7F7D797675726E706C70726E
7C7B7872706C68636085837F7575707877745C5A56747777696B69707069706E6885807B72645D\
756A676C656674767486838176787470726E70736B797C7A777A786C6F6D777B76
7E827C7A7E797A7C787B7A777B7A777877747976746D6B65
7477756F72707274727173716E706E7C7E7C717371787A78757876797C7A787B79797C7A6F716F\
787573757270767371757B7A6D6F6D7977737D787376716C78777472716E707172
77797782857D717476717476777675706D6D79737482817E767572696B67777975787A76737571\
646662817F7B797875787B796E6D6A71706D7578787B7E7E7E8181727779727779
7376747B7A777C79776E6B6974767274726C7B797579777370726E8688846C696B7A787A6D6E6F\
6465666F70717D7A787675726F716D71706D7C7B7873726F7C7B787B7A77767874
747672767F7F7C7A7C6F6C6E747C787175705E5E576F6F687D7D786C6E697F7F7A797472767572\
6B716C72716E7F7E7B7A7A7577777274746F817C7A78737072716E696867797C7C
81837E706F6C7475767476747B7D797878737D7B77757473727170595B597274727376766F7E70\
837B77716F6B7A7C785558587274707A7C78787A767876727D7B777C7B787A7976
7978757E7B7967605F78716F7E7B7B75777379746F6C6967
6F6C6A7473727271707574717675727B7A776E716F656866727873747873737571757471666864\
787B7B6C6F6F757878767574797B79797773807E7A7A78747476727B7A777A7C7A
7C7E7C73757371736F74767270746E7B7F7A7678767775717676717D7C7975747171706D797C7A\
777A7873726F72716E777673646C666F736E7D76756D73706F7274777977707270
7779747A7C7878797A7F86858386867A7F817677787871707974727D7C798184826D6866736E69\
6E69667575708086857D7A7A7476727C7B7872716E6F716F7C7B7A7F7D79837E7C
7B78766F6D6963625F7F82827B7D78777B767A7270726B697C7A766F736D81817C7B7B7472726B\
7E7E7774746B77777262696286817E757570736E6B6C6A646D6F6B7A7C7881837F
73726F7577736B6F6A686B6974777964666267625D79777372706C75736F7377727779756C696B\
5663606F7574727671787A767C7B78727573707577797D777C7C77787A787A7C7A
7C7E7C82827D7A7A758F8C8C6D6F6B75706D6B666169645F
706F6C70726D706A6B6F727077797777767579767479787570726E7274706E706C7875736A6765\
6C69677D7A787A77757C7B787473707D787671706D727A747D7F7B7A7C78726D6A
807E7A767873767A75747873737B777F7C7C757876727978787C7776787670726E72746F7B7673\
73706E6F7477787B7D8082807777727A7978736E6B797674777977787E79797F7A
7E7D7A7776737877747978758483806A7172707172827C7D74726E7D7B777F7B73787672747372\
82827B76787471736E7E7E797775717C7A7473726F7A75736A696670746F777772
797974797B7772706A7A746B82827B7B7A77727670696964726D6A81817C7D7876908E866E6D6A\
7E81776F736D79736A6D6F6A77797472746F61615A585A566E716F6F716F7A7978
7B7472797974807E7A6B696573716D7A746B6A6C67737674716C67787A767F7A6E7775716E746F\
71797B7E7B7B76746E7473707D7F7B7C7E7A7F817D787F7689817D7D7677797A7D
7E7C76807B7675766A7A7C7871736F757773878780736E69
71706D6E706B756F707477756C6E6C6E6D6C787573757471747672797B77797B776C6E6A727470\
6C6E6A787A767678747776737776737779757A7C78797B77666864747672757D79
7174726C6E6C787A767A7C787576776B7271717474787A787A797675777375777281847C828482\
81848482848279787573716D757878767A7571736E727671666C696D716C777B76
7978757F7E7B6F6E6B7C7B787A7976827F8173727171706D7D7F7D7F817F7578767877746D6762\
706E687877747779747E7E7973716D6B69637473707478737D7C79797674757570
7D7D7878757575767776787C8083817B7975847F7C6E6E697D7F7A787A76827C75706E6A787678\
797B7764645D7478735A5A5581817C7B7B76716C676A676573726F76737175706E
77797478767270726D7678736D6F6A6F676574726C707371706B6672747076797770726E7D7B77\
867F7473716B7A746F7E7B797D7A78807D7B726F6D817B7C72706A463C32767572
747671797974777C7E7779757476727B7D797C7B787C7977
7679776A6E69726F6D70776E757B7A777D7A7577736766637C7B7872716E7A7976747370787774\
72716E6E726D777673757775747672757775787A787274726D6C698E8C88706E70
7475767177764F4F4A78736E79767673767475747371736F71706D6C6D6E7E807E7C7E7A8B8482\
87817A7779756F716D777975767572767572797B797577756F716F82817E767572
807D7D828583898B897C807B68686178757374716F7C79777D7C7B7F817F717774787C777D7F7A\
817E7C73757171706F62615E68666272706C6B6A677875737B78767D7A787C7775
7C7B78807E807D7C796C6C6573716D787672797B77727470757773827F7F67696762625D757570\
7676716D6B6768666265605B66615E7772705A555065655E7E797479746F7A7570
7E77757678738387817575707B7673787A7562645F63625F656964717973787A767B7A77757270\
7476717F7D777D78757F837E787A7679787583807E797A7B767574707270717371
7577756D6C6971736F777B767B7D797B7A7770726E7A7C78
6E716F6F6A687873716C6B6873726F71706D73717575737783827F807F7C7B7A776D6C6971706D\
73757371737177797761646676757478746C6F6A6569645F7B7876686E6D78797C
707174727376656D67737772757878727877767C7B6F6E6D7779778685847C7B7A73736E54595B\
4748496C69677774727D7A7878797A73717375736F7C7B78777977707270767876
7F7A787F7A78787371797B777D7F7D7D7F7B6D6D6866645C6E706B6C6A66817B7679736E7C7671\
807B76807A7574746D797779767572787A767A79767E7D7C6D6C6975756E797B77
797B77817F797C7A747E7C766D606075706D7575707A78747E7C78736F676E6E656E6D6A727671\
7A787476716E807E7A716F696D6B65797773595954585853726B6C7E7D7A86817C
6E645C797773706B66787370716C6A7D7F7B76716C7B76747274707C79776362617C77747E7871\
787672858785757471787C7772716E73726F7877747678746E726D807F7C767874
6A706B7E857E76747073757181807F797674858886676762
706B687274726F716F757272696C6A7372717371737876787B79757B7A77787A78696B6772716E\
767A757274706E6D6A71716C7675746E726D7274707572707C807A7C7E7C746F6D
6F6C6A777673757270797674757270676B666B6A677675727D7C79716E6C7574715E605C7A7976\
7C7E7A7F7E7D71706F82827D73716D82827D6C6E69797974756E6C7C7E7C818985
74737071736F75797473726F73726F797B767A7C787071727C7E7A7978757877747D7C797E7D7A\
7A79767978757B7D7B7C7B7875706B736D646F6A657076717B78767175707D7F7B
74746F777974797773746F6C827F7D73716B7F74738079777C7A76737271646362757C7D79746F\
716A687A75707C7772736C6A7F7876635C5A64625C706F6C7D7B777775717A7874
73736E74726E7A7D7B7877767471717B75707D78737572727E7D7C777A7870737371736F7D7F7A\
76787372746F73726F7F7E7B70746F8E89877D78767774727A7E79737571797875
7E7977797B777E7977868582807F7C7877746D736E757B76
7771727679796D706E6C6B6A737271848382817E7E7574737976767572727976767172736B6A69\
7F7D7970746E79797475706E807B797A77757875757673757A79767473706F6E6B
77767371706D7579737B7E7C757473706F6E76757477767372716E62656362656355585672716E\
76757281807D7473707A7976767371726F6D7E7B7B7877767C7E79807E7A7D7B77
6466617A787487807E817E7C7B78767774727E7C7882807A78716F7B81807F7F7A7C7C777C7C77\
8888817F7F7872706C7674707B79756D6B637673717E8181777675817C777B7975
7876727572707875737A77756A65628883806D6B67716F6B807E7A8D8D8855534F84827E666564\
797C7E6E717371747472766E6C726F6D6B656C655C8C887E7E7C76797974616462
726D6871746C7B747283817D6D6F6A81837E8486816D79727A7573766F6E787A788883817E7E77\
797F7A88898A697071737173757377636666716B6C7977736C726F737674837D7E
7775717F7D79817F7B6968657E7D7A61605D787C76717774
7274727172737375737C7B7A6261606E6D6C7572727574737476747274728183816E6F706F6E6D\
7675746A706D6D6F6D807D7B7A7775747672787A78767778706F6C7776737C7B78
7A79767D7C79797A7B7375717675747D7C7B7877767F7E7B7B7A77686A686B6D6B7B7D7B7C7B78\
73726F747873787C776D716C7B7D7971736F7E7D7C7B7A797777727A77776F7270
7774747E807E7A7D7B797B777C7E7A7B7C7D757677797B77717476817B7C847D7C7A77756F736E\
81837F5A5C5878757383807E716E6C64625E716E6C797B797F7E7B797773757772
787A75676462726F6D7C79777979747777727F7E7B7877746D6C69726B6964645F828384787774\
8B868377727071756F6B66648182837F79706C6A665A5A557277797A7D7B656461
7E7D7A767572888A8584827E75706D7C7A7674726E877E7E6C6E6A7B78767A7777757974727575\
787E7B7974717C7373736B677E7C7E7A7D7B6B6664696B66747775747775777172
787672817F7B72706C7776737978757B7A777A78746F6E6D
73727176747678797A7779757D7A78726969726B69757473757773787A76787A7667666571716C\
71706F777977777A787B7A777B7A77797B797978777370707E79777A7976777977
6D6F6D8284827B7876757270706B697C79776665627A79787F7E7D757876707371717371797877\
767977767371726F6D757270797674777472827D78797773797B797673717D7B77
827C776D6865807D7B7A7976807E7A837E7B817B7C837E796A65627577757C7774716C6953514D\
6C6A66746D6B747372777D7A6B6D6B7C77757C79777976747F7E7B70726E757471
787774696A6D7473726A645F83807E807E7A7674707877747F817F73736E7D7772685C5765635D\
6A686472706C72706C6964615C5A566B6B6667676272706C847F7C7E7A707F7A75
787370918A8168676471706F7072707A7976706F6C6A69666D6F6B6F716D82817E6E6D6A7F7E7B\
736C6B7572707D78757C7B787A7775868381807D7B7A7976827F7D767572747370
73726F7A79767C79777A7372746F6D77747276716F72716E
75736D7779777678767271707978777978776B6A676E716F75787877747471736F737772676B66\
7379746F75706E746F767977706F6E7076717076716D736E737475767778757974
767A756C706B7A79767877747878737575706A69666E7171787B7B62615E807D7B746F6D7D7C79\
7C7B786F77717276717E7D7A7C7B787678747678767B7D7B7D7F7D7B7A77807F7C
63686A939291827A747B79757978756B7170787F7E6D7976767F7B8C8C856C706A8585806C6764\
7D817C6A6C6875706E7A797670746F74767276716F757A7C6C717374797B77726D
7E7775837875776F6B6F696472706C7674707C7C7764645F66666170717271706F5D5B536F736B\
7877747D7B776E6C686D6F6D6D6A6A7372716A645F6D686583867E6D6D68706F6C
787774706F6C797F7A696865827D7B77716879736E777772656560757570696F6E747A7971706D\
74716F76757274737073726F7775717B79757A78747877747978757C7B78767572
7978757A7C777779777F7E7B7976747E777676787472716E
7678747476748183817978777B7A7971706F7177726D736E71706D7D7C796D6C696E716F707270\
73736E6E6E6974746F767A757579746668647972717978756F716D7B7A7783827F
787774797875777673767572737477737271726D6877726F7B76736F6C6A747370696B677C7B78\
7F7E7B787B797678767776757674707C7774787A757A78747E76747B79757F7D79
79787571696378757576766F82827D827C776D67627A746F7673736D74767A797674746F73736C\
797B767A78747E7C787D7B77787672726F6F716F6B7C7A747B7B74777A727B7D78
7078716D6D687D7B77736E6B6F6B637777728986847877747A7C7871716A7977716D6C6980827E\
787C775D5B5773726F76767173736E79797473777170706B72706C75736F64625E
8582807976747C7A7679777373716D787A766A6C687C7A746664607F7C7A8080797A7A737F817F\
7C7E7C7F817F7D7F7B7E807C737772706F6C726F6D7476727574717D7674777571
7A7A757A79767E7D7A75777376757273706E73706E7A7775
767470706B697A777571736F7274706F716D7C79777A7C78696F6C6F7572727875696664706968\
6A766F70767173726F767572746F6D6E6C687676717A7C777A807D6E686972726D
7878737A7A756E706C787A767274706F716D7678747575707875757579746F716C7E7E77757169\
6F6E6D757E7C6168697A7779797875444843707975777A78797374767574686A68
7A787A8481817C757381817C7F8280737571666E6A878587767D74726F6D7A746D827C75767069\
7E7D7A757375767D74797B767875736D6A6A73716B7673716F6E6B7A7C787C7677
727575797A6E75756E7A77757F7F786969647F7B73817C797D77787D777881776F70665C827A74\
847D7C756E6F6E6B6B7C787079736C706862807670827B7969696478767275706D
7C766F746E677972676C6661807D7D72746F6970697C7B787978757675727B7D7B7C797779756D\
7E7E79848785686A666D736E686861756E6C666864757270706D6B777E777C7E79
7D7B7776746E736B67757E7C7D7873736D72797875807F7C
7674707472747374757274707577737779757B7F7A7678747577757678767476746E726D6B6866\
6E706C6E706C73777272716E737571747171777675686A6873736C68605C6D706E
737674797C7A7274707A7C7875747172716E6C6B6873736E7976767477777B7C7D74737087857F\
78777676747821130A7B78787E797773757165605D74726E7B7B767D7875807E7A
736E6B73706E7C7D7E7073736F6E6B7F7E7B5F656066636176716C7877747978757D7C79787774\
7C7B7A6666616E746F7376747273747471715A585274716F91908D80827E7D7770
807D7B6F75746C6E6C7C7A767877747573757978777E7D7A84847D6E675E727573787370878581\
7E81797E81797C7A747276717A7C787776736A6C6866645E60605B5E5C58807B78
67646275727082827D6E6C68847E79706B6882847F777673696865807F7C83807E89847F827C77\
726D6A7673717B767471736F7878717A7371737571787573716E6C797471777571
797B7674716F787C77817A7866686C7578787A797673726F
7574716F72707376746E6D6C7476746F727073757376757477767572747275787670726E6C6E6A\
7572727771726C726F71706D7473707678767678767274727473727B7A77696D68
767A75777B767E847F777975787A789598966F757281807D72716E6F716D787A767E807C737570\
7A7A757172737577727A7C7A7A7E797776736D6C6B7A79787979747C7C7771716C
7F7E7B7B7A7772716E7E827D706F6C7978756F6E6B73736C73736E7D7B777A7E797D817C757974\
747775797B777B7A777574716F6E6B716E6E7473727B7A776F6E6B747873666F6F
7B79757873717A797680847F7674707A78747A7C7A77747273736C7A7C787C77747A79766F6E6B\
797B777274707B7975716F69716A5F635C5A6C6A667D7B77787370797674706F6E
7D787578736E817F817A797685857C726D686E716F84817F7C7B787C7E7A7572706568686C6B68\
72716E7E7D7A6764627673717271707978776A69687679797679797779757C7B78
74716F767874787A7675757075736F756E6C797773787573
757471747370686B6973797671737174717178757384817F7675727978757776737C7B78636964\
7271707B7A796F6E6D6C6E6A7274707E75757C77757473707578706D6866777A78
7372717572726D6F6B737571767979545556686E6D7978757C7B786F716D747672777975797B77\
80827E747873787774726F6D78777471706D7A7976777673797875838581797B77
7C807B7577737B7A7772706C7D7B7771706D7A7976797875656C6D7578788A8785757270726F6D\
7377717575706D6C697C7E7A7377727B7A777B7A7775727271706F7D7F7D7F7A78
76757278817D82827B807B767774727A7C7A72706C84827E706E6A76767175736F7D7F7B7E7C78\
8585807D807E7979746E726C76767175706D7A78727873707A79766D6D687B7A77
736E6C827D7B817C797C7A7681817C83837E7F7F7A7E7E79797974757570757169676663757974\
797F7A73777271756F6F736E7C7C777574717675747978778385817D7D787B7B76
767671797A7B6B6E6C777A7A797C7C78797A7B7C7D7C7A76
7C7B788184827C7E7C817C7A7574716C6E6A7374756C6F6F7076736E716F767876716E6C686C67\
757473726F6F7A75727A797879787773726F777673777673696865767572696C6A
7D7A784237347876727375737B7F7A73757172716E767977737976747B7C767778827D7B7A7C78\
7678747779757678747274707779777979747877767574737C7B7A7678767A7C7A
7375717476727476727577726767627A7D7B7A79767977717A757376716F7C7B78767874717570\
7B7F7A7873717678747D7F7B7779756F6D696A67656E6E6774746D74746D747672
747672847E79565E627274707A7C7774746F797B7771706D797674787C776F736E837E7B83817D\
7979747D787677726F6964616666616D6F6A6E726C706E6A7978755D5C597A7976
6F716F79747277757181857F6B666372706A72726D72797072726B817B767978757D7F7B82847F\
7C7B78827F81797472595D5871746C777974787A7880827E767371797974777772
7A7A7568666275736F6A6E687F817C79777374726A7B7975
78767271736F737571777A787072707E7D7C6767627B7B76727470726F6D7E77766E6D6C62625D\
6668647779757375717774727A7775717B74696F6A6C6E6A7B7B767A7A7570746F
7B7F7A737772757974757974616963767A756968656565606767626B6F697B7F7A7679776E726D\
7779757F7E7B7978757A7976726F6D7574717C7E797979747C7A7675736F7C7C77
787E7B707673636966777A787A7D7B8680796C665F77716A7977737A78746F6E6B777975727671\
777D7A767876786E7587817A7B76735A544B736E6C7E8084867D7F847E77797674
7E7B797A7976727873827F7D827E76787E797B7D7B77757178726B837C71706B686D716B6F736D\
787C7670746F75756E706E686A686277756F7F7C7E5E625D7675686B6963797676
7A7D7B7D7D7873686579716D6C67627C7D7E74716F7E746E857F78817F7784847F7C7C777A7976\
8685827E7D7A78797A7E827D79797474746F81817C72767079797472766E5B615C
767D7C7B7F7A7C7E7A787A7681837F7F817D737571777975
6F736D7577737476727073717173717A79787675747675746C696773757174787370746F5A5E58\
60625E7274707274707A7C786C6E6A7572707B7A777579747F828072757370726E
7577737678747E807C747672746F6D72716E737571757773737571767A74797D78777A787A7E79\
777975717570747873777B767C79777C7B787D7F7A72726D82807C7D7F7D6B6E6C
7A7E796C706B787C777D7D7883837E76757276757271706D74737071706D7F7E7B727470787C77\
8188818587827779747D7B7D6D6D6671756F6C73727F797C7D838083877F777772
80807B747C767F7C7A7D7F7B7B78786F6D69716C69807B78736D686A706D777B76737570747671\
767873817F776B6B666E706C6C6E6A7D7F7B7E79766C6A646F75726A706B7A807B
7E807C71716C73736E82807C7D7674797B79767572807D7D7C7B7A797B79818482767977777B76\
6F736E7A7E7977777276766F7D7D7868686364645F767876727170767476787776
7B7F798286817F817D7F7C7A7976747D7A78757270797674
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Red) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BFB7BBADBBB1B3B1A8AFABB7AFA49CA4ABABADB1A8A6A29C
C5A4ADB1B1AAB5B3A6BDC9AFB7C5B1B5B7B5B582B7B1B3AA
AD9CB7C5B7B5BBAFA8B3928ABBB9AF9A86A8B7C1BFBDC3A4
8CBBB9AFB1BDBFC5BDB1BFBBBFB9AFC1BBBBBDBFB5BDAF9E
B1B5BFBDB5B5ADC1B3C9BBB7C1C1BBB1C1CBC5C1AAB1C1AD
A4B3B5B7B3B9B9B5
AFB3AFA8C1BFB3B1C3B7C9B5ADB3ADAAB3ABB9AFB3AFB948
D3ADA2ABA6ABB5AFAAADCFB1C5AAADADBBB5BDC9AFBBAFB1
B7B9A2A8C380AFC59EC5ABA0AFAFA8C3B39AB37F9CB7AFB5
B5ABB5B9CBB3B1C1BDBFB3BBB9AAAAB3B5BFC5AFC1ABBDAF
B1B9ABB7BDB7C5B9B1B9C9C5C3B9A4BFBBBBB5A6C9ABC3C9
98ADBFC3BFAFADC1
B7ADAFADB3A0A6B9BBBFB9B3B3ADABABB3B7A8ADABBDB79A
AFADA8A0B3ADAFA4BDADC3B1AFC18CBBC1C5C7BDB1A4B3B3
ADA8BDB9B9B5C1B3BBA29A9CB5A0AFB7ADAFC1B1A298B5B7
AFB9B5B5B9C7B3C1C3B3A6B7BDB1BDBDBBBBBFB9B5C9C3A6
AAB7C9B5B7B9C3BFB7B5C5C3A6B7AAB3BFB1C9C5BFAFC7B9
A2B7B1BFB7C1ABB9
A8AABBA6A29EA8AAB5A8BB98B7B3B1ADBFB7B3B5B5B3ADAA
92AFB9A8B7B7AD98ABCBD1BBBFB7C1B3B59AB3A2B5C3AFA6
B3B384B1AAB9BFBBC1AB8277B3A0B3C19CADAFA0A8C5B1AF
C9B9B7BDC1ABC1BDB3AAA0C7B7A2C7BDC7B7B3BDB3D5BDAB
B1ADC1C1B5BBC1B5B1C5B7BDB9C5A4BDB1C1B7A6D6B5D6B9
AFC7B5A0B19ABBB1
B5B3ABBDAAADB3AFADCBC1A6A8A8ABABB9B3AFB5ABA2AFC9
BFBBBB88ABAF9EAFB9B7BFABAABBABB3BDBDB7ABAA90ABA0
AFAABDCDABB3AF9AC1A68084AB9EAFCD9AABADA4AF3CADB1
B9C1ABB3ADA0B1B5B7AAA8B9A8B7BBBDB9AFC3C1ADC1B7B7
C9BFC9C1C1BBBFAFBFB5B5B9BBA2CBBBB9B9B9CBB396C1AB
CBB1B3ADB3AFA4A6
A4BDB5ABC5BFB3B7AAC1B5B9A4AAB7ADBFB7BBADB9B5B1C3
8280A4A4779EAFB1B5BBCBB9C7BFA8BDBDADA2A896B7CFA8
B3AAAFBDAFC7B5ABB5C182809CBF9AB9AFABB1B7B7C5B9B5
A8A4ABBBA6B9B7C1BBB9BDB9C1BBC5B9C1B9B79EB9AAB1B1
AABDC5A4B3BDC5B9BFB5C3C1CFBFC1BDCBAFC19EA8BDB7AA
B7B7B7AAB7B1BBB5
B5ABA4B5ADAFADB382A6A8C1BDB5ADB3B7B998BBAABBA0C9
B7A0B9AFA4B3A294C19ED1BBBBB9ABC1C1B7BFC7B1A0CDB9
BBBFB1B9ABAFA2B9BBA87984B7B996AAAFA2BBC352A0C9B5
B3B9BBBBB5ABA2B9C1AFBDB9B3AFADB7B7BDAAC3C9B1A2AD
B5B3BDC7BDBBAFBDB7C5C1C1B7BFB9B3BDD5C7C5C7B7BDAA
B1B3BDBFBBB7C1B7
AF8AB7C7B9ADBDBDA2BFB1BFBFBDB3ABB9ADB3A69CADAAB5
A2AA96B7ADADAFAAA8AFC3C1BDC3A6B5C3B7B7C9B3BBC3B9
AFB5B7D596B7B7BDB9C19A7FC1A4B5AD98A0B5B3BDAFC19C
B3C1C7B5B7ADABB9BBB3B1BBBFB1A8B7BBB7BDB9B5AAB3C7
C5CDC7C1BBB196C3C1C1C5C5C7BFC1B5C198ADABADA4B7BD
C3B7ABAAB5BDB9CB
A296B194B5B9A89E96A49CC3B9A8AAA8AAC1ABB7A0ADB1AA
B184B3C3A6B3B7ABA096A8BFB9AFB9B7C5BDC1B9B3BFB1C1
B3B1A6AAA2C5C3BDBDB194A09AADABB9A2A6B7BDA4AAC3B9
ABA4A2B3AFBFB3B7B5A4B1BDBF96B7B3C5B5B5B7ADBFC1AB
C5C5C9BBC7B9C1C9B3C1B19CBBABAFC3B5C3B7B3BBCDABBB
BDBBBFB1BFC3C39E
B7ADAFB5B1ABAAB1B9C3B7ADB5B5B3BFB3ADAAADAFA4AFA4
A0B1B7B7A8ABB7AA9A63B3AFBDB9CBBDCBCDC5ABBBC7BDBF
AAA6C59EBFBBB5AFAB9A908688B7A4AAB7A2BDBDBDADB5BD
B5B5B3B9BFBBB3A4BBB7A6ADBDABA8C7A6AFC3BDADADA8B1
A4C1B7CBAABBBFB5B3C3BFBBC7BBC3BFCDB9B3B1B5B9BDC1
B5C7BBB9B7B1B1BF
BBB3B5ADA6A6B3B1B5A8B1B3B9AFB7B1AFB7C7B5ABC5B7AA
B5B9B1B7B1B5ADAB92AD98ABAFB7B1A6BFB3A6BBC1B7ADB1
C1BDBBBDBFBDBBBBC1A67B8A90AA92AFA2A0ABAAADA89ABF
B5AFADCBA2B1AAA8A6D6AAB3AAABC3B5BFBFAAC5CDB7C1C5
BDB7B7ABC9B7BDC7C1B7B9BFB1B5BFB9AAC3C7C1B9A6BDB1
BDC3B5C13E9CC76B
BBB5B1B1C3BBB5A6A2C17FBFADB7B7BBB99EB1C1B1ABBFBD
B1B1B5ABABB5ADB3B7BBC171BDBDC59CB7ADC1AFC1CBB9AB
B7B3ABA4ADC5C3B9B79A21447BB1A4B59EB5AAABB5B9AD9C
AAA8B3C5A0AFC7B5C1BFBBBFA8ADC5B7C9B9B7C9B9BDA8AB
AFB9A2B9B5BDC3E4CBBDB9B7BBABB1BBB1ADB7BBBDB1ABB9
A6BBB3C7BDBDADBB
B1B9A8ABABB3B5B5B7BDB1BBBDB7AAABB1B3B7AAAAAFCDBB
ABBFADADAFB3AFADBBB7CBB788A2BDB9BDBDB7BDADB78AEC
B5C1B9AAB7BFBBAFAA40BBAAD8B9B5B9BFB9BFB1A4A6ABB7
ADB9B9BBB9B7B3B5ABBBC3A8AFB9BDB9B5B9B5CFCDB9BFB9
B9C3B7BDB3AFB5C1B3BDBDB9B5B9B7B5BBADBFBDC1B7B7B9
BBB1B5B1DCB5CFB9
C5AFAAB3B5AFBDAFAFB7AFB9BDB1BBB7B3B3B7B1B7B5B1B7
BFBBABB9B5B1BBAAB3B9CBB5BDA296BBBBADB3B9AFB3BDB3
B1B3AFA8A8AFB1AA9EBD9EAB77ABBFB3C7A6B7B9A8B7A0B1
B7B3BBBBB7BFAFA2A2B7BDB5AA9EC3B1BDB9AFB3B79EB3AD
B9AFBDBFB7B1B3C3B3C5BDC9C1BFBBB9BFB5B3BBC3C5BBB3
ABB7ADBBBBC1AFAD
AAB1A09EB1ADB5B1A2A8A4B3AAB5B3AFB3B9B9B1B3BDB1A8
6BAFBDBDBDB7AFABC1AAA8A4C3BBB992C1C5BFBDB7ADAAB3
B9B9AFC7B1B3B5B3AADACDD5B7A8AFBB92A0A6B9ABB7BDA6
B3B3CFC9B7C1ABADB1BDAFB9A2BDBBB1BDC1ADABB3B19EBF
C7C7C1C3AAB3BFC5B7C5B5B7C5BDC7B1AFC1BBB5C5CBC7BB
B5AF98BFB1BFB1C1
ADAA79ADC5B3B1A0AAB5B3A6AAB7ADC3B9AFB7BDB3B5BFBD
B3AAB7B5B7B3B5AFB3BBB5C7BBAFBFC3B3C7BDCDBFA6C1C1
C7C9BDC3C1AFAAB7C9B7C3A8AAB5AFADAD9ACBC1C1ABB9C3
B9D1B5C1B3B3B19ABFC5AFABA8BBB5B5B7C7B5B3B7ADB7BF
BDB9BBBFB1C5AFC5C1C3C3B5B7C1BFBBAFB5B5A89EABAAB9
D3B7C9B3C7C3CBB3
B7AFA8BBB3A4BBBBC5B7B1BBB3BDBFCFCBC3BBBDABB7B1C5
BDB5A8B3B3B7BBB3BBBBB9B1C1B1BDAAADC9C5ADC3BBC3CD
C5AFB5ADC1ADBDDAC7C1C9A8AFBFA8C19692B7B7C3BD9AC1
ADC5BD9EB9B5B7AAC7ADBFBF96AAB9B3B7BBADAFA8AFB9B5
C3C3D8C7C9BBB7B7BD9CB3BDC5BDDCA2B592B9AFBFB1B7C3
B7B7C7C9C1BFBDC5
ABAAADAAB3B1B5ABB7B7BDC1B1B7BDB3B3B7ADB5AFB7B7C7
BBB1A6B7B1B9BDB7BBAAB9B3B5B3A2B99A96A4AB8EAFBDA8
C7D3C7BBBDC9C99C9EBBB9ADC396ABB1B1AAB5B5B3B5ADB1
B3B5ADAABFAFC5BDAFBBBDA4A0B1BFB5C1B7B7ADBDB7BDBB
B5C3B9BFB5B9B3BFC1C5BBC3B9B3BBB1B7A4C3C3BDBBBDC3
BBBFC1B7C1BFB1BD
B9B992AA8CC1B3A2B1B9BDB3B5A4ABB5ADBB90C5C3B7B9B3
BBA2ABB7ADB3B7BBAAB5B3A2B9BFCFBDB9D6C594B5C1A8B1
B5A6AAB9C3BDB5C3B3B3BBBDBDADABA49CA8A8BBAAA6B780
ABC5AFBDC1C1BDAAB9B9C1AF88BBBFB5B9BFA0B1B1BDB9BD
C5C3CBCBB7BFADCFB9AFB1AFC3C1B3BBADC3C79EC3AABFBD
B9BDADC5B3C1BBB5
ADAFB7AAABA6A8B3BDBBB7B9B9B7B3ABB1C1C9C5B3B5A8B7
B7A0A2BBB7BFD19AB1C1A2B190BBADB1D38EF0B3AFAF94A4
A2AAAAB3BFC7C9A6B9AFA8ADA2B5AAB5BFAFB3B5BBC5B1BD
BBADAABFB9A2A2B5B1BBC5B994B3B3B3AAB1ADADB7A6AFB3
AFABB1C9CBC7C7A0B1BFB7C3AFAAADB5AFCDC5B1C1B3C7D3
B5BDCBA4A8B9B9C5
C1ADAAADB9BBD3C9C1ADA8B5AFBDB5B7A8BBB9B7B3C3B7BB
C7BDBBB3B5AFB3AAA0BDC1AFB1B39CA8AD9CA48E829EA077
90ADB9C7BDCBB7B3AFAB9A98B3C1ABC3C5A8ADBDC1B1C3C3
B1B9B9C1C5C7BDC1A4AFB7B3A6B7B9B1BDB1A6A2A2A6AAB1
9CBBB9ADB7B7B5BFBD9CBBC7D1BBC346B3BFB1B9A8C7B9A0
C5B9C9BFB9C5C7B7
AFBDABB7ABA89E8AC3BB9E98B196CDADB5B3D1C3C1B7B9B9
AFABAAAFADB3C5B39CBDB9BFC5C3B9AFB39CA6C1DCBDABBF
ABBD9E889888A4BBB9ADAAB9B1BBB5B3CDA8B3A4ABB3BBAF
C3B3BDB5C9B7A896B3B3B7B9A6B7B3AFBDC9BDA0BBB7BBA8
BFC1BBCFBDC3B3B9C7C3C9BFC3C1BBB3B1B5ABB5ABB5C7DA
C9B1BF82A0BFAFC7
B7B7AFAFADADB3BFCBAFC1B3AABDF2A2AFC19CC1B1AFABAA
B9BBB1B1BBC5AD9AA0AFBFC5BBB9BBBBAFBDA8A0B5ADC3AD
B5B59CB1C3C5C7ABA67FBFBD5DA8B1A89AAFCFBDB7B1B1B3
B7B3D6B5B7BDABC9D1B5C3C190B5BBB7BFB5A8C1BBB7B7B1
C3C1B7BBC7C1BDB3C5C3C9C5B9C1B9BFC3B7B5BDBBB9A4C3
B7B1B1ADB5C1BFB1
BFB9B7A2B5BDB3ADABC3B9BDB5C7B5BFADBDB1ABAD909EB5
BFB3A2BFBBB7AA90DCBBB7B3BFC3BFB3B7B5B3AD98C1AABD
BDBFAFA8BFADC9B973BBA0A2B9BBB7AAAF9EBDBBA4BDCB9A
ABD5B5BDBBA4B5B7A2AAC1B39EB3C1B3C7C1B9B9C3CFBBB3
BBBFBBB7C7BDA6A4BDC7BBC5BBC3C7BDC5BFB9B3C1ADBFC7
C7BD80B5B7BDC1BD
AFAAADA4B3AFABB1BBB9B18CC1AFBDB5C3A8BBBDB1BFB1A8
BBAFBBC1CBAFA6AAA2C3BBB5B792A2B7ABB1C5CB94A6BBB3
B5C3C9B5B3C7B5AF7DB1B7BFABB1B7B9B1B5C3BFC9B5B9A6
D1B3BFCDC3BDC7C9B7C5C9B5AA9CBBB7CFB5B3C3B1B5B7BD
A8C1B5BBC5BBC7C7A6C5C3C7B3B7B3AB92BFABB5BFC9ABB5
8EA0BFC3ABABB5B7
B7BD96A8AB9EADC1ABB1ABB3C1B9B3B5AFB1C1B7BFADB1B1
B5B7B3B5A8C9AAB3B3B1BFB3B99CA8BDC5BBAFCFADB9A8AD
B5BFBBA6A6AD86AF46BBC3D3B7B9AD9CBDABC1A2A2B1ADCD
B7A8BBA2B7C3CBC9BBBFB9C7B3C1BFB7CDB7BBC39EC1C1BB
B7AFB3C5C5A6B9DED6A0BFB7CDC3C3CBCBABB9AFA4ADB1BB
C1AFB5BBC1B9C9BF
CDB1BBB5ADABB9C7BDC5B3B9BBB1C3B5AFBBB7B3BDB3ADA6
AAB7B7B1B1BFA4B7A8BBBBAFBBABC9B7B3B7D3DCC5B3C796
A8A6AB94A4AFAAC5C5BD9EC7B3A8B7A8A27B8CABC7ADAAA6
BFC7BFC3C3B1BFC9BBADBBB9ADBFC5BDB5A4B7BDB7B7B1A4
B5B7BBAFBDC7D6C7A8A6B7C1C9C3CFBFD3C5D1AABFC1B1C7
AFABBBB1BDB3C3B7
BDB7B1B3A6A6CDB3B5B5AFAFC3A4ADA6B7B7B5B3C1AFBDC7
BBBFB7C1B1AFAAB3C3BBC5BFC3AFC3CDC7C1D1C3B5ABB5AB
AFCB9EAABF90B7A6ADB7B1B1AD86ABC1B1A4AFB5C1BDB1E0
BDB7C1C1BDBFC3BFBBA8BDAFABBBC1B1BBB7A4BFC1C9C1AB
BFC9BDC1C1AAB9C1BBC3BDCDB1BBC3AFC9C1C5A2AFC1B5C9
B3A6C3BFAFB9C1BD
B9ADA2BBB1B5BDC3B9B1B5AAB9B3BBADB7ABC1B5C9BBBDB7
BFBFC3AF9CBFB7B39EC1B9CFB7B9B5B99CB7A2A0ABB3B9D8
B5B39EB590AFC3A8BBA2C1BB9AB1DAA6BBA8B5B3B9C7AAC3
B3ADB5C3C1BDCBBD9CB7B9BBABBFE0ABC5CDB3BFBDB3B5AF
9CBBC5BBA4C7AFBDBDC1B7D3C7CDB5AABDBFADC1C7B78E9E
ADC7A4AABDA4B9BB
B1ABA4A29EB9B1C3B5B5B1ADB39EB3AFB3B9C1A8B7BDC1BB
B5B3A8B9BFC1C1C198ABB9ADBFC3BFA8B7BDAA9CAAA2A2B5
B1AAA2B1B1BFBDC3AFB9ABBBCFAFC5AD84B9C1C7B9BBC5B9
BFAFB1BDB7D1BFC5AFB3C3D3B3C1B3B5BBAAB7ADCB96C3B3
ADB3B3CFA0B1B9C7B5BDADBDC5CDA4C5C779C9B9C5BBBBA0
B3C7BDB3B7BDC7C7
B9B7BBB3C1B99CAAA8BBB1B9C3A8B5B5BBB1B3A6B3BBC3B9
B5B1B5B5BBBFC3C1A0B5ABADA2BDAFB9C3BDBF9CADA4ADB1
B3BF94A6B3A6BBB7C1AFA8B5B3BBADADB3B1C7BFB7BDBBB9
C3BDBFBFC36FC5A4C3C1CFAFADBBC394B9CBABB5B7B9BDC7
CDBDB3BDC3B5C9B5BFC7C1BBBDADA6B7BDC7C9CBC3A6A8B3
B7B9B1BDC7CBCFC3
ABB5A4B1A8B1B9B9B7BBB19EB9ABB1BBB1BDBB9CB996C9BF
B3C3C9C1B9BBB3B394C5A0AFC3C3A2A8C3A8BFC5B3C7B3BF
B3B9CFABB7A2A6D3ABA2A8B1B9BBAFC1B3A2B7BFBFB7BDC1
C5BDD3C9C3BFBFC7B5ADC3ABAAB7BFB9D5BDAFAFBDA2AFAA
CDBDABBFB5C9B5CBBBC7C1B5D5C9B9B5B5BFE4BFAFB5C19C
B9B5D1AFC9C5B5C9
ABABBFBBA4BBBBB9BDA4A4BDAAA8BBB3B5B1BDB1B7C3B9B7
BBBDB9AFBDB7B9B594AABFBBB1B7B3BFC1B59EBBAFB5C9C5
B5C1C3A0AAAAD1B1C1A0B3BBD5B7B3C7B7A0B1BDAD6DBBD1
C7D3B9ADABA4CBABC7C5BDB3B3C3AD96B3BDA8ABB5BBAAA2
A4B7ADC39CC3ABBDBDB1BFBBBBB9BBBDC1B7CBC3C5C7AACF
BBBFB1C9BBB5BFD3
B9A4A6B5B5B7AFBFAFAAAAC1C5B5BFBBA8B7B1A6B5AAB1B9
BFB7BDC9C3B7BBB5B1BDBDAAABBBB5ADB7A2B7A29EADABB3
AFC382C3BBB7A6B3B1ADBBA8B9B5BDB79CA6C5AFB7B9D5CB
C3B5B5B3AAB9A8C1D8B3B1C5B5BBC5BBC3B9A8BDBBB5ABBF
C3BDC7BFC3B5BF98C3C7CDC5B9B5BFBDB7BDC5A2CBC5B1C5
C9C5CDB3C7B5C1BD
B79EA6B9B7AABDC3A6B1BFBDBBB7BDADABB7B5B3B1BBBBB3
C1C1AABB80B1B5AFA4AFBFBFB3B3B7B1BBBBAFBDB7BBB7AD
B5BBA0B39CA6AB9CB7C192ADB7B1A6BDC39852B3B39273B9
BFB1C3B9AAC1B3A0CBB1A6C1B9B5A8AFBBB7C3B9CBD5B7C1
B1CFC7C3C1D8BD98C3C9BDC7B3BFAAC3BFB5B7DABD92B1C9
B5A694ABC7ABB9C3
B3B7B9A0ADA8B7AAB1AFB1BDBDB9C5B9ABB3BDABAFB9B1BF
ADA4B9D1AFB3AFAFB1B7C3BBB9C1B1C3B3C3C5B1B1BDC7AF
B1AFB9C3BBC1A0BDC990A8B7B1BBB9B59EB9B7BDD8A8ADC3
B5C3BDC1CBBDBDB3AAB5B5BFADB7B5C1ADBFB3B7C5AFB992
BFC7BDBBC9C7B7B3B5B7C9C9B7B9BDB7ABB5C1AFBFB7CBAF
BDBBADBDB5B5C9B1
ADAB9AB7B3C9BBA4AD9EBFB9A6AAADA69CB1C3C3C3ADB5A6
AFAFBBB7B7CDBDB1B9C1C7B5B7BFC3BFB38CC5ADBDB7A8B5
BBB1A6B59AB9B7C19696B1B3B7BBA6C39AAFAFB1AFADB5D1
BFA6B3B3D5CBADC1BFB5B1C1B9BFBBB7C5BFABB3B5BDB5D8
C3AFBFBBBBA6A6C1B9A8B9C7C5CBD1CBC192C3B7BFA6C1D1
C7BDD6DEB5C5C3B5
AFB7B9ABB5AFC1A6A4B3B7B1AFB5B3AFBBB7ADB5C1B3B9C1
BFC5A2ADC3C1B1ABB3ADAFB9AAB3C1BDBBB7C3A2C1C3AABD
AAC3CDADA0AAAAB584A4A0A0ADBDB9ADB9AD9AAFBBB5BFAA
B5B1B3C9B1CFC3C3B9B3BBBFADA2C5B5AAB9BDC5B396ADB3
C3BBB9C5D3B7BBB7BDC1BFB9BBC5C5C1B7BFBDA0BDE4B5BF
C1C7BDCD966DAABB
AAABCFB1BBC5B7B5C1B7A8C1C5BBADAFC1B9BBB5ADC7B3B5
BDB5ADAAB5BBA8B7B5B9BBB5C7AFB5BDAAB5B3ADC1B1B3C9
A0B3C3BF9EC9B3BF98B79AA8ADB9B7A8B1A4B5C5C7B3C5AA
CBBDB3BBC1B3BFB5B7CBB9BFB9C7B1AFA6ABD1A2C5E2D3D5
B9B1AFC7CDADB3B1B3ADC7B9C1C5B9BFB1C5BFC9C7A6B3A2
BFB1D1BBB3B3BFBB
B9B9B9A4A8C5AAB3AFB5B1BFAFB9BDBDBFB9C1B9B9BBB1BB
BFBBAABFAAB9B7A2C5B3C5ADB7ABC19EB7B7B7BFC1B9B1B3
ADADC3BD96B9C3BDADBDA88EA4ABA6B3AAB3D1CB96A8B7B7
A8ADB9BFB5B3B9C5BDB5B9C7C1B5BFC1B7B3B1CDBFC9A8A4
B1C3C7C5BDC99AC7CDBFC9CDC1C1CFB3BFADB361BFC1B7B3
AFC7C7BDC1B7C1B1
ABADA4B3AF9EB1BDB9AFAFC5B3ADA0B7B1B9ABABA8B3C3C7
C3CFBBC1B1B3AABFAFB5BBB9B9B1BDA2B5ADB5C1B3B1ADB1
A4B7ABB3D1B9B3AD44B3B5A68EAAAFA2A67BBDAFB38EBFC5
C7C3ABA4C1BBC3C5C1BBC1AFBB80CDB3B9BDB7ABC9ADBFAF
C1C3CBBDC5B3BDB1C5BBC7ABC3BDBFB1AAB5CBC3ADB1AABB
C19CC1B3AF92BFAA
B79EABC5B3BBCFC5B5BBC1B7BBADABB1C3BDB7C5ADB9ABC7
BFAFB3AAB3BBBFB1B7C1C1BBB9B1B1C5A8AAB77FB7AFBFC9
BBC7CDCBB9C3BDAFBDAFAABDBB7D909A9E9E94B9BF98B3CD
C3B3BBB9BBBDC3BBBDAABFAFAFADB7CFB3BBABB5C3BBC3CB
D3BDCFD1CBC1B3D1C5CBC9BDCDC1A0B3AFA4AACBCDD3CFC7
9EBDCFB7CDC3B9C1
A4A4ADB5A2A2B3AAB3C3B5B3B5BFB1ADABABBBB7B7B9B7BD
B5AFB7AFA8A8B9AFB3C3BBC1B9C5ADAFA8A0B9BDB3C1C1C9
C7BDD5C7ABBBBBB3C7BDADB7AA9A6DB194AAB9C7B7B5B1AB
C5BDBFBD9CB7B5B1B5C5C1C3BB9AC1C3B3B9C7B9C5E6A4BD
C5C1C79EC3CDC3BDB7C3BBC1C1CFC1C5C9B3BDD8C38CA0B3
BFBDC3CDB39EB5AA
ABB3B59E92C1ABBDAFB3ADAFBBA6C7B7A4BBB5C1B3B1C3B5
BBC7C1ABB3B9ADBBAFB5BFB9BFBFB9A2B1A4ADCBC3C79ACB
D1DEBDA8C1B5A4BFAFB3B9BBC3BDB19888ABBBA0CB98ABB7
ABBFC3C7C1B1BFC173B9D3AAC1A2CBB3BDB5ABB3D6B9B1B7
C1BFC3A2D8AABFC5C9C3B5BBB5B5B7ABB1DAC3ADC7C1BBC1
C3B3D5C9A6A4B5C7
B9C1B5B3A6BFBBBDBFADAABBBBB3AFAABDABB9C5C7C5B7BB
B3AAA0A4B7C1B9A6BBA4C1B9C9C7BBB3A8BBB7BFB3A4B5BD
CFC1BFADBBBFC3AFC7B5BFBBB3ABA892A098ADAAB5AFB99C
C5C3BBBDADA8C5C5ADCBC1B9ADBBB9B790B9BBBFB7B5C3BB
AFB3C9C99EC9BBBBC7AFA0A4BD9EC9BBB7BFBBC588BF9EA4
AA96BBA8B9B3C1CD
AFBBB7CB9486B3ABB5BDB3B9A4B7C3B9B7BFBBB1B7C3C1B5
BFB3A886AAB7A4C9C5A8C5B3C9C7B3B198BBB9D3D5DEB5C7
C3A8A8B5BDB9B9BFB3BFAFB9B5A2BB9EA0ADB598B3B1A0BB
C3A6B9ADBF96C7BDC9C392C7ABCBC3B7B7B5AABFAAAFB5AA
C7B7BFBDC9BBADCBB9D3AFBDA6B7C5CBCDB7AFADABC3BFAD
E2BDB7B7AAB3BFC7
B5BBAFA6C3C3BDA4BBB5BFA6C1B7C9BDABAFB7C7AAB1A8B1
B9A69E9294C5C3B5B7C7BFABBDBFADBBAFADBBB5BDBF927F
8C8E90C9ADC3BBAFB1C3D59AB5AFABB5AA9EC5BFBDA8C1C1
C7C1C5B7DABFC9ADCFC5BBD1ADC1C3CDCBB5C99EC1ADBDC3
E4AAD6BFD5C9BDB9C7D6C5BDAAC1C39ABBABC190B9B5B5C9
CDB9BFC5C3BBCDCB
BBB1B9ABAAAFA8B7BFBBB7B5B7B7C9B7BDBFC5B7B9BFAAC1
AABBB3BBCFA6B1ADB3BFBFBBB7A4ADBDAFC3BF84798896A4
75AAB7C1C3C9B1B1C1B3BBB3AFA4BDB3B7B996B3AAABA0A4
B9C5BF9CBFC1C5B5C1B9BFC3B3C39EBDB3BBCBB5BDC7C5B9
B7BBE0C3B3B9BFB9CBBFB7AFBFBDB1AA9EB9AFC3B9A8AFC9
C1B9B3C3AFABCDB5
A6B1B9B5ADB5C9C1B3ADB3B7AFADBBBDBBBDC9BFB7B9B7C1
BBABB5C1B994A6B7BDC1BFC7BBB5C1BBBDAABDBDAD8E9EB3
B5B5AFAFB9B1C5BFB3AFAAB5BFB5BDBBA4B3CBCBB39ABBC3
B7B9C3B1A8BBB9B3C3BFB9C5AAAFB99EADADABC3C7BFC7C3
BDB3ABC5CBB7C3C1D8C1B3B5C9B9CBB7B5C7B1CDB5CBB3AF
AFB7BBAFC7C7BFC7
BBB9ADAAA4ABB9A8A6BBA8AAA2C7ADB1B5B3AB9EBFB1BBC5
BFAFB1BDB1ADBBB5BDC1BDC5C1ABBDA4ADB1ABABAD8EB7C9
AAB1C1A0ADBBB7BBCFB7B9B5B9ADBBAFB3ABD688CBC5ADC3
B9A6DABDADB3B1ABC3D3BDC5BBAFBBC5CBB5BBD6BDB9CD9E
ABBDA8C5C5BDC7CBB3C7B9C3BBC5C7B79E96C3BFB9BDAFBD
B9BFCDCFB9ADB1BD
B5B9B3828E82AB96BDB7AFB5B796A8B59CAAC7B9AFC5B5B1
C3BBC5B7C9BDC9BBBBA8C1C1D3CBAFBFC3A6BFCBC1A8C5B1
B5CDCFBBB3C1C1C5BBB9BFB7B3A8AFB5C5AAABAABB9CB7C7
B9D3BDB5CBC3CBB7B1BFBFAFBDA4C3AFC5A8B1C1C3BFB7BD
C5BFB5B9AFBDAFB1C7C3AFABB9C3C7C7BFB3B1CDC1BBDCB9
CFB198BBCFB5B1CF
9AAAAAB3B9C3ADBBBDB7B9B5B9B3B59C9CB1B7B3B7ADADC9
B9BFB3CBADC5B9BFA8B5BFBDBBADBDBDB3AFBBB5A4A4B3A6
AFBDB7B3C7B3C9C1B7CBB7C5AFBDAABFABA2B3BBBF9EB3CB
AFD3B5D8BDB3C9BBBFBDC1C5BD98BFCDA8C3B3B9B9BBC3C9
B1CFBBB1A6AFB9B9C3AAB1CFC9C1B3AFADB9C1BB9EC1C3B9
BDCFD5CDADBDD5D1
BFB9BBB3BDC1ABB7C5B19EAFAFA2B5B1C1BBBDBFBBAD9AB5
C3BFAFBFBDB3C3BDB3AFBDC3B1BBC1C3BDAFC3C3B57BC99A
A6BFBDB7C1BDB7BBB1C7A0B9A2C5A8B9BDAABBAABBC79CCB
BBBFBDA4B3A6BDC7C5CDCDC3BFC7BBB1C5B5B9BDBDBBD1BB
CBB7BFB3ADBFBDC7BFD6BFD1C7CDAFBFB3C3BBB3C1C9ABB3
DEDCC9CDC9B7BDB7
BDBFBBC5B7AFB3BFC5B1B9B1B3AFB1BFA8B3C3AAB5ADC1B3
B5BBA4BDBDBBC7C3AABDB7BD9EABE2C9C5C5CBD6D8BFC3AA
C7C3C9D5B5AAB5BDADBFBFB3B7B5B3A2B5ABAABDD5BB9CA2
9AAFBBADB5C1BFC3AFA4B9C3BDB7CDBFAABFBFB3BDBDBDB3
BDC3BFC1BBBBC5E4B9CBC3B5C3AAC3C7B9B5B9B1DAC1BBA6
7FB1C1C1B9B7CDC3
B9B3B7A69CAABDC9C7AAA8AFBBBBBBBBD1D5C7A8C5B3AFB7
BBB9C5BFB1B9AAB9B5C5BFC5C3B7BFDEB3C5A8C7C9B3ADC3
A0A6D3B5ADA8C1B3C3AD90C1ABB5C3C3A4B9B7B7BFAFB3AA
CBB1C1B5B9B7ADB3B5BDBBB9AAABCDAF9CA0C1B9B9A4ADB7
CDCFB1C1B9BFAFB9AAD61FBFB1B1D1C3C59ABBB1AF9EBDA4
B5CDD3B7C9CFC3BD
ABAAB9BFB9ADC9A6B9B5C5BDABB7B3A2B7C1A8AAB5B9B9AD
B5B9B1B5BBAFBBB1CBC1C5C3B9F0B7ABBDBBB392CFB1CDBB
84C3AFAFB7AFB3BBAFB1B5AFC9AAC1AFB3AFB9966796A4C9
E4CDB7ADB7B7CFBDD1D5B7ABAFAAA6B7B5B5ABBBB5B5BBBF
BBBBAFBBBBBFC5BDBDBD9AC3C3B7A0C1B9CBBDABCFAFDAD8
BFD3B7C7C7C7BBDA
AFC5B7AAA6C3C5AFB1B39CC5BDB3A6AFC7B5A6B3ABBBB1B3
B5B1B3C1BDBDC9B9C5B7B9B7B3ABADB7BDB398D1B786B5AA
A0BDA6B9B1C3C1D1AFA8BFBBBFA0BDB3AAAAA4B1B5BDD69E
909ABBAFABB7B1BDB3B5C7B9BDBBB9B5B7A8ADC19CA4C5BB
C1B1C3BBC7B9D8CBC5A0BDB7B9B5B3B3CBC1B1A2AAAFC59E
B3CFC7CBBDCDC1B1
A4C7BBAFA6BFADB3B9ADC1C9BFB3B3ADBDB5C1AAA0B7AAB5
B9B9B3BBB5B7C5B5BDBBBBC1C1AFA2AFC786C396AFA0C5C7
AFC9A6AAB1D5B9B398BDA8ABBBB7B5B3AFAABDBDBFAAB1C1
B5C5AABFB5ABB3AFB58CC3C7BDC7B5BDB1B7B3C3BBBFB5BB
C5C3CFC3A4CFC1ADBBB5AAB5BFAFB7D1BFCDD5C9B3ADC1C3
D5D1C1BBC9A0A8C3
B9AAA6A6ABB7AFBBBBC5A8C7B7C5C3B7BDB3A4ADBDB9C3B3
BFC5B3ABAFCBC5B5ABB9CBBFB9B5BFADB9B3B3ABCBB9CBC7
C5B9AFBBCDB7C3C7ABB3BBB5BDB3BFCFB7AD8E96C9ADB5C3
CBB1B9BBC1BDBBBDC5CF9AC7C1B5B9BBB1C9D3C1B9C5C9BD
A2A8B5BFADC1B9C3B99CC9ADB5D3D1C7C3BFC7B7B5C1C1B5
90B1B9B3CDC3A0FF
C580B3BDABB1BFB3AAB7ABA6B1B1B7B3ADA8C1C5BB9EBFB7
B3BDC3B592BFBDBFBDBFBDCBADC384B5B3C5C3C5C9A0BD6B
C5C1B7B1ABBFC1D1C3BBBBB3AFB9B3B5B3ADB7BFB3B5BFB9
C3AFADB9C1B1C5D1C3BDB1D3B5B9ADBDB7B1ABA4ABC7B5BB
C3D1C9BFC3BBBDADADB5C7ADBDBFCDAAC3BDCFC779B3BBB9
C5AFAFC5B3BDB99A
B9C1BDB3B5AFBDBFBBADA0A8B3ADB7B5C7ABC7ABB9B3C3BD
B3B3BBC19CB3BFC1BDBFC3D3B7CDB5C7B3B3CBC1BBA2BFBF
ADC5C7A0B9CBCFA6B3B7A8A8B3ADB1AA44AAADBBC1A8A8AD
BDB1B7E0A0BBABAFA4B7BBB3BDBDBBC1C3B3C1ABBBAAA69E
B9B5B3C1A8C5C1CBCBADB3C9C7C1BDCBA6CDB3AFC1C7AB92
BBCFBBAFCBA6B9AA
B3B5AFA6A8B7A6BFBDC1BBBFBBBFBDC7CBB1AFADC5B7B9BB
BFB7B1C7BDB7B5BDC3AFC9C1AAB1B1B5ABC1B9B394B57FC7
B3C3B1C1BBAAB9ADBF9CAFAFB1ABB7AA90B1D5A2B7C1B198
ADD5A8B9D1A2AFA8A6CDBD9CC7D59EC78EB7ABB7B5C9B1B5
B9C9E8BFADB1C5CBB7CDA4B1BDBBB3C3CBAFD396BBC5C3BB
A0BFCDBFDA3098C5
CBADA6D6ABC1AFBBB7C1BDB9B9BDB3B3BDBFB9AABDBDC5C7
AFADAFC1B5B7C1C3B5B3C3BBB9C9AAB1B1C9ADB7C5B1BFC1
A6C1B9AAC3BDB3B19898A8BDC1B1B3A4A0A6ABBDBDB9C7AA
CDB7C1C3C5AFD5C5C9BBCDD1C5C9CBBBC1B5C1CFB9ADBFC7
BFBDB3C1BFC1D5B5AFA4B5ADCDA4C1B7A8C7B5BDB5C9B5B1
A6B1BFB56767B9BF
AFB3AAADB9BBA6A6AFBFABAFC1AAADD3CBBFA8AFAFC3B7B9
BDB7B3B7BFADBDC5ABB3C7BDB598BFC3B1C5BBBBC5BDBF9E
AAC7BBBBAAB9BDB7B1B1A8B5B7ADA8B3C59AB9B3C5B7BBC1
B3B1C99EB7CBA8ADCBC9B3CBB79EC5C3ADA2B1B5BDB5C1CF
CBC1CDADB9AAC1BFB9AAADAAB3C9B9BDBB9EBDCDD3B9A2AA
B1CDABABB9A8B1B9
A8B3BBB1ABB5B9ADB9C7B7C9BDB1BBC5C1B5B9BDB1BBABBB
ADB5AFAFBFB3A8C3BFC5BBB9C9AFCBADB7BD96B7A4AABDB5
ABA28CB3A69CADB3B3BBB58ABFC7AFA4A8A4BDC3ADB9C3AA
ABAFCBD3A8B1BFB1C1AFBDBFB5ABA8A6DCBBB394C7A4B7C7
B996BBBFB5BBBFAFA0B3A4AABBD3A6AFC57BB5CBAFAFBFB1
AAB3B7B9BBAFBBAA
A49EB9A0B7B998BFBFB9BDC7BDB1BFBDB1A4C3B9AFAFB1B7
B7B7ABAABBB5B1B7AFB7C1C3C1B5BBB7AFCBB5B9ADC7CBAF
B3B7C7C3B5B1B5BDB1BDBDBFB5B3B7CDB9A8AAAFBFC1B1BB
B3C1C5AFA8BBB3C3C5BDAFC3BFADB1D6A6B1B1BDC5BBADC1
BBB9C1BDC3C7AFB9BDC3C9B3D3B7AABBBDC1CFD1C1CFB9CB
A89CBBB7B9C3BDB9
B7B9B7B5A8AFAFB7AFA2ADB1BBB5B3B9B7BFADC396B5BBB9
AAC5B9AFBBB7BBB1AFB7B7C5C5BFA4BBABB9ADB5A4B9ABB7
ADAAB1C5BBADCFB1AFB7BBB5C79EBFBFBB80B7B3A0AB94C1
B3B1B19CC1BFB5C5AFD1A6B9BDBBAAA694B9BDC5C3B38CB7
C598A4C5C7B7CDB7BBC7AFC9BDC7BDE2BDA8B5CDC1C3AFBD
CBAAB5C1C5B1C9BB
ADCBBDB1ABB9B9B5C9B1B1B39CADBBB1BDABB9ABB5ABB5B5
BBB9BBC3B9BBB9AFA0AFAAB1C3B588BD8EB5B9B7B9C1A6AB
BBB7AFA098AFB5B790B7B1B1ABB9BBB5B1B9B1CBBFA2CDC7
C1B5ADC3B5BFC3BBC9CDBFC1BFB9B3AFBDB5B1ADB7AAAAB7
98ABBBB9B5B9C7CDC379CFC9C3BFC3C7CB98AF9C98ABAFB1
AFB7ADC9B1BDC7D5
AAB9AFB5C1AFB3B5ADB9B5AF9EB3A8ABA0B1A8C5B9C9A8AB
B7C5B5B1B7B3A6B5B5A6BFBFABB9ADBFCDB1CDC9D3BB9AAD
B5AAABB3AAB1AAB3B5BDADB9C1BBB9B9C9B994AAC3BB92BF
ABB5B5B7D1CFB7B7C1BFA8C7B9B3AFBD73B3B1B1BFD6BDC5
B3BDB9BDAFC9B5DAADADB7A692BFBFBFB3C1C3B5AFB9C7C7
B3AFBBB3B9BDD5BB
A4B9ADB39CB3B5AFB1AAB3ABB9B1C3ABBBB3BDAFBBBFC1BD
B7C7BDBBB7C9C3B5ABBBB7B9BBC1B5ADBBB7B7A6AAC99A79
CBA2ABA8C1A8BDC1C3C5B7AFB5B5C5ABB9BBB7B7B5C3BFBD
B7B5ABB1ABC1B7BDA2C9BDAFB9B1B3A8C5B5AABFC7AFBFBB
BDBFC5BBBBB3B1CBB7BBB7BDC37DC1C7B769B7B7BDC9C977
AFA0ADBBC7B7ABCB
B79EB7A8C3ADC1BDC7BBB1AAB7B5B3B3BFB1B3ADBFAABDAD
B3AFAFBDBDB5C7BFB1CBC9C1B7B5BDC5B5BDC5BBA0BFAAAD
A8A4A0B1A6C1A2CBBBB1BBB7BFC5C3CDCBB9A4B1ADBFB5AB
B5BD92B5B9B1BBC7B7C9B9B3B7B5CBBFBDBDC1BDBFCBBDC3
AAADBDCBBFC5B5ABAFC3B7BDBFBFB7BBBFB9CDC9BFB9C5C3
AAF4B7B5C7B9BBA8
B7AAABADB1B9BBB7B3B9B3B1B59CADB1B5A4A0B1CDB1B7B9
ADBD9EB7C1A8B7B9AABFC3C3B7B5CFB5B3B9B1B57FB7B5AD
A8B7CDBFB9BFB9A6AFB3AFB9CDC3ADBFA894A2BBA4B5A6C5
BBABBDA2C1AAB7DEB3C5AD9CABB5DEBDC7CFB7C9ADB1BDCB
ADA8B3CDD3C3BFB9B3C3C3C3DAC3C1B1B7C5C5AFBDBFC5A8
C1ABBDBBBFB7C3C3
ADAFABBFB9B7B3ABB5B9AFB5B5BFA2ABABAFAAAAABB3B3BD
BFAFA8BFA692C1B3B7BDBDB3B5BFB9ADAABDC5A6ABC5AFAF
B9BFBBC1C1BFB79CAFC1D3C9B5B5C59EA2A892A0B5ABB7A4
C7BFC3C9ADAF9CB5CD96B1BFC3B7BBBFB1C1C7C7C1B1A6AF
ABBDA8A0B9B5B7CBBDB5B9CFBDBDBFBDBBAFD1AFA2AFC1C9
B3C3C1BBC1B9C9BB
A8BFAAB3B3D3BDADBDADB3B9BBB9BBB7B1AFB9B7A4B9B1C5
BBB7C1B5C3B3B1BBAFB5B7C1B5B5C1A4B1C5B7B5ABA0BFB7
A8AAB5AFA6A8AF98BFC1C3AF7FAAB7C5ABABA4ABA8B1BDBD
BDB1BBAAB9B3BFC7AFBDB7CDBFB5AFCFB7B7A6C3B9D1C3D5
C5C3C3CBC3C9C1C5BFD1C9BFD6BBD3C9CBBDD8B7C5B1C7AF
84A8B9B9B9B9CFB3
A0B3B1BBB9B9C5B7B3B1BDB7B5BFC1AAB1B5B7B9C1B9B9B9
C1ABC9C7B9BFBBC1BDBDBBC5B7C7B7C7B3AFADBDC3C1A8BD
D6CDBBB7BDAAC1D5C3BDC588B3C3B9ABB3B3A8B9C1B7B7BB
ABBBBBB9B98EB7CFBDCDB3D1AD98B9BFC5C3C7C1C5B9B9B9
CBBFB1B7CBB7ABAFB1B7BBC3B5C1CDCBC9CDCF9EBDADC1BB
B9D5C3B9C7C5CBBF
A2A09CAFA4ADA2B1B7B3A8B1C1BBB5AFAAB3ABB9BDBFAABD
CFA0AFABB5C1B3C7BBB1BDB3C3BDCFA6AFADC5BFABC5CBB7
B1D1D1BBCFAFA4B5BBCDB9B7B7BBC3C1ABB1ABB5BDBFC9AD
CDB7BFD6BBB1C3C1CFC3C1BFB9B7ADA6C7D8B5CBB3B7B3B3
BBBFB7C9C9B7B5ABBDD5C1C1BFC7A6BFC3B9D3C5C3BFC1C9
CB8CAAB5C3B3B5B1
B1A8BDADADB9B7B7B9BDC1C3CBBBBFB7B5AAB5BDB3BDC9A2
B7ADB7A4BFBFA890AFCDB5C7B3CB77BBB584C7A6A2D1D1AA
AFB5BF98AAC7A2ADABC3A6B1BFADC1ABB3A2AFB1B7BFBFAD
ABC3C3B3BBC390C7B1B5BDADA8A2ABB7BFB1ADB9AFC5B1B7
C1B19CAFBFC7B7CFB3B5C1BFC5C9B1BDBBC9A0B9C9EA82BD
C5C9BFADBBC7C5AF
B3B1B1BBB7A0B9BBAFB5C3ABB7AFB9B9ADBDB9A6A06BBBB3
B1BFAFB9B5B7AAB1ADB1C5AFB3C3B7BDB59AD8B7AAB1BBC7
86BDBDB9BDA6A4B1A894B1B3C5ADB1B3B3AB94AFBFB9BBB7
B5D3B3C7C992CDAA9EB7ABCDB3AFBFAFBFBBB3B7BDBBB7BB
C9BDB5C5BFBDB9CFCDC1C1C7BFC1BFC1C7BDC7C7BDC7D6C3
B1BFC1B1C7BDBBBF
ABADA8BBB396B3B5AFAF9AABBBBBAAA8AFB9C1C3B3A0C1C1
C5BDBFC98EAFA6B7C7BFC1BFADBBC5C1A8B5CDB5C7B1A2AB
A6AFBD9CB1C1B5AAB3C7B7BDA8C1B9A2B1B18EBBAAD1B3CD
BFBBD1A6C9ADCBAFA4B7B388C1B7A8AAB9ADA6A8B3CDB7CB
C9B3BFC3C3C5C9C9B3BFBDABB3BD9CCBBBD5BFBBAFABF0B1
C3BBABDAD3BBC1B5
ABAFBBB3BBB3C1BFBBBDB5BFB3B3ADAFA492B7B1B3AFA6B9
BBABC7BFB7B9ABADBBBFC7B5B1C5AFC9B9B9BDA8BDAAC1AA
A0B1AACBC1B5BDB7AFB7B3B9B7A4BFB7B1B1A6AAD8CDB3CB
B7A8B9B3BBC7C3B39E11BFBFC7ADBDC5B1A6BDB9BDC1ADC3
C7C1B5B9BDBFB5C5B9CFD5B996B9BFB5CBC1BFB1A2B792C3
C9BDE6CDAFA0AFB5
ADB1BDADBDAFB9D1B5B1B5BFA8B1AABDBDB7AAAAADB5B7B3
C5BDB1AFBBB7B3AABDB9C7B7B7B5D1BDC3BFC3BDC9BFBDB1
BDB7B1AAA4BBC1B79CAD9EBDD1A8BBB5BBAF98C5A8E4A8B7
B9B5B5C7C9BFDCC394B5BDA4BBB9A6B3AFB9BDB7C1B5B7D3
B9BBA6BFC3B9CDA4A4BFBBC3B7AAC3C3BFC7CDB7A6CBB1BF
B7D5AFC5AFC7C7A8
9CAFB3ABADC3BBB9B1AFA6B7ADD3BFB3BFBDBFB7B1B9A8BF
AFBDB9BBA8C3B1BBBFAFBDCBBBC7ADBBB5B5AAA8ADADC5A8
A8CFB9BBC3ABB7BDB9C3BBCBADBDBDD5B9B1CDAFD5A6B3AD
B9D1ABC9C1DCC7ADB3A8E2C1AAB5BBC5BBBFB9D3AFB9B3B5
C1C384BBC5AFADB7BFBFABBDA2B9BDB3C9C9B7ABBBC180A6
B1B3BFAAB5A6AAB5
A0BDB3A4B5B9AFC9C1ABB9BBBFB5B1A2AFB1A2B7B1B7AFB3
C9B7ABAFB5A6ABB5B9B1BFC5B3BBA8D3BBBDB9BBC1A0BDC7
B9CFBFC7BBCBABADB5BBB9AABBC9AFC1BFB7B5B78EBBB5C9
9AB3CBE0C1B7BBBFBFC3B7BBB7AFA882A6C3BF9CC5B7B7C1
C3B9BFD3D8D5C5CDB7C9C3C7C7B7C3B7C5BFA4A4C5C1B1C5
A89AD3B9CBBBBDB1
ADABB5C1AFC1A4ADC7A8A8C7ABADABA8A4A6ADBBBFBFB3B5
BBB1A4ADBDBBB5BDC1B7B1B7C3C5D1D3C3B1B3C7B9BDBFB1
BFB1BFB9B9B5C7C9A6BD98B3BDB9A6B1ABB3B3ABA6B3B7B7
B9A6CDBFB9B1B3C5BFAFB5A4AA9AB9B1B1AAA4B5B9BBBDCD
C5C7BDBFBDCDC7B1BBBDC9BFBFC7C3C3BDB3B1A4B9B1B7B5
CDC5ADA8BBC9B1B7
9EB7B5BDB3BBAFBDC3C7A0AABBADAFBFAFAFAAADBDAFA6B9
C1BBABB7B1ABA2B7A0B5CBB7ABBBAAB7ADA0BBB9CFBFAF94
C3CDB3B9BDAFB7B5BBC3B3C1B99CADC17D9698AFB9AAC7C1
C1C7B1C5A6B9C9A8AFC5C5AFC1ADB7ABADA6B7BDCFB5C3C3
B9C3B7C5CDBBBDA0BDBBBFB7BBC1BBC9C3C1BFAFB3CFDABB
ABB7B9AFA4ADBBB5
A2AAB5B5B9B1AFB3B7AAB5B3B7B7B7B7A8ABB1B3B1B1ABD1
C1B596BFC1A8BBBBABC1BBBFABB7C7C1A6BFADA0BFB7A4AB
B1BBB7A8B1BDAD94CDA6A6BFC1B9B9B198A6ADB3BDB9BBBB
B9ADB992BFC1B9A8AFBFAFBBAFA8AFBDC7B3ADB7B3ABB3BB
B7BBB3AFABAAB3B5CFBBA2B9E0C3BDB5C1B1A6AFBDA0B5C5
D6C9D1C5BFBBC3B3
A8B5B1BDC3A8B1B9ADABB1BDC3A8B7BBABBDAFBFC198A4AB
ADB5C5BDA8BFAFC1ADA2BDAFABC1B9C5B3A6B7C1B5ABAFBF
BDAFC1B9BDC9A4BBD3B7C3BFBDAAB7AAADB7ABC9C5C1ADB7
BFD8C3B3DAC3ADBBCBCBBDB9AFA4B9A4AD84B5EEB9A0AABF
B7C3AFB9BDC1BDBFD3B1BBC3B3BDC3C7B3CDC7C7C3CBCFBF
B5B3B1DEC9BDC7C5
AFA2B5AFB5B5ABB7D1C5AAB5B3B1B7AFAFB9C3BDC3CDB7B9
A4BFBFB9BFABAABDAAB9CBC5B9AFAFB5B1C5A6AAC1ECBFB1
B5B5B1CBAFB5ADB7C7B7AFC1ADAFABB7BBBBB1BDB1B7B1AD
BBB7B1B7A2B3B7BDCFAABFC9C5C3C5B1B9C1CBBDC7ADB7B3
C7BDA8B3BDB7BFC5C5C3C5C3C3CDBFC5AFB9AB9498B9ADD1
BBBDC3BBA2B99AA8
A4C5B3A6B5B19EBFB5A0AFB9ADB1BBB1AAB9AABFAAB3B5BF
C3B1A0A8BDADB9B19CAAD8B1A4B98AADAABDD1D1ABBDADAD
B1BD9AAFC1C1B9B5B7B3ABC3ADADBBB1B7A0B3BDA8BFD3B9
94ABCB8CCDBFC1BDB5C7AAC7A8CBBBC3C5B3B3B7B980BBAA
A8C1B5B9C9C7BDE0C39CC5C7C5C1C3C3C1C3B79EB5B5AB8E
BDC7BDA4A696B5AA
B9B5BBBDB7B5BDBDBFB1A2B3A2BBB9AAC3C9B3B3BDA4B1B1
BFAA9AAAB7B3BDBFB1B7B1A8ADBFC1C7B1C3B3BFB9929AAD
C1C9CBC1B1C9C3B1B3AABFC3B1A8B5C1AFB59CA0BBC1B9C3
B1BFC3B3A8C9C5CDC1C7BFBFCBBBBBA0CDC1A4B1C1B9A496
AAC3D5C1C3ABA8CB79AFC3B5B5B9C5A4C3AAA6C380B7D3BD
AF86BBC9B7BD7DCB
B1B1ADB7BDB5AFB7A8ADADB1B1AFBBADA6B3BFB59CC5B7B5
B3A8B9BBC1BDC1B5AF9CADB7AFBBB3AA88C3CFBFADB7BBBD
C7B7B5AFBBC5B5A6C3AFBDC3A0C1ADB7BBA8A6B9B3ADB7A8
B5ADB1AFBBC3BDB7C5CFAFC5B5A8B5C5ADB3B7C3BFB396AD
BDBBB9C7C3B9C1C9A6B7A6ABC3C3B9C56384A2CDA688C9B9
B5AAB58AAFAFBDB7
A2AFADBFC5AA98ADBBADCFB1ADB3B1A0AFAAAFBDABBFABB1
BBB9B3C1B9B3AABBC9ABC3B1A4C5B7ABCB5FB9AFC1B1C1CB
B3C5AFBFA4D8ABBDBBBDD8AABDB1B1B3AD9EBFBF9EA2C9BD
AFB9BDB1ADB5BDCBD1B3ADCDD5B9C9C5AAA0C1AFAFB1DAC5
C3A2ABA6AFAABBC1ADBBABB1B5E4BDB7A8BDA08E98A49EBD
B5ADABC7B7E2C3EE
B5B9ADAFB1B3B1B9B3C3BDABBBB1B5AFA4A4B5BDBBB7BFBF
B7CDC1BBBFB3BBBBB9AAC9C3BBBFA0D1A2A4C1AACDBDB5C7
C5CDB39EB3CDAB94B1B5B3B7BBC9BBBFBFBBA4B3A8B7BBC7
BDBDC7ABC1CDC3B5C1ADA0B19AB5C1BBBBB5CFB7B3C1BFC1
B9C1BDBDB7C3AFB9AFBFC9BDB1AAAFB5B5B3ADAB7FBBA4B3
A2BDBFB7BBB7B998
A8B1B5A0AFBBBFB5C1C7B7ABBDAAAFBBAAA2B3ADBBB9C1BB
BFB9A89CC9C7AAB5BBB7C5B1ADBFBBC194B3C1B3BBBDC3B5
B5EAC5C994C7A8AAA8B3CBB7C9AFB7DAB9AFA2A6B9B3BFA6
ABC5AACDC3BFCFB1BBBFCBD8BBA6C1BFBBB1BFB9BFCFBDC9
B5C3C3BBB9BBADBFC3CBB7B3C5C1C5AFADC1B7B1C1C9B1C1
B9B7C7C3BBB3BBC3
B5A2B5B390ABBFA4C9BBB7A6B5ADAAA0AFC3CBB5B598BDBD
B7AA9CC300ABABB5B3AFC1C5CBC7B3B5B784B1A0BBB7BFA2
86AFBBB3A8C9C9BFB5C3C1BDC9B5A8A2BFC1A6B9C3C5CBB7
BFC1BBB77DC7B5C3ADBFB5ADB9BFADBFC9BFD3BDB7C5B9D3
B3C5DCA2BDBBBDAFBBBDC3C3A4C7AFC1B5AFA8AFBDDAA4CB
B59EC5CFAAA4C5CD
BDA8B5BDC1B7C5BFC1BBCDBFAD9AB3AFB3C1B3B9C1BFB1B1
ABB5B3BB90B1B7A8ADAAAFB1C1B9D3B7CBC1AF9AB5B3BFB7
D3B7C3ADB5C7ABC3A2C3A4A0B7AFB5B5B9B7A4AFC7B1C3AB
A2B1B9599AB9A0CFB1B5B9AAC9BBC5C3CFADC3B3C3B9B5C7
AFB7A4C1B7BBCBBFBFCFB7BBC9ADAAB1ADBBAFADCBB5AFAA
B9C1B1BFB1C1B79C
B1B5C3AFC5BBB5C5AFABAABBBBC1B3A4A8B5ABB3AFB5AAA8
B99CBBBBBFBBB3AFC5A6C3B3BDBFCDB1AAC5D6B9D8B5968C
C1B1B1BFC3B7C3ABCFC1BDAAAFB3A2BDC9C79EA8B5BBB7C1
ABBFAFC5CFC7BDB3BBC1E0C3B7C3CDCBBDBBAFA4B5B7CFAA
BBBDB9BBCFD6BBA8B9B3C9BBCBB594A8C9C1AAA2EAB1C7BD
ABC3B7D5C1B396AD
B5BBC3B5A4A4B9CDC1C1B9BDB5BDBFB5AAAFB9C1AFABBBB5
AAB5BBB7BDC3B1B9ADC3B7A2C3C1C5ADB9B9B5AFA8BBBFBF
A6A2A6C3DABFA0AFB7D5B7B9C1ABA2C5C3ABA4C1B7ABBFBD
AFC5C3C9C5C1C5BDB9BBD5B9BDC9A2C9B7C1CBBBBFB9BBCD
C9ABBFB3C5C78EB3ABA8BBD5C1AFCFBDC7BDE2D1B1D8C5AF
BDB7ADC3C7ADC3B5
AFABABADB3B7B1B1A4B9AAB9B9B3B3C5BDB7B3C5AFC7C1BB
BDC3AAAFBBB7A4B3B1A4BFB3A4AFA8B3C3C5C3E2D3D6BDB7
C5ABB3C7B7C5B9C1B9BBDCC7D8B9ADBBC1B7B5B59EC1B3B1
C1B3B3C3CBAFBBB7ADBFC7BBAAB7A8BBB5C3C5ADABAAB7C1
B7B7CFCDBD92C7B1AFB3C1C5C5D1AFC7ADB5A8BDABBBC1C3
C1C1C7ADBDB7BBAA
B1A0BB94AAA8C1B7B5AB9EC9B9ABB7BBBBB9B9BBB5BBBDC3
AFBDBDA4B1ABBDBDA6B5B5B1ADC1BDB1C5B7C1BB98B3BFA4
ADC7C5AABDC7ABC1B5ABAAABBBC9B9A8C7AF9AAFBFAFB1B1
B1C7AACDC9BFB9B5C5C1C1B798BFADB994BF9EBFC7B9B9AD
B3B3F2A898AF7BBFB1B9B7CDD3B3ABB5C3C7AA98DABFB59C
B5CFB1B1C9BDC5B1
C1C3B5C1ADB5B1AAADB1B9B5B9BDB794B1C1BBBDB3C3C5BD
B9BFB7B5AFB7AF9CBFA0BDB9BBB9ABC5B1C7C3BBABA2C7B7
C1BBBB9EB9C5B7C9B5B99EC9AFB1AA7FBBBBA0B5C9C9C9BD
ADAA90CFB3C1B1B5B9C7DCA4B5C3B3AABBBDB5B7BFC1A8CD
C5C7BDABCDBFB9BD96A8C1C3C3A4BBB5BBC3C3B5C9A6C3B7
C3CDCFB7C7C7B5AF
BB9EB9B7B1B7BD94ADA49AB1B7BBB1B5BFB99E94B9AAABB9
ADC7B9B396A2B9B7ADB3A2CDC9D89AA4BDBDAFB7B7BBB9B5
BFB1B7C1CFDCBBBFAA88D3AFCDCBADB7C1A8B1A6D3B7A0AD
C1A8B9C3B7A4B5C7CFADADAAB1C5D1E0B1DCB1ADD194C9C3
B3C1D19EC9B9BDA8D1B7BBB7C1AFB9C7B9AFC3B9BDB3BDCB
A6ADBB84B5B7C9AA
B5BBC5B5BBB7B9B1BDB9B3C9BDADB9C7ABA0C7B3B1ABADB9
B19CC3AFB9B9B7BDAFB7B3C5CBAAB9BDB1ADC3B3ADADC9BF
C7D1D1CBCBCDB9BBABCBADC3BFBBCBBBC5BBB7C1C1AFB5B1
C79EB1C790B3B7A6C3ADD1A2CDBFB3BBBDB7C5C3BBBBB5A4
AA9EB3ADB5A8C3B9CBA4A6B5BDA0B398C5B1B1AFBBCDB3A2
C1AAB5C9AAA0C175
AAAB9EA6B1BFB3BBC3AFB7B7B5BFA6C1BDA8A0BFB7B5BBBB
ADB5BDB1BDBF9CA0A6BBB9BDBDB3BFAFBBB7C5AAA4CFBBAD
BD9EC380BBA6C39AB3B1BDAFBBC7BFB7B5A6BFD3B3CDBBC3
B1BD9AB1BB75AFB7B9CBD5BBAFB1CDBDC5B3BDB9ADCFC1A4
B1C1BBBDBDAFADD3BF90ABC7ADBBB18CB396B7B9B5B7BBC3
B9C9C3C5ADBDA6A2
AAABCBA6ABABB5B1AFBFBDBDAFC1AFA2ABBDADB9ADBFBBBD
ADA2C5D18AB7ADB7B79ABFB7AFBDB5C3C1ADC7ABA2BDBDC5
C7BFB5ABBBAAA2CDBDB3B1C1B7C5C1B3A6ADA8B3BDB7BBB5
B3A8C375B98EA4C9CDCBC5ADC1BDBDABBFCBBDB7B1C1A882
BDA8B9C1BDBD9EA4C5C998AFC7B7C5A2A6B5BFC5C7BFBBB5
B9BDB3BFC1C7B5AD
A4B1B3BBBDBDC3ABB3B3B7B5ADA4A6B3B3AFB5B1A4ABA8BD
B1B3B5AB92A6AFB7BDAFC3B5B1C9B3C7B7C3AAC5B7AAD1BF
C3C9B5B9C1B1ADB3BFB5C3ABB7C5ABB7BDB5A6B9B7BFB5BF
BFC5B3B9B590BBB9BDC9B9ADC3B7B1A8ABC5BBA2B7B5A2B7
D5ADADB7BBCFBB9CC3A0A0ABC5C9BDB3D1E2C7A4B9AB9CB9
B5B7B9A4CFBDB3A0
A0B3C18EA8B19AB5B9BFBFA4BFBDBBC19CB7A0AFBDAFA8A8
ABB9BFB1B7C7B1B1ADA8ABB3B5C5ADAAC5C1B3B9B3C7D1B5
90C1C7BDBF92C598BDF4AFBDC5A0BDBBA4B7BFAF9EBBC5C3
D3B5B9B5B39CCDC5C5B78EDEBDC7B7A8CBB5B5C5BBCBC798
B3B5B9B7CDB1D3BF9CB9B9BDBDB1B1B9B3A8C7B1C7C9D5C3
BFC7BDA6C99AA8BF
ABB3BFABBDBDB1A6ADB7B79EC3AAB9C99E9EAFA8A4B3BBB7
D3BDB9B9A8B7AFB3B7B1BFA8B1CDC1BBABADB596B7ABB9B3
FF279E8CC1B9B1ADABB5CBC5AFB5A6BFBDA0BBB1C3B7AAB1
AFBDB3B1AF8EAA80C7ADA2BFB9A2B7AD9ABDBDB7C3B5B5BB
C1B5C3AAB7B3BFC5AF9286A0BFD3C1A6B3AAB9C9BDB5B7B5
B1C7CBD3C3AFABA0
B1B3B1BDB9BDABB7B5C1B7BFB1ADBBA89A8661A084C5B7B9
BBAFB7CBA2C3A6A8B3CFBDBBC5B5D1C1ADAFA8BBC3B7AD9E
9C7FBFB1A6C9B5B5CDBBB3B9A6B9B9CBC1A896AAB3B3B9AD
C7C3B9B38CAD989CAAB7ABD6CBC7889ABFADB3C7C7B5A6AA
C1AD9AD3B3B982B19CAAAAD3ADB3A2B1D5B5AAAABBB7A2B7
C5BDBDBFBFB9BBA4
B1A8ADABA6C1ABB9B3BBB9BBA8B9B3B5B3A4BBC3B5B9ADAA
B7CDABABB7AABBCDB59CB7B9AF92CBBBB9A6ABB3BFC5ADAD
AFBFC1A6B1B1BFBBAAD5A2BDA492A8C3B5A8ABC1AFC1BFB5
B1B5C1A8B1AB86A8C3A2C7BBB5A0ADC7BDB7B1CBB9AD9CBB
CBAAB1B1BFB9C3B3AD7DADAFA8CFABBD75ADBDB9B9C3C1BD
BBC598B9C5B3BBA2
A8B1ADB3B5BFA694ADB1AFB396B9A2B3B5BBBBC9BDB1BFBD
C1AFABB1AABFB5B7B5C3B3ABBBB7AFADB792A8C3A4A8B7AA
B7BDB9C7CFBDB5B9BBC3CBA4AFA6B3C9C3B1C1ADA8C1C7CF
BFA890C7BFB7BDADC1A8CBBFADC5B1B78ED5B3AFA2A4BDCB
AFB3A09AB19298BBADB3AFB7A277A8ADB9C1ADAABBC1B9BD
C1CDBDE6A4B3A09C
AAAAAAA8B7B7BBBBAAADA6B99EA2C3BDC1B1C3ABADC3BDAD
C9B5B5B1AFC7B3ADB9B5AAADBFAFA8B9C9B7BDAFBBB7B9BB
C5B7B9BBD19EAACDB1C3C7B9B1CDB5ABC5B7C1AFBD9EAAB7
BBBBADBDCDBFAD9CADCBC3E8A6C5A8BBA4B7AD8C7BA6A8BD
BFBBC9A0AFBD9EAFABB9C7B7A6ABC5B5B1C3C1C7B9DAC3BB
C5C9B3BDABB3D6AF
ABA6B3B1A2A6B9B3B1BBBBA2ADA2B9B5B7B7B7BDBB96B1B3
ABA2B9BDB3A0ABB9BDB3B3CBCDCBCDBBAFB3B5ABAD96A4B7
BBC7A8C1BDCDAFABC3C7B3B9A4AAB9B7C5AFA0B1B1C3BBB3
C3B9B3B5C9BFD1A6C3B9CDAAB9BB92B17FCBBFAB9EAFB5B3
B7B9AAB5A4A8B1AAAAADB5AAC3D5AFBDC5C3C9ADCBAD57B5
B1BBB7B7B1BFC1C1
B59EADAAB3B7B398C1ADBDB1B9ADA6B7B3B1B3B9ADA4E4AA
B1AB69B9BBAFB3ABABA2C5C1DED6B7A8B7B5B5BBB3A8CDB5
C9CDDAC19AB9B1C1C3C7ABB9C3CBAFAB8E9AADA0B9BFC3C1
C1C9C3A2AFB9BBADB3CD988EB3B5A49A9496B77F94C5BBBD
C5B5CFB3BFB98E9094ABB9BFB3B1C7C3C7B9BBCFBBB5AAAB
B3A4ABB7BFBFAABD
A6A8B9A2AFABAFB3CFC9BFA4ABAFABB78CB5B9A89CBF9AB9
AAAD94AFB3ADB5A8B7D5C1AF7359A2B7C3B9AFB3C1B7AAB5
C7C7B9BBC3C3A496A6A2CBBBC1C9C9B1BBB5B9BDC5A4B3BB
BBCBC1C5A4B3B3BDC5AFA6A6ADBDB5C9ABA4BB7D7BADC5D5
A6BBAAB9ABC3B5BFADC190C1C5B9D3B3B9ADAFB9B5A6C9B5
9EC5B5AFCBBBD398
AAADA8B39CAFAFB9BFBFB99CADB5ADA6ABB5A6ADB3C1C1B1
A8B7B3BBB398A0B5C3ABB386BDC1C7ABCDAFCDA2BBB3C1CB
B1ABB3AFAFBBBDAAC1BBB9C3C5BDBBBFC1B3AFA8AABFABC3
B1B7BBB1CDAFC7C9C1AF92B3BBABBDC1AFC79092AAC3B7BD
AFB1BDB9B1BFC3B3C5B7AAABC3B5ADAFC7AAE4C3B7BDAFBB
C5BBC5D5C9B9A4B3
B7B5A4A2AFD1CBB3BBB3BBABA0C7AABBB3C9BDB9B5BDB1A8
B7ABB3BFB3AAB5B7AD8E8E75ADB5CBB1BDB5ADC5B9C1C9C3
92BDD6CBBFB7C5CDB9BFC7C1C1D8C7ADB5BFA4B5C5B7CBBF
B9B3B9BD9ED8A4ABC9E275D196BBA6ABADA2A4A2E0C5BB8C
ADABBFCFA4CBD1A4BDB5B9D8C5BBD89CAFB390ABBBA2AFCF
B7C7CB9CC58CB9AB
ADABAFC18EA6B3B3B1ADCBA6A8B59EA4C9BDB1B9B5AAB7C1
BDC3BBAFB5C3B9C7BF9AA0BFC1AFB1B9A4BFABC5BFB7BDA8
B7C5BDBBC1BFB3BBABCBD1BDA8CB7FB9CFAB92ABBBC7BBB3
B998ADC1BBB7C7B9A4AD92CDB9DEB7ABA0CBC7A27FADBD94
C5B5D8D1B3C1B1D6A2BFBDB3ADB9BBC1AFC5BDA09CB1B1B7
B9CBADB7BBBFBDA8
AFB5B9B7C3ADADB3B3B9B998ABABB7B7BFBFBBBBAFC5BDB7
A4CDBFB3AAC196BDC7B3AAABBBB5B5ADB3BBB7CDBBBBB5C3
CDA4C9BDC9CFCBCF9EB3C1AB71A2B1B1B7A0C1C1BBC7AAB3
B99CB19ECFC9B5B9C7AFC39A949EADAD9C82A098ADD1C5C7
B9EA9AABAABDAA9EA4A8CDA6C7AFB3C3C1BDD5C9BDCDB5B1
AFBDC1BDB1B7B5AD
B3B7B5ADBBBBA0A6B3B7ABAF98AFA8A6B5AAAAAAA4AFB5B3
B5A2BDB9B9B39EA6B98EC9B1C3C1A8ADC5C1B5B5BFC3BFC9
90EECDBFBBA0B9A4B5E0A2D3A2C39EB3BDAAB1B5B3A2B1B7
C5CFB7A8ADB5C19296AAAB84A8B9C3A6A4A4AF9EA4CFA4AA
B9AABB9CCDB7BBB794B39CB1ABB1B5B1AFB7BFBDB9BBC1B5
BBBDB7C7BBC5B5AD
B5B1CBBBBFABABA4ABC3A4A6AAAFA6B1B5B396BBBBA8BFCF
B9BBB7B5AFAFADB7BFA8B19CC1C7B9B5B7B5C1B9BDC5BFC7
BBABB9B5CDCDA4BDB5A4BDB1AFBBBDC5C3B9ADABC1BFB7BF
AAA4C3AFA8B7DAB9BDABBBA4C9B984AFB5AFBBAFAAADB392
D3BBC1BBAFB99EC196C7C9BDC7C1C7C3C5AFAAADB1B3C3B7
BDBDC5B3B5AFAFBD
B5AABDABADA8C1BD9CA8AD9CAA9EAAAFB5B1A6B5BDBDA6AD
B9BDA6B9ADA8B5B3B9B3A8C5B3A8B38CBDBB54AAB7BBB59A
BDD1C1CBC7AF96D6B5ADBDCDB5C5B3B5BBB9A4AFB5A8BDC1
ADBBB3BDC79CC7CBC3C3CBAACDD1B3A6C1BBAAC9CD9CB9B3
C1B1BBA2C9AD9CC1BBB5BFC1BBC5D19AA49AB396B3AAB7C1
C3B5AFB3C3AFBBC9
B5B1AFADB3B7BFB5B3B5B1A6A0A6A6AFADAFB1B79AAF9AA4
AFBBADBDB3ADA2AFBBB1BFB1D6B9B50FBFC5AF94B1BFC3C9
AFAFC1AAA8C78896B5B9BBC3B9C196A6AFADB17FB1EAC9C3
C9A8A2C1B9B3BBC5D1A6ADB9D6C5C5C1ADBDB79E968A86C9
98B3CDA6D1AACDB79CC9CFDACDADB5BFABB9BDAFB9ABBBB7
BBB1B9CB96B3BDAF
B3A8AFA6B1A8AFB5B7ADB3AAA2B3B7A2ABB1B5B5ADB1BF9C
B5B7C5B7B9F2A8CBADA8B9C5AFBDABB3BDBDB7A4BDBBC1AB
C7BFADC5AABBA8AFAFC3BDC3B3B1BBBFB3A8ABB1BFA8B196
BFB9BDC9B5BDBDB7AFBDC1BDA8BBADBFABAB90A2C3B9BBAA
C3B9CBBDD3ADA6D1C1C1B394A2ADC598B5ADBB9EB5B5B7C1
B1B5B9B3B3B3BBB9
B3B19AAFABB1B9D1B5BBB7C190ADBFA8A2ADC5C1B1B3A4B7
AFB3A4AFB5739ABBC1A8B1B7BBC9B1B9ADB9ABBDB7BBCFBB
C1B3BFADC3ABBDBB94B3DCB3ADAFB3A4C1AFBFBFB3ABC3C7
B5B9CDC9B7BDADD1AAB5B3C3C5D3C3BBA6B5B3BDB9BDA4BF
AFCDCBC1CBCFC7C5BBB3B398B3BBAFABA8C1B3B5BBCFC3BF
B5BBA0B7BBB9BFC1
C1CBC1CBB3A2AFA2AAA6B5AB9AB3ADBDBDBBAFB7B79CB59C
C350B9AFBFAFADB5AFB1B5CDBDB5B7B5ADB7BBB9B3C1B5BD
AFB1B1B398BDBDBBBDB5C1B5ABBFB9B5C3B7A89EA6B1B1B1
B1D177ADBDB1BBABBBB9A8CFCFBBC3B79C96A4A6AABB84BD
A8BBB7CBA0ADADADADCBBBC3CDC1CDBB7DABB7B9C9B5BBB7
BD9AB39EC7BBB1BF
B9ABAFB7AAC598BFADADC5A68E96B7AFB7BDAB9CA2BFBDAA
BFAFB3B38CB59C9498A0BFB5A6B7C7BBBDADB3C1BBC1B3C1
B9AA90B7BDD5A2B7BBBDA8B7ADB7B5B9D6BF7FAFC5D5D1BB
C5BDADCDCDB9BFB7B9CFAAA4A8B9AAB3AA9EB7C786B5A0BB
BDC3AFBBA2C1B1C5D3CBD1C1BDD5C5B9C5BBB1CBADBBAD80
B5BFC1B9CBC7AFB7
A8B3B1AAABBDB5B5A2AFB1AA7F8AADADBDA2B3BFB3C7ADAA
B3B5C5B1B1ADAFB3AFB5BBB7BDB7ABB1B7C1C1C3ADCDC3A0
BDA2B9C3CFB5B5ABB1ABC7ADB9CBD3B7C3A4ABA2C7C3CFB7
C9B1C7C3BFA8ABC9AF9EB7AFB1B5CBA0A6A2C3C5A2A89EBD
C5ABAFCDC3BBB5C9C1BBCBB5B7A8BDB7B5C39A92B5ADB5B9
BFCDC7C7BBC3B3BB
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005`3oool0
303:b/X0a<C40;>c/`30`<00][Jf0<;2`P2l_;`0a<C40;jn_P36a/H0_[jn0:^[Z`80[jn_0100^[Zj
0;jn_P2d];@0[jn_0;Jf]P2YZJT0Zj^[0:f][@2j^[X0^;Rh0;6a/@2h^;P0^[Zj0<30`03?cll0`<30
0P34a<@01@30`<00_;bl0<;2`P2HV9P0b<S80080^;Rh00X0_;bl0:VYZ@2j^[X0c<c<0<;2`P38b<P0
_;bl0;Bd]02MWId0RXZ:0P30`<009@2c/k<0T92@0;Bd]02n_[h0a/K60;Zj^P3<c<`0^;Rh09BDU038
b<P0^[Zj0<30`03:b/X0c<c<0=7Ad@30`<00c<c<0<30`034a<@0/k>c0<C4a03<c<`0b<S80<K6aP2n
_[h0a<C40<S8b02[Zj/0_;bl0<C4a03:b/X0a<C40<;2`P38b<P0^[Zj0<o?c`38b<P00P34a<@03`2n
_[h0a/K60<S8b038b<P0clo?0;Jf]P2n_[h0b/[:0;>c/`38b<P0_;bl0;Zj^P36a/H0b<S80<;2`P0N
0?ooo`0g0<o?c`35aLD0_;bl0<W9b@30`<00alO70;Vi^@33`l<0alO70<k>cP37alL0/[:b0;Ng]`2b
/[80_;bl0<30`02g]kL0[Jf]0;^k^`2][Jd0/;2`0:n_[`2g]kL0^KVi0;:b/P32`/80_[jn0<G5a@3A
dM40_;bl0<G5a@3<c<`0alO70;^k^`33`l<0V9RH0<?3``2i^KT0^k^k0<G5a@2][Jd0_;bl0<[:bP30
`<00aLG50;^k^`2g]kL0Zj^[08b<S02n_[h0`l?30;Jf]P2BTY80/[:b0;jn_P020;bl_00>0<O7a`2l
_;`0W9bL0<G5a@32`/80bLW90<[:bP39bLT0c/k>0<;2`P3<c<`0^k^k0<;2`P2f][H20<G5a@0>0<?3
``32`/80^k^k0<O7a`35aLD0ZZZZ0<30`032`/80alO70<W9b@33`l<0alO70;^k^`3>c/h20<G5a@0@
0<W9b@37alL0aLG50<[:bP3<c<`0e]KF0;Jf]P2l_;`0aLG50;Jf]P3:b/X0`<300;bl_033`l<0bLW9
0<?3`aT0oooo000G0?ooo`0U0;Jf]P2l_;`0[jn_0<C4a02j^[X0`/;20<g=c@32`/80dm?C0<c<c02l
_;`0^;Rh0:f][@2j^[X0/k>c0;Jf]P2j^[X0][Jf0<30`015ADD0^;Rh0;6a/@2h^;P0[Jf]0;>c/`2l
_;`0[Jf]0;jn_P3Ogml0a<C40;jn_P2_[jl0];Bd0<g=c@34a<@0c<c<0;>c/`020;jn_P0J0;Zj^P2l
_;`0YJFU0;>c/`28R8P0][Jf0<c<c02][Jd0/K6a09^KV`2l_;`0][Jf0:n_[`30`<00YjNW0;jn_P1m
OGd0/K6a0:^[Z`2n_[h0`<300:n_[`3<c<`0cLg=0;Jf]P2n_[h20<S8b00@0<30`032`/80`<300;Rh
^02j^[X0`/;20<c<c03AdM40cLg=0;6a/@3:b/X0`/;20<30`02a/K40_[jn0<[:bP80_[jn00l0_;bl
0<g=c@3?cll0clo?0<K6aP2a/K40a/K60<;2`P36a/H0][Jf0<c<c02_[jl0b/[:09nOW`2h^;P00P3:
b/X20;Jf]P030<g=c@3oool0oooo01`0oooo00<0^k^k0<[:bP2`/;000P3<c<`0B037alL0dm?C0<W9
b@3Hf=P0c/k>0<;2`P30`<00]kNg0;jn_P2g]kL0^k^k0;jn_P2k^k/0`l?304Q8B030`<00];Bd0;^k
^`2_[jl0]kNg0<W9b@2g]kL0][Jf0=SHf035aLD0^k^k0:RXZ02f][H0f][J0<O7a`3?cll0^KVi0<?3
``30`<00_;bl0;jn_P2ZZZX0^k^k09:BTP2k^k/0c/k>0;Bd]02ZZZX0XJ6Q0;jn_P2g]kL0/;2`0;jn
_P2XZ:P0aLG508j>SP2_[jl0/;2`0;Ng]`37alL0/[:b0=GEe@3>c/h0^KVi0;bl_037alL0`l?30;bl
_035aLD0`l?30;^k^`2n_[h0`l?30<c<c03AdM40c/k>0;2`/080b/[:01X0`l?30;2`/02n_[h0b/[:
0;jn_P37alL0`l?30<o?c`3AdM40clo?0<O7a`2d];@0bLW90<G5a@32`/80];Bd0<c<c02b/[80bLW9
0:>SX`30`<00clo?0<c<c02k^k/0];Bd0<W9bAT0oooo000G0?ooo`0m0;jn_P30`<00/k>c0;Rh^02W
YjL0];Bd0<S8b03<c<`0a/K60;6a/@2h^;P0][Jf0;Zj^P32`/80a/K60;bl_02j^[X0a<C40;jn_P2U
YJD0^[Zj0;Jf]P2][Jd0^[Zj0;Bd]02f][H0c<c<0:VYZ@36a/H0];Bd0;jn_P2QXJ40b<S80<C4a03=
cLd0a<C40;Rh^02[Zj/0b<S80;Zj^P2d];@0b/[:0<K6aP2l_;`0b<S80;Zj^P38b<P0ZJVY09^KV`2d
];@0YjNW0;Jf]P2j^[X0_;bl0<c<c02_[jl0/K6a0<C4a02n_[h0_;bl0<;2`P020<C4a0090=7Ad@30
`<00b<S80;Zj^P2c/k<0a/K60<c<c030`<00a<C40080b<S801l0c<c<0<;2`P36a/H0a/K60:f][@2n
_[h0cLg=0;bl_034a<@0^;Rh0<;2`P2n_[h0a<C40<c<c02c/k<0a<C40;Jf]P2j^[X0a/K60=GEe@3A
dM40`/;20;>c/`3EeMD0/K6a0<C4a02n_[h0a/K60<S8b02c/k<0a/K601h0oooo0200`/;20<W9b@32
`/80`/;20:f][@2k^k/0aLG50<W9b@33`l<0_;bl0<;2`P2n_[h0`<300<?3``37alL0aLG50<?3``37
alL0`/;20:n_[`2l_;`0^KVi0;2`/02k^k/0^KVi0<30`03?cll0[Jf]0<[:bP2n_[h0bLW90:RXZ080
bLW901T0clo?0<O7a`2l_;`0/;2`0<O7a`2i^KT0];Bd0<O7a`33`l<0`<300<[:bP2n_[h0bLW90:f]
[@2QXJ40/[:b0:ZZZP2g]kL0^KVi0;^k^`3EeMD0_[jn0;Ng]`39bLT0`/;20080_[jn00/0aLG50<[:
bP3Fe]H0_[jn0<O7a`2n_[h0][Jf0<[:bP3?cll0aLG50<O7a`020<W9b@0O0<c<c033`l<0dm?C0<[:
bP2_[jl0`/;20<[:bP2l_;`0aLG50;^k^`37alL0`/;20<G5a@3>c/h0][Jf0<G5a@2i^KT0_[jn0<W9
b@3AdM40c/k>0<?3``2f][H0f=SH0;Ng]`32`/80_;bl0<W9b@3:b/X0];Bd0<?3``0I0?ooo`005`3o
ool00`34a<@0`/;20<S8b0020;Rh^00D0<30`02a/K40emOG0<o?c`2d];@0[jn_0;Jf]P2a/K40`<30
0;jn_P34a<@0^;Rh0;Jf]P34a<@0b<S80<;2`P2n_[h0UYJF0;>c/`2f][H20<30`00>0<C4a03<c<`0
][Jf0<S8b02c/k<0^[Zj0<C4a036a/H0][Jf0;Rh^02QXJ40YjNW0<K6aP2a/K420<[:bP0R0<30`02l
_;`0YjNW0<C4a02>SXh0Q8B40;>c/`2[Zj/0][Jf0:6QX@2c/k<0`/;20;>c/`32`/80^[Zj0;Rh^030
`<00a<C40;Jf]P2j^[X0[Jf]0;Rh^02l_;`0/K6a0;Jf]P30`<00];Bd0<C4a038b<P0`<300;Jf]P3:
b/X0^[Zj0<30`080][Jf01X0a/K60<o?c`38b<P0b/[:0<;2`P2f][H0`/;20;>c/`2h^;P0dm?C0;6a
/@38b<P0`/;20<K6aP34a<@0dM7A0;Rh^02SXj<0`<300<[:bP2n_[h0`<300;Bd]02f][H0/K6a0;>c
/ah0oooo00h0bLW90<?3``3>c/h0_[jn0<30`032`/80];Bd0=KFeP3Cdm<0]kNg0;Bd]02n_[h0^k^k
0<?3``80aLG502d0^k^k0;Ng]`33`l<0alO70<;2`P33`l<0W9bL0;Ng]`2k^k/0_;bl0<30`035aLD0
c<c<0;Vi^@39bLT0]kNg0;jn_P37alL0b/[:0;jn_P2k^k/0XJ6Q0:f][@39bLT0][Jf0<O7a`3?cll0
`/;20;jn_P2[Zj/0c<c<09:BTP27QhL0]kNg0:n_[`2k^k/0Y:BT0;Bd]035aLD0^KVi0<o?c`2g]kL0
_;bl0<?3``39bLT00P2l_;`03P2`/;00^KVi0;bl_02f][H0^KVi0<?3``2g]kL0dM7A0<k>cP30`<00
]kNg0<W9b@2i^KT0`/;20P2i^KT01`39bLT0dM7A0<[:bP35aLD0`/;20;^k^`37alL00P2k^k/04@3?
cll0];Bd0<k>cP32`/80`l?30<[:bP3?cll0];Bd0:BTY032`/80b/[:0;bl_02n_[h0][Jf0;Ng]`2`
/;00/[:b01T0oooo000G0?ooo`0@0;>c/`30`<00][Jf0<o?c`3:b/X0^[Zj0;jn_P36a/H0a<C40<g=
c@2h^;P0a/K60;Rh^036a/H0_[jn0;Bd]0<0^;Rh01@0gmoO08Z:RP2WYjL0YjNW07moO`2UYJD0^;Rh
0;bl_02n_[h0dM7A0<g=c@3<c<`0`<300=7Ad@3<c<`0[jn_0;Rh^02SXj<0_[jn0:^[Z`80_[jn00<0
[jn_0;Rh^032`/800P2h^;P02@2l_;`0QXJ608R8R02YZJT0b<S809nOW`30`<00^;Rh0;Zj^P030;bl
_00=0<30`02d];@0Zj^[0<;2`P2l_;`0b<S80;jn_P38b<P0`<300<C4a02n_[h0a/K60=7Ad@030<30
`0030<C4a030`<00][Jf0080_[jn00/0a<C40<;2`P2WYjL0`/;20<[:bP30`<00c<c<0<K6aP38b<P0
b/[:0;bl_0020<C4a080dM7A00@0[jn_0;Bd]034a<@0_;bl0`34a<@0102n_[h0`/;20<;2`P2l_;`N
0?ooo`050;Jf]P39bLT0_[jn0=GEe@3?cll00P2n_[h03P3>c/h0c<c<0<o?c`2l_;`0b/[:0<30`039
bLT0`/;20;Jf]P2k^k/0_[jn0;bl_03[jn/0RHV90P2[Zj/06029RHT0Zj^[0;bl_02l_;`0`<300<o?
c`3<c<`0bLW90;^k^`3?cll0dm?C0;:b/P2f][H0Y:BT0;jn_P2b/[80aLG50;jn_P2b/[80_;bl0<G5
a@32`/80aLG50;bl_080SXj>00@0ZZZZ0<?3``2QXJ40_;bl0P2g]kL05P2k^k/0]kNg0<;2`P37alL0
]kNg0:f][@32`/80`<300<c<c02n_[h0alO70<30`033`l<0_;bl0<?3``3AdM40`l?30<;2`P30`<00
`/;20<30`02f][H20;bl_0080<?3``2k^k/0Zj^[0<[:bP37alL0`<300<W9b@32`/820<o?c`0@0<?3
``39bLT0alO70=?Cd`3<c<`0[Jf]0;Ng]`37alL0]kNg0<o?c`30`<00aLG50;^k^`2n_[h0aLG50<30
`1T0oooo000G0?ooo`0;0<;2`P2YZJT0`/;20;Zj^P2l_;`0^;Rh08R8R02[Zj/0ZJVY0<S8b034a<@0
0P2j^[X0C@2n_[h0`<300<S8b02h^;P0eMGE0:f][@3EeMD0^;Rh0<K6aP2l_;`0Zj^[0;Zj^P2QXJ40
b<S80:FUY@3GemL0b/[:0<S8b02c/k<0a<C40;bl_03=cLd0c<c<0<K6aP2][Jd0][Jf0<30`036a/H0
a<C40=7Ad@2[Zj/0YJFU0<g=c@38b<P0QXJ608R8R02c/k<0];Bd09VIV@2f][H0YjNW0;Jf]P3Cdm<0
H61P0<g=c@2d];@0^[Zj0;bl_02n_[h0_;bl0;>c/`2YZJT0`<300;bl_030`<00_;bl0;jn_P32`/80
_[jn0<S8b03=cLd0^[Zj0<o?c`2h^;P0ZJVY0;Bd]02j^[X0a<C40<g=c@34a<@0b<S80<C4a03<c<`0
dM7A0<S8b02n_[h0a/K60080`<3000d0b/[:0=?Cd`3<c<`0cLg=0<K6aP3Cdm<0a<C40;Jf]P30`<00
`/;20;jn_P3=cLd0a<C401h0oooo00`0`l?30;:b/P33`l<0_;bl0;jn_P30`<00QXJ60:^[Z`2i^KT0
b/[:0<O7a`2l_;`20;jn_P0H0<30`039bLT0`/;20=GEe@2`/;00dM7A0;Bd]033`l<0^k^k0:f][@2k
^k/0Xj>S0<O7a`2[Zj/0f=SH0<k>cP3<c<`0];Bd0<G5a@30`<00dM7A0=?Cd`35aLD0Zj^[0P2n_[h0
7P39bLT0c<c<0<k>cP2`/;00ZZZZ0<W9b@33`l<0RHV9092@T02k^k/0^KVi09nOW`2g]kL0/[:b0;Vi
^@3>c/h0IfMW0=GEe@2g]kL0^k^k0<;2`P33`l<0`<300;Ng]`2_[jl0`l?30;jn_P35aLD0_[jn0<G5
a@80`/;20240`l?30<W9b@2g]kL0c/k>0;bl_02_[jl0^KVi0;jn_P33`l<0c<c<0<?3``35aLD0`l?3
0<O7a`3>c/h0alO70;jn_P35aLD0`<300<;2`P3:b/X0c/k>0<[:bP3?cll0alO70<[:bP3<c<`0^KVi
0<;2`P37alL0`/;20<[:bP32`/806@3oool001L0oooo00T0a<C409VIV@3:b/X0_;bl0;6a/@38b<P0
[Jf]0<[:bP2l_;`00P36a/H01P32`/80a/K60<S8b02l_;`0/k>c0:f][@80/K6a00@0_;bl0;jn_P2Q
XJ40`/;20P2d];@0D02f][H0[jn_0;Jf]P3:b/X0a<C40<[:bP2c/k<0_;bl0<;2`P36a/H0a<C40<30
`02h^;P0a<C40;Bd]032`/80b<S80=_Kf`2f][H0_[jn0<g=c@34a<@0WinO08b<S03?cll0Zj^[0<;2
`P2QXJ40YjNW0;Rh^034a<@0b/[:0<o?c`2YZJT0^[Zj0<S8b02l_;`0`<300;Jf]P2c/k<0`<300<S8
b030`<00a/K60<;2`P2[Zj/0a<C40<S8b034a<@0b/[:0;bl_02YZJT0/k>c0<K6aP3Cdm<0cLg=0<S8
b032`/80_[jn0<K6aP3AdM40b<S80<c<c03=cLd0a/K60<S8b032`/80cLg=0;Zj^P2n_[h0];Bd0;6a
/@2h^;P0a/K60;bl_02a/K40[Jf]0<C4a02l_;`0cLg=7P3oool02@33`l<0WinO0<k>cP32`/80]kNg
0<k>cP2i^KT0clo?0<?3``020<W9b@80b/[:00X0c<c<0<;2`P2f][H0Zj^[0;^k^`2f][H0_;bl0;^k
^`2[Zj/0bLW90`2f][H03P2`/;00^k^k0<c<c033`l<0bLW90;:b/P2l_;`0`l?30<O7a`35aLD0_[jn
0<?3``3:b/X0`/;20P33`l<07@3Kfm/0^KVi0;jn_P39bLT0c/k>0:6QX@2@T900clo?0:f][@30`<00
WYjN0:ZZZP2k^k/0`<300<[:bP3Fe]H0ZZZZ0;^k^`3:b/X0`<300;bl_02d];@0]kNg0<?3``37alL0
`/;20<c<c033`l<0/[:b0080aLG501P0`/;20<O7a`2l_;`0Z:RX0;2`/032`/80eMGE0<c<c037alL0
`/;20;bl_037alL0c<c<0<O7a`3:b/X0c<c<0<G5a@37alL0`l?30<k>cP2i^KT0alO70;Vi^@2d];@2
0<O7a`060<G5a@2k^k/0];Bd0<O7a`2n_[h0c/k>6@3oool001L0oooo00P0a<C40;bl_02l_;`0_[jn
0;Zj^P2f][H0_;bl0<[:bP80`/;200X0b/[:0<30`02j^[X0`<300;bl_02j^[X0_;bl0;Jf]P32`/80
^;Rh0P2n_[h01P34a<@0`/;20<;2`P2d];@0ZJVY07=cL`80`<3001P0_;bl0=7Ad@3:b/X0emOG0<S8
b02j^[X0`/;20<c<c036a/H0][Jf0;>c/`3AdM40Zj^[0<S8b032`/80_;bl0;Rh^02>SXh0R8R808b<
S034a<@0/K6a0<S8b02[Zj/20=7Ad@0]0<;2`P3<c<`0b/[:0<K6aP3:b/X0];Bd0<K6aP32`/80^;Rh
0:NWY`36a/H0];Bd0;>c/`34a<@0[jn_0<g=c@2h^;P0_;bl0<30`02d];@0^[Zj0:n_[`2d];@0a/K6
0<C4a03GemL0][Jf0<S8b02h^;P0^[Zj0<o?c`3<c<`0cLg=0<;2`P3:b/X0`/;20<o?c`2j^[X0^;Rh
0;bl_038b<P0a<C40;bl_03<c<`0`/;200<0_[jn00<0c<c<0?ooo`3oool0703oool04`35aLD0_[jn
0<30`030`<00_;bl0;Vi^@2n_[h0c<c<0<W9b@32`/80bLW90<;2`P2n_[h0`/;20;jn_P2l_;`0_[jn
0<30`03:b/X00P2l_;`04032`/80aLG50<?3``35aLD0_;bl0:f][@1mOGd0`/;20<G5a@32`/80dm?C
0<[:bP3Fe]H0c<c<0;bl_035aLD20<W9b@0]0;Vi^@2f][H0dM7A0:n_[`39bLT0`l?30;jn_P2g]kL0
T92@08J6QP2CTi<0aLG50;Bd]032`/80ZZZZ0<o?c`3Cdm<0`<300<?3``37alL0`/;20<W9b@2l_;`0
bLW90<G5a@2g]kL0[jn_0<O7a`2g]kL0/[:b0<?3``2d];@0clo?0<;2`P2n_[h0_;bl0;Jf]P2i^KT0
/;2`0;Ng]`33`l<0aLG50=KFeP2i^KT0bLW90080^k^k0P3<c<`04@3?cll0aLG50<c<c033`l<0clo?
0;jn_P2l_;`0`<300<W9b@37alL0`<300=?Cd`35aLD0_;bl0<30`02l_;`0bLW901T0oooo000G0?oo
o`030<S8b032`/80_;bl0080];Bd0140`<300<;2`P2d];@0_[jn0<30`036a/H0`/;20;bl_02n_[h0
a<C40<;2`P2l_;`0b<S80<C4a02a/K40`<300;bl_0020<;2`P0D0;Rh^02n_[h0XJ6Q0;Zj^P2WYjL0
`/;20;jn_P3<c<`0];Bd0<;2`P2c/k<0b<S80<g=c@34a<@0`<300<o?c`3:b/X0_[jn0<;2`P34a<@2
0<;2`P0J0<g=c@28R8P0V9RH09RHV02h^;P0V9RH0:NWY`2_[jl0`<300;Zj^P2d];@0XJ6Q0;jn_P2l
_;`0/k>c0<g=c@2_[jl0a/K60;Jf]P2d];@0hn?S0;Rh^02j^[X0/K6a0<o?c`32`/820<K6aP0G0;6a
/@3MgMd0b<S80<g=c@3<c<`0^[Zj0;jn_P2c/k<0clo?0;jn_P3=cLd0b<S80;jn_P38b<P0`<300<C4
a03=cLd0a/K60;Jf]P3Cdm<0cLg=0<S8b02d];@00P30`<001P3?cll0`/;20=OGe`32`/80fm_K07Ui
NAh0oooo00<0bLW90<?3``2n_[h00P2g]kL04P2n_[h0`l?30;Ng]`30`<00_[jn0<O7a`39bLT0`l?3
0<30`035aLD0`<300;Vi^@39bLT0`/;20;:b/P30`<00`l?30<W9b@80_[jn01<0alO70:ZZZP2l_;`0
[jn_0<[:bP32`/80c<c<0;^k^`3:b/X0/[:b0<W9b@3>c/h0aLG50<W9b@3?cll0b/[:0<?3``3:b/X0
alO70080aLG500`0c/k>08^;R`2JVYX0WinO0<;2`P2TY:@0/[:b0;Jf]P2l_;`0]kNg0;Jf]P2TY:@2
0<30`0070;Vi^@3AdM40/[:b0<G5a@2i^KT0]kNg0>7Qh@020;^k^`030;:b/P3?cll0`l?30080bLW9
01L0][Jf0=GEe@33`l<0b/[:0<k>cP2l_;`0_[jn0;Bd]03>c/h0`/;20<o?c`3:b/X0`/;20<W9b@35
aLD0bLW90=7Ad@33`l<0][Jf0<o?c`3:b/X0bLW90;Ng]`020<;2`P060<c<c033`l<0fm_K0<[:bP3K
fm/0OGem6@3oool001L0oooo01D0`<300;Zj^P2f][H0b<S80<30`032`/80^[Zj0<o?c`26QXH0cLg=
0<S8b02n_[h0a<C40<30`02UYJD0cLg=0;jn_P2h^;P0a<C40=7Ad@36a/H00`2h^;P0D@2l_;`0`<30
0<C4a032`/80cLg=0<[:bP38b<P0cLg=0:NWY`34a<@0b<S80;bl_03=cLd0emOG0;Rh^02n_[h0^[Zj
0;>c/`2a/K40`/;20<30`02f][H0_[jn038b<P15ADD0R8R80<C4a02YZJT0YJFU0;bl_02h^;P0[jn_
0<C4a02l_;`0Xj>S0;6a/@2[Zj/0b<S80:f][@2l_;`0b/[:0;bl_036a/H0`/;20<c<c02d];@0c<c<
0;Jf]P3=cLd0_[jn0;bl_030`<00^[Zj09^KV`2_[jl0`<300:n_[`36a/H0`/;20;Rh^03Vi^H0dM7A
0<[:bP30`<00b<S80;Rh^02n_[h0b<S80;jn_P34a<@0b<S80<g=c@32`/80^;Rh0;>c/`38b<P0`<30
0<g=c@34a<@0^[Zj0;jn_P0N0?ooo`0F0<W9b@33`l<0][Jf0<G5a@2n_[h0`l?30;Vi^@3?cll0T92@
0<k>cP35aLD0_[jn0;bl_033`l<0Zj^[0<k>cP30`<00][Jf0<;2`P3Cdm<0bLW90<;2`P80^k^k0140
`<300;jn_P32`/80aLG50<k>cP35aLD0c/k>0=gMg@2d];@0aLG50<[:bP2n_[h0c/k>0=KFeP2k^k/0
_[jn0;^k^`020;Bd]00c0<W9b@37alL0_[jn0;jn_P0h>3P0@d=3092@T03<c<`0]kNg0:^[Z`30`<00
^k^k0;Jf]P35aLD0_[jn0:JVYP2b/[80[jn_0<W9b@2][Jd0^k^k0<[:bP2l_;`0aLG50<;2`P3<c<`0
]kNg0<[:bP2i^KT0b/[:0;bl_02k^k/0`<300;Ng]`2SXj<0/[:b0<30`02_[jl0`l?30<30`02k^k/0
inOW0=?Cd`3:b/X0`l?30<W9b@2k^k/0`<300<G5a@2l_;`0aLG50080bLW900T0_[jn0;^k^`2f][H0
bLW90<;2`P3<c<`0`l?30;bl_030`<006@3oool001L0oooo00l0_;bl0<S8b02c/k<0/k>c0;Zj^P2c
/k<0_[jn0<[:bP36a/H0b/[:0<C4a02h^;P0^[Zj0<30`032`/800P2f][H04`2l_;`0fm_K0<K6aP3:
b/X0/k>c0;Zj^P34a<@0`/;20;Rh^036a/H0_[jn0=OGe`2KVi/0][Jf0<S8b034a<@0b/[:0<K6aP3A
dM400P2j^[X0403jn_X0^[Zj0<K6aP2n_[h0][Jf0<;2`P2n_[h0/k>c0;6a/@2YZJT0/K6a0>GUi@38
b<P0`<300<K6aP30`<020<K6aP0a0:f][@2d];@0_[jn0;Bd]030`<00`/;20<K6aP34a<@0][Jf0;bl
_030`<00b<S80;Bd]02l_;`0a<C40<K6aP32`/80a/K60<;2`P3IfMT0clo?0;jn_P2l_;`0`/;20<C4
a03:b/X0`<300;Jf]P38b<P0^[Zj0<C4a03<c<`0`/;20<K6aP34a<@0^;Rh0;jn_P3<c<`0b/[:0<S8
b02n_[h0a<C40<S8b02n_[h0`/;20<30`034a<@0hN7Q0<S8b00N0?ooo`040<?3``3<c<`0];Bd0;Bd
]080^k^k00T0`/;20<[:bP35aLD0b/[:0<O7a`2n_[h0_;bl0<W9b@3:b/X00P2i^KT0102n_[h0f][J
0<c<c03?cll20;bl_080`l?300L0`<300<c<c032`/80e]KF0:RXZ02g]kL0dM7A0080b/[:02@0alO7
0<o?c`2l_;`0`<300?Win@33`l<0c/k>0<O7a`2i^KT0alO70<?3``2i^KT0][Jf09nOW`2b/[80gmoO
0<c<c037alL0bLW90<?3``39bLT0aLG50:^[Z`2b/[80_[jn0;Jf]P30`<00`/;20<?3``32`/80^KVi
0;bl_039bLT0clo?0;Ng]`2n_[h30<?3``040<O7a`33`l<0eMGE0<?3``80_[jn01X0`l?30<;2`P37
alL0_[jn0;Ng]`3:b/X0_[jn0<O7a`3<c<`0`l?30<O7a`35aLD0^k^k0<30`03<c<`0b/[:0<O7a`2n
_[h0aLG50<W9b@30`<00`l?30<G5a@39bLT0i^KV0<c<c1T0oooo000G0?ooo`0=0<[:bP2n_[h0`/;2
0<;2`P2f][H0b/[:0;>c/`2l_;`0];Bd0;bl_030`<00a/K60<;2`P020;Jf]P0A0;jn_P34a<@0^[Zj
0;Jf]P2j^[X0_[jn0;Jf]P34a<@0^;Rh0;jn_P2d];@0`<300<K6aP3GemL0c<c<0;6a/@2UYJD00P3:
b/X0<032`/80b<S80;jn_P32`/80];Bd0;jn_P30`<00_;bl0;Zj^P2l_;`0_[jn0;Jf]P2WYjL0YJFU
0;Rh^026QXH0^;Rh0<K6aP3=cLd0[jn_0;Rh^032`/80[Jf]0:FUY@2h^;P0_[jn0;Jf]P38b<P0a<C4
0<c<c034a<@0][Jf0<C4a03<c<`0^;Rh0:f][@3?cll0a/K60<c<c038b<P0_[jn0;>c/`2SXj<0^[Zj
0<;2`P2f][H0a<C40<[:bP80a<C400X0b/[:0;Zj^P3<c<`0^;Rh0;Zj^P32`/80clo?0<30`036a/H0
`<300P38b<P01`3<c<`0b<S80;Rh^038b<P0];Bd0<30`036a/H00P2d];@N0?ooo`0=0=7Ad@30`<00
`l?30<?3``2k^k/0b/[:0;bl_035aLD0_[jn0<;2`P35aLD0c<c<0<W9b@020;bl_00V0<30`035aLD0
alO70<30`033`l<0alO70;jn_P3:b/X0_[jn0<30`02l_;`0`/;20<O7a`3Fe]H0c<c<0;Bd]02ZZZX0
c/k>0<[:bP37alL0bLW90<30`033`l<0[Jf]0<30`032`/80_[jn0<G5a@2n_[h0`<300;Vi^@2VYZH0
Zj^[0;^k^`2>SXh0^k^k0<W9b@3?cll20:f][@060;jn_P2g]kL0/;2`0;Vi^@2n_[h0^KVi0P35aLD0
603<c<`0`<300;Bd]035aLD0c<c<0;jn_P2d];@0clo?0<G5a@3<c<`0bLW90<30`02f][H0XJ6Q0;^k
^`35aLD0]kNg0<O7a`3?cll0aLG50<c<c039bLT0^k^k0<[:bP80_;bl0100`l?30=7Ad@33`l<0bLW9
0<;2`P39bLT0clo?0<[:bP39bLT0^k^k0<?3``2f][H0]kNg0<?3``2n_[h0][Jf6@3oool001L0oooo
00<0/k>c0;Rh^02j^[X00P34a<@0<@2n_[h0][Jf0<;2`P30`<00^[Zj0;jn_P2d];@0b<S80<C4a02j
^[X0b/[:0<30`02h^;P0a/K60<C4a02h^;P0a/K60;Rh^02j^[X0`<300;bl_038b<P0_[jn0<C4a038
b<P0_;bl0<;2`P36a/H0][Jf0<S8b03:b/X0a/K60;>c/`34a<@0a/K60<o?c`3<c<`0b/[:0;>c/`2]
[Jd0^[Zj0<c<c032`/80][Jf0;Bd]02l_;`0][Jf0;Bd]02YZJT00`3=cLd07@36a/H0clo?0<;2`P3I
fMT0b/[:0;bl_02j^[X0`<300:NWY`3<c<`0][Jf0;6a/@2_[jl0];Bd0;bl_034a<@0cLg=0;Rh^02l
_;`0];Bd0;jn_P36a/H0_[jn0<;2`P36a/H0^;Rh0<S8b03EeMD0b<S80080a/K60140_[jn0<S8b036
a/H0`/;20;Jf]P2l_;`0[Jf]0:^[Z`2h^;P0][Jf0=oOg`38b<P0eMGE0<30`03:b/X0cLg=0;Zj^P0N
0?ooo`040;bl_02n_[h0^KVi0<G5a@80`<3001@0^KVi0<?3``32`/80_[jn0<;2`P2i^KT0aLG50<[:
bP32`/80b/[:0<;2`P2n_[h0bLW90<?3``2n_[h0alO70;jn_P30`<00`/;20;^k^`80`l?301D0aLG5
0<W9b@2n_[h0`l?30<O7a`2i^KT0c/k>0<o?c`39bLT0][Jf0<G5a@37alL0dM7A0=?Cd`39bLT0][Jf
0;2`/02l_;`0clo?0<?3``2i^KT00P2l_;`00`2g]kL0][Jf0;2`/0020<k>cP0B0<[:bP33`l<0b/[:
0;jn_P3Cdm<0aLG50;Vi^@2n_[h0`/;20:^[Z`3:b/X0]kNg0;jn_P2d];@0][Jf0<30`032`/80c<c<
0P2k^k/02@2f][H0_[jn0<G5a@2l_;`0`/;20<G5a@2i^KT0bLW90<o?c`030<O7a`0A0;jn_P37alL0
aLG50<;2`P2g]kL0`<300;Ng]`2[Zj/0]kNg0;Jf]P3Jf]X0`l?30=7Ad@2n_[h0bLW90<k>cP2k^k/0
6@3oool001L0oooo02d0_[jn0;Rh^02h^;P0^[Zj0;>c/`2n_[h0c<c<0<C4a036a/H0b/[:0<;2`P2l
_;`0c<c<0<S8b030`<00b<S80<30`034a<@0_[jn0<c<c02l_;`0];Bd0;Zj^P30`<00a<C40;Zj^P32
`/80^[Zj0<[:bP38b<P0`<300<o?c`2h^;P0_[jn0<o?c`2j^[X0clo?0<S8b03Kfm/0dM7A0;bl_032
`/80];Bd0<C4a036a/H00P3Cdm<01`36a/H0Zj^[0;Zj^P34a<@0[Jf]09^KV`2HV9P00P2n_[h0:@36
a/H0WIfM0<C4a02a/K40cLg=0:NWY`36a/H0`/;20;Bd]02_[jl0][Jf0<C4a02l_;`0WIfM0<30`02j
^[X0_;bl0<;2`P2f][H0[jn_0;Bd]02n_[h0^[Zj0<S8b03UiND0dm?C0=GEe@3<c<`0[jn_0;bl_02Y
ZJT0b<S80=7Ad@38b<P0j>SX0;6a/@34a<@0a/K60;bl_036a/H0^;Rh00<0_[jn00D0cLg=0=GEe@3<
c<`0b/[:0=7Ad@0N0?ooo`070<;2`P2f][H0`<300;jn_P2f][H0`<300<[:bP020<;2`P0X0<[:bP33
`l<0`l?30=7Ad@3>c/h0alO70<k>cP33`l<0`/;20;bl_03>c/h0`<300;Bd]02k^k/0`/;20<G5a@2n
_[h0aLG50;bl_035aLD0b/[:0<;2`P3Fe]H0_[jn0;^k^`3EeMD0^KVi0<c<c035aLD0f][J0<k>cP2k
^k/0`<300;Jf]P37alL0_[jn0<o?c`3>c/h0`/;20:n_[`80`/;200<0[Jf]09jNWP2JVYX00P2n_[h0
4037alL0Xj>S0<c<c02d];@0bLW90:JVYP32`/80`l?30;bl_02XZ:P0];Bd0<;2`P2i^KT0XJ6Q0<?3
``2n_[h20<G5a@0>0;Bd]02`/;00];Bd0;bl_02i^KT0aLG50>;RhP3Cdm<0eMGE0<O7a`2f][H0_[jn
0:ZZZP37alL20=7Ad@070??cl`2d];@0aLG50<O7a`2n_[h0aLG50;Vi^@030;jn_P050<c<c03AdM40
bLW90<O7a`3>c/h06@3oool001L0oooo00`0^[Zj0;6a/@2h^;P0^[Zj0;Bd]032`/80c<c<0<K6aP32
`/80b<S80;Rh^030`<020;Jf]P030;Zj^P30`<00a<C40080^[Zj02<0cLg=0;Rh^02][Jd0^[Zj0;Bd
]02l_;`0_[jn0<;2`P2YZJT0b/[:0;bl_032`/80[jn_0<g=c@2h^;P0/K6a0;Rh^02KVi/0_;bl0:NW
Y`3=cLd0fMWI0<g=c@32`/80clo?0=OGe`2WYjL0Zj^[0<C4a02a/K40`/;20:>SX`2h^;P0_[jn0;Jf
]P020;bl_0080;Jf]P2a/K40_[jn0;jn_P34a<@0^;Rh0<[:bP2l_;`20<[:bP0H0<C4a032`/80/k>c
0:n_[`2n_[h0];Bd0<30`02f][H0];Bd0<C4a02l_;`0`/;20<30`038b<P0_[jn0<C4a02j^[X0_;bl
0<c<c03=cLd0dM7A0;jn_P3?cll0`<300P2j^[X03@30`<00clo?0<o?c`34a<@0`/;20;bl_02j^[X0
a/K60<S8b034a<@0c<c<0;jn_P3:b/X07P3oool01`2l_;`0][Jf0;^k^`2n_[h0^k^k0<30`03>c/h0
0`3:b/X01@2l_;`0aLG50;bl_02l_;`0`<300080alO70P2l_;`01@3?cll0_;bl0:n_[`2l_;`0^k^k
0080`/;201`0aLG50:f][@35aLD0`<300<?3``2b/[80clo?0<30`02_[jl0]kNg09jNWP2k^k/0ZZZZ
0<c<c03Fe]H0c<c<0<;2`P3>c/h0c<c<0;2`/02[Zj/0b/[:0;Ng]`32`/80Z:RX0;^k^`30`<00^KVi
0P2l_;`00`2i^KT0];Bd0<30`0020<G5a@050;^k^`3?cll0^k^k0=GEe@37alL00P30`<006@2i^KT0
/[:b0;jn_P2f][H0`<300;Vi^@30`<00`l?30;^k^`30`<00_[jn0<G5a@2l_;`0`/;20;Vi^@2n_[h0
bLW90<[:bP3>c/h0`l?30=7Ad@2n_[h0^k^k0;Ng]`2l_;`00P3?cll02P33`l<0`/;20;jn_P2l_;`0
aLG50<O7a`32`/80bLW90;bl_037alLI0?ooo`005`3oool02`2f][H0a/K60<C4a02KVi/0a<C40<30
`02n_[h0a/K60<[:bP38b<P0b/[:0080^;Rh01L0^[Zj0<S8b034a<@0`/;20;jn_P30`<00b<S80;6a
/@2h^;P0a<C40;Bd]02j^[X0b/[:0;jn_P2c/k<0^[Zj0<30`036a/H0fm_K0<C4a02l_;`0fMWI0:VY
Z@030;bl_00G0<[:bP2d];@0/K6a0<K6aP2l_;`0];Bd0<c<c030`<00][Jf0<30`03=cLd0^[Zj0;Rh
^02a/K40_;bl0;Bd]02n_[h0/K6a0;jn_P2@T900^[Zj0<[:bP32`/800P36a/H04030`<00/K6a0<K6
aP3=cLd0][Jf092@T036a/H0_;bl0<30`036a/H0YjNW0;Rh^036a/H0`/;20<K6aP3Cdm<20=7Ad@0G
0;jn_P34a<@0cLg=0;Rh^02_[jl0_[jn0<K6aP34a<@0/K6a0<;2`P2d];@0cLg=0;>c/`3Cdm<0][Jf
0<;2`P2l_;`0`<300<;2`P3<c<`0b<S80<;2`P2l_;`07P3oool0402n_[h0alO70<;2`P2QXJ40bLW9
0<;2`P30`<00alO70<[:bP33`l<0aLG50;^k^`2n_[h0_;bl0<W9b@30`<020;jn_P0/0<30`03:b/X0
];Bd0;Ng]`32`/80][Jf0;^k^`3:b/X0_[jn0;^k^`2n_[h0`<300<G5a@3Fe]H0alO70<G5a@3Jf]X0
Z:RX0;bl_030`<00`l?30<W9b@2g]kL0][Jf0<?3``2l_;`0][Jf0<O7a`32`/80^k^k0<;2`P39bLT0
]kNg0;^k^`2_[jl0^KVi0;Bd]030`<00/[:b0;jn_P2GUiL0_;bl0<O7a`30`<020<?3``0@0<;2`P2b
/[80`l?30<[:bP2g]kL0UIFE0<W9b@2l_;`0`<300<G5a@2ZZZX0^KVi0<;2`P2n_[h0`/;20<k>cP80
clo?01L0_[jn0<c<c03>c/h0^k^k0;:b/P30`<00b/[:0<W9b@2i^KT0`/;20;Jf]P3?cll0];Bd0<k>
cP2f][H0`l?30;jn_P32`/80_[jn0<[:bP37alL0`/;20;bl_00I0?ooo`005`3oool06@38b<P0^[Zj
0:f][@2n_[h0a<C40=GEe@34a<@0];Bd0;>c/`30`<00^[Zj0<;2`P36a/H0_;bl0;jn_P34a<@0`<30
0<K6aP2l_;`0^[Zj0=7Ad@3<c<`0`<300<;2`P38b<P00P2f][H03@3:b/X0c<c<0;jn_P2c/k<0V9RH
0:^[Z`2l_;`0/k>c09nOW`2<S8`0Vi^K08B4Q02DU9@00P30`<001`3=cLd0dM7A0<C4a034a<@0`<30
0:VYZ@2UYJD00P2l_;`0702h^;P0c<c<0:NWY`2][Jd0`<300<g=c@32`/80b<S80;6a/@2d];@0_;bl
0<[:bP3<c<`0cLg=0<[:bP2_[jl0b<S80;Jf]P2][Jd0_;bl0;Rh^030`<00^[Zj0;>c/`2YZJT0[Jf]
0;6a/@2h^;P20<30`00H0;Bd]02n_[h0_[jn0<c<c03:b/X0ZJVY0<S8b03<c<`0b<S80<;2`P0c<c<0
/k>c0<30`036a/H0[jn_0<g=c@30`<00c<c<0<30`03?cll0cLg=0<c<c03=cLd0_[jn7P3oool0=@37
alL0_;bl0:n_[`2l_;`0`<300=SHf035aLD0^KVi0;^k^`37alL0`/;20<?3``37alL0_;bl0<?3``35
aLD0`/;20<O7a`39bLT0^k^k0=?Cd`37alL0_[jn0<?3``35aLD0][Jf0;jn_P3:b/X0dM7A0;^k^`2d
];@0WYjN0:n_[`32`/80_;bl09jNWP2>SXh0W9bL08N7Q`2JVYX0bLW90<30`03<c<`0clo?0<;2`P30
`<00^k^k0:f][@2VYZH0^KVi0<30`02g]kL0b/[:0080Zj^[00P0`/;20<[:bP33`l<0`/;20:n_[`2g
]kL0_[jn0<O7a`80bLW90140aLG50;:b/P33`l<0^KVi0:n_[`2n_[h0^KVi0<W9b@2g]kL0][Jf0:^[
Z`2_[jl0/[:b0;Vi^@2n_[h0`<300;Jf]P020;jn_P0@0<W9b@37alL0ZZZZ0<W9b@3>c/h0`l?30;jn
_P0`<300/;2`0<;2`P37alL0/;2`0<c<c033`l<0c/k>0<30`0<0c/k>00<0clo?0<;2`P3oool0603o
ool001L0oooo01<0/k>c0<;2`P34a<@0^;Rh0;Bd]02QXJ40b/[:0<;2`P2UYJD0[Jf]0;jn_P3IfMT0
/k>c0<;2`P30`<00cLg=0<[:bP2n_[h0`<300080_[jn00T0][Jf0;bl_02h^;P0`<300;bl_02KVi/0
a<C40<30`034a<@00P38b<P0;`2l_;`0_[jn0;>c/`36a/H0hN7Q0<;2`P34a<@0/K6a0<;2`P2SXj<0
UYJF09RHV02c/k<0b/[:0<C4a02h^;P0`<300;6a/@32`/80_;bl0<c<c02][Jd0`/;20;6a/@2_[jl0
_[jn0;Bd]038b<P0[jn_0<;2`P3IfMT0b<S80;>c/`2QXJ40][Jf0;Zj^P2d];@0[Jf]0;Rh^02d];@0
a/K60=7Ad@36a/H0c<c<0<C4a038b<P0];Bd0080b<S800h0eMGE0<30`036a/H0_;bl0<[:bP36a/H0
cLg=0<[:bP38b<P0`/;20;Rh^02f][H0/k>c0;bl_080^;Rh00P0cLg=0<o?c`2h^;P0a/K609BDU03?
cll0[jn_0;jn_Qh0oooo00<0][Jf0<30`030`<000P2g]kL0:02ZZZX0c<c<0<G5a@2[Zj/0[jn_0<30
`03Hf=P0`<300<?3``32`/80dm?C0<;2`P2n_[h0`<300;bl_037alL0^KVi0;jn_P30`<00`/;20<[:
bP2OWil0`l?30<30`033`l<0clo?0;jn_P2k^k/0aLG50;:b/P33`l<0fm_K0<30`032`/80/;2`0<30
`02TY:@0W9bL09jNWP2f][H20<[:bP0j0;jn_P33`l<0[jn_0<G5a@30`<00alO70:f][@33`l<0];Bd
0;:b/P30`<00];Bd0<G5a@2b/[80_[jn0=?Cd`33`l<0^k^k0:^[Z`2i^KT0_;bl0;Vi^@2_[jl0]kNg
0:f][@32`/80c<c<0<;2`P37alL0`/;20<G5a@2d];@0b/[:0<G5a@3Cdm<0`/;20<O7a`2n_[h0b/[:
0<O7a`3EeMD0bLW90<O7a`32`/80]kNg0;Jf]P2d];@0_;bl0;^k^`2n_[h0c<c<0<k>cP2l_;`0aLG5
09FEU@3:b/X0/[:b0<?3`aT0oooo000G0?ooo`80^[Zj00d0_;bl0;Zj^P2j^[X0^[Zj0=WIf@2n_[h0
clo?0;Zj^P2h^;P0o?cl0;Rh^02l_;`0cLg=00<0_[jn00<0^[Zj0:VYZ@30`<000P2n_[h01@38b<P0
dM7A0:NWY`2][Jd0][Jf0080a/K600<0`<300;jn_P2n_[h00P2d];@0102][Jd0`/;20;Zj^P2j^[X2
0<;2`P0D0:VYZ@2h^;P0dM7A0=?Cd`2h^;P0/k>c0;bl_034a<@0Jf][0;6a/@2j^[X0XJ6Q0:f][@3G
emL0`/;20;Zj^P2d];@0`<300<C4a02j^[X20<C4a00=0<[:bP2c/k<0clo?0;Rh^036a/H0a<C40:FU
Y@2n_[h0_;bl0;jn_P2d];@0YjNW0<;2`P020<C4a00E0;jn_P30`<00/k>c0;jn_P3GemL0dM7A0;Jf
]P38b<P0a/K60<o?c`30`<00b<S80<30`03<c<`0clo?0;bl_034a<@0`<300;>c/`2[Zj/0_[jn0080
^;Rh00@0];Bd0<S8b03<c<`0];Bd7P3oool05@2l_;`0`<300;Vi^@2i^KT0_;bl0;jn_P3Hf=P0`<30
0<o?c`2n_[h0^k^k0?ooo`32`/80_[jn0<k>cP35aLD0`<300<?3``30`<00[Jf]0<W9b@020<30`00:
0<W9b@3AdM40Zj^[0:f][@2g]kL0aLG50<o?c`33`l<0alO70<?3``80];Bd00@0/;2`0<?3``2l_;`0
^KVi0P33`l<01P2][Jd0^KVi0<c<c03>c/h0][Jf0;:b/P80`l?301X0LG5a0:n_[`2g]kL0Y:BT0:RX
Z03AdM40`<300;bl_02g]kL0`/;20<G5a@2n_[h0aLG50<;2`P37alL0]kNg0=7Ad@2k^k/0alO70<G5
a@2TY:@0`<300;Ng]`2n_[h0][Jf0:ZZZP<0`/;201/0_;bl0<30`02g]kL0`<300=7Ad@3<c<`0^KVi
0<W9b@37alL0dM7A0<30`037alL0`<300<c<c03?cll0_;bl0<?3``2k^k/0/[:b0:f][@2n_[h0_;bl
0;Vi^@2f][H0alO70<W9b@2g]kL06@3oool001L0oooo00D0c<c<0<S8b02a/K40a<C40<c<c0020;Rh
^00?0<o?c`36a/H0b/[:0<;2`P30`<00^[Zj0<K6aP34a<@0`<300<;2`P2OWil0Zj^[0<K6aP2h^;P0
/K6a0080`/;200h0a<C409RHV03QhN40`/;20<C4a036a/H0b/[:0<;2`P2j^[X0a<C40<30`02j^[X0
YJFU0<g=c@80a<C40440a/K60;Jf]P2l_;`0];Bd0=GEe@38b<P0Ng]k0:n_[`2a/K40b<S80;jn_P2j
^[X0][Jf0:FUY@3Cdm<0`/;20:NWY`3=cLd0YjNW0;>c/`3GemL0_;bl0<[:bP2a/K40a/K60<C4a02n
_[h0a<C40;Zj^P2UYJD0a<C40;Jf]P3:b/X0b<S80<K6aP32`/80dm?C0<C4a030`<00a/K60<S8b034
a<@0dm?C0;bl_02YZJT0`/;20<c<c032`/80b<S80<o?c`3Cdm<0`<300<c<c036a/H0`<300<S8b02d
];@0a/K60<g=c@34a<@0R8R80;bl_034a<@0b<S80<C4a00N0?ooo`80c<c<0140]kNg0<W9b@3?cll0
`/;20;Ng]`3<c<`0`l?30<[:bP33`l<0b/[:0;bl_02n_[h0`l?30;bl_02n_[h0Y:BT0:n_[`020<;2
`P060;Bd]037alL0aLG50<G5a@2OWil0fm_K0P35aLD01039bLT0c<c<0<?3``2k^k/20<;2`P0M0;bl
_02ZZZX0c/k>0<O7a`33`l<0aLG50;Ng]`2l_;`0][Jf0=GEe@3?cll0PX:20;:b/P2d];@0bLW90<30
`02l_;`0]kNg0:RXZ03Jf]X0`/;20:^[Z`3>c/h0Z:RX0;Bd]03Fe]H0_[jn0;bl_02d];@00P32`/80
9`2k^k/0aLG50;^k^`2XZ:P0aLG50;Vi^@3:b/X0alO70<?3``32`/80clo?0<30`02l_;`0bLW90<G5
a@32`/80clo?0;bl_02ZZZX0`<300<W9b@32`/80bLW90<o?c`3Cdm<0`/;20<[:bP33`l<0_[jn0<O7
a`2f][H0aLG50<c<c033`l<0SXj>0;bl_033`l<0alO70<?3``0I0?ooo`005`3oool0=P2c/k<0ZJVY
0;6a/@30`<00_;bl0;Jf]P38b<P0a/K60;jn_P2DU9@0b<S80<C4a02h^;P0`/;20:NWY`34a<@0`<30
0<c<c02n_[h0];Bd0;Jf]P38b<P0cLg=0=oOg`2l_;`0[Jf]0;Jf]P2n_[h0a<C40;bl_02IVIT0][Jf
0<c<c030`<00c<c<0<o?c`2IVIT0/k>c0;Zj^P2h^;P0a/K60<c<c02d];@0a/K60<;2`P2c/k<0PX:2
0;jn_P36a/H0/k>c0;Zj^P30`<00^[Zj0;Bd]080`/;20340clo?0<30`02c/k<0emOG0;Rh^03Shn<0
dM7A0<c<c03=cLd0clo?0<[:bP3=cLd0];Bd0:f][@32`/80_[jn0=?Cd`2j^[X0^;Rh0;6a/@2c/k<0
];Bd0;Zj^P36a/H0_;bl0<;2`P3<c<`0_[jn0<o?c`2][Jd0c<c<0<[:bP34a<@0b<S80<C4a02h^;P0
VIVI0;>c/`2h^;P0`/;20<c<c02h^;P0Vi^K0:VYZ@36a/H0b/[:0:^[Z`2h^;P0/k>c01h0oooo00@0
_;bl0:f][@2d];@0`/;20P2n_[h05@39bLT0alO70<30`02LW9`0b/[:0<O7a`2k^k/0`/;20:ZZZP37
alL0`/;20<c<c030`<00];Bd0;Ng]`35aLD0b/[:0=_Kf`2n_[h0/;2`0;Ng]`020<30`00I0;^k^`2Q
XJ40]kNg0<[:bP30`<00c/k>0=KFeP2ZZZX0`<300;jn_P2k^k/0alO70<c<c02g]kL0alO70<30`02f
][H0QhN70;jn_P35aLD0];Bd0;Ng]`2l_;`0]kNg0;Jf]P020<?3``070<k>cP30`<00/[:b0=GEe@2d
];@0inOW0=7Ad@020<c<c00X0<k>cP37alL0b/[:0;Ng]`2`/;00`/;20;jn_P3?cll0^KVi0;Ng]`2d
];@0/;2`0;:b/P2g]kL0`l?30;bl_032`/80b/[:0<?3``3:b/X0[jn_0<k>cP39bLT0_[jn0<;2`P2n
_[h0]kNg09jNWP2d];@0_[jn0<?3``3<c<`0]kNg09jNWP2TY:@0aLG50<W9b@2_[jl0_[jn0;Jf]QT0
oooo000G0?ooo`0<0=7Ad@2n_[h0a<C40;Zj^P2c/k<0_;bl0<[:bP3?cll0_;bl0<K6aP38b<P0b/[:
0P2l_;`01036a/H0^[Zj0<C4a02f][H20;Zj^P0I0<c<c038b<P0`<300;Rh^036a/H0_[jn0:n_[`2j
^[X0c<c<0<S8b02h^;P0c<c<0;jn_P30`<00clo?0=_Kf`38b<P0_[jn09VIV@2_[jl0/k>c0;Zj^P2S
Xj<0];Bd0;6a/@020=7Ad@0j0:NWY`3?cll0_;bl0:f][@2l_;`0[jn_08R8R02<S8`0Zj^[0<g=c@2a
/K40[Jf]0<K6aP3=cLd0`<300<[:bP2h^;P0_[jn0<o?c`2n_[h0b<S80<30`02d];@0c<c<0<C4a02n
_[h0[Jf]0<30`02j^[X0/k>c0;Jf]P2a/K40_;bl0<S8b02l_;`0`/;20;jn_P3Cdm<0];Bd0;>c/`2l
_;`0c<c<0<K6aP3AdM40_[jn0<o?c`32`/80[jn_0<c<c03IfMT0][Jf0:n_[`2UYJD0^[Zj0;Rh^02j
^[X0`/;20;Jf]Qh0oooo0140f=SH0<30`035aLD0_;bl0;Ng]`2n_[h0alO70=GEe@3:b/X0alO70<W9
b@3<c<`0`<300;jn_P3?cll0_[jn0<O7a`020;bl_00=0;^k^`3:b/X0`/;20<G5a@2i^KT0aLG50;jn
_P2`/;00_;bl0<O7a`35aLD0]kNg0<o?c`020<;2`P0X0<O7a`3Hf=P0bLW90<G5a@2VYZH0/;2`0;Jf
]P30`<00Z:RX0;Bd]02b/[80dM7A0<k>cP2VYZH0b/[:0;Vi^@2ZZZX0^k^k0:f][@2;Rh/0TY:B0:f]
[@3<c<`0/[:b0:n_[`35aLD0clo?0<O7a`39bLT0^KVi0<30`03>c/h0^k^k0<G5a@30`<00][Jf0<[:
bP33`l<0^k^k0:^[Z`80_;bl0P2f][H06`2_[jl0^k^k0<W9b@2k^k/0`<300<?3``3>c/h0/[:b0;2`
/02k^k/0c<c<0<O7a`3AdM40^k^k0<[:bP32`/80Z:RX0<c<c03EeMD0`<300;:b/P2ZZZX0^k^k0;Vi
^@2k^k/0`l?30;Vi^@0I0?ooo`005`3oool03@3=cLd0a<C40<;2`P2c/k<0[Jf]0<o?c`38b<P0b/[:
0<C4a02l_;`0clo?0;bl_02d];@00P2j^[X04@32`/80clo?0;Jf]P3:b/X0dm?C0<c<c02l_;`0b<S8
0<30`02n_[h0^[Zj0<[:bP2j^[X0eMGE0<;2`P30`<00a/K60080dm?C0P3GemL02`34a<@0][Jf0;6a
/@2_[jl0clo?0:FUY@2c/k<0UYJF0;jn_P2c/k<0^[Zj0080`<3000/0_;bl09BDU02f][H0^;Rh0:^[
Z`2f][H0_;bl0<S8b02h^;P0i^KV0<C4a0020<30`00C0<C4a036a/H0a/K60<K6aP2h^;P0b/[:0;Jf
]P2c/k<0b<S80;Rh^02j^[X0][Jf0:>SX`34a<@0b<S80<K6aP2d];@0c<c<0;bl_0020<30`00F0:f]
[@3=cLd0b<S80<o?c`3:b/X0_[jn0<S8b03?cll0_;bl0<S8b034a<@0/K6a0;bl_030`<00a<C40;Zj
^P2SXj<0a/K60<;2`P2l_;`0a<C40<30`1h0oooo02l0bLW90<G5a@33`l<0][Jf0;:b/P3?cll0dM7A
0<c<c033`l<0_[jn0<o?c`2n_[h0]kNg0<30`02l_;`0`l?30<o?c`2k^k/0b/[:0=?Cd`3<c<`0bLW9
0<[:bP35aLD0`l?30;^k^`39bLT0_;bl0<o?c`33`l<0_;bl0<[:bP3EeMD0dm?C0=GEe@3Rh^80c<c<
0;jn_P2`/;00[Jf]0<c<c02XZ:P0/;2`09RHV02n_[h0][Jf0;Vi^@020<;2`P0P0;jn_P2GUiL0_[jn
0;bl_02`/;00^k^k0<30`037alL0^KVi0>;RhP33`l<0^KVi0;bl_033`l<0aLG50<O7a`35aLD0][Jf
0<O7a`2g]kL0];Bd0<O7a`2i^KT0^k^k0;Ng]`2VYZH0aLG50<O7a`33`l<0/[:b0<o?c`2n_[h20<;2
`P030;2`/039bLT0`l?30080b/[:00@0_;bl0<G5a@3<c<`0_[jn0P33`l<02`2ZZZX0^KVi0<30`039
bLT0^k^k0:f][@3:b/X0`l?30;jn_P3<c<`0bLW901T0oooo000G0?ooo`0N0;jn_P2j^[X0c<c<0<;2
`P36a/H0`/;20<30`02n_[h0`/;20;6a/@36a/H0`/;20;Bd]03<c<`0`<300;bl_03?cll0_[jn0<C4
a032`/80c<c<0<o?c`2l_;`0Vi^K0<C4a030`<00Zj^[0;jn_P38b<P0_[jn0P30`<005@36a/H0ZJVY
0:n_[`2OWil0/K6a0;Rh^03Ogml0a/K60;Jf]P2[Zj/0^;Rh0;bl_03?cll0];Bd0<;2`P36a/H0b<S8
0:n_[`30`<00hN7Q0<;2`P020;Rh^00M0;Zj^P3:b/X0][Jf0<[:bP2j^[X0];Bd0<[:bP38b<P0a<C4
0=7Ad@34a<@0^[Zj0<[:bP34a<@0/K6a0>KViP2c/k<0b<S80<o?c`2f][H0`<300<C4a036a/H0`<30
0;jn_P3:b/X0`<300:VYZ@36a/H00P3:b/X03P3=cLd0][Jf0<g=c@3Cdm<0_;bl0:n_[`32`/80];Bd
0<S8b03GemL0b<S809JFUP2d];@0dm?C0P2a/K400`2[Zj/0`<300<;2`P0N0?ooo`0>0<O7a`2l_;`0
alO70;jn_P32`/80b/[:0<?3``30`<00`l?30;:b/P37alL0`/;20;Jf]P3:b/X20<30`0030=7Ad@30
`<00`l?30080bLW900X0clo?0;jn_P2LW9`0_[jn0<;2`P2_[jl0aLG50<W9b@2n_[h0`<300P37alL0
2@2][Jd0/[:b09nOW`2`/;00]kNg0=oOg`32`/80^KVi0:^[Z`020;^k^`0:0<c<c02d];@0aLG50<k>
cP39bLT0/;2`0<G5a@3MgMd0`/;20;Jf]P80^k^k01/0aLG50;Jf]P39bLT0^k^k0;Jf]P39bLT0alO7
0<?3``3?cll0`l?30;bl_035aLD0`<300;2`/03Rh^80];Bd0<W9b@3?cll0^KVi0<;2`P30`<00`/;2
0;bl_030`<00alO70;jn_P2ZZZX00`37alL04`3:b/X0^KVi0<c<c03AdM40_;bl0:n_[`30`<00][Jf
0<O7a`3AdM40`l?309jNWP2i^KT0clo?0;2`/02b/[80[Jf]0<30`032`/806@3oool001L0oooo00H0
^;Rh0;Zj^P2f][H0Zj^[0;Rh^030`<020<;2`P050;jn_P2d];@0`<300<30`02l_;`00P3:b/X00`2_
[jl0_[jn0<C4a0020<S8b0080<30`02_[jl0][Jf0<c<c03=cLd0b<S809nOW`2h^;P20<K6aP0`0<[:
bP2j^[X0YJFU0;jn_P2a/K40YJFU0:f][@2UYJD0^;Rh0;jn_P2f][H0[jn_0;Zj^P36a/H0a<C40<c<
c02h^;P0/k>c0<S8b03MgMd0^[Zj0<c<c028R8P0_;bl0<C4a03:b/X0`<300<S8b036a/H0c<c<0;Jf
]P34a<@0][Jf0=?Cd`32`/80c<c<0<K6aP3AdM40fMWI0;Zj^P2h^;P0^[Zj0<30`02YZJT0/k>c0<[:
bP2MWId0b/[:0P2j^[X06@2f][H0eMGE0:f][@2h^;P0cLg=0;Rh^02j^[X0/K6a0<c<c03Cdm<0Zj^[
0<c<c03:b/X0clo?0<30`034a<@0][Jf0<S8b030`<00a/K60<g=c@2j^[X0a<C40<g=c@3:b/X07P3o
ool01P2i^KT0_;bl0;Bd]02[Zj/0^k^k0<;2`P80_[jn01`0^k^k0;Vi^@32`/80`/;20;jn_P3<c<`0
aLG50;Bd]032`/80alO70<[:bP39bLT0`/;20;Bd]02n_[h0c<c<0<k>cP37alL0Xj>S0;Ng]`33`l<0
aLG50<W9b@32`/80[jn_0<;2`P2b/[80XJ6Q0P2`/;001P32`/80_;bl0;Jf]P2_[jl0]kNg0<W9b@80
alO70200][Jf0;Ng]`39bLT0fm_K0<G5a@3:b/X0T92@0;jn_P35aLD0b/[:0<30`039bLT0`l?30<W9
b@2g]kL0`l?30;Vi^@3Cdm<0`l?30<[:bP3>c/h0f=SH0=KFeP2k^k/0/;2`0;Jf]P2n_[h0Zj^[0;Jf
]P39bLT0XJ6Q0<W9b@80^k^k00/0_;bl0=KFeP2`/;00^KVi0<c<c02k^k/0`/;20;Bd]03:b/X0dM7A
0:f][@020<[:bP0<0<k>cP30`<00aLG50;^k^`35aLD0_[jn0<O7a`39bLT0^k^k0<?3``3<c<`0b/[:
6@3oool001L0oooo00P0b<S80;bl_02j^[X0b<S80<30`02SXj<0/k>c0<K6aP80_;bl00/0b/[:0<;2
`P32`/80b<S80;jn_P2a/K40_[jn0<S8b03?cll0`<300;Jf]P020<;2`P040<S8b03<c<`0clo?0:^[
Z`80^;Rh01H0/k>c0<30`02f][H0`<300<[:bP36a/H0Xj>S0;Bd]02[Zj/0];Bd0;jn_P36a/H0V9RH
0:f][@2[Zj/0`<300;bl_038b<P0YjNW0;Rh^030`<00b<S80P2f][H0=02d];@0a/K60;jn_P2j^[X0
_[jn0;bl_036a/H0`<300<;2`P3?cll0OGem0<g=c@2[Zj/0cLg=0=GEe@2f][H0];Bd0<[:bP2KVi/0
_[jn0=7Ad@2h^;P0_[jn0<30`034a<@0cLg=0<[:bP2j^[X0a<C40<[:bP2h^;P0_;bl0<K6aP3=cLd0
a<C40<30`02a/K40ZJVY0<30`034a<@0clo?0=7Ad@3?cll0/k>c0:n_[`2f][H0_;bl0;Bd]030`<00
cLg=0=GEe@36a/HN0?ooo`80bLW900T0_[jn0<[:bP33`l<0YZJV0;^k^`3<c<`0`l?30;jn_P3<c<`0
0P33`l<0G039bLT0`<300;Vi^@35aLD0bLW90<o?c`30`<00`l?30<30`033`l<0bLW90<c<c03Fe]H0
];Bd0;^k^`2g]kL0/;2`0<;2`P2k^k/0`l?30<c<c039bLT0YZJV0;Jf]P2][Jd0]kNg0<G5a@39bLT0
WYjN0:n_[`2[Zj/0_[jn0;^k^`37alL0Zj^[0;^k^`2n_[h0`l?30;Bd]02i^KT0]kNg0<G5a@2n_[h0
_;bl0<30`032`/80b/[:0<;2`P33`l<0clo?08:2PP39bLT0[Jf]0<[:bP3Cdm<0]kNg0;Jf]P39bLT0
WinO0;bl_03?cll0^k^k0;jn_P30`<00`l?30<c<c037alL0_[jn0<O7a`3<c<`0_[jn0;bl_035aLD0
c<c<0<G5a@32`/80];Bd0:f][@2l_;`0alO70<k>cP3?cll0c<c<0;:b/P2`/;00^KVi0;jn_P2g]kL0
`/;20<k>cP3Cdm<0alO76@3oool001L0oooo00@0[jn_0;Rh^030`<00^;Rh0P38b<P02034a<@0Zj^[
0:^[Z`30`<00`/;20<S8b030`<00`/;20P2n_[h0;@34a<@0clo?0<o?c`2j^[X0`<300<S8b02l_;`0
a/K60<C4a02h^;P0ZJVY0;>c/`36a/H0^;Rh0;jn_P2f][H0c<c<0<o?c`2UYJD0`<300;jn_P2d];@0
dM7A0;>c/`38b<P0clo?0:n_[`2][Jd0dm?C0;Bd]036a/H0^;Rh0<30`03IfMT0][Jf0;>c/`2n_[h0
YjNW0;Bd]034a<@0^[Zj0<S8b03Cdm<0b/[:0=oOg`020;6a/@030:^[Z`3=cLd0[jn_0080dm?C0P2j
^[X03P2a/K40YjNW0<C4a034a<@0Zj^[0;Rh^02n_[h0[Jf]0:FUY@2j^[X0[Jf]0<[:bP2YZJT0`/;2
0P34a<@04`2h^;P0b<S80;jn_P30`<00b<S80;bl_030`<00cLg=0<K6aP38b<P0b/[:0;6a/@32`/80
a<C40<K6aP3<c<`0^[Zj0<c<c03Ogml07P3oool01`2b/[80^k^k0<c<c02i^KT0aLG50<W9b@37alL0
0P2`/;001@32`/80`<300<W9b@32`/80`l?30080`<3000L0aLG50<c<c03EeMD0_;bl0<;2`P3<c<`0
_[jn00<0`/;202X0Zj^[0;2`/035aLD0_;bl0<;2`P2l_;`0c<c<0<o?c`2[Zj/0bLW90<30`02g]kL0
dM7A0;^k^`3:b/X0clo?0;Vi^@2`/;00dm?C0;Ng]`33`l<0]kNg0;jn_P3EeMD0]kNg0;Bd]02n_[h0
ZZZZ0;jn_P33`l<0^KVi0<G5a@3Cdm<0b/[:0=[JfP2d];@0_[jn0:f][@3>c/h0/[:b0=KFeP3EeMD2
0;^k^`0=0;Bd]02VYZH0`<300<?3``2_[jl0_[jn0<30`02`/;00ZZZZ0;bl_02`/;00bLW90:ZZZP03
0<?3``0<0;Vi^@33`l<0`<300<30`035aLD0_;bl0<30`03>c/h0alO70<W9b@3:b/X0/[:b0P32`/80
1@35aLD0dm?C0;Vi^@39bLT0f][J01T0oooo000G0?ooo`070<30`02d];@0`/;20<;2`P34a<@0];Bd
0;Jf]P020;6a/@0:0<S8b03<c<`0a/K60<;2`P2d];@0a<C40;Zj^P3:b/X0_;bl0<30`080_[jn00H0
`/;20<g=c@3:b/X0_[jn0;bl_02h^;P20<C4a00h0;Rh^038b<P0`<300;Zj^P34a<@0b<S80:VYZ@2U
YJD0^[Zj0<30`02c/k<0b/[:092@T032`/80_[jn0:f][@2j^[X0];Bd0;jn_P2h^;P0`<300;Bd]032
`/80ZJVY0;>c/`34a<@0`<300<C4a03QhN40emOG0<[:bP2d];@0^[Zj0:f][@2l_;`0Zj^[0<C4a02h
^;P0][Jf0<c<c02l_;`0b<S80;jn_P38b<P0_[jn0:f][@32`/80b/[:0<30`03Cdm<0`<300<g=c@36
a/H0c<c<0;bl_02WYjL30<o?c`0A0<30`02l_;`0a/K60<C4a02n_[h0dM7A0:n_[`3AdM40c<c<0;Rh
^03?cll0cLg=0<K6aP2j^[X0_;bl0<g=c@3:b/X07P3oool01`30`<00/[:b0<?3``33`l<0aLG50;Bd
]02g]kL00P2b/[804P37alL0b/[:0<G5a@32`/80]kNg0<G5a@2g]kL0c<c<0<G5a@39bLT0alO70<;2
`P2l_;`0alO70<W9b@2n_[h0`<300;Vi^@80`l?300d0]kNg0<G5a@37alL0_;bl0<;2`P33`l<0Zj^[
0:RXZ02i^KT0`/;20;Vi^@3<c<`0UiNG0080_[jn03d0[jn_0;^k^`2g]kL0`<300;Jf]P30`<00][Jf
0<30`02XZ:P0/;2`0<?3``2k^k/0clo?0=[JfP3Fe]H0bLW90;:b/P2k^k/0/;2`0;jn_P2_[jl0aLG5
0<;2`P30`<00b/[:0;bl_039bLT0`<300<G5a@2l_;`0[Jf]0<;2`P35aLD0_;bl0<k>cP32`/80clo?
0<W9b@37alL0_;bl0:n_[`3?cll0b/[:0=?Cd`30`<00_;bl0<G5a@33`l<0_[jn0<k>cP2_[jl0clo?
0<[:bP2i^KT0c/k>0<G5a@33`l<0^k^k0;bl_03:b/X0alO701T0oooo000G0?ooo`0A0;jn_P2[Zj/0
a/K60<C4a02f][H0a<C40;Jf]P2h^;P0`/;20<30`038b<P0a<C40;Bd]02h^;P0_[jn0;Zj^P2n_[h0
0P32`/802P2h^;P0cLg=0;jn_P38b<P0SXj>0;jn_P2l_;`0Zj^[0;Jf]P36a/H20<30`0080<K6aP2h
^;P0`<300<30`034a<@0_[jn0<;2`P2j^[X20<;2`P0R0:>SX`2_[jl0[Jf]0;>c/`2SXj<0^[Zj09VI
V@2a/K40^[Zj0<;2`P2c/k<0c<c<0:FUY@1TI6@0^[Zj0<30`01cLg<0_[jn0<K6aP2f][H0`/;20:f]
[@3=cLd0`<300:f][@2f][H0Zj^[0<C4a02l_;`0[jn_0;Bd]034a<@0_;bl0<S8b080clo?01`0][Jf
0<C4a03=cLd0_[jn0<;2`P30`<00gMgM0:6QX@3<c<`0dM7A0<;2`P2j^[X0a/K60;6a/@38b<P0a<C4
0;jn_P3QhN40dm?C09nOW`2d];@0`/;20:n_[`2KVi/0^;Rh0;>c/`36a/H0clo?7P3oool04@2n_[h0
[jn_0<?3``32`/80][Jf0<?3``2d];@0^KVi0<?3``35aLD0bLW90<O7a`2i^KT0^k^k0<;2`P2k^k/0
_;bl0080`/;200X0]kNg0<k>cP2n_[h0bLW909:BTP2l_;`0^k^k0:f][@2g]kL0aLG50P32`/80<@37
alL0^KVi0;jn_P2l_;`0`l?30;jn_P32`/80^KVi0<30`032`/80Z:RX0;Bd]02_[jl0];Bd0:JVYP2l
_;`0WYjN0;Bd]02l_;`0_[jn0;2`/037alL0YZJV06YZJP2k^k/0`/;207]kN`2i^KT0aLG50;Jf]P2n
_[h0/;2`0<[:bP32`/80/;2`0;Jf]P2[Zj/0aLG50;jn_P2`/;00];Bd0<30`02k^k/0aLG50<c<c03A
dM40^KVi0<G5a@3<c<`00P33`l<02P32`/80f=SH0:6QX@37alL0c<c<0<30`02k^k/0aLG50;:b/P35
aLD20<;2`P0;0>7Qh@3:b/X0WinO0;Ng]`30`<00[Jf]0:>SX`2f][H0]kNg0<?3``3<c<`06@3oool0
01L0oooo0P34a<@0EP2][Jd0^;Rh0;6a/@2l_;`0^;Rh0;bl_030`<00b<S80<C4a03<c<`0_[jn0;Zj
^P30`<00_;bl0<30`038b<P0`<300<c<c02a/K40_[jn0=?Cd`2f][H0^[Zj0;Jf]P2h^;P0^[Zj0<[:
bP30`<00b<S80;Bd]03:b/X0_[jn0<S8b03:b/X0`<300<[:bP2f][H0^;Rh0;Jf]P32`/80clo?0<K6
aP2UYJD0`/;20=GEe@2_[jl0_[jn0;Rh^02n_[h0_;bl0;Bd]032`/80][Jf0;bl_03Ogml0];Bd0<K6
aP2h^;P0c<c<0<[:bP3=cLd0a<C40<g=c@30`<00`/;20;jn_P36a/H0];Bd0;Zj^P36a/H0[Jf]0<C4
a030`<00a<C40;bl_036a/H0WinO0<g=c@34a<@0`/;20<o?c`3Cdm<0][Jf0;bl_034a<@0eMGE0`36
a/H03P30`<00];Bd0<S8b02c/k<0b<S80<30`03AdM40a<C40<;2`P2d];@0a<C40;bl_03?cll0^;Rh
7P3oool00`30`<00aLG50;2`/0020<30`00l0<G5a@2l_;`0_[jn0<;2`P3AdM40alO70<k>cP37alL0
_;bl0;jn_P2i^KT0_;bl0<c<c035aLD0c<c<0;Bd]02l_;`0dm?C0;^k^`2n_[h0]kNg0;Vi^@2l_;`0
c<c<0<30`037alL0]kNg0<c<c035aLD0bLW90<O7a`32`/80b/[:0;Ng]`2l_;`0^k^k0;jn_P3?cll0
`l?30:JVYP30`<00clo?0;2`/02n_[h0^KVi0<30`02n_[h0[jn_0;jn_P2i^KT0_[jn0=_Kf`2f][H0
alO70;^k^`37alL0aLG50<k>cP33`l<0bLW90P2n_[h05@2k^k/0aLG50;Jf]P2i^KT0`l?30:n_[`32
`/80_;bl0<G5a@2n_[h0alO70:BTY03?cll0`l?30<;2`P3>c/h0dm?C0;Vi^@2l_;`0`/;20=7Ad@02
0<O7a`0?0<;2`P2l_;`0/[:b0<O7a`2f][H0`l?30;bl_03?cll0`l?30<;2`P2f][H0alO70<30`03>
c/h0^KVi01T0oooo000G0?ooo`0>0;bl_032`/80^;Rh0<;2`P2l_;`0cLg=0:NWY`2j^[X0_[jn0<K6
aP2l_;`0`/;20;jn_P38b<P20<C4a00K0<o?c`34a<@0a/K60<S8b03<c<`0/K6a0;Rh^03<c<`0b/[:
0:n_[`2f][H0];Bd0;Jf]P2a/K40^[Zj0<S8b03:b/X0c<c<0<S8b02f][H0a<C40<o?c`34a<@0/K6a
0<;2`P3:b/X0/k>c0080][Jf01<0`/;209:BTP2WYjL0YjNW0;Jf]P3:b/X0a/K60;jn_P2c/k<0XJ6Q
0;Jf]P34a<@0b<S80:VYZ@2j^[X0];Bd0<c<c02h^;P0eMGE0080clo?00P0^[Zj0<;2`P2n_[h0/k>c
0=7Ad@36a/H0[Jf]0;bl_080`<3000d0Xj>S0;Zj^P30`<00_[jn0;bl_038b<P0eMGE0;Zj^P38b<P0
b/[:0<S8b03<c<`0`/;20080cLg=00h0b<S80;jn_P34a<@0YJFU0<C4a03Zj^X0_;bl0<S8b036a/H0
_;bl0<c<c01cLg<0][Jf0<S8b1h0oooo00h0_[jn0<c<c02g]kL0`<300;^k^`3>c/h0[jn_0;jn_P32
`/80bLW90;Vi^@37alL0`l?30<W9b@80aLG500X0clo?0<30`033`l<0alO70<[:bP2g]kL0`<300<O7
a`35aLD0/[:b0P2i^KT00`2k^k/0/[:b0;^k^`030<O7a`090<o?c`2g]kL0bLW90<o?c`33`l<0][Jf
0<?3``35aLD0/[:b0080];Bd01<0_[jn09>CT`2][Jd0[Jf]0;Bd]037alL0`l?30;bl_02b/[80Y:BT
0;Ng]`30`<00`l?30:RXZ02f][H0]kNg0<c<c02i^KT0dm?C0080c<c<01<0^k^k0<;2`P2n_[h0/[:b
0<c<c030`<00/;2`0;jn_P32`/80_[jn0:RXZ02l_;`0`/;20<30`02n_[h0bLW90=GEe@2l_;`0`l?3
0080alO700/0bLW90<;2`P39bLT0aLG50<O7a`2n_[h0alO70:>SX`33`l<0i^KV0;bl_0020<O7a`05
0;jn_P3:b/X0NGUi0;Jf]P35aLD06@3oool001L0oooo01<0/K6a0;Rh^02d];@0_[jn0<S8b034a<@0
clo?0<K6aP2d];@0_[jn0<;2`P2j^[X0_;bl0<g=c@36a/H0`/;20;Zj^P34a<@0/k>c0080_;bl05@0
^[Zj0;Jf]P34a<@0b/[:0<K6aP2l_;`0^;Rh0<c<c03:b/X0a<C40;bl_034a<@0/K6a0<30`02d];@0
b<S80;Rh^03<c<`0[Jf]0;Zj^P36a/H0`/;20<o?c`2j^[X0a/K609fMW@2WYjL0];Bd0;Zj^P32`/80
`<300;Jf]P2YZJT0];Bd0<C4a03=cLd0c<c<0;6a/@3AdM40a<C40<;2`P30`<00][Jf0<K6aP32`/80
gmoO0<g=c@2n_[h0^;Rh0;6a/@2l_;`0Zj^[0;6a/@3EeMD0c<c<0>7Qh@3AdM40dm?C0;Rh^02l_;`0
cLg=0<o?c`2a/K40^;Rh0;Zj^P2d];@0dm?C0<S8b03<c<`0`<300<c<c02n_[h0c<c<0=GEe@3=cLd0
[Jf]0;>c/`32`/80[Jf]0<c<c032`/80^[Zj0<c<c034a<@N0?ooo`0>0;Jf]P2k^k/0^k^k0<?3``3<
c<`0`/;20<o?c`37alL0]kNg0<G5a@39bLT0_;bl0;jn_P3:b/X20<?3``080;bl_03:b/X0][Jf0<30
`02l_;`0^KVi0;Jf]P35aLD20<[:bP0?0<30`02k^k/0alO70<[:bP30`<00_;bl0<?3``2b/[80`/;2
0;Jf]P37alL0^KVi0<c<c02][Jd0^k^k0080alO70180c/k>0;^k^`35aLD0W9bL0:RXZ02d];@0^KVi
0;jn_P2l_;`0][Jf0:ZZZP2g]kL0aLG50<c<c03:b/X0/[:b0<o?c`33`l<20<;2`P0Z0;Vi^@35aLD0
`<300=oOg`3?cll0_[jn0;Vi^@2b/[80^KVi0:^[Z`2`/;00dM7A0<[:bP3MgMd0clo?0=7Ad@2i^KT0
^k^k0<c<c03?cll0];Bd0;bl_02k^k/0][Jf0<o?c`37alL0b/[:0<30`039bLT0_;bl0<O7a`3?cll0
c<c<0:n_[`2f][H0`l?30;:b/P3>c/h0`/;20;^k^`37alL0^KVi6@3oool001L0oooo00l0_;bl0<S8
b02h^;P0_;bl0<;2`P2a/K40_;bl0<;2`P2n_[h0clo?0<30`03:b/X0a<C40<K6aP30`<000P36a/H0
5038b<P0_[jn0<;2`P32`/80`<300<o?c`2j^[X0_;bl0;6a/@3Cdm<0][Jf0<c<c02n_[h0/k>c0<S8
b02UYJD0_[jn0<g=c@36a/H0b<S80P30`<001@2a/K40];Bd0<o?c`36a/H0_[jn0080b/[:00P0^[Zj
0:n_[`2FUYH0Zj^[0:NWY`2QXJ40[jn_0;Rh^080clo?0200WIfM0;jn_P2n_[h0[jn_0;Bd]036a/H0
_;bl0;Jf]P2l_;`0b<S80<K6aP3:b/X0cLg=0<S8b03?cll0dM7A0<30`02j^[X0^;Rh0<K6aP38b<P0
[jn_0;6a/@3:b/X0cLg=0<c<c034a<@0c<c<0<g=c@3Cdm<0a/K60<o?c`80b<S800T0eMGE0;Jf]P32
`/80][Jf06IVIP36a/H0b<S80<30`02f][H00P36a/H01030`<00a<C40<g=c@2h^;PN0?ooo`0?0<;2
`P3<c<`0^KVi0;Vi^@2n_[h0][Jf0;jn_P33`l<0`<300<[:bP2l_;`0b/[:0<O7a`35aLD0`<300080
alO702P0aLG50;bl_032`/80`/;20;Vi^@3:b/X0]kNg0;jn_P2d];@0dm?C0;Vi^@3:b/X0_[jn0;Bd
]03:b/X0Zj^[0<;2`P3?cll0aLG50<O7a`30`<00`/;20;Bd]02f][H0c<c<0<;2`P2l_;`0bLW90<[:
bP2i^KT0/;2`09ZJVP2][Jd0Zj^[0:JVYP2_[jl0]kNg0<k>cP3<c<`0XJ6Q0P2n_[h0602`/;00][Jf
0<W9b@2l_;`0^KVi0;jn_P39bLT0`/;20<G5a@3<c<`0alO70<[:bP3<c<`0_;bl0;^k^`2l_;`0aLG5
0<W9b@2`/;00];Bd0<W9b@3<c<`0b/[:0<?3``80c<c<00<0dM7A0<G5a@3>c/h00P37alL02@3Cdm<0
^KVi0<?3``2i^KT0LG5a0<G5a@37alL0_;bl0;Ng]`020<G5a@80`/;200<0b/[:0;Vi^@3oool0603o
ool001L0oooo00L0^;Rh0;Zj^P30`<00_;bl0:^[Z`2h^;P0a/K60080_;bl00T0dM7A0<30`02_[jl0
a/K60;jn_P30`<00^;Rh0;Bd]030`<000P3?cll00`3EeMD0`/;20<S8b0020<30`00N0<;2`P2n_[h0
_;bl0<;2`P30`<00^;Rh0<[:bP2_[jl0`/;20;Rh^038b<P0^[Zj0;Rh^032`/80/k>c0<C4a02c/k<0
_[jn0<;2`P2l_;`0][Jf04i>CP2n_[h0[jn_09RHV02f][H0_;bl0;>c/`28R8P0a/K60P2h^;P05P34
a<@0b/[:0<c<c03:b/X0Zj^[0<C4a032`/80b/[:0<c<c030`<00a/K60;>c/`2n_[h0dM7A0;bl_036
a/H0a<C40;Zj^P3=cLd0];Bd0<K6aP2f][H20<o?c`0H0<K6aP3AdM40`<300<;2`P3AdM40`/;20<g=
c@3:b/X0a<C40<K6aP2n_[h0ZJVY0=7Ad@3<c<`0/k>c0;Jf]P2][Jd0a<C40:VYZ@38b<P0][Jf09JF
UP3Cdm<0[Jf]7P3oool01`2k^k/0_;bl0<;2`P2n_[h0[jn_0;Vi^@37alL00P2n_[h03P3AdM40`/;2
0;:b/P37alL0`<300<?3``2f][H0]kNg0<;2`P3?cll0b/[:0=KFeP35aLD0b/[:0P32`/808P37alL0
`<300<30`035aLD0`l?30;bl_03:b/X0/[:b0<?3``2k^k/0b/[:0;jn_P2l_;`0_[jn0;Jf]P35aLD0
]kNg0<G5a@2n_[h0^KVi0;Bd]01GEeL0^k^k0:f][@2HV9P0];Bd0;Vi^@2b/[80S8b<0<;2`P2f][H0
]kNg0<;2`P37alL20<W9b@0;0:f][@35aLD0`/;20<W9b@3:b/X0_[jn0<?3``2f][H0`<300<k>cP2i
^KT00P33`l<02@2l_;`0b/[:0;Jf]P35aLD0]kNg0<c<c039bLT0`/;20=7Ad@020;jn_P0D0<k>cP32
`/80c<c<0<W9b@33`l<0aLG50<30`02[Zj/0dm?C0<O7a`2b/[80][Jf0;2`/035aLD0ZZZZ0<O7a`2i
^KT0W9bL0=GEe@2d];@I0?ooo`005`3oool06`34a<@0[Jf]0<c<c030`<00c<c<0=_Kf`3=cLd0^[Zj
0<C4a036a/H0b/[:0<C4a02d];@0b/[:0<C4a03AdM40^[Zj0<K6aP2j^[X0b/[:0;>c/`30`<00][Jf
0<;2`P38b<P0_[jn0<C4a0020<[:bP0G0<30`02h^;P0_[jn0=7Ad@2d];@0_[jn08B4Q02l_;`0];Bd
0=7Ad@32`/80cLg=0=?Cd`3GemL0`/;20<30`02f][H0a<C40;6a/@34a<@0`/;20820P02HV9P00P2[
Zj/03P2SXj<0a/K60<;2`P30`<00c<c<0<;2`P30`<00a/K60<S8b034a<@0b/[:0<;2`P2c/k<0c<c<
0P2f][H04@30`<00emOG0;Zj^P32`/80/k>c0<[:bP32`/80b/[:0=7Ad@30`<00eMGE0=OGe`3AdM40
b<S80=OGe`3<c<`0dM7A0080clo?00d0b<S80:f][@2j^[X0][Jf0:f][@3=cLd0fm_K0=oOg`3Cdm<0
Xj>S0<[:bP3Kfm/0a<C40080a/K600<0cLg=0?ooo`3oool0703oool06P35aLD0/;2`0<[:bP2n_[h0
alO70=[JfP37alL0_;bl0<G5a@37alL0b/[:0<;2`P2k^k/0bLW90<?3``3>c/h0^KVi0<O7a`2l_;`0
b/[:0;Jf]P32`/80^KVi0<O7a`39bLT0`<300`35aLD05`30`<00^KVi0;bl_03>c/h0];Bd0;jn_P29
RHT0^k^k0;Bd]03<c<`0aLG50<o?c`3EeMD0dM7A0<?3``32`/80]kNg0<?3``2b/[80`l?30<;2`P29
RHT0W9bL0080ZZZZ00D0WYjN0<;2`P37alL0`/;20<[:bP020<;2`P070<O7a`39bLT0`l?30<W9b@35
aLD0/;2`0<c<c0020;^k^`0J0;bl_03AdM40^k^k0<;2`P2d];@0bLW90<;2`P39bLT0clo?0<;2`P3C
dm<0eMGE0<o?c`37alL0eMGE0<[:bP3?cll0dM7A0<o?c`37alL0[Jf]0;^k^`2g]kL0/;2`0<k>cP3?
cll20=gMg@070:n_[`3:b/X0f][J0<;2`P37alL0`l?30<[:bP0I0?ooo`005`3oool20<30`00H0:f]
[@2OWil0clo?0;Rh^02l_;`0`<300;Zj^P2l_;`0b<S80<[:bP2j^[X0/K6a0<S8b03=cLd0`<300;Rh
^03:b/X0^;Rh0<[:bP3<c<`0^;Rh0<30`036a/H0b<S80P2l_;`30<K6aP0<0<[:bP2QXJ40_[jn0;Bd
]03GemL0clo?0=?Cd`3QhN40gMgM0>[ZjP3AdM40/k>c0P2d];@0;032`/80][Jf0<30`02n_[h0`/;2
0<30`02h^;P0T92@0;Rh^02j^[X0WinO0=?Cd`2[Zj/0^[Zj0:n_[`3<c<`0cLg=0<S8b02h^;P0a/K6
0<S8b030`<00fm_K0;6a/@38b<P0dM7A0;Zj^P34a<@0_;bl0;>c/`3GemL0`<300;Rh^02n_[h0`/;2
0<K6aP2UYJD0fm_K0:f][@3AdM40clo?0<K6aP2l_;`0`/;20P2l_;`03P2c/k<0^;Rh0<[:bP2d];@0
`/;20;bl_032`/80b/[:0<S8b03Kfm/0b<S80:>SX`2h^;P0dm?C7P3oool07030`<00`/;20;2`/02T
Y:@0clo?0;Ng]`2n_[h0`/;20;bl_02n_[h0bLW90<k>cP30`<00/;2`0<G5a@3>c/h0`/;20;Vi^@39
bLT0_[jn0<k>cP3AdM40^k^k0;jn_P33`l<0aLG50;^k^`2l_;`40<G5a@0?0:JVYP2l_;`0][Jf0=?C
d`3<c<`0clo?0=KFeP3Kfm/0inOW0<o?c`2k^k/0]kNg0;:b/P33`l<0]kNg0080`<3002<0`l?30<;2
`P2i^KT0UIFE0;Ng]`2l_;`0Y:BT0<k>cP2][Jd0_;bl0;:b/P39bLT0c<c<0<O7a`2i^KT0aLG50<O7
a`33`l<0eMGE0;:b/P37alL0clo?0;^k^`33`l<0_;bl0;Bd]03<c<`0`<300;Vi^@2n_[h0`l?30<O7
a`2ZZZX0f][J0;2`/0020<k>cP0C0<O7a`2l_;`0`l?30<30`02k^k/0];Bd0;Vi^@39bLT0][Jf0<?3
``2n_[h0`/;20<W9b@33`l<0f=SH0<W9b@2XZ:P0^k^k0<o?c`0I0?ooo`005`3oool01@30`<00cLg=
0;Jf]P2YZJT0`/;20080c<c<03T0^[Zj0;Jf]P30`<00`/;20;bl_02a/K40a<C40;Zj^P3<c<`0cLg=
0<c<c02n_[h0b<S80;Jf]P2_[jl0Zj^[0;Zj^P38b<P0[Jf]0;Jf]P2[Zj/0b<S80<o?c`3=cLd0b<S8
0;Zj^P2_[jl0_[jn0<[:bP2j^[X0ZJVY0<[:bP3MgMd0clo?0<g=c@2j^[X0a/K60<[:bP2f][H0dm?C
0<K6aP32`/80^[Zj0;6a/@2[Zj/0Xj>S09^KV`2][Jd0^[Zj0;6a/@2h^;P0XJ6Q0<[:bP36a/H0b/[:
0;Zj^P2d];@00P3:b/X09`3Cdm<0a/K60;Rh^02a/K40_[jn0;bl_02DU9@0`<300<S8b030`<00_;bl
0<[:bP32`/80^[Zj0=GEe@3?cll0XJ6Q0<c<c038b<P0dm?C0;bl_02a/K40a<C40:FUY@3?cll0`/;2
0;jn_P30`<00c<c<09JFUP38b<P0VIVI0:VYZ@2][Jd0b/[:0;Jf]P2h^;P0cLg=0=WIf@0N0?ooo`04
0<30`03>c/h0_;bl0;2`/080alO703H0c<c<0;bl_02d];@0_[jn0<G5a@2n_[h0][Jf0<O7a`2l_;`0
c/k>0<o?c`3:b/X0_[jn0<W9b@2i^KT0/[:b0;2`/030`<00b/[:0;:b/P2i^KT0/;2`0<[:bP3>c/h0
clo?0<W9b@2n_[h0];Bd0;jn_P3?cll0_[jn0:ZZZP3:b/X0fm_K0<o?c`3>c/h0^KVi0<G5a@39bLT0
]kNg0<o?c`35aLD0`/;20;^k^`2][Jd0[jn_0:RXZ02QXJ40/;2`0;Ng]`2d];@0^k^k0:>SX`37alL2
0<[:bP0=0;bl_02g]kL0alO70<O7a`3>c/h0`l?30;^k^`2d];@0_;bl0;^k^`2JVYX0`<300<G5a@02
0;bl_00L0<W9b@32`/80_[jn0=7Ad@3>c/h0YZJV0<c<c035aLD0clo?0;jn_P2_[jl0`l?30:RXZ03>
c/h0aLG50;jn_P39bLT0b/[:09NGU`33`l<0WinO0:^[Z`2b/[80`<300;bl_02d];@0c/k>0=SHf1T0
oooo000G0?ooo`080;bl_02n_[h0cLg=0:^[Z`2FUYH0^[Zj0;Rh^034a<@20<30`00?0;Rh^036a/H0
_;bl0<C4a03<c<`0_[jn0<C4a03:b/X0b<S80<;2`P30`<00[jn_09:BTP2_[jl0_[jn0080b<S800d0
[jn_0<c<c03?cll0cLg=0<30`02n_[h0YJFU0;jn_P3AdM40dm?C0=gMg@3=cLd0b/[:0080[jn_01d0
];Bd0<30`030`<00a/K60;Jf]P2l_;`0a/K60<;2`P2_[jl0`/;20:VYZ@2][Jd0^[Zj09fMW@2h^;P0
YJFU0<;2`P3:b/X0[Jf]0;Bd]038b<P0WinO0<g=c@30`<00b/[:09^KV`36a/H0/K6a0<o?c`020;jn
_P0P0;Rh^02YZJT0[jn_0;bl_032`/80][Jf0;Zj^P3<c<`0a<C40<c<c038b<P0dM7A0<30`03IfMT0
][Jf0:f][@2n_[h0c<c<0<o?c`3AdM40][Jf0;Bd]02l_;`0c<c<0;Zj^P3`l?00a<C40;jn_P32`/80
`<300<K6aP3=cLdN0?ooo`0I0;^k^`33`l<0c/k>0;Jf]P2LW9`0^k^k0;jn_P37alL0`/;20<?3``2i
^KT0alO70;jn_P35aLD0c<c<0;bl_032`/80bLW90<O7a`30`<00_[jn0;2`/02NWYh0[jn_0;jn_P02
0<W9b@0@0;2`/03:b/X0c/k>0<c<c02n_[h0_;bl0:JVYP2l_;`0clo?0=7Ad@3Jf]X0c<c<0<W9b@2`
/;00];Bd0;:b/P80`<3003`0aLG50;Vi^@2k^k/0`l?30<30`02_[jl0`/;20:RXZ02_[jl0][Jf09bL
W02g]kL0YZJV0<;2`P39bLT0[jn_0;Jf]P33`l<0WinO0<c<c032`/80bLW909bLW035aLD0/;2`0<c<
c02n_[h0`/;20;^k^`2XZ:P0[jn_0;^k^`30`<00][Jf0;bl_039bLT0`l?30<c<c035aLD0clo?0<30
`03Fe]H0]kNg0:n_[`2n_[h0b/[:0<c<c03>c/h0]kNg0;Jf]P2g]kL0alO70;bl_03`l?00alO70;jn
_P39bLT0`/;20<W9b@3?cllI0?ooo`005`3oool0:P2l_;`0a<C40;Bd]036a/H0dM7A0<c<c02f][H0
^[Zj0<o?c`2a/K40c<c<0=7Ad@34a<@0`<300;bl_03=cLd0/K6a0;jn_P2d];@0`<300;Bd]02c/k<0
WinO08j>SP3:b/X0^;Rh0;Zj^P36a/H0`/;20<30`032`/80];Bd0<;2`P2f][H0`/;20<C4a032`/80
cLg=08J6QP2<S8`0SXj>092@T080clo?00d0b<S80;bl_02n_[h0dm?C09fMW@32`/80][Jf0<30`02f
][H0Zj^[0<c<c036a/H0`<300080a<C400l0emOG0<C4a032`/80gmoO0<C4a03AdM40][Jf0<c<c032
`/80dm?C0;6a/@3:b/X0dm?C0=7Ad@2h^;P00P38b<P07@2j^[X0b/[:0<o?c`2a/K40fMWI0<;2`P3G
emL0clo?0<[:bP3=cLd0eMGE0<c<c02a/K40b<S80<[:bP2SXj<0`/;20<S8b02HV9P0`<300;bl_02d
];@0b<S80;bl_03<c<`0dM7A0<S8b03IfMT0emOG01h0oooo00H0`<300=7Ad@2g]kL0b/[:0=7Ad@3?
cll20;Vi^@1Q0<W9b@2i^KT0dM7A0<c<c037alL0`l?30;jn_P3?cll0][Jf0;bl_02d];@0`/;20;Ng
]`2d];@0Y:BT09FEU@37alL0^k^k0;bl_037alL0`l?30<;2`P33`l<0][Jf0<;2`P2g]kL0`/;20<W9
b@30`<00c/k>092@T02BTY80Ti>C09FEU@3>c/h0b/[:0<?3``2i^KT0`<300=?Cd`2SXj<0`<300;Ng
]`2l_;`0^KVi0:n_[`3>c/h0bLW90<G5a@39bLT0aLG50=7Ad@3<c<`0bLW90=[JfP32`/80aLG50;Bd
]03:b/X0`/;20=?Cd`2d];@0bLW90=7Ad@3?cll0^k^k0<W9b@37alL0^KVi0<O7a`3<c<`0/[:b0=SH
f033`l<0e]KF0<k>cP35aLD0c<c<0=GEe@3:b/X0/[:b0<O7a`39bLT0WinO0<;2`P37alL0W9bL0<30
`02l_;`0]kNg0<W9b@2n_[h0bLW90<k>cP35aLD0eMGE0=?Cd`0I0?ooo`005`3oool09`2c/k<0_[jn
0;>c/`2d];@0b/[:0<S8b02n_[h0^;Rh0;jn_P34a<@0_;bl0<;2`P34a<@0`/;20<C4a032`/80^[Zj
0;Bd]02c/k<0cLg=0;Rh^02l_;`0b<S80<g=c@2YZJT0^[Zj0<30`02l_;`0c<c<0<S8b032`/80`<30
0<;2`P3=cLd0b/[:0<C4a02d];@0V9RH0;Jf]P020;bl_0100;Jf]P34a<@0^;Rh0<c<c036a/H0^[Zj
0;6a/@2n_[h0b<S80;bl_034a<@0YjNW0;Zj^P36a/H0cLg=0;Zj^P32`/80a/K60;Zj^P30`<00^;Rh
0:n_[`32`/80`<300;Zj^P3<c<`0a/K60=7Ad@2f][H0_[jn0:>SX`2f][H0/k>c0;6a/@3=cLd0c<c<
0<g=c@32`/80^[Zj0:n_[`38b<P0cLg=0<c<c038b<P0gmoO0<S8b02f][H0c<c<0;bl_03=cLd0_[jn
0;bl_02h^;P0dm?C0;bl_03AdM40][Jf0;Zj^P2n_[h0`/;20;Bd]03:b/X0c<c<0<g=cAh0oooo00h0
][Jf0<30`02k^k/0^KVi0<W9b@37alL0bLW90<?3``39bLT0aLG50;jn_P32`/80`l?30<;2`P80`l?3
00`0_;bl0;Vi^@2g]kL0bLW90;^k^`2l_;`0alO70<W9b@2XZ:P0_;bl0<;2`P30`<020<W9b@090<?3
``32`/80`/;20<W9b@3:b/X0alO70;Vi^@2HV9P0^KVi0080_;bl03T0]kNg0<30`02i^KT0b/[:0<G5
a@2n_[h0/[:b0;^k^`30`<00_;bl0<?3``2[Zj/0^k^k0<W9b@3>c/h0^k^k0<;2`P37alL0_;bl0<30
`02i^KT0/;2`0<;2`P33`l<0_[jn0<W9b@33`l<0dM7A0;Jf]P2l_;`0Y:BT0;Bd]02b/[80/;2`0<c<
c039bLT0c<c<0<?3``2k^k/0/[:b0<W9b@3>c/h0alO70<[:bP3Ogml0b/[:0;Vi^@3<c<`0_[jn0<k>
cP2n_[h0_;bl0;Vi^@3AdM40_;bl0<o?c`2i^KT00`32`/80102d];@0c/k>0<W9b@3<c<`I0?ooo`00
5`3oool0D@2n_[h0a/K60;jn_P2a/K40[jn_0<K6aP2c/k<0b<S80;Bd]02f][H0[jn_0;Bd]02f][H0
^[Zj0;Jf]P2[Zj/0a/K60;Rh^032`/80c<c<0;Jf]P32`/80cLg=0;Rh^02d];@0_;bl0<C4a038b<P0
a<C40<g=c@2c/k<0b/[:0;>c/`2n_[h0[jn_0;>c/`2d];@0Vi^K0<c<c02a/K40^;Rh0<S8b02d];@0
`/;20;jn_P32`/80eMGE0;Bd]02a/K40];Bd0;6a/@2j^[X0][Jf0;>c/`3MgMd0T92@0=7Ad@2d];@0
b/[:0<30`02][Jd0a<C40;Bd]02j^[X0^;Rh0:n_[`3IfMT0a<C40<[:bP30`<00a<C40<[:bP3Cdm<0
^[Zj0<30`02l_;`0`<300=?Cd`2UYJD0a<C40:^[Z`020<S8b00;0<K6aP3=cLd0][Jf0<[:bP2l_;`0
`/;20<c<c03=cLd0_[jn0:FUY@3:b/X00`32`/80202f][H0`<300<c<c03Cdm<0cLg=0;Zj^P2h^;P0
a<C47P3oool20<?3``180;jn_P2d];@0][Jf0<O7a`2b/[80aLG50;Bd]02i^KT0/[:b0;Jf]P30`<00
`l?30;bl_02_[jl0aLG50;bl_035aLD0b/[:0;Ng]`2n_[h0bLW90;Vi^@2f][H0_;bl0<?3``37alL0
`l?30<k>cP2g]kL0alO70;Jf]P2k^k/0/[:b0;Bd]02f][H0XJ6Q0<c<c02b/[80^KVi0<O7a`2f][H0
`/;20;jn_P32`/80e]KF0;Vi^@2f][H0^KVi0;Bd]02l_;`0^KVi0;Bd]03Jf]X0UIFE0<o?c`2f][H0
bLW90<30`02_[jl0`l?30;Vi^@2n_[h0^KVi0;:b/P3Fe]H0`l?30<O7a`2n_[h0`<300<O7a`3>c/h0
^KVi0P2n_[h01@30`<00dM7A0:RXZ033`l<0[jn_0080bLW900@0`/;20<k>cP2i^KT0b/[:0P32`/80
3@3:b/X0c<c<0<;2`P2[Zj/0bLW90<?3``2n_[h0`<300;Ng]`30`<00bLW90=7Ad@3>c/h00P2i^KT0
0`33`l<0oooo0?ooo`0G0?ooo`005`3oool04P2l_;`0a/K608:2PP2BTY80RXZ:0:n_[`3<c<`0a<C4
0;>c/`2l_;`0_[jn0;Jf]P32`/80ZJVY0;Jf]P2l_;`0/k>c0<S8b080^;Rh02h0`/;20<S8b02n_[h0
c<c<0<30`02n_[h0`/;20:^[Z`34a<@0eMGE0<g=c@2l_;`0c<c<0<o?c`32`/80fm_K0<S8b02SXj<0
^;Rh0;Zj^P3AdM40dm?C0<S8b036a/H0a<C40<S8b032`/80clo?0;jn_P2f][H0/K6a0;Rh^038b<P0
[Jf]0;Rh^02a/K40^;Rh0;>c/`3:b/X0`<300=WIf@2h^;P0cLg=0<K6aP3=cLd0^[Zj0P36a/H05P2_
[jl0_;bl0<;2`P2_[jl0cLg=0:FUY@2f][H0b<S80<K6aP2n_[h0a<C40<;2`P3:b/X0a/K60:n_[`3:
b/X0];Bd0<[:bP36a/H0_;bl0<S8b03:b/X20<K6aP0=0<;2`P2][Jd0dm?C0<C4a02n_[h0iNGU0=GE
e@2f][H0WIfM0;jn_P2j^[X0^;Rh0=GEe@0N0?ooo`0V0;bl_037alL0Rh^;09RHV02@T900/[:b0<c<
c035aLD0^KVi0<30`032`/80^KVi0<30`02][Jd0^KVi0;jn_P2f][H0c<c<0;^k^`2l_;`0aLG50<W9
b@2n_[h0c<c<0<;2`P33`l<0aLG50;:b/P39bLT0f=SH0=7Ad@2n_[h0c<c<0<o?c`37alL0eMGE0<O7
a`2ZZZX20;Vi^@0J0<k>cP3?cll0aLG50<?3``35aLD0c<c<0<;2`P3:b/X0_[jn0;Vi^@2_[jl0][Jf
0<W9b@2`/;00^k^k0;:b/P2f][H0]kNg0<k>cP33`l<0e]KF0;^k^`3>c/h0alO70<k>cP2l_;`20<G5
a@070;:b/P2n_[h0_[jn0:f][@35aLD0Y:BT0;:b/P020<G5a@0L0;jn_P33`l<0`l?30<W9b@33`l<0
/;2`0<O7a`2g]kL0b/[:0<O7a`2n_[h0bLW90<c<c035aLD0`/;20<?3``2b/[80eMGE0<G5a@30`<00
gMgM0=KFeP2f][H0WinO0<?3``2f][H0^KVi0=?CdaT0oooo000G0?ooo`0A0:^[Z`2n_[h0][Jf0<30
`03GemL0_[jn0<C4a02n_[h0`<300;bl_030`<00`/;20:VYZ@2d];@0a/K60;Jf]P3<c<`00P2j^[X0
303?cll0a/K60;>c/`3=cLd0];Bd0<c<c036a/H0[jn_0;bl_036a/H0b<S80;Bd]080`<3000H0][Jf
0;jn_P2j^[X0ZJVY0:NWY`2][Jd20<30`0050<C4a02h^;P0^[Zj0<o?c`38b<P00P2n_[h01P3<c<`0
][Jf0<C4a02a/K40[jn_0:FUY@80^;Rh0280a<C40;Rh^03=cLd0/k>c0=GEe@3Kfm/0_;bl0;Jf]P38
b<P0^[Zj0<;2`P34a<@0b<S80<30`02n_[h0c<c<0:f][@2n_[h0YjNW0;bl_02n_[h0a/K60<c<c03G
emL0`/;20;Rh^02][Jd0][Jf0<;2`P3<c<`0/k>c0;jn_P3<c<`0a<C40P2f][H03@2l_;`0dM7A0;jn
_P2WYjL0b<S80<c<c036a/H0cLg=0=WIf@3<c<`0a<C40=?Cd`3EeMD07P3oool02P2ZZZX0^k^k0;bl
_033`l<0eMGE0;^k^`37alL0`/;20<?3``30`<020<?3``050:f][@2d];@0aLG50;bl_03:b/X00P2i
^KT0303>c/h0aLG50;Jf]P3>c/h0^KVi0<k>cP35aLD0/;2`0;bl_035aLD0bLW90;Vi^@80`/;200L0
^KVi0<30`02b/[80ZZZZ0:n_[`2b/[80_;bl0080`/;200@0]kNg0;^k^`3>c/h0alO70P2n_[h00`3:
b/X0]kNg0<?3``020;:b/P0>0:ZZZP2d];@0][Jf0<;2`P2g]kL0c/k>0;Jf]P3EeMD0f][J0;jn_P2i
^KT0alO70;^k^`30`<020<W9b@0R0<;2`P2n_[h0b/[:0:f][@30`<00[Jf]0;jn_P33`l<0b/[:0<o?
c`3AdM40`/;20;Vi^@2_[jl0]kNg0;jn_P37alL0/;2`0<30`03<c<`0aLG50;Vi^@2k^k/0_[jn0<c<
c030`<00YZJV0<[:bP37alL0`/;20<c<c03EeMD0b/[:0<O7a`80dM7A6@3oool001L0oooo00T0`/;2
0<C4a02j^[X0b/[:0<o?c`2l_;`0dm?C0<30`02][Jd00P2f][H04`32`/80_[jn0<g=c@2n_[h0b<S8
0<C4a02j^[X0YjNW0;bl_036a/H0a<C40<K6aP34a<@0^[Zj0<C4a02j^[X0][Jf0<C4a02n_[h00P34
a<@08P36a/H0`<300<K6aP36a/H0^;Rh0820P02SXj<0[Jf]0;Jf]P30`<00_;bl0<C4a02n_[h0`/;2
0;Rh^02WYjL0`<300:VYZ@3<c<`0[jn_0<30`02][Jd0][Jf0:n_[`30`<00XJ6Q0<g=c@2n_[h0`/;2
0:NWY`2c/k<0ZJVY0;bl_036a/H20<o?c`070<K6aP32`/80^[Zj0;6a/@2n_[h0/K6a0;jn_P020<30
`0060=GEe@30`<00][Jf0<K6aP2j^[X0];Bd0P36a/H04P2n_[h0eMGE0<c<c03:b/X0clo?0;>c/`38
b<P0^;Rh0<c<c02f][H0_[jn0<S8b02[Zj/0gMgM0=_Kf`3=cLd0c<c<0;jn_P80a<C47P3oool02@33
`l<0b/[:0;jn_P3:b/X0clo?0;Vi^@3Cdm<0`/;20;2`/0020;^k^`030<?3``30`<00c/k>0080`l?3
04<0`<300;Vi^@2XZ:P0_;bl0<G5a@30`<00aLG50<O7a`2n_[h0`l?30;^k^`2g]kL0`l?30;^k^`30
`<00aLG50<O7a`32`/80alO70<[:bP2k^k/0PX:20:>SX`2_[jl0_;bl0<;2`P2k^k/0`l?30;jn_P32
`/80^KVi0:ZZZP30`<00Zj^[0<[:bP2`/;00`/;20;2`/02i^KT0[jn_0;jn_P2SXj<0c/k>0<30`033
`l<0Zj^[0;Jf]P2][Jd0_;bl0<G5a@3Fe]H0clo?0<O7a`33`l<0^k^k0;:b/P30`<00];Bd0;bl_032
`/80^k^k0<k>cP2k^k/0]kNg0<G5a@2k^k/0][Jf0080aLG500X0_[jn0=?Cd`3<c<`0b/[:0<o?c`2f
][H0`l?30;Ng]`37alL0^KVi0P39bLT00`2][Jd0f][J0=SHf0020<[:bP030<;2`P37alL0aLG501T0
oooo000G0?ooo`0:0;Jf]P2j^[X0^[Zj0:^[Z`2f][H0`<300=?Cd`2f][H0];Bd0;Jf]P80b<S803h0
`<300=OGe`3Kfm/0[jn_0<g=c@2j^[X0][Jf0<S8b02h^;P0b/[:0<K6aP2d];@0_;bl0<30`02l_;`0
b<S80<K6aP3?cll0a<C40<c<c03Zj^X0`<300:n_[`3=cLd0clo?0;Zj^P3:b/X0YjNW0:f][@3Kfm/0
`/;20;Bd]038b<P0][Jf0<[:bP2HV9P0b<S80;>c/`2l_;`0b/[:0:NWY`2h^;P0_[jn0;Zj^P36a/H0
^[Zj0:n_[`3AdM40];Bd0;Rh^030`<00_[jn0;Bd]02j^[X0`<300<;2`P30`<00[Jf]0<o?c`2d];@0
ZJVY0;6a/@80_;bl0180Zj^[0;Bd]02n_[h0dM7A0<;2`P36a/H0[Jf]0;Rh^032`/80[jn_0=GEe@0V
9RH0^;Rh0;Bd]03?cll0a/K60<S8b032`/820;Rh^0090:FUY@38b<P0`<300<c<c03IfMT0b<S80<g=
c@36a/H0a<C401h0oooo0P2n_[h01P2k^k/0[jn_0;Vi^@35aLD0dm?C0;Vi^@80]kNg03P0aLG50<W9
b@39bLT0eMGE0=SHf02`/;00bLW90;^k^`2g]kL0`l?30;^k^`3AdM40aLG50;Ng]`2n_[h0`<300;bl
_039bLT0aLG50<o?c`32`/80c<c<0>OWi`32`/80/;2`0<c<c03>c/h0^k^k0<W9b@2][Jd0/[:b0=GE
e@30`<00];Bd0<O7a`2i^KT0c<c<09bLW037alL0];Bd0;bl_039bLT0Zj^[0;^k^`2`/;00_;bl0<W9
b@2k^k/0^KVi0=?Cd`2g]kL0^k^k0<30`02n_[h0][Jf0;^k^`80`/;202D0`<300;2`/03?cll0/;2`
0:ZZZP2_[jl0`<300;jn_P2][Jd0][Jf0;jn_P3AdM40_;bl0<?3``2b/[80^k^k0;jn_P2_[jl0dm?C
02h^;P2l_;`0^k^k0<k>cP37alL0bLW90<;2`P2i^KT0/[:b0:RXZ03>c/h0alO70<c<c03Fe]H0`l?3
0<k>cP37alL0`l?301T0oooo000G0?ooo`080<30`02n_[h0`/;20<[:bP2d];@0clo?0<30`02l_;`2
0<c<c0070;Zj^P30`<00/K6a0;jn_P3=cLd0][Jf0<;2`P020<K6aP0F0;bl_038b<P0^;Rh0;bl_02j
^[X0/k>c0;jn_P3Cdm<0b<S80<c<c030`<00m_Kf0;jn_P2c/k<0a<C40;Zj^P2WYjL0fm_K0;Bd]038
b<P0TY:B0<o?c`80_;bl01<0][Jf0<30`03<c<`0/k>c0<;2`P2l_;`0eMGE0:f][@34a<@0][Jf0;>c
/`30`<00WIfM06m_K`2[Zj/0a/K60>?Sh`38b<P0/k>c0080_[jn01<0fm_K0<C4a03IfMT0_[jn0;Bd
]02h^;P0Zj^[0;bl_02d];@0^[Zj0;Bd]02n_[h0`/;20<S8b03<c<`0`/;20;Jf]P2n_[h0^[Zj00@0
a<C400h0XJ6Q0<S8b02n_[h0ZJVY0<S8b030`<00a/K60;Bd]03Kfm/0`<300>?Sh`38b<P0gmoO0<C4
a080cLg=00<0b<S80>7Qh@3oool07@3oool04@30`<00_[jn0<?3``35aLD0][Jf0<k>cP33`l<0`<30
0<k>cP3?cll0`<300<;2`P2d];@0_[jn0<k>cP2i^KT0`l?30080alO700<0`/;20<c<c02i^KT00P2l
_;`09P2f][H0^k^k0<k>cP37alL0b/[:0<30`03`l?00_[jn0;Bd]033`l<0^k^k0:JVYP3Fe]H0]kNg
0<W9b@2CTi<0b/[:0;Vi^@2k^k/0]kNg0;jn_P37alL0^KVi0<30`02k^k/0dM7A0;2`/035aLD0^KVi
0;Jf]P30`<00XJ6Q07QhN02][Jd0c<c<0>7Qh@39bLT0/[:b0P2n_[h0503Fe]H0`l?30=GEe@32`/80
/[:b0;Jf]P2[Zj/0^k^k0;Jf]P2i^KT0/[:b0;^k^`30`<00aLG50<W9b@32`/80^k^k0<?3``2k^k/0
`/;20`33`l<03P2TY:@0clo?0<;2`P2XZ:P0alO70<30`032`/80/[:b0=KFeP2l_;`0fm_K0<?3``3J
f]X0`/;20P3?cll00`35aLD0gMgM0?ooo`0H0?ooo`005`3oool05`2a/K40c<c<0;Rh^02c/k<0b/[:
0=?Cd`30`<00`/;20:^[Z`3<c<`0a<C40;Bd]02n_[h0a/K60;bl_030`<00_;bl0;jn_P2d];@0`<30
0;jn_P2l_;`0_[jn0080a<C401/0cLg=0<[:bP3?cll0a/K60:n_[`2[Zj/0];Bd0;jn_P34a<@0YJFU
0=?Cd`2n_[h0U9BD0;Jf]P2][Jd0c<c<0;Zj^P36a/H0b/[:0<S8b03GemL0/k>c0<K6aP32`/80a/K6
0:>SX`30`<000P2f][H0902d];@0/K6a0<K6aP3EeMD0WIfM092@T02][Jd0_;bl0;>c/`2n_[h0^[Zj
0<C4a02h^;P0b/[:0<K6aP34a<@0`/;20;jn_P2l_;`0[Jf]0;>c/`2SXj<0Zj^[0<c<c032`/80^;Rh
0=OGe`38b<P0`/;20;Rh^03GemL0dM7A0:f][@3<c<`0`<300;bl_080^[Zj00X0dM7A0;Rh^02[Zj/0
/K6a0;Jf]P3AdM40`<300=GEe@3=cLd0dm?C0P3AdM400`2h^;P0oooo0?ooo`0L0?ooo`0G0<30`03>
c/h0^k^k0;Jf]P3<c<`0dm?C0<G5a@37alL0/[:b0<k>cP37alL0^k^k0<?3``37alL0_;bl0;jn_P2i
^KT0`l?30;^k^`32`/80`<300;Vi^@35aLD00P33`l<06`3?cll0dM7A0<W9b@37alL0];Bd0:n_[`2f
][H0_[jn0<?3``2ZZZX0dm?C0;jn_P2GUiL0][Jf0;2`/03<c<`0^k^k0<?3``3<c<`0b/[:0=SHf02f
][H0aLG50<;2`P35aLD0Zj^[0<G5a@020;Jf]P0A0;:b/P2d];@0`<300=?Cd`2NWYh0UiNG0;Ng]`2k
^k/0]kNg0<;2`P2g]kL0`l?30;jn_P3:b/X0alO70<?3``2n_[h00P2k^k/0202][Jd0/[:b0:JVYP2]
[Jd0b/[:0<;2`P2l_;`0dM7A0P35aLD01`2k^k/0e]KF0=7Ad@2`/;00c<c<0<30`02l_;`00P2k^k/0
3@3?cll0_;bl0:ZZZP2f][H0^k^k0=7Ad@32`/80dm?C0<c<c03>c/h0f=SH0<c<c02i^KT06@3oool0
01L0oooo03P0Zj^[0<g=c@2n_[h0/k>c0<K6aP2l_;`0`<300;Bd]038b<P0clo?0<K6aP2j^[X0];Bd
0<30`02l_;`0][Jf0;6a/@2n_[h0/K6a0<;2`P36a/H0_;bl0<S8b02l_;`0_[jn0<K6aP3:b/X0_[jn
0;Rh^03IfMT0_;bl0:VYZ@2f][H0cLg=0<S8b02IVIT0][Jf0:f][@3Cdm<0];Bd0=7Ad@2c/k<0][Jf
0=_Kf`30`<00^[Zj0:FUY@2_[jl0/k>c0<;2`P2l_;`0^[Zj0;>c/`2][Jd0a<C40<[:bP80a/K600<0
a<C40;Zj^P2l_;`00P2l_;`0:P2c/k<0_;bl0;Jf]P2@T900a/K60<C4a030`<00_[jn0<K6aP2n_[h0
a<C40<30`032`/80a/K60;bl_032`/80b/[:0=GEe@3:b/X0Zj^[0=?Cd`2j^[X0b<S80<;2`P2a/K40
clo?0<30`038b<P0emOG0<K6aP3Kfm/0dM7A0;bl_02f][H0cLg=0>7Qh@3GemL0b<S80<;2`P2YZJT0
];Bd0<[:bQh0oooo01/0[Jf]0<o?c`30`<00][Jf0<W9b@35aLD0`<300;Jf]P37alL0dM7A0<W9b@2k
^k/0][Jf0<;2`P2l_;`0][Jf0:n_[`32`/80][Jf0<?3``37alL0^KVi0<W9b@2l_;`0_[jn0<;2`P37
alL00P30`<00C03AdM40^k^k0:^[Z`2g]kL0c<c<0<G5a@2OWil0]kNg0:f][@3?cll0];Bd0<c<c02`
/;00][Jf0=_Kf`33`l<0_[jn0:JVYP2`/;00];Bd0<;2`P2k^k/0^KVi0;Jf]P2`/;00`l?30<O7a`35
aLD0`/;20<W9b@2i^KT0`/;20;Vi^@30`<00]kNg0;Vi^@2g]kL0VYZJ0<O7a`3:b/X0`/;20;^k^`32
`/80^k^k0<30`02l_;`0`/;20<G5a@2l_;`0`/;20<c<c03Cdm<0bLW90:f][@3?cll0_;bl0<W9b@33
`l<0][Jf0<[:bP2l_;`0`l?30=GEe@35aLD0fm_K0<c<c02i^KT0];Bd0<W9b@3Jf]X0eMGE0<O7a`32
`/80XJ6Q0;Bd]039bLTI0?ooo`005`3oool06@3AdM40SXj>0<[:bP2h^;P0_[jn0<S8b02f][H0a<C4
0;Rh^02j^[X0a/K60<C4a030`<00^[Zj0;Bd]03<c<`0`/;20:FUY@36a/H0][Jf0<30`036a/H0_;bl
0:6QX@38b<P00P34a<@04036a/H0a<C40;Bd]03:b/X0TY:B0<;2`P30`<00clo?0=?Cd`36a/H0YJFU
07=cL`3<c<`0b<S80;jn_P2j^[X20<S8b00W0=OGe`3:b/X0a<C40;Rh^02_[jl0`<300;Zj^P2c/k<0
[Jf]0;Zj^P32`/80^[Zj0<K6aP2l_;`0b/[:0:n_[`2l_;`0cLg=0;jn_P34a<@0emOG0<[:bP2][Jd0
emOG0;Zj^P2c/k<0`/;20;Jf]P2][Jd0YjNW0;6a/@3?cll0_[jn0<C4a03EeMD0clo?0<K6aP3:b/X0
`/;20080];Bd01<0_;bl0<g=c@3:b/X0c<c<0=WIf@2a/K40b/[:0=GEe@3=cLd0Ogmo0;Zj^P32`/80
c<c<0;>c/`2f][H0dM7A0<30`034a<@0Vi^K01h0oooo05@0dM7A09FEU@3:b/X0^k^k0<30`033`l<0
][Jf0<;2`P2g]kL0^k^k0<G5a@32`/80_[jn0;bl_02g]kL0b/[:0<G5a@2XZ:P0aLG50;Vi^@32`/80
b/[:0<30`02LW9`0`l?30<;2`P37alL0aLG50<?3``2f][H0bLW909FEU@30`<00_[jn0<c<c03Cdm<0
c<c<0:JVYP1oOgl0b/[:0<O7a`2n_[h0]kNg0<?3``37alL0f=SH0<W9b@30`<00]kNg0;2`/030`<00
^k^k0;Bd]02_[jl0_;bl0<?3``2k^k/0aLG50;jn_P39bLT0/[:b0;jn_P3:b/X0_;bl0<?3``3EeMD0
b/[:0;:b/P3Cdm<0^KVi0;:b/P30`<00]kNg0;2`/02[Zj/0/;2`0<[:bP2k^k/0`<300=_Kf`3>c/h0
aLG50<W9b@32`/820;Jf]P0C0;bl_03<c<`0alO70<W9b@3EeMD0/[:b0<W9b@3Cdm<0c<c<08B4Q02n
_[h0`/;20<[:bP2f][H0]kNg0<k>cP32`/80c/k>09NGU`0I0?ooo`005`3oool01@36a/H0cLg=0;Zj
^P2l_;`0][Jf0080`<3000L0];Bd0:NWY`2d];@0`<300;jn_P30`<00cLg=0080/k>c05T0`<300;Zj
^P3?cll0a<C40;Zj^P38b<P0a<C409nOW`2f][H0b<S80<C4a036a/H0b/[:0;jn_P3Cdm<0^;Rh0=OG
e`2j^[X0dM7A0<30`032`/80[jn_0<K6aP2d];@0c<c<0<g=c@2a/K40clo?0=?Cd`2YZJT0^[Zj0;Bd
]02[Zj/0/k>c0:f][@2d];@0CTi>0;>c/`2d];@0`/;20<g=c@2d];@0[Jf]0;bl_02f][H0iNGU0:FU
Y@30`<00^;Rh0;bl_02n_[h0`/;20<30`036a/H0b<S80<[:bP32`/80^;Rh0<[:bP2j^[X0[jn_0:^[
Z`2SXj<0[jn_0<C4a03:b/X0[Jf]0<C4a03:b/X0dM7A0;Zj^P34a<@0b/[:0<C4a02l_;`0cLg=0:f]
[@2f][H0/k>c0<[:bP3?cll0/k>c0<;2`P3EeMD0`/;20;Bd]02QXJ40^;Rh0:VYZ@0N0?ooo`0:0<?3
``3:b/X0^k^k0;bl_02g]kL0aLG50<W9b@2i^KT0ZZZZ0;Bd]080_[jn00T0alO70<o?c`2g]kL0];Bd
0<30`02k^k/0clo?0<?3``2k^k/00P35aLD0302XZ:P0_;bl0<O7a`33`l<0aLG50<W9b@2n_[h0dM7A
0;^k^`3AdM40^k^k0<o?c`80`/;204@0[jn_0<W9b@2f][H0b/[:0<c<c02_[jl0bLW90<o?c`2][Jd0
^k^k0;Bd]02_[jl0][Jf0;2`/02g]kL0EeMG0;2`/02f][H0`/;20<W9b@2b/[80[jn_0;bl_02f][H0
gmoO0:JVYP2n_[h0]kNg0;^k^`2n_[h0`/;20;bl_032`/80`l?30<G5a@32`/80]kNg0<G5a@2k^k/0
[jn_0:^[Z`2TY:@0/[:b0;jn_P35aLD0[Jf]0<G5a@3:b/X0clo?0;Vi^@30`<00b/[:0<G5a@2n_[h0
c/k>0:n_[`2i^KT0][Jf0<G5a@3:b/X0];Bd0<;2`P3Cdm<0`/;20;2`/02JVYX0^KVi0:RXZ1T0oooo
000G0?ooo`0_0;Zj^P32`/80];Bd0;Bd]02n_[h0^[Zj0<c<c03?cll0b/[:0<C4a032`/80`<300<[:
bP3AdM40^;Rh0;Bd]03AdM40`<300<;2`P30`<00];Bd0;bl_03:b/X0a<C40;jn_P34a<@0b/[:0;Jf
]P3?cll0][Jf0;jn_P2h^;P0_;bl0;>c/`30`<00^[Zj09^KV`2l_;`0cLg=0;Jf]P3:b/X0_[jn0<S8
b02a/K40`<300;Bd]02h^;P00P2l_;`0>02n_[h0^;Rh0<C4a02HV9P0][Jf0<o?c`2QXJ40a<C40;jn
_P2UYJD0];Bd0=_Kf`30`<00dm?C0:FUY@2f][H0];Bd0=WIf@3:b/X0YJFU0<c<c02c/k<0dm?C08j>
SP2n_[h0_;bl0;Rh^03<c<`0];Bd0;Rh^03?cll0n?Sh0<;2`P2j^[X0_;bl0<g=c@2j^[X0clo?0;6a
/@32`/80a/K60<;2`P3?cll0emOG0=WIf@2SXj<0clo?0<c<c030`<00/K6a0<S8b03Cdm<0eMGE04M7
A`2f][H0dM7A7P3oool04P2n_[h0`l?30;Ng]`2g]kL0`/;20;jn_P3<c<`0clo?0<[:bP3<c<`0aLG5
0<;2`P3:b/X0dm?C0;bl_02f][H0c/k>0;bl_080_[jn01/0_;bl0<?3``3>c/h0`l?30;jn_P33`l<0
bLW90;Ng]`3>c/h0][Jf0;bl_02i^KT0_;bl0;Bd]030`<00^k^k09nOW`2l_;`0clo?0;Vi^@39bLT0
_;bl0<[:bP2b/[80`<300;Jf]P2d];@00P2k^k/0:`2l_;`0]kNg0<;2`P2OWil0][Jf0<o?c`2TY:@0
`/;20;bl_02TY:@0^KVi0=_Kf`33`l<0dm?C0:ZZZP2g]kL0];Bd0=GEe@37alL0Y:BT0<W9b@2`/;00
clo?09FEU@2n_[h0^KVi0;^k^`3<c<`0]kNg0;^k^`3AdM40k^k^0<?3``2i^KT0`l?30<k>cP2l_;`0
clo?0;2`/03:b/X0c<c<0<O7a`3?cll00P3Fe]H02`2TY:@0b/[:0<[:bP3>c/h0ZZZZ0<?3``3EeMD0
fm_K05ADE02l_;`0c<c<01T0oooo000G0?ooo`0;0=7Ad@32`/80iNGU0;Rh^038b<P0^[Zj0;jn_P38
b<P0a<C40;jn_P30`<000P2n_[h04`34a<@0a/K60;6a/@3:b/X0a<C40<c<c036a/H0`/;20<C4a03?
cll0_;bl0;jn_P3:b/X0_;bl0;Zj^P3:b/X0a/K60=GEe@2a/K400P2h^;P05@2d];@0_[jn0<c<c02h
^;P0b<S80:VYZ@38b<P0a/K60;6a/@34a<@0^[Zj0;Rh^02MWId0Zj^[0<30`034a<@0];Bd0;Jf]P2W
YjL0Zj^[0:n_[`020<C4a00:0<g=c@2YZJT0fMWI0;jn_P3:b/X0dM7A0;bl_03Cdm<0b<S80;Zj^P80
fMWI0P3:b/X02@2n_[h0dM7A0;bl_034a<@0`<300;6a/@32`/80b/[:0<C4a0020<30`00E0<K6aP3<
c<`0`/;20;bl_02a/K40`/;20<c<c02WYjL0b<S80<C4a02d];@0_;bl0<[:bP32`/80clo?0;Rh^02c
/k<0][Jf0<K6aP2_[jl0Ogmo0080a<C47P3oool01@3Cdm<0`/;20>;RhP2k^k/0b/[:0080`/;200@0
b/[:0<O7a`37alL0`l?30P35aLD00`37alL0bLW90;:b/P020<O7a`0>0<k>cP35aLD0`/;20<O7a`3?
cll0_;bl0;jn_P39bLT0_;bl0;^k^`39bLT0`l?30=7Ad@2b/[820;Vi^@170;Jf]P2n_[h0b/[:0;Vi
^@3:b/X0[Jf]0<O7a`33`l<0][Jf0<?3``2k^k/0^KVi09bLW02_[jl0`/;20<G5a@2g]kL0^KVi0:f]
[@2[Zj/0][Jf0<O7a`33`l<0c<c<0:^[Z`3Hf=P0`/;20<c<c03>c/h0^k^k0=?Cd`39bLT0_;bl0=GE
e@3Cdm<0alO70<[:bP30`<00c<c<0;bl_035aLD0`<300;Bd]033`l<0b/[:0<O7a`2n_[h0`/;20<G5
a@3AdM40`<300;^k^`2`/;00`<300<c<c02[Zj/0alO70<G5a@2g]kL0_;bl0<O7a`30`<00c/k>0;^k
^`2f][H0`<300<G5a@2[Zj/0RHV90<k>cP32`/806@3oool001L0oooo00l0_;bl0;Zj^P2l_;`0_;bl
0<[:bP2d];@0_;bl0<c<c02h^;P0_;bl0<g=c@2j^[X0cLg=0=7Ad@36a/H00P2f][H02@3?cll0a<C4
0<30`02n_[h0`<300<C4a03<c<`0^[Zj0=?Cd`020;Zj^P0=0=?Cd`2l_;`0WinO0<K6aP3:b/X0];Bd
0<;2`P38b<P0dM7A0<[:bP2UYJD0][Jf0<g=c@020;jn_P030;bl_030`<00^[Zj0080][Jf03T0_[jn
0;bl_02d];@0[jn_0<c<c02OWil0_;bl0;Jf]P34a<@0`/;20=GEe@38b<P0_[jn0:^[Z`34a<@0fm_K
0:n_[`2d];@0clo?0;Zj^P3AdM40^[Zj0<C4a032`/80ZJVY0:f][@2j^[X0`/;20;Rh^038b<P0fm_K
0<S8b03?cll0];Bd0<K6aP2f][H0_[jn0<30`02j^[X0/k>c0;Zj^P3?cll0`<300<[:bP38b<P0`<30
0<c<c03AdM40^;Rh0:^[Z`2d];@0dm?C0;Rh^02a/K40];Bd0;jn_P30`<007P3oool20;jn_P0:0<G5
a@2n_[h0c/k>0;Ng]`2n_[h0c<c<0;^k^`2n_[h0c/k>0;bl_080dm?C00H0bLW90;Ng]`2g]kL0clo?
0<G5a@30`<020;jn_P0C0<;2`P3<c<`0_;bl0=?Cd`2l_;`0_[jn0=?Cd`30`<00Xj>S0<W9b@3<c<`0
^k^k0<;2`P35aLD0c/k>0<O7a`2XZ:P0][Jf0<c<c0020<30`0050;jn_P32`/80_;bl0;Jf]P2_[jl0
0P2g]kL08P2f][H0/;2`0<k>cP2QXJ40_[jn0;Vi^@35aLD0`/;20<o?c`33`l<0_;bl0:^[Z`32`/80
eMGE0;2`/02f][H0c/k>0;^k^`3?cll0_;bl0<?3``32`/80[Jf]0;Jf]P2g]kL0`<300;^k^`37alL0
e]KF0<O7a`3Cdm<0^KVi0<O7a`2f][H20<30`00A0;Ng]`2b/[80^k^k0<k>cP30`<00b/[:0<W9b@32
`/80c<c<0=7Ad@2k^k/0ZZZZ0;^k^`3AdM40]kNg0;jn_P2d];@00P30`<0I0?ooo`005`3oool0402h
^;P0[Jf]0:n_[`36a/H0b<S80:VYZ@34a<@0_;bl0;Zj^P3=cLd0b/[:0<c<c03:b/X0`<300:NWY`36
a/H20;bl_00g0;jn_P34a<@0a<C40;bl_02f][H0b<S80;6a/@2n_[h0][Jf0;jn_P38b<P0cLg=0;>c
/`38b<P0a<C40;bl_034a<@0a/K60;Bd]03:b/X0_;bl0;Zj^P2n_[h0cLg=0<[:bP2j^[X0_[jn0<C4
a02h^;P0b/[:0<c<c032`/80^[Zj0;jn_P30`<00/K6a0:VYZ@2_[jl0a/K60;Rh^02n_[h0][Jf0=7A
d@2l_;`0/K6a0<;2`P30`<00clo?0<C4a02l_;`0c<c<0<S8b02j^[X0gmoO0:VYZ@020;Bd]0090=WI
f@3:b/X0][Jf0<C4a032`/80b<S80<C4a03:b/X0cLg=00<0b/[:0P3EeMD02`2j^[X0[Jf]0<30`032
`/80eMGE0>SXj038b<P0eMGE0<K6aP2d];@0ZJVY0080b<S800<0a/K60<;2`P30`<007P3oool01`2i
^KT0/;2`0;:b/P37alL0bLW90:RXZ03<c<`00P35aLD02P3?cll0b/[:0<c<c03:b/X0`/;20:n_[`37
alL0_[jn0;^k^`2l_;`20<;2`P0Z0;Vi^@2f][H0aLG50;Jf]P2n_[h0^k^k0;jn_P37alL0c/k>0;^k
^`39bLT0aLG50;jn_P35aLD0alO70;Vi^@3>c/h0_[jn0;^k^`2n_[h0c<c<0<W9b@2d];@0^k^k0<O7
a`2i^KT0alO70<W9b@30`<00^k^k0;jn_P30`<00[jn_0:RXZ02b/[80aLG50;Vi^@30`<00^KVi0<[:
bP2i^KT0[jn_0P32`/80203?cll0`l?30;^k^`37alL0`l?30;Ng]`3Hf=P0[Jf]0P2g]kL07P3Fe]H0
b/[:0;2`/035aLD0_[jn0<O7a`33`l<0bLW90<c<c035aLD0alO70<W9b@3AdM40eMGE0;bl_02`/;00
bLW90<[:bP3Cdm<0gmoO0<O7a`3Cdm<0`l?30;Bd]02][Jd0bLW90<?3``37alL0`<300<?3`aT0oooo
000G0?ooo`0B0;jn_P36a/H0`/;20;Bd]02l_;`0/k>c0<S8b02a/K40];Bd0<30`02n_[h0^[Zj0;jn
_P36a/H0c<c<0<K6aP2WYjL0`<300P36a/H01@3AdM40_;bl0;>c/`32`/80_[jn0080_;bl04h0_[jn
0<C4a038b<P0`/;20:NWY`2n_[h0[jn_0;Bd]032`/80/K6a0<K6aP34a<@0^[Zj0;Jf]P2n_[h0c<c<
0:FUY@36a/H0Zj^[0;Bd]034a<@0_;bl0<c<c02[Zj/0a/K60<;2`P20P800][Jf0;>c/`2][Jd0XJ6Q
0<g=c@30`<00^;Rh0:>SX`3:b/X0b<S80;Zj^P3<c<`0dm?C0:VYZ@2n_[h0`/;20:VYZ@2][Jd0ZJVY
0<K6aP2h^;P0b<S80;Jf]P2IVIT0c<c<0:6QX@2][Jd0c<c<0<g=c@34a<@0_[jn0<;2`P3=cLd0][Jf
0<c<c03Cdm<0`/;20>KViP32`/80_;bl0<[:bP3=cLd0clo?0;Rh^03Cdm<0][Jf0<;2`P38b<P0^;Rh
0<S8b02j^[XN0?ooo`0<0<;2`P37alL0`l?30;Ng]`2n_[h0][Jf0<G5a@2d];@0^KVi0<G5a@30`<00
_[jn0P2l_;`05`3<c<`0alO70:JVYP37alL0c<c<0<O7a`3AdM40aLG50;Vi^@35aLD0`/;20<?3``2n
_[h0`/;20<G5a@39bLT0`l?30:^[Z`30`<00/[:b0;Jf]P2n_[h0[jn_0080`/;200P0^KVi0;Jf]P2l
_;`0c/k>0;Bd]03>c/h0[jn_0;Bd]080_;bl0280dm?C0:^[Z`35aLD0`/;208V9R@2d];@0][Jf0;2`
/02VYZH0b/[:0;jn_P2i^KT0YZJV0<G5a@33`l<0^KVi0<[:bP3Cdm<0[Jf]0;bl_030`<00[Jf]0:n_
[`2XZ:P0`l?30;bl_035aLD0^KVi09bLW037alL0XJ6Q0:^[Z`3:b/X0clo?0P32`/805035aLD0clo?
0;Ng]`3<c<`0dm?C0<30`03QhN40`<300;bl_032`/80bLW90<[:bP2f][H0c/k>0;Jf]P30`<00alO7
0;Vi^@39bLT0_;bl6@3oool001L0oooo01/0^[Zj0=OGe`2n_[h0^;Rh0<K6aP3:b/X0a/K60;Rh^02n
_[h0/K6a0:VYZ@32`/80][Jf0<[:bP2h^;P0`<300;bl_02_[jl0^;Rh0<;2`P36a/H0`<300<[:bP38
b<P0b/[:0;Zj^P2][Jd00P2f][H08P3?cll0`/;209JFUP3:b/X0Vi^K0<30`034a<@0a/K60<g=c@2h
^;P0b<S80<C4a02l_;`0YjNW0;Bd]02h^;P0^[Zj09fMW@2n_[h0`<300;Zj^P36a/H0`/;20;Rh^036
a/H0^;Rh0=?Cd`34a<@0dM7A0<[:bP34a<@0_;bl0<[:bP2n_[h20<S8b0050<;2`P3?cll0`/;20<K6
aP34a<@00P2f][H06@34a<@0_;bl0;Rh^034a<@0][Jf0:f][@2f][H0/K6a0<C4a030`<00_;bl0<K6
aP3EeMD0c<c<08:2PP3EeMD0a/K60;bl_02n_[h0c<c<0<o?c`2c/k<0Vi^K0:f][@30`<000P2n_[h0
1P34a<@0^[Zj0<o?c`34a<@0b/[:0=OGeah0oooo00l0_;bl0=KFeP30`<00^k^k0<O7a`35aLD0c<c<
0;bl_030`<00^KVi0:ZZZP35aLD0][Jf0<[:bP2g]kL00P2l_;`0<P2b/[80^k^k0<?3``37alL0bLW9
0<c<c039bLT0b/[:0<;2`P2`/;00^k^k0;Vi^@3<c<`0`<3009RHV037alL0WYjN0<30`035aLD0alO7
0<k>cP2g]kL0aLG50<;2`P2k^k/0[Jf]0;Bd]02k^k/0`l?30:>SX`3:b/X0aLG50;bl_033`l<0`/;2
0;Vi^@33`l<0_;bl0<k>cP32`/80c/k>0<[:bP35aLD0_;bl0<W9b@2k^k/0`l?30<G5a@32`/80clo?
0P33`l<02`32`/80^KVi0;Ng]`33`l<0_;bl0;Vi^@35aLD0][Jf0;2`/02i^KT0/;2`00<0`<3000d0
`l?30<o?c`37alL0QXJ60=?Cd`3:b/X0`l?30<30`039bLT0c<c<0;Jf]P2OWil0[jn_00<0`<3000H0
`/;20;Vi^@3>c/h0`l?30<[:bP3Fe]HI0?ooo`005`3oool0102h^;P0cLg=0;Bd]034a<@20<30`00C
0;>c/`30`<00_;bl0<30`02[Zj/0];Bd0;Zj^P2][Jd0_[jn0=7Ad@36a/H0clo?0:n_[`2c/k<0c<c<
0;bl_02h^;P0a<C40<30`0020;bl_00U0;>c/`3<c<`0^;Rh0<K6aP2j^[X0c<c<0=WIf@3AdM40clo?
0=WIf@32`/80_[jn0<K6aP2j^[X0_;bl0;Jf]P2h^;P0/K6a0;Zj^P2l_;`0];Bd0<30`038b<P0`/;2
0<30`034a<@0`/;20:FUY@2][Jd0a/K60;6a/@3AdM40_[jn0;Rh^02j^[X0dm?C0=7Ad@020;Zj^P0C
0<o?c`2d];@0cLg=0<30`02l_;`0b/[:07]kN`2j^[X0^;Rh0<C4a03Shn<0cLg=0=GEe@34a<@0`<30
0<[:bP2n_[h0dM7A0=gMg@020;6a/@030<c<c02IVIT0a/K60080a/K600d0^[Zj0<[:bP2l_;`0][Jf
0<30`03=cLd0^[Zj0;Rh^034a<@0^[Zj0<C4a03MgMd0a<C401h0oooo00P0^k^k0<c<c02g]kL0aLG5
0;bl_032`/80_;bl0<?3``80_;bl00l0Zj^[0;:b/P2l_;`0/;2`0<30`03AdM40`l?30<k>cP2`/;00
]kNg0<k>cP2l_;`0^KVi0<G5a@32`/800P2l_;`03P2f][H0c<c<0;^k^`37alL0_;bl0<c<c03Hf=P0
fm_K0<k>cP3Fe]H0`/;20;^k^`32`/80]kNg0`2i^KT0502b/[80^k^k0;bl_02i^KT0`l?30<[:bP32
`/80`<300<G5a@2n_[h0Y:BT0;2`/03:b/X0]kNg0=SHf037alL0^k^k0;bl_03Cdm<0dM7A0P2l_;`0
3@3:b/X0];Bd0<c<c030`<00^k^k0<O7a`22PX80^k^k0;Vi^@3<c<`0gMgM0<W9b@3?cll00P33`l<0
103:b/X0`<300<c<c03Kfm/20;Bd]0030<O7a`2NWYh0aLG50080aLG500d0^k^k0<W9b@2l_;`0]kNg
0<30`03<c<`0^k^k0;Jf]P30`<00^k^k0<?3``3Fe]H0`<3001T0oooo000G0?ooo`0=0;6a/@36a/H0
`<300:VYZ@30`<00a<C40;jn_P2f][H0`<300;Rh^036a/H0b/[:0;>c/`020<S8b00R0;Jf]P32`/80
b<S80<g=c@3:b/X0cLg=0<C4a032`/80a/K60<o?c`2l_;`0/k>c0<;2`P2n_[h0b<S80<g=c@32`/80
^[Zj0<S8b02n_[h0[Jf]0;6a/@3?cll0Ogmo0<g=c@2YZJT0^;Rh0:n_[`2a/K40a<C40<S8b032`/80
_[jn0;Jf]P80_;bl00<0c<c<0<K6aP38b<P00P2n_[h06@2d];@0_[jn0<C4a02n_[h0_;bl0;Rh^02_
[jl0a/K60<C4a03:b/X0eMGE0<C4a02f][H0a/K60<30`02_[jl0`<300;Rh^02n_[h0cLg=0<30`03?
cll0c<c<0<C4a038b<P00P2n_[h05P2j^[X0dM7A0;jn_P32`/80^[Zj0<[:bP24Q8@0b<S80=?Cd`2h
^;P0][Jf0;jn_P30`<00c<c<0<C4a02_[jl0YjNW0;Bd]032`/80a<C40;>c/`3AdM4N0?ooo`0^0;Bd
]037alL0`/;20:f][@32`/80aLG50<30`02i^KT0`/;20;^k^`37alL0bLW90;Bd]039bLT0alO70;^k
^`32`/80`l?30<k>cP3:b/X0clo?0<?3``32`/80alO70=7Ad@2l_;`0];Bd0<;2`P2n_[h0bLW90<k>
cP33`l<0_;bl0<W9b@2n_[h0[jn_0;:b/P3>c/h0P8200<k>cP2[Zj/0]kNg0;2`/02_[jl0`l?30<[:
bP80`/;200H0^k^k0<30`02l_;`0b/[:0<?3``35aLD20;jn_P050;Ng]`30`<00`l?30;jn_P2l_;`0
0P2i^KT02P3>c/h0`/;20<O7a`3AdM40`l?30;^k^`37alL0_[jn0;2`/033`l<20;^k^`060<c<c02l
_;`0b/[:0<O7a`32`/80bLW90P30`<004P2k^k/0clo?0;jn_P32`/80_;bl0<W9b@2;Rh/0alO70<o?
c`2`/;00^KVi0;jn_P32`/80c<c<0<G5a@2`/;00ZZZZ0;Jf]P80`/;200<0];Bd0<o?c`3oool0603o
ool001L0oooo02H0c<c<0;Jf]P2j^[X0_[jn0<K6aP38b<P0`<300<K6aP30`<00^;Rh0;bl_02j^[X0
_[jn0<;2`P2a/K40];Bd0<c<c02d];@0_[jn0;bl_030`<00XJ6Q0;Zj^P3:b/X0];Bd0<g=c@2f][H0
_[jn0<S8b02n_[h0_;bl0=7Ad@2h^;P0][Jf0;Rh^02j^[X0PX:20;Zj^P80[Jf]03<0`<300>?Sh`34
a<@0a/K60<30`02][Jd0[jn_0;Jf]P30`<00dm?C0<[:bP2j^[X0[Jf]09:BTP2WYjL0^;Rh0;Bd]02U
YJD0cLg=0<C4a02c/k<0ZJVY0<S8b02a/K40][Jf0>7Qh@3AdM40];Bd09nOW`2_[jl0iNGU0<C4a03?
cll0emOG0<30`02c/k<0][Jf0<;2`P3?cll0/k>c0<c<c03Cdm<0fMWI0<o?c`36a/H0`<300<o?c`3:
b/X0hN7Q0<o?c`3AdM400P2n_[h02P3:b/X0];Bd0<[:bP3=cLd0c<c<0<S8b02c/k<0`<300<S8b034
a<@20<[:bQh0oooo05T0b/[:0;Vi^@2l_;`0`<300<O7a`39bLT0_[jn0<?3``2n_[h0^KVi0;bl_02i
^KT0_;bl0<?3``2d];@0]kNg0<c<c02g]kL0_[jn0<;2`P35aLD0YZJV0;bl_035aLD0/[:b0<W9b@2f
][H0_[jn0<G5a@32`/80`<300=7Ad@2k^k/0^KVi0;bl_02i^KT0Rh^;0<30`02_[jl0[Jf]0;bl_03H
f=P0`/;20<G5a@30`<00[jn_0;:b/P2g]kL0`<300=7Ad@39bLT0^KVi0:f][@2NWYh0Y:BT0;Jf]P2b
/[80ZZZZ0<W9b@30`<00];Bd0:^[Z`37alL0/[:b0;Vi^@3Ogml0fm_K0;Vi^@2TY:@0/[:b0>7Qh@33
`l<0b/[:0=7Ad@2l_;`0/[:b0;Jf]P30`<00c<c<0;^k^`39bLT0eMGE0=[JfP3<c<`0`/;20;bl_03:
b/X0bLW90=gMg@020<c<c00<0<30`02n_[h0alO70;Bd]03:b/X0`l?30<[:bP37alL0];Bd0<;2`P35
aLD0`/;20P39bLTI0?ooo`005`3oool0202a/K40];Bd0<c<c036a/H0a<C40<30`032`/80a/K60`2l
_;`0?`2_[jl0^;Rh0;Rh^02l_;`0][Jf0;>c/`2f][H0^[Zj0<C4a02f][H0];Bd0<c<c02n_[h0WinO
0;>c/`2j^[X0b/[:0<c<c034a<@0cLg=0<K6aP2j^[X0][Jf0<c<c02YZJT0[jn_0<S8b02c/k<0`<30
0<c<c03:b/X0cLg=0<K6aP2n_[h0Xj>S0;>c/`3IfMT0clo?0;bl_02d];@0b<S80:FUY@2WYjL0SXj>
0:FUY@2d];@0a<C40:f][@3?cll0a/K60<o?c`2d];@0][Jf0:>SX`32`/80Zj^[0<30`032`/80a/K6
0<;2`P36a/H0/K6a0<30`0020<K6aP0M0;jn_P2c/k<0_;bl0<[:bP2_[jl0WinO0<[:bP32`/80clo?
0<;2`P2j^[X0`<300<C4a03:b/X0clo?0<[:bP32`/80eMGE0;Bd]02_[jl0^[Zj0<S8b02j^[X0b/[:
0<C4a02n_[h0_;bl0<o?c`32`/807P3oool02@2g]kL0];Bd0<c<c037alL0aLG50<;2`P30`<00`l?3
0;^k^`020;bl_01?0:n_[`2g]kL0^k^k0;jn_P2f][H0];Bd0;Vi^@2k^k/0alO70;^k^`2d];@0bLW9
0;bl_02TY:@0][Jf0;bl_03:b/X0c<c<0<G5a@3>c/h0`l?30;Vi^@2f][H0c/k>0;2`/02b/[80bLW9
0;Vi^@33`l<0c<c<0<[:bP3>c/h0aLG50;jn_P2VYZH0][Jf0=KFeP3>c/h0_;bl0;Ng]`39bLT0ZZZZ
0:JVYP2EUID0YZJV0;Ng]`32`/80Zj^[0<[:bP35aLD0c/k>0;Jf]P2g]kL0YZJV0<30`02`/;00`/;2
0<?3``37alL0`/;20<G5a@2b/[80`<300<G5a@33`l<0`<300;Jf]P2n_[h0b/[:0;2`/02TY:@0aLG5
0<30`03<c<`0`<300;Vi^@30`<00`l?30<O7a`020<[:bP0=0<;2`P3AdM40];Bd0:f][@32`/80alO7
0;^k^`39bLT0aLG50<30`02n_[h0c/k>0<;2`P0I0?ooo`005`3oool0502d];@0a/K60;Rh^02h^;P0
emOG0<[:bP3<c<`0_;bl0<;2`P30`<00`/;20<S8b036a/H0_[jn0;bl_034a<@0/K6a0<K6aP2n_[h0
dm?C0P34a<@01P32`/80cLg=0;jn_P32`/80_;bl0<;2`P80a<C400<0`/;20<g=c@2a/K400P2n_[h0
4@2l_;`0/k>c0:NWY`2n_[h0YJFU0:f][@2j^[X0/k>c0;Jf]P2][Jd0WinO0<c<c03:b/X0][Jf08J6
QP2a/K40_[jn0080/k>c00@0^;Rh0<30`02_[jl0a<C40P3:b/X07`2h^;P0/K6a0;Rh^02c/k<0a/K6
0<g=c@30`<00_[jn0=gMg@3<c<`0`<300=GEe@2f][H0b<S80:VYZ@2l_;`0eMGE0<[:bP3QhN40`/;2
0<[:bP3AdM40b/[:0<o?c`3:b/X0a<C40=GEe@3<c<`0cLg=0;Zj^P3Ogml00P3AdM40303Kfm/0];Bd
0<c<c02h^;P0`/;208B4Q02c/k<0a/K60;bl_03:b/X0eMGE0;Zj^Qh0oooo01P0]kNg0<W9b@35aLD0
aLG50>7Qh@3:b/X0c<c<0;jn_P33`l<0`<300<;2`P39bLT0b/[:0<30`02n_[h0aLG50;Bd]037alL0
`<300=?Cd`35aLD0bLW90<?3``3Cdm<20<G5a@0@0;jn_P33`l<0aLG50<W9b@33`l<0c/k>0;Bd]030
`<00_[jn0<30`02g]kL0[Jf]0<;2`P2b/[80]kNg0<?3``80^KVi00P0][Jf0:JVYP3<c<`0bLW90;Ng
]`2<S8`0/[:b0;jn_P80];Bd00@0^KVi0<30`02`/;00`l?30P37alL0;@2i^KT0/[:b0;^k^`2f][H0
bLW90<o?c`32`/80_[jn0=KFeP39bLT0_;bl0=?Cd`2i^KT0`l?30:f][@2n_[h0dM7A0<W9b@3Ogml0
`l?30<c<c03Cdm<0c<c<0<k>cP37alL0`/;20=7Ad@3<c<`0dM7A0;bl_03Jf]X0c<c<0=?Cd`3QhN40
`<300<k>cP2l_;`0aLG508b<S02k^k/0alO70;jn_P35aLD0e]KF0;jn_P0I0?ooo`005`3oool00`2[
Zj/0^[Zj0<;2`P020<30`0090<c<c030`<00_[jn0<[:bP2j^[X0_;bl0<g=c@2f][H0_[jn0080`/;2
0P38b<P07036a/H0_;bl0:n_[`38b<P0eMGE0<K6aP3<c<`0a<C40;Zj^P34a<@0b<S80;Zj^P36a/H0
a<C40=?Cd`30`<00/K6a0<K6aP3<c<`0b/[:0<C4a03MgMd0dm?C0<;2`P2j^[X0[jn_0<30`03=cLd2
0<c<c008092@T02j^[X0b<S80<30`02l_;`0^;Rh0:n_[`30`<020<C4a0030<;2`P2c/k<0`/;20080
`<3000d0UYJF0;jn_P3EeMD0b<S80:n_[`3Cdm<0/K6a0<30`036a/H0cLg=0<[:bP3<c<`0b/[:00<0
`<3000/0a/K60;Rh^02n_[h0dM7A0;jn_P2f][H0^;Rh0;jn_P38b<P0`/;20<g=c@020=OGe`80eMGE
00/0Zj^[0<C4a02d];@0_;bl0;Bd]03MgMd0c<c<0<30`03<c<`0b/[:0;jn_P0N0?ooo`030;Bd]02n
_[h0`/;20080`<3000@0c/k>0<;2`P30`<00b/[:0P2l_;`08P3>c/h0^KVi0<30`033`l<0_[jn0<[:
bP39bLT0alO70;jn_P2b/[80alO70=GEe@37alL0c<c<0<W9b@32`/80alO70<W9b@2l_;`0`/;20<G5
a@3Cdm<0`/;20;Bd]032`/80alO70<G5a@33`l<0gMgM0=7Ad@32`/80_;bl0:n_[`2l_;`20<O7a`0:
0<[:bP2EUID0^k^k0<G5a@33`l<0^KVi0;Ng]`2`/;00`<300<G5a@80`/;200`0];Bd0<;2`P30`<00
`l?309jNWP2n_[h0dm?C0<W9b@2b/[80e]KF0;Ng]`30`<020<G5a@030<W9b@3Cdm<0alO700<0`<30
01X0aLG50;Vi^@2n_[h0clo?0;jn_P2g]kL0^KVi0;jn_P39bLT0_[jn0<[:bP3Kfm/0e]KF0<o?c`3C
dm<0Zj^[0<?3``2f][H0_[jn0;bl_03Fe]H0alO70<30`03:b/X0aLG50;^k^aT0oooo000G0?ooo`0:
0;6a/@2_[jl0^[Zj0;Zj^P36a/H0a<C40<30`034a<@0b<S80<K6aP80cLg=00/0a/K60<;2`P2f][H0
b/[:0<;2`P3<c<`0b<S80:n_[`2j^[X0a<C40;6a/@020<c<c00Y09nOW`2l_;`0fMWI0<;2`P30`<00
dM7A08B4Q038b<P0`/;20<g=c@2h^;P0YjNW0<g=c@2a/K40];Bd0;bl_03<c<`0[Jf]0<c<c02WYjL0
/k>c0<30`02f][H0^[Zj0;Rh^02n_[h0b<S80<30`02_[jl0];Bd0;Jf]P32`/80^;Rh0;jn_P2d];@0
clo?0<30`038b<P0clo?09BDU03:b/X00P32`/801@2d];@0[jn_0;Bd]02f][H0_[jn00<0][Jf00L0
c<c<0;Rh^02n_[h0`<300:VYZ@2l_;`0c<c<0080eMGE01@0^[Zj0;bl_02l_;`0dM7A0<g=c@2_[jl0
`<300;jn_P2_[jl0_;bl0<g=c@3^k^h0SXj>0<30`038b<P0a/K60;Bd]03=cLd0b/[:0;Jf]Qh0oooo
0P2d];@20;bl_0060<O7a`32`/80`l?30<O7a`3:b/X0alO70P3>c/h02`37alL0`l?30;Vi^@3:b/X0
`l?30<c<c037alL0/[:b0;bl_035aLD0];Bd0080c<c<01P0Z:RX0;jn_P3EeMD0`l?30<;2`P3Cdm<0
RHV90<G5a@30`<00clo?0<O7a`2b/[80bLW90;:b/P2d];@0_;bl0<c<c02_[jl0bLW90:RXZ02b/[80
`<300;:b/P2g]kL20;^k^`0f0<O7a`2n_[h0[jn_0;Bd]02f][H0bLW90;Ng]`2i^KT0/[:b0<c<c02n
_[h0bLW90<o?c`2JVYX0b/[:0;jn_P30`<00][Jf0;2`/02b/[80]kNg0;jn_P2f][H0];Bd0;Ng]`3:
b/X0^KVi0;jn_P32`/80ZZZZ0;^k^`39bLT0eMGE0=?Cd`2k^k/0_;bl0<?3``3AdM40b/[:0:ZZZP32
`/80`<300;:b/P32`/80eMGE0>OWi`24Q8@0alO70<W9b@35aLD0^KVi0<o?c`37alL0^k^k6@3oool0
01L0oooo00/0b<S80<30`038b<P0a<C40:f][@34a<@0][Jf0;bl_03:b/X0][Jf0<;2`P020<S8b01<
0;Zj^P3:b/X0/k>c0:n_[`1kNg/0^[Zj0<30`03<c<`0_;bl0<K6aP32`/80a<C40<30`02j^[X0_[jn
0=7Ad@30`<00b/[:0<C4a03:b/X0`/;20=?Cd`3=cLd0^;Rh0;Zj^P3EeMD0S8b<0<C4a03:b/X0^;Rh
0:^[Z`2YZJT0][Jf0;6a/@2f][H0^;Rh0<[:bP2j^[X0^;Rh0<30`02h^;P0XJ6Q0;bl_036a/H0`<30
0;Zj^P2l_;`0eMGE0<[:bP3=cLd0V9RH0<o?c`2][Jd0`<300;6a/@3Cdm<0^[Zj0<K6aP2l_;`0a/K6
0<S8b032`/80a<C40<;2`P2n_[h0`/;20<c<c032`/80dM7A0<c<c034a<@0eMGE0=?Cd`38b<P0clo?
0<;2`P80cLg=00h0a<C40<[:bP3GemL0c<c<0<K6aP3<c<`0dm?C0;bl_03<c<`0b<S80;Rh^034a<@0
b/[:0<;2`Qh0oooo00X0b/[:0<;2`P39bLT0aLG50;2`/03:b/X0^k^k0<30`03<c<`0_[jn0`39bLT0
2`2l_;`0b/[:0;Jf]P2b/[80Q8B40;^k^`32`/80c<c<0;jn_P37alL0`l?30080aLG50P2l_;`05P3A
dM40`/;20<c<c032`/80alO70<30`03Hf=P0dm?C0;jn_P2g]kL0f=SH092@T033`l<0b/[:0;Vi^@2[
Zj/0ZZZZ0;Jf]P2_[jl0][Jf0;Ng]`37alL20;Vi^@060;jn_P2g]kL0YZJV0;jn_P39bLT0_[jn0P30
`<00303EeMD0b/[:0<[:bP2JVYX0clo?0;2`/02l_;`0/;2`0=7Ad@2k^k/0bLW90;jn_P80bLW90P33
`l<07@32`/80_[jn0<;2`P3<c<`0`<300<k>cP39bLT0alO70=?Cd`3AdM40alO70<o?c`33`l<0c/k>
0=GEe@35aLD0b/[:0<o?c`39bLT0`/;20<W9b@3Hf=P0`l?30<W9b@37alL0_;bl0<O7a`3>c/h0`l?3
01T0oooo000G0?ooo`0d0:n_[`2a/K40_[jn0;Zj^P2MWId0^[Zj0;>c/`2j^[X0[jn_0;>c/`32`/80
^;Rh0:n_[`2f][H0`<300<[:bP2j^[X0YjNW0<S8b034a<@0b/[:0<K6aP3?cll0UYJF0;Jf]P2n_[h0
cLg=0<K6aP38b<P0^[Zj0<S8b03<c<`0b<S80:n_[`3?cll0];Bd0<[:bP2h^;P0WinO0:VYZ@2c/k<0
`<300:>SX`2l_;`0^;Rh0;Jf]P2j^[X0`<300<K6aP2a/K40a/K60;jn_P80^[Zj01/0U9BD0<30`02]
[Jd0][Jf0=GEe@2n_[h0`/;20:f][@3=cLd0/k>c0<g=c@2c/k<0][Jf0;>c/`2@T900b<S80:n_[`2a
/K40`/;20;Jf]P2][Jd0][Jf0=?Cd`30`<00dm?C0;Jf]P36a/H00P3:b/X05P3=cLd0c<c<0;Jf]P32
`/80`<300;Zj^P34a<@0Xj>S0<[:bP32`/80a/K60<;2`P2c/k<0_;bl0>c/k032`/80][Jf0;Rh^03Q
hN40`/;20<30`02j^[XN0?ooo`0d0;Jf]P2g]kL0`<300;^k^`2QXJ40_[jn0;bl_032`/80];Bd0;Ng
]`35aLD0^k^k0;Bd]02g]kL0`<300<W9b@2k^k/0[Jf]0<O7a`35aLD0alO70<G5a@3>c/h0VYZJ0;Ng
]`32`/80clo?0<W9b@3:b/X0_;bl0<W9b@3:b/X0alO70;2`/03?cll0]kNg0<[:bP2i^KT0Xj>S0:f]
[@2f][H0`/;20:JVYP30`<00^k^k0;Jf]P2k^k/0_;bl0<;2`P2_[jl0`l?30;bl_080]kNg01/0UiNG
0;jn_P2`/;00^KVi0<c<c02k^k/0`/;20:n_[`3:b/X0/[:b0<k>cP2f][H0^KVi0;Jf]P2EUID0alO7
0;Bd]02b/[80^k^k0;Bd]02b/[80^KVi0=7Ad@2l_;`0c/k>0;Vi^@35aLD00`39bLT02`3<c<`0^KVi
0<?3``32`/80^k^k0<?3``2VYZH0b/[:0<;2`P35aLD0`/;20080^KVi00P0i>CT0;jn_P2k^k/0]kNg
0=gMg@32`/80`<300;Vi^AT0oooo000G0?ooo`0<0;Zj^P38b<P0`<300<S8b030`<00cLg=0<S8b03:
b/X0`/;20<K6aP30`<00^[Zj0P2l_;`09P2QXJ40_[jn0<C4a034a<@0][Jf0<K6aP2h^;P0b/[:0<K6
aP34a<@0b<S80;Zj^P2h^;P0c<c<0=?Cd`2h^;P0c<c<0;bl_03EeMD0a/K60<30`02SXj<0a/K60:VY
Z@30`<00YjNW0;jn_P2f][H0dm?C0;bl_034a<@0_[jn0<30`02f][H0_;bl0;Zj^P2[Zj/0a/K60P2h
^;P0<`2c/k<0][Jf0=_Kf`2f][H0a<C40;bl_030`<00a<C40;Jf]P3<c<`0dM7A0<30`00J6QX0a<C4
0<K6aP3=cLd0a<C40<c<c032`/80][Jf0<g=c@34a<@0b/[:0;Jf]P3<c<`0b<S80<g=c@3:b/X0a<C4
0;jn_P3AdM40a/K60=_Kf`3Cdm<0VIVI0<30`03<c<`0_;bl0=7Ad@32`/80];Bd0:VYZ@2j^[X0WinO
0<c<c034a<@0k>c/0=?Cd`2WYjL0a<C40<[:bP0N0?ooo`0@0;bl_035aLD0`/;20<W9b@32`/80c/k>
0<W9b@3:b/X0`l?30<W9b@32`/80_;bl0;jn_P2k^k/0YZJV0;bl_080`<3000@0];Bd0<O7a`2k^k/0
b/[:0P35aLD07039bLT0_;bl0<30`03<c<`0dm?C0;bl_03>c/h0_[jn0=GEe@37alL0`/;20:RXZ032
`/80Zj^[0<W9b@2ZZZX0_;bl0;Vi^@3>c/h0_;bl0<?3``2n_[h0_;bl0;Vi^@2n_[h0_;bl0:f][@35
aLD20;Vi^@0H0;2`/02d];@0f][J0;Vi^@3?cll0aLG50;^k^`30`<00^KVi0<W9b@3EeMD0`/;2030`
<03<c<`0bLW90<o?c`33`l<0b/[:0;jn_P2d];@0bLW90<?3``35aLD0];Bd0`37alL06035aLD0`l?3
0<30`03>c/h0`l?30=KFeP3Cdm<0WinO0<30`039bLT0_;bl0<o?c`33`l<0]kNg0:^[Z`2l_;`0Y:BT
0<c<c033`l<0inOW0=7Ad@2ZZZX0`l?30<W9bAT0oooo000G0?ooo`040:n_[`2f][H0/K6a0<[:bP80
`<3001X0`/;20;jn_P32`/80c<c<0;Bd]02h^;P0cLg=0<C4a02n_[h0][Jf0;6a/@32`/80a<C40;Zj
^P3<c<`0a/K60;Jf]P3:b/X0a<C40;jn_P3<c<`0`<300<g=c@34a<@0`/;20=oOg`<0b/[:01l0c<c<
0=OGe`3=cLd0^;Rh0<S8b032`/80_[jn0;Jf]P36a/H0a<C40;Jf]P2SXj<0Zj^[0<C4a03Cdm<0[jn_
0<;2`P2f][H0^;Rh0:FUY@3<c<`0/k>c0:VYZ@2j^[X0`<300;Bd]036a/H0clo?0<C4a03Xj>P0b/[:
0080`/;200`0ZJVY0<;2`P2c/k<0^[Zj0;>c/`2l_;`0`<300<g=c@2l_;`0_[jn0=WIf@34a<@20;jn
_P80a/K60140YjNW0:^[Z`3<c<`0`/;20<C4a02a/K40a/K60<;2`P34a<@0b<S80<30`02c/k<0emOG
0;jn_P34a<@0dm?C0:n_[`030<[:bP030:n_[`3oool0oooo01`0oooo00D0_[jn0<30`02d];@0alO7
0;bl_0020<?3``1@0<30`033`l<0c<c<0;Ng]`2k^k/0bLW90<O7a`32`/80][Jf0;Bd]033`l<0aLG5
0;jn_P3<c<`0bLW90;Ng]`3:b/X0aLG50;jn_P3<c<`0`<300<o?c`35aLD0`l?30=gMg@3:b/X0c<c<
0<W9b@3<c<`0e]KF0<k>cP2i^KT0c/k>0<W9b@2l_;`0][Jf0<c<c039bLT0]kNg0:JVYP2[Zj/0`l?3
0=?Cd`2`/;00`/;20;jn_P2f][H0YZJV0<[:bP2k^k/0Xj>S0;bl_030`<00][Jf0<G5a@3>c/h0c<c<
0>KViP3<c<`0`l?30<30`02ZZZX0`/;20;:b/P2k^k/0][Jf0;jn_P32`/80b/[:0<30`032`/80f][J
0<30`02i^KT0`<300<O7a`33`l<0Zj^[0:f][@39bLT20<;2`P0@0;:b/P37alL0`/;20<;2`P39bLT0
_;bl0;Jf]P3Fe]H0_;bl0<;2`P3>c/h0[Jf]0<O7a`3>c/h0b/[:0;2`/1T0oooo000G0?ooo`0=0:NW
Y`3:b/X0YjNW0<30`038b<P0^[Zj0<g=c@2h^;P0a/K60<S8b03<c<`0^;Rh0:FUY@040;jn_P1<0<;2
`P2j^[X0^[Zj0;jn_P2h^;P0_;bl0<C4a030`<00^[Zj0<30`02][Jd0`/;20<30`038b<P0][Jf0=oO
g`32`/80b/[:0=7Ad@36a/H0[Jf]0<[:bP30`<00eMGE0<K6aP3<c<`0dm?C0;6a/@2][Jd0^;Rh0<30
`02a/K40`/;20<o?c`2l_;`0`/;20;>c/`2d];@0^[Zj0:>SX`2l_;`0c<c<0:VYZ@38b<P0j>SX0<g=
c@34a<@0^[Zj0<C4a038b<P0_;bl0<S8b034a<@0Zj^[08J6QP2c/k<0b/[:0<C4a032`/80^[Zj0;jn
_P3=cLd0`<300<K6aP3IfMT0gmoO0=_Kf`3?cll0^[Zj0<c<c03:b/X0c<c<0;bl_038b<P0_[jn0<c<
c080ZJVY00<0dm?C0;jn_P30`<000P2WYjL01@3IfMT0`<300<;2`P34a<@0^;Rh01h0oooo0240ZZZZ
0<O7a`2b/[80alO70<c<c032`/80c/k>0;^k^`37alL0bLW90<c<c02l_;`0ZZZZ0<30`02l_;`0_[jn
0<30`039bLT0`/;20;jn_P32`/80^k^k0;jn_P35aLD0_[jn0<?3``30`<00][Jf0<O7a`2n_[h0aLG5
0;Vi^@3MgMd00P35aLD04P3Hf=P0`l?30:f][@3:b/X0`<300=?Cd`35aLD0dm?C0<k>cP2`/;00[jn_
0;^k^`30`<00/[:b0<;2`P3>c/h0^k^k0<?3``80]kNg0200_;bl0;Bd]02l_;`0clo?0:f][@3:b/X0
hN7Q0<k>cP35aLD0^k^k0<;2`P35aLD0^k^k0<G5a@32`/80[jn_08j>SP2f][H0bLW90;jn_P39bLT0
_;bl0;jn_P3:b/X0`<300<G5a@3Fe]H0fm_K0=SHf03?cll0_;bl0<c<c080bLW900@0^k^k0<G5a@2n
_[h0b/[:0P2ZZZX02P3Cdm<0aLG50<W9b@2ZZZX0Zj^[0=[JfP30`<00`/;20<?3``2i^KTI0?ooo`00
5`3oool0402d];@0/k>c0=7Ad@2l_;`0b<S80;Rh^03Cdm<0][Jf0;bl_03Cdm<0];Bd0;Zj^P2f][H0
^;Rh0;>c/`38b<P20<K6aP0A0;Zj^P32`/80_[jn0;>c/`2l_;`0a<C40<;2`P3:b/X0cLg=0<C4a02n
_[h0b<S80<c<c03MgMd0fMWI0<K6aP32`/800P3=cLd03P30`<00_[jn0<c<c02n_[h0c<c<0<30`032
`/80dm?C0=GEe@2][Jd0ZJVY0<C4a03=cLd0a<C40P2c/k<03`2j^[X0][Jf0;>c/`2c/k<0^[Zj0<C4
a032`/80[Jf]0<K6aP30`<00];Bd0;Zj^P3<c<`0_;bl0<;2`P020;Rh^00J0<K6aP2h^;P0^;Rh0;Jf
]P2a/K40`<300<;2`P34a<@0dm?C0<g=c@30`<00_;bl0<c<c03IfMT0^[Zj0<;2`P34a<@0eMGE0<c<
c03Cdm<0clo?0<K6aP34a<@0][Jf0:VYZ@36a/H20<30`0070=?Cd`38b<P0];Bd0;bl_03EeMD0_[jn
0<C4a00N0?ooo`0?0;Jf]P2g]kL0c<c<0;^k^`37alL0_;bl0=?Cd`2i^KT0_;bl0=?Cd`2b/[80`<30
0;bl_02i^KT0][Jf00<0bLW903D0_[jn0<?3``30`<00][Jf0;jn_P33`l<0`/;20<O7a`3:b/X0`/;2
0;bl_035aLD0b/[:0=SHf03Fe]H0alO70<?3``3?cll0c<c<0<G5a@30`<00c<c<0<30`03<c<`0`l?3
0<30`03?cll0dM7A0:n_[`2XZ:P0`<300<W9b@3:b/X0][Jf0;Ng]`2n_[h0^KVi0;Bd]02b/[80_;bl
0<G5a@2k^k/0[jn_0<G5a@30`<00]kNg0;^k^`3:b/X0_[jn0<?3``2l_;`0^k^k0<?3``020;Vi^@0P
0;Jf]P2`/;00`<300<;2`P33`l<0dM7A0<c<c035aLD0^KVi0<o?c`3Hf=P0]kNg0<;2`P37alL0eMGE
0<c<c03Cdm<0clo?0<O7a`33`l<0][Jf0:ZZZP37alL0`/;20;bl_03AdM40bLW90;Jf]P30`<00dM7A
0;bl_032`/8I0?ooo`005`3oool03P2c/k<0`/;20<C4a030`<00b/[:0;jn_P30`<00dm?C0;Zj^P2n
_[h0b<S80;bl_03<c<`0/k>c0P2l_;`0:P34a<@0_[jn0;>c/`2h^;P0b/[:0;Rh^034a<@0_[jn0;Rh
^02n_[h0YjNW0;Rh^03AdM40^[Zj0<[:bP2f][H0a<C40;Zj^P3?cll0`<300=GEe@36a/H0[Jf]0<[:
bP3Cdm<0^[Zj0<K6aP34a<@0c<c<0<[:bP38b<P0^[Zj0<S8b030`<00Xj>S0;Zj^P2BTY80Xj>S0:FU
Y@2h^;P0`/;20<o?c`80b<S800H0cLg=0<c<c02c/k<0a/K60<C4a02d];@20<C4a0090;bl_03=cLd0
a<C40;Rh^032`/80^[Zj0<c<c03GemL0_;bl00<0b/[:00H0^[Zj0<S8b03?cll0`<300:NWY`3:b/X2
0<S8b00A0;>c/`34a<@0clo?0=GEe@3?cll0_[jn0<30`03=cLd0dM7A0=WIf@2j^[X0a<C40<30`02l
_;`0^[Zj0<S8b02l_;`07P3oool03P2d];@0bLW90<?3``32`/80c/k>0<?3``37alL0dm?C0;Vi^@2n
_[h0bLW90;jn_P3<c<`0^KVi0P2n_[h09@37alL0`<300;Jf]P2k^k/0b/[:0;^k^`35aLD0`<300;^k
^`2n_[h0ZZZZ0;^k^`3Cdm<0_;bl0<[:bP2i^KT0aLG50;bl_03>c/h0`<300=?Cd`35aLD0ZZZZ0<W9
b@3AdM40^k^k0<?3``37alL0c/k>0<c<c035aLD0^k^k0<O7a`30`<00YZJV0;Vi^@2CTi<00P2TY:@0
0`2f][H0_[jn0<[:bP020<O7a`060<c<c03:b/X0/[:b0<?3``35aLD0/[:b0P35aLD02@2n_[h0c/k>
0<;2`P2g]kL0_[jn0;Ng]`37alL0dM7A0;bl_0030<W9b@0I0;bl_039bLT0clo?0<W9b@2][Jd0b/[:
0<W9b@30`<00^KVi0<G5a@3:b/X0dM7A0<c<c030`<00_;bl0<k>cP3AdM40e]KF0<?3``32`/80`<30
0;jn_P2l_;`0bLW90;bl_00I0?ooo`005`3oool02`2YZJT0][Jf0<[:bP36a/H0^;Rh0;Zj^P34a<@0
][Jf0<;2`P30`<00a<C40080_[jn00<0][Jf0;Zj^P38b<P00P36a/H0802d];@0fMWI0<K6aP2SXj<0
c<c<0<S8b02d];@0clo?0;bl_038b<P0`/;20;Rh^034a<@0clo?0<30`02f][H0/k>c0:f][@3<c<`0
a<C40<30`02n_[h0b<S80<C4a02d];@0`<300;Bd]02QXJ40dm?C0:f][@36a/H0b<S80P36a/H06@2O
Wil0[Jf]0;6a/@2f][H0a<C40<S8b02n_[h0`<300;bl_02QXJ40c<c<0<S8b036a/H0`<300<c<c02f
][H0b<S80;Zj^P2n_[h0c<c<0<o?c`2j^[X0];Bd0<;2`P30`<000`32`/820;Jf]P0G0;Rh^02f][H0
`/;20=GEe@30`<00][Jf0=oOg`38b<P0a<C40<K6aP38b<P0^[Zj0;bl_034a<@0YjNW0;bl_03MgMd0
dM7A0=WIf@3<c<`0`/;20<[:bP2l_;`07P3oool01@2[Zj/0^KVi0<W9b@37alL0_;bl0080`/;200@0
][Jf0<30`032`/80aLG50P2n_[h09@2i^KT0_;bl0<O7a`35aLD0`/;20;:b/P3Cdm<0`<300:BTY039
bLT0alO70;Ng]`3:b/X0^KVi0<O7a`32`/80]kNg0<;2`P37alL0`<300;Bd]02b/[80Zj^[0<O7a`30
`<00_;bl0<30`039bLT0aLG50;Ng]`35aLD0^KVi0:JVYP3AdM40[jn_0<G5a@37alL00P33`l<01P2S
Xj<0[jn_0;Bd]02i^KT0alO70<?3``80`<3000<0`/;20:ZZZP39bLT00P37alL0402n_[h0bLW90;Ng
]`39bLT0`/;20<30`03<c<`0b/[:0;^k^`2i^KT0`l?30<30`033`l<0aLG50<;2`P2i^KT20;Ng]`0F
0;Bd]033`l<0e]KF0;jn_P2g]kL0f=SH0<G5a@33`l<0`/;20<O7a`2g]kL0_[jn0<O7a`2][Jd0_;bl
0=[JfP3<c<`0dm?C0<[:bP32`/80bLW90;Vi^AT0oooo000G0?ooo`030;jn_P2_[jl0`/;20080b<S8
00<0`<300=?Cd`3<c<`00P2h^;P02P2f][H0_[jn0;Jf]P2f][H0`<300<K6aP3?cll0dm?C0;jn_P2l
_;`20<;2`P070;bl_03<c<`0^;Rh0<C4a02h^;P0_[jn0<g=c@020;bl_00E0<30`032`/80^;Rh0;>c
/`2f][H0a/K60>[ZjP2h^;P0^[Zj0;bl_02n_[h0b/[:0;bl_02d];@0_[jn0<[:bP2l_;`0b<S80;6a
/@2f][H0/k>c0080`/;201h0];Bd0<30`02n_[h0_[jn0<;2`P3<c<`0_;bl0;jn_P2_[jl0c<c<0;Zj
^P34a<@0/k>c0<S8b03EeMD0dM7A0<C4a02n_[h0a/K60<g=c@3GemL0dm?C0;Jf]P30`<00_;bl0<30
`02d];@0`<300<[:bP34a<@20<c<c00C0<o?c`3Cdm<0clo?0=?Cd`32`/80c<c<0;Jf]P2a/K40XJ6Q
09^KV`30`<00a/K60<C4a036a/H0c<c<0<30`036a/H0XJ6Q0;bl_00N0?ooo`030<?3``2][Jd0b/[:
0080clo?00<0_;bl0=KFeP3>c/h00P2k^k/0702i^KT0_[jn0;Ng]`2k^k/0`l?30<;2`P3:b/X0eMGE
0<;2`P2n_[h0`l?30<O7a`32`/80c<c<0;^k^`37alL0^k^k0;bl_03>c/h0`/;20;jn_P2l_;`0`<30
0;Vi^@2f][H0];Bd0<?3``3Vi^H20;Vi^@0<0;bl_030`<00b/[:0;bl_02f][H0_[jn0<[:bP2k^k/0
alO70;Bd]02g]kL0];Bd0P32`/807P2g]kL0`/;20;^k^`2k^k/0_[jn0<O7a`39bLT0_[jn0:n_[`35
aLD0_;bl0<?3``2`/;00`l?30=7Ad@3>c/h0`l?30<30`033`l<0b/[:0=?Cd`3?cll0];Bd0;bl_02i
^KT0`/;20;Ng]`32`/80b/[:0<G5a@80b/[:01<0clo?0=?Cd`3<c<`0dM7A0<?3``3:b/X0]kNg0;2`
/02SXj<0XJ6Q0<30`033`l<0_;bl0<;2`P37alL0^k^k0<?3``2TY:@0^KVi01T0oooo000G0?ooo`0>
0:^[Z`3=cLd0];Bd0<C4a030`<00Zj^[0<30`02WYjL0/k>c0<K6aP2j^[X0b<S80<30`02f][H20<K6
aP0i0;6a/@2j^[X0_;bl0<c<c032`/80[jn_0;Jf]P36a/H0];Bd0;jn_P2][Jd0^;Rh0=_Kf`2a/K40
a/K609RHV02j^[X0][Jf0=oOg`3MgMd0^;Rh0=7Ad@2j^[X0];Bd0<C4a02WYjL0][Jf0<g=c@30`<00
];Bd0;Jf]P2c/k<0b/[:0;Bd]02c/k<0`/;20<K6aP2a/K40_;bl0<K6aP2_[jl0dM7A0;Bd]02KVi/0
^;Rh09fMW@3IfMT0a/K60<S8b034a<@0dm?C0;6a/@3Cdm<0/K6a0<C4a03<c<`0dM7A0080`<3000d0
a/K608j>SP2j^[X0][Jf0<g=c@2l_;`0`<300<o?c`3:b/X0j>SX0<c<c02SXj<0c<c<0080b<S800D0
cLg=0<[:bP38b<P0_[jn0:^[Z`020;Rh^0080:NWY`34a<@0`/;20<c<c02a/K40Xj>S0<C4a02f][HN
0?ooo`190;2`/039bLT0]kNg0<G5a@32`/80Zj^[0<O7a`2][Jd0][Jf0<?3``2i^KT0bLW90<G5a@2i
^KT0alO70<W9b@2f][H0^k^k0;bl_039bLT0_[jn0;Jf]P2i^KT0`/;20;Jf]P2l_;`0Zj^[0;^k^`3M
gMd0/;2`0<?3``2NWYh0_;bl0;Vi^@3MgMd0fm_K0;^k^`3?cll0^KVi0;^k^`37alL0Zj^[0;^k^`3:
b/X0`<300;Ng]`2i^KT0];Bd0<W9b@2f][H0_;bl0<G5a@37alL0[jn_0;Vi^@32`/80/;2`0=7Ad@2g
]kL0WinO0;Ng]`2NWYh0eMGE0<G5a@3:b/X0alO70=?Cd`2b/[80c/k>0:n_[`30`<00alO70<k>cP02
0;jn_P0D0<?3``2@T900^k^k0;Bd]03:b/X0_;bl0<30`03>c/h0b/[:0>7Qh@37alL0YZJV0<[:bP39
bLT0b/[:0=?Cd`3<c<`0alO70;jn_P2_[jl20;^k^`0809nOW`33`l<0aLG50<o?c`2`/;00Y:BT0<G5
a@2f][HI0?ooo`005`3oool0:`36a/H0b/[:0<[:bP34a<@0`/;20<[:bP36a/H0_[jn0;Zj^P30`<00
[jn_0<K6aP2h^;P0b/[:0<K6aP34a<@0b/[:0;6a/@32`/80/K6a0;jn_P2YZJT0^;Rh0<30`02h^;P0
c<c<0;jn_P34a<@0_[jn0;Zj^P3<c<`0b<S80=?Cd`30`<00][Jf0;bl_030`<00YjNW0;jn_P38b<P0
clo?0=7Ad@38b<P00P3<c<`01030`<00^[Zj0<K6aP3:b/X20;Rh^00>0<K6aP2d];@0^[Zj0:VYZ@2]
[Jd0a<C40<;2`P3?cll0_[jn0<c<c02h^;P0Zj^[0<o?c`3<c<`20=?Cd`0V0<c<c032`/80clo?0<S8
b02][Jd0gMgM0<g=c@2SXj<0`<300;Rh^02KVi/0Xj>S0=?Cd`3GemL0clo?0<[:bP32`/80a/K608:2
PP3=cLd0dm?C0:f][@36a/H0c<c<0;Rh^03AdM40XJ6Q0;jn_P1mOGd0/K6a0=GEe@2j^[X0SXj>0<;2
`P38b<P0a<C408b<S03Kfm/N0?ooo`0=0<O7a`35aLD0b/[:0<G5a@33`l<0b/[:0<W9b@30`<00^KVi
0<;2`P2b/[80alO70;^k^`020<c<c00D0;jn_P35aLD0/;2`0;jn_P2d];@0`/;20;2`/02n_[h0_;bl
0;Ng]`3<c<`0`<300<;2`P2l_;`0^KVi0<W9b@3:b/X0dm?C0<;2`P2l_;`20<?3``0X0:ZZZP2k^k/0
alO70<k>cP3?cll0b/[:0=?Cd`37alL0`/;20;^k^`35aLD0bLW90;Vi^@2f][H0`/;20;Bd]02i^KT0
ZZZZ0:f][@30`<00_[jn0<c<c02l_;`0c<c<0;Ng]`2_[jl0dM7A0<[:bP3AdM40clo?0<W9b@37alL0
bLW90<?3``2[Zj/0e]KF0<[:bP2XZ:P0`/;20;^k^`80Y:BT01X0c/k>0=[JfP3?cll0c<c<0<W9b@37
alL0PX:20=KFeP3>c/h0]kNg0<O7a`3>c/h0_;bl0=7Ad@2VYZH0`<3007UiN@2`/;00f=SH0<;2`P2C
Ti<0`/;20<W9b@33`l<0UiNG0=GEeAT0oooo000G0?ooo`0k0<30`02l_;`0a<C40<[:bP32`/80_[jn
0;Rh^02j^[X0];Bd0;jn_P32`/80b<S80;Zj^P2c/k<0`<300<;2`P2[Zj/0dM7A0<C4a03:b/X0_;bl
0;jn_P30`<00c<c<0<S8b036a/H0[jn_0:>SX`2d];@0_;bl0<S8b030`<00][Jf09JFUP3EeMD0b/[:
0;Rh^032`/80b/[:0=GEe@36a/H0`/;20;Bd]038b<P0^;Rh0:VYZ@3:b/X0cLg=0=?Cd`2a/K40`<30
0;Zj^P38b<P0];Bd0;>c/`36a/H0`<300<C4a02UYJD00P2d];@06`2f][H0b/[:0=7Ad@3:b/X0a<C4
0=_Kf`2f][H0b/[:0;jn_P34a<@0dM7A0;Zj^P30`<00a<C40<c<c02h^;P0Vi^K0;6a/@32`/80a/K6
0<g=c@36a/H0`<300<o?c`2][Jd0_;bl0:VYZ@020<S8b00?0;jn_P3:b/X0HV9R0;Jf]P3IfMT0Xj>S
092@T03GemL0/k>c0:NWY`2h^;P0VIVI0;>c/`30`<00a<C401h0oooo0180`/;20<?3``35aLD0b/[:
0<?3``30`<00][Jf0;Vi^@2f][H0_;bl0;jn_P39bLT0_;bl0;:b/P2n_[h0`l?30:n_[`3AdM420<G5
a@0J0<30`037alL0bLW90=7Ad@3>c/h0`/;20;:b/P2ZZZX0^KVi0;jn_P39bLT0_[jn0;Jf]P2HV9P0
e]KF0<o?c`30`<00bLW90<[:bP3EeMD0alO70<?3``2d];@0bLW90;^k^`2][Jd20<W9b@0;0<k>cP2_
[jl0`/;20;bl_035aLD0];Bd0;:b/P33`l<0_[jn0<;2`P2QXJ400P2f][H06`2g]kL0b/[:0=7Ad@3:
b/X0aLG50=KFeP2g]kL0alO70;^k^`39bLT0dM7A0;Vi^@2n_[h0`/;20<c<c02d];@0WYjN0;Ng]`32
`/80`l?30<c<c037alL0`<300<k>cP2b/[80bLW90:f][@020<o?c`0=0<O7a`33`l<0HF5Q0;Ng]`3C
dm<0WinO09FEU@3MgMd0/;2`0:JVYP2k^k/0YZJV0;Jf]P020<G5aAT0oooo000G0?ooo`0b0;Jf]P34
a<@0c<c<0=7Ad@2d];@0YJFU0<[:bP2j^[X0eMGE0;Rh^02l_;`0_[jn0:f][@2l_;`0][Jf0<30`02_
[jl0c<c<0;Rh^02l_;`0a<C40;Jf]P34a<@0b<S80<;2`P38b<P0fMWI0;>c/`3:b/X0/K6a0=7Ad@36
a/H0[jn_0=WIf@36a/H0/k>c0<S8b02n_[h0fMWI0<30`03AdM40_;bl0<c<c03IfMT0];Bd0<c<c038
b<P0gMgM0;6a/@38b<P20;jn_P0e0;Zj^P2[Zj/0a<C40<S8b02c/k<0emOG0<[:bP2n_[h0a/K60;jn
_P32`/80_;bl0<K6aP3Cdm<0^;Rh0;>c/`34a<@0eMGE0<o?c`3<c<`0ZJVY0:f][@36a/H0][Jf0;jn
_P3GemL0`<300;Jf]P2[Zj/0[Jf]0;jn_P2j^[X0dM7A0;Bd]02j^[X0^;Rh0<K6aP3QhN40`<300;Zj
^P2[Zj/0/K6a09fMW@2SXj<0YjNW0:^[Z`32`/80];Bd0:^[Z`3IfMT0m_Kf0<[:bP3lo?`07P3oool0
5P2k^k/0`l?30<O7a`3AdM40`<300:ZZZP3:b/X0_;bl0=KFeP2l_;`0_[jn0<30`02`/;00^k^k0;Jf
]P35aLD0][Jf0<c<c02k^k/0`l?30<[:bP2l_;`20<W9b@0J0<?3``35aLD0dm?C0;Bd]039bLT0];Bd
0=7Ad@37alL0][Jf0=SHf037alL0][Jf0<O7a`2l_;`0f=SH0<;2`P3AdM40_[jn0<W9b@3>c/h0/[:b
0<c<c035aLD0eMGE0;:b/P3>c/h20<30`00D0;bl_02_[jl0^k^k0<30`02`/;00c<c<0<[:bP30`<00
alO70<30`032`/80_;bl0<;2`P3>c/h0];Bd0:n_[`39bLT0b/[:0<k>cP3:b/X20:^[Z`0O0<?3``2g
]kL0_;bl0<k>cP32`/80];Bd0:ZZZP2_[jl0`l?30;Jf]P3<c<`0][Jf0;bl_02g]kL0`<300=?Cd`32
`/80_;bl0:n_[`2][Jd0Xj>S0;2`/02_[jl0Zj^[0<30`02f][H0[jn_0>7Qh@3]kNd0bLW90?knoP0I
0?ooo`005`3oool0:P2f][H0`<300:f][@2l_;`0b<S80<K6aP38b<P0cLg=0;jn_P2j^[X0b/[:0;jn
_P38b<P0][Jf0;6a/@2d];@0`/;20<30`038b<P0_[jn0;bl_02d];@0ZJVY0=GEe@3:b/X0_;bl0<;2
`P2j^[X0c<c<0;Zj^P3<c<`0`/;20<S8b02KVi/0cLg=0;>c/`2n_[h0a<C40;bl_038b<P0iNGU0=7A
d@80emOG02P0][Jf0;Bd]02f][H0dM7A0;jn_P3?cll0][Jf0;jn_P2l_;`0/k>c0:n_[`2c/k<0a/K6
0<;2`P2YZJT0/k>c0<[:bP3UiND0dM7A0<c<c03Kfm/0^[Zj0<S8b03Cdm<0gMgM0<30`034a<@0a/K6
0<[:bP2n_[h0a/K60<o?c`3=cLd0`/;20=7Ad@3?cll0b/[:0<;2`P30`<00`/;20P36a/H00`3:b/X0
`<300=7Ad@020<S8b00>0;Jf]P2c/k<0][Jf0;Jf]P36a/H0cLg=0;Rh^030`<00_[jn0<g=c@3<c<`0
_;bl0;Zj^P3:b/XN0?ooo`0c0;Vi^@32`/80[Jf]0;^k^`35aLD0bLW90<O7a`3<c<`0_[jn0;bl_03:
b/X0`<300<W9b@2i^KT0];Bd0;Vi^@35aLD0`l?30<[:bP30`<00_[jn0;Bd]02ZZZX0dM7A0<[:bP2l
_;`0`/;20;bl_03:b/X0_;bl0<W9b@32`/80alO709nOW`3:b/X0][Jf0<30`033`l<0_;bl0<o?c`3R
h^80c/k>0=[JfP3AdM40^KVi0;bl_02i^KT0clo?0;jn_P3>c/h0^k^k0080_[jn00<0][Jf0:n_[`2b
/[800P33`l<0302`/;00]kNg0<O7a`3Ogml0eMGE0<W9b@3EeMD0]kNg0<?3``3>c/h0f=SH0;jn_P80
aLG500H0c/k>0<30`035aLD0b/[:0<c<c030`<020<c<c00I0<W9b@32`/80`<300<;2`P35aLD0alO7
0<[:bP2l_;`0c/k>0<O7a`39bLT0]kNg0;:b/P2g]kL0][Jf0<?3``3:b/X0^KVi0<30`02n_[h0c<c<
0<O7a`2i^KT0^k^k0<W9b@0I0?ooo`005`3oool03`2h^;P0[jn_0;Zj^P2MWId0^[Zj0<K6aP3?cll0
`/;20;jn_P2[Zj/0b<S80;jn_P2[Zj/0][Jf0<[:bP020<;2`P0J09^KV`34a<@0a<C40;6a/@2YZJT0
b/[:0000002_[jl0`/;20;Zj^P2f][H0b<S80<g=c@3:b/X0^[Zj0;bl_02n_[h0^;Rh0:>SX`32`/80
a<C40:VYZ@2:RXX0_[jn0<;2`P2j^[X20=7Ad@0>0<S8b02l_;`0b<S80<C4a03?cll0`/;20;Bd]038
b<P0a/K60:^[Z`2n_[h0c<c<0<o?c`34a<@20<S8b0040;6a/@1_Kfl0a/K60;Rh^0<0a/K60180][Jf
0;Rh^02f][H0a<C40=GEe@38b<P0dM7A0;>c/`3=cLd0`/;20=WIf@3=cLd0hN7Q0:6QX@2l_;`0][Jf
0;bl_038b<P20<[:bP0A0;6a/@3=cLd0];Bd0<[:bP2n_[h0[jn_0;Jf]P2h^;P0emOG0:FUY@2c/k<0
XJ6Q0<c<c03Cdm<0Zj^[0=GEe@3IfMT07P3oool03`2n_[h0/[:b0;jn_P2SXj<0_;bl0<G5a@3>c/h0
`/;20;jn_P2i^KT0clo?0<;2`P2d];@0]kNg0<W9b@020<30`00<0:6QX@37alL0alO70;Jf]P2ZZZX0
bLW90000002b/[80`<300;^k^`2g]kL0alO70P3>c/h01@2k^k/0_;bl0;jn_P2i^KT0Z:RX0080`/;2
00D0Zj^[09:BTP37alL0`/;20;^k^`020<c<c0070<?3``2l_;`0alO70<?3``3>c/h0`<300;Bd]002
0<?3``0c0:^[Z`2l_;`0alO70=KFeP32`/80`l?30<[:bP2][Jd0M7Ad0<O7a`2k^k/0alO70<G5a@32
`/80/;2`0;Jf]P2`/;00_[jn0<o?c`33`l<0clo?0;Jf]P39bLT0_[jn0=KFeP39bLT0fm_K0:BTY02l
_;`0^KVi0;jn_P39bLT0b/[:0<W9b@2d];@0clo?0;Bd]035aLD0^k^k0;2`/02g]kL0^k^k0<k>cP2O
Wil0[Jf]0:JVYP3:b/X0c<c<0:f][@3?cll0eMGE01T0oooo000G0?ooo`0B0<c<c02f][H0a<C40<S8
b02n_[h0c<c<0<g=c@32`/80clo?0<K6aP2d];@0`<300;bl_02j^[X0b<S80<K6aP3=cLd0`/;20P2d
];@07@34a<@0`<300<S8b02SXj<0_;bl0;Bd]02j^[X0][Jf0;bl_03=cLd0a/K60=WIf@2n_[h0dM7A
0;Jf]P2MWId0^;Rh0;Jf]P36a/H0hn?S0<S8b03AdM40][Jf0=OGe`2a/K40dM7A0:VYZ@2a/K40[Jf]
00<0a<C400@0b/[:0;jn_P2SXj<0[jn_0P32`/805`2a/K40][Jf0<;2`P1WIfL0/k>c0;jn_P2a/K40
fm_K0;jn_P32`/80][Jf0=GEe@3AdM40clo?0=OGe`2f][H0c<c<0<[:bP32`/80_[jn0<o?c`30`<00
/K6a0080_[jn01H0`/;20<C4a03=cLd0dm?C0;Bd]03AdM40/k>c0:VYZ@2a/K40/k>c0;Jf]P2d];@0
clo?0<;2`P2l_;`0`/;20<S8b02f][H0`/;20=WIf@2l_;`0XJ6Q7P3oool01@3<c<`0^KVi0<?3``37
alL0_[jn0080b/[:00D0`/;20<o?c`39bLT0^KVi0;jn_P020;^k^`80alO702<0c/k>0<?3``2g]kL0
^k^k0<G5a@2n_[h0aLG50:n_[`33`l<0];Bd0;Vi^@2f][H0^k^k0<[:bP33`l<0e]KF0;jn_P3?cll0
]kNg0:>SX`2k^k/0^KVi0<O7a`3Jf]X0`l?30=GEe@2d];@0dM7A0:f][@3EeMD0Zj^[0;2`/02][Jd0
`/;20<?3``020<G5a@0V0;jn_P2VYZH0/;2`0<G5a@33`l<0/;2`0;^k^`2n_[h0Lg=c0:n_[`2l_;`0
[jn_0=GEe@2k^k/0_[jn0;Bd]03AdM40c/k>0<c<c03AdM40];Bd0<O7a`39bLT0_[jn0;^k^`3:b/X0
_;bl0;Bd]02k^k/0_[jn0<;2`P2n_[h0c/k>0<c<c02b/[80c<c<0;:b/P2[Zj/20;:b/P030;Ng]`2f
][H0c<c<00<0_[jn00H0alO70<30`037alL0eMGE0;Ng]`2SXj<I0?ooo`005`3oool02@30`<00`/;2
0;>c/`3<c<`0b<S80<;2`P2n_[h0^[Zj0;Rh^0020;jn_P80][Jf00D0^[Zj0<;2`P30`<00][Jf0<30
`0020;Bd]00:0:VYZ@2j^[X0^[Zj0<K6aP32`/80_;bl0=7Ad@2[Zj/0c<c<0=?Cd`80clo?00P0^;Rh
0;jn_P3EeMD0cLg=0>GUi@2a/K40YjNW0<C4a080];Bd03l0b<S80<C4a03?cll0^;Rh0=_Kf`3Cdm<0
`<300<K6aP3:b/X0^;Rh0<S8b036a/H0YJFU0:n_[`32`/80];Bd0<K6aP2a/K40/k>c0=7Ad@3GemL0
clo?0=?Cd`34a<@0`<300=oOg`30`<00/K6a0<c<c03:b/X0a<C40<30`02d];@0`/;20;>c/`3Cdm<0
`<300=7Ad@30`<00`/;20=GEe@3Shn<0[Jf]0;jn_P2h^;P0dM7A0<K6aP2c/k<0Vi^K0:n_[`3?cll0
][Jf0:n_[`3bl_80/K6a0<;2`P2WYjL0c<c<0;jn_P3Ogml0^[Zj0:NWY`2n_[h07P3oool01@35aLD0
`<300;Jf]P3:b/X0aLG50080`<3000h0_;bl0;^k^`30`<00`l?30;bl_030`<00bLW90<?3``2n_[h0
^k^k0<O7a`2l_;`0];Bd0:ZZZP80]kNg0140aLG50<;2`P2n_[h0dM7A0:^[Z`37alL0f][J0<W9b@3?
cll0^KVi0;^k^`3Cdm<0bLW90=oOg`2f][H0[jn_0<G5a@020;Ng]`0]0<?3``30`<00b/[:0;Jf]P3F
e]H0b/[:0;Vi^@2n_[h0c<c<0;bl_039bLT0`/;20:RXZ02`/;00`l?30;:b/P33`l<0/;2`0;Ng]`3<
c<`0dM7A0<[:bP33`l<0^k^k0;bl_03Hf=P0^KVi0;jn_P37alL0aLG50;:b/P2n_[h0];Bd0<?3``2Z
ZZX0clo?0<?3``3?cll0`<300<;2`P3Cdm<0hN7Q0:f][@2l_;`0]kNg0080c<c<0100^k^k0:>SX`2`
/;00c/k>0;Jf]P2_[jl0h^;R0;:b/P33`l<0Zj^[0<?3``2n_[h0c<c<0;^k^`2VYZH0^k^k6@3oool0
01L0oooo01h0`<300;Rh^02j^[X0`<300<C4a02h^;P0];Bd0<K6aP2a/K40a/K60<S8b02j^[X0c<c<
0<30`02j^[X0b<S80;>c/`3:b/X0a<C40<30`038b<P0^[Zj0<30`02n_[h0^[Zj0<30`032`/80/K6a
0<c<c02[Zj/20;Rh^00R0<30`03:b/X0b/[:0?KfmP3Ogml0fm_K0<K6aP3:b/X0/K6a0;Rh^03=cLd0
b<S80<30`03=cLd0^;Rh0=_Kf`36a/H0emOG0<30`02d];@0b/[:0;bl_02h^;P0^[Zj0:f][@2n_[h0
^;Rh0<[:bP30`<00a/K60<[:bP2d];@0`<300;bl_080cLg=0140a<C40;>c/`2WYjL0`<300<;2`P30
`<00c<c<0;6a/@2YZJT0][Jf0<30`02n_[h0gMgM0=?Cd`2n_[h0UYJF0;Jf]P020:n_[`090<S8b032
`/80dm?C0;Rh^03:b/X0Zj^[0:NWY`2l_;`0[jn_0080b<S800L0dM7A0<C4a03=cLd0];Bd0;Jf]P32
`/80/K6a01h0oooo01T0_;bl0;Ng]`2i^KT0_[jn0<;2`P2i^KT0/[:b0<?3``2b/[80alO70<W9b@2n
_[h0c/k>0<;2`P2l_;`0bLW90;Jf]P3:b/X0aLG50;jn_P35aLD0]kNg0;bl_030`<00_;bl0080_[jn
00<0];Bd0<c<c02`/;000P2f][H05@2n_[h0bLW90<W9b@3]kNd0f=SH0=?Cd`3>c/h0alO70;2`/02g
]kL0c<c<0<W9b@30`<00b/[:0;Vi^@3Hf=P0aLG50=GEe@30`<00][Jf0<G5a@020;^k^`0b0;Vi^@2d
];@0aLG50;Vi^@35aLD0_[jn0<O7a`39bLT0];Bd0;jn_P2k^k/0c/k>0<o?c`30`<00/;2`0:JVYP2n
_[h0`l?30;bl_03:b/X0/;2`0:^[Z`2g]kL0`<300;jn_P3Ogml0dM7A0;Jf]P2LW9`0][Jf0;2`/02b
/[80alO70<W9b@3Cdm<0/[:b0<k>cP2VYZH0ZZZZ0;bl_02b/[80`l?30<O7a`3<c<`0aLG50<c<c02f
][H0^KVi0<;2`P2b/[8I0?ooo`005`3oool0>@2n_[h0[Jf]0:>SX`2h^;P0][Jf0<S8b032`/80^;Rh
0:^[Z`3AdM40a/K60<C4a036a/H0_[jn0;bl_038b<P0`/;20<S8b03:b/X0cLg=0<K6aP34a<@0Zj^[
0;Rh^02c/k<0dM7A0;>c/`32`/80_;bl0;Zj^P38b<P0`<300;Bd]038b<P0b/[:0<g=c@2WYjL0`/;2
0:^[Z`2d];@0cLg=0<c<c02f][H0a/K60:^[Z`34a<@0_[jn0:f][@30`<00b<S80<o?c`30`<00c<c<
0;>c/`2SXj<0_;bl0<c<c0030;jn_P060<c<c03AdM40clo?0<c<c03=cLd0_;bl0P3=cLd09@2l_;`0
WIfM0;>c/`2l_;`0Vi^K0<K6aP2UYJD0c<c<0;Jf]P2h^;P0^[Zj0<30`03hn?P0YJFU0:6QX@2n_[h0
b<S80;Zj^P32`/80][Jf0=_Kf`2l_;`0];Bd0;bl_03:b/X0^[Zj09RHV03Ogml0a<C40;Rh^034a<@0
clo?0;Jf]P38b<P0a/K60<c<c02h^;P07P3oool0>@2l_;`0[Jf]0:^[Z`2n_[h0_;bl0<O7a`30`<00
]kNg0:^[Z`39bLT0alO70<G5a@3<c<`0`l?30<;2`P39bLT0`l?30<W9b@3:b/X0dm?C0<;2`P33`l<0
[Jf]0;Vi^@2d];@0c<c<0;:b/P30`<00_;bl0;Vi^@37alL0`/;20;Ng]`39bLT0aLG50=KFeP2b/[80
b/[:0:f][@2f][H0c<c<0<[:bP2f][H0alO70:n_[`35aLD0]kNg0;2`/02l_;`0bLW90<k>cP30`<00
bLW90;Jf]P2SXj<0_[jn0<W9b@030;bl_0030<W9b@3>c/h0c/k>0080bLW90100_;bl0<W9b@39bLT0
^k^k09nOW`2b/[80_[jn09nOW`35aLD0Z:RX0<G5a@2`/;00^KVi0;bl_02n_[h0l_;b0P2QXJ420<?3
``0=0;Ng]`2n_[h0^KVi0=GEe@2i^KT0/[:b0;bl_039bLT0][Jf09bLW03Jf]X0`/;20;^k^`020<G5
a@050;Jf]P30`<00`/;20<k>cP2i^KT06@3oool001L0oooo02P0b<S80<[:bP38b<P0];Bd0;bl_030
`<00];Bd0;Rh^030`<00_;bl0<30`02n_[h0XJ6Q0;Rh^038b<P0b/[:0<30`03<c<`0b/[:0<K6aP38
b<P0_[jn0;bl_02c/k<0^[Zj0:>SX`36a/H0/K6a0<c<c030`<00_[jn0;Zj^P3Cdm<0`<300=7Ad@2n
_[h0/k>c0:n_[`2l_;`0b<S80P32`/803`2[Zj/0b/[:0;jn_P3AdM40^;Rh0:FUY@3?cll0][Jf0;bl
_02YZJT0a/K60<30`02UYJD0^[Zj0=OGe`020<g=c@050;Zj^P2_[jl0fm_K0;bl_03:b/X00P2l_;`0
7`34a<@0fm_K0;6a/@2j^[X0/k>c0;Rh^036a/H0`<300;Bd]034a<@0_[jn0;Jf]P3EeMD0c<c<0;Zj
^P2[Zj/0clo?0<;2`P3:b/X0Xj>S0;Bd]03=cLd0`/;20;Bd]02n_[h0`/;20<S8b036a/H0^;Rh0<S8
b02_[jl00P3AdM40103UiND0dm?C0<C4a03=cLd20;Bd]1h0oooo00h0b/[:0<W9b@37alL0][Jf0;bl
_032`/80][Jf0;Vi^@30`<00_;bl0<30`02n_[h0Xj>S0;Vi^@80alO701P0_[jn0<O7a`37alL0`/;2
0<?3``2n_[h0_;bl0;Jf]P2l_;`0YZJV0<G5a@2_[jl0c<c<0<W9b@37alL0`<300=KFeP35aLD0alO7
0<30`02d];@0[jn_0;^k^`37alL20<;2`P0`0:ZZZP3AdM40_[jn0<c<c02k^k/0Z:RX0<k>cP2g]kL0
`l?30:f][@3<c<`0_[jn0:JVYP2i^KT0e]KF0=GEe@37alL0]kNg0:^[Z`3Fe]H0^KVi0<G5a@33`l<0
`<300<[:bP3Jf]X0/;2`0;Vi^@2d];@0^k^k0<o?c`35aLD0/[:b0<;2`P39bLT0^KVi0<o?c`39bLT0
]kNg0:f][@3?cll0`l?30<O7a`2TY:@0];Bd0<W9b@33`l<0/[:b0P30`<001@35aLD0alO70;^k^`37
alL0[Jf]0080dM7A00H0fm_K0<o?c`30`<00c<c<0;Jf]P2d];@I0?ooo`005`3oool06`32`/80Zj^[
0<C4a02n_[h0a<C40<;2`P36a/H0/k>c0:6QX@36a/H0_;bl0;jn_P2h^;P0c<c<0<K6aP2QXJ40_[jn
0;6a/@2l_;`0b/[:0<g=c@30`<00^[Zj0:FUY@2a/K40a<C40;Zj^P020;>c/`0?0<o?c`3GemL0YjNW
09fMW@36a/H0_;bl0;Jf]P2l_;`0b<S80<;2`P2n_[h0^;Rh0<K6aP3=cLd0j>SX0080`/;201<0][Jf
0=WIf@2f][H0dm?C0=7Ad@2d];@0b<S80:n_[`2d];@0ZJVY0>?Sh`2][Jd0_;bl0<K6aP2][Jd0b<S8
0;jn_P2d];@0/k>c0080a<C40200];Bd0:NWY`2_[jl0cLg=0>7Qh@2f][H0eMGE0;6a/@3IfMT0YjNW
0=7Ad@2n_[h0b/[:0>7Qh@2[Zj/0cLg=0<[:bP2h^;P0clo?0<C4a038b<P0cLg=0;Jf]P2d];@0c<c<
0;jn_P38b<P0_[jn0<;2`P3<c<`0^[Zj0;Jf]P80`<3000@0U9BD0<K6aP3=cLd0[jn_7P3oool08@32
`/80[jn_0<;2`P2l_;`0`/;20<30`033`l<0][Jf0:RXZ039bLT0aLG50<30`02n_[h0c<c<0<O7a`2Q
XJ40_;bl0;:b/P2i^KT0aLG50<c<c030`<00^k^k0:f][@2g]kL0`/;20;Vi^@2d];@0[jn_0<k>cP3F
e]H0Z:RX0:>SX`020;jn_P0L0;Bd]02k^k/0bLW90<?3``30`<00_;bl0<k>cP39bLT0h^;R0<;2`P33
`l<0][Jf0=[JfP2k^k/0eMGE0=?Cd`2i^KT0alO70;2`/02g]kL0[Jf]0=_Kf`2][Jd0`/;20<k>cP2]
[Jd0aLG50;jn_P80/;2`02P0`<300;bl_02i^KT0];Bd0;Ng]`32`/80dM7A0;:b/P3AdM40[jn_0=?C
d`2b/[80c<c<0<30`032`/80f][J0:n_[`3Hf=P0`l?30;Jf]P3?cll0`/;20<G5a@3:b/X0]kNg0;Vi
^@39bLT0_;bl0<G5a@2l_;`0^KVi0<?3``32`/80];Bd0;:b/P2n_[h0WYjN0<[:bP3Hf=P0[jn_6@3o
ool001L0oooo00l0_;bl0;jn_P32`/80b<S80<C4a030`<00_;bl0<;2`P30`<00c<c<0<[:bP36a/H0
cLg=0;Rh^02][Jd00P30`<001P34a<@0_[jn0;Rh^02a/K40b/[:0;Jf]P80`<3003<0b/[:0;bl_02f
][H0a<C40<[:bP2j^[X0/k>c0<;2`P2_[jl0clo?0;Zj^P2c/k<0Zj^[0<C4a03=cLd0clo?0<g=c@36
a/H0eMGE0;jn_P2f][H0ZJVY0:f][@32`/80_[jn0;Zj^P3:b/X0c<c<0<;2`P2n_[h0b<S80=7Ad@32
`/80/k>c0;bl_02SXj<0c<c<09nOW`30`<00][Jf0:FUY@2l_;`0gMgM0:FUY@3AdM40^[Zj0<C4a036
a/H0/k>c0<[:bP34a<@00P32`/801P2_[jl0YJFU0<;2`P2j^[X0_[jn0;>c/`80b/[:00T0/K6a0:^[
Z`34a<@0Xj>S0;>c/`2DU9@0`<300;Jf]P2d];@00P38b<P0202_[jl0cLg=0;jn_P36a/H0`<300:f]
[@2l_;`0Ng]k7P3oool02P2l_;`0`l?30<30`035aLD0`/;20<30`02l_;`0_[jn0;bl_03<c<`20<O7
a`030<o?c`2k^k/0/;2`0080`/;200H0_[jn0;^k^`2k^k/0[jn_0<W9b@2g]kL20<30`00>0<O7a`2k
^k/0]kNg0;jn_P3:b/X0]kNg0;Jf]P2l_;`0ZZZZ0<o?c`2k^k/0/[:b0:JVYP32`/820<o?c`80bLW9
03@0clo?0;bl_02i^KT0/[:b0:^[Z`2n_[h0^k^k0;Ng]`35aLD0b/[:0<;2`P2n_[h0alO70<c<c030
`<00Zj^[0;Ng]`2TY:@0bLW90:RXZ02l_;`0]kNg0:RXZ032`/80f=SH0:ZZZP3>c/h0[Jf]0<30`032
`/80][Jf0<O7a`30`<00aLG50;jn_P2k^k/0Z:RX0<?3``2i^KT0]kNg0;^k^`35aLD0b/[:0;2`/02X
Z:P0`l?30:RXZ02f][H0VYZJ0<;2`P2f][H0];Bd0P39bLT0202b/[80b/[:0<;2`P32`/80bLW90;2`
/02n_[h0P8206@3oool001L0oooo00<0][Jf0;Zj^P2c/k<00P2h^;P05032`/80][Jf0<K6aP34a<@0
b/[:0;bl_036a/H0][Jf0;Rh^03:b/X0a/K60;Zj^P3=cLd0b<S80<30`02][Jd0c<c<0=OGe`2KVi/0
c<c<0P2j^[X05P2[Zj/0c<c<0<S8b03=cLd0b/[:0=7Ad@34a<@0cLg=0;Rh^02_[jl0b/[:0<c<c03=
cLd0c<c<0<;2`P2j^[X0Zj^[0:NWY`3IfMT0cLg=0;Rh^03=cLd20<c<c00>0<S8b02c/k<0^[Zj0:n_
[`2j^[X0b/[:0<S8b02n_[h0_;bl0;Bd]022PX80a<C40:>SX`2[Zj/20<o?c`0V0<c<c02j^[X0cLg=
0<K6aP2d];@0_[jn0<S8b02j^[X0^;Rh0;Zj^P2][Jd0TY:B0;Jf]P34a<@0_;bl0;Jf]P32`/80/K6a
0<[:bP3=cLd0Vi^K0<[:bP2j^[X0b<S80:n_[`2c/k<0a/K60<[:bP3=cLd0a/K60<30`036a/H0b/[:
0<30`03?cll0emOG0<C4a02[Zj/N0?ooo`030;Vi^@30`<00][Jf0080^k^k00L0`<300;^k^`39bLT0
alO70<[:bP2n_[h0bLW90080^k^k00/0b/[:0<O7a`2l_;`0c/k>0<W9b@35aLD0^KVi0<k>cP3Hf=P0
W9bL0<[:bP020<30`00:0:ZZZP39bLT0`/;20<W9b@3<c<`0dM7A0<G5a@3?cll0^k^k0;:b/P80b/[:
00X0clo?0<c<c033`l<0_;bl0;^k^`2b/[80dm?C0<?3``2l_;`0c/k>0P3:b/X06037alL0/[:b0;Vi
^@2`/;00^k^k0<O7a`35aLD0^k^k0;Vi^@2d];@0QhN70<[:bP2ZZZX0[Jf]0<k>cP3<c<`0b/[:0;Vi
^@3:b/X0`/;20;:b/P2k^k/0`l?30;Ng]`80^KVi01`0[Jf]09RHV02i^KT0b/[:0<?3``2f][H0b/[:
0;2`/03AdM40alO70:BTY03:b/X0_;bl0<W9b@2_[jl0/[:b0<W9b@37alL0c<c<0<G5a@2n_[h0`/;2
0<[:bP32`/80b/[:0=7Ad@2k^k/0Xj>S6@3oool001L0oooo00<0/k>c0<;2`P32`/800P34a<@02036
a/H0`/;20<;2`P36a/H0a<C40;bl_02c/k<0^[Zj0P2f][H0:`2n_[h0ZJVY0;Rh^02f][H0a<C40<30
`032`/80^;Rh09VIV@2c/k<0_[jn0<C4a02j^[X0b/[:0;jn_P3?cll0][Jf0<g=c@34a<@0][Jf0<o?
c`2n_[h0ZJVY0<K6aP3?cll0b<S80<;2`P30`<00`/;20;bl_032`/80dm?C0<K6aP2c/k<0a<C40=7A
d@2d];@0c<c<0<[:bP2f][H0a/K60;jn_P2l_;`00P3<c<`03`36a/H0_;bl0;Zj^P2FUYH0^[Zj0<[:
bP3=cLd0_[jn0;Zj^P3:b/X0`<300;Bd]02h^;P0`<300<C4a0020;bl_00L0;>c/`2d];@0^[Zj0:^[
Z`34a<@0`/;20=?Cd`2SXj<0b/[:0:NWY`2_[jl0a<C40<o?c`3:b/X0`<300=gMg@3Cdm<0/K6a0<30
`02c/k<0/K6a0<C4a02n_[h0`<300:n_[`2j^[X0`<300:f][Ah0oooo00<0][Jf0;jn_P32`/800P33
`l<0903:b/X0`l?30<?3``37alL0bLW90<;2`P2f][H0^k^k0;Vi^@2g]kL0`<300:ZZZP2k^k/0^KVi
0<O7a`32`/80`l?30;^k^`2QXJ40][Jf0<;2`P37alL0`/;20<c<c02l_;`0c/k>0;bl_03?cll0aLG5
0;Jf]P3EeMD0_[jn0:^[Z`39bLT0c<c<0<W9b@80`<300P2n_[h03@3:b/X0eMGE0<O7a`2d];@0`/;2
0<c<c02b/[80c<c<0<W9b@2d];@0`l?30;jn_P2l_;`00P3<c<`0;@2l_;`0_[jn0;Vi^@2HV9P0_;bl
0<G5a@3:b/X0_;bl0;Vi^@39bLT0`/;20;Bd]02f][H0`/;20<30`02k^k/0_;bl0:n_[`2b/[80_;bl
0:ZZZP30`<00aLG50<c<c02VYZH0bLW90:ZZZP2XZ:P0aLG50<k>cP37alL0`/;20=KFeP3?cll0/;2`
0<30`02d];@0/[:b0<G5a@2n_[h0`<300;Ng]`32`/80_[jn0:f][@0I0?ooo`005`3oool04P2][Jd0
/k>c09fMW@2d];@0^;Rh0:NWY`36a/H0`/;20;Zj^P2d];@0dm?C0<S8b03=cLd0ZJVY0;jn_P2l_;`0
c<c<0;bl_080];Bd02P0a/K60<S8b02j^[X0_;bl0<c<c030`<00^[Zj0:NWY`2c/k<0a/K60<c<c02f
][H0/k>c0<c<c034a<@0`<300;Zj^P3=cLd0];Bd0;Jf]P3EeMD0`/;20<[:bP2WYjL0fMWI0:f][@30
`<00];Bd0<C4a03=cLd0][Jf0<C4a02[Zj/0_[jn0<o?c`2f][H0[Jf]0<c<c038b<P0emOG0P32`/80
6`2d];@0Vi^K0<[:bP32`/80][Jf09RHV03Zj^X0`<300;Bd]02][Jd0dM7A0;bl_02n_[h0^[Zj0<[:
bP36a/H0V9RH0;>c/`32`/80_;bl0<c<c032`/80a/K60:6QX@30`<00`/;20<[:bP020;jn_P0>0<;2
`P2l_;`0a/K60;Rh^03?cll0`/;20=7Ad@34a<@0a/K60;bl_02_[jl0Xj>S0<30`038b<PN0?ooo`06
0:f][@2f][H0Xj>S0;Ng]`2l_;`0Zj^[0P37alL01P32`/80/;2`0=7Ad@35aLD0b/[:0:ZZZP80_[jn
00H0c<c<0;^k^`2d];@0/[:b0<;2`P33`l<20;Ng]`070<G5a@32`/80alO70:JVYP2d];@0`/;20<[:
bP020;2`/00F0<k>cP30`<00`<300;^k^`3<c<`0][Jf0<?3``3Ti>@0bLW90<[:bP2VYZH0dm?C0:^[
Z`32`/80_[jn0<?3``32`/80^k^k0<?3``2][Jd0_[jn0<[:bP80]kNg00<0c/k>0<G5a@3Cdm<00P30
`<006`2][Jd0WinO0<G5a@2n_[h0];Bd09FEU@3Ti>@0`/;20:n_[`2][Jd0clo?0;bl_02k^k/0]kNg
0<G5a@32`/80V9RH0:f][@2n_[h0^k^k0<[:bP2n_[h0]kNg09nOW`30`<00^k^k0<O7a`020;bl_00>
0;jn_P2i^KT0aLG50:^[Z`33`l<0_;bl0<W9b@32`/80aLG50;bl_02ZZZX0WinO0;jn_P33`l<I0?oo
o`005`3oool03`2h^;P0][Jf0;Zj^P3:b/X0a<C40;jn_P2l_;`0a<C40;jn_P2SXj<0b/[:0<K6aP3E
eMD0Zj^[0:FUY@020;Bd]0040<30`038b<P0_;bl0<;2`P80`<3003D0];Bd0<C4a02n_[h0a<C40;Bd
]036a/H0];Bd0=?Cd`3<c<`0b<S80;Rh^036a/H0WIfM0;jn_P2c/k<0c<c<0?Shn00g=cL0Xj>S09JF
UP3:b/X0`/;20;jn_P2a/K40dM7A0<c<c02h^;P0`/;20;>c/`32`/80YJFU0<S8b02h^;P0b<S80:VY
Z@2n_[h0_;bl0<[:bP2n_[h0a<C40:>SX`2j^[X0TY:B0;Zj^P2[Zj/0`/;20<K6aP38b<P0_;bl0:>S
X`36a/H0`/;20<S8b0020;Zj^P0?0<30`032`/80c<c<0:n_[`2f][H0`<300<C4a02f][H0YjNW09JF
UP32`/80eMGE0<C4a02_[jl0_;bl0080b<S800X0];Bd0<K6aP2l_;`0_[jn0<[:bP3=cLd0fm_K0;Rh
^02d];@0Xj>S7P3oool05@2g]kL0^KVi0;bl_03:b/X0alO70<30`02n_[h0aLG50<;2`P2TY:@0c<c<
0<?3``3AdM40Zj^[0:RXZ02b/[80/;2`0;jn_P35aLD0^k^k0<30`0020<?3``0]0;Bd]032`/80aLG5
0<30`02n_[h0bLW90;Ng]`3AdM40eMGE0<W9b@2g]kL0`/;20:6QX@2n_[h0];Bd0<G5a@3clo<0=SHf
0:BTY02CTi<0aLG50;jn_P2k^k/0/;2`0<o?c`3:b/X0][Jf0;jn_P2f][H0b/[:0;2`/035aLD0^KVi
0<o?c`2][Jd0^k^k0;Vi^@37alL0_;bl0<30`02VYZH0]kNg09>CT`2g]kL0ZZZZ00<0`l?300D0];Bd
09bLW032`/80b/[:0<G5a@020;Vi^@0?0;jn_P30`<00alO70:n_[`2g]kL0_[jn0<?3``2g]kL0ZZZZ
09:BTP33`l<0eMGE0<G5a@2][Jd0^KVi0080bLW900X0^k^k0<;2`P2k^k/0`<300<[:bP3>c/h0eMGE
0;Jf]P2_[jl0Z:RX6@3oool001L0oooo01<0`<300;Jf]P32`/80_[jn0<;2`P2h^;P0`/;20<g=c@3<
c<`0cLg=0<30`03:b/X0_;bl0:n_[`24Q8@0`<300:NWY`3EeMD0a<C40080`<3003h0a<C40=OGe`2_
[jl0clo?0;Jf]P30`<00fm_K0<[:bP3?cll0a<C40<c<c034a<@0^[Zj0;Bd]032`/80b/[:0;jn_P2[
Zj/0/k>c09:BTP3<c<`0][Jf0=OGe`32`/80_[jn0<S8b030`<00a/K60;>c/`3=cLd0`<300=7Ad@2h
^;P0VIVI0:f][@32`/80a/K60<;2`P3=cLd0c<c<0<;2`P2IVIT0^[Zj0:6QX@2UYJD0_[jn0;>c/`3M
gMd0dM7A09:BTP2WYjL0c<c<0:f][@34a<@0c<c<0;bl_02c/k<0][Jf0;>c/`2IVIT0emOG0;bl_080
`<3001@0ZJVY0;>c/`2_[jl0Vi^K0:NWY`2MWId0_[jn0=OGe`2f][H0^;Rh0<[:bP36a/H0/K6a0=GE
e@3=cLd0b/[:0<K6aP30`<00_[jn0:VYZAh0oooo00L0`/;20;bl_03:b/X0alO70<[:bP2g]kL0`<30
00<0c/k>04/0`/;20<[:bP2l_;`0/;2`08N7Q`30`<00ZZZZ0<o?c`32`/80`<300;bl_035aLD0e]KF
0:n_[`3<c<`0^KVi0<;2`P3Fe]H0alO70=SHf039bLT0c<c<0<G5a@2l_;`0];Bd0<;2`P39bLT0_[jn
0:^[Z`2g]kL0XJ6Q0<O7a`2f][H0e]KF0<?3``2k^k/0b/[:0<;2`P37alL0][Jf0<c<c033`l<0c<c<
0;Jf]P2SXj<0/;2`0;Vi^@37alL0_[jn0<c<c037alL0`l?309nOW`2i^KT0VYZJ0:6QX@2n_[h0];Bd
0=gMg@3?cll0T92@0:^[Z`39bLT0/;2`0<30`039bLT0_;bl0;:b/P2f][H0/[:b09jNWP3Cdm<0^KVi
0<30`035aLD00P2][Jd03`2[Zj/0V9RH0:ZZZP2XZ:P0`<300=KFeP2f][H0/;2`0<[:bP37alL0];Bd
0<k>cP39bLT0alO70<G5a@020<30`0030:JVYP3oool0oooo01L0oooo000G0?ooo`060:^[Z`2h^;P0
^[Zj0;bl_036a/H0];Bd0P32`/807@2l_;`0^[Zj0:>SX`2a/K40`/;20;bl_038b<P0cLg=0<;2`P2n
_[h0a/K60<[:bP2l_;`0^;Rh0;jn_P2j^[X0clo?0;bl_02n_[h0b/[:0;Zj^P3:b/X0a/K60;Jf]P2d
];@0_[jn0;Rh^02n_[h0^;Rh0080][Jf0100a<C40<[:bP34a<@0gMgM0<o?c`30`<00];Bd0;Zj^P3I
fMT0Xj>S0:n_[`2UYJD0_;bl0<K6aP2n_[h0b<S80P2d];@0903<c<`0cLg=0<;2`P2][Jd0eMGE0<c<
c038b<P0][Jf0:VYZ@2h^;P0dm?C0<S8b02f][H0^[Zj0<30`02UYJD0dm?C0;bl_02WYjL0/K6a0<[:
bP3GemL0`<300;6a/@2YZJT0`<3009nOW`30`<00/k>c0;Rh^030`<00YJFU09VIV@2l_;`0_[jn0<K6
aP80_;bl00X0c<c<0<[:bP36a/H0cLg=0=GEe@36a/H0j>SX0;>c/`2OWil0Vi^K7P3oool01P2_[jl0
_;bl0;^k^`2l_;`0aLG50;Ng]`80_[jn0P2k^k/03`2TY:@0]kNg0<O7a`30`<00bLW90<[:bP30`<00
_;bl0<G5a@3:b/X0_[jn0;Ng]`2l_;`0][Jf0<[:bP020;^k^`0Z0<W9b@2k^k/0b/[:0<O7a`2g]kL0
][Jf0;jn_P2f][H0`/;20;Vi^@30`<00^KVi0<30`037alL0b/[:0=gMg@3Fe]H0alO70;Vi^@2l_;`0
f=SH0:RXZ02][Jd0Z:RX0;Vi^@3:b/X0_;bl0<O7a`2f][H0]kNg0<W9b@3>c/h0`l?30:f][@3Hf=P0
alO70<?3``2i^KT0[Jf]0;Bd]03>c/h0`<300P2`/;005`2l_;`0XJ6Q0=7Ad@2i^KT0Y:BT0;2`/037
alL0dm?C0;jn_P2_[jl0[Jf]0<W9b@2QXJ40_[jn0;:b/P2g]kL0_;bl0;2`/02NWYh0`<300;^k^`33
`l<0_[jn00<0aLG500P0alO70<k>cP3?cll0`/;20>WYj@2d];@0WinO09bLW1T0oooo000G0?ooo`04
0;6a/@2f][H0][Jf0<C4a080_[jn02D0][Jf0;Zj^P2c/k<0_;bl0:6QX@36a/H0`<300<S8b02h^;P0
/k>c0<K6aP3?cll0b/[:0:f][@32`/80a/K60<;2`P38b<P0b/[:0<C4a03:b/X0`/;20;Jf]P2n_[h0
/k>c0;Zj^P38b<P0eMGE0<C4a02_[jl0_[jn0<C4a03?cll0c<c<0;jn_P30`<00`/;20080];Bd01T0
b/[:0;Jf]P38b<P0_[jn0;Rh^03EeMD0`/;20<g=c@2l_;`0a/K60;Jf]P2l_;`0^[Zj0<30`034a<@0
b<S80;Zj^P3EeMD0a/K60;jn_P2UYJD0dm?C0<;2`P3/k>`0[Jf]0080^;Rh00@0/K6a0<C4a02j^[X0
R8R80P2d];@20<C4a0060<g=c@2UYJD0];Bd0;Zj^P2n_[h0Zj^[0P36a/H04@2j^[X0a<C40<S8b02j
^[X0^;Rh0<g=c@3Cdm<0clo?0=?Cd`2n_[h0b/[:0<S8b02n_[h0b/[:0<30`03Ogml0[jn_01h0oooo
02H0/[:b0;Bd]02i^KT0aLG50<;2`P30`<00][Jf0;Vi^@2b/[80_[jn0:JVYP37alL0`/;20<O7a`2i
^KT0];Bd0<30`03<c<`0alO70:n_[`2n_[h0`/;20;jn_P35aLD0c/k>0<O7a`35aLD0`l?30;Jf]P2n
_[h0][Jf0<G5a@3?cll0eMGE0<O7a`2`/;00`<300<G5a@80b/[:00<0_[jn0<30`032`/800P2l_;`0
0`3?cll0][Jf0;jn_P020;bl_00E0<c<c030`<00bLW90;^k^`30`<00]kNg0;jn_P2g]kL0_;bl0<30
`035aLD0/;2`0<c<c035aLD0^KVi0:BTY03>c/h0`l?30=oOg`2_[jl0];Bd0080[jn_00<0`<300;Ng
]`2<S8`00P2g]kL02`37alL0`<300<[:bP2VYZH0];Bd0;2`/030`<00ZZZZ0<?3``2f][H0]kNg0080
c<c<00L0][Jf0;Vi^@3:b/X0clo?0<?3``3?cll0aLG50080`l?300D0[jn_0<O7a`2n_[h0eMGE0:f]
[@0I0?ooo`005`3oool20;>c/`050<30`02_[jl0[Jf]0;bl_02n_[h00P38b<P0102_[jl0^[Zj0<K6
aP32`/820;jn_P0<0<[:bP38b<P0Xj>S0;jn_P3<c<`0[jn_0<K6aP3:b/X0_[jn0;Jf]P36a/H0a<C4
0P30`<030=WIf@190<;2`P2d];@0a/K60;Rh^02n_[h0Zj^[0<S8b032`/80cLg=0:n_[`38b<P0clo?
0;Jf]P2c/k<0clo?0<;2`P30`<00XJ6Q0:n_[`30`<00cLg=0;Bd]02UYJD0^;Rh0<;2`P2n_[h0_;bl
0<c<c02l_;`0`/;20=OGe`34a<@0clo?0:n_[`36a/H0b/[:0:n_[`2n_[h0Vi^K0<;2`P28R8P0dm?C
0<S8b02QXJ40][Jf0;Rh^02c/k<0_[jn0;Jf]P32`/80/K6a0:6QX@2h^;P0ZJVY0;Zj^P34a<@0b<S8
0<o?c`2d];@0^[Zj0<S8b03<c<`0/K6a0<S8b02c/k<0CTi>0;jn_P34a<@0b/[:0<C4a03<c<`0b<S8
0<C4a00N0?ooo`030;Bd]02`/;00`/;20080/[:b00P0_[jn0;bl_035aLD0aLG50:n_[`2i^KT0`l?3
0<30`080_[jn04P0alO70<G5a@2TY:@0_;bl0<W9b@2b/[80`l?30<O7a`35aLD0^k^k0<O7a`33`l<0
_[jn0;bl_03Hf=P0fm_K0=SHf032`/80];Bd0<;2`P2f][H0^k^k0:f][@33`l<0`/;20<c<c02`/;00
alO70=KFeP2k^k/0];Bd0<o?c`33`l<0`<300:6QX@2[Zj/0`<300<W9b@2d];@0Xj>S0;Vi^@2n_[h0
`<300;Vi^@37alL0`/;20<k>cP3Fe]H0`/;20<k>cP2][Jd0`l?30<;2`P2_[jl0alO709RHV02n_[h0
Rh^;0<k>cP33`l<0YZJV0;Ng]`2k^k/0][Jf0;bl_02d];@0_[jn0:n_[`2VYZH0^k^k0:RXZ02i^KT2
0<G5a@0@0<30`02`/;00]kNg0<W9b@3<c<`0];Bd0<k>cP2_[jl0Cdm?0;^k^`30`<00dM7A0<;2`P39
bLT0alO70<G5aAT0oooo000G0?ooo`0G0<C4a02_[jl0`<300<S8b03<c<`0`<300<S8b02d];@0a<C4
0;Rh^030`<00][Jf0;jn_P30`<00_[jn0<K6aP2j^[X0Zj^[0>SXj02_[jl0`<3007=cL`2h^;P00P2n
_[h0D02h^;P0/k>c0:f][@3AdM40fMWI0=?Cd`34a<@0];Bd0<C4a02l_;`0b<S80<30`02d];@0_;bl
0<c<c03Kfm/0i^KV0=7Ad@2l_;`0];Bd0<C4a03:b/X0`<300<[:bP3?cll0cLg=0;bl_02FUYH0WinO
0;>c/`2WYjL0_;bl0<K6aP30`<00b<S80<g=c@2[Zj/0];Bd0;jn_P38b<P0^[Zj0<o?c`2UYJD0V9RH
0;bl_02YZJT0WinO09BDU02FUYH0][Jf09fMW@34a<@0^[Zj0;bl_032`/80gmoO0;bl_02n_[h0a/K6
09RHV02UYJD0a<C40<K6aP2f][H0_[jn0<c<c032`/80emOG0<;2`P3AdM40a/K60;bl_02f][H0`<30
0:^[Z`2h^;P0b<S80<K6aP2f][H0b/[:7P3oool00`35aLD0[Jf]0;Jf]P020<[:bP1T0;jn_P37alL0
][Jf0<?3``2i^KT0`<300;Bd]02n_[h0`/;20;bl_037alL0_;bl0:f][@3Rh^80^KVi0<?3``1hN7P0
][Jf0<?3``30`<00]kNg0;Bd]02f][H0dM7A0=SHf03:b/X0`/;20;Bd]032`/80_;bl0<W9b@32`/80
]kNg0;bl_03?cll0f][J0>CTi03<c<`0_[jn0;Ng]`35aLD0c<c<0<30`035aLD0b/[:0<k>cP2k^k/0
VYZJ0:6QX@2b/[80ZZZZ0;jn_P37alL0`/;20<O7a`3EeMD0YZJV0;Bd]02l_;`0aLG50;Vi^@3Cdm<0
ZZZZ09RHV02i^KT0ZZZZ0:6QX@2EUID0VYZJ0;Vi^@2JVYX0`<300;Ng]`2i^KT0_[jn0=KFeP2i^KT0
_[jn0<;2`P2LW9`0Y:BT0;jn_P33`l<0^KVi0;^k^`35aLD0`/;20=7Ad@32`/80dM7A0<c<c030`<00
^KVi0<;2`P2][Jd0]kNg0<?3``35aLD0][Jf0<O7aaT0oooo000G0?ooo`070:VYZ@2j^[X0][Jf0:^[
Z`2f][H0];Bd0<C4a0020<K6aP0E0:VYZ@2d];@0^[Zj0:f][@2d];@0_;bl0;Zj^P2f][H0dM7A0<g=
c@2a/K40_[jn0;Jf]P2n_[h0][Jf0:VYZ@2l_;`0b/[:0:n_[`2j^[X0a<C40080cLg=00L0/k>c0=GE
e@3EeMD0[jn_0<C4a02_[jl0hn?S0080^;Rh0400a<C40;Jf]P38b<P0b/[:0;Bd]03=cLd0`<300<[:
bP3<c<`0a<C40<;2`P38b<P0/k>c0:f][@2WYjL0_[jn0;bl_03?cll0^[Zj0<C4a02a/K40clo?0;Bd
]02j^[X0a<C40;Jf]P2IVIT0b/[:0;Zj^P2l_;`0`<300:^[Z`32`/80S8b<0;6a/@38b<P0_;bl0<;2
`P2f][H0c<c<0<30`02d];@0_;bl0;Jf]P3<c<`0a/K60;Rh^03?cll0`/;20;Zj^P2f][H0cLg=0>?S
h`32`/80^[Zj0<g=c@2l_;`0a<C40<S8b034a<@0fm_K0<30`02h^;P0b<S87P3oool03`2[Zj/0_;bl
0;bl_02_[jl0^k^k0;jn_P32`/80aLG50<O7a`2ZZZX0][Jf0;Vi^@2_[jl0/[:b0<30`0020;Vi^@0@
0<[:bP3>c/h0];Bd0;jn_P2i^KT0`<300;Vi^@2XZ:P0_;bl0<W9b@2b/[80^k^k0<?3``3:b/X0clo?
0;Ng]`80clo?03L0[Jf]0<30`02b/[80gMgM0;Vi^@2g]kL0`<300;Ng]`33`l<0alO70;bl_03:b/X0
`<300<W9b@3:b/X0`l?30<;2`P37alL0/;2`0:BTY02VYZH0^k^k0;Vi^@3<c<`0]kNg0<30`02b/[80
clo?0;2`/02n_[h0aLG50;^k^`2QXJ40clo?0;Ng]`2i^KT0_;bl0:n_[`33`l<0Ti>C0;:b/P35aLD0
^k^k0<30`02f][H0c<c<0<?3``2k^k/0^KVi0;bl_03>c/h0alO70;jn_P3:b/X0_[jn0080]kNg00H0
c<c<0>7Qh@33`l<0_;bl0<W9b@2k^k/30<G5a@040=SHf030`<00][Jf0<?3`aT0oooo000G0?ooo`0K
0;Bd]034a<@0ZJVY0;Jf]P3GemL0cLg=0;jn_P2f][H0_[jn0;Jf]P2WYjL0^[Zj0<C4a02c/k<0b<S8
0;bl_02h^;P0a<C40;Rh^02_[jl0/k>c0<C4a03=cLd0^[Zj0;6a/@2n_[h0];Bd0080WIfM01<0];Bd
0;bl_03AdM40^;Rh0<C4a02a/K40b<S80<30`03=cLd0b<S809nOW`32`/80dM7A0<g=c@2j^[X0b/[:
0=7Ad@2d];@0clo?0080b/[:01d0hN7Q0<o?c`2j^[X0a<C40:VYZ@2h^;P0dm?C0<[:bP34a<@0_[jn
0;Jf]P30`<00WIfM0=OGe`2YZJT0/K6a0>[ZjP1kNg/0eMGE09fMW@2d];@0^[Zj0;jn_P2f][H0ZJVY
0>7Qh@3:b/X0a<C409^KV`020;Zj^P0H0=?Cd`2a/K40emOG0<C4a02l_;`0/K6a0<K6aP3=cLd0clo?
0>?Sh`2c/k<0];Bd09nOW`2YZJT0`<300;Jf]P2n_[h0_;bl0<c<c03?cll0Xj>S09BDU03:b/X0`<30
7P3oool03`2l_;`0bLW90:n_[`2k^k/0f=SH0=7Ad@33`l<0_;bl0<?3``2n_[h0[Jf]0;Jf]P30`<00
][Jf0<W9b@020<;2`P0:0<?3``2i^KT0/;2`0;Bd]02n_[h0c/k>0;jn_P2f][H0_[jn0;Jf]P80Xj>S
01<0][Jf0;bl_03?cll0^KVi0<?3``2d];@0c<c<0<?3``39bLT0aLG509nOW`30`<00dM7A0<k>cP2l
_;`0alO70<[:bP2g]kL0b/[:0080aLG503L0e]KF0<O7a`2i^KT0`/;20:>SX`2k^k/0e]KF0<G5a@32
`/80_;bl0;Vi^@32`/80XJ6Q0=GEe@2ZZZX0/;2`0>;RhP20P800dM7A0:BTY02n_[h0`<300;Jf]P2g
]kL0YZJV0=7Ad@33`l<0`<300:6QX@2b/[80_;bl0<o?c`2_[jl0dM7A0;bl_02n_[h0][Jf0<O7a`35
aLD0b/[:0>KViP2k^k/0_[jn0:RXZ02b/[80_[jn0;Ng]`30`<00^k^k0<W9b@3<c<`0YZJV09RHV033
`l<0`<3001T0oooo000G0?ooo`0F0;Zj^P2f][H0b<S809JFUP2][Jd0][Jf0;jn_P2j^[X0emOG0;6a
/@2_[jl0/k>c0;6a/@3<c<`0`<300<K6aP30`<00/K6a0;jn_P38b<P0b/[:0<K6aP80_;bl0240b/[:
0<g=c@36a/H0YjNW0:f][@38b<P0][Jf0<;2`P3:b/X0];Bd0;Rh^03<c<`0a/K60<30`02f][H0^[Zj
0=7Ad@3<c<`0b<S80<[:bP2n_[h0b<S80;Zj^P3<c<`0`<300;Rh^03GemL0S8b<0=7Ad@2_[jl0V9RH
0:n_[`38b<P00P30`<009@36a/H0Vi^K0<C4a034a<@0`<300<g=c@30`<00ZJVY09^KV`3GemL0`<30
0;Jf]P2l_;`0WinO0=GEe@34a<@0R8R80<30`03<c<`0Vi^K0;bl_03UiND0eMGE0;>c/`36a/H0cLg=
0:n_[`32`/80`<300;bl_03=cLd0^[Zj0;Rh^02YZJT0c<c<09nOW`2YZJT00P30`<001`2n_[h0clo?
0;>c/`2n_[h0a/K60<;2`P2_[jl07P3oool02P2l_;`0_[jn0<[:bP2NWYh0/[:b0;bl_030`<00_;bl
0=KFeP2i^KT30;Bd]00;0<c<c032`/80alO70<O7a`2b/[80_[jn0<O7a`39bLT0c<c<0;^k^`30`<00
0P3<c<`04P35aLD0Zj^[0;2`/037alL0]kNg0;jn_P35aLD0/[:b0;Ng]`3>c/h0bLW90;bl_02i^KT0
`<300=7Ad@3<c<`0aLG50<o?c`80aLG50380`l?30<k>cP32`/80][Jf0=?Cd`2@T900dM7A0;:b/P2J
VYX0/[:b0<W9b@2n_[h0_;bl0<;2`P2QXJ40aLG50<30`02l_;`0c<c<0<30`02][Jd0W9bL0=_Kf`30
`<00^KVi0;Ng]`2TY:@0f][J0;Vi^@2;Rh/0bLW90<c<c02OWil0_;bl0=gMg@3AdM40];Bd0<?3``3A
dM40[jn_0<?3``35aLD0`/;20<c<c02k^k/0_[jn0:ZZZP3<c<`0Y:BT0:RXZ080`/;200L0_;bl0<c<
c02b/[80_[jn0<G5a@30`<00];Bd01T0oooo000G0?ooo`070;Jf]P2j^[X0a<C40<K6aP2UYJD0ZJVY
0<30`0020<K6aP0309nOW`2d];@0a<C400<0a/K600<0`/;20;>c/`34a<@00P34a<@0103IfMT0`/;2
0;Jf]P2YZJT20<C4a00;0<g=c@32`/80^;Rh0<;2`P34a<@0^;Rh0;6a/@2f][H0^[Zj0<c<c030`<00
0P38b<P07`3:b/X0Xj>S0<c<c034a<@0cLg=0<S8b03=cLd0WIfM0<30`02[Zj/0MgMg0:NWY`2][Jd0
c<c<0:f][@30`<00a<C40;jn_P2f][H0^[Zj0<30`02WYjL0Vi^K0=7Ad@3=cLd0^[Zj0<30`02h^;P0
`<3008b<S02IVIT00P2c/k<01@2KVi/0R8R80:VYZ@2c/k<0clo?0080a/K601@0iNGU0:6QX@2c/k<0
][Jf0<C4a02UYJD0/K6a0;Bd]03Cdm<0cLg=0:^[Z`2f][H0`/;20<S8b03GemL0c<c<0<C4a03?cll0
_;bl0;Jf]P80a<C400@0^;Rh0;Zj^P2d];@0];Bd7P3oool0102k^k/0`l?30<;2`P37alL20:f][@07
0;jn_P33`l<0`l?30:JVYP2b/[80aLG50<O7a`030<G5a@0=0;Vi^@35aLD0`l?30<G5a@3Hf=P0`l?3
0;Vi^@2][Jd0aLG50<O7a`3?cll0`l?30;^k^`020<G5a@070;^k^`2d];@0^KVi0;bl_037alL0_[jn
0<W9b@020<G5a@0N0:JVYP3<c<`0`l?30<c<c03>c/h0bLW90:6QX@30`<00[Jf]07emO@2XZ:P0/;2`
0<[:bP2`/;00`/;20<G5a@30`<00][Jf0;^k^`30`<00];Bd09bLW03AdM40b/[:0;Vi^@30`<00][Jf
0;bl_02>SXh0V9RH0P2b/[807@2OWil0S8b<0:RXZ02b/[80c/k>0;Vi^@32`/80e]KF0:BTY02g]kL0
^KVi0<?3``2XZ:P0/;2`0;Bd]03AdM40c<c<0;2`/02i^KT0`/;20<O7a`3Fe]H0c<c<0<?3``3?cll0
_;bl0;Ng]`33`l<0aLG50080_;bl00<0]kNg0;Jf]P3oool0603oool001L0oooo00<0^;Rh0<C4a02d
];@00P32`/807@2WYjL0`/;20;Zj^P2h^;P0`<300:VYZ@2l_;`0^[Zj0<C4a02a/K40_[jn0;Rh^02j
^[X0`<300<C4a02c/k<0a<C40<30`032`/80_;bl0;Bd]038b<P0UYJF0<c<c03:b/X0b<S80<30`02n
_[h0c<c<0080`/;202X0c<c<0<o?c`3?cll0Xj>S0?Cdm036a/H0a<C40;Bd]03?cll0a<C40<o?c`2c
/k<0fm_K0:6QX@3Cdm<0Zj^[0<C4a02j^[X0_[jn0;Bd]036a/H0a<C40;Jf]P30`<00`/;20:FUY@2c
/k<0^[Zj0<[:bP2KVi/0];Bd0;>c/`2:RXX0^;Rh0<S8b02[Zj/0/K6a0:NWY`2f][H0Xj>S0=gMg@2]
[Jd20;6a/@0I0<o?c`2SXj<0c<c<0;Bd]030`<00WIfM0;bl_02a/K40/k>c0;Bd]02l_;`0^;Rh0;Jf
]P34a<@0`/;20<30`032`/80b<S80<;2`P3:b/X0a<C40<g=c@30`<00`/;20;Bd]00N0?ooo`030;Bd
]035aLD0^KVi0080aLG501X0ZZZZ0<O7a`30`<00]kNg0;bl_02XZ:P0^KVi0;Ng]`35aLD0][Jf0;^k
^`2f][H0`/;20<O7a`30`<00/;2`0<?3``30`<00_[jn0;Vi^@2k^k/0c<c<09ZJVP3<c<`0bLW90<O7
a`80^k^k01X0b/[:0<30`033`l<0c<c<0<o?c`3>c/h0[jn_0?;blP30`<00`/;20;Vi^@3AdM40`l?3
0<c<c02_[jl0eMGE0:BTY03>c/h0Zj^[0<?3``2g]kL0_;bl0;Ng]`3>c/h0c<c<0;Bd]080`/;20140
Y:BT0;:b/P2i^KT0aLG509bLW02l_;`0]kNg08N7Q`2`/;00aLG50:^[Z`2d];@0[jn_0;^k^`2VYZH0
dM7A0:^[Z`020;:b/P0>0<[:bP2VYZH0c<c<0:^[Z`2l_;`0WYjN0;Vi^@2f][H0];Bd0;Ng]`2l_;`0
^KVi0;Ng]`32`/820<30`0030<;2`P37alL0`/;20080aLG500@0c<c<0<?3``30`<00][Jf6@3oool0
01L0oooo01T0^[Zj0:VYZ@2h^;P0^[Zj0;Bd]034a<@0/K6a0;bl_032`/80WinO0:FUY@2n_[h0][Jf
0;bl_02a/K40_[jn0<[:bP3AdM40Xj>S0;Jf]P36a/H0/k>c0<K6aP2j^[X0];Bd0080_;bl02L0a<C4
0;Bd]02d];@0[jn_0<g=c@2SXj<0`<3006IVIP34a<@0a/K60;Rh^02WYjL0`/;20=?Cd`2l_;`0dm?C
0;bl_02_[jl0fm_K0<c<c02j^[X0b/[:0;>c/`3<c<`0^;Rh0<S8b02l_;`0YjNW0;Bd]02h^;P0b/[:
0;jn_P2l_;`0a/K60<30`03?cll0YJFU0<S8b03:b/X00P30`<009@2OWil0a/K60:n_[`2YZJT0`/;2
0;Rh^02SXj<0b<S80:FUY@2n_[h0/k>c0:n_[`2f][H0WinO0<c<c02j^[X0b<S80<;2`P2l_;`0c<c<
0;bl_03=cLd0gmoO0:NWY`2h^;P0[jn_0:>SX`2f][H0[Jf]0<g=c@38b<P0^[Zj0:VYZ@3=cLd0[Jf]
0<;2`P3?cll07P3oool0C`2i^KT0[Jf]0;Ng]`2i^KT0];Bd0<G5a@2b/[80_;bl0<;2`P2TY:@0Zj^[
0;^k^`2g]kL0_;bl0;Bd]02k^k/0aLG50<o?c`2][Jd0];Bd0<;2`P2b/[80`l?30;Vi^@2d];@0^KVi
0<;2`P30`<00/[:b0:f][@2d];@0c/k>0:f][@39bLT0K6a/0<;2`P37alL0`<300:^[Z`3:b/X0e]KF
0;jn_P3>c/h0^k^k0:n_[`3QhN40`<300;Bd]032`/80[Jf]0<[:bP32`/80`l?30;jn_P2_[jl0/;2`
0;^k^`37alL0aLG50<;2`P2f][H0`/;20<O7a`2TY:@0_[jn0<W9b@37alL0]kNg09NGU`30`<00]kNg
0;2`/02i^KT0/[:b0:6QX@39bLT0Y:BT0;bl_02d];@00P2ZZZX0402OWil0clo?0;Ng]`37alL0`/;2
0;bl_03<c<`0];Bd0<W9b@3MgMd0Z:RX0;Jf]P2b/[80Y:BT0;Vi^@2`/;020<G5a@060;Jf]P2ZZZX0
c/k>0;bl_032`/80c/k>6@3oool001L0oooo05`0^[Zj0;Jf]P2j^[X0`<300<C4a03?cll0`<300<;2
`P2n_[h0][Jf0:>SX`2c/k<0`<300;Bd]02l_;`0_[jn0:NWY`2h^;P0U9BD0;>c/`3:b/X0^[Zj0<[:
bP2j^[X0];Bd0;Rh^02n_[h0`<300<[:bP3Kfm/0`<300;Zj^P000000`/;20;bl_02DU9@0][Jf0<S8
b03=cLd0[jn_0;>c/`3<c<`0^;Rh0<g=c@2MWId0VIVI0;Bd]032`/80b/[:0<30`038b<P0WinO0;jn
_P2h^;P0];Bd08B4Q02d];@0eMGE0<30`03<c<`0_;bl0<K6aP30`<00^;Rh0<;2`P3<c<`0XJ6Q0;bl
_02h^;P0fm_K0=?Cd`36a/H0_[jn0<[:bP2n_[h0Vi^K09BDU02<S8`0b<S80;Jf]P3EeMD0Zj^[0<g=
c@2YZJT0_[jn0:>SX`3?cll0dM7A0<[:bP2][Jd0^;Rh0;jn_P80^;Rh0P2l_;`02@2_[jl0^[Zj0<S8
b02d];@0b/[:0<K6aP32`/80a<C40;Jf]P0N0?ooo`0H0;Vi^@30`<00^KVi0;jn_P32`/80b/[:0<;2
`P33`l<0`<300;Bd]02XZ:P0/[:b0;bl_02f][H0^k^k0<;2`P2[Zj/0/[:b09NGU`2f][H0b/[:0;Vi
^@37alL0^k^k0P2f][H06P33`l<0aLG50<o?c`3Cdm<0`l?30<O7a`0:2PX0alO70;^k^`2HV9P0][Jf
0<?3``3:b/X0/;2`0;Jf]P3AdM40_[jn0<c<c02NWYh0WinO0;:b/P32`/80bLW90<30`03:b/X0WinO
0P30`<009`2k^k/0QXJ60;Ng]`3AdM40^KVi0<c<c030`<00`l?30<30`032`/80aLG50<[:bP2JVYX0
_[jn0;Vi^@3Fe]H0bLW90<30`02k^k/0alO70;jn_P2JVYX0UIFE092@T037alL0^KVi0<o?c`2[Zj/0
bLW90:^[Z`2n_[h0YZJV0<k>cP3AdM40aLG50:n_[`2k^k/0`<300;Ng]`020;^k^`060;jn_P2b/[80
^k^k0<?3``2g]kL0aLG50P37alL00`33`l<0]kNg0?ooo`0H0?ooo`005`3oool06P2j^[X0][Jf0:f]
[@2n_[h0][Jf0;bl_02n_[h0^[Zj0<;2`P2f][H0[jn_0;Bd]02f][H0/k>c0;Rh^032`/80^[Zj0;Rh
^036a/H0[Jf]0<S8b03IfMT0a<C40<K6aP3oool0dM7A0P2d];@02036a/H0_;bl0<K6aP2f][H0`<30
0<[:bP2n_[h0Zj^[0P34a<@01`2d];@0cLg=0<K6aP2d];@0eMGE0<;2`P2_[jl00P2h^;P01P3=cLd0
dm?C0<C4a030`<00b<S80;Zj^P80[jn_02P0^;Rh0<K6aP32`/80/K6a0<C4a02h^;P0fMWI0;Zj^P32
`/80b/[:0;Zj^P3:b/X0`<300<C4a02_[jl0^[Zj0<C4a02a/K40YjNW08b<S038b<P0^;Rh0;jn_P2a
/K40^;Rh0<o?c`34a<@0fm_K0:f][@3Cdm<0b<S80<g=c@2f][H0ZJVY0;Bd]03<c<`0Vi^K0;Rh^032
`/80YJFU0`34a<@01`2d];@0`/;20<K6aP2l_;`0[jn_0<30`02l_;`07P3oool0402k^k/0^KVi0;:b
/P30`<00^KVi0;jn_P32`/80_;bl0<?3``2f][H0[jn_0;bl_02g]kL0];Bd0;Vi^@33`l<20;bl_00l
0<G5a@2[Zj/0`l?30=?Cd`32`/80alO70?[jnP3?cll0][Jf0;Bd]033`l<0^KVi0<;2`P2n_[h0_;bl
0<[:bP2n_[h0/;2`0<O7a`30`<00/[:b0<c<c035aLD0][Jf0<o?c`32`/80/;2`0;:b/P2f][H0bLW9
0<k>cP30`<00`/;20<G5a@2k^k/0/;2`0;Jf]P2l_;`0aLG50;jn_P2g]kL0`/;20;^k^`3Cdm<0^KVi
0<30`03:b/X0_;bl0<O7a`30`<00`l?30;2`/02i^KT0`/;20:f][@2LW9`0Ti>C0<G5a@2i^KT0`<30
0P2f][H03`3Fe]H0`l?30<k>cP2[Zj/0dm?C0<O7a`3:b/X0^KVi0:^[Z`2f][H0b/[:0:6QX@2k^k/0
aLG50:^[Z`020<W9b@060<;2`P2g]kL0`<300<?3``2i^KT0/[:b0P2n_[hI0?ooo`005`3oool01@2j
^[X0^;Rh0<C4a02h^;P0];Bd0080_;bl00D0`/;20;jn_P38b<P0YJFU0<K6aP020:n_[`0L0;Zj^P30
`<00^;Rh0<;2`P2SXj<0a/K60;Jf]P2a/K40_;bl0<C4a01oOgl0`/;20<S8b02d];@0_[jn0<S8b03E
eMD0`/;20<30`02a/K40/k>c0<C4a02n_[h0`/;20<S8b03AdM40`<300<K6aP80/k>c00X0a<C40<;2
`P2[Zj/0gmoO0;Jf]P2a/K40`<300;bl_03=cLd0`<300P36a/H0<@2f][H0clo?0<K6aP2l_;`0dm?C
0<S8b02j^[X0b/[:0;>c/`3EeMD0_[jn0;Rh^03?cll0b/[:0=7Ad@34a<@0][Jf0;jn_P2c/k<0^;Rh
0<C4a02][Jd0a/K60<c<c03:b/X0a/K60=?Cd`3GemL0cLg=0<C4a02l_;`0];Bd0<C4a03?cll0`<30
0;bl_02h^;P0^[Zj0;bl_032`/80fm_K0<c<c02n_[h0a/K60:n_[`36a/H0a<C40<[:bP36a/H07P3o
ool00`2k^k/0^KVi0<?3``020;^k^`0;0;jn_P2l_;`0`/;20;jn_P37alL0Y:BT0<W9b@2d];@0[jn_
0;Vi^@32`/800P2i^KT03`2XZ:P0alO70;bl_02`/;00^k^k0<W9b@2<S8`0`/;20<O7a`2d];@0_;bl
0<G5a@3AdM40_[jn0<30`0020;Bd]00C0<?3``2n_[h0`/;20<G5a@3<c<`0_[jn0<G5a@2b/[80];Bd
0<?3``32`/80];Bd0=gMg@2i^KT0];Bd0;^k^`2i^KT0b/[:0;bl_0020<G5a@0]0;bl_03?cll0alO7
0;bl_03?cll0`l?30;bl_03:b/X0/[:b0=7Ad@2k^k/0]kNg0<c<c037alL0dM7A0<30`02b/[80^k^k
0;Bd]02i^KT0`l?30:^[Z`35aLD0c<c<0<W9b@33`l<0c/k>0=7Ad@39bLT0`<300;Vi^@2][Jd0`<30
0<[:bP2l_;`0]kNg0;Jf]P2k^k/0`<300<G5a@3Fe]H0alO70;^k^`3<c<`0/[:b0080b/[:00<0clo?
0<?3``3oool0603oool001L0oooo01D0_[jn0;Rh^036a/H0][Jf0<c<c02QXJ40^[Zj0;6a/@30`<00
[Jf]09RHV034a<@0_;bl0;Zj^P30`<00/K6a0:n_[`38b<P0a/K60;Zj^P30`<000P34a<@09`2UYJD0
a/K609fMW@2QXJ40/K6a0<o?c`2f][H0a<C40<g=c@32`/80a<C40;Zj^P3=cLd0a<C40<K6aP3:b/X0
cLg=0;jn_P2UYJD0a/K60=7Ad@2OWil0];Bd0<30`02_[jl0a<C40;jn_P3<c<`0`/;20=?Cd`2n_[h0
OGem0:n_[`3AdM40cLg=0;jn_P38b<P0a<C40<o?c`020<g=c@0E0<c<c02l_;`0b/[:0:VYZ@2d];@0
^;Rh0;Zj^P2l_;`0[jn_0:>SX`2l_;`0V9RH0;bl_02UYJD0_[jn0<c<c02SXj<0];Bd0:6QX@3<c<`0
^[Zj0080clo?0180fMWI0<C4a03Kfm/0c<c<0<C4a03EeMD0^[Zj0=?Cd`2n_[h0a<C40;jn_P3<c<`0
clo?0<g=c@36a/H0dm?C0;bl_034a<@N0?ooo`0?0;bl_02g]kL0alO70;Vi^@3>c/h0XJ6Q0;Vi^@2d
];@0`l?30;:b/P2HV9P0`/;20;^k^`2l_;`0`/;20080[jn_00@0`l?30<;2`P2g]kL0_;bl0P30`<00
:P2SXj<0`/;209jNWP2QXJ40[Jf]0<[:bP2d];@0`/;20<c<c032`/80`l?30;^k^`39bLT0`<300<?3
``35aLD0c<c<0;jn_P2XZ:P0alO70<W9b@2LW9`0[jn_0;jn_P2`/;00`/;20;^k^`3:b/X0`l?30<[:
bP2n_[h0NGUi0;:b/P3Kfm/0aLG50<30`039bLT0`l?30<o?c`33`l<0bLW90<c<c080^k^k01L0Zj^[
0;2`/02d];@0]kNg0;Jf]P2[Zj/0XJ6Q0;Ng]`2HV9P0Zj^[0:>SX`33`l<0alO70:JVYP2d];@0XJ6Q
0=7Ad@2f][H0alO70<G5a@3Cdm<0`l?30=SHf0020<[:bP070<o?c`2g]kL0c/k>0;Vi^@30`<00][Jf
0<k>cP020<[:bP040<?3``3?cll0^k^k0<;2`QT0oooo000G0?ooo`0;0;Rh^030`<00^;Rh0;Rh^034
a<@0_;bl0:FUY@2l_;`0`/;20;Zj^P2@T9000P2j^[X0503:b/X0[jn_0<K6aP34a<@0eMGE0;bl_02f
][H0`/;20=7Ad@2n_[h0/K6a0;Bd]030`<00_;bl0<K6aP3<c<`0cLg=0<C4a02l_;`0`/;20P38b<P0
203?cll0][Jf0=7Ad@2_[jl0cLg=0;>c/`3:b/X0c<c<0P2l_;`0:02c/k<0^;Rh0<g=c@2j^[X0b/[:
0>7Qh@3Ogml0b<S80:f][@2l_;`0^;Rh0<C4a03Ogml0`<300=7Ad@3:b/X0clo?0<;2`P2][Jd0Zj^[
0<S8b02c/k<0b<S80;bl_02n_[h0clo?0:VYZ@2c/k<0[jn_0<o?c`2WYjL0_;bl0;>c/`3AdM40];Bd
0;Rh^03AdM40_[jn0<S8b03<c<`20<S8b00B0=WIf@38b<P0^;Rh0<g=c@30`<00_[jn0:>SX`2KVi/0
`/;20;Bd]02j^[X0clo?0=gMg@3Cdm<0b/[:0<K6aP2f][H0_[jn7P3oool02`2d];@0_[jn0;^k^`2k
^k/0alO70<30`02ZZZX0^k^k0;jn_P2g]kL0T92@0080^KVi01h0alO70:n_[`35aLD0`<300=GEe@2n
_[h0][Jf0<30`03>c/h0_;bl0;Bd]02f][H0_[jn0;^k^`30`<00alO70<W9b@32`/80^KVi0;jn_P33
`l<0alO70<[:bP2d];@0c/k>0;:b/P39bLT0/;2`0<G5a@37alL20;bl_00B0;Bd]02i^KT0c<c<0;Vi
^@35aLD0e]KF0=SHf03?cll0Z:RX0;Ng]`2l_;`0c/k>0=?Cd`2l_;`0c<c<0<?3``3<c<`0alO70P2]
[Jd0:037alL0];Bd0<?3``2i^KT0^k^k0<G5a@2XZ:P0/[:b0:n_[`3<c<`0Y:BT0;bl_02`/;00c<c<
0;:b/P2f][H0c/k>0<30`039bLT0clo?0<[:bP39bLT0f=SH0<?3``2f][H0bLW90;bl_02g]kL0Xj>S
09bLW033`l<0^KVi0<?3``39bLT0e]KF0<o?c`3:b/X0alO70;Vi^@30`<0I0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00?P3oool2@0000080oooo0d0000030?ooo`9000000`3oool2@00000030?oo
od00001000000080oooo00=000000?ooo`3oool0L03oool4@0000080oooo0d0000030?ooo`=00000
0P3oool2@00004H0oooo000m0?ooo`03@000003ooom0000000<0oooo00E000000?ooo`3oool0oooo
@00000040?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000L`3oool014000000
oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo@0000018
0?ooo`00?@3oool014000000oooo@000040000020?ooo`04@000003oool0oooo0?ooo`=000000P3o
ool3@0000080oooo00A000000?ooo`3ooom00000L`3oool014000000oooo0?oood0000020?ooo`05
@000003oool0oooo0?oood0000000P3oool00d000000oooo@0000002@00004H0oooo000m0?ooo`03
@000003oool0oooo0080oooo14000000103ooom00000@000040000020?ooo`=0000000<0oooo@000
040000000T00001d0?ooo`=000000`3oool00d000000oooo0?ooo`02@00000040?oood0000100000
0?ooo`=00000AP3oool003d0oooo00=000000?ooo`3oool0R03oool014000000oooo0?oood000002
0?ooo`03@000003oool0oooo04l0oooo000m0?ooo`=00000Q`3oool4@0000080oooo0T00001A0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00WP3oool03@2o_kl0]kNg0:f][@2k^k/0/K6a0;>c/`2X
Z:P0[jn_0:^[Z`2g]kL0[jn_09bLW02TY:@00P2[Zj/01`2a/K40Z:RX0:JVYP2RXZ80W9bL0:BTY02]
[Jd00P2a/K40<02ZZZX0/k>c0:JVYP2m_Kd0bLW90;Ng]`35aLD0/K6a0;Fe]@2g]kL0]KFe08:2PP2g
]kL0/K6a0:ZZZP2][Jd0W9bL0;Ng]`35aLD0]KFe0;^k^`2_[jl0Z:RX09:BTP2:RXX0^k^k0;Vi^@2_
[jl0QXJ60:RXZ02g]kL0`L710;no_`33`l<0Y:BT08b<S02k^k/0[jn_0;6a/@2m_Kd0_kno0<G5a@2a
/K40_kno0;^k^`2o_kl0[jn_0<71`@80^k^k00P0_Kfm0;Fe]@2m_Kd0[jn_09jNWP2e]KD0_kno0;fm
_@80]KFe00@0`L710;>c/`39bLT0^k^k0P31`L40302k^k/0/K6a0<71`@35aLD0`L710:ZZZP2a/K40
`L710:BTY02c/k<0]KFe0;Ng]`80^KVi00<0]KFe0?ooo`3oool05`3oool001L0oooo0240Ngam07Mi
M`1bL780NGMi07AbM01eN7P0KgE`07=iMP1aMWP0MgYl06ecLP1YK6`0KFi_075^K01aM780M7Id06ma
K`1^KVT0K79a07j0OP1]K6/0LVeZ07AdK`1`Kf`0MWEb07EcM@1^M7<0NWMg07=fM01gMg80OWUg07Ai
N`1gMG400P1fN7H0A@1LHUd0M7=`07EkN01`Lg40LWEg06U[J@1nOGX0MgIc07IhM01iNgL0Kg5_07El
OP1TIFP0H5]F07QgMP1cL6h0J6IR05iNF@1_LF`0O7Yb07]dLP1jN7@0OGeh065PG`1iNgL0N7Yh07=d
M@1jO7X0Ngei07j0O01jO7P0M7Me07UgL@1kNGD0N7Ec07=`KP1iOGL0NG]f07YjM@1kNgH0NWUh07=k
M`1ZK6L0M75a07IeM01jO7P0MWUi07IhMP1bM700MGAa081oO01iNgL0MgUe07aiN@1iMWP0M7Yg07ak
NP21NWT0O7n1071bKP1dMW80O7ag06e`KP1eNgX0MWEd07MdLP1hNWH0N7]i07IhMP0O0?ooo`0:0:n_
[`2c/k<0Z:RX0<71`@2o_kl0/k>c0<?3``2g]kL0bLW90;Fe]@80[Jf]01<0ZZZZ0;>c/`2[Zj/0[jn_
0;>c/`2_[jl0^KVi04Q8B02][Jd0XZ:R0:^[Z`2VYZH0Zj^[0:n_[`2ZZZX0[Jf]0<o?c`35aLD0ZZZZ
0080[Jf]0100^k^k0;fm_@39bLT0[jn_0;^k^`2a/K40]kNg0;Vi^@2RXZ80Z:RX0820P02_[jl0aLG5
09jNWP2[Zj/0X:2P0P2_[jl01`2XZ:P0/k>c09ZJVP2c/k<0Ogmo09bLW02_[jl00P2e]KD0;@2[Zj/0
^KVi0<_;b`2c/k<0/K6a0<71`@2o_kl0/k>c0;^k^`2i^KT0ZZZZ0;>c/`2e]KD0_kno0<G5a@31`L40
Zj^[0;fm_@2_[jl0^KVi0:^[Z`2g]kL0_Kfm0;Ng]`2i^KT0/K6a0;Vi^@39bLT0`l?30;Vi^@2TY:@0
_kno0;^k^`2e]KD0YZJV0<W9b@2[Zj/0`l?309RHV02][Jd0_kno0<?3``2_[jl0[Jf]0<71`@0I0?oo
o`005`3oool0J01cLW40MGEj06m^J`1lNG/0NgAk07EhN01mOWl0MgQi0821PP1fOG`0MG]j079cM01`
KFl0MGAc075`K`1cLW40MGAc07=bL@1hMgH0QH1k079cM01/Kfd0LG=a075`K`1fM7H0LgEi071]K`1b
MVh0M7Ij07iiM`1`MW40LViV07UnP`1fNGL0NWUh081mO@1iMWH0LgEc07AfM01gM780N7Ec06m`L@1m
OWl0FeYI07=bL@1ZKFd0OX61075_I`1[I680Lg9_06m^J`1mOg/0MGMc06QZIP1JE5L0JFmZ07MfL`1c
K6/0MWMh075^K01fM7H0N7f007EbL01dMW80O7]h07YgM@1kNgH0NGQg07QgMP1`Kfh0L7=a07IhMP1k
OG/0OX1n07=eL`1aKf/0NWaj07=hNP1dMgD0N7Mf07MfL`1jO7X0MgIc07imNP1dMGH0N7im081oOP1n
OG`0N7Yh06e_K@1kNWT0NGQg07UmN01^LVd0P7ek075^K01mO7T0IfIS079cM01kO7d0OGak07=bL@1b
LVd0O7ii7`3oool02@2g]kL0[Jf]0:f][@2c/k<0X:2P0:JVYP2k^k/0_kno0;Vi^@020;>c/`80Zj^[
03P0/k>c0;Ng]`2][Jd0Zj^[0;fm_@2g]kL0VYZJ0:f][@2XZ:P0X:2P0;>c/`2][Jd0Y:BT0;fm_@2]
[Jd0`l?30:n_[`31`L40S8b<0;^k^`31`L40alO70;fm_@2a/K40Y:BT0;>c/`2][Jd0Z:RX0;fm_@2i
^KT0]KFe0<71`@2c/k<0^k^k09ZJVP2LW9`0]KFe0:2PX02_[jl0[Jf]0:n_[`31`L40/K6a0::RXP2e
]KD0]kNg0:n_[`2i^KT0]KFe0;Vi^@37alL0/k>c0<71`@2c/k<0YZJV0;Ng]`<0_Kfm0P2k^k/07`2o
_kl0]KFe0<W9b@33`l<0YZJV0;Ng]`39bLT0]KFe0;Ng]`2i^KT0_kno0;Ng]`2e]KD0aLG50:JVYP2g
]kL0ZZZZ0;>c/`2o_kl0bLW90<G5a@2o_kl0[jn_0<O7a`2RXZ80]kNg0;6a/@2o_kl0`L710:^[Z`2i
^KT06@3oool001L0oooo02D0MgIe079gN@1bL7D0MG=e06]ZJ@1^LG40NG]g07]mN@1hNWH0MFmb079_
L@1aLW<0LGAd07EhMP1gNWP0LWEg075dMP1jNGP0MgIe07=eL`1bM780Kg9`06]]J`1bLG00Lg5c06eb
M01jOGd0LV]Y07AgN@1cLG<0O7Ii065WIP1lNGT0OW]k07mnO@1jNGP0KFa[0080MG]h0200LWA`06ma
K@1hNWH0N7Yf07IeM01lNgX0NG]i06a^K01XJfT0JFAR06]ZI`1cLVl0MgUe079dL01cMG40M6ic06a_
K`1WJVX0MWUi07=eL`1hN7<0MWQd07IiM`1oP840MGMc07akN01mNWP0MGAc07MjNP1jOGd0M7Mg07Yg
M`80NG]i01l0Ngek07QjN020NWl0OGYj06i]JP1`KFd0MgIe07IeLP1gNGL0N7=a07ehMP1gMWD0MWUg
07imO01mO7/0MgUg071bL01eM7<0NgYi07AfLP1nP7`0NgQf07=`KP1oPX80K6m_07MiM@1dMW80NgYi
07akNP1aL6d0N7Yf01l0oooo00/0]KFe0;>c/`2m_Kd0ZZZZ0:f][@2c/k<0[Jf]0<_;b`31`L40YZJV
0:RXZ0020:^[Z`070;Vi^@2c/k<0]KFe0:^[Z`2RXZ80[jn_0<W9b@020;^k^`0g08R8R02[Zj/0[jn_
0:n_[`2i^KT0]kNg0;no_`2ZZZX0^k^k0:^[Z`2c/k<0_Kfm0;Ng]`2[Zj/0ZZZZ092@T02PX:00[jn_
0:ZZZP2m_Kd0cLg=0;>c/`2_[jl0VYZJ0<71`@20P800Q8B40:^[Z`2NWYh0[jn_09ZJVP2[Zj/0[Jf]
0:BTY02_[jl0[Jf]0;6a/@2i^KT0`L710;>c/`2][Jd0X:2P0;6a/@2e]KD0ZZZZ0:RXZ02i^KT0Z:RX
0;^k^`2m_Kd0^KVi0:n_[`33`l<0[Jf]0<71`@020;Ng]`070;no_`39bLT0`L710<71`@2k^k/0[jn_
0;no_`020;Fe]@040;^k^`2RXZ80bl_;0;^k^`80^KVi00/0bl_;0;>c/`2FUYH0`L710<_;b`2a/K40
/k>c0:f][@2_[jl0Y:BT0:JVYP0I0?ooo`005`3oool0C01fNGT0MGQf07YkO01`Lg<0LW=d07EgM@1b
Kfd0PH>107aoO`1^LFl0Kg9b075bL`1aKg40N7Mf07EfM`1fNGL0LG=a06abK`1cNGH0NgIc07UhM@1i
MWH0Gf5O07=bL@1ZJFP0LgMb07QgM01gNGL0LG=a071bL01iNgT0LG1_07YiN01jN7X0MgYj075bL`1S
If80LG1_06]ZJ@1cNWT0L6m^089lO@1aM780MGMe07=eL`1lNG/0KV][05]MF@1MF5<0JVaZ07=bL@22
PGh0J6MT075`K@1]L700LgQm03P^901bM6l0N7Mf07aiN@1aKVh0MG9b06]]J`1dLg00MWEb07MfL`1`
Kfh0N7Mf06maK`1gNWP0NGUn07QgM01cLVl0OGai07anNP1lMgD207MbL00J081oOP1kNWT0O7]j07al
M`1iN7D0NgYg07]hN01fL740MW=a07QgM01/Kfd0PG]l07UhM@1hNWH0N7]m0860O@1eLfd0IVQT07ag
M@21O7X0M7Ib07EgL`1bLFh0Lg9_06e_J`1^L6`O0?ooo`0E0:BTY02m_Kd0Zj^[0<G5a@2o_kl0/k>c
0:ZZZP31`L40]KFe0;Vi^@2TY:@0]kNg0:f][@2o_kl0]kNg0:f][@2i^KT0]KFe0;6a/@33`l<0P820
0080Y:BT00T0MgMg09jNWP2a/K40]KFe0;^k^`3;bl/0alO70;no_`2XZ:P00P2m_Kd05@2RXZ80Z:RX
09JFUP2g]kL0Z:RX0;>c/`2ZZZX0[jn_0;fm_@37alL0]KFe0:^[Z`2e]KD0PX:20820P02LW9`0_kno
09ZJVP2_[jl0Zj^[0;6a/@020;Ng]`0D0;Vi^@2e]KD0Z:RX0:BTY02k^k/0YZJV0;Vi^@2g]kL0`L71
0;Vi^@2m_Kd0^KVi0<71`@35aLD0^KVi0<71`@2i^KT0]kNg0;Vi^@2ZZZX20;6a/@0B0;fm_@35aLD0
Y:BT0;>c/`2m_Kd0^KVi0;no_`2e]KD0`l?30<o?c`2o_kl0`L710;fm_@3;bl/0`L7109jNWP2XZ:P0
_Kfm102g]kL0102ZZZX0/K6a0;^k^`2e]KDI0?ooo`005`3oool05@1]L6h0NWMi075bL`1nOh00Ngam
07EdL`1`MW<0O7Yl07IiN`1hOWd0L7Ie07MjNP1bLg@0NgYi07MfM@1bLFh0N7=a07IcL`1dLg80G65S
05]KE00206eZJ00e06YYJ01cL6h0M7=b07IeLP1iMW@0N7Yf07mnN`1kOGT0KgMa07YmO`1bMGD0K6i/
06mcKP1gMW<0Ph2006m/K01eMWL0L7Ic07YcLP1cK6/0OgQg07IcM@1fMG80O7Yl05aIE`1KFUL0Ng]f
06QVHP1hKfl0LgMb075cK`1gMG40MgE_07ikN@1hMGD0Kg5_06e/J@1aL6d0NGQe07QkN`1gMW<0O7]h
07UhM@1hMg@0N7Ib07ajMP1iMg<0OX1n07agM@1hMg@0MgUe06YXJP1`LVh00P1dMW806P1`LVh0NWUf
06eZJ01eN7X0NWah07imNP1kOGT0MWYe07ekO@1lNW`0NgEf07aiN@1jNGP0PH1o07=gLP1ZKVT0Kg5_
07YiN01gMFl0MgUm07MiM01gNGL0L7Ia07AhL`1iN7L0MWEd7`3oool0802e]KD0Zj^[0;Fe]@2][Jd0
[jn_0:f][@22PX80YZJV0:RXZ031`L40_Kfm0:f][@2c/k<0]kNg0;Vi^@2k^k/0ZZZZ0;^k^`2PX:00
bLW90:2PX02i^KT0[jn_0:BTY02c/k<0U9BD0<71`@2NWYh0dM7A0;^k^`2i^KT0Zj^[0P31`L409@2o
_kl0alO70;6a/@2PX:00^KVi0;^k^`2o_kl0/K6a0;Vi^@2_[jl0XZ:R0;Vi^@2k^k/0NGUi08B4Q02g
]kL0^KVi09JFUP2_[jl0XZ:R0;^k^`33`l<0DU9B0<W9b@2e]KD0/k>c0;Vi^@2k^k/0]KFe0:^[Z`2R
XZ80^KVi0:n_[`2m_Kd0^KVi0;>c/`2][Jd00P2g]kL0802m_Kd0ZZZZ0<W9b@2a/K40XZ:R0:f][@2c
/k<0_Kfm0<O7a`2m_Kd0^k^k0;fm_@2g]kL0aLG50<71`@2g]kL0_kno0;Vi^@2c/k<0_Kfm0<O7a`35
aLD0alO70;Ng]`2m_Kd0/K6a0;>c/`2m_Kd0_kno0;Ng]`31`L40]kNg6@3oool001L0oooo03`0MWQf
075[K01fN7H0LWAb07=eL`1bLg@0G5YB06i/J01_Jg00O7]j07IhMP1bM780MGAc07MfL`1hMg@0NG]i
071cM@1iPX00Jfe[07MkMP1[Lfd0N7Yf07=eL@1eM740K6]X06EWH`1lNgP0JVUX07UhM`1iO7`0N7]k
075`K@1lMG@0MgMb07]nOP1oOGl0JfeX089lM@1hLW<0NGMc07]jN@1hP7`0LG1_07=/J`1/JFL0NG]f
06mfM@1GFE@0GEYH07QaL01VHf40L6ib07=bK`1/JV`0OH5l04=5@01[KFT0P7j007EdL@1hMGD207Uf
MP0H075`K`1/JfX0N7Mf07akNP1cMG<0N7Ec07EfM`1cN7/0LWQe07MkMP1jOWT0L7A_07elN@1dLg80
K6]Z079aL01fNG/0MGAc07mnN`1jNGH0NG]g07=bK`1gOGP0OX1l0P1lNgP0401kNWL0N7Md07EgM@1j
O7X0QWil07imNP1oOWd0MgYh07Z1NP1dNG/0MG9`07YgM@1kN7P0MgIe07anNP1gNGDO0?ooo`090:n_
[`2:RXX0alO70;Vi^@2][Jd0_Kfm0::RXP2o_kl0/K6a0080_kno00`0/k>c0:^[Z`2i^KT0[Jf]0:JV
YP2LW9`0[Jf]0:ZZZP2e]KD0ZZZZ09JFUP2g]kL20:f][@0B0:ZZZP2XZ:P0[jn_0<?3``2m_Kd0`l?3
0:JVYP2e]KD0`l?30;Ng]`39bLT0/k>c0;^k^`2i^KT0[jn_0;Fe]@2g]kL0eMGE0P2g]kL0:02m_Kd0
^KVi09ZJVP1oOgl0`L710:BTY02e]KD0V9RH0:2PX02e]KD0/k>c0;fm_@31`L40W9bL0;>c/`31`L40
]KFe0;Ng]`2][Jd0Zj^[0;Vi^@2c/k<0/K6a0;^k^`2o_kl0Z:RX0;Ng]`2k^k/0]kNg0;fm_@2e]KD0
ZZZZ0;>c/`37alL0cLg=0<O7a`31`L40^k^k0;6a/@33`l<20<71`@0B0<G5a@37alL0_kno0<71`@2e
]KD0`L710:f][@2[Zj/0[Jf]0:BTY02g]kL0`l?30;Ng]`2[Zj/0ZZZZ0;fm_@2i^KT0bl_;6@3oool0
01L0oooo05H0LgUf061SH@1oO7`0N7Ee079_K`1jNg`0K6e`07]lO@1dMGH0NgYi07YhO01eN7X0LGYj
07QkN`1bMGD0KW1^06U]J01bKg40L6m^06a^JP1`MW40IVMX07MhN@1bLFh0Lg9_071bKP1_KV/0Lg9a
07akNP1jNGH0OGai06i`K01mN7H0MgEi07MjN020NGL0NG=f07ekO`1hNGX0Lg5e07IhMP26QH@0IVQV
07MbL01gMW<0N7Ul07afM`1XIV80FUaH06e/J@1fN7@0LW5`06MWH01[JVL0MGUd07YlNP1cMWH0O7n1
07EdL@1lNgX0Ogim07IeM01bLVd0LG1_07QgMP1iN7L0MG]h07UjN`1kN7H0M6m/06m/K01iNgL0MgUe
07YlN01hMg@0L6]V07E`J`1oNWD0OWn008:1P01lNgP0NGQe07AfLP1VIF80O81k07akN080OWej0100
NgYg07akN01fN7H0O7il06MLF@1aMWP0LW5`06e_K@1gLgP0OGYh07MeM`1aKg40L6e]07YiN01hMG<0
PGil7`3oool03P2g]kL0[Jf]0;Fe]@2a/K40Zj^[0:ZZZP2i^KT0`l?30;Ng]`2][Jd0]KFe0;>c/`2o
_kl0/k>c0P2][Jd01@2_[jl0Y:BT0:n_[`2TY:@0/K6a0080]kNg01l0Z:RX0:^[Z`2ZZZX0VYZJ06=S
H`2c/k<0_Kfm0;Vi^@3;bl/0_Kfm0<_;b`35aLD0Zj^[0;^k^`37alL0_kno0:ZZZP2VYZH0aLG509jN
WP2k^k/0]KFe0:n_[`2[Zj/0T92@08J6QP28R8P0]kNg0:BTY02g]kL0XZ:R00<0_Kfm0180]KFe0;fm
_@2e]KD0]KFe0;Vi^@2o_kl0^k^k0;>c/`2TY:@0]kNg0:JVYP2][Jd0_Kfm0:RXZ037alL0YZJV0:n_
[`33`l<20:f][@0I0:RXZ02a/K40`L710;Ng]`3;bl/0ZZZZ0;^k^`2e]KD0/k>c0<?3``2o_kl0alO7
0;^k^`33`l<0_kno0<g=c@2c/k<0/K6a0;Fe]@2i^KT0_Kfm0;Fe]@37alL0^k^k0;Vi^@020;6a/@03
0;no_`3oool0oooo01L0oooo000G0?ooo`1X07MiM`1bMG<0MWEd07AfM01aM780L79`07QeL`1mO7/0
MgQi079hM@1fO7/0MGMe07]dL`1eMgD0LWEc079dLP1cMG<0KG9d07=hNP1[KV`0M7Ib07MfM@1gNGL0
LGQg07MjNP1`LG80J6]Y04a?C@1cLW40NWMg07QeM@21P7l0PH>108:1P01nNg/0LGAb07mmN@1jNGP0
NgYi071bL01^L6h0JVaZ07]mN`1iNgT0MWQf075cK`1XKFl0HeeH05iJDP1gNGL0KFm]071gL01gNgD0
K6aW07Z0O`1jN7@0LW9]07ImMP1fNWD0MWai07EgM@1hLG80NGQg07EcK`1]JVX0NGEj07MjN01bL6`0
NWUf075cL@1_KVd0KW=e07=eL`1mMg80NWUf079dL01_KV/0M75_06e[I`1lNWH0PH>1071bL01iNgT0
Ngek07EdL@1mOg/0Ngek07UkN@1iN7L0OGak07]hMP22Ogd0N7Yh07AcLP1fMG@0N7]i07YiN01fMG@0
Ogeo07UhM`1hMW80M7Id07AfLP1kOGTO0?ooo`030;^k^`2c/k<0[Jf]0080YZJV02D0/k>c0;Fe]@2X
Z:P0/K6a0;>c/`2i^KT0]kNg0;6a/@2_[jl0]kNg0;Fe]@2[Zj/0aLG50;Ng]`2ZZZX0^KVi0;6a/@2g
]kL0/K6a0;Fe]@2[Zj/0TY:B0:f][@2HV9P0[jn_0;Ng]`2a/K40YZJV0;no_`2VYZH0^k^k0<71`@2g
]kL0/K6a0<71`@2m_Kd0^k^k0080_Kfm0P2k^k/06P31`L40Ng]k08Z:RP2@T900ZZZZ09:BTP2RXZ80
X:2P0:^[Z`2ZZZX0[Jf]09ZJVP2o_kl0]KFe0:n_[`3;bl/0XZ:R0;6a/@2ZZZX0Z:RX0=KFeP2ZZZX0
/k>c0:ZZZP33`l<0]KFe0P2o_kl01@2ZZZX0cLg=0;Ng]`31`L40aLG50080]kNg0100Zj^[0<W9b@2g
]kL0alO70<71`@2g]kL0^KVi0;6a/@2e]KD0_kno0;Vi^@2ZZZX0alO70<71`@2i^KT0YZJV0P2m_Kd0
1P33`l<0]KFe0<71`@2LW9`0alO706][JaT0oooo000G0?ooo`0307UkN@1eN7H0LWEc0080KW5_0480
MGMc07IhMP1_LFl0M7Id07EgL`1cM7D0MgQi07AeMP1cMW@0MgUg07IhM01aMG00OW]i07MiM@1fMG80
N7Md07AeMP1gN7T0MW=c079eM@1aMWP0I6MW079dLP1aMWP0LgQj07MfM@1dOG/0NgQj07EgL`1^L6`0
NG]i07MiM`1bMGL0M7Mi07aoO@1jO7X0NWQj07]iN`1jNGP0NGQg07anO01^L6`0F5YE061RGP1`LgD0
I69T07=`LP1/JV`0Jfi^071dK`1bLFh0Kfi[06QWI01fMG@0Lg1`079_K`21OWh0M7Yg071bL01_LFl0
KW1^08N9Q`1eM740L6m/075`K@1mOgd207]jN@0G071_KP1nPW`0Mg]f07anNP1nOG`0NWMe07MdLP1a
L6d0P7ml07MfM@1jMgL0O7]j07MfM@1hNgT0Ngmj07IiN@1kOWh0N7Yf071bKP1mOg/0O7ij07QkN@1^
LFl00P1jMgD01P1mOg/0MWQf07b3Q01YN7X0OhF4051BCAl0oooo01H0^k^k0;Fe]@2a/K40`l?30;^k
^`2e]KD0XZ:R0<71`@1oOgl0_kno0:f][@2g]kL0^k^k0;Vi^@2NWYh0`L710;6a/@2[Zj/0_kno0;fm
_@2a/K40]KFe0P2[Zj/01@2e]KD0/k>c0;Ng]`2k^k/0`L710080_Kfm04X0aLG509bLW02g]kL0`L71
0:n_[`31`L40bl_;0:^[Z`2g]kL0/k>c0:^[Z`2TY:@0aLG50<?3``2i^KT0]kNg024Q8@14A4@0Ng]k
0;6a/@2TY:@0WYjN0;Fe]@2ZZZX0Zj^[0;Fe]@2][Jd0W9bL0:ZZZP2XZ:P0aLG50:2PX02_[jl0alO7
0;Fe]@2o_kl0^k^k0;no_`2XZ:P0aLG50;Ng]`39bLT0^KVi0;Ng]`2i^KT0_Kfm0:RXZ02[Zj/0^KVi
0::RXP2i^KT0]KFe0;fm_@3Ti>@0bl_;0;fm_@2i^KT0^k^k0:^[Z`2a/K40^k^k0;6a/@2g]kL0^k^k
0;fm_@2a/K40Zj^[0:JVYP2k^k/0/k>c0<O7a`2m_Kd0[Jf]0;^k^aT0oooo000G0?ooo`0C07UgN@1f
M7H0M79^07ekM`1iMg<0MWQf06adL01lOgd0FUUH07]nO01gMGL0MgIc07UiLP1hMgH0JVUX07anO01d
MW@0LG=^07]iM@0207AjN@1C07IcM@1aLg40MWEd079`K01eMg<0MgUe07UhM`1CEU@0NWag07YkO01n
OXD0MgUg079aL01lNgX0LgEc0863P@1hNgT0LG=a07MfL`1eM740KFm]079dLP1nN7T0OGMh07MfL`1X
JW00:RdU03`g:`1dNG/0KF]_07IeM01ZJFP0MWEd075^KP1fNGL0N7]i079eL`1`Kf`0KfaZ07EbL01n
NgT0LgEa07mlNP1fMG80O7ij07]jM`1kOG/0Kg5_079dLP1nOGX0P7ij07QfLP1gMG40P8J307YdK`1_
I6<0LFi/07=bK`1hMg@0N7Yf07IhM01jLg40OGQe0860O`1jO7X0N7Mf07MfM@1aLg40M7Id07UkM`1d
MW80LWAb07UkN@1jOWT0M7Qc075cL@1^L6h0NG]i07EgM@1oOW/0NWUf079dLP1iMW@07`3oool03`2a
/K40^KVi0:^[Z`2[Zj/0/k>c0;Fe]@2g]kL0_Kfm0;6a/@2k^k/0_Kfm0:ZZZP2[Zj/0/K6a0;>c/`02
0:ZZZP040:n_[`3=cLd0^k^k0;no_`80[Jf]03l0[jn_0;>c/`2][Jd0^k^k0;Ng]`3;bl/0R8R80::R
XP2m_Kd0^KVi0;fm_@2g]kL0_Kfm0:f][@2g]kL0k>c/0;Fe]@31`L40^KVi0:ZZZP2o_kl0^k^k0:n_
[`2ZZZX0^k^k0:ZZZP3Hf=P0^KVi0;Fe]@2o_kl0^KVi0;no_`2a/K40Y:BT0:^[Z`2g]kL0[Jf]0;Vi
^@2k^k/0^KVi0;Ng]`2c/k<0]KFe0;^k^`33`l<0Z:RX0:n_[`2m_Kd0^KVi0;Fe]@2i^KT0]KFe0<g=
c@2i^KT0_kno0;Vi^@33`l<0]kNg0;fm_@2c/k<0[jn_0<71`@2c/k<00P2m_Kd0202e]KD0^KVi0;Ng
]`2e]KD0^k^k0;no_`2m_Kd0`L710P2g]kL01`2k^k/0/K6a0;Fe]@2a/K40]KFe0<o?c`2i^KT06@3o
ool001L0oooo00l0M7Ef07QkN`1aL6d0LG1]07EdL@1fL740MgIe07YlNP1dNWL0NGaj07MjO01`Lg<0
LGAb07AgN@1eN7X00P1`LW00:P1cMG<0PXF3075bL`1kO7d0LW1b079dLP1eN7H0LgE`079cM01iNW/0
MgIe07MjN01OI6H0K79_07YkOP1jO7X0NWek07MjN01jP7d0MgAd061IE`2BUID0MWAf07ajO01`LW00
MgUg07]hN01iMWH0L6m^03Xl=`1iJf40L6m/07QkN`1fMgP0N7Mf07]jN@1hMgH0M7Yg06e]J01^KVT0
LG5/079aKP80N7Md02/0NGQe07MiM@1eLW00MWEb075cK`1iMgT0Kg5_07=eL`1hNWP0NWUf07IhMP1h
NWP0MWQf08>0P01hOgH0NgIc07QeL`1hLg40OGQf07YlN01eMg<0Lg9_07IhM01eM7<0NWUh07YmN`1h
NgT0N7Yh07MiM`1fLg40NGId079dLP1jO7X0O7]h07MfL`1gNGL0NG]i07AfM01fN7H0M7Mg07IiN@23
R8X0N7]k01l0oooo00d0aLG50:n_[`2c/k<0]KFe0:n_[`2m_Kd0[jn_0;Ng]`2_[jl0^KVi0;fm_@2k
^k/0]kNg0080/k>c0140/K6a0;Ng]`2e]KD0/K6a0;Ng]`2k^k/0Zj^[0;Vi^@2e]KD0/K6a0:ZZZP2c
/k<0^KVi0<_;b`2m_Kd0XZ:R09JFUP020;^k^`030;>c/`2i^KT0[jn_0080/k>c00L0/K6a0;>c/`2_
[jl0Z:RX0:n_[`2a/K40ZZZZ0080WYjN03T0Zj^[07MgM`2[Zj/0_kno0<O7a`2VYZH0]kNg0;Vi^@2X
Z:P0X:2P0;6a/@2g]kL0/k>c0;^k^`2g]kL0_kno0:n_[`2RXZ80]kNg0;fm_@2e]KD0ZZZZ0<?3``2a
/K40_Kfm0;Vi^@2_[jl0]kNg09jNWP2c/k<0[Jf]0:n_[`2m_Kd0_kno0;Ng]`2a/K40`l?30;>c/`35
aLD0_Kfm0<71`@2o_kl0^k^k0;Vi^@2o_kl0/k>c0;^k^`33`l<0aLG50;^k^`2[Zj/0]kNg0:f][@2k
^k/0`L710:n_[`2][Jd06@3oool001L0oooo01D0L7Ic07AgM@1ZIfD0M7=`079dL01fN7H0K6UY06m/
K01]JVX0MGIg07IgN01eMWL0LgAe07EgM@1hNWP0M7Mg07EhN01jNg`0M7Ef051HFP1cLW400P1jNGP0
401gMWD0LgEc075cK`1lOWX0L7Ic06ecL01mO7/0NGQg07QgM01lNgP0OWel07]jN@1jO7X0LWAb071^
L01eM74207QgM00U07mmO`1dMgL0MG]f07IcL@1`Kfh0RHR708:0PP26QhP0Kg5_07=`KP1iN7D0I6=P
06]ZI`1hNg/0LGMf07MhN@1jLWH0MGUd07EjO023PWl0P7]h07akNP1aMg80LWQc07AjM@1jO7X0N7Yf
06a[J01jMgD0NG]g07YhO01lNW`0LW9]075`K@1dLg00JVMU07]jM`0207mnN`0D07ejN01`KF/0MGAa
07]jM`1gM780OW]i07IhMP1gNGL0NWUh07mnO@1dNG/0LgQj07b1P`1fNgd0OX1n0863P@1oQH80MW=c
07=bK`1WIV<207]jM`0307AcL01lNgP0oooo01h0oooo03L0[Jf]0:ZZZP2][Jd0aLG50;>c/`2a/K40
ZZZZ0;Fe]@2c/k<0YZJV0:ZZZP2][Jd0`l?30;Vi^@2_[jl0_Kfm0;>c/`2e]KD0_kno0;fm_@2ZZZX0
]kNg0;Fe]@2g]kL0/k>c0:n_[`2c/k<0^k^k0;Fe]@2k^k/0[jn_0;no_`33`l<0/k>c0;fm_@3=cLd0
_kno0:JVYP31`L40alO70<W9b@2m_Kd0`l?30:n_[`2ZZZX0]kNg0<W9b@33`l<0Z:RX0:ZZZP2e]KD0
[jn_0:f][@2JVYX0bl_;0080`L7100D0^KVi0<?3``2i^KT0dM7A0<71`@020;>c/`060;6a/@2JVYX0
aLG50:n_[`2[Zj/0Z:RX0P2e]KD02`2g]kL0alO70;Fe]@2g]kL0[Jf]0;Ng]`2o_kl0^KVi0;^k^`2o
_kl0/K6a0080aLG501@0`L710<?3``33`l<0]kNg0<71`@2o_kl0^k^k0:n_[`2e]KD0Z:RX09jNWP2[
Zj/0ZZZZ0=?Cd`2g]kL0bLW90;>c/`33`l<0bl_;0;>c/aT0oooo000G0?ooo`1E079`LP1`Lg<0LWA`
07iiM`1eNG@0M7Id071bL01fN7H0MGMe06idL`1gNGL0LW5`07ekM`1hNGX0LgAe07YlNP1eMgD0MW=c
07]jN@1eMgD0L7=c07MjN01fLg<0MGMe07IiM`1cMG40MG]f07UfMP1oOW/0NG]i07=eL`1kN7H0MG9`
07mmO`1jNg`0PWam06i`KP1lOgl0O7Ug07mjN020Ogh0OGai07akN01cL6h0L6e[081mO@1gM7@0OGQf
06mbL01fMG80Lg9_079`K01bLFh0J6][07anO01lOWX0LG=_07QjMP1hN7<0Q8Ao07IfL@1lO7L0MGAc
07AgM@1XJVP0NgQh07imNP1aKg<0Kfi]07UfM01fLFh0MgUe07mnN`1fLg40MG=_079aKP1gMW<0NgYg
07YhM01hMW80NgYg07AcL01nNgT0Lg1^07akN00207ejN00A07IcL@1lNgP0NgYg07UhM@1cLVl0MWEb
06m]K`1ZK6P0LG=_071bKP25Qh<0Mg]f0822OP1eMg<0OGai085nO01eM7407`3oool05P2g]kL0[jn_
0;^k^`2c/k<0Y:BT0;^k^`35aLD0]kNg0;6a/@2k^k/0/k>c0;no_`3?cll0bl_;0<?3``2m_Kd0Zj^[
0;Ng]`2a/K40aLG50;Fe]@2XZ:P20;>c/`0B0;Ng]`2c/k<0^k^k0;^k^`2i^KT0`L710;6a/@2m_Kd0
ZZZZ0:f][@35aLD0[Jf]0<?3``2k^k/0cLg=0<G5a@2_[jl0]KFe0P2][Jd02P2m_Kd0f][J0<O7a`39
bLT0Z:RX0:n_[`2o_kl0Z:RX09JFUP2BTY820;Ng]`0;0<?3``2JVYX0`L710:f][@35aLD0WYjN0;Vi
^@2e]KD0]kNg0:ZZZP2][Jd00P2o_kl0702FUYH0^KVi0;>c/`2g]kL0^k^k0:f][@2XZ:P0[jn_0;Vi
^@2e]KD0`l?30=SHf037alL0bLW90;^k^`2g]kL0_Kfm09bLW02c/k<0aLG50;fm_@3Lg=`0XZ:R0;Fe
]@2i^KT0[jn_0;no_`2a/K430;Ng]`050<O7a`39bLT0_kno0;fm_@35aLD06@3oool001L0oooo0600
MgIe07=cKP1iLg@0MGAc06e`KP1iMW@0OWej07MiM@1dNWD0NGaj07YdM@1kMGH0Pgen085kO01mMgP0
NW]l075gMP1gNGD0M7Ib07YiN01fMG@0Kg5]07EdL@1gNGL0NG]i07EdL`1iN7L0NGAb07AaK`1lNgX0
M7Me07YoP@1bMW40P7ek07ioP01bM700NG]g07f0OP22QH<0OX1l07=eL@1bLFh0O7]j079iN01jNW<0
Oh5l07alM`20NWD0KfaZ07]iM@1_KFT0O7Yf06ITH01THUh0MgIc07ejN01jMgD0J6ES079_K@1nOWT0
NWYe06YZI@1fN7H0Mg5b071^IP1oOW/0LW9]07]eL01VIF80L7Ie07QgMP1gMGL0NGQg079bK@1cLVl0
Lg5]07QfLP1fM700OGQe07ekM`1oPGl0P8:007UmN01gMW<0NWEc06U[I`1eNgP0NWUh07YkOP2:S980
K6m]07IiM`1TIV@0LgEc07]jM`1dLg0307MfL`0507mnN`20PWh0Ngei07YlN01nP7`07`3oool01P2[
Zj/0ZZZZ0:ZZZP2c/k<0/K6a0;Fe]@80]kNg00@0_Kfm0<71`@2a/K40_Kfm0P2c/k<00`2g]kL0]KFe
0:n_[`020;Ng]`0H0<O7a`2a/K40YZJV0;Ng]`2a/K40^KVi0;Ng]`2k^k/0ZZZZ0;Vi^@2e]KD0/k>c
0::RXP2i^KT0VYZJ0:BTY02[Zj/0SXj>0:n_[`2XZ:P0alO70=?Cd`37alL0^k^k0P39bLT02@2LW9`0
WYjN0;Vi^@2][Jd0`l?309JFUP2[Zj/0/K6a0:ZZZP020;Fe]@0A0;>c/`2][Jd0/K6a0;>c/`2e]KD0
ZZZZ0;no_`2_[jl0aLG50;fm_@2k^k/0_Kfm0:BTY02PX:00_kno0;Fe]@31`L400P2g]kL04P2m_Kd0
]kNg0;fm_@2k^k/0`l?30;Vi^@2o_kl0]KFe0;Vi^@2o_kl0`L710<G5a@2k^k/0^KVi0;>c/`2k^k/0
/K6a0;Ng]`80`l?300X0_Kfm0;^k^`2m_Kd0^k^k0;no_`31`L40]kNg0;no_`2a/K40_Kfm6@3oool0
01L0oooo00`0LGAb071_KP1`Lg40MGAc07AaL@1fN7@0Mgel07MjNP1jN7X0O7]j07MdM01jMgL207Eb
LP0307MdM01fMgP0LgUh0080MgAb0200NGQg07AcLP1^KFX0MgAb07QeM@1jMgL0MgIe07UhM`1`JfT0
MG9`07IeM01eN7H0K6i/06QcM01VJFL0KFmZ075cK`1cMG40NWEb06mZI`1oOW/0QHB107UhM@1jNGP0
P7ml0823N`1ZK6P0NGQe07QiNP1bKfl0IVQV075cL@80M7Id03<0L79`07IeLP1eLW00MW=a079_K@1e
MWL0MWUg079eL`1`Lg40LgEa07ilP01jO7P0LgIf07UiM01]L700Jfi/07AfL@1kMW<0O7Md07MbL01g
LG@0LW5^07MeL@1jN7@0NGMc07IaKP1mNgL0NgUe07IdL01hMG<0MGAa07anNP1nP7`0NGIf07eoO@1e
Mg<0NGAa07AdK`1gMg80KFm]07eoO@1jNGH0NGQe07YeL`1iM780NgYg07akN01gNGD0Ngei07AfLP1j
O7P07`3oool20;Vi^@0^0:ZZZP2<S8`0`L710;>c/`2a/K40^KVi0;fm_@2c/k<0]KFe0:^[Z`2e]KD0
[Jf]0;^k^`35aLD0`l?30;Ng]`2i^KT0/k>c0::RXP2[Zj/0]kNg0:f][@2c/k<0^k^k0:ZZZP2e]KD0
/k>c0;Vi^@2o_kl0clo?0;fm_@2i^KT0aLG509BDU02e]KD0`L710;6a/@2e]KD0YZJV0:ZZZP2i^KT0
_Kfm0;Fe]@33`l<0/k>c0;^k^`80_Kfm00<0[Jf]0:^[Z`2LW9`00P2XZ:P01`2k^k/0ZZZZ0;Ng]`20
P800Zj^[0<G5a@2m_Kd00P31`L40402m_Kd0ZZZZ0;Vi^@31`L40[jn_08R8R02o_kl0]KFe0;Vi^@2o
_kl0X:2P0;6a/@2m_Kd0^KVi0;fm_@33`l<20<_;b`0G0;Ng]`2o_kl0clo?0;Vi^@2_[jl0/K6a0<?3
``31`L40/k>c0;^k^`2][Jd0alO709jNWP33`l<0ZZZZ0;no_`2i^KT0_Kfm0:f][@35aLD0`L710;^k
^`2e]KD06@3oool001L0oooo0440N79c07QjN01`NGD0HFAR07aiN@1eMgD0M7Id07QjN01jO7X0MG]f
06ecL01aLg40MW=c079dLP1iNgT0OWUd07ehL`1gMW<0N7Md07UoO01/Kfd0LG=_07MiM@1eM740MgIc
07UlNP1`MW<0MW1a06a_K@1hMg@0NgYg08>5P@1hMGL0QhV507j4P`1UJfH0O7Ed06m]J@1dMGH0MWai
06iaK`1hNWH0OGai07YeLP1fLFh0MGMe07EdL@1iLW40NWMe079dK`1aLg40KG5/06U_JP1_MG00NGId
071_K01^KFX0MgIc075dLP1nO7P0Lg5]07YhM01lNWH0NWMe071_K00207QjMP0U07=bK`1OGU/0NGQe
07]jN@1hMg@0NgYg06]ZI`1dLg00NWYe07QhL`1jNWD0OW]i07f1O021P7d0MgIc07]iN`1bL780N7=a
07=^K01dMW@0LgEa07aiN@1eKg00NGQe079aKP1mNWX0JW1]07f1O01`LVh0NgQf07QeL`1jMgD0LWQc
07imNP1lNgP0NGQe07IeLP0O0?ooo`0i0<71`@2][Jd0[Jf]0;Vi^@2k^k/0dm?C0<71`@2][Jd0Z:RX
0;Fe]@2_[jl0]KFe0;Ng]`2XZ:P0^k^k0;Ng]`2c/k<0`l?30;Ng]`2k^k/0_Kfm0;^k^`2c/k<0]KFe
0:n_[`2ZZZX0X:2P0;fm_@31`L40/K6a0;>c/`2LW9`0Z:RX0:f][@2TY:@0SXj>08:2PP2NWYh0MgMg
092@T02][Jd0^KVi0<O7a`3;bl/0]kNg0;>c/`2_[jl0VYZJ09RHV02c/k<0`L710:^[Z`35aLD0Z:RX
0:f][@2m_Kd0`L710080`l?301L0/K6a0;Vi^@31`L40aLG50<O7a`2m_Kd0`L710:n_[`2g]kL0/k>c
0:JVYP2i^KT0/K6a0;fm_@2a/K40YZJV0::RXP2VYZH0ZZZZ0;6a/@2k^k/0^KVi0:f][@020;Ng]`0E
0;no_`2m_Kd0W9bL0;^k^`3AdM40^k^k0<?3``16ATH0/k>c0;6a/@2i^KT0Z:RX0<O7a`2i^KT0aLG5
0;Vi^@39bLT0_kno0<G5a@37alL0]kNg01T0oooo000G0?ooo`0k07akN01bM780LVeZ07QfLP1iNG@0
QH:207aiM`1bLG00Kg1a07IgN01jNGP0MWQf07MjN01_MG80NGIf07MiM`1eMgD0OGYh07MeN@1oOW/0
NX1o07UmN01eMg<0Lg]g07EdL`1`LVh0Jg9c07YlNP1cM7L0M7Ia07E`K@1YHV00LWEe06U/KP1]L780
HVIP06YTG`1[IV<0EUQC06=PGP1bMgT0Ogik07YlN021P7d0MgUe07=gL@1aLfh0J6]Y06MYI@1lMG@0
LG=_07efM@1nOGX0KfYX07YgM@1lOWX0M75_07ehMP1dKfX00P1hLFl0501lMG<0Ogei07YnN@1lO7L0
KFMR07=^K01eLW00KVeZ07MiM@1hMG<0NWMi07AdK`1^L6h0K71[06i]JP1`Kf`0M7=`06U[IP1iMg<0
LW5^0P1gMW<05@1fMG80NWah06U[I`1iNgT0Ogim07UkMP1mN7<0?BhP07E`J`1kPGh0N7Yh06m^J`1o
OW/0N7Mf07imO01hMg@0P7ml07]nO01nOG`0Ogim07MfM@0O0?ooo`0B0:n_[`2m_Kd0]kNg0:^[Z`2X
Z:P0WYjN0<?3``2k^k/0WYjN09RHV02a/K40cLg=0:f][@2e]KD0/k>c0<?3``31`L40]kNg0P2i^KT0
102[Zj/0ZZZZ0:n_[`2][Jd20;>c/`0@09bLW02m_Kd0^KVi0<G5a@33`l<0^KVi0:n_[`2c/k<0YZJV
0<71`@3Lg=`0_Kfm0;no_`2[Zj/0_Kfm09jNWP80R8R803d0Y:BT0;^k^`2i^KT0ZZZZ0;Vi^@2a/K40
^k^k0;Fe]@3=cLd0Z:RX0;>c/`2TY:@0Zj^[0;^k^`2_[jl0`l?30;>c/`2e]KD0bLW90;Ng]`2XZ:P0
UYJF0;>c/`2g]kL0^KVi0:JVYP2c/k<0[jn_0;fm_@39bLT0_Kfm0;^k^`2g]kL0^k^k0:RXZ031`L40
^k^k0<o?c`2m_Kd0`l?30;Vi^@37alL0`l?30<W9b@33`l<0`L710;^k^`2c/k<0/K6a0:^[Z`2e]KD0
Zj^[0;Fe]@37alL0bLW90;6a/@2o_kl0PX:20;no_`2_[jl0alO701T0oooo000G0?ooo`1L07=`KP1j
N7@0MgUd075cK`1_LFl0JVMW07elN`1iN7L0JVUX06M]JP1VJ6@0PXB2079`M01fN7H0MGMe07enO`1l
O7D0MgIc07QgM01cMG<0LGIh071bL01cMG<0MGMe07j0O01eMGX0JFAQ07YiMP1kNWL0OWUf07ekO@1h
Ng<0MGIg06U_JP1^L6`0O7Yf07YhM01aKf/0NgUe075_J`1jN7@0Gf5O06MRG@1OHV00KG1^07QiNP1b
L780L7=c07QgMP1iN7L0MWEd07E`J`22OGP0KfeY06e_K@1aKV`0MG9`07UfM01mNgL0MFi/07YeLP1f
N7<0Mg]f06m`L@1VIfP0MGIg07EbL01hLG00KVeZ07MbL01eLfl0NWYe0820N`1jNWD0Jg=]07MiM@1i
NgL0Kg5]07]jN@1lNgX0Ph9o07YgM@1mNWP0MGAa07mlNP1mNWP0P7j007]iN`1lNgP0NGQe07EcK`1d
LVh207IeLP0:075cL@1fLg<0Ogik081oO01dLg80NgYg05aPF`1kOgX0Lfi/07mfMQl0oooo0P2g]kL0
302_[jl0[Jf]0:f][@2c/k<0bl_;0:n_[`31`L40/k>c0:ZZZP3bl_80XZ:R0:n_[`80`L7100D0/K6a
0:n_[`2[Zj/0ZZZZ0;^k^`020;6a/@080;^k^`35aLD0VYZJ0:2PX02_[jl0_kno0;^k^`2i^KT20;^k
^`040:n_[`2XZ:P0X:2P0;Fe]@80[Jf]0P2e]KD08`2LW9`0/K6a0<G5a@37alL0Zj^[0:JVYP2o_kl0
_Kfm05eMG@2XZ:P0/K6a09ZJVP2_[jl0clo?0;fm_@2g]kL0/K6a0;>c/`2g]kL0/k>c0;Fe]@2g]kL0
_Kfm0:^[Z`39bLT0]KFe0<?3``31`L40T92@0;^k^`2g]kL0_kno0;Fe]@2XZ:P0^k^k0080]kNg01D0
/K6a0<71`@2g]kL0^k^k0<O7a`31`L40/k>c0<G5a@33`l<0bLW90;Vi^@31`L40^KVi0;no_`33`l<0
]KFe0;fm_@2k^k/0^KVi0:BTY02g]kL00P2a/K40102][Jd0`L710;no_`2a/K4I0?ooo`005`3oool0
5@1gM780MgAd07=eL01bM700LWAb07EdL`21Q880LgId07aoO@1eM7<0NWMi09FFV@1/LgD0LgEc07an
O01lMWL0M7Id07=fMP1aM7@0N7Ee07UgN@0207AfM00@07j0OP1bM780J6YX06]]J@1cLVl0OWej07Uj
O@1hMgH0NGIh07=aK@1jMgD0Kg5]06]]J`1bM780OGmk079dL080MWQf00l0M7=`07elN@1nP7/0Oh5l
06i`K01JFEH0NgEf07YiMP1_KfX0M7A_06mbLP1XIf@0LfeV07YhM01gM7800P1dLFl04@1gNGL0MGAc
08N9Q`1fNGL0NWah075`K`20Ogh0Q8>207IcL@1lNGL0HfUT07IeLP1iMW@0NgIc07IaKP1_JVL0O7Me
0080MgUe01/0M7Ib07ehM@1lMg@0NGId07n3OP1lP7/0NWMe07ikN@1mNWP0P7mn07imO01lNgP0N7Md
07]mN`1mOgd0MgIc07YiMP1iMg40N71/06e/J@1gMW<0M7=b07AcL01bLFh0O7]h07]mN@1dLFl07`3o
ool02P2o_kl0^KVi0::RXP2e]KD0_Kfm0;>c/`2[Zj/0`l?30;Vi^@2m_Kd20;Fe]@0J0;no_`2][Jd0
_Kfm0:^[Z`2][Jd0T92@09jNWP2e]KD0/k>c0::RXP2o_kl0^k^k0;Ng]`2@T900g=cL0;^k^`2g]kL0
_kno0<?3``2o_kl0/k>c0;Ng]`2c/k<0[Jf]09RHV031`L420;fm_@0_0;no_`2_[jl0Z:RX0:f][@39
bLT0^KVi07=cL`2PX:00XZ:R0;Vi^@2k^k/0]kNg0:n_[`2NWYh0_Kfm0;^k^`2TY:@0bl_;09ZJVP2[
Zj/0eMGE0;fm_@2k^k/0Y:BT0;Fe]@2g]kL0ZZZZ0<71`@2c/k<0WYjN0<71`@2c/k<0alO70<71`@2i
^KT0`l?30<o?c`2k^k/0/k>c0;no_`2k^k/0]kNg0<O7a`2m_Kd0Y:BT0;fm_@37alL00P2k^k/04033
`l<0alO70;fm_@35aLD0^KVi0;>c/`31`L40[Jf]0;no_`37alL0_Kfm0820P02e]KD0_Kfm0<71`@2m
_KdI0?ooo`005`3oool0J01kOG/0N7]k06a_K`1fNGT0NWem07EcM@1aLfl0OGmk07QjMP1jO7X0Ogal
07IgNP1kM780LWYc07YiMP1aMg80LWQc06=VI01ZK6X0Ngek07EcM@1/Kfd0NgQh07MiM`1`Lg40Hf9Q
08Z8Q01iN7L0MGMe07]jN@1mO7/0NgQf07MiM@1fN7H0MGMe079dLP1lOW`0L7=a07YiN01jNGH0NgYg
06meLP1kOG/0LW5^0822P01DDe00NGId06]^K01/Kfd0NGId07MdLP1`Kf`0Lg9_06YYIP1iN7D0KFYX
07YgM@21OW`0LG1]08J3P@1fLFl0NWEc06e_K@1fNWD0MgUe06a[J01`MW40MGAa06YYIP1eM740O7Ug
07mlNP1lNgP0N7Yf07QhL`23PGd0NGUd07EgLP1iN7L0NgYi07MiM@1oPGd0NWEb06iWI@1jN7@0Ogei
07UhM@1nP7`0OGmm07n1O`1jMgD0OWej07]mN@1eMg<0O7]h079aKP1kNWL0Ogik07YiMP1KFUL0MWEb
07YiMP1lNgP0NWUf7`3oool0J@2_[jl0ZZZZ0:BTY02c/k<0[jn_0:^[Z`2k^k/0^KVi0;6a/@2<S8`0
`L710;fm_@2e]KD0`l?30:RXZ02m_Kd0/K6a0;no_`2a/K40Z:RX0:n_[`2k^k/0`L710<_;b`2_[jl0
ZZZZ0::RXP33`l<0^k^k0;Ng]`2BTY80XZ:R0;Ng]`2[Zj/0aLG50<_;b`2DU9@0YZJV0;>c/`2e]KD0
`l?30<W9b@2e]KD0alO70;Fe]@2_[jl0OGem0;Ng]`2o_kl0Zj^[0;6a/@2g]kL0/K6a0;Fe]@33`l<0
_kno0<W9b@2i^KT0YZJV0=7Ad@2c/k<0cLg=0<?3``2m_Kd0alO70<W9b@35aLD0bLW90;Fe]@2ZZZX0
^k^k0;Ng]`3?cll0]KFe0;>c/`2a/K40]KFe0;Ng]`2m_Kd0`L710;Fe]@2k^k/0aLG50;^k^`37alL0
YZJV0<G5a@33`l<0/k>c0;Ng]`2c/k<0Zj^[09:BTP2[Zj/0]KFe0;no_`39bLT0Zj^[08j>SP2PX:00
_kno0<?3``2[Zj/0]KFe0;Ng]`0I0?ooo`005`3oool06@1gNWP0NWUf06m^J`1aL6d0JVUV079aL01a
Mg@0M7Yg075gM01eLW@0N7eo07EhN01fN7H0LgEc07AfM01gMWD0NgYi079dLP1dMW@0MWEd07MfM@1e
MgD0MWQf081oO01`LG@00P1eM7<0?`1dMW80MGMc07QeM`1YK6`0Kg5_07j0OP1iNgT0LgEc08>7PP1h
MG<0Kg9`079aL01fMW40Ng]f06i_L01^KF`0LWAb05iMG00m>3D0NGIf07elN@25Q840N7I`079`K01Y
JfL0NWah075cK`1/KV`0K6e`07AeMP1bM780Mg]f06mbLP1iN7D0K6YR07elN@21P7d0P7ml07UhM@1k
NWL0OgYg07E`K@1lMg@0NgYi08:6P@1gNGD0NGQe07elN`1lNWH0O7Md07UbL01gMW<0LgEa07ikN`1n
OG`0KW5_07QgMP27PX00Jfe[07]kMP1gMg80OGYh07elN@02085nO00<075cK`1cMG40KFaY079aKP1d
LFl0O7Ed07=bL@1fMG@0NGId07QeL`20NgT0NgQf7`3oool0503=cLd0/K6a0;Fe]@2][Jd0Zj^[0;Vi
^@2m_Kd0aLG50;>c/`2i^KT0^k^k0<?3``2e]KD0[jn_0;^k^`2c/k<0_Kfm0;>c/`2][Jd0YZJV0P2g
]kL20;6a/@030;no_`2g]kL0Z:RX00<0^k^k00l0Zj^[0<W9b@2g]kL0/k>c0=?Cd`3Lg=`0aLG50;>c
/`2FUYH0Z:RX0:JVYP2[Zj/0U9BD0:n_[`2ZZZX00P35aLD03P2NWYh0alO70;>c/`2XZ:P0]kNg0::R
XP1kNg/0S8b<0:^[Z`37alL0ZZZZ0:JVYP2o_kl0alO70P33`l<02`2a/K40_kno0<W9b@2][Jd0^k^k
0;Vi^@2][Jd0aLG50;fm_@2e]KD0Y:BT00<0]kNg00H0/K6a0:BTY02g]kL0^k^k0:n_[`2m_Kd20<O7
a`0D0:RXZ02VYZH0]kNg0<W9b@33`l<0clo?0;no_`3Cdm<0dM7A0:ZZZP2o_kl0`L710;6a/@2_[jl0
Zj^[0;^k^`2a/K40/k>c0<?3``2g]kLI0?ooo`005`3oool0J022P880M7Id07IiM`1bM780LG1_07Qe
L`1jO7P0OWn007EeNP1hNWP0M7=b07elN`1fMG@0LgEc07UjO@1eM7<0NWUh07EbLP1bM780L7Ic07Mm
NP1gNgD0M7Mg07]jM`1]K6T0MgIc06m^J`1iM780Lg1^07UkM`1aLfl0P7em07EgM@1gM7@0QGmh08Z5
PP1eMWL0Ogik06ISI@1_KV/0KW1^06EXIP1]L6P0Lg5]071_K01nP7`0NWah06YZI@1oOgX0KfeW07Me
L@1_LF`0K6iY05QJE@1aK6T0Ogik079aKP1`Kf`0NgYg07mnO@1kN7P0OGMh07AcL01kMW@0P7ml07Um
N01bMW40N7Md079aKP1kNWL0OWej07IfL@1]KFP0MgMb07YgM@1gL6h0M79^06e_JP1fM700MgEa07=e
L@1jN7@0OgIf08N4PP1_LF`0KW1[07MeL@1lO7L0OGYh08>0OP1kMW40QGmj07ifM01`KVH0Ngek07b4
P01dLW@0Lfi/075YI`1iM740M7=`07EdL@1mN7H0Mg9`7`3oool00`2m_Kd0]kNg0;>c/`020:JVYP03
0<g=c@2e]KD0]KFe0080[jn_00<0`l?30:f][@2VYZH00P2g]kL05P2c/k<0`L710:n_[`2m_Kd0alO7
0;no_`2g]kL0`L710;6a/@2_[jl0/k>c0<?3``2k^k/0aLG50<?3``2_[jl0`l?30<g=c@37alL0dM7A
0<?3``2e]KD20:^[Z`080:n_[`3;bl/0WYjN0:ZZZP2@T900]kNg0:JVYP2][Jd20;6a/@0P0:f][@26
QXH0Zj^[0;6a/@2TY:@0[jn_0;Fe]@31`L40/K6a0>3Ph02m_Kd0]kNg0<71`@2m_Kd0_kno0<?3``2o
_kl0Z:RX0;fm_@2_[jl0Zj^[0<71`@2a/K40^k^k0;Ng]`2TY:@0`L710<W9b@31`L40Zj^[0<W9b@2m
_Kd20<71`@0F0:ZZZP31`L40^k^k0<?3``2m_Kd0/K6a0;^k^`33`l<0[jn_0<W9b@35aLD0XZ:R0:n_
[`31`L40]KFe0;>c/`2VYZH0`l?30;no_`2i^KT0`L710;fm_AT0oooo000G0?ooo`0_07YnN@1gNGL0
MGQf06i`KP1^KF`0PWmm07IkOP1fO7/0LgUf07=eL`1]L6h0LWEc06iaK`1gM7@0MgAb07EhMP1lOgd0
Lg9a07YlNP1iNgT0Ngek07MeN@1lNgX0LgIf071cL`1eM740OGai07UdLP1kN7H0OGQf07=gLP1mNWX0
Oh5o07akNP24Ph00OH>8075bL`1fMG@0LFm[07=^J@21Og/0L71[07^0Q@1SHEd0MgIc079dL01gNGD0
0P1dMgD07`1NH5`0LG9c07akNP1dLg80KFa[07IeM01lNgP0NWUf07AcL01jNGH0MgM`07ajM01lMg80
NgYg07ejN01kNWL0NG]g06mcKP1cLVl0LG1]07UhM@1lNgP0NGAa07MbK`1]J6D0NgQf081kN01lNWH0
LG5/07]hN020OGd00P1lMgD05P1`KF/0N7Md07UkMP1mOgX0NWaj08:5P`1iNgL0OGmk07=eL`20NgH0
O7]h06a_I`1cMG00O7Md07IiN@1eM740KVQY07ejNP1kN7H0N7Ec07aiN`1jMgTO0?ooo`1D0;Vi^@2]
[Jd0^k^k0;6a/@2e]KD0_Kfm0;Vi^@2a/K40]KFe0:ZZZP2i^KT0^k^k0:f][@2g]kL0Zj^[0;Fe]@39
bLT0^k^k0;fm_@2g]kL0_kno0<?3``2_[jl0W9bL0;no_`2c/k<0WYjN0<71`@2i^KT0]kNg0;Vi^@2e
]KD0^KVi09bLW02RXZ80X:2P0:^[Z`2c/k<0f=SH0;Fe]@2c/k<0WYjN0;Fe]@2_[jl0`l?30:RXZ02k
^k/0`L710;^k^`2JVYX0/K6a0=[JfP2k^k/0Z:RX0;Fe]@2c/k<0^KVi0:ZZZP33`l<0/k>c0:f][@33
`l<0`L710;fm_@3;bl/0_Kfm0;Ng]`2i^KT0^k^k0:^[Z`3Ph>00Zj^[0<G5a@3=cLd0/k>c0;fm_@2c
/k<0]KFe0:n_[`2k^k/0aLG50;^k^`2TY:@0alO70P2m_Kd04`31`L40]kNg0<O7a`3=cLd0]KFe0:ZZ
ZP2m_Kd0[Jf]0<71`@37alL0]kNg08j>SP2][Jd0alO70:BTY02ZZZX0Y:BT0;Vi^@2k^k/06@3oool0
01L0oooo06P0N7Ih079dLP1iOGP0M7Qc07IjM@1jN7X0N7Mf07AfM01fN7H0L6m/07EdL@1iN7D0LW5^
07MmNP1aMg@0MWEd081oOP1iMW@0NWUf07]mN`1kOGT0OGmm07=eL`1kNG<0MgYb07EgM@1ZK6X0O7Ig
08>0P01gMW<0N7Md07IgN01YJfT0MgIe06a^K01[IV40MG=_07QhK`28QhH0MWYe07EbL01fLg40HeaJ
07=eL@1mOg/0NGQg06a_K@1lNW`0NG]i07AgM`29R8D0KVUW07UhM@1_Lfh0MGAa07QlM`1oNWP0L79^
07EdL@1bLFh0MWEb07elN@1jNGH0PH1m07YiMP1YJ6D0MgAb07UiM01aKf/0NgIc08b;R01nNgT0PWmm
07EbL01kN7H0MGUd07IjM@1cMg80JFIT07UfM01iMg<0KF]W07mjN01cL6h0NWah07anNP1gLW00QH1n
08:1OP1fMG80L6iZ07YhM01kNWL0O7]h07n3OP1gNgH0HV5P079aL01oPGd0KFm[071_K01]K6T0N7Md
07UhMAl0oooo00H0/K6a0:^[Z`2RXZ80WYjN0;Vi^@2a/K420;Fe]@0@0;6a/@2][Jd0/k>c0;>c/`2_
[jl0/k>c0;Vi^@2XZ:P0]kNg0;fm_@31`L40^k^k0;>c/`2XZ:P0^KVi0;no_`80`L7102/0V9RH0:^[
Z`2i^KT0_kno0<?3``2o_kl0Z:RX0;Ng]`2ZZZX0W9bL0:ZZZP2RXZ80]KFe0;6a/@2ZZZX0XZ:R0;6a
/@2o_kl0_Kfm0<?3``2_[jl0Zj^[0;^k^`3?cll0[jn_0<G5a@24Q8@0^KVi0<71`@37alL0^KVi0<G5
a@2i^KT0_kno0:n_[`2m_Kd0]kNg0=7Ad@2o_kl0aLG50;>c/`33`l<0dm?C0080/k>c00L0]KFe0;^k
^`2ZZZX0]kNg0<_;b`2FUYH0`l?300<0/k>c00l0clo?0:2PX02a/K40alO70;Fe]@2m_Kd0[Jf]0<G5
a@3=cLd0Y:BT0<G5a@37alL0bLW90;Vi^@35aLD00P2k^k/01@2c/k<0alO70;fm_@2c/k<0_Kfm0080
alO76@3oool001L0oooo00/0N7]i07MeN@1eM7<0O7]j07QgMP1YJ6D0Kg1a07UjN`1dMGH0N7Ec06ma
K`0207IhMP0_07UkN@1dMW@0KVm`07EfM`1iNgT0OGmm07IeM01dLWH0MWQd07IhMP1kOG/0OGmm07ao
P@1[K6d0MW=a079fL@1/L6/0NWMe07=bL@1mO7/0NWUh07]jN@1YJ6D0KFaY079_K@1dLFl0MGIg07]j
N@1^KFX0MGAa06i/J01iMg<0O7]h07=gLP1_JVP0MW=a07UkMP1bLVd0LVm]07EbL01dLFl0NgIc07Md
LP1jMgD0NGId07ejNP1jMgD00P1kN7H0:P1BE500OWii06e/J@1mO7/0O7ij07=bK`1bLFh0NGQe07el
N@1hMW80PH1m075cL@1fMG80N7Md07YiMP1oOW/0PX5n07YlN01jNGP0OGak07IcL`20OWX0NgYg07mn
N`1lNGL0NGId079_K@1^JfT0MgMb07YiN01oOW/0PH1m07eoN`1^L6`0Kfi[07MbL01hMG<0M75_07Yg
M@21OW`0Ph9o07ejN1l0oooo00/0^KVi0;Ng]`2c/k<0`L710;Vi^@2LW9`0Z:RX0;^k^`2a/K40^KVi
0<?3``020;Fe]@080;^k^`2a/K40YZJV0;>c/`2k^k/0`l?30;Vi^@2a/K420;Fe]@0C0;^k^`2o_kl0
`L710:2PX02e]KD0Zj^[0::RXP2m_Kd0[jn_0;Vi^@33`l<0_kno09bLW02][Jd0Y:BT0;6a/@2c/k<0
_kno09BDU0020:JVYP0W0;^k^`2g]kL0`L710:RXZ02e]KD0/k>c0;^k^`2][Jd0/k>c0;6a/@37alL0
_kno0;Ng]`2k^k/0^KVi0<?3``2m_Kd0_kno0<?3``1_Kfl0aLG50:BTY031`L40clo?0:n_[`2][Jd0
`l?309BDU02i^KT0bl_;0:^[Z`2g]kL0^KVi0;fm_@37alL0_Kfm0;>c/`2m_Kd0`l?30080]KFe01@0
_kno0<O7a`31`L40_Kfm0:f][@2VYZH0]kNg0;fm_@39bLT0bl_;0<?3``2VYZH0Z:RX0;Ng]`2i^KT0
/K6a0;fm_@3;bl/0clo?0<?3`aT0oooo000G0?ooo`0M075dMP1fN7H0M7A_06meLP1dMGP0N7Ee07Mf
M@1iN7L0M7=b06YYIP1aLg40M7Id07UkN@1dMW@0NWaj06U[J@1hNWP0IVMX081iM`1eL6h0OGQf081m
O`1lMWL0NGId07EdL`1eM740IFEP07inN@1cLW400P1mO7/0>`1/LVl0OGYj06m]K`1kNWT0OW]m07mj
N01eLfl0NgUe07EiL`1hN7<0LF]T07MeL@1/KVX0KW1/075[K01/IVL0KfeY07AbKP1iNG@0Lg=^07ak
N01eM740K6]X07]eMP1kOGT0MgUe07YlN01nP7`0NWii08F4P@20NgT0NgUk07]mN@1oPGd0MWQd079e
M`1aMg80L7Ia07MmN01kN7H0QX5o07YiMP1cMg80Lg5]06aYI`1cL6h0L6e[089kNP1jNGH0NgYg07Ia
K`20Og`0MWEb07UhM@1oOW/0O7ag07IeM020Og`0N7Yf0080MW5^0P1kN7H02P1cL6h0MW=a07akN01h
Mg@0MWQc08B1P@1cLF/0OW]m07IcL@20OG/O0?ooo`80Zj^[00D0^k^k0:BTY02k^k/0^k^k0;fm_@02
0:BTY0050;fm_@2ZZZX0^k^k0;>c/`2e]KD00P2a/K40=02g]kL0`l?30;Vi^@2g]kL0_Kfm0;Vi^@2_
[jl0_Kfm0;Ng]`2e]KD0U9BD0:ZZZP2o_kl0/K6a0;Ng]`2c/k<0_kno0<71`@2NWYh0^k^k0:n_[`2e
]KD0aLG50;Fe]@31`L40`l?30:2PX02ZZZX0dM7A0;6a/@31`L40/k>c0;^k^`3EeMD0]kNg0;>c/`2g
]kL0X:2P0;6a/@2m_Kd0[Jf]0;^k^`3AdM40alO70=?Cd`2][Jd0Zj^[0:BTY03;bl/0Zj^[0<G5a@2m
_Kd20;>c/`0>0:f][@2FUYH0/k>c0;fm_@2XZ:P0]KFe0;^k^`2ZZZX0XZ:R0;Ng]`2][Jd0`l?309bL
W033`l<20;fm_@0C0;6a/@2o_kl0^k^k0;Vi^@2k^k/0_Kfm0<71`@3;bl/0`l?30<G5a@37alL0ZZZZ
0;^k^`2o_kl0/K6a0<W9b@2e]KD0_kno0=?Cd`0I0?ooo`005`3oool01`1aKV`0LG=a07UgN`1]Lg00
NG]g07UkN@1jNGP00P1]K6/01@1jMgD0Kg5_07UkN@1eMgD0MWQf0080M7Id03<0MgUg07eoN`1hOh00
NGId07YgM@1hNg/0LgEc07MiM@1hNgT0MW=e06E[J01`L6/0NGQg07AcLP1gMWD0MG9b07aoO@1fMG@0
JVUX07UgN@1fLFl0P8:007j0OP1fL740O7]j06]^L01`LW00L6e[08B1O`1lNWH0JfUU07EcK`1iMg<0
Mg9_07E`K@1oOW/0MgIc06]ZI`1jNGH0LWA`055CC`1iNgL0Ogaj08F7P`1hMg@0LVm]06e/J@21OW`0
LFi/07mlNP1nPH400P1eM7408`1mO7T0LVm]07EiM01jNGH0KfaZ075_J`1iMW@0L6e[06aYI`1]Kf/0
MgAb07elN@1YJfL0OGQf075/JP1jNGH0M7=`07]kMP1iN7L0N7Md07UkM`1jMG80O7Md07MdLP1mNWP0
OW]i07mlNP1`Kf`0NGQe07]iM@1dNWL0P7eo07IdL01kOGT0QHN301l0oooo00D0^KVi0:BTY02e]KD0
]KFe0;Ng]`020:n_[`80ZZZZ0180`L710<G5a@2o_kl0^k^k0:RXZ02g]kL0YZJV0;Fe]@2ZZZX0/K6a
0;Vi^@2g]kL0_Kfm0<W9b@33`l<0]kNg0;Fe]@2a/K420;fm_@040:^[Z`2k^k/0]KFe0:f][@80]kNg
04H0XZ:R09jNWP2][Jd0/k>c0:n_[`33`l<0PX:20<?3``2g]kL0YZJV0;>c/`2a/K40^k^k0:RXZ02i
^KT0]KFe0;fm_@2LW9`0YZJV0<G5a@2_[jl0]kNg0=GEe@3;bl/0`l?30;Fe]@2c/k<0ZZZZ0;Vi^@2X
Z:P0`L710;>c/`2a/K40aLG50;Fe]@35aLD0^k^k0<?3``2i^KT0Z:RX0;^k^`2e]KD0Zj^[0;no_`2m
_Kd0alO70;no_`33`l<0]KFe09RHV033`l<0alO70<g=c@2i^KT0]KFe0;no_`2m_Kd0]kNg0<G5a@2R
XZ80bl_;0<G5a@2a/K40bLW90<G5a@3=cLd0/k>c0;Fe]@31`L40_Kfm6@3oool001L0oooo00L0N7Md
06eaK01fN7H0MWQf07MiM`1cLFd0Lg9_0080L6m/05l0O7]h07IeLP1kNWL0NGQe06maK`1gNGL0KWA_
07IlN`1`MGL0M7Mi07]jN@1gMWD0NWQb081nN01gMW<0NGQe07IeM01dLg00NWUf071_K01aLfl0NG]g
07IgN01gNGD0K7A^07MkMP1/JfP0LWA`075cL@1eMgD0Lg1`07elN`1mN7<0NGMa07MfL`1^KFX0M75_
079_K@1iMW@0Kg=^07IaKP1jN7@0MgMb06U[IP1^L6/0LgMa07MiO@1hNGX0QXR307elN@1fLF`0MWA`
07EdL@1hMG<0KfaZ07aiM`28QH<0MG=e07imNP1fMG80NGQe07ikN@1mNgL0N7Ib06m]J@1jNGH0MWag
075gLP1kPG`0OGYh07YgM@1kNWT0OGeh07IeLP1kNWL0OGmm07moNP22Ogl0OW]i07IeLP1kNWL0NWUf
07MfL`1jO7P0K6iZ0860O@1nOGX0M7=`081oO01nOWL0PWYf07EdL@1fMG80O7ij07YlN00O0?ooo`0A
0;Ng]`2NWYh0^KVi0;Ng]`2ZZZX0_Kfm0:JVYP2a/K40_kno0;fm_@2k^k/0_Kfm0:f][@2[Zj/0]kNg
0;>c/`2a/K400P2k^k/02P2c/k<0`L710:ZZZP2k^k/0P8200;6a/@2_[jl0Y:BT0:n_[`2o_kl20;>c
/`0H0;Ng]`2a/K40^k^k0:n_[`2m_Kd0]kNg0;^k^`2][Jd0]KFe0;^k^`2PX:00/k>c0:JVYP2[Zj/0
W9bL0;Ng]`2BTY80[Jf]0;Ng]`2a/K40YZJV0<?3``2HV9P0DU9B0P2c/k<0;01cLg<0^KVi0;no_`2a
/K40^KVi0:ZZZP31`L40/k>c0:2PX02a/K40YZJV0<71`@2i^KT0Z:RX0:n_[`2k^k/0]kNg0<?3``3;
bl/0eMGE0;Ng]`31`L40clo?0<O7a`33`l<0`L710=SHf02HV9P0`l?30<W9b@2m_Kd0/k>c0;no_`2Z
ZZX0`l?30;no_`2g]kL0f][J0;fm_@2BTY80/K6a0;Fe]@2VYZH0U9BD0P2[Zj/00`2i^KT0`l?30?oo
o`0H0?ooo`005`3oool04@1gMW<0JVaZ07QjMP1gNGD0L79^07YiMP1^LVd0M7=`07]hMP1jMgL0MgIe
07YiN01bLG00LG=a07MfM@1eM740M7Ib0080NGQe00X0O7]h07anO01`MW<0NG]i07AfLP1fN7@0LgEa
06e/J@1cLVl0NgYg0P1eMgD0B@1gNWP0NGMc07UmN01cMg80NWUf07UhM@1gMW<0LWA`07IhM01iN7D0
MFi]06URH01^KFX0LG1]07MdLP1lNgP0I6=P079_K@1dN7<0KW1[07YeLP1mOGP0IfUU07EdL@1eMgD0
I6=P05A?C01kNWL0M79^07emN01hN7<0O7ij07EgM@1[KF/0PH>107AbKP1lNGL0N7Ec07IcL@1_KV/0
NGUd07MeL@1mNgL0N7Ib08IoOP1gLW00O7Ug07AhLP23OW/0OGQf07agM@28QX80NWQd07emN020P7/0
NWQd07mmN@1kNWL0L6m/07ekM`1kNGD0MWEd08V8Q`1jPGX0I6IQ07AaK`1fN7@0KViY06ETH`1aLfh0
LG1_07QjMP1mOg/07`3oool02@2c/k<0]kNg0:2PX02][Jd0Z:RX0;Ng]`2a/K40[jn_0;6a/@020;fm
_@0H0<G5a@2i^KT0Zj^[0;>c/`2[Zj/0[jn_0;Vi^@2a/K40_kno0:BTY02i^KT0dM7A0:n_[`2c/k<0
[jn_0;6a/@2g]kL0`l?30;Vi^@31`L40/K6a0<?3``2c/k<0aLG50P2a/K406P2m_Kd0[jn_0;6a/@2_
[jl0^KVi0<?3``31`L40X:2P0;fm_@39bLT0Z:RX0;Ng]`2a/K40^k^k0;Vi^@2NWYh0^KVi0;Ng]`2m
_Kd0f=SH0:f][@33`l<0]KFe0<?3``31`L40bl_;0P2m_Kd0:02c/k<0]KFe0;Fe]@2o_kl0[Jf]0;Fe
]@31`L40[Jf]0;no_`2c/k<0aLG50:n_[`2i^KT0TY:B0<O7a`2m_Kd0^k^k0<W9b@37alL0/k>c0;Fe
]@2g]kL0bLW90;Ng]`2i^KT0_Kfm0;Ng]`2[Zj/0`L710:n_[`2o_kl0]kNg0<_;b`2m_Kd0^k^k0:f]
[@2m_Kd0]KFe0<W9b@2a/K4I0?ooo`005`3oool03`1bM780LG=^07MiM@1eMg<0P89n07UlNP1bNgL0
JW1]07]hN01hP7X0L7Ie079eM@1^Kg00JF]Y07AfM00207elN`0[079fL@1fN7@0LgIf07=fMP1iO7`0
MgQi08:1P01jNGP0M75_07QeL`1lNgX0MWEd07MfL`1kNWL0OGQf07EdL@1QH5d0OWej079_K`1gOg/0
Kg5]07IeLP1iM780M7=b07IhMP1XIfH0N7Yh07MiM`1VHfD0IUeM07AcLP1eM7<0NGId06i[J@1mNgL0
J6IR07=aK@1dLg00Lg=^079bK@1fMW40Ngek06i`K00207EgL`0B085lNP1bKfd0O7Ug07]hMP1fMG80
O7ii07QhL`1kM780NGMc07ilMP1kNG<0LFmY07EgL`1jN7@0MWA`08R6PP1mNgL0Lg5]0P1iMW@206iY
I`0D07QeL`1_JVP0N7Yf07mnN`21Oh40Q8>00860O@1lNgP0I6IR07MdM01kNWL0KVeZ07ajO01oOGl0
NWQl08N5R@2;QX@0OW]i07eoN`1fN7@O0?ooo`0[0:n_[`2g]kL0Zj^[0;Fe]@2_[jl0`L710:BTY02c
/k<0]kNg0;6a/@2_[jl0/k>c0:n_[`2k^k/0]kNg0;Fe]@31`L40/k>c0;Vi^@31`L40aLG50::RXP2]
[Jd0`l?30<71`@2[Zj/0/k>c0:f][@2_[jl0ZZZZ0;>c/`31`L40_Kfm0;^k^`33`l<0XZ:R0<71`@33
`l<0_Kfm0:ZZZP33`l<0cLg=0:f][@020:ZZZP060;Fe]@24Q8@0X:2P0:2PX02][Jd0_Kfm0P2i^KT0
2`2][Jd0VYZJ0:n_[`2k^k/0_kno0:ZZZP2e]KD0/K6a0<W9b@2a/K40clo?0080`l?30140/k>c0;^k
^`2o_kl0[Jf]0<G5a@2e]KD0ZZZZ0;Vi^@2m_Kd0/k>c09JFUP2][Jd0/k>c0;^k^`2i^KT0aLG50=?C
d`020;Ng]`040;fm_@31`L40_kno0;^k^`80aLG500h0`L710;Ng]`2m_Kd0X:2P0;fm_@3Ti>@0]KFe
0<71`@37alL0_Kfm0<g=c@1]KFd0ZZZZ0;^k^aT0oooo000G0?ooo`0[07=eL`1gN7/0LG=_07IhM01c
MG40O7il06eZJP1eM7<0MgIe07AjN@1fMgP0MGQh07=fMP1iNgT0MgUg07IiM`1lOgd0MGUd07QjMP1k
NWL0OWej06a_K`1bLg@0O7ag07AdK`1aKV`0MG9`079aL01hMgH0L6m/07EdL@1lNgP0NGeh07MeM`1m
Ngd0K79_07eoO@1`LVh0NWUf071_KP1mN7H0LW1/06]VH`02071bK@0B05eOFP1]JVX0JfYY06]ZJ@1j
O7P0N7Yf079`K01hMW80LW1/07=bK`1iNG@0MWIa07]kMP1fM6h0M75_07EbL020OG/0Ph9o0P1mOg/0
9`1hNWH0MGAa07]fL`1bL6`0K6iY07j0N`1`KF/0N7Ec07YgM@1nP7`0IVQV079dLP1eMgD0OGYh07Uf
M01nNgT0QH:007MdLP1iMW@0NWah07akN01kOGT0N7Md07inN@1nOWL0O7]h07MfL`1kO7l0JfUS07Yi
MP2>SHX0MWEb07akN01oNWP0NWEc089mNP1ACd/0L79^07UkM`0O0?ooo`0C0:ZZZP2[Zj/0/K6a0;^k
^`35aLD0]kNg0<71`@2g]kL0Z:RX0<71`@35aLD0[Jf]0:n_[`31`L40^KVi0;Fe]@2][Jd0alO70;>c
/`020;Fe]@1D0:f][@2ZZZX0]KFe0;^k^`2g]kL0]KFe0;Vi^@2k^k/0alO70:n_[`2e]KD0_Kfm0:ZZ
ZP2c/k<0[Jf]0<71`@2a/K40bLW90:2PX02c/k<0`l?30;no_`39bLT0/k>c0;no_`2HV9P0VYZJ0:RX
Z02][Jd0^KVi0;Ng]`2a/K40Y:BT0;Fe]@35aLD0alO70<G5a@2ZZZX0bl_;0;fm_@2k^k/0`L710;>c
/`2o_kl0]KFe0<_;b`2i^KT0_kno0;Vi^@2a/K40[jn_0:JVYP2[Zj/0dM7A0<G5a@3Rh^80dm?C0=GE
e@2a/K40[jn_0<O7a`3=cLd0[Jf]0;6a/@2c/k<0[Jf]0<O7a`31`L40aLG50;Vi^@2o_kl0/K6a0;no
_`39bLT0alO70:JVYP2c/k<0_kno0;6a/@3AdM40^k^k0;>c/`2o_kl0^k^k6@3oool001L0oooo05<0
L6m^075cL@1dLG40NGIf07ikN`1gNGD0O7mm07MjN01_LFl0O7Ig07UhM`1bM780LgEc07anNP1hNWH0
MWQf079dLP1oNGX0MG1^07YiMP1fMG80LWA`071bKP1iO7X0Kg9`07MjNP1fMG@0N7=a07IcL@1oO7X0
LgUd07IeLP1`Kf`0MWQf07EgM@1bLFh0M7=`07EgL`20OG/0JfeY07EdL@1kN7P0JVMU081oO01eM740
IfEO07MeK`1XJVH0Kg5]07QhL`1gMg80KfeY07AbKP1]JfL0OWUg07mnN`1eM740OWej0860O@1jNGH0
MGAa07UhM@1eLW00NgYg07IhM01gNGD0PHN607]fL`1hLg00OgYg07A_K01^K6P0LFm[08B2OP1/JfP0
SHR508F0O@26PGh0N7Md07AcL01oOW/0PWmm079_K@0207EdL@0C079aKP1oPGd0N7Yf07imNP1hMg@0
Ngei07AfLP1nP7/0P89m07mnN`1^KFX0MG1^07]hMP1dKF`0Q7el07UhM@1eM740Ngeh07UiL00O0?oo
o`80^KVi00T0Y:BT0:RXZ035aLD0ZZZZ0:n_[`2e]KD0/K6a0;no_`2_[jl00P2m_Kd01P2o_kl0^KVi
0;Vi^@2i^KT0^k^k0;6a/@80^k^k00`0ZZZZ0;no_`2ZZZX0^KVi0::RXP35aLD0/k>c0<G5a@2g]kL0
Zj^[0<71`@2NWYh20;Ng]`040;no_`31`L40^KVi0;>c/`80[Jf]0100`l?30;fm_@2i^KT0`l?30;fm
_@2][Jd0Z:RX08j>SP2TY:@0Zj^[0:JVYP2ZZZX0/k>c0=7Ad@3;bl/0UYJF0P2g]kL07@2XZ:P0[Jf]
0;no_`2e]KD0/k>c0;Vi^@35aLD0]KFe0;Vi^@37alL0`L710;no_`31`L40]kNg0;>c/`2a/K40_kno
0<W9b@2XZ:P0Y:BT0<?3``37alL0aLG50;fm_@39bLT0alO70<g=c@2o_kl0bLW90080`L7100T0clo?
0;>c/`2o_kl0/k>c065QH@2o_kl0`L710;Ng]`2_[jl00P37alL0102m_Kd0]kNg0<71`@2a/K4I0?oo
o`005`3oool03`1hMGD0N7]k06ecL01_MG00OWQc071_KP1cMG<0MWQf07AfM01kOgX0N7]i07YlNP1j
NGP0NgYg07QgM00207QjN01A07UkM`1dMW80NgYg07UhM@1`Mg00Ngmj07QeL`1gNGD0K6m]07j1O`1e
LW00LWA`07MfL`1aL6d0O7]j07MfM@1gNgD0Mgim07]jM`1hMg@0M7Id07EgM@1bKfd0LW5^07YjM@1V
IV40N7Ib07elN@1bM700NWUf06m^J`1RHEh0LFYX06iWI@1eLfl0L6iZ07EcK`21Og/0IVER06m^J`1g
MW<0Kfi[079aKP1hMg@0NgYi07EbL01hMG<0OW]i07YgM@1fNWD0Ogik07akN01fMG80Ngmj07MgLP1e
M740M7=b08:1OP20NgT0Kfi[06e_K@1dLg00OGai07imNP1jNGH0P7ek06QUH`22PGh0NgYg081oO022
PGh0O7]h08>2O`1eLW00NgQf079_K@1;B4H0NgYg07akN01gMg80Lg9_0080OgYg00@0NWMe07MiM@1l
OWX0M7=`7`3oool01`2[Zj/0[Jf]0;>c/`2_[jl0WYjN0;6a/@2i^KT00P2_[jl06035aLD0/k>c0:2P
X02g]kL0/K6a0;Vi^@2[Zj/0Z:RX0;>c/`33`l<0alO70<o?c`2k^k/0`L710;6a/@2c/k<0_kno0:n_
[`2e]KD0^k^k0;Vi^@2a/K40_Kfm0::RXP80]KFe04H0`L710;>c/`2a/K40/K6a0:BTY02g]kL0Zj^[
0;>c/`2i^KT0/k>c0:f][@14A4@0]KFe0:JVYP2>SXh0ZZZZ0:n_[`2VYZH0Ng]k0;fm_@2_[jl0/k>c
0;no_`35aLD0alO70<?3``2TY:@0`L710;^k^`33`l<0aLG50;^k^`31`L40[jn_0;^k^`3=cLd0/k>c
0;Vi^@2m_Kd0]kNg0<W9b@2][Jd0_kno0:n_[`33`l<0bl_;0;fm_@35aLD0/k>c0;6a/@35aLD0^k^k
0<O7a`33`l<0_Kfm0;no_`2a/K40ZZZZ0<_;b`33`l<0[Jf]0;6a/@2ZZZX0`L7109bLW031`L40/k>c
09:BTP2o_kl0ZZZZ6@3oool001L0oooo03@0MgUg06Y]J`1nOGX0MGMc07UmN023QH<0MWih07UdLP1l
NGL0MgYh079eL`1aNGD0M75a07elN@1jNGH0OX1l079dL01hNWP0LGAb07]hMP1cL6h0MGMe071bL01i
NgT0NgYg07AfM01gNGL0O7ag07UiM01hMg@0M7=`07AfLP1_LFd0L6m/07MfL`1JF5@0Lg5]07]kLP20
P7/0NGQg07mnO@21Pgh0N7Qc07ehMP1jMgD0NWUf07=bK`1`Kf`0NWUf05UFE01SHUl0J6YU0P1ZK6L0
3@1hNWD0NgQh06MVI@1eMgD0OGQe07EgM@1iNgT0N7Yh07YiMP1mO7T0NGQg07YhNP1`L6/00P1cLW40
8`1bLG00MgMb07EdL@1iN7D0LG1]07IeLP1iN7D0OGai0860O@25OWd0NWMe08B3P021P7d0O7]h07Ed
L@1nOGX0PH1m081oOP1jNGP0O7]h06]]J@1eM740Lg9_06eZJ021OW`0PXEm08F7Q@23PHD0JVQZ07Yl
NP23QH<0MgUe07ejN01hNWH0O7ij01l0oooo01/0]kNg09jNWP35aLD0/k>c0;^k^`3?cll0]KFe0;^k
^`31`L40]kNg0;^k^`2[Zj/0/K6a0<?3``2m_Kd0aLG50:f][@2i^KT0Zj^[0<O7a`2_[jl0/k>c0:ZZ
ZP2c/k<0^k^k0;6a/@2g]kL00P31`L405`2i^KT0/K6a0;6a/@35aLD0Z:RX0;Ng]`1oOgl0]kNg0:n_
[`39bLT0^k^k0<O7a`3=cLd0bl_;0<?3``2m_Kd0[jn_0;fm_@2ZZZX0_Kfm0;^k^`1mOGd0T92@0080
WYjN00h0U9BD0;Vi^@2o_kl0/k>c0<g=c@33`l<0/k>c0;Vi^@2k^k/0_Kfm0<?3``2k^k/0ZZZZ0;no
_`80[jn_02<0]kNg0<o?c`2c/k<0^k^k0:^[Z`33`l<0^k^k0<?3``3;bl/0_Kfm0<o?c`3AdM40bl_;
0<71`@3AdM40aLG50<_;b`39bLT0cLg=0<71`@2PX:00/k>c0:n_[`2ZZZX0bl_;0<g=c@3Cdm<0clo?
09jNWP2m_Kd0clo?0;Ng]`33`l<0^KVi0<71`@0I0?ooo`005`3oool03@1]Kfd0KG1^07IeLP1/KVX0
K71[07EgM@1eK6`0OH5l07IhM01eM7<0NgQh07AjM`1bMG<00P1aL6d207MhN@1G07QeM@1gMWD0MWUi
07=fMP1gNGL0LgEc06maK`1hMg@0LgEc07EgM@1mP7h0O7mm07QgM01nOGX0LW=d06m`L@1[JF/0N7Ih
07YlNP1lOW`0O7]j0820N`1oOWd0NWUh07n1O`1aL6l0NGQe07UkM`1oOW/0NWUf079aKP1gMW<0J6ES
055@C@1dMW40IFMR071bK@1oP840MgAd07IeM01dMW@0OW]k07YlNP1kOG/0NWaj07MfL`1fMG80M7=b
07IdMP1nQ8<0OGQe07UdL@1XHf00O7]j07EdL@1hMg@0Ogik07QgM02?SX/0KFaY07YiMP1nNGL0O7]h
06YYIP1mO7T0PX5n07elN@1gMW<0OGai07UhM`1lNgX0Ph9o07anNP1nOGX0P7ml07EgL`28RXH0OGmm
065SG`1[KfT0Ngmj07YhM01mNgL0PW]j06Y^J@1fN7@0L79^01l0oooo01`0Zj^[0;>c/`2NWYh0TY:B
0<71`@2[Zj/0[jn_0;>c/`2][Jd0[jn_0;^k^`37alL0]kNg0:BTY02k^k/0`L710;>c/`2a/K40`l?3
0;Fe]@37alL0`L710:^[Z`2c/k<0^KVi0;^k^`2_[jl0]KFe0`2o_kl0>02i^KT0XZ:R0;6a/@2][Jd0
bl_;0<?3``37alL0bl_;0=7Ad@3Ng]h0_Kfm0:RXZ02e]KD0Y:BT0;no_`2_[jl0^KVi0;^k^`33`l<0
_Kfm0;6a/@28R8P0Zj^[0;^k^`2PX:00bl_;0:^[Z`2g]kL0Zj^[0;no_`37alL0`L710;6a/@2o_kl0
`L710;Vi^@3Cdm<0ZZZZ0<71`@3;bl/0/k>c0;fm_@2e]KD0Zj^[0=KFeP2i^KT0/K6a0;Ng]`2o_kl0
`l?30::RXP3Hf=P0ZZZZ0<G5a@39bLT0`l?30`2e]KD03`2g]kL0Zj^[0;6a/@33`l<0[Jf]0<O7a`31
`L40^k^k0<?3``2c/k<0eMGE0<W9b@2TY:@0]KFe0<O7a`0I0?ooo`005`3oool07@1aMg@0MGMe06Y]
J`1TIV@0O7mm075cK`1cMG<0MGMe079dLP1cMG<0KV][07mlO01gM7@0KFm[07UkM`1lOW`0MGMe07Ac
L01mO7T0NGIf07mlO01lOGh0LG=a07QjMP1bM700NG]g07=eL@1fMG80N7Md0080NgYg04T0N7ag07Af
LP1]K6T0LW5^0863O`1oPGd0J6i[0868P@24QX@0Rhf;06m`L@1lNgX0MW5_06eaK01cLVl0MGAa07Qg
M01iMW@0NWMe07AcL01WJFD0GeiK075cK`1[IV@0PH5l06MUH@1aK6T0LFi/07]mN@1mO7T0Ogik07Ac
L01kNWL0O7]h05ACD01hMgH0L6m/07akN01/JfP0PH1m07YiMP1fMG80LG1]07E`KP1hMg@0M7=`07Mf
L`1lNGL0NgQf06aYI`28QH<0L6e[07]jM`20Og`0OGYh07IeLP1iN7D0MWEd07MeL@1aL6d0M7=`08V8
Q@1bLFh0OgQf07aeL`1iN7D0OGai07EkMP26QH80P7]i06eXIP1fLg40Oh5m01l0oooo00T0^KVi0<71
`@2c/k<0YZJV0;no_`2k^k/0_kno0:f][@2ZZZX00P2k^k/0=@2_[jl0ZZZZ0;fm_@2[Zj/0aLG50<O7
a`35aLD0]kNg0;^k^`2ZZZX0X:2P0:BTY02g]kL0`L710:JVYP2k^k/0Y:BT0<71`@39bLT0alO70;^k
^`2c/k<0Z:RX0;Ng]`2o_kl0/k>c0:BTY02m_Kd0clo?0<71`@2o_kl0[Jf]0;no_`33`l<0[jn_0<O7
a`2o_kl0^k^k0;>c/`2[Zj/0Z:RX0:2PX02HV9P0[Jf]0:ZZZP2e]KD0^KVi09bLW035aLD0`l?30;fm
_@2][Jd0Z:RX0080aLG500h0bl_;0<71`@2i^KT0[Jf]0;Vi^@2g]kL0T92@0;Vi^@2k^k/0]kNg0;Fe
]@33`l<0^k^k0;>c/`80bLW901L0WYjN0<W9b@2k^k/0alO70:n_[`2PX:00_Kfm09jNWP39bLT0^k^k
0;Ng]`2k^k/0aLG508R8R02o_kl0WYjN0:ZZZP2FUYH0^k^k0:RXZ02c/k<0`L710<g=c@0I0?ooo`00
5`3oool0?`1hMg@0O7il07EbLP1^Jf/0NgQh07UmN01kOG/0LWAb071bK@1iMg<0MGQf07=eL`1`Kfh0
NWUh075dLP1nOG`0Ogim07imNP1gMW<0MGMe071bL01[KV`0KFa[07akNP1hNWP0KVe/07UbL01]K6/0
N7Mf081oO01oOWd0NG]i06m^K@1iMW@0MgIc07]lO@1]JfL0MWIa07YlNP23QX@0O7mm079dL01iNgL0
NgYg07elN@1oPGd0MWEb07]jM`1iN7D0LFmY06m/JP1THEl0JfQV06MTHP1`M6l0MVm]07=/JP1hLg40
OWah07ejNP1iN7L0NWaj06maK`0207ilN00W079`K021PG`0N7=a079_K@1iN7D0N7Ib06=PGP1hMg@0
NG]g07]kMP1fMG80OGai07UhM@1cLW40MGAc081oO01ZIfD0P7ek07UkM`1oPGd0LgEc06]_JP1]LF`0
JVUV081oO01iN7L0MgIc07]mN01nOGX0Gf5L07]kMP1ZHf40L6]X06I]K01iO7@0Kg9b07EcK@1lOW`0
PXB201l0oooo02P0[jn_0;^k^`3;bl/0U9BD08J6QP2c/k<0]KFe0;fm_@2c/k<0^KVi0:BTY033`l<0
^KVi0;Ng]`2o_kl0/K6a0;Ng]`33`l<0`L710;Fe]@2c/k<0Z:RX08J6QP2ZZZX0]kNg0<W9b@35aLD0
Z:RX0<G5a@39bLT0alO70;>c/`2a/K40V9RH0;Vi^@3Cdm<0eMGE0=kNgP37alL0`l?30P2XZ:P07@2e
]KD0^KVi0;Vi^@2o_kl0/k>c0:n_[`2i^KT0]KFe0::RXP2k^k/0X:2P0:f][@2e]KD0V9RH0;>c/`2P
X:00^k^k0<?3``2VYZH0[Jf]0;no_`2FUYH0alO70;fm_@33`l<0TY:B0<O7a`2[Zj/0`l?30080]kNg
01/0]KFe0:ZZZP2ZZZX0[jn_0;Fe]@2ZZZX0]kNg0;no_`2m_Kd0bLW90;^k^`3;bl/0^KVi0=?Cd`2_
[jl0YZJV0;Ng]`35aLD0bl_;0<g=c@2_[jl0[Jf]0:^[Z`33`l<0_kno0>;RhP2m_Kd00P2g]kL00`2c
/k<0_kno0<O7a`0I0?ooo`005`3oool0J01fMG@0NGUn06iaK`1mNWX0OH1n07YmO@1iLW00MWA`07]o
N@1^Kg00MgEg0820N`1jNGP0LGMf07=eL`1oOWd0L6m^07AfLP1_LFd0N7]i06iaK`1ZL6d0I6IT07il
N01mMW@0MW=a07MdLP1oNWP0LG=_07YgM@1kN7H0LW5^07=bK`1bLFh0NGQe07IiN@1kOW`0I6]/05YI
F01QG5T0HUeJ081oO01bLFh0OGmj07UkMP1dMW@0OGmm08J1O`1XIF<0Lg9_075gLP1fN7H0L79`06Y/
JP1kNWT0NWMg06m/K01lNGT0Oh=n07aiN`1nO7h0MgQi07]iM@20P7L0LW9]08>2P@1nOGX0Q85o079_
K@1lNGL0OGai0860O@1fLg40P7]i06YYIP1bM700NWah07eoN`2>SHX0L6m/07]hMP26Ph40P7ml07Yi
MP1oOW/0Qh:007imNP1jLg80O7]h07elN@1XJ640NGQe075`K@1SHUl0N7Md07IeLP1fLFl0PW]i07Qe
L`1kOGT0OX1l07UkM`22Q800PH=o7`3oool00`2e]KD0^k^k0:JVYP020<?3``0d0;fm_@2k^k/0]KFe
0;no_`2VYZH0`L710<W9b@2m_Kd0Zj^[0:n_[`37alL0ZZZZ0;6a/@2XZ:P0/K6a0:JVYP2NWYh0TY:B
09BDU035aLD0]KFe0;Ng]`37alL0_kno0;fm_@2o_kl0[Jf]0;^k^`2_[jl0^k^k0;Fe]@2m_Kd0_kno
07moO`2<S8`0SXj>092@T039bLT0`l?30;^k^`2_[jl0/K6a0=GEe@2JVYX0]KFe0:n_[`2[Zj/0ZZZZ
09jNWP35aLD0_kno0;fm_@80`L7102D0alO70<71`@2g]kL0f][J0;no_`39bLT0[Jf]0<G5a@2k^k/0
dM7A0:f][@33`l<0cLg=0<_;b`2e]KD0bLW90<71`@2][Jd0_Kfm0<?3``2ZZZX0e]KF0;no_`3EeMD0
bLW90;Vi^@37alL0e]KF0<G5a@2ZZZX0`L710<?3``2JVYX0^k^k0<71`@2@T900^KVi0080]KFe00L0
cLg=0;Vi^@2o_kl0aLG50;^k^`3=cLd0bl_;01T0oooo000G0?ooo`1X07UlNP1dMW40LGYf071_KP1c
L700Kg=^07]mN@1iOGP0Mgeh07IgN01gMGL0P81k07MfM@1jOGd0NgYi07MfM@1hMgH0Ngei071bKP1`
L6/0NGUd07EhMP1iN7L0KWIb07AfM01bM700MGMc07]mN@1iOgX0MgUe06e_J`1bLFh0Lg9_07elN@1k
NWL0GF1P05mRH01VIV40KFYX05EED01`L6/0O7]h07elN@20PX00M7Id07anO01eMgD0NGYk07EhN01]
LF`0NWMe07EdL@1gMW<0N7Md07E`K@1`KVX0LFm[06]YI@1hLg40OW]k07]jN@1YJfT0O7il07ilP01f
M7H0O7]h07QgM01mOg/0MGMc07eoN`1ZJFH0MGAa07UfM021O7X0MWEb07mlNP1nNgT0N7Ec07MfL`1i
N7D0OGio07EfM`1hMg@0NgYg0860O@1kOGT0MgUe07=bK`1jNGH0M7=`071`J@1ZJFH0N7Md07elN@1h
Mg@0Kfi[07=dM@1lNgX0N7Md07EgL`1mOg/0LG=_089oO@1fLg4O0?ooo`0Q0:JVYP2a/K40]KFe0:f]
[@2e]KD0bLW90;>c/`2][Jd0/k>c0;Ng]`2_[jl0^k^k0;fm_@2k^k/0_Kfm0;no_`2g]kL0^KVi0;Ng
]`31`L40Zj^[0;Fe]@31`L40^KVi09BDU02g]kL0_Kfm0<71`@2o_kl0^k^k0;Fe]@31`L40^k^k00<0
_Kfm00<0[Jf]08j>SP2c/k<00P2e]KD20:n_[`0;0;6a/@35aLD0_kno0;>c/`2ZZZX0]KFe0;no_`2e
]KD0_Kfm0:BTY02c/k<00P3;bl/0402c/k<0^k^k0<?3``2g]kL0^KVi0;6a/@2XZ:P0^k^k0;Vi^@2c
/k<0_kno0;Vi^@35aLD0ZZZZ0;Vi^@2NWYh20:f][@0O0:^[Z`37alL0_kno0<O7a`33`l<0/k>c0:^[
Z`35aLD0bl_;0;Ng]`31`L40f=SH0<71`@2c/k<0bLW90;Vi^@3;bl/0]kNg0;Fe]@2a/K40cLg=0;Fe
]@3;bl/0/k>c0:n_[`2g]kL0^k^k0:n_[`37alL0_kno0<O7a`0I0?ooo`005`3oool09`1^L6h0M7Id
07I`L@1bLG00MWai081kN01eMWT0LW=f07EfN@1gNGL0LW5^07UhM@1jNGH0NGQe07YiMP1kN7H0MgAb
07QaL01gL6l0NG]g075cL@1fMG80O7]h06E[IP1^M6l0MgAb07YgM@1lMG@0Ogik07UkN@1fN7H0O7Me
07YnN@1`Kfh0NWaj07YiN01RHUd0JVEP07EbL00207IeLP0o07=iM01hNWH0M7=`07imNP1eM7<0Lg9a
071_K01fMW40MWEb07YiMP1iMW@0KFYX07EdL@21OW`0MGAa06QWI01iN7D0MgAb07QgM01mO7T0M7=`
07UhM@1hMgH0MGAc07elN`1kOGT0OX1n071bKP1cMG40N7Ib079bK@1bL6`0LFm[07elN@1kOGT0Ogik
07ehMP1jNGH0MGAa07ikN@21OW`0Mgeh07ejN028QhH0O7]j07EbL01fLg40N7Ec085nO01gMW<0MWEb
07mnN`22PGh0MWEb0860O@1eLW00LgAe07MfM@1iN7D0Lg5]07mlO01kOGT0Ogik01l0oooo0280^k^k
0;Vi^@2ZZZX0Y:BT0:^[Z`2i^KT0YZJV0;^k^`2XZ:P0ZZZZ0::RXP2][Jd0/K6a0;Fe]@2c/k<0WYjN
0;no_`2a/K40^k^k0<G5a@2_[jl0/K6a0;fm_@2a/K40[Jf]0;Fe]@2m_Kd0`L710;fm_@31`L40Zj^[
0;fm_@2TY:@0[Jf]0P2[Zj/08@2][Jd0SXj>0<W9b@2ZZZX0/K6a0<71`@2PX:00^k^k0;Ng]`2k^k/0
clo?0;Vi^@2e]KD0^KVi0:f][@2k^k/0/k>c0:^[Z`3Fe]H0R8R80<_;b`2][Jd0`l?30;Vi^@2VYZH0
_Kfm0:f][@2c/k<0/K6a0:^[Z`3Cdm<0_Kfm0<G5a@020;^k^`0:0<G5a@3;bl/0]KFe0;^k^`2m_Kd0
^KVi0<g=c@2NWYh0_Kfm0:RXZ080aLG501H0_Kfm0<_;b`2c/k<0alO70;Vi^@2k^k/0aLG50<O7a`2g
]kL0WYjN0<?3``2o_kl0^KVi0;fm_@2_[jl0^KVi0;no_`3=cLd0clo?0:f][@2a/K40_Kfm6@3oool0
01L0oooo0500NGIf07QjMP1`MW<0KFm]075^KP1hNWP0KW1/07UkM`1_LFd0L79`07moNP1bLFh0M79d
07IdMP1eLW80JVaZ07]jM`1dLg80NGQg07]jM`1cLVl0M7Qc07YnN@1bLFh0NGQe07IeLP1jNGH0O7]h
07imNP1lOW`0LG1_07YlN01bMW40M7Ib075^K01aL6d0HVAR07MiM020OG/0L6m/07AcL01[LFh0LW5`
07UhM@1gMW<0Ph:107MdLP1hLG00MVm^079_K@1iM780Lg1^07EbL01aL6d0GeiK0860O@1nOGX0LW5^
07QgM01^KFX0RHR507YiMP1eM7<0M7=`075^K01mN7H0QHB107ilN01iMg<0Lg1^07UiM021PG`0MWA`
07UgL`27PX00N7Md08:1OP1ZJFH0LG1]07YiMP80OW]i01H0NWYe07moNP1eLW00Ogaj07QeM@1mNWP0
OWej07mnN`1gMWD0JVUX06IXI01kN7H0N7Qc07YhM01cLVl0N7Md07]mN@22PGh0Pgil079dL01dLg00
NWUf7`3oool06@2e]KD0^KVi08:2PP2>SXh0PX:20:^[Z`2m_Kd0]kNg0:n_[`2e]KD0]kNg0:RXZ02e
]KD0W9bL0:ZZZP2i^KT0[jn_0<G5a@2e]KD0/K6a0;^k^`35aLD0]kNg0<W9b@2m_Kd00P2k^k/0402X
Z:P0`L710=?Cd`3;bl/0[jn_0;no_`33`l<0_kno0<_;b`31`L40Z:RX0;6a/@2e]KD0cLg=0<o?c`2k
^k/20<71`@0E0<G5a@2k^k/0_kno0;Ng]`2c/k<0Z:RX0:n_[`35aLD0ZZZZ0:^[Z`2ZZZX0^k^k0;Ng
]`37alL0^KVi0=?Cd`2e]KD0bl_;0<?3``3;bl/0]kNg0080_kno01H0[jn_0;fm_@33`l<0[jn_0<G5
a@2XZ:P0/K6a0<?3``2o_kl0]kNg0;fm_@2o_kl0]KFe0;Vi^@2_[jl0_Kfm0;6a/@37alL0`l?30:n_
[`2i^KT0`l?30P37alL03@2o_kl0/K6a0<g=c@31`L40^k^k0=cLg03?cll0/K6a09RHV02k^k/0]KFe
0;6a/@3?cll06@3oool001L0oooo06P0MWEb07QjN01LEeD0HUmM05aKF01aKV`0NWek07MiM`1cL700
MWEd06I/J`1_LW00MWQd06U[J@1`LW00N7Ec07=`KP1nNg/0MW=a07elN`1iN7L0OW]i07MfL`1jMgD0
P7ek07UfMP1iN7L0Kfa/07aiN@25PX80PGin07=eL`1mOgd0KW9/07]hN021QH00KfQW07imNP1dLg00
MWA`08:0O01iNgL0MGUd07ajMP1lNGL0NGQe07QgM01kOgX0MgIc06m_JP1cLfh0MW=a07ikN@1`KF/0
L6m/07UcKP1YHV00Mg1_07QgMP25Q840NWMe07IcL@1mNWP0PGil07MdLP1dLFl0NgYg07=^K01jMG<0
KFQV07ehL`1nOWL0KfUT07AbK01lMg@0NgYg07MfL`1jNGH0OW]i07]hMP1hNWH0Lfi[07YlN01cLVl0
Ogaj07ejN01cMG<0LG=a07elN`1oNWL0OgYe07]hMP1eMg80PX6007aiM`1iMW@0RXZ508>2P@1dLVh0
IfEQ07UfMP1fM6h0M7=`08>2Oal0oooo00`0VYZJ0:ZZZP2c/k<0^KVi0<?3``2][Jd0_Kfm0;Ng]`2i
^KT0]KFe0;Vi^@2e]KD209bLW0030;6a/@2c/k<0]kNg0080[Jf]00`0bLW90;no_`2c/k<0bl_;0:f]
[@35aLD0_kno0:RXZ02e]KD0_kno0;^k^`2][Jd20;fm_@030;>c/`2k^k/0]KFe0080Y:BT00@0YZJV
0:n_[`2m_Kd0]kNg0P2c/k<0?@39bLT0`L710;Ng]`2g]kL0aLG50:n_[`2m_Kd0ZZZZ0:^[Z`2RXZ80
/k>c0;^k^`2o_kl0/k>c0<_;b`2_[jl0dm?C0=SHf02m_Kd0/k>c0<W9b@2k^k/0_Kfm0<71`@35aLD0
_Kfm0;no_`3=cLd0Z:RX0<?3``2c/k<0^KVi0;^k^`33`l<0bLW90<o?c`2k^k/0/K6a0:JVYP2_[jl0
^KVi0<?3``2ZZZX0/K6a0<W9b@31`L40/k>c0:n_[`2][Jd0`L710;^k^`2NWYh0`L710<?3``2m_Kd0
clo?0=GEe@3=cLd0_Kfm0=GEe@3AdM406@3oool001L0oooo06P0NgQf07QiNP1eM7<0NWaj07aoO@1a
MG00OX5o07AgM@1ZKF/0Lg9a06a^K01fN7H0M7Id07anO01iMWH0Ng]f07UiM01bM700J6YV07elN@1k
NWL0LgUd07]jM`1eM7<0OGak07YiMP1eM740Lg9_07elN@1dMW40NGUd07aiM`1jMgD0Lg1^07ejN01m
NWX0F5I@0820N`1XJ6<0KVeZ07]bLP1gMG40O7Yf07YiMP1gMW<0M7=`07mnN`1[JVL0N7Md07imNP1_
KV/0N7Ec07YgM@1`KF/0L6iZ07UgL`1oOGT0JFMS07UfM01kN7H0NWMe06eZJ01^JfT0NWEb07mjM`1n
NGH0PWn107ejN01kN7H0Ogaj07UdL@1nMW@0MVm]07QfLP1jMgD0NGMa08B2O01iMg40PGYh07MbK`1e
M740LW5^07]jM`1jNGH0NgIc08N2O`1kOG/0Q8>0089oO@1cL6h0Ng]f07EcK`1mN7H0MG9`07afN@20
NgT0LFaY08^6P`2:QH80P7ij089mNP1gMWD0NWUh07MiMal0oooo00T0_kno0;Vi^@2c/k<0_Kfm0<71
`@2[Zj/0aLG50;6a/@2NWYh00P2_[jl05`2e]KD0/K6a0<71`@2k^k/0_kno0;^k^`2][Jd0VYZJ0;Fe
]@2o_kl0[jn_0;no_`2m_Kd0/k>c0;fm_@2c/k<0[jn_0;fm_@2a/K40^k^k0<71`@33`l<0_Kfm0080
`l?301h0]KFe07]kN`2JVYX0YZJV0;no_`2m_Kd0]kNg0;fm_@2g]kL0^k^k0;6a/@2PX:00^KVi0::R
XP35aLD0Z:RX0;fm_@2ZZZX0^k^k0:ZZZP2k^k/0W9bL0<_;b`2k^k/0_kno0:BTY02c/k<0YZJV0;fm
_@37alL20<g=c@0U0<?3``2o_kl0^k^k0;6a/@35aLD0]KFe0;Vi^@2m_Kd0^k^k0=7Ad@2k^k/0]kNg
0;no_`2c/k<0[Jf]0;no_`37alL0_kno0=KFeP2o_kl0alO70<g=c@2_[jl0_kno0;>c/`2k^k/0/k>c
0<71`@39bLT0Zj^[0=kNgP3Lg=`0bLW90<g=c@2g]kL0_Kfm0;Ng]`0I0?ooo`005`3oool06`1jMgD0
Ngam07ikN`1gM780Lg1^07EdL`1nP7h0M7Id07QjN01dMGH0Lg9a07AcLP1kNWT0Kfi[07EdL@1`LVh0
MWQd079hL`1lNGL0MW=a07UfM01]JfL0NWMg07UhM@1oOW/0OGai071_K00207YiN00[06Y/JP1aL6d0
SHZ807ikN@1nP7`0PHF008N6Q@1kNgH0OGYh071]J`1oO7X0OGYh08J1O`1fN7@0L79^07IeLP1bLFh0
NgYg07]mN@1eM740MW5^07E`K@1/JVH0MWA`075_J`1jMgD0QX>107UfM01YIV@0J6IR07=bK`1iNgL0
LWIa07aiM`1kNWL0OGai07=bK`1]JVP0OGYh07YgM@1gM780PW]i071[J@0207]fM00N07EdL@1jMgD0
NWMe07EbL01jNWD0OG]g07aiM`1iM780NGId07ikN@1hMG<0PH1m07elN@1fMG80L6e[07ehMP1oOgX0
N7Ib07IhMP1dLG40RH^707alM`1iM6l0FUE@07AcL01lNgP0O7Ug07MiM@22PWd0OG]g7`3oool02P2i
^KT0/k>c0:JVYP2LW9`0ZZZZ0;fm_@37alL0ZZZZ0:RXZ02_[jl30;^k^`0;0=7Ad@3EeMD0Z:RX0<G5
a@2c/k<0[jn_0;Ng]`2i^KT0aLG50;no_`2a/K400P2i^KT0702e]KD0aLG50;no_`33`l<0]kNg0;no
_`3Ng]h0/k>c0:RXZ037alL0bLW90;>c/`33`l<0X:2P0:JVYP3Cdm<0]KFe0:RXZ031`L40/k>c0<?3
``2@T900`L710:^[Z`2e]KD0`l?30:BTY02i^KT20;Ng]`0P0;no_`2c/k<0ZZZZ0<_;b`2a/K40]KFe
0;Vi^@2g]kL0[Jf]0;>c/`2m_Kd0^k^k0;Vi^@2ZZZX0cLg=0:n_[`2LW9`0X:2P0<71`@2i^KT0Y:BT
0:f][@2g]kL0clo?0;6a/@31`L40^KVi0;no_`2i^KT0ZZZZ0=KFeP0O7al20;6a/@0?0=7Ad@33`l<0
aLG50;^k^`2a/K40[jn_09jNWP2m_Kd0]KFe0<g=c@3Cdm<0]kNg0<o?c`33`l<0_Kfm01T0oooo000G
0?ooo`0b07QbL`1eM7<0KWAa06U/JP1`LW00NWMg07n1O`1`LW00Kg5_07=bK`1iNgL0NG]i07UgN@24
Ph00QXF206m^J`1nOWT0MGAa07=bK`1iN7D0N7=a07ilOP1kNWL0N7Ec071]J`1hMg@0MWEb07ikN@1n
P7`0OGmm07MiM@1kOG/0MGMe07j0O01_KV/0Ogik07EdL@1bKfd0OGai06]ZJ@1^KF`0MWQd079dL01_
LFd0O7]h07elN`1bLG00Hf9O07akN01fMG8207elN@0d06eZJ01hLg40MgAb07]jN@1cLW40MGAa0860
O`1dLFl0O7Ug07IcL@1gMW<0LW5^07EdL@1fMG80NWMe07QgM01`KF/0LFaZ089oO@1YJfL0JfmZ07ae
M01hMG<0KFaY079aKP1gMW<0PWmm08>0OP1lNWH0N6e/07]cL@1cKV/0L6iZ08N2O`0Y9al0Ngin07Aa
L@24Og`0OGYh07ikN@1XIf@0M7=`07=cK01ZJFH0NW]l07IgN022OG/0QHB107MkMP23OW`0OGYh07Yi
MQl0oooo0140Zj^[0:ZZZP2o_kl0^KVi0:f][@39bLT0^KVi0;Fe]@35aLD0_Kfm0:^[Z`2c/k<0XZ:R
0;Ng]`31`L40ZZZZ0;Fe]@020;Vi^@0F0:f][@2i^KT0/K6a0;Fe]@2k^k/0[jn_0;6a/@3;bl/0`L71
0<G5a@2i^KT0l?3`0;Ng]`2[Zj/0_Kfm0;>c/`2BTY80clo?0;6a/@2k^k/0Q8B40<?3``<0[jn_0180
/k>c0;^k^`2_[jl0]KFe0:n_[`39bLT0ZZZZ0<71`@2c/k<0[jn_0;Vi^@2FUYH0IfMW0:BTY039bLT0
i>CT0<g=c@2][Jd20;Ng]`080<o?c`2m_Kd0eMGE0;Ng]`2[Zj/0[jn_0:JVYP2g]kL20;Fe]@070:^[
Z`2e]KD0]KFe0;^k^`2o_kl0^k^k0:n_[`020;^k^`0B0;no_`2m_Kd0_Kfm0;fm_@2JVYX0`l?30;Ng
]`2PX:00`L710;Vi^@2m_Kd0Zj^[0<o?c`2_[jl0f][J0;no_`3Cdm<0]kNg0P37alL00`2k^k/0f][J
0?ooo`0H0?ooo`005`3oool04@1aMg@0L7Ic07]hMP1hO7L0LW5^081oO01hMgH0MWEd07imO01jOGd0
MgIe07EgM@1/Kfd0MgIc07anO01`LW00MWQf0080N7Yh03/0MWUi07QkN`1dLg00MWEb07=`KP1iN7D0
M7Ia0861O01lNgP0OGai07QgM02DTi00MgIc07YiMP1iN7D0MGAa06AZI@1dLFl0PXB207UkN@1MGeX0
OGmj07=eL@1gNGD0Lg9_07EgL`1cL700M7=b07IhM01cMG40L6e[07aiM`1cL6h0MG9`07=`KP1VIF80
CTe:06IUHP1]K6T0SXV7089kN@1gLVl0LW1/07MfL`23QH40NWUf08B1O`26Q800LG5/07=cKP1`L6/0
KVaX07IaKP1fM700LG5/07UiM01fN7@0NG]g07]mN@0207UhM@0407UfMP1iM740NgUe07ilN080NWUf
00h0J6MT07elN@1gMWD0Jf]V07akN01hMg@0PH5l075aK023QH40LgMb08V9Q01kNgH0QHN307MiM@80
Ogim00<0NG]g08V8Q@3oool07P3oool05`2_[jl0aLG50:ZZZP2VYZH0`l?30<G5a@2a/K40/k>c09bL
W035aLD0_Kfm0:JVYP2_[jl0alO70;Fe]@2c/k<0Zj^[0;^k^`2a/K40/k>c0;6a/@2c/k<0`L710080
_Kfm01/0^KVi0<G5a@2g]kL0^KVi0;>c/`2[Zj/0[Jf]0;Ng]`2m_Kd0V9RH0=7Ad@2g]kL0QXJ60:ZZ
ZP2PX:00_Kfm0:JVYP2i^KT0`l?30<71`@3AdM40[jn_0;no_`2k^k/0_kno0:2PX02m_Kd00P2ZZZX0
902TY:@0/K6a0;Fe]@3Fe]H0WYjN092@T02JVYX0[jn_0:^[Z`2g]kL0/K6a0;fm_@2e]KD0alO70;Vi
^@2m_Kd0^KVi0;Fe]@2g]kL0Z:RX0:f][@2LW9`0Y:BT0<G5a@2k^k/0/K6a0<?3``2k^k/0alO70;Vi
^@3;bl/0aLG50:2PX02m_Kd0^KVi0;Fe]@80/k>c00d0bl_;0;6a/@2RXZ80ZZZZ0:n_[`35aLD0/k>c
0<o?c`37alL0bl_;0<g=c@31`L40/K6a01T0oooo000G0?ooo`0:06e/J@1oOWd0LgId06i`KP1kNWT0
LWEg07QgM01bLFh0O7]h081oOP80MGAa00L0LW5^07YgM@1fMG80L79^06]_JP1gMWD0L6m^0080N7Yh
05<0MGE`07UkN@1gMW<0OWej07IjM@1jO7P0NGId07b2P@1lQ7h0LgEa06a[J01oOW/0GUeJ07ekM`1V
Hf40JfeY07j0O01oPGd0Lg5]0820N`1`LVh0M7Ib08J5Q01hMgH0IfUU07YeL`1_KV/0LG1]07MeL@1f
M700MG9`07=`KP1`KF/0NWah07]jM`1`M6l0M7Ye07IdL01nMGD0L71[07]eL01aL6l0MGE`07=bK`1f
MG@0HEiN07miNP1jMgD0Oh9j07IfL@1dMW40MgUd07EgLP1mO7T0NgYg07IeLP1iN7D0OWel07elN`1m
O7T0KFaY08>1O@1lNWH0NG]i07IhMP1`Kfh0MW=a07=gLP1gNgH0Q8>007]jM`22PH00P81k07EeL01b
LVd0O7ii08J8P`24Ph00O7]h07UhM@1[Jf80Kg5]07elN@0O0?ooo`0K0:BTY037alL0[jn_0:JVYP2o
_kl0[Jf]0;Vi^@2][Jd0`L710<W9b@2o_kl0/k>c0:f][@2m_Kd0]KFe0:ZZZP2PX:00]kNg0:ZZZP2e
]KD0^KVi0;>c/`2k^k/0]KFe0;Ng]`2e]KD0_Kfm0080^k^k01T0`L710:n_[`2RXZ80[jn_0<O7a`33
`l<0UYJF0:n_[`2PX:00alO70:n_[`39bLT0YZJV0:ZZZP3EeMD0^KVi0;>c/`2HV9P0Z:RX0:^[Z`2k
^k/0]kNg0;Fe]@2_[jl0ZZZZ0080_Kfm0340_kno0;6a/@31`L40]KFe0<G5a@2o_kl0]KFe0:^[Z`2c
/k<0[jn_08b<S033`l<0alO70;fm_@2e]KD0_Kfm0;6a/@2g]kL0/k>c0;^k^`2o_kl0]KFe0;^k^`33
`l<0clo?0<?3``2TY:@0clo?0:f][@2k^k/0]KFe0:ZZZP2o_kl0[jn_0;Ng]`3AdM40_kno0=GEe@39
bLT0/k>c0:f][@31`L40eMGE0=7Ad@31`L40^k^k0:2PX02XZ:P0`l?301T0oooo000G0?ooo`1X07Qa
L01`Kfh0KVe/075`K`1gMWD0Lg9a07UhM@1nOGX0Kfi[07mnO@1nN7T0OGMh07MaLP1jMgD0MGAa079a
KP1jNGP0N7Yh07egN01kMW@0OX1l07EdL@1aL6d0PGaj07j0O01fLg40LG1]07QfLP1kOG/0N7Md07Ie
LP1kNWL0N7Md07EbL01eLfl0LGE`07QlM`21NWT0OgQg07imNP1hMg@0NGMc08:1P01gM780OGYh075`
K@1eM740NGQe07IeLP1eMg<0NgQf08>6OP1gMg00LVeX06IUHP20PWh0LW5^07IcL@21OW`0M75_07Qe
L`1iMW@0NWEb07UfM01jMgD0OW]i08=nO01oOW/0O7]h07IeLP1hN7<0M79^081nNP25Pgl0O7Yf07in
N@20P7/0NWag06a^K01_KV/0NgUe079`K01lOWT0N7Ib07QgM01YIVH0P89m079]JP25Q840Q8>007mm
N@1mNgL0NgQf07MdLP1fM700O7Yf07aeM01SG5/0M7Id07QgM01eLfl0OGak06]VH@2LUi8O0?ooo`0H
0<G5a@20P800_Kfm0:^[Z`2a/K40_kno0:ZZZP2g]kL0Zj^[0:JVYP2a/K40]kNg0;>c/`2][Jd0Z:RX
0<G5a@2k^k/0WYjN0;no_`2g]kL0_Kfm0<?3``2e]KD0TY:B0P2o_kl06@2m_Kd0_kno0;fm_@2][Jd0
`l?308B4Q02e]KD0/k>c0<?3``35aLD0bLW90:2PX01[Jf/0aLG50<71`@2g]kL0/K6a0;no_`31`L40
dM7A0<?3``2k^k/0/k>c0:n_[`2i^KT00P2c/k<05@2][Jd0]kNg0;no_`2c/k<0_kno0;Vi^@33`l<0
[jn_0;Vi^@31`L40/K6a0<G5a@3AdM40_Kfm0;6a/@3Cdm<0]KFe0:f][@2m_Kd0]kNg0;6a/@020:^[
Z`080<O7a`2e]KD0^k^k0=7Ad@39bLT0_kno0<?3``2k^k/20:f][@0=0;Fe]@37alL0_Kfm0;no_`3=
cLd0ZZZZ0<?3``3?cll0alO707UiN@2c/k<0^k^k0<G5a@020:n_[`040<G5a@2m_Kd0^KVi09ZJVQT0
oooo000G0?ooo`1X07j0OP1KGE/0NWaj075cL@1dMW@0Ng]f071bKP1gNGD0LG=_06idL@1dMW80MgUe
07EgL`1bM780Kg5_07imNP1iN7L0JVUV07]jM`1eNG@0NWMe07ejNP1fMG@0Ng]f07YhM01kNGD0NWUh
07]jM`21P7d0LW5^07elN@1MGe/0MGMc07j0O01mOg/0OX5o06]YI@1jN7@0D4m>07imNP1lNgP0M7A_
075aK01kNgH0O7]h07elN@1iN7D0NGUd07EcK`1hMg@0MGAa07IaKP1eL6d0LVeZ07]hMP1eM740MWEb
07]jM`1mO7T0Lfi/079fL@1hMG<0M7Ib07iiMP24Ph00OH2007YlNP25Pgl0MWA`07QfLP1bL6`0Mg9_
07A]J`1aJVP0KF]W07moNP1fMW40NGUd07enO`24PX@0NgYg07elN@1iN7D0NWUf079aKP1fMG80Ogik
079aKP1kOGT0PXB0071_K01mO7T0NWUf07mnN`1GEE40MGAc07UhM@1nOGX0Lg1^07=bK`1nP7`0NWMe
07QiO01XI5`O0?ooo`0>0;Vi^@31`L40/k>c0;Fe]@2_[jl0_Kfm0;^k^`2][Jd0X:2P0:RXZ02c/k<0
]kNg0;Fe]@37alL20:^[Z`0O0;Vi^@2c/k<0`l?30;fm_@2c/k<0^k^k0<71`@2LW9`0/k>c0<71`@2m
_Kd0_kno0<?3``2g]kL0cLg=0;Fe]@37alL0/k>c0<_;b`31`L40^k^k0::RXP2o_kl0[Jf]0<G5a@37
alL0X:2P0<_;b`3?cll0YZJV0;>c/`020:RXZ00S0;>c/`2][Jd0/K6a04A4A02ZZZX0[Jf]0;^k^`31
`L40Z:RX0:f][@2m_Kd0/K6a0>3Ph02PX:00^k^k0:^[Z`2_[jl0]kNg0;^k^`2c/k<0_Kfm0;^k^`31
`L40`l?30;>c/`31`L40^k^k0:ZZZP2VYZH0WYjN0;Fe]@2c/k<0`L710:RXZ035aLD00P3;bl/04`2]
[Jd0/k>c0<O7a`31`L40_Kfm0<_;b`2VYZH0/k>c0:n_[`31`L40alO70:^[Z`2k^k/0clo?0;^k^`2_
[jl0YZJV0;Vi^@2ZZZX06@3oool001L0oooo01<0N7Yf07anNP1eM740MWEb07=bK`1jMgL0NGMi079a
L01[JVL0Kg5]079`K01gMW<0MWMh07mnO@1aL6l0LG1]07QgM01eM740OGmm0080MGAa00/0NG]g07ai
M`1eLW80NgQh07akN01jNGH0NgYg08F4P@1gMW<0PX5n07IcL@0207EdL@0F0860O@1lMgD0K6iZ07]k
MP1kNWT0LW5^07imNP1[KfX0N7=a085oN@23PGd0MGAa07MfL`1_LFd0KfaZ079]J`1dLFl0L71[03`l
=`1`L6/0NGQe07anN@80Kg5/02h0NWEb07AbKP1gMG40S8Z607UgL`1aLfl0LgEa06e_J`1gMW<0MGMb
07YjM@1jN7@0NG]f07ehM@1eLfl0O7ag075/J@1`KVX0KVaX06YXI01hMW80MVi/07alM`1_KFT0OWUg
07aiM`21P7d0LWA`07EiM020PWh0O7Ug07YeL`21OW`0KVeZ089oO@1cL6h0O7ag07moNP1aL6d0NGQe
08>2O`1iN7D0Lg5[06iWGP1hLg00L6]V7`3oool07P2c/k<0]KFe0:JVYP2XZ:P0]kNg0:JVYP2m_Kd0
`L710;^k^`2o_kl0^k^k0;fm_@37alL0bl_;0;6a/@2][Jd0aLG50;Ng]`2i^KT0^k^k0;Ng]`2a/K40
alO70;fm_@2g]kL0_Kfm0<?3``2_[jl0bLW90:ZZZP80/K6a00l0]KFe0:^[Z`2i^KT0/k>c09BDU02e
]KD0alO70;>c/`33`l<0/K6a0<71`@2ZZZX0^KVi0:f][@2o_kl00P2_[jl0>02a/K40Zj^[0;Ng]`2@
T900/K6a0=GEe@2RXZ80]kNg0;6a/@2HV9P0[Jf]0=GEe@2i^KT0dM7A0::RXP2_[jl0Z:RX0<g=c@2m
_Kd0W9bL0<O7a`2NWYh0alO708j>SP2g]kL0Zj^[0;Fe]@39bLT0/K6a0;Fe]@39bLT0j>SX0;no_`2]
[Jd0/K6a0<_;b`2g]kL0cLg=0:BTY02m_Kd0^k^k0;>c/`33`l<0bl_;0=?Cd`2FUYH0^k^k0<G5a@33
`l<0X:2P0;no_`3=cLd0_kno030`<02HV9P0aLG56@3oool001L0oooo00/0PH1o079hM@27RXP0LG=a
07akNP1cM7D0MgIe07akNP1jNGP0N7Ih07YkO00207EfM`1K07YiN01kNWT0L6m/07YlN01jNGP0OWel
07=bK`1bN7D0LgUh07aoO@1gMW<0O7]h07elN@1fMG80MGAa07UhM@1hNWH0P89n071_K01dLg00P7ml
079aKP1gMW<0M7=`07]jN@1lNgX0KV]Y07akN01`Kfh0OGak07YiMP1eM740IfEO06MVI@1_K6X0NWMe
07AaK`1eLW00KFm]06]ZJ@1^K6P0NWUh07YiMP1hMg@0Ogik08:4PP1gMWD0O7]j07elN`1cMG40QX5o
07ikN@20Og`0NGAb08B4O`1nO7P0P7]h085lNP1lP7/0MWEb07aiM`23PWl0LVm]07]hMP1oO7X0NgQh
07YiN01lMgD0NgYg07amOP26QH@0LgEa06e_J`1fN7@0LWA`06eZJ01lNgP0MgUg06maK`1oO7X0NWah
07IhM020Og`0MW=a06i`KP1dLW@0NgYg07I^J01>EE@0N7Ul07]iM@0O0?ooo`090<_;b`2][Jd0e]KF
0:^[Z`31`L40[jn_0;Ng]`31`L40_Kfm0080^KVi0P2c/k<00`2m_Kd0_kno0:ZZZP020;fm_@0>0<G5
a@37alL0[Jf]0:n_[`31`L40]KFe0;Ng]`33`l<0]KFe0;>c/`33`l<0^KVi0<W9b@2ZZZX20;6a/@0E
0:f][@2g]kL0aLG50;6a/@31`L40YZJV0<71`@2i^KT0ZZZZ0;fm_@2c/k<0/K6a09RHV02XZ:P0_Kfm
0<71`@2a/K40/k>c0:2PX02VYZH0Zj^[0080_Kfm0300alO70:ZZZP3=cLd0]kNg0<?3``35aLD0[jn_
0=GEe@35aLD0^k^k0<g=c@3AdM40aLG50<_;b`2k^k/0`L710;Fe]@31`L40^KVi0:f][@2o_kl0alO7
0;fm_@2c/k<0`L710;no_`31`L40]KFe0:n_[`2TY:@0]KFe0<g=c@2TY:@0`L710;Ng]`2XZ:P0]KFe
0;fm_@2e]KD0bLW90;Fe]@2VYZH0/K6a0;no_`2e]KD0IfMW0;Vi^@2o_klI0?ooo`005`3oool03`1c
MG<0MGAc079eM`1hMG<0NGal06iaK`1cMG<0Ngek075cL@1cMG<0L7Ic079dLP25OWl0PH1o07]jN@02
07=bK`1G07eoO@1gNGL0NWUf07MfL`1eMg<0MgUe079dLP1jO7X0OX5o075dLP1eM7<0NWek07IeM01W
IV<0NgYi07AaL@1nOGX0NGQe07UkM`1jO7P0Ngei06YYIP1`LVh0Ogik07UfM01`KF/0N7Ec07YgM@1d
LVh0M7A_06mbJP1fMVl0LW5^06m^J`1eN7H0OWel06QVHP1eLW00OWUg07MdLP1iN7D0MG]f07AfLP20
PWh0JVaX0865P01_KV/0LW5^0860O@20Og`0PH1m07MdLP1ZIF<0OWUf079[J@1/KFh0M7A_07IdL01f
Lg40O7]h08>5P@21P7d0O7]h079aL01hNWP0L79^07akN01hMg@0L7A_079`K01`Kfh0P7ml07QgM01j
O7X0NG]i06YYIP22OG/0QH1n07QcL@1/K6L0M75a08:1OP1aLfl0LFmc06maK@1dMW@0N7Md01l0oooo
00l0[jn_0;>c/`2][Jd0^KVi0;^k^`2VYZH0[jn_0;no_`2[Zj/0[jn_0<71`@2][Jd0dm?C0<_;b`2o
_kl00P2_[jl04@33`l<0]kNg0;Vi^@2g]kL0/k>c0;Ng]`2o_kl0[Jf]0<G5a@2[Zj/0/k>c0<O7a`2e
]KD0V9RH0;no_`33`l<0/K6a0080^k^k00D0aLG50;fm_@2NWYh0ZZZZ0<O7a`020;^k^`0i0;Vi^@2m
_Kd0]kNg0;6a/@2XZ:P0]KFe0;Ng]`2][Jd0Z:RX0<G5a@2JVYX0^KVi0;>c/`35aLD0^k^k0<71`@2c
/k<0/K6a09jNWP2g]kL0bl_;0:RXZ02][Jd0bLW90;>c/`3;bl/0]kNg0<G5a@33`l<0[Jf]0::RXP2a
/K40_Kfm0;Fe]@31`L40clo?0<71`@3=cLd0[Jf]0;Vi^@2ZZZX0_kno0;Vi^@2ZZZX0[Jf]0;>c/`39
bLT0^KVi0;fm_@2k^k/0_Kfm0<g=c@3Cdm<0^KVi0::RXP2a/K40cLg=0080Zj^[00<0Z:RX0;6a/@2i
^KT06@3oool001L0oooo01D0Kg9`07EgM@1dMW@0LG=a07IhMP1hNWD0N7Yh07n1O`1gNGL0P8:007Ag
M@1iNgT0OWel07b0NP1fN7<0NWUf07AfLP1iNgL0LG=_079dLP1fNGL00P1cMG<0A`1eM7<0Kfi]07el
N@1kNWL0OX1k07QjN020Og`0Lg9_0860O@1gMW<0NWaj06IXIP1gMWD0L79]07YlNP1fN7H0LFi/06aY
I`1eM740KVeZ06UXI@1bLFh0MGAa07UhM@1fMW40H5mL07mnN`1cLVl0KG5/06mcKP1]LF`0OGYh079_
K@1hO7L0OGai075`K@1cMg80PH1m08F0OP1dMW@0NgQf07AaK`1lNGL0LgEc07]jM`1fMG80LG1]06m^
J`2:RHH0NGQe07EdL@1UHV00KFYZ07MiM`1oQH80N7Yf06ISH@1kNWT0MWA`07UfM01kNWL0JfYW07Eb
L01]L780L7Ic08F0OP1^L6`0LgEa07ikN@1HDT/0PH1o0080Lg9_00P0Ngil071cL@1eMg80MgE_07R4
O@1cLVl0NGIf071_K1l0oooo0100Y:BT09jNWP2PX:00]kNg0;Vi^@2HV9P0_kno0;Vi^@2m_Kd0alO7
0;fm_@2o_kl0_Kfm0;6a/@2TY:@0^KVi0P2_[jl02P2a/K40]kNg0;Ng]`2[Zj/0ZZZZ0;^k^`2e]KD0
]kNg0:n_[`2g]kL20<71`@0[0;Fe]@2k^k/0]kNg0:n_[`2e]KD0^KVi0:f][@37alL0[jn_0;>c/`2g
]kL0alO70<?3``2a/K40]KFe0;fm_@2a/K40_Kfm0;no_`2e]KD0/k>c0;Ng]`2i^KT0Z:RX0:ZZZP2_
[jl0_kno0;6a/@2k^k/0/k>c0<71`@2_[jl0Z:RX0;^k^`2c/k<0`l?30;fm_@2_[jl0`l?30;no_`2a
/K40e]KF0:JVYP020;6a/@0N0<G5a@2k^k/0[Jf]0<71`@2i^KT0`L710;fm_@33`l<0alO70;Vi^@2m
_Kd0`l?30<W9b@3Cdm<0]kNg0:ZZZP2k^k/0_Kfm0<o?c`3AdM40`L710<o?c`2i^KT0Z:RX09bLW02k
^k/0]kNg0<?3``2m_Kd0^KVi6@3oool001L0oooo01<0KG=`06Y]J`1[KV`0MgYh07QkN@1WJfH0NgUk
07QeM`1jM7L0Ogim07AfM01kOG/0NWaj07AgM@1]JVX0N7Yh07=eL`1cMG40M7Ib0080MgUe03<0LGE`
071bKP1fKfh0M7=`07MfL`1cLW40MgIc07elN@1lOW`0MW1a07UkN@1cMG<0PHB207IiM`1hNWP0Ogal
0860O`1cMG<0MGAa07MfL`1mO7T0MWEb07AdK@1fMW40M7=`07YiMP1jO7P0Ngei07EdL@1gMW<0PX60
07QgM01_KfX0Lfi/07]jM`1lNgP0M7=`07EbL01lP7X0OWUf07=eL01iN7D0MGMe07eoO@1nP7h0NWUf
07emN01kNgH0LW9]07AdK`1^JfT00P1dLFl07P1jO7L0NGaj079bJ`1lNGL0NGeg07QhL`1jNGH0OGai
07mnN`1cMG40NWah07elN@20PWh0MGMc07MdLP1`KF/0NGMi07YhNP1lP7/0Q8b607akN023PWl0N7Yf
06maK@1YJfT0NG]i07MkMP1mNWP0NWQd07QgMQl0oooo00@0]kNg0;Vi^@2e]KD0Z:RX0`2_[jl0502R
XZ80[Jf]0;6a/@2k^k/0/k>c0;Vi^@2g]kL0_kno0<?3``2FUYH0]KFe0;^k^`2i^KT0aLG50;Vi^@2_
[jl0^k^k0;Ng]`2a/K40[jn_0P2g]kL0=P35aLD0_kno0:BTY02k^k/0Zj^[0:f][@2e]KD0Y:BT0;Vi
^@2g]kL0[Jf]0:ZZZP2a/K40aLG50:f][@3?cll0/K6a0:n_[`2k^k/0]KFe0<O7a`2NWYh0_kno0;^k
^`20P800]kNg0;>c/`2PX:00U9BD0<71`@2c/k<0/K6a09bLW031`L40_kno0;Fe]@35aLD0dM7A0:JV
YP2i^KT0_Kfm0:ZZZP2VYZH0U9BD0;Vi^@2m_Kd0`l?30;>c/`2<S8`0]kNg09RHV02TY:@0aLG50<O7
a`80]kNg01@0^k^k0<O7a`2_[jl0_Kfm0<O7a`2m_Kd0h^;R0;fm_@2e]KD0cLg=0<71`@33`l<0[jn_
0<_;b`2ZZZX0]KFe0<71`@2a/K40bLW90;^k^aT0oooo000G0?ooo`0k07MfM@1hNWP0MWQf06maK`1c
MG<0Lg1^07=kM`1/Kfd0LW5`07AgM`1fN7H0MGAc07QfLP1gNW80Ngek07ejN01VJVD0MWMh07UjN`1`
LW00OX1n07QeM`1cL700MgIe07UhM`1dMGH0LgEc07MfM@1nPGl0OW]i07]hMP1]JVP0LFi/07QgM01b
LFh0MWQc07QjM@1aLfl0MgUe079dL01`LVh0OWel07UhM@1bJFd0PgYl07=aK@1gMG40NGUb07IeLP1Z
K6P0NgYg07]oNP1iN7D0FeID07E`KP1[KF/0LG=a06EWI@1eMg<00P1dLg00:`1YJ6D0Ng]f07IdL01n
OGX0LgEc08B1O`1hMW80NWQd07UgL`1`JfT0IF]V07QjMP1jLg80OWI`07EbL01QHel0Mgeh07inN@1W
If80OWej07mnO@1gNGD0PXB007UhM`1oOWd0Lg9_081oO01oPGl0NWQd08f;Q`1jN7@0Kg1a089lM@1l
OWT0OGmj07=cKP21PG`0L79^07IhM01lNgP0M7=`081kN@1iM7807`3oool0102][Jd0bl_;0;6a/@2[
Zj/20;Vi^@080<W9b@2a/K40/K6a0;>c/`2LW9`0^k^k0;6a/@2m_Kd20:^[Z`0O0;Fe]@2[Zj/0]KFe
0;Fe]@2i^KT0^k^k0<?3``2i^KT0^k^k0:n_[`2PX:00[jn_0:ZZZP33`l<0]KFe08R8R02m_Kd0SXj>
0;Vi^@2g]kL0^KVi0<71`@2[Zj/0^k^k0;Ng]`2_[jl0X:2P0:n_[`2e]KD0]kNg092@T0020;6a/@0K
0:^[Z`2i^KT0^k^k0;6a/@2i^KT0/K6a0<_;b`2o_kl0cLg=0<O7a`31`L40]KFe0<?3``2e]KD0_kno
0<?3``2k^k/0cLg=0;no_`31`L40_kno0;>c/`2_[jl0_Kfm0;Fe]@2a/K40]kNg0080ZZZZ01<0]kNg
0:^[Z`2k^k/0^KVi0;Fe]@2i^KT0cLg=0<?3``1iNGT0clo?0<?3``2o_kl0`l?30<O7a`3;bl/0[jn_
09bLW02HV9P0Zj^[0080[jn_00H0]kNg0:f][@39bLT0_Kfm0<O7a`3EeMDI0?ooo`005`3oool06@1`
Lg40N7ik07IaK`1lNGL0LgMb07EgM@1bL780N7Mf07IeLP1cMg80MG=e06maK01aM780Jfe[07AfM01n
P7h0N7Yf081oO01_KV/0MgIe07imO01fMG80M7=`07EgM@1^L6h00P1fMG80801^L6h0Ngek075cL@1h
NWP0LWAb08:4PP1dM7T0PX24081oO01iN7D0J6aW079fL@1fNWD0L7A_07EbL01`KF/0M7=`071_K01f
MG80NWUf079aL01hMgH0NGQe07QgM01hNWD0P7Ug07QhL`1`KF/0OGYj07UlO01TKfl0LGIh0P1fLg40
5`1gM780Ph1n07MdLP1gM780O7Ug07]oNP1oOW/0N7Md07EdL@1cMG40E5=@07EdL@1dLg00M79d08N9
Q@1jOWT0OX9m07EdL@1jNGH0NWaj07=fM020P7/0MWEd0080LVm]00<0Mgeh06i]JP1kNWL00P1kNWL0
3@1eM740O7]h07IeLP1cLVl0N7Md07mnN`1eM740Lg=^07UiM01eM740NWUf08J6P@1iNG@07`3oool0
6@2ZZZX0^KVi0;Fe]@31`L40[jn_0;>c/`2][Jd0^KVi0;Fe]@2_[jl0WYjN0:RXZ02[Zj/0X:2P0;6a
/@35aLD0^KVi0<W9b@2XZ:P0Zj^[0<G5a@2e]KD0/K6a0;Ng]`2c/k<00P2e]KD01P2VYZH0_kno0:^[
Z`2i^KT0[Jf]0;no_`80cLg=01d0bLW90=?Cd`2k^k/0[Jf]0;Fe]@2ZZZX0Zj^[0;>c/`2a/K40ZZZZ
0;>c/`2e]KD0[Jf]0;Vi^@31`L40^k^k0;Vi^@39bLT0^KVi09BDU02ZZZX0`l?309:BTP2o_kl0Zj^[
0;Fe]@2g]kL0dM7A0<o?c`020;Ng]`0C0;no_`2XZ:P0alO70;Vi^@2_[jl0_Kfm07=cL`2c/k<0/K6a
0;no_`3Fe]H0_Kfm0<G5a@2m_Kd0^KVi0;fm_@2_[jl0bLW90=[JfP020:f][@030;Ng]`2BTY80_kno
0080_kno00d0/k>c0<?3``2e]KD0[jn_0;Vi^@37alL0/k>c0:n_[`2k^k/0/k>c0;fm_@3EeMD0^k^k
01T0oooo000G0?ooo`0Q06e_K@1hNWP0MGMe06U[J@1eMgD0MWUg07AfM01`LW00MGMe075cL@1dLg00
OGai075`K@1iNgT0MG]h07=bL@1iN7D0Ng]f07anO01gLG80Ogim07YiMP1iN7D0P7mn07egN01fMG80
LG1]07UhM@1hMg@0NG]i07anO01fN7H0NG]i0080MgIc02d0KVeZ081oO01XIV00EeE?085nO01/JfP0
Kfi[07akN01_KfX0NWUf07ehM@1nNGH0MgIe07=bL@1fMG80OWej075cK`1hNWH0NG]g07MfL`1fLFl0
OGQf07]fM01gMW<0MWEb075`K@1dLg00O7Yl07MiM@1jO7P0K6iZ0822OP1cLW40N7Yh07AgM@1eMg<0
OWMf07IcL@1`MW40Ngei07=gLP1kOgX0NGeh07YhM01kNGD00P1iMW@05P1eM740M7=`07MfL`1iN7D0
MgAb07YiMP1IF5D0O7]h07n1O@1gLf/0CdI607MfL`1jMgD0P7ek081iM`1cKV/0JfYW079aKP1iN7D0
MgUe075`K@21P7dO0?ooo`0Z0:BTY02i^KT0/k>c09bLW02c/k<0]KFe0;6a/@2ZZZX0/k>c0:^[Z`2i
^KT0`l?30:^[Z`2k^k/0/k>c0:n_[`2k^k/0_kno0<71`@2m_Kd0alO70;fm_@2k^k/0]kNg0<W9b@2e
]KD0Zj^[0;^k^`2g]kL0^k^k0<71`@2e]KD0[Jf]0;^k^`2g]kL0YZJV0:ZZZP39bLT0NGUi0<_;b`2R
XZ80Zj^[0P2XZ:P01@2m_Kd0`L710<?3``2g]kL0[jn_0080]KFe00<0aLG50;Vi^@2k^k/00P2g]kL0
6@2e]KD0_kno0;fm_@2g]kL0]KFe0;6a/@2[Zj/0`L710;Ng]`2m_Kd0bLW90;fm_@2_[jl0^KVi0;>c
/`2XZ:P0aLG50;Fe]@2ZZZX0alO70:n_[`2o_kl0^k^k0;no_`35aLD00P2k^k/02@2c/k<0bl_;0;Ng
]`2k^k/0]kNg0<?3``1mOGd0`L710<O7a`030;Ng]`0:0;fm_@39bLT0bLW90:n_[`2PX:00[Jf]0;^k
^`2g]kL0Zj^[0<_;baT0oooo000G0?ooo`1707MiM`1ZKVT0Kfi]07elN`1bLG00O7Ug07mmO`1iMgT0
M79d071^L01fLFl0MGUd07EbL01kNWT0M7=b079_K`1kN7P0L79^07YnN@1eMWL0LgAe07=fM01jO7X0
MWQf07n1O`1kOW`0M7Me0860O`1lNgX0MgIc07IeLP1jNGP0MWIa07YlN01nP7`0NG]o07]nOP1`JfP0
LVeZ06m_JP1]KfX0M7=`06i]JP1lNGT0K6UY07UkM`1dMW80NGMc07MeL@1nOWT0OGak08:1P021P7l0
N7Mf07AcLP1bLFh0NgYg07IeLP1fNGL0NWMe06AVHP1fNWD0M7Ib07UkM`1oPGd0MgUe081mN`1eN7H0
MgUg07IeM021OW`00P1jMG007`1lMg80NWah0860O@1jNGH0OGai071_K01bLFh0PGin07]fL`1nOG`0
MWEd07=bK`1mO7T0MgUe07YlN01kOG/0MgUg07UkN@1kOG/0N7Md081oO01kPG`0N7=a07ikN@1`KF/0
UYJA07MbK@1fNGL0N7Ee07UkN@1_LFl07`3oool0:P2g]kL0ZZZZ0:f][@2a/K40^KVi0;^k^`2c/k<0
^KVi0;>c/`2a/K40]KFe0:f][@2a/K40]KFe0:BTY02a/K40cLg=0;6a/@2g]kL0^KVi0;fm_@2NWYh0
]kNg0<71`@2XZ:P0^KVi0:ZZZP2o_kl0`l?30;Ng]`2e]KD0clo?0;Fe]@2c/k<0/K6a0;Fe]@1oOgl0
]kNg0:f][@2XZ:P0]kNg0<g=c@80_kno02X0^KVi0:JVYP2_[jl0[jn_0;Vi^@3=cLd0`l?30:f][@2X
Z:P0U9BD0::RXP2k^k/0Y:BT0:JVYP35aLD0^k^k0:^[Z`2RXZ80`L710:ZZZP2g]kL0g]kN0<G5a@2]
[Jd0W9bL0:^[Z`3Ng]h0_Kfm0<O7a`3?cll0]kNg0:f][@2a/K40_Kfm0<_;b`2XZ:P0/k>c0<g=c@3C
dm<0`l?30;Vi^@2c/k<20<?3``0?0=[JfP33`l<0`L710;6a/@2g]kL0aLG50:n_[`2m_Kd0_kno0<G5
a@31`L40Zj^[0;fm_@2k^k/0]kNg0080`l?36@3oool001L0oooo05H0Mgej071bL01bM780M7Id07Qj
N01iNgT0MGMc07QjMP1eMg<0M7=`06U[I`1bM700M7Ib07IhMP1]Kfd0M75_089mN`1dLFl0MgIc079_
K`1jMgL0JVMU07MdLP1_LF`0MgUd07QnN@1`LVh0NgIc07eoNP1gMWD0MWEd08>0OP1eLW00N7Md07Ac
LP1fM700MgAd07IfL@1bKFX0KfeY07MgLP1kNGD0N7=`07]jM`1hMg@0Lfi/07E`KP1cLVl0N7Md07el
N@1bM700Ng]b06m]J@1UGf00NG=^06eaK01fMG80KVUW07UiM01aL6d0NWUf06a[J01`Kf`0Mg9`08^8
QP1eM740OX2406UVI01aKV`0MW=a08^:Q`1oOgX0Ph=n07MgLP20PWd0M79^07YhM021Og/0LW9]06m`
L@22PH00QHB307eoN`1kOGT0MGMb07eoNP80OGai00h0OGmk07b0N`1dMW@0MgIc07ilN01cLFd0NWaj
07]nMP1nOGX0O7]h075`K@1jMgD0NG]g07MiM@80OGai7`3oool02@2][Jd0[jn_0;no_`2i^KT0]kNg
0;>c/`2e]KD0^KVi0:n_[`020;Fe]@060::RXP2[Zj/0Zj^[0:n_[`2ZZZX0Zj^[0P2c/k<0202m_Kd0
[jn_0:RXZ02o_kl0YZJV09:BTP2c/k<0]kNg0P2m_Kd0502e]KD0_kno0;Vi^@2][Jd0ZZZZ0<G5a@2V
YZH0Zj^[0<G5a@2_[jl0^KVi0;no_`2k^k/0`L710;no_`2g]kL0W9bL0:n_[`3Cdm<0bLW90P2e]KD0
9@35aLD0XZ:R0:RXZ02BTY80X:2P0;Fe]@2g]kL0Y:BT0<O7a`2o_kl0bLW90:f][@2_[jl0W9bL0;Fe
]@2FUYH0/K6a0;no_`33`l<0^k^k0;no_`2a/K40`L710<O7a`31`L40/K6a0:JVYP2_[jl0_Kfm0:RX
Z02PX:00^KVi0;Fe]@3;bl/0_Kfm0;Fe]@2i^KT00P2m_Kd03`2o_kl0_Kfm0;^k^`3AdM40[jn_0::R
XP2_[jl0`L710;>c/`33`l<0`L710;^k^`2i^KT0bLW90;^k^`0I0?ooo`005`3oool0=01_LFl0NgYi
07EcM`1eLgL0QH>707YlNP1jOG/0LWEc07EhMP1hMg@0N7Ec07UkN@1gNWX0M7Id07=eL`1gNGL0KFm]
07QjN01dMW@0NGIf07MiM`1lNGT0MWQf07EfM`1dMGH0NGQg07=eL`1fN7H0O7il07IiN@1fN7H0O7il
07AfM01nOGX0MgIc07IeM01[JVT0Ngil07MfM@1_JF`0L6e_07=`L01^KF`0Kg9`07=]KP1kOG/0O7]j
07elN@1cLVl0L6m/07MfL`1nOGX2075`K@0b075gM01_KV/0M7=`07YiMP1jO7P0M7=`07UhM@1`Kf`0
MG1^07]jN@1oOWd0Lg9a07YgM@22QX40Ngei07IeLP1cMg80Mg9`07MkMP1^JfT0OGYh08B2OP1mO7T0
QXR607iiM`1mN7H0PH1o07elN`20Og`0O7]j07]iM@24PWh0P7ek07]hMP1iM780QHN30820N`21P7l0
NWQj07MaM01nOG`0M7=b07mhM`1MF5H0Kg1a07QjN01hMG<0N7ag08>2P@1eM7<O0?ooo`050:RXZ02o
_kl0/k>c0;>c/`3Cdm<00P2m_Kd00`2][Jd0/k>c0;Vi^@020;^k^`0A0;Ng]`2a/K40[jn_0;Ng]`2T
Y:@0^KVi0;6a/@35aLD0]kNg0<71`@2e]KD0`l?30;>c/`2k^k/0[jn_0;Fe]@2g]kL00P2e]KD05@31
`L40Y:BT0;6a/@2g]kL0]KFe0:^[Z`2PX:00]kNg0:RXZ02ZZZX0]KFe0:n_[`2XZ:P0[jn_09RHV02o
_kl0`l?30:n_[`1oOgl0ZZZZ0;Ng]`020:^[Z`030:BTY02[Zj/0Z:RX00<0_Kfm00`0/K6a0:ZZZP2i
^KT0/k>c0;no_`37alL0_Kfm0;Ng]`3=cLd0_kno0:n_[`3?cll20;Ng]`050:JVYP2i^KT0dM7A0<?3
``3EeMD00P33`l<04`3;bl/0`l?30<W9b@35aLD0_kno0=7Ad@39bLT0e]KF0;^k^`3Cdm<0bLW90<_;
b`3Hf=P0]kNg0<G5a@2a/K40alO708B4Q02XZ:P00`2i^KT00`3?cll0/k>c0?ooo`0H0?ooo`005`3o
ool00`1[K6d0MGAc07UhM@0207QgM00f07imO01eMgD0M7Id07YlNP1gM780Ngek07anO01`LW00M7Id
07IhMP1hN7<0O7]j07QkN@1hNWP0O7Ug075^K020NgP0Oh:007]mN`1iNgT0O7Ui07YdM@1jNGP0OX5o
07MdLP1oNWD0MgUg07EgM@1cMG<0LVm]07YjM@1lO7L0Kg5]07YiMP27QXD0PX5n07MdLP1jNGH0L6iZ
07agLP1mOGP0NWUh07imNP1OGU/0OG]g07QgMP1aMFl0MGE`07EcK`1hMg@0O7Ug07MfL`1gNGD0LG1]
0P1iN7D03P1hMg@0HV5P07MfL`23PWl0NWMe089kN@24PH40LVm_06MUH@1hMg@0OWig07elN@1oOGl0
O7ag0`1hMg@06P21P7d0NgYg07MfL`21P7d0MgIc075`K@1dLg00MgIc07UkN@1mO7T0O7ij08:3Q021
Ph40P89m089oO@1ZK6P0NWUf079aKP1lMG<0N75b08J6P@1mOGP0N7Md07imNP21O7L0NgIa7`3oool0
0`2PX:00/k>c0;^k^`020;Vi^@0<0<G5a@2c/k<0/K6a0;fm_@2g]kL0]KFe0<71`@2ZZZX0/K6a0;Fe
]@2i^KT0`L710`2i^KT01P2[Zj/0bLW90<O7a`2i^KT0_kno0<71`@80_Kfm01P0^k^k0;Ng]`37alL0
]kNg0<O7a`2c/k<0[Jf]0;fm_@33`l<0`L710;fm_@3Fe]H0cLg=0;^k^`2g]kL0ZZZZ0<71`@3EeMD0
`l?30<G5a@28R8P0/k>c0<?3``2i^KT20;>c/`070:RXZ02i^KT0`L710;Ng]`2k^k/0Zj^[0;^k^`02
0;Vi^@0=08j>SP2g]kL0clo?0<g=c@2c/k<0dM7A0:f][@2i^KT0_kno0<G5a@33`l<0alO70<G5a@03
0;Vi^@0J0;no_`2a/K40]kNg0<_;b`2g]kL0[jn_0;6a/@2g]kL0^k^k0;Fe]@31`L40cLg=0<_;b`39
bLT0clo?09jNWP2m_Kd0[Jf]0<71`@2i^KT0eMGE0<?3``2i^KT0aLG50<_;b`2o_klI0?ooo`005`3o
ool0C01/LW40Jfe[07=fM01]L6h0LWEc06a^JP1gNGL0MGMe06maK`1dLFl0NGIh07IiN@1cLG<0L7=c
07EiL`1hMWP0NWQj07]mN`1`LVh0Ph2206]`LP1cLFd0LG5/07anO01eMgD0Ogan07UgN@1dMgD0MGQf
07ekO@1jNGP0Ph5m07=eL01bM6l0OX1k07]hN01nPW`0PH>107MiM`1dLFl0Q85o07UgL`23PGd0LgEa
06e/J@1iN7D0PX5n07QhL`1gMG40NGMc07f0OP1lMgD0LGE`07AaK`1fLFh0NWag07]iM@20NgP0PWmm
07MiM`1kNWT0QhF107AcL01mOg/0O7ij08>2O`1mOgd0Ngmj07QgM01gM780LWIa07n1O@28Qh@0MW=a
085nO01gMG4207EcK`0J07UhM@1kNWL0P89n0822P01gMW<0MW=c07YlN026R8@0O7il07aiN@1oPGl0
KVUV07]kLP1mO7T0N7Ec07ikN@1mO7/0NgYi07aiM`21OW`0HEUE071bK@1fNG40MGEj07IiM`1dMW@O
0?ooo`0G0;6a/@2XZ:P0[Jf]0:f][@2i^KT0]kNg0;Vi^@2m_Kd0`L710<?3``3;bl/0_kno0;Ng]`2e
]KD0ZZZZ0;fm_@2c/k<0_Kfm0<W9b@2RXZ80[Jf]0;Ng]`2TY:@00P2o_kl0D02@T900[jn_0<g=c@2e
]KD0/k>c0<_;b`1gMgL0^k^k0;Fe]@37alL0YZJV0::RXP3AdM40ZZZZ0:n_[`2e]KD0_kno09RHV037
alL0XZ:R0:f][@2[Zj/0YZJV0;6a/@2o_kl0[Jf]0<71`@2c/k<0XZ:R0:n_[`2a/K40]kNg0;no_`2]
[Jd0Zj^[0<?3``2c/k<0^k^k0<?3``2@T900alO70;Fe]@2m_Kd0[Jf]0:RXZ02[Zj/0]kNg0;no_`2a
/K40[Jf]0:n_[`35aLD0/K6a0;Ng]`2a/K40W9bL0:n_[`2o_kl0alO70<o?c`2c/k<0]KFe0<71`@35
aLD0bLW90;6a/@2m_Kd0^k^k0:2PX02i^KT0bLW90>[ZjP22PX80aLG50<W9b@2o_kl0[Jf]0<O7a`35
aLD0[jn_6@3oool001L0oooo03/0M6m]06m^K@1bM780LWAb07QjN01gNGD0N7Mf07YiN01lNgX0OGYh
07UlNP1kOW`0MgYh07IhMP1`LW00NWaj07EhMP1jOG/0P7]h07MiM`1bM780MgUg06e_K@1kOG/0Kg5_
06=VIP1cMG<0PXB007n0P@1eMgD0PH1o05IHE01fN7@0GF1N07mnO@1^LgP0Q7ii08B3P01`Kf`0Lg5]
07IeLP1WKFX0L79`07mmN@1/JVH0LGMd07eoO@1^LV`0M7A_079fL@1lNgP0LG=_07EgL`1/KVX0M79^
07MhN@1kN7P0Ng=_075aK00207eoN`0[07EgL`1mOgd0Hf1N07mlNP1dLFl0MWQc079aKP1_KV/0K6]X
075aK01kMW<0M79^079bK@1hMg@0OWej07AcL01gMW<0O7ag07AgM@1cMG40Ngei07n2P01gNWP0MGAa
07IeLP1lMGH0Ngei081nNP1dKVL0NWMe07UfM020NW/0N7Ee081nP02ASh/0G5eA07igN020NgT0NgYg
079aL01oOWd0OWah07=bL@0O0?ooo`0;0;>c/`2a/K40^k^k0;Ng]`2PX:00^KVi0:n_[`2e]KD0`l?3
0:^[Z`2g]kL00P2i^KT06`2][Jd0_Kfm0:JVYP2PX:00Jf][0;^k^`2c/k<0_kno0:n_[`2i^KT0]KFe
0;Ng]`2a/K40[Jf]0;6a/@35aLD0/k>c0<?3``2g]kL0_Kfm0;Fe]@3Hf=P0]kNg0:ZZZP2a/K40alO7
08J6QP020;fm_@0/0;Vi^@2VYZH0Y:BT0;6a/@2XZ:P0/K6a0;>c/`35aLD0[Jf]0;6a/@2c/k<0Zj^[
09BDU02_[jl0_kno0;^k^`2g]kL0]KFe0=?Cd`37alL0bLW909:BTP3=cLd0ZZZZ0;Ng]`2[Zj/0cLg=
0;>c/`2o_kl0[jn_0;no_`2k^k/0/k>c0;fm_@2k^k/0]kNg0;^k^`2m_Kd0]KFe0<G5a@2o_kl0_Kfm
0<o?c`3=cLd20<71`@040;no_`31`L40_kno0<71`@<0alO700X0_Kfm0<O7a`3Fe]H0/K6a0;no_`31
`L40/K6a0;fm_@2k^k/0_kno6@3oool001L0oooo01/0LFi^079_K`1iMW@0MGAa06IUHP1eM7<0Lg1b
07=dM@1XKVd0LG1_07UfMP1`Lg40Kfi]07=bK`1hMg@0OGai07EdL@1[JVT0O7]h07imNP1jO7P0NgYg
081oO01cLVl0KVeZ07MfM@1oOWd00P1kNWT05`1bM780NG]i07imNP1_KV/0MW=a089oO@1fLFl0M7=`
06aWI01aIV<0KV]Y07=`KP1YJ6D0M7=`07aeM01fLg40MGAa07mnN`1gMg80NWYe07ajMP1hMW80K6]X
0080M7A_01X0NGMc071]J`24PGl0MG9`07]fL@1iN7D0Q8>006i]JP1bL6`0PGil07=`KP1]JVP0Mg9`
05mNF`1lNgP0MgIc06m^K@1hN740LW9]06i]K01_K6X0PX5n07MgLP21PG`0P7ek07EbL080OGai01H0
OWii0820N`1eLW00NgQf07YgM@1aKV`0NWUf06UXI@21O7X0NGQe08J3P@1iN7D0Lg1`075eL02DSXT0
OGQc07UbL@1aLfl0RHR507UhM@1lMg@0MWA`7`3oool01P2[Zj/0[Jf]0;^k^`2c/k<0UYJF0;>c/`80
[jn_00X0VYZJ0:^[Z`2k^k/0ZZZZ0:RXZ02_[jl0^KVi0<?3``2c/k<0X:2P0P31`L40802m_Kd0_kno
0<W9b@2>SXh0[jn_0;Ng]`37alL0_kno0<71`@2][Jd0^k^k0<G5a@31`L40Z:RX0<g=c@2e]KD0alO7
0;6a/@2[Zj/0YZJV0:n_[`2m_Kd0W9bL0<71`@2e]KD0ZZZZ0;>c/`2g]kL0_Kfm0:RXZ031`L40^KVi
0P2a/K406`2>SXh0^k^k0:ZZZP2c/k<0cLg=0;no_`2k^k/0YZJV0<W9b@2][Jd0bl_;0:n_[`2g]kL0
/k>c08R8R031`L40Z:RX0:ZZZP2i^KT0[Jf]0:JVYP2c/k<0cLg=0;Ng]`3;bl/0/k>c0;no_`020<?3
``0F0<G5a@39bLT0/k>c0;no_`2m_Kd0/k>c0;fm_@2LW9`0bl_;0;^k^`2o_kl0^k^k0:n_[`2[Zj/0
l?3`0<?3``2k^k/0Zj^[0=[JfP2k^k/0`L710;Fe]AT0oooo000G0?ooo`0d075dLP1cNgL0MGMe07Uk
N@1eMgD0O7il07UkN@1jO7X0MWQf07]jN@1eMgD0LWAb07=eL`1]MG40I6MU07AfLP1eNG@0LgUd06ib
K@1iNgT0LG=a07mlNP1kNWL0N7]i075cL@1bM780NG=d07]mN`1fN7H0M7=b07imO01cMG<0N7Yh07Qe
L`1jMgD0KfQV071[J01lMG@0L7Mi06]ZI`1dMW80PH5l07akNP1fMG80NWUf07=gLP1gNgH0MG9`07Qe
L`1]K6T0NgYg07MfL`80M7=`0380L79]08R5P`22Ogd0MG9`07MeM`1_Mg40N7eo07EiM01oOGT0OH20
07EgM@1ZJ6@08R4P07]jN@1oOWd0LW9]07YiMP1dN7<0KW9]07YnN@1hMg@0O7ag079bK@1mOGP0Ogaj
07akN01hO7L0NWUf07]fM01fMG80N7Yf08>5P@26PGl0N7Yf07QgM01kOGT0MWEb0860O@1lNGL0M75_
06a[J01gM780I6IT081mN`1jNGH0Shj;08:1OP1[JVL0LgUf07IlNAl0oooo02D0Zj^[0:n_[`2c/k<0
^k^k0;>c/`31`L40^k^k0;fm_@2e]KD0_kno0;>c/`2][Jd0[jn_0:BTY02BTY80/K6a0;>c/`2_[jl0
YZJV0;Vi^@2[Zj/0alO70;no_`2g]kL0^KVi0:f][@2k^k/0_kno0<O7a`2a/K40aLG50:n_[`39bLT0
^KVi0;fm_@2XZ:P0_Kfm0080ZZZZ00d0X:2P0;6a/@2ZZZX0bl_;0;Fe]@2m_Kd0]kNg0:n_[`2c/k<0
^KVi0;Ng]`2TY:@0_kno0080/K6a00d0YZJV0:ZZZP3Hf=P0/k>c0<_;b`2g]kL0Z:RX0;>c/`2k^k/0
alO70<?3``2c/k<04A4A0080_kno00D0alO70;fm_@35aLD0/K6a0:JVYP020;fm_@0M0<71`@2][Jd0
`l?30<71`@2e]KD0^KVi0;fm_@2o_kl0aLG50;Vi^@3?cll0eMGE09JFUP2i^KT0_kno0;Fe]@3;bl/0
_kno0;6a/@2RXZ80]kNg09:BTP39bLT0_Kfm0>KViP3=cLd0X:2P0:n_[`2e]KD06@3oool001L0oooo
03/0LVic07AbM01bKfd0NWah07=gLP1hMgH0MWQf07AfM01fN7H0Ngek07AgM`1`Lg40NWii07YiN01g
MWD0L79^079_K@1fN7H0MgUg07j0OP1jOG/0M7Yi07=bK`1gNGL0MGAc071fL`1jOG/0N7Md07MeM`1g
NGL0MWQf08B7Q@1mO7/0NgId07elN@1jOG/0Ngil07YiMP1dLg00NW]l07MhN@1`LVh0KFm[07UjN`1l
NGT0JFQU079aKP1ZK6P0NWUf06m^J`1iN7D0MWQf07UbL`1cLfh0OWej06m`L@2>SHX0Kf]S07QgM002
07IaKP0[07mjM`1kNG/0RXb:07elN`1UHel0MWQf06e[I`1iN7D0N7Yh06i`K01cL6h0N7Ec07YgM@1g
NGD0MWEd07MfM@25Q8<0N7Qc07UiM01kMW@0OGYh07QjMP22Ogd0KFaY07]mN@1iN7D0OGIe071_K01m
NWP0OGQe07]iM@1oPG`0MgMb06i`KP21Ph40M7Ib07MiM@26PG`0LfiY07ilN01oO7`0Ogaj06m^J`0O
0?ooo`0<0:f][@2a/K40[Jf]0;fm_@2_[jl0^KVi0;Fe]@2a/K40]KFe0;no_`2XZ:P0ZZZZ0P2m_Kd0
4`2g]kL0ZZZZ0:f][@2e]KD0]kNg0;>c/`2m_Kd0/K6a0:n_[`2k^k/0]kNg0:ZZZP2m_Kd0^KVi0<O7
a`2g]kL0]KFe0=7Ad@2m_Kd00P33`l<0402m_Kd0bLW90;no_`2a/K40_Kfm0;Ng]`2a/K40ZZZZ0;^k
^`31`L40]kNg09bLW02NWYh0_Kfm0=7Ad@2XZ:P20;^k^`030:n_[`2HV9P0aLG50080Z:RX01X0]kNg
0;Vi^@2e]KD0alO70<W9b@2o_kl0g=cL0<?3``2e]KD0_Kfm0:BTY02k^k/0YZJV0;>c/`2_[jl0^KVi
0;fm_@31`L40]KFe0;Ng]`3Cdm<0^k^k0:JVYP2o_kl0`l?30;Vi^@80Y:BT00@0_kno0;^k^`2g]kL0
ZZZZ0P33`l<02P2o_kl0cLg=0;Ng]`2VYZH0bl_;0;6a/@2g]kL0eMGE0:n_[`35aLD20<O7a`030:RX
Z03oool0oooo01L0oooo000G0?ooo`0P06UZJ`1cMG40LGE`079dL01mN7H0NGIh07AfM01cMG<0KW1^
07MmNP25PhD0NgQh07E`KP1kN7P0NWah07MfL`1dMW@0N7Yf06maK@1cLW40NWUh07QjN01iNgT0OGYj
07AfM01iNG@0NgYi07=iMP21P7l0NG]g07n1O@1bMG<207IeM00b071_K01_LVH0LVa]07ihN@1_JVP0
Kfi[08>2O`1iM740OGYj075dLP1gNGL0N7Ec07elN@1iN7D0PH1m07YiMP1jMG<0QXB007QcL01dK6X0
LgEa08J8QP1^KF`0MGAa07QfN024OWT0LFaZ081nP02:R8@0Ogim079dLP1eN7H0KfYW07anNP1`LVh0
MWQd07UfMP1iNgT0NgYg07QfL025QXL0N7Ec07EdL@1fN7@0O81j07emN01iOGL0OX9l07=bK`1bLFh2
07]mN00B075`K@1jNGH0N7Ye07YlM`1eMFh0P81i081nNP1aKf/0NGMi07aoO`1KDDL0M7=`07EhMP1k
NWT0L6m/06i]JP1`Kf`0MWEb7`3oool0C02PX:00_Kfm0:BTY02e]KD0^KVi0:n_[`31`L40Zj^[0;Vi
^@2k^k/0_kno0;6a/@2RXZ80[jn_0;6a/@2g]kL0/K6a0;Ng]`2_[jl0/k>c0;Ng]`2[Zj/0[jn_0;Fe
]@2VYZH0]KFe0;Vi^@2a/K40_kno0;>c/`2k^k/0Z:RX0=?Cd`2k^k/0^KVi0;^k^`31`L40X:2P0<O7
a`2i^KT0clo?0;no_`37alL0bl_;0:^[Z`2][Jd0]KFe0;Vi^@2ZZZX0^k^k0<W9b@2_[jl0_kno0;Ng
]`2e]KD0]kNg08j>SP2e]KD0bLW909ZJVP2c/k<0h>3P0<71`@2g]kL0^k^k0;no_`33`l<0]kNg0;^k
^`2g]kL0Z:RX08:2PP2VYZH0`l?30;no_`35aLD20;Ng]`0?0<71`@2i^KT0_kno0=?Cd`3Hf=P0eMGE
0<g=c@2g]kL0bLW90<?3``37alL0]kNg0<?3``2g]kL0aLG50080Y:BT00X0aLG50<71`@2a/K40Z:RX
09ZJVP3Cdm<0^KVi0;^k^`2m_Kd0/K6a6@3oool001L0oooo06P0JfYW07YlN01]JV`0MWMh07QkN`1c
M7D0O7il075cL@1hNWP0NG]i07IgN01dLg80K6UW07=fM01dMW80MgIc07AfM01gN7T0LgAe081oOP1g
MWD0LG=a07=eL`1^Mg<0LG=a07IdMP1hMg@0M6e^07imO01eMg<0NG]g06mbL01iN7L0NWMe07QlM`1i
P880JfeY07YgM`1oO7X0N7Md08>2O`1oOGl0NG]g0861O01aKf/0MW=a07UhM@1hMg@0L6m/081oO01c
MG40O7]h07]hMP1gL6l0MgAb069XK@1iO7`0MWEb06Q[J@1eNgX0PH>108b<Q`1gNGL0NGAa07]iM@1k
NgH0OG]g07UkM`1gNGD0LgEa06m/JP1^L6h0OGai07]iL`1YJ6L0MgAb07MfL`1lOWX0OGYh07QgM025
Q840R8N408J5PP1nOGX0MgAb081mN`1mO7T0Ogik07MeL@1mNgL0MgIc07imNP1kNGD0KF]W07j1O`1l
MWL0M7Mi06mZI`1XJVP0QHB307QgM01iN7D0NWUf07AcL1l0oooo00L0[Jf]0:^[Z`31`L40[jn_0<71
`@2TY:@0alO70080Z:RX00L0alO70:^[Z`2[Zj/0Z:RX0:BTY02VYZH0^k^k0080_kno02<0/k>c0;Fe
]@2a/K40Y:BT0:f][@2m_Kd0^k^k0;fm_@31`L40]kNg0;6a/@33`l<0aLG50=7Ad@3Cdm<0`l?30;>c
/`37alL0^KVi0;fm_@2a/K40_kno0;6a/@2o_kl0^KVi0;Fe]@37alL0bLW90:JVYP2HV9P0/k>c0;fm
_@2i^KT0YZJV0:^[Z`020;>c/`0@0:^[Z`2VYZH0]kNg0;Ng]`2i^KT0YZJV0;no_`2i^KT0/K6a0;>c
/`35aLD0[jn_0;Fe]@2TY:@0ZZZZ0;Vi^@80/K6a0140ZZZZ0:BTY02i^KT0^k^k0;fm_@3=cLd0alO7
0;fm_@2o_kl0_Kfm0<g=c@2a/K40^k^k0;fm_@39bLT0_kno0<O7a`020<?3``0=0;fm_@2a/K40Y:BT
0;Vi^@2a/K40]kNg0<g=c@35aLD0[Jf]0:RXZ039bLT0/K6a0;Ng]`0I0?ooo`005`3oool0C01ZL6d0
MgQi07YiMP1eMgD0NGal07=fMP1mMgP0Oh5o06]dL01`MW<0LWAb07=eL`1kOG/0Lg1`07=eL`1bMG<0
NWUh07=fM01^L6h0O7]h07UlNP1aLg40MgUg075cL@1/KV`0MgIc06]ZI`1fLg40MgQi075dLP1iO7X0
L79`079dLP1[LFh0NGml07QgM01kNWL0LgUh06E]I`1mO7T0PX5n07QjMP1jO7P0LgUh07MmO01iNgL0
OGmk07EdL@1lNgP0JFQU079dL01lQWl0FEmJ06IXI01cLfh0N7Qc071`J`1oOgX0O7]h07mnN`1dLg00
OWej07QjMP20NGL0Kg5/07=cKP1nNGL0LgEc07anO01bM780MgUe079hL`1^M6l0Mgeh07YjM@1fMG82
07elN@0J07QgM01mO7T0OW]i089oO@1iMgT0NWQj07YlNP1iNgT0Ng]d07MeK`1lNGL0NGmj0822OP1m
Og/0O7]h07=gLP1eOW`0Ph1n08V4P@1aM7H0MgUe07QgM01cMG<0LWAb07UkN@1fMG8O0?ooo`0=09jN
WP2g]kL0_Kfm0;>c/`2k^k/0[jn_0<?3``37alL0X:2P0:ZZZP2k^k/0[jn_0;no_`020:n_[`0[0:f]
[@2m_Kd0[jn_0:JVYP2i^KT0^k^k0:^[Z`2g]kL0/K6a0:^[Z`2g]kL0X:2P0;Fe]@3;bl/0Zj^[0;^k
^`2ZZZX0]kNg0:f][@2k^k/0^KVi0<o?c`2o_kl0U9BD0<?3``3=cLd0/k>c0;Vi^@2_[jl0]kNg0;Fe
]@2k^k/0/k>c0<71`@2i^KT0W9bL0:f][@1mOGd0UYJF09RHV02_[jl0^KVi0<O7a`020<71`@060<O7
a`35aLD0YZJV0;Vi^@39bLT0Z:RX0P35aLD02@2_[jl0`L710;Ng]`2[Zj/0[Jf]0:JVYP2g]kL0clo?
0;Fe]@030<?3``0I0;Ng]`35aLD0cLg=0;^k^`2PX:00_Kfm0;^k^`2o_kl0^k^k0<71`@2k^k/0bLW9
0<?3``2o_kl0[jn_0;>c/`3?cll0f][J0:^[Z`2g]kL0^KVi0:n_[`2][Jd0^k^k0;Fe]@0I0?ooo`00
5`3oool02P1/JfP0L79`07IlN@1hNWP0M7=b07=dM@1gNGD0L79^07IhM01eMgD307MfL`0T06mbL01a
M780MG]h07AjM`1dNWD0LG5/07anN@1fNW@0IVQT07]mN@1_LFl0NGan07UoNP1aMG00O7]h07]jM`1a
Lfl0MgUe07moN01^LVd0NgUe079`K01[KFP0MgUd06ecKP1aMg80M7Id07UkN@1_LFl0M7=b07YgM`1b
LG00PX5n06i`K01^KFX0NgYg0P1hNWH0=@1dLg00IfIS06i]JP1eLW00NWUh07QgM01iNgH0N7Md079e
M@1hNg/0I6MW07akN01hNWP0KgMc07=eL`1kOGT0NG]i07=dM@1_Kg@0LgId07moNP1eM740LW5`07Mj
N01aMg@0MGQf07UhM`1gOGP0NGQe07=bK`1aLfl0L79]07EeL023PX40NGMc06abK`1hOW/0OG]g07Yi
MP1fNWD0O7]h07A_K01cMG<0NWUh06]ZJ@1fMG80QhJ30820N`24Q7l0OWej07UhM@1mO7T0MGE`01l0
oooo00X0XZ:R0:ZZZP2e]KD0^KVi0;6a/@2_[jl0]kNg0:ZZZP2e]KD0/k>c0`2g]kL00`2XZ:P0Zj^[
0;>c/`020;6a/@0P0:^[Z`3AdM40]KFe09JFUP2o_kl0`L710:RXZ02k^k/0Zj^[0<71`@2k^k/0Zj^[
0;Ng]`37alL0`L710:JVYP2][Jd0X:2P0;no_`2g]kL0Zj^[0;6a/@2k^k/0]kNg0:RXZ02m_Kd0[Jf]
09BDU03=cLd0YZJV0;no_`31`L420;Vi^@0509RHV02VYZH0[Jf]0;>c/`2m_Kd00P2k^k/02P2i^KT0
[Jf]09:BTP2o_kl0`L710;Vi^@2XZ:P0_kno0:n_[`2k^k/20:n_[`070;fm_@37alL0/k>c0:f][@2c
/k<0Zj^[0;>c/`020;^k^`0I0;>c/`2_[jl0Zj^[0:ZZZP2e]KD0clo?0;^k^`2RXZ80h>3P0<?3``2m
_Kd0]KFe0<71`@2VYZH0[jn_0;fm_@2PX:00]KFe0=KFeP39bLT0dM7A0<G5a@2k^k/0`l?30;>c/`0I
0?ooo`005`3oool0J01_Lfh0MWQf07YlNP1mOgd0Kg5_07AdK`1bNgL0LGMd07AfM01jMG80Kfi[07Mf
L`1iN7D0LG1_07YiN01kNWT0O7Ig06MTI01]JVX0LW1b07IdMP1nN7T0NWAe07]mN`1cMG<0O7Ui079d
LP1/KVT0LgEc075jMP1lPWl0N7ii07EbL01^Kg80MgUg07aiN@1aMg@0LgQj07]eMP1jN7@0Lg9_07Qn
O@1jO7X0P7ek06eZJ025P7h0MgIc07eoN`1kNWL0L6m/07MfL`1`L6/0LW9]07MgLP20NgT0OWUf07aj
MP1bLVd0NgYg08R8O`1mOGP0MGAc07egN01bKfd0NGQe0863O`21PG`0N7Yf07=eL@1]Kf/0N7Ye079d
L01MGe/0MWQd09>?Q`1[KV`0L7=a07]nO01gNGD0OGmk07QjN01jO7X0O7il07YlN025Pgl0M6YP07U^
J`1mP7h0NWii07eoN`1oOgX0MGE`08:0N01oOWd0OGef085lM`23M700MW5_07EhMP1dMgD0RhV507Yk
OP1oPgh0OW]i7`3oool00`2_[jl0XZ:R0:n_[`020;Fe]@070:^[Z`3AdM40aLG50:ZZZP2e]KD0/k>c
0;Ng]`020:n_[`060;Vi^@2m_Kd0`l?30<g=c@2g]kL0^KVi0P2o_kl0202i^KT0_kno0:^[Z`2m_Kd0
ZZZZ0;Vi^@3;bl/0^KVi0P2_[jl01`2e]KD0/K6a0:JVYP2ZZZX0`L710>c/k02a/K400P2e]KD02`2a
/K40bl_;0;Fe]@2][Jd0]kNg0<O7a`2_[jl0`L710:f][@2_[jl0Zj^[0080^k^k00H0/K6a0;fm_@2a
/K40/K6a0:f][@2k^k/20;Ng]`070::RXP2c/k<0]kNg0;fm_@2ZZZX0_kno0<W9b@020<G5a@0=0;6a
/@2i^KT0`L710<_;b`37alL0[Jf]0;Ng]`2c/k<0_Kfm0:RXZ02c/k<0_Kfm0;Ng]`020<G5a@0C0<?3
``35aLD0`l?30<g=c@2o_kl0aLG50:n_[`2[Zj/0U9BD09RHV02i^KT0[Jf]0;^k^`2m_Kd0`l?30;^k
^`2i^KT0VYZJ0:RXZ00I0?ooo`005`3oool00`1cMWH0K6iY07=hNP0207IkO@0_075gLP24PH40OWel
071cL@1fLg40M7=`07MfL`1cLVl0Lg9a07QgMP1jNWD0OGmj08:1P01gMWD0KFYX07]hMP1kN7P0N7Ee
075cL@1`LW00NWUh071cL@1hMW80OW]k07QeM@1cMG<0LgMb07AcL01nP7`0KW1^071bK@2BSHX0Ng=_
07AcL01fM700MWEb085lNP1cLFd0MWEb079aKP1oO7X0MgIc07=eL@1lNgP0Lg9_075`K@1gMW<00P1i
N7D0<P1jMgD0M7Ia07MiM01dMW40NGeh07MeN@1dLW@0MgIc07EmM`1gM780NWUf08>5P@1`L6/0P89n
07j0O01mOg/0OWUf07QjMP1lOWX0PH=o07YmO@1bLVd0MgMb07EeL01oO7X0NWMe07EgM@1jO7X0MgUg
07]mN@1nOGX0OGmm07j1O`1mNWP0PX5n07]hMP1nOGX0Lg9_07QoMP1UIf<0IfAR07QgM01bNWH0NGUb
07YjM@1mOGP0NGMa07QjMP1XIf@0KgE`7`3oool08P2TY:@0aLG50:JVYP2e]KD0/K6a09jNWP2e]KD0
X:2P0:n_[`2i^KT0[Jf]0;^k^`2a/K40ZZZZ0;Vi^@2o_kl0ZZZZ0;>c/`2e]KD0_kno0;6a/@2PX:00
Z:RX0;fm_@2][Jd0/K6a09bLW02ZZZX0f=SH0:BTY02i^KT0RXZ:0:f][@2ZZZX20=7Ad@0=0:^[Z`2m
_Kd0[Jf]0;6a/@2m_Kd0VYZJ0:n_[`31`L40^KVi0;Fe]@2g]kL0Zj^[0<?3``020:f][@0F0;^k^`2g
]kL0X:2P0;>c/`2m_Kd0Z:RX0=?Cd`2i^KT0U9BD0:^[Z`2<S8`0cLg=0;no_`31`L40_Kfm0<O7a`2Z
ZZX0alO70:RXZ02k^k/0`l?30<G5a@80/k>c00`0^KVi0820P02k^k/0ZZZZ0<71`@2e]KD0^KVi0<W9
b@37alL0h>3P0<?3``2LW9`20<G5a@060<71`@33`l<0`l?30<71`@2g]kL0WYjN0P2e]KD0202[Zj/0
_Kfm0<O7a`2m_Kd0Y:BT09JFUP2e]KD0ZZZZ6@3oool001L0oooo06P0N7Yh07IlM`1jO7X0MgUg07Ih
MP1jO7X0NgYi07AfM01/M700MGMe07UhM`1hNWP0L7=a07elN`20NW/0MGUc07YlM`1]Kf/0M7Qc07^1
OP1`MWD0J6][071cL`1eLfl0NWEb07]mN`1dMW@0MgUe06maK@1bM700Ngei07akNP1dMgD0OGYj07Eb
LP1kMGH0I6YW06Q/I`1bMW40O7]h081oO01lNgX0M7Me081mO`1mOGP0MGAa071_K01kNWL0OGai06mc
KP1fNWD0O7Yf07=aK@1fM700JfeY07UiM01lO7L0N7Qc07AfLP1kOG/0OGak07EcK`20Ogh0OWej08:1
OP1lOWX0Oh5m07]hN021OgT0NG]g07UkMP22QX40O7ij06eXIP1dKfd0N7=a06eTI01VJ6@0L7Qb07f1
O01lOgd0OGak075hN@1_LW80EeM@07=nP@1mPG`0MWEb07QjN01nOG`0KG=b07f0OP1`JfP0OGId05]D
B`1gKf/0QH:207=dM@1NGEX0NGQe081kN@1jNGH0FEaL0865P1l0oooo0180^KVi0;Fe]@2m_Kd0]kNg
0;Fe]@2m_Kd0_kno0;6a/@2RXZ80/k>c0::RXP2i^KT0ZZZZ0<?3``39bLT0/k>c0;fm_@2TY:@20;6a
/@0_0:ZZZP2JVYX0ZZZZ0;Ng]`2c/k<0_kno0;6a/@2g]kL0/K6a0:f][@2o_kl0`L710<O7a`2a/K40
/k>c0;no_`2i^KT0TY:B0:f][@31`L40bLW90<_;b`31`L40bLW90<?3``2a/K40/k>c0;no_`33`l<0
/K6a0:RXZ02e]KD0[jn_0;Fe]@2LW9`0X:2P0;^k^`2i^KT0`l?30;6a/@2o_kl0/k>c0:RXZ039bLT0
aLG50<g=c@37alL00P2o_kl0903;bl/0^k^k0:2PX03=cLd0`L710:BTY031`L40^KVi0:BTY02FUYH0
`l?30=GEe@31`L40`l?30:^[Z`3;bl/0NGUi0:n_[`33`l<0]KFe0;Vi^@35aLD0Y:BT0<?3``2VYZH0
`l?30820P02g]kL0dm?C0:n_[`26QXH0^k^k0<W9b@2m_Kd0OGem0<_;baT0oooo000G0?ooo`1X07Ag
M@1dMGH0MgUg07YlNP1fN7H0LgId06mcKP1bM700LW5^07AfLP1cMG<0NG]i079dLP1^L6`0MGMc07Ih
MP1YK6X0OX1n07MiM`1eNgP0KgEd07QfN01iMgT0NW]l07amOP1fNWD0Lfi/06UXI`1gMWD0LgEc07Uk
N@1eMg<0Gf5M07elN`23PX40Ngam07MhN@1iNgT0NWaj07n2P01gNWP0Lg5]07UhM`1nNgT0MW=a07el
N@1cLVl0NWii07f1O01lMgD0LWAb07MiM@1iNgL0Kg5]07QjMP1eMg<0LWA`07MiM@1fLFh0LW5^07Ac
L01cLVl0OH1n07YlNP1gNGL0OX1n08>5P@1nO7P0MWIa06maK01fNGT0LWA`07EgL`1gNGD0OGmm07Ec
K@1VI600LVm_07YiMP1iN7D0Ogik07ejN01hMg@0O7]h06i]K01gMGT0KV]Y075^K01mNgd0N7Ih07il
MP1<ASd0GFAS08:4O`1^J640GeiK0823Q@1fL6/0L6YU07IcL@1PHfD0Lg1^07YgM`1gNGLO0?ooo`80
/K6a00D0]kNg0;fm_@2e]KD0[jn_0:RXZ0020:f][@80/K6a03X0^k^k0:f][@2VYZH0/k>c0;Fe]@2L
W9`0aLG50;Ng]`2e]KD0Z:RX0;Vi^@2k^k/0`L710;fm_@2e]KD0[jn_09bLW02][Jd0[jn_0;^k^`2c
/k<0ZZZZ08R8R03?cll0_kno0:f][@2g]kL0_Kfm0<O7a`2g]kL0]KFe0:n_[`35aLD0]KFe0:JVYP33
`l<0_Kfm0<?3``2PX:00`L710:f][@2k^k/0Z:RX0:JVYP2i^KT0/k>c0;Ng]`2XZ:P0]KFe0:f][@2_
[jl0^k^k0<?3``2m_Kd0]kNg0<o?c`2_[jl0aLG50P2e]KD04@35aLD0[Jf]0;>c/`2g]kL0_kno0;>c
/`2FUYH0[Jf]0;^k^`2i^KT0alO70<?3``2i^KT0bLW90:JVYP2g]kL0YZJV0080`l?300l0^KVi0<G5
a@1SHf<0XZ:R0<g=c@2VYZH0R8R80<W9b@2e]KD0ZZZZ0;Fe]@2:RXX0[jn_0;fm_@2g]kL06@3oool0
01L0oooo0340K79a07=iMP1kOGP0OX1n071aM01WJFL0NGaj079dLP23PX40M7=b07EgM@1dMW@0Jfe[
07=eL@1`LVh0NWMg075^KP1kOG/0LG=a07UjN`1hNGX0MG9b07aiN@1eN7H0L7=a07UkM`20Q7l0LG1]
07AcL01]Kfd0OX1n07MjN021Q880BTe;07QjN01cL6h0M7Ib07b2O`21Q880MGMe07j0OP1kOGT0KFm[
08R4O01aLF`0NG]g07YlN028QX00L6m/0080M7Id03D0MGMe079dLP1ZK6X0Ng]d06Y`J`1/L6X0P8=k
07=fM01hNWP0NWaj07AfM01fMG80NWYe0861O024Q7l0MG=]089iN@26PWX0N7Yh081oO01`JfP0JfeX
07ajMP1cMg80M7Ib08V3O01nMgD0OGQf06abK@1^KFX0LgIf071dKP1iNG@0LW5^07UdLP1aLfl0M7]d
08j8O`1jMgD0MgAb06m/JP1jOg@0HVES06MXJ`1]JVX0JVaX07IhM01bLFh0LFaZ07n4Q`2=Thh0OGai
09>FV00O0?ooo`0b0::RXP2_[jl0_kno0<G5a@2ZZZX0V9RH0;^k^`2][Jd0clo?0;6a/@2][Jd0/K6a
0:2PX02_[jl0ZZZZ0;fm_@2[Zj/0_kno0:^[Z`2a/K40^KVi0;>c/`31`L40^KVi0;>c/`2k^k/0bLW9
0:^[Z`33`l<0Y:BT0<G5a@2g]kL0Zj^[0<_;b`2i^KT0[jn_0<71`@2a/K40bl_;0;>c/`35aLD0[jn_
0;no_`3Hf=P0Zj^[0;fm_@2k^k/0f=SH0:ZZZP2m_Kd20;6a/@0e0:f][@2NWYh0_kno0;no_`2NWYh0
bLW90;fm_@2_[jl0^KVi0;6a/@2][Jd0]KFe0;fm_@3;bl/0/k>c0:f][@3=cLd0eMGE0<W9b@35aLD0
ZZZZ0:2PX031`L40[jn_0;6a/@3Jf]X0aLG50::RXP2[Zj/0YZJV0:n_[`2ZZZX0`L710:f][@2k^k/0
Zj^[0;Fe]@3Ti>@0_Kfm0;Ng]`2XZ:P0X:2P08j>SP2HV9P0Y:BT09jNWP2e]KD0[Jf]0:^[Z`37alL0
h^;R0<?3``3^k^h06@3oool001L0oooo00d0MWMh07QgMP1cM7L0M7Id07EgL`1dMW@0MGQf07eoO@1j
NGP0LG1_07AfM01fN7H0LgEc0080KFm[02@0NWUh07UhM`1gNGL0Ngek07MdLP22Ogd0O7il07UkN@1e
M7<0NGQg07UoNP1hMg@0L6m/07elN@1iNgT0Ngek06]_J@1/L6X0KG1^07anO01`KF/0NWah07IhMP1o
OWd0OXB108:8Q@1ZK6P0MGMc08:0N01aLFP0M6m]07IhM01eNgX0MgUg081nNP1iMg<207]iL`0U07Ug
L@1eM7<0Kg9b07MhN@1iN7D0NWYe07YhLP1oOGL0LFmY08:4PP1mOGP0MWIa07alM`1bM700M7M_06QY
K01fMgP0O7]h07UfM01fNWD0Ph9o07MdLP1lNW`0NgIc07aoO@1hMg@0O7Me07YiN01gMG40OGmj07=c
KP1cLVl0Ngei081kN@1jO7L0L7Ie07=bL@0207IhM00<07EbLP1aKfT0FUUF07UgL`1]JVP0K6UW07Yl
N01kN7H0Mg]e07MjNP1hOWT0If1O7`3oool09P2XZ:P0/K6a0:2PX02_[jl0^k^k0;no_`31`L40alO7
0;Ng]`2[Zj/0_Kfm0:n_[`2k^k/0ZZZZ0::RXP2][Jd0^k^k0;Vi^@31`L40^k^k0;Vi^@2XZ:P0W9bL
0<W9b@37alL0]KFe0;^k^`2g]kL0aLG50:f][@2o_kl0^k^k0<71`@2DU9@0`L710;>c/`2k^k/0_Kfm
0P2e]KD08P3Zj^X0aLG50<W9b@37alL0Z:RX0:ZZZP2XZ:P0bl_;0;Ng]`39bLT0[jn_0;Ng]`2i^KT0
[jn_0::RXP2VYZH0^KVi0;no_`2VYZH0Zj^[0<G5a@3=cLd0`l?30;no_`3?cll0/K6a0;no_`3;bl/0
f=SH0;^k^`31`L40_kno0;^k^`2a/K420;no_`030<o?c`2m_Kd0bLW90080`l?301P0^k^k0;Vi^@2k
^k/0_kno0<?3``3;bl/0]kNg0<G5a@31`L40aLG50:n_[`2][Jd0]kNg0;6a/@31`L40bLW90;6a/@2i
^KT0]kNg0<O7a`33`l<0/k>c0;^k^`33`l<I0?ooo`005`3oool03`1fLg<0K6i/07EdL`1SIF<0LGAb
07]jM`20Og`0NGQe07MfL`1^K700LW]i071fM@1[K6d0Lg9_07elN@0207IhM00J06MTHP1jNGP0MgIe
071_KP1YJfL0OGai075^K01aLfl0MWQd07EdL@1cLVl0OWej085nO01oO7`0MGAa07MfL`1MGe/0M7=`
06]XIP1gNGD0NgId06a[J01NFeT0LgIh07EdL@1_KV/20820N`0Y07IeLP1mO7T0O7]h07YiMP1fN7@0
Kg5]06a^J@1kNgH0O7Yf07QfLP1mOGP0OWej085oP@1kNgH0O7]j07UdL@1gKfT0OgYh07IcL@1mNWP0
LVm]07]jM`1bLV/0N7=^07]eL01bLV/0P89m07]kMP25P7d0NWEb07inN@1hN7<0QHB107EeL01nOWT0
K6MT07YeLP1iLW00NWaj07UkN@1jO7X00P1mO7T0101oOWd0Lg5]07alM`1fMW4207=bK`0:07YcL@29
Pg`0KFUQ07I`J@1ZIfD0OWej08>1N`1]K6T0OX9m08:4P1l0oooo00l0]KFe0::RXP2c/k<0T92@0:^[
Z`2o_kl0bLW90;^k^`2g]kL0YZJV0;Fe]@2ZZZX0X:2P0:n_[`33`l<00P2e]KD06P2HV9P0_Kfm0;fm
_@2ZZZX0W9bL0<?3``000000Zj^[0;Fe]@2c/k<0[jn_0<71`@3;bl/0alO70;>c/`2e]KD0]kNg0;6a
/@2PX:00^k^k0;Ng]`2RXZ80QXJ60:n_[`2k^k/0/k>c0P39bLT0?02o_kl0]KFe0<71`@2m_Kd0bLW9
0;Fe]@2XZ:P0_kno0<71`@2VYZH0^KVi0<?3``3;bl/0]kNg0;no_`31`L40]kNg07emO@37alL0]KFe
0<?3``2o_kl0]KFe0:f][@2i^KT0[Jf]0;no_`39bLT0_kno0=?Cd`2g]kL0aLG50;Vi^@3Cdm<0aLG5
0=cLg02RXZ80_Kfm0;^k^`2_[jl0^k^k0;fm_@33`l<0Y:BT0<O7a`2_[jl0`L710;Fe]@2XZ:P0[jn_
0;fm_@3Jf]X0Y:BT0;Fe]@2NWYh0aLG50<o?c`2TY:@0aLG50<g=cAT0oooo000G0?ooo`1X07YmN`1_
LW00NWUf07akN01gMW<0OWej07anNP1iN7D0PWmm07]jN@1XJVH0MGMc07=eL@1eM740O7]h07QjN01l
OW`0NgQf07AaK`1aL6l0MWUg07EgL`1iNgL0M7Ef07MfL`1_LFd0LWA`071bKP1dMW80O7ij07QjMP25
Q840PH1m07akN01cLVl0J6ES07EbL01kNgH0MgYh08F9P`1gNgH0LW9]07IhMP1oPgh0LFmY06a[J01m
NWP0KFm[06]]J@1cNGH0MWUg07IcL@1hO7L0MgIc07=^J`1oN7L0M7af07ehMP1/LW40M7Qc07QdK017
BDL0N7Ib06]_JP23QH00M79Z07IfL@1`LVd0P89n07UkN@1nP7`0Ph=n079bK@1mOGP0MG=]07QhL`1f
MW40Ogmj07=cKP1gMg80O7Ia07MfL`1iN7D0PH1m07]nO023PG/0Mg5/07UkM`1bL6`0L6]X07A_K01b
L6`0NGQe079aKP21Og/0MWQc07=eL`1hN7<0O7]h07AbM01kN7P0O8B007MeK`1YIf<O0?ooo`0B0;fm
_@2XZ:P0_Kfm0<71`@2g]kL0aLG50<71`@2k^k/0cLg=0;no_`2][Jd0/k>c0:n_[`2c/k<0`L710;Vi
^@31`L40_kno0P2a/K40=P2e]KD0/k>c0;^k^`2@T900/K6a0:RXZ02][Jd0ZZZZ0:n_[`31`L40^KVi
0=?Cd`2g]kL0bl_;0:n_[`2JVYX0]KFe0;>c/`2g]kL0dm?C0;Ng]`33`l<0[Jf]0<O7a`2[Zj/0`l?3
0::RXP2TY:@0X:2P0;Ng]`2_[jl0]KFe0;Vi^@2g]kL0Y:BT0:n_[`37alL0`l?30:^[Z`2RXZ80/K6a
05UIF@2JVYX0^KVi0:2PX03?cll0]KFe0;Vi^@2ZZZX0bLW90<G5a@33`l<0clo?0:f][@80`l?300P0
^KVi0;Fe]@37alL0]kNg0:BTY031`L40]kNg0;^k^`80_kno01<0clo?0;Ng]`39bLT0[Jf]0:ZZZP2a
/K40[Jf]0:n_[`2][Jd0bl_;0;Fe]@2_[jl0^KVi0<71`@2a/K40_kno0<71`@2g]kL0W9bL01T0oooo
000G0?ooo`0E07AgM`1fN7@0Lg1^07imNP1iNgL0MWQd07=fM01aM780L7=a07UfM01lM780MG9b06eb
M01_M7T0MWQf07EgL`1cLW40MWMh071aLP1hNWH0JF]W0080NGA_0540NGQe07EdL@1cMG<0OX1n06i/
J01eMg80NX6307]oN@22Ogd0L7Ia07inN@27PWl0N7ii07I_KP1VJ6`0HFYZ07aiM`1dLFl0Ng]f07em
N01gNG@0OGmj08>5P@1lOWX0NX5j071gL01eO7/0K7=b07YdM@20NgT0OgYe06m^J`1fN7H0NGQe07Ma
K01aKf/0Ng1_07=mM@1nP7/0Ogmj07Z1MP1eNG40NG]g07agLP1mMg00Mfmc07ebK`22OGP0NWU/07Ug
L`1cLFd0KFm]07M`I`23PGd0L7Mf07UkN@1jP7d0NGQe08>2O`27RHL0NG]i07QfLP1eLfl0P81k07Ub
L01fL740IFAS06m^J`20Og`0O7ij06a^JP2ATHP0M6m/07mhMP1aJVP0OGef07MfL`26Qg/0MGAa06IZ
I@1bMW407`3oool02@2a/K40]KFe0:n_[`35aLD0^k^k0;Fe]@2_[jl0Zj^[0:ZZZP020;^k^`0:0;>c
/`2TY:@0Z:RX0;Fe]@2c/k<0[jn_0;Fe]@2ZZZX0Z:RX09bLW080^k^k0140_kno0;^k^`2_[jl0aLG5
0:JVYP33`l<0_Kfm0;no_`3=cLd0/K6a0:ZZZP3Fe]H0^KVi0=SHf02e]KD0S8b<0<71`@020;6a/@0o
0;no_`2g]kL0`l?30:^[Z`3?cll0_Kfm0:ZZZP2_[jl0/k>c0::RXP39bLT0alO709jNWP2XZ:P0]KFe
0;Ng]`31`L40Zj^[0;no_`35aLD0clo?0<O7a`2m_Kd0/k>c0<71`@3Ph>00`l?30;Ng]`3=cLd0bl_;
0;fm_@2k^k/0[jn_0;Fe]@2g]kL0clo?0:ZZZP2m_Kd0^KVi0;^k^`3?cll0e]KF0:RXZ02i^KT0/k>c
0<W9b@3;bl/0]KFe09BDU02XZ:P0bLW90:ZZZP2RXZ80j^[Z0;6a/@37alL0Zj^[0<?3``2g]kL0eMGE
0;>c/`2FUYH0[Jf]01T0oooo000G0?ooo`0607IeLP1iN7D0MW=a06e/J@1]Kf/0N7Ec0P1lOgd0H01h
NgT0NWUf07YhO01kOG/0MWih071cL@1cLW40O7]h07=iMP1aLg40NG]i071bKP1fN7@0NGQe07MfL`1m
O7T0M7=`07QkL`1bMFd0OGeh06a/I`1mN7H0O7]h07j2O@1hMG<0N7Ee07IeM01cLVl0NGQe07]dL`1k
N7H0KW1/06a^JP1mOGP0RHV407]iM@1[JFD0MgUe08J8Q01gMg80N7Qc075cL@1/KV`0OWel07elN@1a
LFX0O7]h07MbK@1aKf/0Ngek07=aK@1nP7/0OG]g081kN01lMg@0OWYb07YhLP1hMG<0NGMc07QjN01j
NW40P7]i06aVG`1gM780O7Uk085oN@1iMg40N7Yf07UiM022P7`0P7ih075aJP1eM740OWej07mnN`1R
HEh0LFm[06m]J@1iNgH0QXJ107=]J023OWT0NWUf07mnN`1jO7P0Q8J207AdK@28QH<0OWUf07YeLP1g
MWD0LW9]07efM01bMG<0OGmk07IhM1l0oooo00T0[jn_0:^[Z`2][Jd0/k>c0;Ng]`2a/K40Y:BT0;Vi
^@2ZZZX00P2i^KT05P2c/k<0aLG50;fm_@2g]kL0aLG50:n_[`37alL0`L710;^k^`33`l<0ZZZZ0:n_
[`2k^k/0]kNg0;>c/`2a/K40Y:BT0;no_`2TY:@0[jn_0:RXZ02c/k<20<?3``0C0>;RhP3Cdm<0e]KF
0;Ng]`35aLD0Zj^[0;>c/`37alL0aLG50;Vi^@31`L40^KVi0=cLg037alL0f=SH0;Vi^@2][Jd0`L71
0;Ng]`020;Fe]@0Y09jNWP2c/k<0/K6a0<71`@2c/k<0`l?30<_;b`2_[jl0^k^k0;Ng]`2o_kl0alO7
0;^k^`2ZZZX0Z:RX0;^k^`2e]KD0`l?30<G5a@2[Zj/0ZZZZ0;Ng]`31`L40]kNg0<o?c`3=cLd0_Kfm
09:BTP2a/K40[jn_0;>c/`31`L40aLG50=7Ad@2_[jl0alO70:f][@2XZ:P0_Kfm0:^[Z`2k^k/00`31
`L401@37alL0[Jf]0;Ng]`2k^k/0ZZZZ01T0oooo000G0?ooo`0:07=gLP1aLfl0LWA`07EgL`1gNGD0
M7=`06eaK01hNWH0L6m/07QjN080MGAc0480OWel07YgM@1gM780OW]i07=`KP1oO7X0O7Ug07YhM01m
NgL0L7A_07=gLP1gM780KFYX07EgL`1dN7<0KFm]07EgM@1]K6/0Lg=^06mcKP1mO7T0OWej07elN@2=
Thh0QhEo07YeLP1gNW`0OWah075_J`1oOW/0MgUe07ikN@1hMg@0N7=`07UhM@2:QH80OgYg07QgM01b
LFh0NG]f07alM`1gMG40MWA`06Y]K@1lOgl0MGIg07alM`1eMg<0MGUd07ejN01cLFd0NGMc07MeL@1b
L6`0Ngil07UiM01`L6/0MgMb06mZI@1fN7H0OGMb07imNP1bL6`0L6]X07MbK`1lMg@207MfL`0H08:1
OP1jMVh0I65O07n1O@1cKV/0MFi/07akN01nO7P0Q85o07=cK01oO7`0LVaU07IaKP1jMG80LFi/07Uk
MP1lNgP0O81k07aiM`1oOW/0LW5^07MbL01iN7D0L6m/7`3oool0302a/K40X:2P09BDU02ZZZX0Z:RX
0<71`@2e]KD0Zj^[09jNWP39bLT0^KVi0;Ng]`80^k^k00H0^KVi0;^k^`2e]KD0^k^k0;fm_@33`l<2
0;fm_@050:BTY02a/K40Zj^[0;fm_@2VYZH00P2e]KD0702][Jd0`L710;fm_@2a/K40aLG50<71`@2k
^k/0V9RH0;>c/`2TY:@0[Jf]0<O7a`35aLD0ZZZZ0<O7a`2[Zj/0`L710;Fe]@2ZZZX0Zj^[0;^k^`39
bLT0^KVi0<O7a`2_[jl0VYZJ0:n_[`2o_kl30;6a/@060<O7a`3=cLd0bLW90;no_`2i^KT0]KFe0P31
`L40202g]kL0V9RH0:f][@2i^KT0U9BD0;no_`2NWYh0alO70P2i^KT04`2][Jd0/k>c0?;blP2XZ:P0
V9RH0:n_[`2o_kl0/K6a0;Vi^@2g]kL0dm?C0;>c/`2[Zj/0]KFe0<?3``2ZZZX0V9RH0=[JfP2o_kl0
0P2e]KD01P3?cll0/K6a0;6a/@2m_Kd0aLG50;6a/AT0oooo000G0?ooo`1P07akNP1mO7T0O7]h079a
KP1fMG80M7Me079aKP1dLg00N7Md07IeLP1jMG<0MgIc06EWH`1dLg00O7]h07YlN01eMg<0OGeh07il
N01hN7<0Ng]f07MfL`1fMG80MgAb07=`KP1YJ6D0NgYg06]_JP1hNg/0NGMi07QfN01aM7@0M7Mg07n3
OP1mP7P0NGId06a^JP1oOW/0MgEa07akN01iN7D0JVaW07QjM@1nO7h0MgIc07IcL@1hLfh0JVUV081o
O01dMGH0L6]Y05YDC`1iNW/0NGMc07IdL020Ph40P8:0081nP01bM6l0L6iX06=SGP23QH40O7ag07Ae
MP1fMG@0N7=`07miNP1]Kf/0MWA`07eiL@1eL6d0NGYm07YgM`1fLF`0Mg=[07afN@1_LW00PX9m07in
N@1oOGT0LFaY089oO@1kN7H0N7Ec06IXI01_LFd0O7ii07emN01]LF`0NGId07IhM01iNgL0OGYh07Ic
L@20NgP0KViY0P1mP7h01P22RX@0Ph5m07MiM01oOW/0MW5^07=aKAl0oooo02P0`L710<?3``31`L40
[Jf]0;Fe]@2a/K40[Jf]0;6a/@2i^KT0]KFe0;Vi^@2g]kL0U9BD0;6a/@31`L40_Kfm0;>c/`33`l<0
aLG50;fm_@2o_kl0]kNg0;Fe]@2_[jl0]kNg09bLW02o_kl0X:2P0;fm_@2k^k/0^KVi0:^[Z`35aLD0
/K6a0<?3``2k^k/0Zj^[0::RXP2g]kL0`L710P2k^k/02P2NWYh0aLG50;Ng]`39bLT0]KFe09jNWP39
bLT0[jn_0;6a/@2ZZZX20;^k^`0[0:2PX02e]KD0bLW90<W9b@2m_Kd0[Jf]0:ZZZP3?cll0/k>c0<71
`@2a/K40]KFe0<O7a`3Lg=`0Y:BT0;Fe]@2c/k<0ZZZZ0;^k^`2m_Kd0]KFe0;no_`31`L40Z:RX0<g=
c@37alL0_Kfm0:^[Z`3=cLd0_kno0;fm_@2FUYH0Z:RX0<71`@33`l<0Y:BT0;^k^`2e]KD0^k^k0<?3
``2e]KD0bLW90:JVYP020<?3``060<g=c@3?cll0]kNg0<O7a`2e]KD0[jn_6@3oool001L0oooo06P0
NGQe06Y/JP1gNGD0M7Ib07MiM@1jN7@0LWYf06e`KP1XIfH0M7Yi07UoO01dMW@0MW=c07]mN`1hNWP0
IFMR07QfLP1`Kf`0LGE`079dL01oOW/0N7Md07EdL@1/Kfl0N7]k07MiM@1bM700MG1]08:0O020Og`0
R8>106QZIP1jNW<0NWYe07=eL`1gLVd0NG]i07QnN`1fN7H0NgId07AcLP1lOWT0Ph=n08Z<R01iN7D0
L79^05mUI025Q8<0Lg9a0860O`1bLG00MgIc07akN01_KV/0KV]Y08F9Q01gLW00JfeY07ajO01_KFT0
N7Ib07ekM`1]LF/0MW1[07miM023OGP0LWUb071ZK@1dKVl0OWUg08AnM@1dLV`0RX9n07A_JP1bMW00
IFY/0820N`1mMW@0MG=]07alM@1ZK6X0P7j207QlMP1jOG/0Q7mm07MiM@1iNgL0MgQi07=bK`1hLG00
Ogei07QfLP1cLFd0N7Ib07YhL01eOGH0NWAe06ibK@1bMf`0NGMc05ePH01gNWX0P7j2071^JQl0oooo
02<0^k^k09jNWP2g]kL0/K6a0;Ng]`2m_Kd0[Jf]0:BTY02JVYX0/K6a0;Ng]`2a/K40]KFe0;no_`2i
^KT0U9BD0;Vi^@2ZZZX0Zj^[0;Vi^@37alL0^KVi0;>c/`2FUYH0XZ:R0;Ng]`2][Jd0/k>c0::RXP39
bLT0f=SH09ZJVP2TY:@0_Kfm0:n_[`020;Ng]`0M0;^k^`2e]KD0_kno0;6a/@2g]kL0`L710=cLg02k
^k/0_kno0:ZZZP3Cdm<0[jn_0<g=c@3;bl/0[Jf]0<71`@2XZ:P0/K6a0:JVYP3Cdm<0X:2P0:f][@31
`L40Z:RX0<?3``2g]kL0Y:BT0;Fe]@37alL00P2][Jd09@2ZZZX0/K6a0=7Ad@3Ph>00/K6a0=cLg02a
/K40dM7A09BDU039bLT0`l?30<71`@3AdM40WYjN0<W9b@2i^KT0Z:RX0=7Ad@2g]kL0^k^k0<71`@2_
[jl0^KVi0<O7a`2i^KT0`l?30;Vi^@2m_Kd0/k>c0;fm_@2VYZH0[Jf]0;^k^`24Q8@0]kNg0<W9b@2Z
ZZX06@3oool001L0oooo06P0MWEb07UfMP1fN7@0NG]g07MiM@1hMg@0NWEb07QhL`1eMg80P7ek079e
L`1hNWP0Ogim075cL@1[KF/0MGMe07AgM@1aNG<0LWIa07AcL01YKfX0OGai07=bK`1hMg@0MgIc07Yl
N01cMG40Mg9_07ilN021O7X0L7A_07Q`KP1dKVL0LW9]07eoO@1eM740LVaU081kN01kNGD0Ogim08Ao
O@21NWT0PH1m08:2O@1hMW80LF]/0863OP1bKFP0OGQc07UdK`21O7L0NGQe07imNP1iN7D0O7]h07b0
N`1cKV`0MWQd07meK`1ZJ6@0M79^07mmN@1eMg80Mg9_06iYIP1mN7D0LWEe06aYI`22P7`0NgUa07Ed
J@1jNWD0Mg1^07ilN01mNgL0NGQg07IhL`1]KW40L6e[06YYIP1bM700MWI_06m`L@1mOg/0PGaj06e_
J`1^K6H0MWA`06]XIP1eL6h0If1N07igM@1dLVh0Lg5]07UkN@22NgT0MFi/07anNP1`MWD0MWYe081g
N@1[KF/0O7Ec05ECCal0oooo01L0]KFe0;^k^`2e]KD0^k^k0;Ng]`2i^KT0_Kfm0;Vi^@2c/k<0bLW9
0;fm_@2i^KT0alO70:^[Z`2PX:00/k>c0;6a/@2[Zj/0[Jf]0;Vi^@2LW9`0`l?30:n_[`020;Vi^@0;
0;fm_@2_[jl0]kNg0;>c/`3;bl/0ZZZZ0;Vi^@2m_Kd0/K6a0<?3``2c/k<00P2][Jd04@2o_kl0alO7
0=7Ad@3AdM40bl_;0<g=c@2i^KT0^k^k0:^[Z`2][Jd0`l?30;no_`2k^k/0bl_;0<G5a@2k^k/0]kNg
0080`L710180]KFe0;6a/@37alL0WYjN0<O7a`2@T900/k>c0;Ng]`2VYZH0[Jf]0=7Ad@2RXZ80cLg=
0;>c/`2k^k/0_Kfm0;Ng]`35aLD20;^k^`0L0;Fe]@2TY:@0WYjN0;>c/`2][Jd0]KFe0:RXZ02i^KT0
bl_;0:BTY02VYZH0_Kfm0:2PX02c/k<0V9RH0<G5a@2a/K40[jn_0;^k^`3=cLd0/k>c0<71`@2ZZZX0
]KFe0<W9b@2PX:00`L7107EeMAT0oooo000G0?ooo`1@071bK@1aM7@0KWA_07AaK`1kNWL0MGMe07el
N`1cMG<0MgYh07MmO01kN7H0KVeZ07anNP1jMgD0KfaZ07]mN@1gNGD0MWQf07UkN@1bLg@0MWMh07Yl
NP1dMW@0Ngin06U_KP1[KfX0KW9]07UkN@1jP7d0NWek07EgL`1kOgX0NG]g07MiM`1nP7h0L75d08>1
O@1iMWH0LW5`07YnN@1ZKVT0Fe]F07UmN01^L7@0OGYh07EhN01dMgL0NWah07=bK`1oOGT0NgYi07Mh
N@1fNGL0KV]Y08F4P`1eMg<0PXB007UkM`1dLg00NWUf06QZIP1dN7<0EDi<07=bK`1gNGL0N7]k0868
R@1iN7D0LgEa07AhL`22Ph@0OWej07EdL@1jNW<0N7Yf08>3OP1lO7L0KFQU07AfM01lOW`207YlN00F
07=eL@1bM780NgQf06=LFP1aL6d0OgYe07UdL@1dKf`0HEaI07EcK`1VI5`0N7ik07IjM@1gNgH0NGQg
07QgMP20PWh0OGmk07imNP1jNGH0KW1^06a/IAl0oooo00<0ZZZZ0:^[Z`2VYZH00P2[Zj/00`2e]KD0
[jn_0;no_`020;fm_@80[jn_00`0XZ:R0:^[Z`2m_Kd0^KVi0:f][@2o_kl0^k^k0;fm_@2RXZ80aLG5
0=7Ad@2:RXX30;Ng]`0g09ZJVP2o_kl0[jn_0;fm_@2e]KD0`l?30<71`@37alL0Zj^[0::RXP2m_Kd0
aLG50<O7a`2o_kl0]KFe0:^[Z`2ZZZX0XZ:R0<g=c@2m_Kd0/K6a0<71`@2g]kL0aLG50<71`@2VYZH0
[Jf]0:RXZ02c/k<0_Kfm0;^k^`2e]KD0/k>c0:RXZ01eMGD0^KVi08j>SP2TY:@0bLW90<_;b`35aLD0
[Jf]0<71`@2m_Kd0Zj^[0;no_`3;bl/0_Kfm0;6a/@31`L40Z:RX08:2PP2XZ:P0^KVi0<71`@020;fm
_@0E0:BTY035aLD0bLW909RHV037alL0]kNg0<G5a@2RXZ80YZJV0;no_`35aLD0alO70;no_`2k^k/0
^KVi0;fm_@2c/k<0_kno0<O7a`2e]KD0[Jf]01T0oooo000G0?ooo`0306e`KP1dN7<0NGQe0080NWUf
06<0OGYj07EhMP1eN7H0MgYh07IiN@1]L700KW1^07EdL@1eLW00Lg9_07AfM01]JfL0LG=a06mbL01d
Lg80MGMe07IhMP1aLg40KW1^07=fM01gMWD0NWUh07=dM@1fMW40M7Ib081oO01eLW80MgUg07f1O01`
LVh0OWn0071[J024OgX0NgYi07eoN`20NgT0N7Md07akN01dN7<0LWEc07^1P01fMgP0OGYh075`K@1n
P7/0LG5/07MfM@1jOG/0MWai07QjMP1gMW<0NgYg07IeLP1kOG/0OWYb07EZI`1hMG<0Hf5M07UdLP1h
O7L0NWMe081nNP1bM700OGai07MdLP1dMgD0LG=^07igM@1iNG@0K6i/07IeLP1/L6X0Mg5/08J9Q`1b
M780MgUd07UhM`23PG/0NGMa07elN@1[JVL0JfiV075cK`20Og`0NWah07EgM@24QX40SHn;06e_J`1h
Mg@0LG1]06U_K01fNGL0MgIc07QgM01]KVl0NWAe07EgL`1[KFT07`3oool00`2TY:@0/K6a0;^k^`02
0;fm_@070<?3``2c/k<0/k>c0;Ng]`2e]KD0[Jf]0:JVYP020;>c/`0/0:n_[`2a/K40Y:BT0:^[Z`2X
Z:P0_Kfm0;>c/`2e]KD0Zj^[09:BTP2VYZH0]kNg0;fm_@2_[jl0`l?30;6a/@39bLT0/k>c0<O7a`2g
]kL0ZZZZ0<G5a@2g]kL0ZZZZ0;no_`33`l<0bLW90;Fe]@2i^KT0/K6a0:f][@2c/k<0_kno0<?3``2[
Zj/0]kNg0<G5a@2[Zj/0_Kfm0;Fe]@2VYZH0^KVi0;Ng]`2e]KD20;no_`0C0<G5a@2i^KT0]KFe092@
T02k^k/0^KVi0<W9b@2i^KT0[Jf]0<?3``2a/K40Z:RX0:^[Z`35aLD0^k^k0;Ng]`2e]KD0XZ:R0;Ng
]`020:f][@050;Ng]`2k^k/0clo?09bLW033`l<00P2PX:004@35aLD0bLW90;fm_@2c/k<0dM7A0<O7
a`2TY:@0^KVi0:^[Z`2LW9`0]KFe0;Ng]`2i^KT0Y:BT0;fm_@2c/k<0X:2P01T0oooo000G0?ooo`1H
06]]J@1eL6h0HVES06maK`1dLg80J6YX07QjN01kN7P0NgAe06eaJ`1jO7P0NG]g07anNP1YJfL0MgIc
07=eL`1jOG/0LgEa06maK@1aLfh0N7Ye07]kMP1dM6l0Ogeg07AbK01dMgD0LWAh06mZI@1eN7P0MWYe
07imNP1bLV/0OWel07aiM`1eNG@0N7Md07mnN`24OG/0MW5^06=bMP1lPXT0NWaj07]jN@1TJVD0OXAo
07YgM@2FRXL0Lg5c07YiMP1[LW40NWUf07UhM@1]K6T0MgIc07=bK`1ZKFl0NGYk07imO025Pgl0MWQd
07QjMP1fN7@0JFAQ089lM`1nN7<0OWUd07MbK@2;SHT0NWMe07mhM`1gLFX0PH1m07IeLP1fMW40OWUd
085lM`1oNWD0If9M07E^H`1fL6T0MgEa089mNP1dN7<0QHV406UWH@1hMg@0N7Qa07YgM@80M7Ib00h0
N7Qc07EeL01_Mg40M7=X07moMP20N780QX1i07]iM@1oNWL0NWEb06i^I`1XJ640KgMc07]kMQl0oooo
00L0X:2P0;>c/`2>SXh0Z:RX0;6a/@2JVYX0^KVi0080_kno00T0Y:BT0;no_`2k^k/0`L7109bLW02g
]kL0[jn_0;fm_@2_[jl00P2XZ:P0:02i^KT0_kno0;6a/@2g]kL0alO70;6a/@2][Jd0Z:RX0:^[Z`2e
]KD0aLG50:f][@2ZZZX0aLG50;>c/`2i^KT0/k>c0<O7a`2e]KD0T92@0<71`@37alL0_Kfm09:BTP35
aLD0V9RH0;fm_@2_[jl0_Kfm0<G5a@2PX:00_Kfm0:BTY02g]kL0_kno0:n_[`2NWYh0aLG50<?3``3C
dm<20;Fe]@0;0;>c/`2LW9`0cLg=0<G5a@2g]kL0SXj>0=kNgP2m_Kd0]kNg0:RXZ03;bl/00P2e]KD0
2`2k^k/0bl_;0<O7a`2HV9P0]KFe0;Vi^@2g]kL0cLg=0;6a/@2o_kl0W9bL0080^KVi0140_Kfm0;6a
/@2a/K40^KVi0;>c/`37alL0/K6a0<O7a`39bLT0eMGE0;no_`37alL0_Kfm0:JVYP2JVYX0Z:RX0;no
_`0I0?ooo`005`3oool05@1aLfl0MG9`075dLP1jO7X0NWUh07AfM01bMG<0MgUg07MfM@1ZJ6@0L79^
07QjMP20PWh0JVaX06YYIP1_LF`0KG5[07EgL`1iNgL0QH=o07YhM00207QgMP0d07MiM@1cMG40MGIg
07MiM01dLG<0Kg5/07AaK`22PGh0O7f0075cK`1bKfd0MWYe06IUHP1aL6d0N7Yf07EmM`2LU980;C0T
065QFP1lMg80N7ag07AhL`1aKf/0MWai0860O@1nOGX0MWQc06i`KP1kNG/0NWQj06]YJ`1dLg00OG]m
07MdM01`JfT0LgE`07YlN01eMg<0M7Ib069XI@1`M6l0FemJ07n3OP1bM6l0NgQf07QjMP1/L6/0Mg]f
06QXG`1jNWD0NWQj07MeL@80MWA`01/0NGMc07ajMP1fN7@0L6iZ07MbK`1eMg<0Ngei07=bK`1TJVL0
GV5I06]]J@25PX00O7Ug06i^J@1eMG00L6e]081kN@1jLG40MWYe07MeL@1dMW@0Ogaj085nO025QH00
Lg=^075aJP1[J6H07`3oool00`2[Zj/0/k>c0:^[Z`020;fm_@080;6a/@2][Jd0]kNg0;Ng]`2NWYh0
`l?30;Vi^@39bLT209jNWP060:RXZ02TY:@0/k>c0;^k^`2g]kL0_Kfm0P2i^KT0<P2XZ:P0]kNg0;>c
/`2g]kL0/K6a0;no_`2a/K40cLg=0<71`@2k^k/0Zj^[0;Fe]@2FUYH0]kNg0:^[Z`2c/k<0oooo02LW
9`2NWYh0S8b<0;Vi^@2a/K40[Jf]0:^[Z`3;bl/0aLG50:n_[`2e]KD0YZJV0;fm_@2PX:00^k^k0;6a
/@33`l<0ZZZZ0;6a/@2_[jl0_Kfm0;6a/@2_[jl0SXj>0:ZZZP20P800[Jf]0::RXP2o_kl0^KVi0;Ng
]`2][Jd0VYZJ0P2m_Kd07P33`l<0]KFe0;Fe]@2k^k/0]KFe0<?3``2ZZZX0]kNg0;>c/`35aLD0[jn_
09:BTP26QXH0_kno0=?Cd`31`L40YZJV0;>c/`2i^KT0bLW90;fm_@2e]KD0]kNg0;6a/@37alL0bl_;
0=?Cd`2_[jl0Zj^[0:2PX1T0oooo000G0?ooo`1X07AgM@1eLW80NWQj07QfN01jN7X0LG=_07IhM01l
OW`0Mgel07]nO01bM780NGaj06meLP1XKV/0GUQC06]gM01MJVL0OX9m07MiM@1iNgL0LgMb07MiM`21
Ph40OGmk06ibK@1_LW00MGMe08>5P@1iNgL0OWn207IiN@24OG/0LWAb07=eL@1_LFd0NGQe07MfL`1b
M700JVaX06U`K`1JGf80M79^06i]JP20Ph40MWQf089kNP1iN7L0MGMe07QjN01hOW/0N7Mf0865P01l
P7/0Kg=^071]J`1eN700MGMb07QjN01oOW/0OGeh07QjMP1eN7H0LWA`06MWGP1YJF80L6m/07MfL`27
QXD0PH1m07moN01OGeP0Ngei079]J`1eNG@0Ogmj07IeLP1^L6`0L79^07akN01bL6`0QH=o07EeL01h
Mg@0G5YF06U[J@1`L6T0L6iX08F0N`1eJVL0K6EV07AfM026Ph40MWQd071cJ`1iO7X0MgYh06a_K@1n
PW`0NWii07YlN01kNWL0N7Md07UfM01]JfDO0?ooo`0/0;6a/@2c/k<0_Kfm0;Vi^@2m_Kd0Zj^[0;Fe
]@31`L40]kNg0;no_`2a/K40^k^k0:RXZ02JVYX0QXJ60:2PX024Q8@0aLG50;Ng]`2i^KT0[jn_0;Ng
]`3;bl/0XZ:R0<?3``2XZ:P0/k>c0<o?c`2m_Kd0aLG50;Fe]@3AdM40`L710:f][@2XZ:P0^k^k0<?3
``2g]kL0WYjN09bLW01oOgl0_kno0;6a/@39bLT20;Fe]@040<g=c@2c/k<0^KVi0:JVYP80^KVi0280
`L710:RXZ02FUYH0ZZZZ0;>c/`2i^KT0[Jf]0<O7a`33`l<0/k>c08b<S02][Jd0V9RH09bLW02g]kL0
Zj^[0=KFeP3;bl/0R8R809ZJVP2o_kl0[Jf]0;>c/`37alL0]KFe0:JVYP2ZZZX0[Jf]09ZJVP3Cdm<0
/k>c0;Vi^@2a/K40W9bL0P2ZZZX01@2][Jd0/k>c0::RXP2a/K40eMGE0080ZZZZ00@0^k^k0;Ng]`2R
XZ80aLG50P2m_Kd0102o_kl0^KVi0;^k^`2TY:@I0?ooo`005`3oool0J01_K6X0M7=b07EdL@1fMG80
NgYg06iaK`1bN7<0M7Qc07=eL@1eM740N7]k06a_K`1eN7P0MWEd07UkN@20OWX0NWQd07AfLP1kNWL0
O7il07=eL`1aLfl0M7Ib07]oNP1fN7H0MgEa07IfL@1mO7T0LG1]07UlNP1gNWP0Lg9_07MfL`1TK6H0
Kg=^07efM@1_LW@0MgUg071bL01gNG@0NWah07n6Q@23QXH0NWn107IgN01iM780OGai0864PP1]J6H0
KVUV07EeL020QXD0OGYj07AfLP1bLFh0Kg5_07akNP1oOGT0NgQf06m]J@1SHUl0Oh:207MkMP1jLW00
LV]Y07ajMP1_Lfd0Ng]d079bJ`1nOWL0M7A[069YHP26PGh0MGE`07=^J`1]Kf/0NWah0863O`1cLVl0
MGMc06Q[J@1dMgT0I6IR06MRG@1bL6`0MG=_07=gLP1gNGD0EV=P06meM01bMW40N7Yf07akN01`MGL0
NGeg07alM`1hNWP0O7il08:2O@1jNWD0Shb<07E`K@1[IV40JFAO7`3oool0J@2XZ:P0/K6a0;>c/`2e
]KD0_kno0:JVYP2][Jd0/K6a0:n_[`2c/k<0UYJF0::RXP2c/k<0]KFe0;^k^`39bLT0_Kfm0;6a/@2o
_kl0_Kfm0:n_[`2[Zj/0/K6a0:ZZZP2o_kl0]kNg0;Fe]@33`l<0/k>c0;^k^`2g]kL0[jn_0:f][@2g
]kL0Z:RX0<?3``2TY:@0Z:RX0:ZZZP2g]kL0_Kfm0;Vi^@37alL0_Kfm0;Fe]@2i^KT0^k^k0<_;b`2T
Y:@0[jn_0:JVYP2c/k<0`l?30;6a/@31`L40[Jf]0:RXZ037alL0clo?0;no_`2XZ:P0alO70;no_`2g
]kL0_Kfm0:f][@2XZ:P0bl_;0;no_`2][Jd0/K6a0;Ng]`2>SXh0eMGE0;>c/`2RXZ80Y:BT0;fm_@3;
bl/0/k>c0:2PX02JVYX0/K6a09:BTP2k^k/0[Jf]0;>c/`2_[jl0XZ:R07MgM`2XZ:P0[Jf]0;Vi^@2]
[Jd0ZZZZ0;^k^`31`L40^KVi0<71`@3=cLd0_Kfm0>KViP2c/k<0X:2P09bLW00I0?ooo`005`3oool0
J01`Kf`0L79]06mbL01gNGL0MgIe07UfM01`LVh0LWA`06i`K01hMG<0K6UW07ejN01jMgD0O7]h07Ac
L01aL6d0LWYd07eoN`1jO7P0P7ij07IhL`1fNWD0M7Qc07mlO01eN7H0LWUh07QlM`1fN7H0LWA_07]f
L`1cL6h0KgAg0822P01gMg80NWUh07=^J`1gNGL0N7ii07UoNP1nOGX0MgIc07UhM@24Ph00JW5b071a
LP1dLVh0OG]g07mkL`1hMW80PX9k07IhM01aLfh0OWii07MeL@1cLVl0NWEc06YYIP1`M6l0NGUd07Uk
M`1bL6X0NWA[07]jM`1bMW00JFUT079]JP21PG`0T8j606i]JP1nPGL0Kg=]06e_JP1gNG@0LWA_065Q
FP1^LFl0Kg5_07YiN01kM780NGUd06]YI@1cLFd0NWA[06Y/I`1aK6L0N7Yf07mjKP1gMG40LGUk07ik
N`1fM6h0M7=`07eoN`1oPGd0N7mf08V1O@1mMWL0OWaf081kMP1eMVX0NWah07EgL`27Qh00LfiY7`3o
ool20:ZZZP0B0:RXZ02g]kL0]kNg0;^k^`2ZZZX0[Jf]0:JVYP2i^KT0WYjN0<?3``2m_Kd0`L710;6a
/@2[Zj/0[Jf]0<?3``2m_Kd0[Jf]0P2e]KD09@2a/K40[jn_0<O7a`2][Jd0^KVi0;Fe]@2ZZZX0_kno
0:n_[`2XZ:P0^KVi0<W9b@2m_Kd0[jn_0;^k^`2g]kL0^k^k0<G5a@2g]kL0^KVi0;^k^`2NWYh0ZZZZ
0<g=c@2a/K40alO70;Vi^@2a/K40cLg=0;Fe]@35aLD0]kNg0<71`@2_[jl0_Kfm0:ZZZP2g]kL00P2k
^k/0;02m_Kd0cLg=0;no_`2][Jd0W9bL0<_;b`33`l<0j>SX0:JVYP2XZ:P0^k^k0:BTY02g]kL0[Jf]
07]kN`2VYZH0Z:RX0;fm_@2k^k/0bLW90:2PX02_[jl0_Kfm0:n_[`2[Zj/0^KVi0<O7a`2VYZH0Zj^[
0<G5a@2e]KD0/K6a0<71`@37alL0^KVi0=[JfP33`l<0aLG50<W9b@2c/k<0_Kfm0;>c/`3Fe]H0[jn_
6@3oool001L0oooo00L0LG1]06i`J`1dMgD0K6i/06i]K01hMG<0M7Ib0080NG]g0P1/KVX0G@1hNWH0
MWQd07MfL`1gMW<0NWah07UkM`1VJ6@0M7Ib075dLP1/KV`0N7Yf07YlN01[LW40LGAd07QjN01jNGH0
MGMc0864O022Q880PHB408:4PP1cLFd0MGQh07IjM@1aLfh0IVaY06eaK01gNgH0NGQe07mnN`1lNgP0
NWUf089oP@1cLW40OGmm07n1O`1eN7H0N7Md071^J01hMg@0MgUd07inN@1cLFd0M7=`07AhL`1mO7T0
NGId07emN01hMGD0MGIg07IhO01kNGD0Q7ml06i^J@1mOgX0N7Yf071^JP1hMWP0NG]g06ATG@1JFUD0
PH5l07]kMP1aK6L0Lg9_07IcL@1eL6h0MgUd07QfLP1fN7<0KFmZ06mWI@1dLV`0L6]V079dL01fNGL0
L79^08IoM01cLF/0NWA_07ikN@1mNWP0LVm]085kO01bL6X0AS`b07AfL@1iNG@0Mgan07MiM@1kOGT0
O7]h07aiM`0O0?ooo`070:^[Z`2VYZH0/K6a0::RXP2VYZH0^KVi0;6a/@020;^k^`040::RXP2][Jd0
^KVi0;Fe]@80]kNg00`0_Kfm0;^k^`2FUYH0/K6a0;>c/`2RXZ80^KVi0;fm_@2c/k<0X:2P0;Vi^@2m
_Kd20;>c/`0J0<g=c@3;bl/0cLg=0;^k^`2_[jl0]KFe0:^[Z`2][Jd0UYJF0;Ng]`2k^k/0alO70:RX
Z031`L40cLg=0:n_[`2[Zj/0`l?30;>c/`2i^KT0Y:BT0:ZZZP2i^KT0aLG50:n_[`2PX:020;6a/@0K
0;^k^`2c/k<0`l?30;Vi^@2e]KD0bLW90;no_`3AdM40YZJV0;Vi^@3=cLd0ZZZZ0;Vi^@2BTY80/K6a
07moO`3;bl/0_kno09jNWP2_[jl0]KFe0;>c/`2i^KT0ZZZZ0;Fe]@2TY:@0Z:RX0080ZZZZ00h0[Jf]
0;Fe]@33`l<0eMGE0:n_[`2m_Kd0aLG50<W9b@2][Jd0bl_;0:f][@1GEeL0/K6a0;^k^`80]kNg00<0
_kno0<71`@31`L406@3oool001L0oooo01l0MWUg06Y^J@1`Mfh0MG]j07MmNP1eMg<0O7]h079aKP1j
NGH0M7=`079aKP1^LVd0MgIc07EgM@1dMW80N7Yh079dLP1]K6T0SXb807AeMP1aMgH0Cdm:07QcKP1c
MW@0MGAc075cK`1aL6d0K6e^07anNP2;Q880Qh5j0080MgUe0P1fMG80A@1iNgT0Kg5_08:1OP1fMG80
P7em08:5P`1lP7/0J6QQ07QeL`1dLFl0OGak07n1O`1aMg@0N7ag085nO01cMG40LG1_069QGP1XIV80
JfYW07QeL`1kN7H0OGYh07akN020OX00OGai06a/I@1hMW80NG]g079dL01eMg<0PWmo069RG@1eMG00
MWIa06e[I`1UH5/0IV5N07MbL01JEE00OWUd07UdK`1jMG00OWMe07IhL`1eMG00NgIc07QjM@1RI5l0
IFUT075iL`1hNWH0NgYg07AfL@1oOGL0OGQe07n3OP1hNWH0Ph1n07UjN`1fMG@0L79`07EgM@1]K6T0
LG=_07MkMP1kNWL0L79^07YlN00O0?ooo`0I0;Fe]@2NWYh0ZZZZ0;>c/`2g]kL0/k>c0<71`@2][Jd0
_Kfm0;6a/@2i^KT0YZJV0;Ng]`2c/k<0/K6a0;Vi^@2][Jd0Y:BT0>CTi02ZZZX0Zj^[06UYJ@2i^KT0
^k^k0:n_[`020:^[Z`0O0::RXP35aLD0g]kN0=KFeP2g]kL0Z:RX0;Ng]`2e]KD0^k^k0;>c/`2XZ:P0
]KFe0<W9b@3=cLd0f][J0<71`@2i^KT0/K6a0<71`@33`l<0Zj^[0;Vi^@33`l<0bl_;0:n_[`2>SXh0
VYZJ0:f][@2PX:00^KVi0<?3``020<71`@0]0<W9b@2RXZ80[jn_0;Vi^@2k^k/0[Jf]0<g=c@2HV9P0
SXj>0;>c/`2TY:@0VYZJ09BDU02FUYH0]kNg09BDU035aLD0^k^k0;fm_@2e]KD0clo?0;>c/`2o_kl0
^KVi092@T02DU9@0Zj^[0;Vi^@2c/k<0/K6a0<O7a`33`l<0alO70;^k^`3?cll0^k^k0;Fe]@2ZZZX0
/k>c0:BTY02[Zj/0]kNg0;no_`2ZZZX0_Kfm01T0oooo000G0?ooo`0W06iaK`1_JVP0K6]X07=bK`1a
L6d0Lg5e08>2O`20Og`0NgYg06e/J@1cMG<0LG=a07MiM`1QI6H0MWEd06mZI@1YI5l0NgQf06Q^K@1`
LG@0LW=f06E]I`1cMg80LWQg07IlN`1_KVd0MgUg08J5Q01cLfh0E5UK04M8B@1/JFL0OGYh07QiNP1c
LG<0MG=_07MiM`1`LW00MWQf0080OgYh03l0NG]g07eoO@1mOg/0KFeX06i`J`1/JVH0PG]f07UcKP20
NgH0P7Ye07AdK@1iMgT0MWEb07YiMP1nOG`0KFaY07EeKP1iNgL0PGmi07ajM01nO7H0MG1]07EeL01j
N7@0OWah07=_I`1^KFX0LWIa07YhM01fLFh0LFmY06e[I@1iMg<0FEUD079[K01nOGX0QX5l06iTG01i
Mg<0N7=`075/JP1mOg/0MW5/079dL01lNGL0Hf9Q07agM01hMW80QHN507EdL@1hO7L0LW5^07QgM01f
N7@0KW9]081oO01ZL6/0OXEn07IdL01cMG40NGId08F8QP1WIf807`3oool0102ZZZX0[Jf]0;>c/`2L
W9`20:n_[`80_kno00T0^KVi09bLW02][Jd0[Jf]0:JVYP2[Zj/0]KFe0:f][@2c/k<00P31`L403P2a
/K40]kNg0;>c/`2k^k/0/k>c09RHV02e]KD0`l?30:^[Z`2c/k<0_Kfm0<71`@37alL0Zj^[0P3=cLd0
AP2RXZ80^k^k0;>c/`3;bl/0/K6a0:^[Z`2c/k<0[jn_0;^k^`2m_Kd0ZZZZ0<71`@2i^KT0`l?30<G5
a@2m_Kd0^k^k0<71`@2c/k<0[jn_0:RXZ02ZZZX0Zj^[0<?3``2a/K40]kNg0;6a/@3=cLd0[jn_0<O7
a`39bLT0[jn_09:BTP2c/k<0^k^k0;fm_@31`L40[jn_0<O7a`2@T900ZZZZ0<?3``2g]kL0_Kfm0;6a
/@2m_Kd0^KVi0;6a/@2o_kl0/k>c0<G5a@2g]kL0ZZZZ0<?3``2e]KD0[Jf]0:n_[`37alL0i>CT0<?3
``2g]kL0_Kfm0:n_[`35aLD0^k^k0<G5a@3EeMD0^KVi0:BTY02c/k<I0?ooo`005`3oool0J01gLG80
MWUi06a[JP1cLW40Q8>2085nOP1iMWH0MG9b07UfMP1aLW<0Ogei071dKP1iNG@0MG1^081kN@1hMGD0
MW=e07YiMP1dLg00MgIc075`K@1eNG<0Ngil071_KP1fMG@0MgIc079aKP1RIF<0EEQF079aKP1fMG80
PH1m07YiMP1fLg40LVm]07ikN`1lOWT0P7ij07ekM`1TIV40NWQd085nO01kN7H0MgAb07ilN01hLFl0
Nh6007moNP1lO7L0R8R107moN01bL6`0MWA`07]iM@1fLg40OX6107MfM@21O7L0N7Ib07EbL01hMG<0
NWMe08R3P01]JfL0LFm[081nNP2=SHP0Q89n06IUI01iO7h0KW5c079fKP1/LVl0KF]U06aUG01nO7H0
NGUd065THP1bKFP0LGA/08>1O@1]KfX0PH=n08B6P@1jMG<0MVm^07QjN028Ph40NGmj08R9RP1YL740
Lg5c07EcM`1aJf`0NGMc06abK`1cMW@0MgEa07mmN@21Og/0JFQU065PG@1hO7H0LGMd7`3oool06`2g
]kL0]KFe0::RXP2_[jl0dM7A0<_;b`2k^k/0/k>c0;^k^`2[Zj/0X:2P0:ZZZP2k^k/0/k>c0<W9b@2i
^KT0]KFe0;fm_@2a/K40Z:RX0:^[Z`2c/k<0_kno0;>c/`2ZZZX0]kNg0:f][@0208j>SP0C0:f][@2e
]KD0bl_;0;6a/@2m_Kd0[Jf]0<G5a@2i^KT0`L710<?3``2BTY80_Kfm0=KFeP3;bl/0]kNg0<G5a@3=
cLd0^KVi0<O7a`020<71`@0g0=SHf037alL0]KFe0;no_`2TY:@0]KFe0<G5a@3;bl/0_kno0;Vi^@2c
/k<0_Kfm09jNWP3Hf=P0Y:BT0:^[Z`3Rh^80MGEe0=7Ad@2FUYH0YZJV0:^[Z`2][Jd0XZ:R0:BTY03P
h>00aLG50;^k^`2<S8`0Zj^[0;no_`3?cll0Y:BT0<_;b`2TY:@0_Kfm0;Fe]@2i^KT0aLG50;^k^`3H
f=P0W9bL0:n_[`2@T900Zj^[0;^k^`2RXZ80[jn_0;Ng]`37alL0bl_;09bLW02<S8`0^KVi0:^[Z`0I
0?ooo`005`3oool0=@1bM780LG9c07akNP1RHF00KVe/07EbLP1dMW@0LWAb0863P@1^Kg00MWEd06Y`
K@1]Kfd0P7ek07YgM@1hNWP0MWMh071_K01gMW<0NWUf07elN@1iNW/0LgEa07elN`1hMgH0Ogik07]j
M`1XJVP0Ngek07akN01cLVl0M7Qc06eaK01kOGT0LG=_07imO01gMg80NWMg06mbL01gM7@0OX1n07Uk
M`1lOWX0Ngam07EfM`1aM7H0PG]l08AmO01jMgD0PH=o05YLF01hMG<0Ph1n0080LFi/02P0NG]i07mn
N`1iMg<0N7Ye06MTHP1bKfd0O7Ug07MgLP1oOW/0N7Md06e/J@1bJfT0PX>407QgM02;QX<0Mg9`06]V
I021PX<0OgU`06aZIP1bMgT0NWek06ETH@1nOGX0MWEb08B2OP1eL6d0O7Yf07AbKP1/KVX0NgQf07Yg
M`1eNG@0N7ik07UdL@1lLg<0Lf]W07ilOP1[IV@0JF]V0P1dMgD01`1hMW80PGmk079`K01gMW<0NgYg
07YhM01_KVd07`3oool0>02][Jd0Zj^[0<71`@2>SXh0YZJV0;>c/`2a/K40[Jf]0<_;b`2VYZH0Z:RX
09jNWP2TY:@0bLW90;fm_@2i^KT0]KFe0:ZZZP2g]kL0`L710<?3``2k^k/0[jn_0;Fe]@33`l<0alO7
0;no_`2JVYX0X:2P0<71`@2_[jl0/K6a0;Vi^@2TY:@0Zj^[0<G5a@2o_kl0]kNg0:RXZ02g]kL0aLG5
0;fm_@2k^k/0_kno0;>c/`2k^k/0Zj^[0=7Ad@2m_Kd0Z:RX0<_;b`1oOgl0clo?0:^[Z`2BTY80Zj^[
0P2k^k/09P2c/k<0^KVi09RHV031`L40^k^k0;Ng]`37alL0^KVi0:f][@2BTY80cLg=0;Vi^@2g]kL0
Zj^[0:2PX03;bl/0alO707moO`2][Jd0_Kfm09BDU02e]KD0f=SH0=7Ad@2c/k<0`L710=KFeP2RXZ80
_kno0;fm_@2][Jd0^KVi0;^k^`31`L40[jn_0;fm_@2PX:00W9bL0P2a/K401`2i^KT0bl_;0:f][@2g
]kL0_kno0;fm_@2XZ:P06@3oool001L0oooo00L0Lg9a07IdMP1gNGD0OGYh079YJ@1bJfT0MGMc0080
N7Yf00@0IfIU075`K`1gNGL0MgYh0P1kNWL0F@1iN7L0Lg1`07iiM`1jNGH0KFm]08:4PP1kN7H0MG9`
07aiM`1VIF80NWUh07mnO@1eN7H0LG=a07UhM`1fNGL0MW=a07EbL01iMW@0MgAb089mN01iNgT0MW=a
07ekM`22O7L0KFQU07YiMP20OWX0Pgik085kO01ZIF80MGMe07agM01aK6T0K6YV07A]J`1dLg80Mgej
06]]J`1lNGL0NGId07mnN`1`LVh0N7Md06UZK@1dLg80JVAO081nNP1fM700N7Md07n1O`1cLfh0J5aG
06ESG@1ZJ6@0LW1/06UTH@1LFUH0Jf]V06MWHP24Og`0OWY`07mjM@1hLg00THZ1075`K`1`LW00NWUf
071_K01]Kf/0Kg5]08:1OP1^KFX0Lfa[07EbL01mN7D0O7]h07YgM@20OG/0NWUf089oO@1fMG80Lg9_
07YiMP1lNGL0NW=b07MdLP1fLFl0LW5^01l0oooo00@0[jn_0;Fe]@2g]kL0`l?30P2][Jd01@2c/k<0
^KVi0;Vi^@2HV9P0Zj^[0080]kNg0P2o_kl03`2k^k/0[jn_0<G5a@2m_Kd0]kNg0<g=c@2o_kl0/k>c
0:ZZZP31`L40_Kfm0<O7a`2c/k<0ZZZZ0;^k^`020;Fe]@040:f][@2c/k<0]kNg0<g=c@80^k^k0100
`l?30<g=c@2TY:@0bLW90;fm_@3?cll0bl_;0<o?c`2NWYh0`L710:^[Z`1aLG40XZ:R0;6a/@2g]kL0
X:2P0P31`L403P2k^k/0ZZZZ0;>c/`2i^KT0W9bL09jNWP3?cll0bLW90;Fe]@2i^KT0[jn_0<?3``2J
VYX0U9BD0P2][Jd08@2LW9`0PX:20:2PX02][Jd0dM7A0<G5a@37alL0j^[Z09ZJVP2[Zj/0ZZZZ0;fm
_@2NWYh0Y:BT0:RXZ03=cLd0alO70:n_[`2c/k<0`l?30<71`@3EeMD0bLW90;fm_@3=cLd0]KFe0:n_
[`2m_Kd0`L710;fm_@2g]kL0]KFe0:f][@0I0?ooo`005`3oool00`1eLfd0MgUg079aL00207UhM`1S
06]ZI`1eN7P0MgAd075cK`1cMg80LgUd06meL01^M6l0MWUg071_KP1`MW40KG=^07=dM@1fMgP0MWYe
06a`J`1jNGH0N7Md07EeL01ZJFH0KW5a07QkN`1RHEh0M6m]07elN@1lNgP0KgMa07imNP1lNgP0MWQd
07IhMP1mOgd0NgYg081oO01SJ6X0Ti:A07]iM@1iN7D0Jg5`07QoOP1fOg/0S8b506a`JP25QH00OH5l
06Y/J01eL6h0NWUf071dK`1fLFl0MGYl06aaL`1dNG/0OWMe08=hM@1gKf/0KfUT07IdL01lO7L0I6AO
06IVH@1`LG80GE]C06mcJ`1hMg@0OG]g06e_K@1]JVX0Lg9a06YTG`23QWh0KFeX071_K01hMg@0L6m/
06UXI@22OG/0Mg5X07UcKP1UIF00MGE`06U_KP1dNWT0M75_07IeLP1dLg00Lg9_07MeL@1jN7@0N7Md
07UhM@1lNgP0NGQe07YlM`1gNGL0Ogik07igMP1fN7@0LW5^01l0oooo00<0/k>c0;Ng]`2][Jd00P2k
^k/02@2PX:00/k>c0;Ng]`2[Zj/0[jn_09RHV02XZ:P0YZJV0;Fe]@020:ZZZP060:BTY02_[jl0]KFe
0;>c/`2RXZ80_Kfm0P2i^KT02P2c/k<0YZJV0;Vi^@2>SXh0bLW90<?3``31`L40Z:RX0:f][@35aLD2
0;Fe]@0T0;no_`33`l<0bLW9092@T03^k^h0cLg=0;no_`2PX:00^KVi0:BTY02e]KD0XZ:R0=?Cd`2R
XZ80`l?309jNWP2m_Kd0ZZZZ0;6a/@2e]KD0/k>c0;6a/@2g]kL0aLG50<o?c`2XZ:P0[Jf]0;Fe]@31
`L40TY:B0:ZZZP2[Zj/0Q8B40:RXZ033`l<0YZJV0P2TY:@0102_[jl0Y:BT0<o?c`2TY:@20:ZZZP03
0;^k^`2LW9`0cLg=0080]kNg01@0U9BD0;>c/`2LW9`0Zj^[0;6a/@2e]KD0/K6a0:n_[`2o_kl0_Kfm
0;Vi^@2k^k/0`L710;^k^`2m_Kd0]kNg0<O7a`35aLD0]KFe0:f][AT0oooo000G0?ooo`1107IdL01`
JfT0LG=_079dL01_LFd0O7Ug06U_K01_MG80LWQe06UVI01ZMVl0L7Ia07=bK`1fMG80M6m]07IfL@1j
O7L0NX1m06iXJ@1hN7<0NWYe06i`K01hNWH0Kg5]07IhM01eMG00N7Ee07EiM01nOWL0MG5Y06m^K@1e
OW`0NWMi07UhM@14B4<0L7Ue07UcM01fMG@0J6YX07YhNP24PH40PH5l07n2P01cMG40IViZ07ImM01b
Kfd0NWA]089lM@1nOGX0MG=e07ImM01iNgH0N7Ec07=aJ`1fLg40Kfi[07YlN01bMGD0NGY^07EeKP1j
MgD0JFUT07mkL`21O7T00P1mMgP09@1`IU`0PWYd08AmO01eKVl0O7Q`07UcK01`J680P7I`06UYI01h
MW80MG1]07afK`1dKVL0K6IQ081mO@1bM6l0JG1Y07UhM@1fMG80Ngek07aiM`1nOWT0Q8N506QZIP1]
Lfh0J6QQ06IXI01eLW00L6e[07MnM`1mNgL0MWA^07=[I`1eOW`0Lfeb07UhM@20Og`07`3oool02P2e
]KD0ZZZZ0:^[Z`2][Jd0Z:RX0<71`@2LW9`0Z:RX0:f][@2LW9`20:ZZZP040:n_[`2e]KD0/K6a0;Fe
]@80_Kfm05L0YZJV0:f][@2m_Kd0YZJV0;Vi^@2][Jd0Z:RX0;>c/`2i^KT0/k>c0:RXZ02c/k<0Z:RX
0;>c/`2<S8`0_Kfm05ADE02ZZZX0]kNg0;^k^`2JVYX0_Kfm0=7Ad@31`L40bl_;0:n_[`2FUYH0e]KF
0;Fe]@2m_Kd0cLg=0;Fe]@35aLD0/k>c0;^k^`2i^KT0Y:BT0:n_[`2e]KD0_Kfm0<71`@2][Jd0^k^k
0;fm_@37alL0W9bL0<O7a`3;bl/0`l?30<_;b`2ZZZX0cLg=0;>c/`2VYZH0`L710;^k^`2ZZZX0cLg=
09bLW02i^KT0/k>c0;6a/@2k^k/0XZ:R0<W9b@2][Jd0`L710;^k^`2e]KD0_kno0;^k^`35aLD0dM7A
09ZJVP2TY:@0/k>c09JFUP2c/k<0ZZZZ0;Ng]`33`l<0]KFe0:n_[`2c/k<0[jn_0;^k^`39bLT06@3o
ool001L0oooo00X0MWA`07AbM01bM700MGMc07MiM@1kOgX0MGMe07IhMP1dMW@0KW9]0P1^L6`0>@1c
Mg80LW5^07=eL@1gMWD0J6YX07=cK01XH5`0LgId07UlNP1bM700NWah079aKP1/JfP0Lg=^07UfMP1d
MgL0M7=`08N5O`1hMgH0MWAh07]hN01nNGL0LgEa06EPG@1kNgH0OGQe081nNP1cKV/0Lg1^071cL`1_
KV/0Ogik05mUH01fLF`0N7Md07UhM@1mO7T0O7]j06IVH@1^M6l0LgId079cM01JF580M75_096@S@20
PWh0P7ek06meM01/KV`0O7Yf07EcM@1iN7L0OWej08B4O@1^Ieh0N7=`08N5P@0207j1N@0Q079fL@1j
O7P0MgIc06Y/J01PH5/0GUaH081kN01WI680MG9`06i/J024OWT0L6]X08:4O`1YJ6D0P7ml08>0OP29
Q7l0LVeZ07IcL@1kMW@0LG=_07QhL@1cMG40N7Ec075^K01iM740NG]f07AaK`1hO7L0PGYh07EhN01j
NGH0Lg9_01l0oooo02L0]KFe0;6a/@2][Jd0/k>c0;Ng]`2o_kl0/k>c0;Fe]@2a/K40YZJV0:2PX02V
YZH0[jn_0:f][@2_[jl0]kNg09ZJVP2_[jl0VYZJ0:BTY02k^k/0[Jf]0;fm_@2c/k<0[Jf]0:n_[`2k
^k/0/K6a0;no_`3Fe]H0^KVi0;Fe]@0?3`l0_kno0:n_[`2DU9@0/K6a0;no_`39bLT00P2_[jl0>031
`L40ZZZZ0<O7a`28R8P0UYJF0;Fe]@2k^k/0`l?30;Vi^@31`L40UYJF0:n_[`2][Jd0/K6a07moO`2a
/K40bLW90<?3``39bLT0Z:RX0<71`@2i^KT0/k>c0;^k^`35aLD0YZJV0:f][@2i^KT0e]KF0<G5a@31
`L40[Jf]0;fm_@2g]kL0UYJF08Z:RP26QXH0bLW90;>c/`3=cLd0YZJV0=7Ad@2ZZZX0]kNg09bLW039
bLT0clo?0<g=c@2][Jd0]KFe0;no_`2[Zj/0_Kfm0:n_[`2i^KT0Zj^[0P2k^k/01P2a/K40^KVi0<_;
b`2c/k<0_Kfm0:n_[aT0oooo000G0?ooo`1N07EdL@1_LW00KVe/07AfM01_LW00LgEc07MfM@1bM780
MGQf071bKP1eLW80Mg5b06abK`1aL6d0M7=`07IhMP1bM780M7=b07]jM`1fNWD0Mg]f07j4O`1gNGD0
UIRF06meLP21P7d0LW5^06maK@1nP7`0LgE`07YjM@1aLW<0NWaj07YnN@1gMW<0KFa[07UiM01lO7L0
LG5/07mnN`1kNWL0OX9m071_K01iN7D0Kfi[07=cKP1mNgL0NWii07f1O01dMgD0NG]g07]jM`1eM740
Kfi[07AcLP1kNWL0Kfi[07AhL`1kNGD0N7=a07YiMP20Q7l0NWQd07YlNP1gM780Lg=/07YlN01jNGH0
Kfi[07UkM`1bM700LFmY075ZG`1SG5X0K6YV07QcL01iMW@0L6m^07ehM@1hLfh0NWUf08F5O01bKFP0
KW5_07akN01lOWX0MG9`06EXJ01bLFh0OWej06MTHP1fLg40LW5`06YYJ080MWUi00P0MgUe07AaK`1f
N7@0N7Yf07EeL01eKV`0NGMc07QeLal0oooo02d0/k>c0:RXZ02VYZH0/K6a0:RXZ02_[jl0]kNg0:f]
[@2c/k<0ZZZZ0::RXP2g]kL0XZ:R0:^[Z`2a/K40]KFe0:f][@2a/K40_kno09bLW02g]kL0aLG50;Ng
]`2i^KT0l_;b0<_;b`2][Jd0Z:RX0;Vi^@2_[jl0_Kfm0:^[Z`2c/k<0_Kfm0;Ng]`2TY:@0_Kfm0;^k
^`2[Zj/0alO70;no_`2][Jd0aLG50;^k^`2XZ:P00P2_[jl0402m_Kd0`l?30;>c/`2a/K40^k^k0;>c
/`2XZ:P0Zj^[0;6a/@2o_kl0/K6a09JFUP2o_kl0^KVi0<W9b@2e]KD20;fm_@070;Ng]`2m_Kd0`L71
0;fm_@2XZ:P0[Jf]0;no_`020:^[Z`0;092@T033`l<0^KVi0;^k^`2ZZZX0^KVi0<_;b`2m_Kd0dm?C
0:f][@3AdM400P31`L40202c/k<0XZ:R0:f][@35aLD0V9RH0;Fe]@2k^k/0WYjN0P2e]KD0102g]kL0
/K6a0;Fe]@2i^KT20;>c/`030;^k^`2i^KT0oooo01P0oooo000G0?ooo`1X07EdL@1dLg00LgUf075c
L@1dLG40N7Ec07IeLP1iN7D0MgIc07akN01bLG00NgYi06m^K@1/KVX0LWA`07agM@1dLg00MGQ`06eX
IP1cLW40MG9b06e_J`1cMG40E5EF06Q^K@1iN7D0O7]h06maK@1gNGD0NG]g0822OP1dN7<0LVm]07Qg
M01aL6d0NWUf07UhM@23QH40NG]g07b0N`1eMg<0LW1/07ekM`1aL6d0NWUf06E/K@1eN7P0RXN507Eb
L01cMg40MGE`06e/J@1lOWX0LgMb07]jM`1eLW80LG1_07eoO@1fMG80N85m08:2N`20NgH0NWaj079`
K024PWh0L6iZ07IfL@1mOg/0OWah08F5P01mP7h0KW9/07IfL@1eL6d0NWQb07YiMP1]KFP0NgYg07=^
K022OG/0O7Yf0861O023Pgh0Ogmj07UiM01eMG00MG5Y06MVH`1iOgX0LgMb075eK`1_Lfh0O7ag07Ie
M01iN7L0PhF107emN01fMW40NGYk06]^K01gNWX0N7Uj07]lO@1lNWHO0?ooo`0U0;>c/`2a/K40[jn_
0:^[Z`2a/K40^KVi0;Fe]@2k^k/0]kNg0<71`@2@T900_kno0:RXZ02RXZ80[Jf]0<71`@2a/K40/k>c
0:BTY02g]kL0/k>c0:BTY02_[jl0]KFe07=cL`2k^k/0`L710:RXZ02a/K40^k^k0<W9b@2a/K40^KVi
0:f][@2[Zj/0_Kfm0;Ng]`020;^k^`0?0<71`@2c/k<0_kno0:f][@2[Zj/0_Kfm0;^k^`2DU9@0g=cL
0;>c/`2][Jd0[jn_0;>c/`31`L40[jn_0080_kno01h0/k>c0<?3``37alL0]KFe0;Vi^@39bLT0]kNg
0;fm_@2][Jd0dM7A0;Fe]@2c/k<0`l?30<G5a@33`l<0^k^k0:JVYP2e]KD0/k>c0;Vi^@2m_Kd0Y:BT
0;no_`3=cLd0bl_;0<71`@3;bl/0clo?0<G5a@2k^k/30;>c/`0@0;^k^`2_[jl0Zj^[0:RXZ02c/k<0
]KFe0;^k^`3?cll0`l?30;Fe]@2k^k/0X:2P0;Ng]`2i^KT0_kno0<71`AT0oooo000G0?ooo`0E07Qf
LP1aLfl0MgYh071bL01nOG`0IfMR079dL01bKfd0OWMf06i]K01VJ6@0MgUe07=eL@1gM780NWMe06U_
JP1/KVX0Ng]f07YjM@1kOgX0LgMb0080MGUd0540MWYe06UXI@1UIF00IfMR06]_J@1fNGL0KW9]07Mi
M@1oOW/0NWUf079_K@1eM740O7ii07ajMP1eLfl0O7ag07QnN`1`MW<0MgYh07YmN`26P7T0K6IO07Ug
L`1jN7@0Kfi[07MiM@1gOGX0MWQf07Q^M@27PGX0NgIc07=^K01nP8@0QWeo08AnM`1nNgT0NWUf079h
L`22Ogd0N7ii07]mN`1gMG40N79[08=lL@1]LF/0Kg=]07QlMP1`M6l0L6iX06YXHP1gMFl0Ogan07Ie
J01[JF<0NGIf07YmN`1mOGP0NG5]06aWHP1lOGh0M75_08EoN021OgL0Q8Ao07alM`26QH80OWej07Qi
NP1nPWd0NGUd0861O01bMW00NGUd079fKP1fOG`0Ngmj07anNP1hNWH0Oh5m07=eL@1gNGD07`3oool0
1P2i^KT0Zj^[0;Ng]`2ZZZX0aLG509RHV080[Jf]00d0aLG50:JVYP2>SXh0]kNg0:n_[`2g]kL0_Kfm
09bLW02RXZ80_kno0;fm_@2ZZZX0[jn_0080/k>c00h0S8b<0;Fe]@2DU9@0V9RH0:2PX02o_kl0YZJV
0;Ng]`37alL0^k^k0;fm_@2c/k<0`L710;^k^`80`L7101H0^KVi0:ZZZP2@T900]kNg0=GEe@2RXZ80
]kNg0;^k^`2XZ:P0]kNg0:f][@2g]kL0]KFe0=KFeP2o_kl0Ogmo0:n_[`35aLD0dM7A0;^k^`35aLD0
_Kfm0P3=cLd0:P2i^KT0_kno0;Ng]`3?cll0ZZZZ0:BTY02XZ:P0ZZZZ0;>c/`2ZZZX0WYjN0;Ng]`26
QXH0]KFe0:2PX02k^k/0`l?30:n_[`2k^k/0XZ:R0<71`@35aLD0dm?C0<_;b`3AdM40_Kfm0=GEe@35
aLD0^KVi0<G5a@2a/K40bl_;0:f][@2k^k/0[Jf]0;Fe]@2o_kl0`L710;Vi^@37alL0[jn_0;Ng]aT0
oooo000G0?ooo`0;06mcK@1eMg<0L7=a075cL@1jNGP0MWEd06aYI`1cMG40M7Qc071dK`1PHUh00P1b
M7007P1jO7P0K6iZ07]jM`1eNG@0Oh:0079eL`1eMg<0MWQd07j0O01dMW80LW5^07=eL@1eMg<0LgEa
07IjM01gNWP0NWii07MiM@1aMG00Mg]f07aiM`1lNgP0OGmj08:0O01mOgd0Jfi/07YnN@1/L6/0OGeh
08>3OP80MWEb03/0M7=`075`K@1oOW/0LWA`0868P@25Qh80MgUd07ekO@1]KFH0K7=b07miO01mPh00
PhMo0820N`1dO7H0Ogaj07eoN`1_KFT0LFaY081kN01cKFP0JW1]07=eL01dMW40MWQc085oM`1^L6`0
K6iZ07eoN`1nNGH0KgEb06Y`J`1jP7/0OX1l075aK022P7`0OGId07UkN@1fMG80O7]j07UkN@21Q880
MWUg06mcKP1jOWT0MgMb07IfK`1mOGP0I6AO07IhMP1bLG00MWAf07]oN@22QX40Oh5m07mlNP1mNWP0
MG9`07UfM00O0?ooo`0;0:RXZ02c/k<0ZZZZ0:^[Z`2m_Kd0]KFe0::RXP2_[jl0/K6a0:ZZZP1oOgl0
0P2][Jd02@2m_Kd0XZ:R0;no_`2c/k<0alO70:f][@2ZZZX0]KFe0<G5a@020;6a/@0C0:f][@2c/k<0
[jn_0;Fe]@2k^k/0_Kfm0;Ng]`2[Zj/0/K6a0;Ng]`31`L40`l?30:f][@3=cLd0X:2P0;fm_@2RXZ80
^KVi0<?3``020;Fe]@0g0:^[Z`2a/K40alO70:f][@2i^KT0bl_;0=?Cd`33`l<0Y:BT0:^[Z`2RXZ80
alO70<o?c`2g]kL0bLW90;6a/@33`l<0_kno0:RXZ02[Zj/0bLW909jNWP2g]kL0[jn_0;6a/@3;bl/0
X:2P0:JVYP2RXZ80`l?30::RXP2XZ:P0WYjN0;fm_@2[Zj/0[jn_0<g=c@33`l<0^k^k0<W9b@31`L40
^k^k0<_;b`2g]kL0Z:RX0;fm_@2g]kL0]KFe09ZJVP2BTY80]KFe0:f][@2e]KD0_kno0<g=c@020<O7
a`030<?3``2c/k<0^k^k01T0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo000T0?ooo`=00000C@3oool2@0000:X0oooo000U0?ooo`03@000
003oool0oooo04h0oooo00=000000?ooo`3oool0Y`3oool001H0oooo0d0000020?ooo`E0000000D0
oooo@000003ooom000000?ooo`03@0000080oooo0d0000030?ooo`9000003P3oool3@00000<0oooo
0T0000020?ooo`=000000`3oool2@0000080oooo0d00000=0?ooo`=0000000L0oooo@000003ooom0
00000?oood000000oooo00A000000P3oool3@0000080oooo0T00001?0?ooo`=0000000@0oooo@000
003oool0oooo0T0000030?ooo`=00000A`3oool001H0oooo00=000000?oood0000000P3oool3@000
00080?oood000000oooo@000003ooom000000?oood0000020?ooo`04@000003oool0oooo@00000<0
oooo00=000000?ooo`3oool03P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@000
0080oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000003oool0oooo@00000l0oooo00U0
00000?ooo`3ooom000000?oood000000oooo@000003oool00d0000020?ooo`06@000003oool0oooo
@000003ooom00000DP3oool01T000000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3o
oom00000A`3oool001P0oooo00=000000?ooo`3oool00P3oool02D000000oooo@000003ooom00000
0?oood000000oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo0d00000>0?ooo`03@000
003oool0oooo0080oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom00000
0080oooo00A000000?ooo`3ooom000003`3oool024000000oooo0?oood000000oooo@000003ooom0
00000`3oool014000000oooo0?oood0000020?ooo`03@000003ooom0000000900000D03oool3@000
0080oooo0d0000020?ooo`04@000003oool0oooo@00004L0oooo000G0?ooo`03@000003oool0oooo
0080oooo0T0000001P3ooom00000@000003ooom000000?ooo`A000000`3oool014000000oooo0?oo
o`3oool3@00000h0oooo0d0000030?ooo`9000000`3oool00d000000oooo0?ooo`020?ooo`900000
0P3oool4@00000`0oooo0T0000020?ooo`90000000<0oooo@000003oool00P3oool2@00000<0oooo
0d000000103ooom00000@0000400001@0?ooo`05@000003oool0oooo@000003oool00d0000030?oo
o`=00000A`3oool001H0oooo00=000000?oood0000004P3oool00d000000oooo0?ooo`0M0?ooo`03
@000003oool0oooo07d0oooo00A000000?ooo`3ooom000002@3oool00d000000oooo0?ooo`150?oo
o`005P3oool3@0000140oooo0T00000N0?ooo`9000006@3oool00d000000oooo0?ooo`1R0?ooo`A0
00002@3oool2@00004L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo000Y0?ooo`900000:`3oool3@00007/0oooo0d0000190?ooo`00:`3o
ool00d000000oooo0?ooo`0Y0?ooo`03@000003oool0oooo07/0oooo00=000000?ooo`3oool0B03o
ool001d0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool01D000004
0?ooo`03@000003oool0oooo00P0oooo0d0000020?ooo`E0000000D0oooo@000003ooom000000?oo
o`03@0000080oooo0d0000030?ooo`9000003P3oool6@0000080oooo00=000000?ooo`3oool00d00
000:0?ooo`=000000`3oool2@0000080oooo0T00000<0?ooo`=000000`3oool2@0000080oooo0d00
00030?ooo`9000000P3oool3@00000d0oooo0d0000030?ooo`90000000L0oooo@000003ooom00000
0?oood000000oooo00=000000`3oool2@00000030?oood00001000000080oooo00=000000?ooo`3o
ool00T0000000`3ooom00000@00000020?ooo`03@000003oool0oooo009000000P3oool2@00002/0
oooo000N0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03
@000003oool0oooo00P0oooo00=000000?ooo`3oool03`3oool00d000000oooo@00000020?ooo`=0
000000P0oooo@000003ooom000000?oood000000oooo@0000080oooo00A000000?ooo`3ooom00000
0`3oool00d000000oooo0?ooo`0>0?ooo`=000000P3oool01T000000oooo0?oood000000oooo@000
0080oooo00=000000?ooo`3oool02@3oool01D000000oooo0?ooo`3ooom000000080oooo00E00000
0?ooo`3oool0oooo@000000;0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000
0P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom000003P3oool00d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo0090000000H0oooo@000003ooom000000?oood00
00020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@000
00040?ooo`06@000003oool0oooo@000003ooom000000P3oool01D000000oooo0?ooo`3ooom00000
02X0oooo000N0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?oo
o`03@000003oool0oooo00P0oooo00=000000?ooo`3oool04@3oool00d000000oooo0?ooo`020?oo
o`09@000003ooom000000?oood000000oooo@000003ooom000000080oooo00A000000?ooo`3ooom0
00000`3oool3@0000100oooo00A000000?ooo`3ooom000000P3oool00d000000oooo@00000020?oo
o`03@000003oool0oooo00T0oooo00E000000?ooo`3oool0oooo@00000050?ooo`03@000003oool0
oooo00X0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000020?ooo`05@000003o
ool0oooo0?oood0000000P3oool014000000oooo0?oood00000>0?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool00T0000001P3ooom000000?oood000000oooo@0000080oooo00=00000
0?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom00000009000000P3oool0
1T000000oooo0?oood000000oooo@00000D0oooo00=000000?ooo`3oool0:@3oool001h0oooo0T00
00030?ooo`900000103oool3@00000X0oooo00=000000?ooo`3oool0403oool00d000000oooo0?oo
o`020?ooo`90000000H0oooo@00004000000oooo@000003oool4@00000<0oooo00A000000?ooo`3o
ool0oooo0d00000?0?ooo`90000000<0oooo@000040000000T0000030?ooo`=000002P3oool2@000
0080oooo140000030?ooo`9000002`3oool3@00000<0oooo0T0000030?ooo`03@000003oool0oooo
0080oooo0T0000020?ooo`A00000303oool3@00000<0oooo0T0000001P3ooom00000@000003ooom0
00000?ooo`A000000`3oool2@00000030?oood0000100000009000000P3oool3@00000030?oood00
001000000090000000<0oooo@000040000000T0000030?ooo`900000:P3oool001h0oooo00A00000
0?ooo`3ooom00000503oool00d000000oooo0?ooo`0?0?ooo`03@000003ooom000000180oooo00=0
00000?ooo`3oool07`3oool00d000000oooo0?ooo`0=0?ooo`03@000003oool0oooo01/0oooo00=0
00000?ooo`3oool0?P3oool00d000000oooo0?ooo`0_0?ooo`007@3oool5@0000080oooo00=00000
0?ooo`3oool03P3oool2@0000140oooo0d00000A0?ooo`900000803oool2@00000/0oooo00=00000
0?ooo`3oool07P3oool2@0000780oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.111801, -0.0500106, 
  0.00774775, 0.00774775}, {{14.375, 137.313}, {280.5, 
  157.563}} -> {-28.6172, -10.4982, 1.22116, 1.22116}, {{149.625, 272.563}, {
  280.5, 157.563}} -> {-193.779, -10.4982, 1.22116, 1.22116}, {{14.375, 
  137.313}, {145.313, 22.375}} -> {-29.5078, -177.887, 1.2329, 1.2329}, {{
  149.625, 272.563}, {145.313, 22.375}} -> {-193.779, -175.584, 1.22116, 
  1.22116}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.4 Color characteristic vectors",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman"],
  StyleBox[
  "Color image is always composed of the three-color components depending on \
a wavelength of light [2]. The longest, middle and shortest wavelengths are \
corresponding to the red, green and blue color components, respectively. \
Since a classification of the color components is based on this fact, then \
project the red, green and blue respectively to the x-, y- and z-axes \
components of a Cartesian coordinate system yields a set of three-dimensional \
vectors. This defines the three-dimensional color image characteristic \
vectors. Figure 2 shows the color characteristic vectors of the sample image \
in Fig. 1.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
vectored3D=Flatten[Table[{{j,i,k},(0.1/Sqrt[3.])*
\t\t{sample[[1,i,j]],sample[[2,i,j]],sample[[3,i,j]]}},
\t\t{i,1,dim[[2]],2},{j,1,dim[[3]],2},{k,1}],2];\
\>", "Input",
  CellLabel->"In[24]:=",
  FormatType->InputForm],

Cell[CellGroupData[{

Cell["\<\
ListPlotVectorField3D[vectored3D,
\tVectorHeads -> True,ColorFunction->hueColor,
\tPlotLabel->\"Fig.2. Color vectors\",
\tBoxRatios -> {1, 1, 0.1},Boxed->False];
Show[GraphicsArray[{colorBar10}],ImageSize->{200,20}]; \
\>", "Input",
  CellLabel->"In[25]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-016 1.04846 -0.144512 1.04846 [
[.5 .67125 -62 0 ]
[.5 .67125 62 12.5625 ]
[ 0 0 0 0 ]
[ 1 .65875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .67125 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.2) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
141.000000 12.812500 moveto
(vectors) show
183.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .65875 L
0 .65875 L
closepath
clip
newpath
.618 .252 1 r
.5 Mabswid
.40773 .5943 m
.40666 .63266 L
s
.55 .269 1 r
.41586 .59196 m
.41488 .63001 L
s
.559 .267 1 r
.40292 .58997 m
.4018 .62805 L
s
.485 .287 1 r
.424 .58961 m
.42311 .62736 L
s
.342 .378 1 r
.41106 .58762 m
.41009 .62301 L
s
.372 .52 1 r
.43218 .58725 m
.43148 .62027 L
s
.56 .267 1 r
.39807 .58562 m
.39692 .62342 L
s
.512 .279 1 r
.41922 .58526 m
.41827 .6234 L
s
.522 .277 1 r
.44037 .58489 m
.43966 .6227 L
s
.618 .252 1 r
.40716 .61681 m
.40687 .62494 L
s
.40688 .62491 m
.40716 .61681 L
s
.40716 .61681 m
.40666 .63266 L
s
.578 .262 1 r
.40623 .58325 m
.4051 .62279 L
s
.618 .252 1 r
.42741 .58289 m
.42653 .62175 L
s
.734 .224 1 r
.44859 .58252 m
.44793 .62241 L
s
.55 .269 1 r
.41533 .61442 m
.41507 .62235 L
s
.41508 .62232 m
.41533 .61442 L
s
.41533 .61442 m
.41488 .63001 L
s
.638 .247 1 r
.39321 .58124 m
.39194 .62047 L
s
.608 .254 1 r
.41441 .58088 m
.41339 .61977 L
s
.618 .252 1 r
.40687 .62494 m
.40659 .63308 L
s
.40666 .63266 m
.40687 .62494 L
s
.40659 .63308 m
.40688 .62491 L
s
.40688 .62491 m
.40666 .63266 L
s
.588 .259 1 r
.43562 .58051 m
.43484 .61907 L
s
.41 .682 1 r
.45684 .58015 m
.45639 .61154 L
s
.559 .267 1 r
.40231 .61242 m
.40202 .62039 L
s
.40203 .62036 m
.40231 .61242 L
s
.40231 .61242 m
.4018 .62805 L
s
.485 .287 1 r
.42353 .61203 m
.42329 .61976 L
s
.4233 .61973 m
.42353 .61203 L
s
.42353 .61203 m
.42311 .62736 L
s
1 .159 .96 r
.40138 .57887 m
.40007 .62258 L
s
.372 .52 1 r
.43182 .60659 m
.43161 .61363 L
s
.43163 .6136 m
.43182 .60659 L
s
.43182 .60659 m
.43148 .62027 L
s
.834 .201 1 r
.42261 .5785 m
.42162 .61982 L
s
.55 .269 1 r
.41507 .62235 m
.41482 .63029 L
s
.41488 .63001 m
.41507 .62235 L
s
.41482 .63029 m
.41508 .62232 L
s
.41508 .62232 m
.41488 .63001 L
s
.342 .378 1 r
.41053 .60867 m
.41028 .61589 L
s
.41029 .61586 m
.41053 .60867 L
s
.41053 .60867 m
.41009 .62301 L
s
.618 .252 1 r
.44386 .57813 m
.44316 .61706 L
s
.669 .239 1 r
.46511 .57776 m
.46463 .61738 L
s
.618 .252 1 r
.40666 .63266 m
.40659 .63308 L
s
.521 .277 1 r
.38831 .57685 m
.38703 .61511 L
s
.765 .217 1 r
.40957 .57648 m
.40844 .61748 L
s
.559 .267 1 r
.40202 .62039 m
.40174 .62837 L
s
.4018 .62805 m
.40202 .62039 L
s
.40174 .62837 m
.40203 .62036 L
s
.40203 .62036 m
.4018 .62805 L
s
.485 .287 1 r
.42329 .61976 m
.42306 .6275 L
s
.42311 .62736 m
.42329 .61976 L
s
.42306 .6275 m
.4233 .61973 L
s
.4233 .61973 m
.42311 .62736 L
s
.628 .249 1 r
.43084 .57611 m
.42998 .61575 L
s
.372 .52 1 r
.45212 .57574 m
.45158 .60958 L
s
.56 .267 1 r
.39745 .60779 m
.39714 .61581 L
s
.39716 .61578 m
.39745 .60779 L
s
.39745 .60779 m
.39692 .62342 L
s
.372 .52 1 r
.43161 .61363 m
.43142 .62067 L
s
.43148 .62027 m
.43161 .61363 L
s
.43142 .62067 m
.43163 .6136 L
s
.43163 .6136 m
.43148 .62027 L
s
.589 .259 1 r
.4734 .57538 m
.47303 .614 L
s
.512 .279 1 r
.41871 .60791 m
.41845 .61572 L
s
.41847 .61569 m
.41871 .60791 L
s
.41871 .60791 m
.41827 .6234 L
s
.55 .269 1 r
.41488 .63001 m
.41482 .63029 L
s
.342 .378 1 r
.41028 .61589 m
.41004 .62311 L
s
.41009 .62301 m
.41028 .61589 L
s
.41004 .62311 m
.41029 .61586 L
s
.41029 .61586 m
.41009 .62301 L
s
.522 .277 1 r
.44 .60721 m
.43979 .61509 L
s
.43981 .61506 m
.44 .60721 L
s
.44 .60721 m
.43966 .6227 L
s
.733 .224 1 r
.3965 .57445 m
.39519 .61583 L
s
.56 .267 1 r
.41779 .57409 m
.41681 .61273 L
s
.598 .257 1 r
.43909 .57372 m
.43833 .61305 L
s
.765 .217 1 r
.4604 .57335 m
.45985 .6144 L
s
.559 .267 1 r
.4018 .62805 m
.40174 .62837 L
s
.62 .251 1 r
.48172 .57298 m
.48143 .61232 L
s
.485 .287 1 r
.42311 .62736 m
.42306 .6275 L
s
.578 .262 1 r
.4056 .6069 m
.40532 .61483 L
s
.40533 .6148 m
.4056 .6069 L
s
.4056 .6069 m
.4051 .62279 L
s
.618 .252 1 r
.42694 .60579 m
.4267 .61393 L
s
.42672 .61389 m
.42694 .60579 L
s
.42694 .60579 m
.42653 .62175 L
s
.372 .52 1 r
.43148 .62027 m
.43142 .62067 L
s
.56 .267 1 r
.38339 .57242 m
.38204 .61108 L
s
.39714 .61581 m
.39685 .62384 L
s
.39692 .62342 m
.39714 .61581 L
s
.39685 .62384 m
.39716 .61578 L
s
.39716 .61578 m
.39692 .62342 L
s
.777 .214 1 r
.40471 .57205 m
.40353 .61278 L
s
.734 .224 1 r
.44826 .60597 m
.44806 .61438 L
s
.44807 .61435 m
.44826 .60597 L
s
.44826 .60597 m
.44793 .62241 L
s
.41 .682 1 r
.45662 .59852 m
.45648 .60523 L
s
.45649 .60521 m
.45662 .59852 L
s
.45662 .59852 m
.45639 .61154 L
s
.342 .378 1 r
.41009 .62301 m
.41004 .62311 L
s
.45 .297 1 r
.42603 .57168 m
.42518 .60864 L
s
.512 .279 1 r
.41845 .61572 m
.41821 .62354 L
s
.41827 .6234 m
.41845 .61572 L
s
.41821 .62354 m
.41847 .61569 L
s
.41847 .61569 m
.41827 .6234 L
s
.522 .277 1 r
.43979 .61509 m
.4396 .62298 L
s
.43966 .6227 m
.43979 .61509 L
s
.4396 .62298 m
.43981 .61506 L
s
.43981 .61506 m
.43966 .6227 L
s
.35 .414 1 r
.44737 .57131 m
.44678 .60588 L
s
.367 .322 1 r
.46871 .57094 m
.46831 .60688 L
s
.638 .247 1 r
.39252 .6044 m
.39219 .61257 L
s
.39221 .61254 m
.39252 .6044 L
s
.39252 .6044 m
.39194 .62047 L
s
.608 .254 1 r
.41386 .60384 m
.41359 .61194 L
s
.4136 .61191 m
.41386 .60384 L
s
.41386 .60384 m
.41339 .61977 L
s
.367 .322 1 r
.49007 .57057 m
.48988 .60652 L
s
.588 .259 1 r
.43521 .60324 m
.43499 .6113 L
s
.435 .61127 m
.43521 .60324 L
s
.43521 .60324 m
.43484 .61907 L
s
.424 .305 1 r
.39159 .57002 m
.39037 .60734 L
s
.385 .317 1 r
.41294 .56965 m
.41199 .60526 L
s
.352 .327 1 r
.4343 .56928 m
.43356 .60489 L
s
.578 .262 1 r
.40532 .61483 m
.40504 .62276 L
s
.4051 .62279 m
.40532 .61483 L
s
.40504 .62276 m
.40533 .6148 L
s
.40533 .6148 m
.4051 .62279 L
s
.618 .252 1 r
.4267 .61393 m
.42647 .62206 L
s
.42653 .62175 m
.4267 .61393 L
s
.42647 .62206 m
.42672 .61389 L
s
.42672 .61389 m
.42653 .62175 L
s
.416 .307 1 r
.45567 .56891 m
.45513 .60556 L
s
.41 .682 1 r
.45648 .60523 m
.45634 .61194 L
s
.45639 .61154 m
.45648 .60523 L
s
.45634 .61194 m
.45649 .60521 L
s
.45649 .60521 m
.45639 .61154 L
s
.56 .267 1 r
.39692 .62342 m
.39685 .62384 L
s
.703 .231 1 r
.47705 .56853 m
.4767 .60828 L
s
.734 .224 1 r
.44806 .61438 m
.44787 .6228 L
s
.44793 .62241 m
.44806 .61438 L
s
.44787 .6228 m
.44807 .61435 L
s
.44807 .61435 m
.44793 .62241 L
s
.512 .279 1 r
.41827 .6234 m
.41821 .62354 L
s
.712 .229 1 r
.49843 .56816 m
.49833 .60791 L
s
.45 .297 1 r
.37844 .56798 m
.37707 .60567 L
s
.522 .277 1 r
.43966 .6227 m
.4396 .62298 L
s
.618 .252 1 r
.4435 .60108 m
.44329 .60922 L
s
.4433 .60919 m
.4435 .60108 L
s
.4435 .60108 m
.44316 .61706 L
s
.521 .277 1 r
.39981 .56761 m
.39865 .60599 L
s
.834 .201 1 r
.42208 .6029 m
.42181 .6115 L
s
.42183 .61146 m
.42208 .6029 L
s
.42208 .6029 m
.42162 .61982 L
s
.669 .239 1 r
.46488 .60115 m
.46472 .6094 L
s
.46474 .60937 m
.46488 .60115 L
s
.46488 .60115 m
.46463 .61738 L
s
.608 .254 1 r
.4212 .56723 m
.42024 .60631 L
s
1 .159 .96 r
.40066 .60482 m
.40032 .61377 L
s
.40034 .61373 m
.40066 .60482 L
s
.40066 .60482 m
.40007 .62258 L
s
.638 .247 1 r
.39219 .61257 m
.39188 .62075 L
s
.39194 .62047 m
.39219 .61257 L
s
.39188 .62075 m
.39221 .61254 L
s
.39221 .61254 m
.39194 .62047 L
s
.608 .254 1 r
.41359 .61194 m
.41333 .62005 L
s
.41339 .61977 m
.41359 .61194 L
s
.41333 .62005 m
.4136 .61191 L
s
.4136 .61191 m
.41339 .61977 L
s
.485 .287 1 r
.44259 .56686 m
.44189 .60491 L
s
.372 .52 1 r
.45185 .59576 m
.45168 .60277 L
s
.4517 .60274 m
.45185 .59576 L
s
.45185 .59576 m
.45158 .60958 L
s
.588 .259 1 r
.43499 .6113 m
.43478 .61938 L
s
.43484 .61907 m
.43499 .6113 L
s
.43478 .61938 m
.435 .61127 L
s
.435 .61127 m
.43484 .61907 L
s
.521 .277 1 r
.3876 .59953 m
.38728 .6074 L
s
.38729 .60737 m
.3876 .59953 L
s
.3876 .59953 m
.38703 .61511 L
s
.476 .29 1 r
.46399 .56649 m
.46353 .60386 L
s
.531 .274 1 r
.48541 .56612 m
.48516 .60418 L
s
.41 .682 1 r
.45639 .61154 m
.45634 .61194 L
s
.834 .201 1 r
.50683 .56575 m
.50681 .60725 L
s
.579 .262 1 r
.38666 .56556 m
.38535 .60397 L
s
.578 .262 1 r
.4051 .62279 m
.40504 .62276 L
s
.765 .217 1 r
.40895 .60079 m
.40866 .60922 L
s
.40867 .60919 m
.40895 .60079 L
s
.40895 .60079 m
.40844 .61748 L
s
.628 .249 1 r
.43038 .59965 m
.43014 .60777 L
s
.43016 .60774 m
.43038 .59965 L
s
.43038 .59965 m
.42998 .61575 L
s
.618 .252 1 r
.42653 .62175 m
.42647 .62206 L
s
.94 .179 1 r
.40806 .56519 m
.40686 .60807 L
s
.589 .259 1 r
.47324 .59814 m
.4731 .60622 L
s
.47311 .60619 m
.47324 .59814 L
s
.47324 .59814 m
.47303 .614 L
s
.701 .232 1 r
.42948 .56481 m
.42859 .60495 L
s
.734 .224 1 r
.44793 .62241 m
.44787 .6228 L
s
.376 .32 1 r
.45091 .56444 m
.45034 .60012 L
s
.618 .252 1 r
.44329 .60922 m
.4431 .61737 L
s
.44316 .61706 m
.44329 .60922 L
s
.4431 .61737 m
.4433 .60919 L
s
.4433 .60919 m
.44316 .61706 L
s
.522 .277 1 r
.47234 .56407 m
.47196 .60249 L
s
.56 .267 1 r
.41726 .59696 m
.417 .60495 L
s
.41701 .60492 m
.41726 .59696 L
s
.41726 .59696 m
.41681 .61273 L
s
.345 .389 1 r
.49379 .56369 m
.49365 .59835 L
s
.834 .201 1 r
.42181 .6115 m
.42156 .6201 L
s
.42162 .61982 m
.42181 .6115 L
s
.42156 .6201 m
.42183 .61146 L
s
.42183 .61146 m
.42162 .61982 L
s
.638 .247 1 r
.39194 .62047 m
.39188 .62075 L
s
.372 .52 1 r
.45168 .60277 m
.45153 .60978 L
s
.45158 .60958 m
.45168 .60277 L
s
.45153 .60978 m
.4517 .60274 L
s
.4517 .60274 m
.45158 .60958 L
s
.669 .239 1 r
.46472 .6094 m
.46457 .61766 L
s
.46463 .61738 m
.46472 .6094 L
s
.45 .297 1 r
.37347 .56351 m
.37206 .60057 L
s
.669 .239 1 r
.46457 .61766 m
.46474 .60937 L
s
.46474 .60937 m
.46463 .61738 L
s
.608 .254 1 r
.41339 .61977 m
.41333 .62005 L
s
.638 .247 1 r
.51525 .56332 m
.51532 .60279 L
s
.733 .224 1 r
.39577 .59919 m
.39545 .60749 L
s
.39547 .60746 m
.39577 .59919 L
s
.39577 .59919 m
.39519 .61583 L
s
.588 .259 1 r
.43484 .61907 m
.43478 .61938 L
s
1 .159 .96 r
.40032 .61377 m
.4 .62273 L
s
.40007 .62258 m
.40032 .61377 L
s
.598 .257 1 r
.43869 .59707 m
.43847 .60513 L
s
.43849 .6051 m
.43869 .59707 L
s
.43869 .59707 m
.43833 .61305 L
s
1 .159 .96 r
.4 .62273 m
.40034 .61373 L
s
.40034 .61373 m
.40007 .62258 L
s
.503 .282 1 r
.3949 .56313 m
.3937 .60089 L
s
.521 .277 1 r
.38728 .6074 m
.38697 .61528 L
s
.38703 .61511 m
.38728 .6074 L
s
.38697 .61528 m
.38729 .60737 L
s
.38729 .60737 m
.38703 .61511 L
s
.669 .239 1 r
.41634 .56276 m
.4153 .60292 L
s
.62 .251 1 r
.4816 .59627 m
.48148 .6044 L
s
.4815 .60437 m
.4816 .59627 L
s
.4816 .59627 m
.48143 .61232 L
s
.45 .297 1 r
.43779 .56238 m
.43706 .59912 L
s
.765 .217 1 r
.46013 .59769 m
.45995 .60613 L
s
.45997 .60609 m
.46013 .59769 L
s
.46013 .59769 m
.45985 .6144 L
s
.35 .414 1 r
.44707 .59167 m
.44689 .59893 L
s
.4469 .5989 m
.44707 .59167 L
s
.44707 .59167 m
.44678 .60588 L
s
.56 .267 1 r
.38264 .59531 m
.3823 .6033 L
s
.38232 .60327 m
.38264 .59531 L
s
.38264 .59531 m
.38204 .61108 L
s
.669 .239 1 r
.45925 .56201 m
.4587 .60184 L
s
.628 .249 1 r
.43014 .60777 m
.42992 .61589 L
s
.42998 .61575 m
.43014 .60777 L
s
.45 .297 1 r
.42558 .59346 m
.42535 .6012 L
s
.42536 .60117 m
.42558 .59346 L
s
.42558 .59346 m
.42518 .60864 L
s
.628 .249 1 r
.42992 .61589 m
.43016 .60774 L
s
.43016 .60774 m
.42998 .61575 L
s
.765 .217 1 r
.40866 .60922 m
.40837 .61766 L
s
.40844 .61748 m
.40866 .60922 L
s
.40837 .61766 m
.40867 .60919 L
s
.40867 .60919 m
.40844 .61748 L
s
.347 .403 1 r
.48072 .56164 m
.48044 .597 L
s
.589 .259 1 r
.4731 .60622 m
.47297 .61431 L
s
.47303 .614 m
.4731 .60622 L
s
.47297 .61431 m
.47311 .60619 L
s
.47311 .60619 m
.47303 .614 L
s
.367 .322 1 r
.46853 .59215 m
.46839 .59965 L
s
.4684 .59962 m
.46853 .59215 L
s
.46853 .59215 m
.46831 .60688 L
s
.521 .277 1 r
.5022 .56126 m
.50213 .59973 L
s
.777 .214 1 r
.40407 .59606 m
.40376 .60458 L
s
.40377 .60454 m
.40407 .59606 L
s
.40407 .59606 m
.40353 .61278 L
s
.504 .282 1 r
.3817 .56107 m
.38034 .5992 L
s
.367 .322 1 r
.49001 .59178 m
.48991 .59929 L
s
.48993 .59926 m
.49001 .59178 L
s
.49001 .59178 m
.48988 .60652 L
s
.38 .553 1 r
.52369 .56089 m
.52383 .59455 L
s
.55 .269 1 r
.40316 .5607 m
.40198 .60055 L
s
.618 .252 1 r
.44316 .61706 m
.4431 .61737 L
s
.372 .52 1 r
.45158 .60958 m
.45153 .60978 L
s
.669 .239 1 r
.42464 .56032 m
.42369 .60052 L
s
.385 .317 1 r
.41244 .59048 m
.41218 .59809 L
s
.41219 .59806 m
.41244 .59048 L
s
.41244 .59048 m
.41199 .60526 L
s
.56 .267 1 r
.417 .60495 m
.41675 .61294 L
s
.41681 .61273 m
.417 .60495 L
s
.41675 .61294 m
.41701 .60492 L
s
.41701 .60492 m
.41681 .61273 L
s
.424 .305 1 r
.39091 .59222 m
.39061 .59983 L
s
.39062 .5998 m
.39091 .59222 L
s
.39091 .59222 m
.39037 .60734 L
s
.69 .234 1 r
.44612 .55995 m
.44541 .6005 L
s
.669 .239 1 r
.46463 .61738 m
.46457 .61766 L
s
.834 .201 1 r
.42162 .61982 m
.42156 .6201 L
s
.352 .327 1 r
.43391 .59026 m
.4337 .59773 L
s
.43372 .5977 m
.43391 .59026 L
s
.43391 .59026 m
.43356 .60489 L
s
.521 .277 1 r
.38703 .61511 m
.38697 .61528 L
s
.368 .497 1 r
.46762 .55957 m
.46723 .59359 L
s
.733 .224 1 r
.39545 .60749 m
.39514 .6158 L
s
.39519 .61583 m
.39545 .60749 L
s
.598 .257 1 r
.43847 .60513 m
.43827 .61319 L
s
.43833 .61305 m
.43847 .60513 L
s
.733 .224 1 r
.39514 .6158 m
.39547 .60746 L
s
.39547 .60746 m
.39519 .61583 L
s
.598 .257 1 r
.43827 .61319 m
.43849 .6051 L
s
.43849 .6051 m
.43833 .61305 L
s
.402 .648 1 r
.48912 .5592 m
.48896 .59047 L
s
1 .159 .96 r
.40007 .62258 m
.4 .62273 L
s
.416 .307 1 r
.4554 .59053 m
.45523 .59818 L
s
.45524 .59815 m
.4554 .59053 L
s
.4554 .59053 m
.45513 .60556 L
s
.375 .32 1 r
.36846 .55901 m
.36705 .5951 L
s
.391 .315 1 r
.51064 .55882 m
.51066 .59526 L
s
.35 .414 1 r
.44689 .59893 m
.44673 .60619 L
s
.44678 .60588 m
.44689 .59893 L
s
.44673 .60619 m
.4469 .5989 L
s
.4469 .5989 m
.44678 .60588 L
s
.62 .251 1 r
.48148 .6044 m
.48137 .61254 L
s
.48143 .61232 m
.48148 .6044 L
s
.48137 .61254 m
.4815 .60437 L
s
.4815 .60437 m
.48143 .61232 L
s
.383 .317 1 r
.38995 .55863 m
.38873 .59541 L
s
.765 .217 1 r
.45995 .60613 m
.45979 .61458 L
s
.45985 .6144 m
.45995 .60613 L
s
.45979 .61458 m
.45997 .60609 L
s
.45997 .60609 m
.45985 .6144 L
s
.56 .267 1 r
.3823 .6033 m
.38198 .6113 L
s
.38204 .61108 m
.3823 .6033 L
s
.357 .451 1 r
.53216 .55845 m
.53239 .59282 L
s
.56 .267 1 r
.38198 .6113 m
.38232 .60327 L
s
.38232 .60327 m
.38204 .61108 L
s
.45 .297 1 r
.42535 .6012 m
.42512 .60895 L
s
.42518 .60864 m
.42535 .6012 L
s
.42512 .60895 m
.42536 .60117 L
s
.42536 .60117 m
.42518 .60864 L
s
1 .161 .972 r
.41145 .55826 m
.41027 .60159 L
s
.628 .249 1 r
.42998 .61575 m
.42992 .61589 L
s
.765 .217 1 r
.40844 .61748 m
.40837 .61766 L
s
.367 .322 1 r
.46839 .59965 m
.46826 .60716 L
s
.46831 .60688 m
.46839 .59965 L
s
.589 .259 1 r
.47303 .614 m
.47297 .61431 L
s
.703 .231 1 r
.4769 .59188 m
.47676 .60027 L
s
.47678 .60024 m
.4769 .59188 L
s
.4769 .59188 m
.4767 .60828 L
s
.367 .322 1 r
.46826 .60716 m
.4684 .59962 L
s
.4684 .59962 m
.46831 .60688 L
s
.337 .354 1 r
.43296 .55788 m
.4322 .59364 L
s
.45 .297 1 r
.37767 .59039 m
.37734 .59808 L
s
.37735 .59805 m
.37767 .59039 L
s
.37767 .59039 m
.37707 .60567 L
s
.367 .322 1 r
.48991 .59929 m
.48983 .60679 L
s
.48988 .60652 m
.48991 .59929 L
s
.712 .229 1 r
.49843 .59149 m
.49834 .59991 L
s
.49836 .59988 m
.49843 .59149 L
s
.49843 .59149 m
.49833 .60791 L
s
.367 .322 1 r
.48983 .60679 m
.48993 .59926 L
s
.48993 .59926 m
.48988 .60652 L
s
.744 .222 1 r
.45448 .55751 m
.45387 .59809 L
s
.777 .214 1 r
.40376 .60458 m
.40346 .6131 L
s
.40353 .61278 m
.40376 .60458 L
s
.40346 .6131 m
.40377 .60454 L
s
.40377 .60454 m
.40353 .61278 L
s
.521 .277 1 r
.39917 .59036 m
.39887 .59826 L
s
.39889 .59823 m
.39917 .59036 L
s
.39917 .59036 m
.39865 .60599 L
s
.68 .237 1 r
.47601 .55713 m
.47565 .59703 L
s
.385 .317 1 r
.41218 .59809 m
.41193 .60571 L
s
.41199 .60526 m
.41218 .59809 L
s
.608 .254 1 r
.42069 .5903 m
.42043 .59844 L
s
.42044 .59841 m
.42069 .5903 L
s
.42069 .5903 m
.42024 .60631 L
s
.588 .259 1 r
.49755 .55675 m
.49742 .59631 L
s
.385 .317 1 r
.41193 .60571 m
.41219 .59806 L
s
.41219 .59806 m
.41199 .60526 L
s
.56 .267 1 r
.41681 .61273 m
.41675 .61294 L
s
.485 .287 1 r
.44222 .58946 m
.44202 .59725 L
s
.44204 .59722 m
.44222 .58946 L
s
.44222 .58946 m
.44189 .60491 L
s
.494 .285 1 r
.37671 .55656 m
.37529 .59475 L
s
.424 .305 1 r
.39061 .59983 m
.39031 .60744 L
s
.39037 .60734 m
.39061 .59983 L
s
.39031 .60744 m
.39062 .5998 L
s
.39062 .5998 m
.39037 .60734 L
s
.476 .29 1 r
.46377 .58851 m
.46362 .59634 L
s
.46363 .59631 m
.46377 .58851 L
s
.46377 .58851 m
.46353 .60386 L
s
.352 .327 1 r
.4337 .59773 m
.43351 .6052 L
s
.43356 .60489 m
.4337 .59773 L
s
.701 .232 1 r
.5191 .55638 m
.51921 .59767 L
s
.352 .327 1 r
.43351 .6052 m
.43372 .5977 L
s
.43372 .5977 m
.43356 .60489 L
s
.618 .252 1 r
.39823 .55619 m
.39702 .59541 L
s
.372 .52 1 r
.54065 .556 m
.54096 .58937 L
s
.598 .257 1 r
.43833 .61305 m
.43827 .61319 L
s
.531 .274 1 r
.48532 .58855 m
.4852 .59651 L
s
.48522 .59648 m
.48532 .58855 L
s
.48532 .58855 m
.48516 .60418 L
s
.744 .222 1 r
.41976 .55581 m
.41875 .59642 L
s
.733 .224 1 r
.39519 .61583 m
.39514 .6158 L
s
.35 .414 1 r
.44678 .60588 m
.44673 .60619 L
s
.416 .307 1 r
.45523 .59818 m
.45507 .60583 L
s
.45513 .60556 m
.45523 .59818 L
s
.45507 .60583 m
.45524 .59815 L
s
.45524 .59815 m
.45513 .60556 L
s
.486 .287 1 r
.44131 .55543 m
.4406 .59294 L
s
.579 .262 1 r
.38594 .58812 m
.38561 .59623 L
s
.38562 .5962 m
.38594 .58812 L
s
.38594 .58812 m
.38535 .60397 L
s
.62 .251 1 r
.48143 .61232 m
.48137 .61254 L
s
.754 .219 1 r
.46286 .55506 m
.46233 .59636 L
s
.45 .297 1 r
.42518 .60864 m
.42512 .60895 L
s
.56 .267 1 r
.38204 .61108 m
.38198 .6113 L
s
.376 .32 1 r
.45062 .58535 m
.45044 .59294 L
s
.45046 .59291 m
.45062 .58535 L
s
.45062 .58535 m
.45034 .60012 L
s
.765 .217 1 r
.45985 .6144 m
.45979 .61458 L
s
.744 .222 1 r
.48442 .55468 m
.48415 .5953 L
s
.367 .322 1 r
.46831 .60688 m
.46826 .60716 L
s
.834 .201 1 r
.50687 .59025 m
.5068 .59889 L
s
.50682 .59885 m
.50687 .59025 L
s
.50687 .59025 m
.50681 .60725 L
s
.618 .252 1 r
.36343 .55449 m
.3618 .59442 L
s
.345 .389 1 r
.49376 .58403 m
.49367 .59138 L
s
.49369 .59135 m
.49376 .58403 L
s
.49376 .58403 m
.49365 .59835 L
s
.45 .297 1 r
.37734 .59808 m
.37701 .60577 L
s
.37707 .60567 m
.37734 .59808 L
s
.522 .277 1 r
.506 .5543 m
.50597 .59251 L
s
.45 .297 1 r
.37701 .60577 m
.37735 .59805 L
s
.37735 .59805 m
.37707 .60567 L
s
.367 .322 1 r
.48988 .60652 m
.48983 .60679 L
s
.703 .231 1 r
.47676 .60027 m
.47664 .60867 L
s
.4767 .60828 m
.47676 .60027 L
s
.588 .259 1 r
.38498 .55411 m
.38363 .59301 L
s
.703 .231 1 r
.47664 .60867 m
.47678 .60024 L
s
.47678 .60024 m
.4767 .60828 L
s
.701 .232 1 r
.42901 .58851 m
.42876 .59687 L
s
.42878 .59684 m
.42901 .58851 L
s
.42901 .58851 m
.42859 .60495 L
s
.36 .325 1 r
.52758 .55392 m
.52778 .59111 L
s
.712 .229 1 r
.49834 .59991 m
.49827 .60833 L
s
.49833 .60791 m
.49834 .59991 L
s
.579 .262 1 r
.40654 .55373 m
.40542 .59264 L
s
.712 .229 1 r
.49827 .60833 m
.49836 .59988 L
s
.49836 .59988 m
.49833 .60791 L
s
.521 .277 1 r
.39887 .59826 m
.39859 .60616 L
s
.39865 .60599 m
.39887 .59826 L
s
.522 .277 1 r
.47217 .58685 m
.47203 .59476 L
s
.47204 .59473 m
.47217 .58685 L
s
.47217 .58685 m
.47196 .60249 L
s
.521 .277 1 r
.39859 .60616 m
.39889 .59823 L
s
.39889 .59823 m
.39865 .60599 L
s
.94 .179 1 r
.40741 .59061 m
.40709 .59943 L
s
.40711 .59939 m
.40741 .59061 L
s
.40741 .59061 m
.40686 .60807 L
s
.777 .214 1 r
.40353 .61278 m
.40346 .6131 L
s
.45 .297 1 r
.37269 .58534 m
.37234 .59311 L
s
.37235 .59308 m
.37269 .58534 L
s
.37269 .58534 m
.37206 .60057 L
s
.834 .201 1 r
.54917 .55354 m
.54965 .59522 L
s
.385 .317 1 r
.41199 .60526 m
.41193 .60571 L
s
.45 .297 1 r
.4281 .55336 m
.42727 .59054 L
s
.352 .327 1 r
.43356 .60489 m
.43351 .6052 L
s
.424 .305 1 r
.39037 .60734 m
.39031 .60744 L
s
.608 .254 1 r
.42043 .59844 m
.42018 .60659 L
s
.42024 .60631 m
.42043 .59844 L
s
.485 .287 1 r
.44202 .59725 m
.44183 .60505 L
s
.44189 .60491 m
.44202 .59725 L
s
.608 .254 1 r
.42018 .60659 m
.42044 .59841 L
s
.42044 .59841 m
.42024 .60631 L
s
.485 .287 1 r
.44183 .60505 m
.44204 .59722 L
s
.44204 .59722 m
.44189 .60491 L
s
.503 .282 1 r
.39424 .58538 m
.39393 .59329 L
s
.39395 .59326 m
.39424 .58538 L
s
.39424 .58538 m
.3937 .60089 L
s
.495 .284 1 r
.44968 .55298 m
.44907 .59051 L
s
.476 .29 1 r
.46362 .59634 m
.46347 .60417 L
s
.46353 .60386 m
.46362 .59634 L
s
.46347 .60417 m
.46363 .59631 L
s
.46363 .59631 m
.46353 .60386 L
s
.638 .247 1 r
.51535 .58662 m
.5153 .59484 L
s
.51532 .59481 m
.51535 .58662 L
s
.51535 .58662 m
.51532 .60279 L
s
.494 .284 1 r
.47127 .5526 m
.47087 .59083 L
s
.45 .297 1 r
.43742 .58392 m
.4372 .59173 L
s
.43722 .59169 m
.43742 .58392 L
s
.43742 .58392 m
.43706 .59912 L
s
.531 .274 1 r
.4852 .59651 m
.48511 .60449 L
s
.48516 .60418 m
.4852 .59651 L
s
.48511 .60449 m
.48522 .59648 L
s
.48522 .59648 m
.48516 .60418 L
s
.416 .307 1 r
.45513 .60556 m
.45507 .60583 L
s
.648 .244 1 r
.49287 .55222 m
.4927 .59184 L
s
.347 .403 1 r
.4806 .58264 m
.48049 .58989 L
s
.48051 .58986 m
.4806 .58264 L
s
.4806 .58264 m
.48044 .597 L
s
.598 .257 1 r
.37169 .55203 m
.37016 .59165 L
s
.669 .239 1 r
.41578 .58657 m
.4155 .59483 L
s
.41552 .5948 m
.41578 .58657 L
s
.41578 .58657 m
.4153 .60292 L
s
.559 .267 1 r
.51447 .55184 m
.51454 .59043 L
s
.38 .553 1 r
.52382 .5808 m
.5238 .58778 L
s
.52381 .58775 m
.52382 .5808 L
s
.52382 .5808 m
.52383 .59455 L
s
.45 .297 1 r
.39327 .55165 m
.39204 .58955 L
s
.579 .262 1 r
.38561 .59623 m
.38528 .60435 L
s
.38535 .60397 m
.38561 .59623 L
s
.38528 .60435 m
.38562 .5962 L
s
.38562 .5962 m
.38535 .60397 L
s
.376 .32 1 r
.45044 .59294 m
.45028 .60053 L
s
.45034 .60012 m
.45044 .59294 L
s
.777 .214 1 r
.53609 .55146 m
.53642 .59247 L
s
.376 .32 1 r
.45028 .60053 m
.45046 .59291 L
s
.45046 .59291 m
.45034 .60012 L
s
.669 .239 1 r
.45898 .58552 m
.4588 .59382 L
s
.45882 .59379 m
.45898 .58552 L
s
.45898 .58552 m
.4587 .60184 L
s
.733 .224 1 r
.41487 .55127 m
.4138 .59194 L
s
.442 .3 1 r
.55772 .55108 m
.55824 .5883 L
s
.345 .389 1 r
.49367 .59138 m
.4936 .59873 L
s
.49365 .59835 m
.49367 .59138 L
s
.4936 .59873 m
.49369 .59135 L
s
.49369 .59135 m
.49365 .59835 L
s
.402 .648 1 r
.48908 .57728 m
.48899 .58419 L
s
.489 .58416 m
.48908 .57728 L
s
.48908 .57728 m
.48896 .59047 L
s
.512 .279 1 r
.43647 .55089 m
.43568 .58949 L
s
.45 .297 1 r
.37707 .60567 m
.37701 .60577 L
s
.521 .277 1 r
.50221 .58407 m
.50214 .59198 L
s
.50216 .59195 m
.50221 .58407 L
s
.50221 .58407 m
.50213 .59973 L
s
.504 .282 1 r
.38095 .58364 m
.38061 .59152 L
s
.38062 .59149 m
.38095 .58364 L
s
.38095 .58364 m
.38034 .5992 L
s
.834 .201 1 r
.5068 .59889 m
.50675 .60753 L
s
.50681 .60725 m
.5068 .59889 L
s
.50675 .60753 m
.50682 .59885 L
s
.50682 .59885 m
.50681 .60725 L
s
.68 .237 1 r
.45808 .55051 m
.45752 .5905 L
s
.703 .231 1 r
.4767 .60828 m
.47664 .60867 L
s
.368 .497 1 r
.46743 .57964 m
.4673 .58675 L
s
.46731 .58672 m
.46743 .57964 L
s
.46743 .57964 m
.46723 .59359 L
s
.701 .232 1 r
.42876 .59687 m
.42853 .60523 L
s
.42859 .60495 m
.42876 .59687 L
s
.42853 .60523 m
.42878 .59684 L
s
.42878 .59684 m
.42859 .60495 L
s
.521 .277 1 r
.39865 .60599 m
.39859 .60616 L
s
.711 .229 1 r
.4797 .55013 m
.47938 .59047 L
s
.712 .229 1 r
.49833 .60791 m
.49827 .60833 L
s
.522 .277 1 r
.47203 .59476 m
.4719 .60267 L
s
.47196 .60249 m
.47203 .59476 L
s
.4719 .60267 m
.47204 .59473 L
s
.47204 .59473 m
.47196 .60249 L
s
.45 .297 1 r
.37234 .59311 m
.372 .60088 L
s
.37206 .60057 m
.37234 .59311 L
s
.372 .60088 m
.37235 .59308 L
s
.37235 .59308 m
.37206 .60057 L
s
.344 .33 1 r
.35837 .54994 m
.35686 .5858 L
s
.55 .269 1 r
.4025 .58463 m
.40221 .59252 L
s
.40222 .59249 m
.4025 .58463 L
s
.4025 .58463 m
.40198 .60055 L
s
.618 .252 1 r
.50133 .54975 m
.50126 .58906 L
s
.94 .179 1 r
.40709 .59943 m
.40679 .60826 L
s
.40686 .60807 m
.40709 .59943 L
s
.40679 .60826 m
.40711 .59939 L
s
.40711 .59939 m
.40686 .60807 L
s
.679 .237 1 r
.37998 .54956 m
.37849 .5906 L
s
.485 .287 1 r
.44189 .60491 m
.44183 .60505 L
s
.476 .29 1 r
.46353 .60386 m
.46347 .60417 L
s
.608 .254 1 r
.42024 .60631 m
.42018 .60659 L
s
.669 .239 1 r
.42413 .58416 m
.42387 .59243 L
s
.42389 .59239 m
.42413 .58416 L
s
.42413 .58416 m
.42369 .60052 L
s
.503 .282 1 r
.39393 .59329 m
.39363 .6012 L
s
.3937 .60089 m
.39393 .59329 L
s
.335 .341 1 r
.52298 .54937 m
.52313 .58489 L
s
.503 .282 1 r
.39363 .6012 m
.39395 .59326 L
s
.39395 .59326 m
.3937 .60089 L
s
.375 .32 1 r
.36768 .58027 m
.36732 .58783 L
s
.36734 .58781 m
.36768 .58027 L
s
.36768 .58027 m
.36705 .5951 L
s
.589 .259 1 r
.40159 .54918 m
.40041 .5885 L
s
.357 .451 1 r
.53234 .57869 m
.53234 .58591 L
s
.53235 .58588 m
.53234 .57869 L
s
.53234 .57869 m
.53239 .59282 L
s
.45 .297 1 r
.4372 .59173 m
.437 .59953 L
s
.43706 .59912 m
.4372 .59173 L
s
.579 .262 1 r
.54463 .54899 m
.54503 .58796 L
s
.391 .315 1 r
.5107 .58032 m
.51065 .58792 L
s
.51066 .58789 m
.5107 .58032 L
s
.5107 .58032 m
.51066 .59526 L
s
.45 .297 1 r
.437 .59953 m
.43722 .59169 L
s
.43722 .59169 m
.43706 .59912 L
s
.638 .247 1 r
.5153 .59484 m
.51527 .60307 L
s
.51532 .60279 m
.5153 .59484 L
s
.69 .234 1 r
.44575 .58403 m
.44554 .59233 L
s
.44556 .5923 m
.44575 .58403 L
s
.44575 .58403 m
.44541 .6005 L
s
.638 .247 1 r
.51527 .60307 m
.51532 .59481 L
s
.51532 .59481 m
.51532 .60279 L
s
.522 .277 1 r
.42322 .5488 m
.4223 .58709 L
s
.531 .274 1 r
.48516 .60418 m
.48511 .60449 L
s
.347 .403 1 r
.48049 .58989 m
.48039 .59714 L
s
.48044 .597 m
.48049 .58989 L
s
.48039 .59714 m
.48051 .58986 L
s
.48051 .58986 m
.48044 .597 L
s
.383 .317 1 r
.38927 .58047 m
.38896 .58801 L
s
.38898 .58798 m
.38927 .58047 L
s
.38927 .58047 m
.38873 .59541 L
s
.88 .191 1 r
.56629 .54861 m
.56698 .5907 L
s
.38 .553 1 r
.5238 .58778 m
.52379 .59475 L
s
.52383 .59455 m
.5238 .58778 L
s
.52379 .59475 m
.52381 .58775 L
s
.52381 .58775 m
.52383 .59455 L
s
.385 .576 1 r
.44486 .54842 m
.44423 .58326 L
s
.376 .32 1 r
.45034 .60012 m
.45028 .60053 L
s
.337 .354 1 r
.43256 .57908 m
.43235 .58644 L
s
.43236 .58641 m
.43256 .57908 L
s
.43256 .57908 m
.4322 .59364 L
s
.669 .239 1 r
.4155 .59483 m
.41524 .6031 L
s
.4153 .60292 m
.4155 .59483 L
s
.41524 .6031 m
.41552 .5948 L
s
.41552 .5948 m
.4153 .60292 L
s
.579 .262 1 r
.38535 .60397 m
.38528 .60435 L
s
.598 .257 1 r
.4665 .54804 m
.46603 .58806 L
s
.345 .389 1 r
.49365 .59835 m
.4936 .59873 L
s
.402 .648 1 r
.48899 .58419 m
.48891 .59109 L
s
.48896 .59047 m
.48899 .58419 L
s
.48891 .59109 m
.489 .58416 L
s
.489 .58416 m
.48896 .59047 L
s
.408 .31 1 r
.48816 .54766 m
.48795 .58492 L
s
.669 .239 1 r
.4588 .59382 m
.45864 .60213 L
s
.4587 .60184 m
.4588 .59382 L
s
.701 .231 1 r
.36665 .54747 m
.36505 .5875 L
s
.669 .239 1 r
.45864 .60213 m
.45882 .59379 L
s
.45882 .59379 m
.4587 .60184 L
s
.598 .257 1 r
.50983 .54728 m
.50984 .588 L
s
.521 .277 1 r
.50214 .59198 m
.50208 .5999 L
s
.50213 .59973 m
.50214 .59198 L
s
.50208 .5999 m
.50216 .59195 L
s
.50216 .59195 m
.50213 .59973 L
s
.504 .282 1 r
.38061 .59152 m
.38028 .59941 L
s
.38034 .5992 m
.38061 .59152 L
s
.368 .497 1 r
.4673 .58675 m
.46718 .59386 L
s
.46723 .59359 m
.4673 .58675 L
s
.504 .282 1 r
.38028 .59941 m
.38062 .59149 L
s
.38062 .59149 m
.38034 .5992 L
s
.368 .497 1 r
.46718 .59386 m
.46731 .58672 L
s
.46731 .58672 m
.46723 .59359 L
s
.494 .284 1 r
.38829 .54709 m
.387 .58505 L
s
.372 .52 1 r
.54088 .57554 m
.54089 .58266 L
s
.54091 .58263 m
.54088 .57554 L
s
.54088 .57554 m
.54096 .58937 L
s
.669 .239 1 r
.53151 .5469 m
.53177 .58728 L
s
.834 .201 1 r
.50681 .60725 m
.50675 .60753 L
s
.55 .269 1 r
.40994 .54671 m
.40887 .58536 L
s
.45 .297 1 r
.37206 .60057 m
.372 .60088 L
s
1 .161 .972 r
.41082 .58381 m
.4105 .59286 L
s
.41052 .59282 m
.41082 .58381 L
s
.41082 .58381 m
.41027 .60159 L
s
.744 .222 1 r
.45417 .58143 m
.45398 .58991 L
s
.454 .58988 m
.45417 .58143 L
s
.45417 .58143 m
.45387 .59809 L
s
.522 .277 1 r
.47196 .60249 m
.4719 .60267 L
s
.733 .224 1 r
.55319 .54652 m
.55371 .58725 L
s
.701 .232 1 r
.42859 .60495 m
.42853 .60523 L
s
.68 .237 1 r
.47585 .58065 m
.47571 .58899 L
s
.47573 .58896 m
.47585 .58065 L
s
.47585 .58065 m
.47565 .59703 L
s
.701 .232 1 r
.4316 .54633 m
.43073 .58672 L
s
.494 .285 1 r
.37592 .5792 m
.37557 .58706 L
s
.37559 .58703 m
.37592 .5792 L
s
.37592 .5792 m
.37529 .59475 L
s
.55 .269 1 r
.40221 .59252 m
.40193 .60041 L
s
.40198 .60055 m
.40221 .59252 L
s
.711 .229 1 r
.57489 .54614 m
.57565 .58653 L
s
.55 .269 1 r
.40193 .60041 m
.40222 .59249 L
s
.40222 .59249 m
.40198 .60055 L
s
.588 .259 1 r
.49753 .58028 m
.49744 .58835 L
s
.49746 .58831 m
.49753 .58028 L
s
.49753 .58028 m
.49742 .59631 L
s
.543 .271 1 r
.45327 .54594 m
.45271 .58288 L
s
.503 .282 1 r
.3937 .60089 m
.39363 .6012 L
s
.357 .451 1 r
.53234 .58591 m
.53235 .59313 L
s
.53239 .59282 m
.53234 .58591 L
s
.53235 .59313 m
.53235 .58588 L
s
.53235 .58588 m
.53239 .59282 L
s
.375 .32 1 r
.36732 .58783 m
.36698 .59541 L
s
.36705 .5951 m
.36732 .58783 L
s
.36698 .59541 m
.36734 .58781 L
s
.36734 .58781 m
.36705 .5951 L
s
.669 .239 1 r
.42387 .59243 m
.42363 .6007 L
s
.42369 .60052 m
.42387 .59243 L
s
.94 .179 1 r
.40686 .60807 m
.40679 .60826 L
s
.669 .239 1 r
.42363 .6007 m
.42389 .59239 L
s
.42389 .59239 m
.42369 .60052 L
s
.45 .297 1 r
.43706 .59912 m
.437 .59953 L
s
.618 .252 1 r
.39757 .5793 m
.39726 .58751 L
s
.39727 .58748 m
.39757 .5793 L
s
.39757 .5793 m
.39702 .59541 L
s
.531 .274 1 r
.47495 .54556 m
.4746 .58389 L
s
.391 .315 1 r
.51065 .58792 m
.51061 .59553 L
s
.51066 .59526 m
.51065 .58792 L
s
.38 .553 1 r
.52383 .59455 m
.52379 .59475 L
s
.391 .315 1 r
.51061 .59553 m
.51066 .58789 L
s
.51066 .58789 m
.51066 .59526 L
s
.347 .403 1 r
.48044 .597 m
.48039 .59714 L
s
.485 .287 1 r
.35328 .54537 m
.3516 .5837 L
s
.638 .247 1 r
.51532 .60279 m
.51527 .60307 L
s
.486 .287 1 r
.44095 .5775 m
.44074 .58539 L
s
.44075 .58536 m
.44095 .5775 L
s
.44095 .5775 m
.4406 .59294 L
s
.383 .317 1 r
.38896 .58801 m
.38867 .59555 L
s
.38873 .59541 m
.38896 .58801 L
s
.711 .229 1 r
.49665 .54518 m
.49652 .58558 L
s
.383 .317 1 r
.38867 .59555 m
.38898 .58798 L
s
.38898 .58798 m
.38873 .59541 L
s
.69 .234 1 r
.44554 .59233 m
.44535 .60064 L
s
.44541 .6005 m
.44554 .59233 L
s
.44535 .60064 m
.44556 .5923 L
s
.44556 .5923 m
.44541 .6005 L
s
.701 .232 1 r
.51922 .58106 m
.51918 .58935 L
s
.5192 .58931 m
.51922 .58106 L
s
.51922 .58106 m
.51921 .59767 L
s
.459 .295 1 r
.37495 .54499 m
.37352 .58297 L
s
.402 .648 1 r
.48896 .59047 m
.48891 .59109 L
s
.744 .222 1 r
.41923 .57975 m
.41895 .58824 L
s
.41897 .5882 m
.41923 .57975 L
s
.41923 .57975 m
.41875 .59642 L
s
.337 .354 1 r
.43235 .58644 m
.43215 .59381 L
s
.4322 .59364 m
.43235 .58644 L
s
.393 .314 1 r
.51835 .5448 m
.51846 .58037 L
s
.337 .354 1 r
.43215 .59381 m
.43236 .58641 L
s
.43236 .58641 m
.4322 .59364 L
s
.638 .247 1 r
.39663 .54461 m
.39537 .58433 L
s
.833 .201 1 r
.54006 .54442 m
.54044 .58726 L
s
.669 .239 1 r
.4153 .60292 m
.41524 .6031 L
s
.368 .497 1 r
.41831 .54423 m
.41744 .57842 L
s
.608 .254 1 r
.56178 .54403 m
.56238 .58342 L
s
.368 .497 1 r
.46723 .59359 m
.46718 .59386 L
s
.522 .277 1 r
.50604 .57685 m
.50597 .58482 L
s
.50599 .58479 m
.50604 .57685 L
s
.50604 .57685 m
.50597 .59251 L
s
.618 .252 1 r
.44001 .54384 m
.43925 .58323 L
s
.669 .239 1 r
.4587 .60184 m
.45864 .60213 L
s
.754 .219 1 r
.4626 .57958 m
.46243 .58804 L
s
.46245 .58801 m
.4626 .57958 L
s
.4626 .57958 m
.46233 .59636 L
s
.372 .52 1 r
.54089 .58266 m
.54092 .58978 L
s
.54096 .58937 m
.54089 .58266 L
s
.54092 .58978 m
.54091 .58263 L
s
.54091 .58263 m
.54096 .58937 L
s
.36 .325 1 r
.52775 .57621 m
.52773 .58362 L
s
.52775 .58359 m
.52775 .57621 L
s
.52775 .57621 m
.52778 .59111 L
s
.744 .222 1 r
.48432 .57862 m
.4842 .58712 L
s
.48422 .58708 m
.48432 .57862 L
s
.48432 .57862 m
.48415 .5953 L
s
.521 .277 1 r
.50213 .59973 m
.50208 .5999 L
s
.559 .267 1 r
.58351 .54365 m
.58434 .58234 L
s
.504 .282 1 r
.38034 .5992 m
.38028 .59941 L
s
.618 .252 1 r
.36251 .57824 m
.36212 .58638 L
s
.36214 .58635 m
.36251 .57824 L
s
.36251 .57824 m
.3618 .59442 L
s
.588 .259 1 r
.38424 .57704 m
.38389 .58518 L
s
.38391 .58515 m
.38424 .57704 L
s
.38424 .57704 m
.38363 .59301 L
s
.382 .563 1 r
.46171 .54346 m
.4613 .57593 L
s
.45 .297 1 r
.42766 .57527 m
.42743 .58306 L
s
.42744 .58303 m
.42766 .57527 L
s
.42766 .57527 m
.42727 .59054 L
s
.579 .262 1 r
.40593 .5767 m
.40564 .58481 L
s
.40565 .58478 m
.40593 .5767 L
s
.40593 .5767 m
.40542 .59264 L
s
.618 .252 1 r
.48343 .54308 m
.48315 .58247 L
s
1 .149 .907 r
.36158 .54289 m
.35969 .58818 L
s
.495 .284 1 r
.44937 .57502 m
.44918 .58296 L
s
.4492 .58293 m
.44937 .57502 L
s
.44937 .57502 m
.44907 .59051 L
s
.368 .322 1 r
.50516 .54269 m
.50513 .57863 L
s
.357 .451 1 r
.53239 .59282 m
.53235 .59313 L
s
.744 .222 1 r
.45398 .58991 m
.4538 .59841 L
s
.45387 .59809 m
.45398 .58991 L
s
.4538 .59841 m
.454 .58988 L
s
.454 .58988 m
.45387 .59809 L
s
.494 .285 1 r
.37557 .58706 m
.37523 .59492 L
s
.37529 .59475 m
.37557 .58706 L
s
.37523 .59492 m
.37559 .58703 L
s
.37559 .58703 m
.37529 .59475 L
s
.68 .237 1 r
.47571 .58899 m
.47559 .59735 L
s
.47565 .59703 m
.47571 .58899 L
s
.55 .269 1 r
.40198 .60055 m
.40193 .60041 L
s
.347 .403 1 r
.38328 .5425 m
.38202 .5781 L
s
.68 .237 1 r
.47559 .59735 m
.47573 .58896 L
s
.47573 .58896 m
.47565 .59703 L
s
.375 .32 1 r
.36705 .5951 m
.36698 .59541 L
s
1 .161 .972 r
.4105 .59286 m
.4102 .60192 L
s
.41027 .60159 m
.4105 .59286 L
s
.4102 .60192 m
.41052 .59282 L
s
.41052 .59282 m
.41027 .60159 L
s
.66 .241 1 r
.52689 .54231 m
.5271 .58171 L
s
.588 .259 1 r
.49744 .58835 m
.49737 .59642 L
s
.49742 .59631 m
.49744 .58835 L
s
.49737 .59642 m
.49746 .58831 L
s
.49746 .58831 m
.49742 .59631 L
s
.834 .201 1 r
.54951 .57815 m
.54955 .58682 L
s
.54957 .58679 m
.54951 .57815 L
s
.54951 .57815 m
.54965 .59522 L
s
.494 .284 1 r
.47108 .57526 m
.47094 .58313 L
s
.47096 .5831 m
.47108 .57526 L
s
.47108 .57526 m
.47087 .59083 L
s
.391 .315 1 r
.51066 .59526 m
.51061 .59553 L
s
.789 .211 1 r
.40499 .54212 m
.40374 .58465 L
s
1 .143 .88 r
.54864 .54193 m
.54914 .5855 L
s
.669 .239 1 r
.42369 .60052 m
.42363 .6007 L
s
.618 .252 1 r
.39726 .58751 m
.39695 .59572 L
s
.39702 .59541 m
.39726 .58751 L
s
.39695 .59572 m
.39727 .58748 L
s
.39727 .58748 m
.39702 .59541 L
s
.383 .317 1 r
.38873 .59541 m
.38867 .59555 L
s
.416 .307 1 r
.42671 .54173 m
.42582 .57976 L
s
.486 .287 1 r
.44074 .58539 m
.44054 .59329 L
s
.4406 .59294 m
.44074 .58539 L
s
.44054 .59329 m
.44075 .58536 L
s
.44075 .58536 m
.4406 .59294 L
s
.45 .297 1 r
.5704 .54154 m
.57105 .57888 L
s
.337 .354 1 r
.4322 .59364 m
.43215 .59381 L
s
.648 .244 1 r
.49282 .57557 m
.49272 .58386 L
s
.49274 .58383 m
.49282 .57557 L
s
.49282 .57557 m
.4927 .59184 L
s
.69 .234 1 r
.44541 .6005 m
.44535 .60064 L
s
.559 .267 1 r
.51457 .57458 m
.51452 .58266 L
s
.51454 .58263 m
.51457 .57458 L
s
.51457 .57458 m
.51454 .59043 L
s
.669 .239 1 r
.44844 .54135 m
.44776 .58146 L
s
.45 .297 1 r
.39259 .57419 m
.39228 .58192 L
s
.3923 .58189 m
.39259 .57419 L
s
.39259 .57419 m
.39204 .58955 L
s
.701 .232 1 r
.51918 .58935 m
.51916 .59764 L
s
.51921 .59767 m
.51918 .58935 L
s
.51916 .59764 m
.5192 .58931 L
s
.5192 .58931 m
.51921 .59767 L
s
.598 .257 1 r
.37084 .57556 m
.37047 .58367 L
s
.37048 .58364 m
.37084 .57556 L
s
.37084 .57556 m
.37016 .59165 L
s
.68 .237 1 r
.59216 .54116 m
.59311 .58093 L
s
.36 .325 1 r
.47018 .54097 m
.46977 .57831 L
s
.442 .3 1 r
.55808 .57304 m
.55812 .58081 L
s
.55814 .58078 m
.55808 .57304 L
s
.55808 .57304 m
.55824 .5883 L
s
.744 .222 1 r
.41895 .58824 m
.41869 .59674 L
s
.41875 .59642 m
.41895 .58824 L
s
.41869 .59674 m
.41897 .5882 L
s
.41897 .5882 m
.41875 .59642 L
s
.588 .259 1 r
.34817 .54077 m
.3464 .57985 L
s
.372 .52 1 r
.54096 .58937 m
.54092 .58978 L
s
.629 .249 1 r
.49193 .54058 m
.49175 .58001 L
s
.512 .279 1 r
.36989 .54039 m
.36838 .57913 L
s
.43606 .57381 m
.43583 .58172 L
s
.43585 .58169 m
.43606 .57381 L
s
.43606 .57381 m
.43568 .58949 L
s
.777 .214 1 r
.53634 .57564 m
.53634 .58421 L
s
.53636 .58418 m
.53634 .57564 L
s
.53634 .57564 m
.53642 .59247 L
s
.522 .277 1 r
.50597 .58482 m
.50592 .59279 L
s
.50597 .59251 m
.50597 .58482 L
s
.36 .325 1 r
.52773 .58362 m
.52773 .59104 L
s
.52778 .59111 m
.52773 .58362 L
s
.522 .277 1 r
.50592 .59279 m
.50599 .58479 L
s
.50599 .58479 m
.50597 .59251 L
s
.36 .325 1 r
.52773 .59104 m
.52775 .58359 L
s
.52775 .58359 m
.52778 .59111 L
s
.733 .224 1 r
.41429 .57528 m
.414 .58375 L
s
.41402 .58372 m
.41429 .57528 L
s
.41429 .57528 m
.4138 .59194 L
s
.38 .554 1 r
.51369 .5402 m
.51375 .57375 L
s
.344 .33 1 r
.35753 .5711 m
.35716 .57858 L
s
.35717 .57855 m
.35753 .5711 L
s
.35753 .5711 m
.35686 .5858 L
s
.722 .227 1 r
.39163 .54001 m
.39027 .58117 L
s
.754 .219 1 r
.46243 .58804 m
.46227 .59651 L
s
.46233 .59636 m
.46243 .58804 L
s
.46227 .59651 m
.46245 .58801 L
s
.46245 .58801 m
.46233 .59636 L
s
.618 .252 1 r
.36212 .58638 m
.36174 .59453 L
s
.3618 .59442 m
.36212 .58638 L
s
.588 .259 1 r
.38389 .58518 m
.38356 .59333 L
s
.38363 .59301 m
.38389 .58518 L
s
.531 .274 1 r
.53546 .53981 m
.53576 .57821 L
s
.618 .252 1 r
.36174 .59453 m
.36214 .58635 L
s
.36214 .58635 m
.3618 .59442 L
s
.588 .259 1 r
.38356 .59333 m
.38391 .58515 L
s
.38391 .58515 m
.38363 .59301 L
s
.744 .222 1 r
.4842 .58712 m
.48409 .59562 L
s
.48415 .5953 m
.4842 .58712 L
s
.48409 .59562 m
.48422 .58708 L
s
.48422 .58708 m
.48415 .5953 L
s
.335 .341 1 r
.52311 .57029 m
.52309 .57774 L
s
.5231 .57771 m
.52311 .57029 L
s
.52311 .57029 m
.52313 .58489 L
s
.45 .297 1 r
.42743 .58306 m
.42721 .59086 L
s
.42727 .59054 m
.42743 .58306 L
s
.42721 .59086 m
.42744 .58303 L
s
.42744 .58303 m
.42727 .59054 L
s
.68 .237 1 r
.4578 .57408 m
.45762 .58245 L
s
.45764 .58241 m
.4578 .57408 L
s
.4578 .57408 m
.45752 .5905 L
s
.618 .252 1 r
.41337 .53962 m
.41229 .57975 L
s
.579 .262 1 r
.40564 .58481 m
.40536 .59292 L
s
.40542 .59264 m
.40564 .58481 L
s
.638 .247 1 r
.55724 .53943 m
.55781 .5806 L
s
.579 .262 1 r
.40536 .59292 m
.40565 .58478 L
s
.40565 .58478 m
.40542 .59264 L
s
.608 .254 1 r
.43513 .53924 m
.43431 .57903 L
s
.495 .284 1 r
.44918 .58296 m
.44901 .5909 L
s
.44907 .59051 m
.44918 .58296 L
s
.711 .229 1 r
.47957 .57391 m
.47944 .58235 L
s
.47945 .58231 m
.47957 .57391 L
s
.47957 .57391 m
.47938 .59047 L
s
.495 .284 1 r
.44901 .5909 m
.4492 .58293 L
s
.4492 .58293 m
.44907 .59051 L
s
.618 .252 1 r
.50134 .57292 m
.50127 .58114 L
s
.50128 .58111 m
.50134 .57292 L
s
.50134 .57292 m
.50126 .58906 L
s
.45 .297 1 r
.57904 .53904 m
.57979 .57641 L
s
.494 .285 1 r
.37529 .59475 m
.37523 .59492 L
s
.744 .222 1 r
.45387 .59809 m
.4538 .59841 L
s
.733 .224 1 r
.4569 .53885 m
.4563 .57969 L
s
.68 .237 1 r
.47565 .59703 m
.47559 .59735 L
s
.385 .576 1 r
.44452 .56942 m
.44435 .57625 L
s
.44436 .57622 m
.44452 .56942 L
s
.44452 .56942 m
.44423 .58326 L
s
.531 .274 1 r
.60084 .53866 m
.60184 .57672 L
s
.588 .259 1 r
.49742 .59631 m
.49737 .59642 L
s
.494 .284 1 r
.47094 .58313 m
.47082 .59101 L
s
.47087 .59083 m
.47094 .58313 L
s
.47082 .59101 m
.47096 .5831 L
s
.47096 .5831 m
.47087 .59083 L
s
.512 .279 1 r
.47867 .53847 m
.47833 .57827 L
s
.589 .259 1 r
.40095 .57246 m
.40064 .58058 L
s
.40066 .58055 m
.40095 .57246 L
s
.40095 .57246 m
.40041 .5885 L
s
1 .161 .972 r
.41027 .60159 m
.4102 .60192 L
s
.579 .262 1 r
.54492 .572 m
.54494 .58012 L
s
.54496 .58009 m
.54492 .572 L
s
.54492 .572 m
.54503 .58796 L
s
.522 .277 1 r
.42273 .5714 m
.42248 .57938 L
s
.4225 .57935 m
.42273 .5714 L
s
.42273 .5714 m
.4223 .58709 L
s
.868 .194 1 r
.35648 .53827 m
.35465 .58085 L
s
.679 .237 1 r
.37914 .57407 m
.37878 .58233 L
s
.3788 .5823 m
.37914 .57407 L
s
.37914 .57407 m
.37849 .5906 L
s
.834 .201 1 r
.54955 .58682 m
.5496 .59551 L
s
.54965 .59522 m
.54955 .58682 L
s
.5496 .59551 m
.54957 .58679 L
s
.54957 .58679 m
.54965 .59522 L
s
.486 .287 1 r
.4406 .59294 m
.44054 .59329 L
s
.618 .252 1 r
.39702 .59541 m
.39695 .59572 L
s
.578 .262 1 r
.50046 .53808 m
.50037 .57754 L
s
.638 .247 1 r
.37824 .53789 m
.37677 .5777 L
s
.45 .297 1 r
.39228 .58192 m
.39199 .58966 L
s
.39204 .58955 m
.39228 .58192 L
s
.904 .186 1 r
.52225 .5377 m
.52242 .58063 L
s
.45 .297 1 r
.39199 .58966 m
.3923 .58189 L
s
.3923 .58189 m
.39204 .58955 L
s
.648 .244 1 r
.49272 .58386 m
.49264 .59216 L
s
.4927 .59184 m
.49272 .58386 L
s
.559 .267 1 r
.51452 .58266 m
.51449 .59074 L
s
.51454 .59043 m
.51452 .58266 L
s
.648 .244 1 r
.49264 .59216 m
.49274 .58383 L
s
.49274 .58383 m
.4927 .59184 L
s
.559 .267 1 r
.51449 .59074 m
.51454 .58263 L
s
.51454 .58263 m
.51454 .59043 L
s
.66 .241 1 r
.40001 .5375 m
.39878 .57766 L
s
.598 .257 1 r
.37047 .58367 m
.3701 .59179 L
s
.37016 .59165 m
.37047 .58367 L
s
.408 .31 1 r
.48808 .56979 m
.48798 .57742 L
s
.488 .57739 m
.48808 .56979 L
s
.48808 .56979 m
.48795 .58492 L
s
.598 .257 1 r
.3701 .59179 m
.37048 .58364 L
s
.37048 .58364 m
.37016 .59165 L
s
.701 .232 1 r
.51921 .59767 m
.51916 .59764 L
s
.442 .3 1 r
.55812 .58081 m
.55819 .58858 L
s
.55824 .5883 m
.55812 .58081 L
s
.55819 .58858 m
.55814 .58078 L
s
.55814 .58078 m
.55824 .5883 L
s
.777 .214 1 r
.54406 .53731 m
.54448 .57852 L
s
.744 .222 1 r
.41875 .59642 m
.41869 .59674 L
s
.88 .191 1 r
.56676 .57343 m
.56683 .58222 L
s
.56685 .58219 m
.56676 .57343 L
s
.56676 .57343 m
.56698 .5907 L
s
.777 .214 1 r
.42179 .53712 m
.42076 .57902 L
s
.598 .257 1 r
.46627 .57191 m
.46612 .58 L
s
.46613 .57997 m
.46627 .57191 L
s
.46627 .57191 m
.46603 .58806 L
s
.733 .224 1 r
.56588 .53692 m
.56655 .57813 L
s
.36 .325 1 r
.52778 .59111 m
.52773 .59104 L
s
.344 .33 1 r
.35716 .57858 m
.3568 .58607 L
s
.35686 .5858 m
.35716 .57858 L
s
.649 .244 1 r
.44358 .53673 m
.44286 .57621 L
s
.494 .284 1 r
.38758 .56949 m
.38726 .57741 L
s
.38727 .57738 m
.38758 .56949 L
s
.38758 .56949 m
.387 .58505 L
s
.522 .277 1 r
.50597 .59251 m
.50592 .59279 L
s
.344 .33 1 r
.3568 .58607 m
.35717 .57855 L
s
.35717 .57855 m
.35686 .5858 L
s
.512 .279 1 r
.43583 .58172 m
.43563 .58963 L
s
.43568 .58949 m
.43583 .58172 L
s
.43563 .58963 m
.43585 .58169 L
s
.43585 .58169 m
.43568 .58949 L
s
.701 .231 1 r
.36577 .57099 m
.36537 .57944 L
s
.36538 .5794 m
.36577 .57099 L
s
.36577 .57099 m
.36505 .5875 L
s
.618 .252 1 r
.5877 .53654 m
.58859 .57602 L
s
.777 .214 1 r
.53634 .58421 m
.53636 .59279 L
s
.53642 .59247 m
.53634 .58421 L
s
.579 .262 1 r
.46538 .53635 m
.4649 .57548 L
s
.777 .214 1 r
.53636 .59279 m
.53636 .58418 L
s
.53636 .58418 m
.53642 .59247 L
s
.733 .224 1 r
.414 .58375 m
.41373 .59223 L
s
.4138 .59194 m
.414 .58375 L
s
.335 .341 1 r
.52309 .57774 m
.52308 .5852 L
s
.52313 .58489 m
.52309 .57774 L
s
.733 .224 1 r
.41373 .59223 m
.41402 .58372 L
s
.41402 .58372 m
.4138 .59194 L
s
.335 .341 1 r
.52308 .5852 m
.5231 .57771 L
s
.5231 .57771 m
.52313 .58489 L
s
.45 .297 1 r
.42727 .59054 m
.42721 .59086 L
s
.588 .259 1 r
.38363 .59301 m
.38356 .59333 L
s
.8 .209 1 r
.60954 .53615 m
.61075 .57842 L
s
.799 .209 1 r
.34302 .53615 m
.34106 .57807 L
s
.55 .269 1 r
.40936 .56952 m
.40908 .57758 L
s
.40909 .57755 m
.40936 .56952 L
s
.40936 .56952 m
.40887 .58536 L
s
.618 .252 1 r
.3618 .59442 m
.36174 .59453 L
s
.543 .271 1 r
.45301 .56725 m
.45282 .57545 L
s
.45283 .57542 m
.45301 .56725 L
s
.45301 .56725 m
.45271 .58288 L
s
.754 .219 1 r
.46233 .59636 m
.46227 .59651 L
s
.744 .222 1 r
.48415 .5953 m
.48409 .59562 L
s
.35 .413 1 r
.48719 .53596 m
.48698 .57129 L
s
.598 .257 1 r
.50989 .57177 m
.50983 .5798 L
s
.50984 .57977 m
.50989 .57177 L
s
.50989 .57177 m
.50984 .588 L
s
.579 .262 1 r
.40542 .59264 m
.40536 .59292 L
s
.669 .239 1 r
.53172 .57084 m
.53171 .57915 L
s
.53172 .57911 m
.53172 .57084 L
s
.53172 .57084 m
.53177 .58728 L
s
.68 .237 1 r
.45762 .58245 m
.45746 .59082 L
s
.45752 .5905 m
.45762 .58245 L
s
.733 .224 1 r
.36481 .53577 m
.36315 .57665 L
s
.68 .237 1 r
.45746 .59082 m
.45764 .58241 L
s
.45764 .58241 m
.45752 .5905 L
s
.495 .284 1 r
.44907 .59051 m
.44901 .5909 L
s
.608 .254 1 r
.50901 .53557 m
.50902 .57541 L
s
.385 .576 1 r
.44435 .57625 m
.44418 .58308 L
s
.44423 .58326 m
.44435 .57625 L
s
.44418 .58308 m
.44436 .57622 L
s
.44436 .57622 m
.44423 .58326 L
s
.733 .224 1 r
.55355 .57056 m
.55359 .57905 L
s
.55361 .57901 m
.55355 .57056 L
s
.55355 .57056 m
.55371 .58725 L
s
.521 .277 1 r
.3866 .53538 m
.38527 .57418 L
s
.701 .232 1 r
.43114 .57017 m
.4309 .57858 L
s
.43091 .57855 m
.43114 .57017 L
s
.43114 .57017 m
.43073 .58672 L
s
.711 .229 1 r
.47944 .58235 m
.47932 .59079 L
s
.47938 .59047 m
.47944 .58235 L
s
.618 .252 1 r
.50127 .58114 m
.5012 .58938 L
s
.50126 .58906 m
.50127 .58114 L
s
.711 .229 1 r
.47932 .59079 m
.47945 .58231 L
s
.47945 .58231 m
.47938 .59047 L
s
.618 .252 1 r
.5012 .58938 m
.50128 .58111 L
s
.50128 .58111 m
.50126 .58906 L
s
.393 .314 1 r
.51846 .56547 m
.51843 .57321 L
s
.51844 .57318 m
.51846 .56547 L
s
.51846 .56547 m
.51846 .58037 L
s
.503 .282 1 r
.53084 .53519 m
.53109 .57399 L
s
.711 .229 1 r
.57539 .56994 m
.57549 .57839 L
s
.57551 .57836 m
.57539 .56994 L
s
.57539 .56994 m
.57565 .58653 L
s
.531 .274 1 r
.4748 .56815 m
.47466 .57617 L
s
.47468 .57614 m
.4748 .56815 L
s
.4748 .56815 m
.4746 .58389 L
s
.905 .186 1 r
.40841 .53499 m
.40718 .57832 L
s
.494 .284 1 r
.47087 .59083 m
.47082 .59101 L
s
.368 .497 1 r
.41785 .56439 m
.41761 .57154 L
s
.41763 .57151 m
.41785 .56439 L
s
.41785 .56439 m
.41744 .57842 L
s
.485 .287 1 r
.35234 .56813 m
.35194 .57598 L
s
.35195 .57595 m
.35234 .56813 L
s
.35234 .56813 m
.3516 .5837 L
s
.744 .222 1 r
.55268 .5348 m
.5532 .57639 L
s
.382 .563 1 r
.46152 .56229 m
.46137 .56941 L
s
.46139 .56938 m
.46152 .56229 L
s
.46152 .56229 m
.4613 .57593 L
s
.589 .259 1 r
.40064 .58058 m
.40035 .58871 L
s
.40041 .5885 m
.40064 .58058 L
s
.522 .277 1 r
.42248 .57938 m
.42224 .58737 L
s
.4223 .58709 m
.42248 .57938 L
s
.589 .259 1 r
.40035 .58871 m
.40066 .58055 L
s
.40066 .58055 m
.40041 .5885 L
s
.522 .277 1 r
.42224 .58737 m
.4225 .57935 L
s
.4225 .57935 m
.4223 .58709 L
s
.579 .262 1 r
.54494 .58012 m
.54498 .58825 L
s
.54503 .58796 m
.54494 .58012 L
s
.344 .33 1 r
.43022 .53461 m
.42941 .57133 L
s
.579 .262 1 r
.54498 .58825 m
.54496 .58009 L
s
.54496 .58009 m
.54503 .58796 L
s
.459 .295 1 r
.37415 .56754 m
.3738 .57533 L
s
.37381 .5753 m
.37415 .56754 L
s
.37415 .56754 m
.37352 .58297 L
s
.679 .237 1 r
.37878 .58233 m
.37843 .59061 L
s
.37849 .5906 m
.37878 .58233 L
s
.55 .269 1 r
.57453 .53441 m
.57526 .57322 L
s
.679 .237 1 r
.37843 .59061 m
.3788 .5823 L
s
.3788 .5823 m
.37849 .5906 L
s
.834 .201 1 r
.54965 .59522 m
.5496 .59551 L
s
.68 .237 1 r
.45205 .53422 m
.45142 .57407 L
s
.45 .297 1 r
.39204 .58955 m
.39199 .58966 L
s
.711 .229 1 r
.49662 .569 m
.49653 .57745 L
s
.49655 .57741 m
.49662 .569 L
s
.49662 .569 m
.49652 .58558 L
s
.559 .267 1 r
.51454 .59043 m
.51449 .59074 L
s
1 .149 .907 r
.5964 .53402 m
.5975 .57841 L
s
.648 .244 1 r
.4927 .59184 m
.49264 .59216 L
s
.442 .3 1 r
.55824 .5883 m
.55819 .58858 L
s
.408 .31 1 r
.48798 .57742 m
.4879 .58506 L
s
.48795 .58492 m
.48798 .57742 L
s
.4879 .58506 m
.488 .57739 L
s
.488 .57739 m
.48795 .58492 L
s
.531 .274 1 r
.47389 .53383 m
.4735 .573 L
s
.598 .257 1 r
.37016 .59165 m
.3701 .59179 L
s
.638 .247 1 r
.39594 .56805 m
.39562 .57633 L
s
.39563 .5763 m
.39594 .56805 L
s
.39594 .56805 m
.39537 .58433 L
s
.367 .497 1 r
.61827 .53364 m
.61935 .56864 L
s
.588 .259 1 r
.35135 .53364 m
.34961 .57281 L
s
.669 .239 1 r
.49573 .53344 m
.49558 .5747 L
s
.344 .33 1 r
.35686 .5858 m
.3568 .58607 L
s
.598 .257 1 r
.46612 .58 m
.46598 .5881 L
s
.46603 .58806 m
.46612 .58 L
s
.608 .254 1 r
.56219 .56728 m
.56225 .57549 L
s
.56227 .57545 m
.56219 .56728 L
s
.56219 .56728 m
.56238 .58342 L
s
.648 .244 1 r
.37317 .53325 m
.37164 .57312 L
s
.598 .257 1 r
.46598 .5881 m
.46613 .57997 L
s
.46613 .57997 m
.46603 .58806 L
s
.88 .191 1 r
.56683 .58222 m
.56693 .59102 L
s
.56698 .5907 m
.56683 .58222 L
s
.512 .279 1 r
.43568 .58949 m
.43563 .58963 L
s
.618 .252 1 r
.43962 .56705 m
.43939 .5753 L
s
.43941 .57526 m
.43962 .56705 L
s
.43962 .56705 m
.43925 .58323 L
s
.494 .284 1 r
.38726 .57741 m
.38694 .58533 L
s
.387 .58505 m
.38726 .57741 L
s
.559 .267 1 r
.58405 .56645 m
.58416 .57455 L
s
.58418 .57452 m
.58405 .56645 L
s
.58405 .56645 m
.58434 .58234 L
s
.88 .191 1 r
.56693 .59102 m
.56685 .58219 L
s
.56685 .58219 m
.56698 .5907 L
s
.476 .29 1 r
.51759 .53306 m
.51769 .57084 L
s
.494 .284 1 r
.38694 .58533 m
.38727 .57738 L
s
.38727 .57738 m
.387 .58505 L
s
.335 .341 1 r
.52313 .58489 m
.52308 .5852 L
s
.368 .322 1 r
.50519 .56379 m
.50513 .5714 L
s
.50514 .57137 m
.50519 .56379 L
s
.50519 .56379 m
.50513 .57863 L
s
.733 .224 1 r
.395 .53286 m
.39367 .57413 L
s
.701 .231 1 r
.36537 .57944 m
.36498 .58789 L
s
.36505 .5875 m
.36537 .57944 L
s
.347 .403 1 r
.38258 .56364 m
.38226 .57094 L
s
.38228 .57091 m
.38258 .56364 L
s
.38258 .56364 m
.38202 .5781 L
s
.7 .232 1 r
.53946 .53267 m
.53981 .57359 L
s
.701 .231 1 r
.36498 .58789 m
.36538 .5794 L
s
.36538 .5794 m
.36505 .5875 L
s
.777 .214 1 r
.53642 .59247 m
.53636 .59279 L
s
.833 .201 1 r
.54034 .57002 m
.54035 .57862 L
s
.54037 .57859 m
.54034 .57002 L
s
.54034 .57002 m
.54044 .58726 L
s
.733 .224 1 r
.4138 .59194 m
.41373 .59223 L
s
.41684 .53247 m
.41578 .5734 L
s
.55 .269 1 r
.40908 .57758 m
.40881 .58564 L
s
.40887 .58536 m
.40908 .57758 L
s
.40881 .58564 m
.40909 .57755 L
s
.40909 .57755 m
.40887 .58536 L
s
.385 .576 1 r
.44423 .58326 m
.44418 .58308 L
s
.618 .252 1 r
.48332 .56629 m
.4832 .57454 L
s
.48322 .57451 m
.48332 .56629 L
s
.48332 .56629 m
.48315 .58247 L
s
.543 .271 1 r
.45282 .57545 m
.45264 .58365 L
s
.45271 .58288 m
.45282 .57545 L
s
.638 .247 1 r
.56133 .53228 m
.56193 .57251 L
s
.543 .271 1 r
.45264 .58365 m
.45283 .57542 L
s
.45283 .57542 m
.45271 .58288 L
s
.598 .257 1 r
.50983 .5798 m
.50978 .58783 L
s
.50984 .588 m
.50983 .5798 L
s
.50978 .58783 m
.50984 .57977 L
s
.50984 .57977 m
.50984 .588 L
s
.531 1 .914 r
.43869 .53209 m
.43813 .56019 L
s
.68 .237 1 r
.45752 .5905 m
.45746 .59082 L
s
.669 .239 1 r
.53171 .57915 m
.53171 .58746 L
s
.53177 .58728 m
.53171 .57915 L
s
.53171 .58746 m
.53172 .57911 L
s
.53172 .57911 m
.53177 .58728 L
s
.504 .282 1 r
.58322 .53189 m
.58403 .56969 L
s
.744 .222 1 r
.46055 .5317 m
.46 .57263 L
s
.393 .314 1 r
.51843 .57321 m
.51841 .58096 L
s
.51846 .58037 m
.51843 .57321 L
s
.51841 .58096 m
.51844 .57318 L
s
.51844 .57318 m
.51846 .58037 L
s
.618 .252 1 r
.50126 .58906 m
.5012 .58938 L
s
.66 .241 1 r
.52707 .56539 m
.52705 .57378 L
s
.52707 .57375 m
.52707 .56539 L
s
.52707 .56539 m
.5271 .58171 L
s
.368 .497 1 r
.41761 .57154 m
.41739 .57869 L
s
.41744 .57842 m
.41761 .57154 L
s
.41739 .57869 m
.41763 .57151 L
s
.41763 .57151 m
.41744 .57842 L
s
.869 .194 1 r
.60512 .5315 m
.60628 .57383 L
s
.579 .262 1 r
.33785 .5315 m
.33596 .5707 L
s
.711 .229 1 r
.47938 .59047 m
.47932 .59079 L
s
.733 .224 1 r
.55359 .57905 m
.55366 .58754 L
s
.55371 .58725 m
.55359 .57905 L
s
.55366 .58754 m
.55361 .57901 L
s
.55361 .57901 m
.55371 .58725 L
s
.382 .563 1 r
.46137 .56941 m
.46124 .57652 L
s
.4613 .57593 m
.46137 .56941 L
s
.701 .232 1 r
.4309 .57858 m
.43067 .587 L
s
.43073 .58672 m
.4309 .57858 L
s
.382 .563 1 r
.46124 .57652 m
.46139 .56938 L
s
.46139 .56938 m
.4613 .57593 L
s
.531 .274 1 r
.47466 .57617 m
.47454 .5842 L
s
.4746 .58389 m
.47466 .57617 L
s
.701 .232 1 r
.43067 .587 m
.43091 .57855 L
s
.43091 .57855 m
.43073 .58672 L
s
.531 .274 1 r
.47454 .5842 m
.47468 .57614 L
s
.47468 .57614 m
.4746 .58389 L
s
.45 .297 1 r
.57083 .56354 m
.57091 .57136 L
s
.57093 .57133 m
.57083 .56354 L
s
.57083 .56354 m
.57105 .57888 L
s
.701 .232 1 r
.48242 .53131 m
.48212 .5719 L
s
.711 .229 1 r
.57549 .57839 m
.5756 .58685 L
s
.57565 .58653 m
.57549 .57839 L
s
.485 .287 1 r
.35194 .57598 m
.35155 .58384 L
s
.3516 .5837 m
.35194 .57598 L
s
.711 .229 1 r
.5756 .58685 m
.57551 .57836 L
s
.57551 .57836 m
.57565 .58653 L
s
.485 .287 1 r
.35155 .58384 m
.35195 .57595 L
s
.35195 .57595 m
.3516 .5837 L
s
.416 .307 1 r
.42623 .56449 m
.42599 .57211 L
s
.42601 .57208 m
.42623 .56449 L
s
.42623 .56449 m
.42582 .57976 L
s
.81 .206 1 r
.62702 .53111 m
.62844 .57345 L
s
.476 .29 1 r
.3597 .53111 m
.3581 .56893 L
s
.522 .277 1 r
.4223 .58709 m
.42224 .58737 L
s
.589 .259 1 r
.40041 .5885 m
.40035 .58871 L
s
.38 .554 1 r
.51377 .55995 m
.51373 .567 L
s
.51374 .56697 m
.51377 .55995 L
s
.51377 .55995 m
.51375 .57375 L
s
.579 .262 1 r
.54503 .58796 m
.54498 .58825 L
s
.459 .295 1 r
.3738 .57533 m
.37346 .58311 L
s
.37352 .58297 m
.3738 .57533 L
s
.755 .219 1 r
.5043 .53092 m
.50425 .57326 L
s
.459 .295 1 r
.37346 .58311 m
.37381 .5753 L
s
.37381 .5753 m
.37352 .58297 L
s
.629 .249 1 r
.38155 .53073 m
.38015 .56993 L
s
.679 .237 1 r
.37849 .5906 m
.37843 .59061 L
s
.36 .325 1 r
.46998 .56335 m
.46984 .57079 L
s
.46986 .57076 m
.46998 .56335 L
s
.46998 .56335 m
.46977 .57831 L
s
.388 .588 1 r
.52619 .53053 m
.52636 .56453 L
s
.408 .31 1 r
.48795 .58492 m
.4879 .58506 L
s
.669 .239 1 r
.44809 .56503 m
.44789 .57338 L
s
.44791 .57335 m
.44809 .56503 L
s
.44809 .56503 m
.44776 .58146 L
s
.569 .264 1 r
.40342 .53034 m
.40224 .5699 L
s
1 .149 .907 r
.36051 .56994 m
.36006 .57905 L
s
.36008 .57901 m
.36051 .56994 L
s
.36051 .56994 m
.35969 .58818 L
s
.68 .237 1 r
.59277 .56449 m
.59291 .57292 L
s
.59293 .57288 m
.59277 .56449 L
s
.59277 .56449 m
.59311 .58093 L
s
.789 .211 1 r
.4043 .56757 m
.40398 .57608 L
s
.404 .57604 m
.4043 .56757 L
s
.4043 .56757 m
.40374 .58465 L
s
.711 .229 1 r
.49653 .57745 m
.49646 .58591 L
s
.49652 .58558 m
.49653 .57745 L
s
.49646 .58591 m
.49655 .57741 L
s
.49655 .57741 m
.49652 .58558 L
s
.559 .267 1 r
.5481 .53014 m
.54854 .56901 L
s
1 .143 .88 r
.54899 .56738 m
.54903 .57672 L
s
.54905 .57668 m
.54899 .56738 L
s
.54899 .56738 m
.54914 .5855 L
s
.588 .259 1 r
.34718 .5638 m
.34675 .57198 L
s
.34677 .57195 m
.34718 .5638 L
s
.34718 .5638 m
.3464 .57985 L
s
.345 .39 1 r
.42529 .52995 m
.42446 .56534 L
s
.638 .247 1 r
.39562 .57633 m
.39531 .58461 L
s
.39537 .58433 m
.39562 .57633 L
s
.39531 .58461 m
.39563 .5763 L
s
.39563 .5763 m
.39537 .58433 L
s
.629 .249 1 r
.49188 .56378 m
.49178 .57207 L
s
.4918 .57204 m
.49188 .56378 L
s
.49188 .56378 m
.49175 .58001 L
s
.691 .234 1 r
.57001 .52975 m
.57071 .56967 L
s
.512 .279 1 r
.36905 .56339 m
.36867 .57133 L
s
.36869 .5713 m
.36905 .56339 L
s
.36905 .56339 m
.36838 .57913 L
s
.377 .538 1 r
.44718 .52956 m
.44655 .56496 L
s
.598 .257 1 r
.46603 .58806 m
.46598 .5881 L
s
.494 .284 1 r
.387 .58505 m
.38694 .58533 L
s
.608 .254 1 r
.56225 .57549 m
.56233 .5837 L
s
.56238 .58342 m
.56225 .57549 L
s
.56233 .5837 m
.56227 .57545 L
s
.56227 .57545 m
.56238 .58342 L
s
.368 .322 1 r
.50513 .5714 m
.50508 .57901 L
s
.50513 .57863 m
.50513 .5714 L
s
.723 .226 1 r
.59193 .52936 m
.59289 .56963 L
s
.368 .322 1 r
.50508 .57901 m
.50514 .57137 L
s
.50514 .57137 m
.50513 .57863 L
s
.559 .267 1 r
.58416 .57455 m
.58429 .58266 L
s
.58434 .58234 m
.58416 .57455 L
s
.347 .403 1 r
.38226 .57094 m
.38196 .57823 L
s
.38202 .5781 m
.38226 .57094 L
s
.559 .267 1 r
.58429 .58266 m
.58418 .57452 L
s
.58418 .57452 m
.58434 .58234 L
s
.531 .274 1 r
.53569 .56244 m
.53569 .57048 L
s
.53571 .57045 m
.53569 .56244 L
s
.53569 .56244 m
.53576 .57821 L
s
.347 .403 1 r
.38196 .57823 m
.38228 .57091 L
s
.38228 .57091 m
.38202 .5781 L
s
.618 .252 1 r
.43939 .5753 m
.43919 .58354 L
s
.43925 .58323 m
.43939 .5753 L
s
.43919 .58354 m
.43941 .57526 L
s
.43941 .57526 m
.43925 .58323 L
s
.857 .196 1 r
.46907 .52917 m
.4686 .57188 L
s
.88 .191 1 r
.56698 .5907 m
.56693 .59102 L
s
.744 .222 1 r
.61386 .52897 m
.61509 .56994 L
s
.45 .297 1 r
.34619 .52897 m
.34447 .56646 L
s
.701 .231 1 r
.36505 .5875 m
.36498 .58789 L
s
.543 .271 1 r
.45271 .58288 m
.45264 .58365 L
s
.55 .269 1 r
.40887 .58536 m
.40881 .58564 L
s
.45 .297 1 r
.57953 .56106 m
.57963 .56889 L
s
.57964 .56886 m
.57953 .56106 L
s
.57953 .56106 m
.57979 .57641 L
s
.638 .247 1 r
.49098 .52878 m
.49077 .56975 L
s
.722 .227 1 r
.39088 .56445 m
.39053 .57288 L
s
.39055 .57285 m
.39088 .56445 L
s
.39088 .56445 m
.39027 .58117 L
s
.369 .505 1 r
.63581 .52858 m
.637 .56122 L
s
.618 .252 1 r
.36807 .52858 m
.36646 .56886 L
s
.833 .201 1 r
.54035 .57862 m
.54038 .58723 L
s
.54044 .58726 m
.54035 .57862 L
s
.54038 .58723 m
.54037 .57859 L
s
.54037 .57859 m
.54044 .58726 L
s
.618 .252 1 r
.41279 .56348 m
.4125 .57167 L
s
.41252 .57164 m
.41279 .56348 L
s
.41279 .56348 m
.41229 .57975 L
s
.598 .257 1 r
.50984 .588 m
.50978 .58783 L
s
.618 .252 1 r
.4832 .57454 m
.4831 .58279 L
s
.48315 .58247 m
.4832 .57454 L
s
.4831 .58279 m
.48322 .57451 L
s
.48322 .57451 m
.48315 .58247 L
s
.69 .234 1 r
.5129 .52839 m
.51295 .56937 L
s
.382 .563 1 r
.4613 .57593 m
.46124 .57652 L
s
.368 .497 1 r
.41744 .57842 m
.41739 .57869 L
s
.393 .314 1 r
.51846 .58037 m
.51841 .58096 L
s
.531 .274 1 r
.60148 .56098 m
.60163 .56906 L
s
.60165 .56903 m
.60148 .56098 L
s
.60148 .56098 m
.60184 .57672 L
s
.608 .254 1 r
.4347 .56283 m
.43446 .57101 L
s
.43448 .57098 m
.4347 .56283 L
s
.4347 .56283 m
.43431 .57903 L
s
.598 .257 1 r
.38996 .52819 m
.38864 .56743 L
s
.669 .239 1 r
.53177 .58728 m
.53171 .58746 L
s
.476 .29 1 r
.53482 .528 m
.53511 .56585 L
s
.638 .247 1 r
.55763 .56415 m
.55768 .57231 L
s
.5577 .57228 m
.55763 .56415 L
s
.55763 .56415 m
.55781 .5806 L
s
.68 .236 1 r
.41186 .5278 m
.41071 .56949 L
s
.531 .274 1 r
.4746 .58389 m
.47454 .5842 L
s
.38 .554 1 r
.51373 .567 m
.5137 .57405 L
s
.51375 .57375 m
.51373 .567 L
s
.5137 .57405 m
.51374 .56697 L
s
.51374 .56697 m
.51375 .57375 L
s
.66 .241 1 r
.52705 .57378 m
.52705 .58217 L
s
.5271 .58171 m
.52705 .57378 L
s
.45 .297 1 r
.57091 .57136 m
.57101 .57919 L
s
.57105 .57888 m
.57091 .57136 L
s
.66 .241 1 r
.52705 .58217 m
.52707 .57375 L
s
.52707 .57375 m
.5271 .58171 L
s
.45 .297 1 r
.57101 .57919 m
.57093 .57133 L
s
.57093 .57133 m
.57105 .57888 L
s
.733 .224 1 r
.55371 .58725 m
.55366 .58754 L
s
.416 .307 1 r
.42599 .57211 m
.42578 .57973 L
s
.42582 .57976 m
.42599 .57211 L
s
.733 .224 1 r
.4566 .56296 m
.45641 .57146 L
s
.45643 .57143 m
.4566 .56296 L
s
.4566 .56296 m
.4563 .57969 L
s
.531 .274 1 r
.55676 .52761 m
.55729 .56616 L
s
.701 .232 1 r
.43073 .58672 m
.43067 .587 L
s
.485 .287 1 r
.3516 .5837 m
.35155 .58384 L
s
.416 .307 1 r
.42578 .57973 m
.42601 .57208 L
s
.42601 .57208 m
.42582 .57976 L
s
.337 .354 1 r
.43377 .52741 m
.43301 .56353 L
s
.711 .229 1 r
.57565 .58653 m
.5756 .58685 L
s
.459 .295 1 r
.37352 .58297 m
.37346 .58311 L
s
.512 .279 1 r
.47852 .56241 m
.47839 .57025 L
s
.47841 .57022 m
.47852 .56241 L
s
.47852 .56241 m
.47833 .57827 L
s
.68 .237 1 r
.57871 .52722 m
.57951 .56717 L
s
.578 .262 1 r
.50046 .56148 m
.50038 .56959 L
s
.5004 .56956 m
.50046 .56148 L
s
.50046 .56148 m
.50037 .57754 L
s
.36 .325 1 r
.46984 .57079 m
.46972 .57824 L
s
.46977 .57831 m
.46984 .57079 L
s
.46972 .57824 m
.46986 .57076 L
s
.46986 .57076 m
.46977 .57831 L
s
.669 .239 1 r
.45569 .52702 m
.45509 .56732 L
s
.638 .247 1 r
.37743 .56139 m
.37706 .56968 L
s
.37708 .56965 m
.37743 .56139 L
s
.37743 .56139 m
.37677 .5777 L
s
.434 .302 1 r
.60067 .52683 m
.60164 .56365 L
s
.638 .247 1 r
.33265 .52683 m
.3306 .56783 L
s
.494 .284 1 r
.47762 .52663 m
.47729 .56485 L
s
.868 .194 1 r
.35545 .56352 m
.35501 .57227 L
s
.35502 .57224 m
.35545 .56352 L
s
.35545 .56352 m
.35465 .58085 L
s
.669 .239 1 r
.44789 .57338 m
.4477 .58175 L
s
.44776 .58146 m
.44789 .57338 L
s
.777 .214 1 r
.62264 .52644 m
.62397 .56744 L
s
.608 .254 1 r
.35455 .52644 m
.35283 .56605 L
s
.711 .229 1 r
.49652 .58558 m
.49646 .58591 L
s
.669 .239 1 r
.4477 .58175 m
.44791 .57335 L
s
.44791 .57335 m
.44776 .58146 L
s
.66 .241 1 r
.39934 .56124 m
.39902 .56957 L
s
.39903 .56954 m
.39934 .56124 L
s
.39934 .56124 m
.39878 .57766 L
s
.68 .237 1 r
.59291 .57292 m
.59306 .58135 L
s
.59311 .58093 m
.59291 .57292 L
s
.59306 .58135 m
.59293 .57288 L
s
.59293 .57288 m
.59311 .58093 L
s
.789 .211 1 r
.40398 .57608 m
.40368 .58459 L
s
.40374 .58465 m
.40398 .57608 L
s
.40368 .58459 m
.404 .57604 L
s
.404 .57604 m
.40374 .58465 L
s
.588 .259 1 r
.34675 .57198 m
.34633 .58017 L
s
.3464 .57985 m
.34675 .57198 L
s
.55 .269 1 r
.49957 .52624 m
.49946 .5662 L
s
.588 .259 1 r
.34633 .58017 m
.34677 .57195 L
s
.34677 .57195 m
.3464 .57985 L
s
.35 .413 1 r
.48711 .55686 m
.48701 .56418 L
s
.48703 .56415 m
.48711 .55686 L
s
.48711 .55686 m
.48698 .57129 L
s
.638 .247 1 r
.39537 .58433 m
.39531 .58461 L
s
1 .149 .907 r
.36006 .57905 m
.35963 .58816 L
s
.35969 .58818 m
.36006 .57905 L
s
.35963 .58816 m
.36008 .57901 L
s
.36008 .57901 m
.35969 .58818 L
s
.649 .244 1 r
.64461 .52605 m
.64615 .56566 L
s
.476 .29 1 r
.37647 .52605 m
.37505 .56392 L
s
.512 .279 1 r
.36867 .57133 m
.36832 .57927 L
s
.36838 .57913 m
.36867 .57133 L
s
.368 .322 1 r
.50513 .57863 m
.50508 .57901 L
s
.777 .214 1 r
.54436 .5616 m
.54438 .57021 L
s
.5444 .57018 m
.54436 .5616 L
s
.54436 .5616 m
.54448 .57852 L
s
.512 .279 1 r
.36832 .57927 m
.36869 .5713 L
s
.36869 .5713 m
.36838 .57913 L
s
.347 .403 1 r
.38202 .5781 m
.38196 .57823 L
s
.629 .249 1 r
.49178 .57207 m
.49169 .58036 L
s
.49175 .58001 m
.49178 .57207 L
s
.649 .244 1 r
.44321 .55989 m
.443 .56826 L
s
.44301 .56823 m
.44321 .55989 L
s
.44321 .55989 m
.44286 .57621 L
s
.629 .249 1 r
.49169 .58036 m
.4918 .57204 L
s
.4918 .57204 m
.49175 .58001 L
s
.799 .209 1 r
.52152 .52585 m
.52168 .56791 L
s
.904 .186 1 r
.52241 .56315 m
.52238 .57198 L
s
.5224 .57194 m
.52241 .56315 L
s
.52241 .56315 m
.52242 .58063 L
s
1 .143 .88 r
.54903 .57672 m
.54909 .58607 L
s
.54914 .5855 m
.54903 .57672 L
s
.608 .254 1 r
.56238 .58342 m
.56233 .5837 L
s
1 .143 .88 r
.54909 .58607 m
.54905 .57668 L
s
.54905 .57668 m
.54914 .5855 L
s
.559 .267 1 r
.58434 .58234 m
.58429 .58266 L
s
.618 .252 1 r
.58828 .55981 m
.5884 .56807 L
s
.58842 .56803 m
.58828 .55981 L
s
.58828 .55981 m
.58859 .57602 L
s
.766 .217 1 r
.39839 .52566 m
.3971 .56702 L
s
.579 .262 1 r
.46515 .55944 m
.46499 .5676 L
s
.46501 .56757 m
.46515 .55944 L
s
.46515 .55944 m
.4649 .57548 L
s
.618 .252 1 r
.43925 .58323 m
.43919 .58354 L
s
.531 .274 1 r
.53569 .57048 m
.53571 .57853 L
s
.53576 .57821 m
.53569 .57048 L
s
.733 .224 1 r
.56633 .56135 m
.5664 .56983 L
s
.56642 .5698 m
.56633 .56135 L
s
.56633 .56135 m
.56655 .57813 L
s
.531 .274 1 r
.53571 .57853 m
.53571 .57045 L
s
.53571 .57045 m
.53576 .57821 L
s
.777 .214 1 r
.42123 .56203 m
.42096 .57058 L
s
.42097 .57054 m
.42123 .56203 L
s
.42123 .56203 m
.42076 .57902 L
s
.953 .176 1 r
.54348 .52546 m
.54391 .56857 L
s
.512 .279 1 r
.42033 .52526 m
.41936 .56419 L
s
.45 .297 1 r
.57963 .56889 m
.57974 .57672 L
s
.57979 .57641 m
.57963 .56889 L
s
.57974 .57672 m
.57964 .56886 L
s
.57964 .56886 m
.57979 .57641 L
s
.589 .259 1 r
.56545 .52507 m
.56609 .56435 L
s
.81 .206 1 r
.44228 .52487 m
.44148 .56729 L
s
.618 .252 1 r
.48315 .58247 m
.4831 .58279 L
s
.722 .227 1 r
.39053 .57288 m
.39021 .58132 L
s
.39027 .58117 m
.39053 .57288 L
s
.618 .252 1 r
.4125 .57167 m
.41224 .57986 L
s
.41229 .57975 m
.4125 .57167 L
s
.712 .229 1 r
.58744 .52468 m
.58835 .56501 L
s
.722 .227 1 r
.39021 .58132 m
.39055 .57285 L
s
.39055 .57285 m
.39027 .58117 L
s
.618 .252 1 r
.41224 .57986 m
.41252 .57164 L
s
.41252 .57164 m
.41229 .57975 L
s
.521 .277 1 r
.38586 .55838 m
.38553 .56637 L
s
.38554 .56633 m
.38586 .55838 L
s
.38586 .55838 m
.38527 .57418 L
s
.38 .554 1 r
.51375 .57375 m
.5137 .57405 L
s
.799 .209 1 r
.34192 .561 m
.34145 .56962 L
s
.34147 .56959 m
.34192 .561 L
s
.34192 .561 m
.34106 .57807 L
s
.608 .254 1 r
.50907 .55919 m
.50901 .56739 L
s
.50902 .56735 m
.50907 .55919 L
s
.50907 .55919 m
.50902 .57541 L
s
.833 .201 1 r
.54044 .58726 m
.54038 .58723 L
s
.531 .274 1 r
.60163 .56906 m
.6018 .57714 L
s
.60184 .57672 m
.60163 .56906 L
s
.733 .224 1 r
.36389 .5599 m
.36348 .56841 L
s
.36349 .56838 m
.36389 .5599 L
s
.36389 .5599 m
.36315 .57665 L
s
.46423 .52448 m
.46372 .56551 L
s
.531 .274 1 r
.6018 .57714 m
.60165 .56903 L
s
.60165 .56903 m
.60184 .57672 L
s
.608 .254 1 r
.43446 .57101 m
.43425 .57921 L
s
.43431 .57903 m
.43446 .57101 L
s
.43425 .57921 m
.43448 .57098 L
s
.43448 .57098 m
.43431 .57903 L
s
.8 .209 1 r
.61031 .56131 m
.61049 .5699 L
s
.61051 .56987 m
.61031 .56131 L
s
.61031 .56131 m
.61075 .57842 L
s
.503 .282 1 r
.53104 .55826 m
.53103 .56618 L
s
.53105 .56614 m
.53104 .55826 L
s
.53104 .55826 m
.53109 .57399 L
s
.344 .33 1 r
.42979 .55648 m
.42956 .56394 L
s
.42958 .56391 m
.42979 .55648 L
s
.42979 .55648 m
.42941 .57133 L
s
.868 .194 1 r
.60943 .52429 m
.61067 .56776 L
s
.777 .214 1 r
.341 .52428 m
.33904 .56566 L
s
.45 .297 1 r
.57105 .57888 m
.57101 .57919 L
s
.531 1 .914 r
.43839 .54901 m
.43823 .55454 L
s
.43825 .55452 m
.43839 .54901 L
s
.43839 .54901 m
.43813 .56019 L
s
.638 .247 1 r
.55768 .57231 m
.55775 .58047 L
s
.55781 .5806 m
.55768 .57231 L
s
.486 .287 1 r
.4862 .52409 m
.48597 .56199 L
s
.638 .247 1 r
.55775 .58047 m
.5577 .57228 L
s
.5577 .57228 m
.55781 .5806 L
s
.416 .307 1 r
.42582 .57976 m
.42578 .57973 L
s
.66 .241 1 r
.5271 .58171 m
.52705 .58217 L
s
.711 .229 1 r
.63144 .52389 m
.63286 .56458 L
s
.531 .274 1 r
.36294 .52389 m
.36135 .56249 L
s
.367 .497 1 r
.61896 .55449 m
.61913 .5616 L
s
.61914 .56157 m
.61896 .55449 L
s
.61896 .55449 m
.61935 .56864 L
s
.711 .229 1 r
.50818 .5237 m
.50818 .56439 L
s
.55 .269 1 r
.57502 .55732 m
.57511 .56541 L
s
.57513 .56538 m
.57502 .55732 L
s
.57502 .55732 m
.57526 .57322 L
s
.733 .224 1 r
.45641 .57146 m
.45624 .57998 L
s
.4563 .57969 m
.45641 .57146 L
s
.512 .279 1 r
.47839 .57025 m
.47828 .5781 L
s
.47833 .57827 m
.47839 .57025 L
s
.733 .224 1 r
.45624 .57998 m
.45643 .57143 L
s
.45643 .57143 m
.4563 .57969 L
s
.512 .279 1 r
.47828 .5781 m
.47841 .57022 L
s
.47841 .57022 m
.47833 .57827 L
s
.36 .325 1 r
.46977 .57831 m
.46972 .57824 L
s
.4 .312 1 r
.65345 .5235 m
.65497 .56036 L
s
.648 .244 1 r
.38489 .5235 m
.38349 .5635 L
s
.578 .262 1 r
.50038 .56959 m
.50031 .57772 L
s
.50037 .57754 m
.50038 .56959 L
s
.50031 .57772 m
.5004 .56956 L
s
.5004 .56956 m
.50037 .57754 L
s
.473 .915 1 r
.53017 .5233 m
.53035 .55461 L
s
.68 .237 1 r
.45174 .5576 m
.45154 .56605 L
s
.45156 .56601 m
.45174 .5576 L
s
.45174 .5576 m
.45142 .57407 L
s
.744 .222 1 r
.55305 .55952 m
.55309 .56801 L
s
.55311 .56797 m
.55305 .55952 L
s
.55305 .55952 m
.5532 .57639 L
s
.722 .227 1 r
.40686 .52311 m
.40566 .56451 L
s
.638 .247 1 r
.37706 .56968 m
.37671 .57798 L
s
.37677 .5777 m
.37706 .56968 L
s
.37671 .57798 m
.37708 .56965 L
s
.37708 .56965 m
.37677 .5777 L
s
.905 .186 1 r
.40774 .56078 m
.40742 .56959 L
s
.40744 .56955 m
.40774 .56078 L
s
.40774 .56078 m
.40718 .57832 L
s
.531 .274 1 r
.47371 .55712 m
.47357 .56511 L
s
.47359 .56508 m
.47371 .55712 L
s
.47371 .55712 m
.4735 .573 L
s
.711 .229 1 r
.55217 .52291 m
.55267 .56361 L
s
.588 .259 1 r
.35038 .55672 m
.34995 .56492 L
s
.34997 .56489 m
.35038 .55672 L
s
.35038 .55672 m
.34961 .57281 L
s
.35 .413 1 r
.48701 .56418 m
.48693 .5715 L
s
.48698 .57129 m
.48701 .56418 L
s
.48693 .5715 m
.48703 .56415 L
s
.48703 .56415 m
.48698 .57129 L
s
.54 .272 1 r
.42883 .52272 m
.42794 .56202 L
s
.669 .239 1 r
.44776 .58146 m
.4477 .58175 L
s
.68 .237 1 r
.59311 .58093 m
.59306 .58135 L
s
.476 .29 1 r
.5177 .55532 m
.51766 .56324 L
s
.51768 .56321 m
.5177 .55532 L
s
.5177 .55532 m
.51769 .57084 L
s
.588 .259 1 r
.3464 .57985 m
.34633 .58017 L
s
.66 .241 1 r
.39902 .56957 m
.39871 .57791 L
s
.39878 .57766 m
.39902 .56957 L
s
.649 .244 1 r
.57417 .52252 m
.57492 .56218 L
s
.66 .241 1 r
.39871 .57791 m
.39903 .56954 L
s
.39903 .56954 m
.39878 .57766 L
s
.868 .194 1 r
.35501 .57227 m
.35458 .58104 L
s
.35465 .58085 m
.35501 .57227 L
s
.35458 .58104 m
.35502 .57224 L
s
.35502 .57224 m
.35465 .58085 L
s
.789 .211 1 r
.40374 .58465 m
.40368 .58459 L
s
.512 .279 1 r
.36838 .57913 m
.36832 .57927 L
s
.441 .3 1 r
.45081 .52232 m
.4502 .5599 L
s
.648 .244 1 r
.37233 .55675 m
.37194 .56509 L
s
.37196 .56506 m
.37233 .55675 L
s
.37233 .55675 m
.37164 .57312 L
s
.629 .249 1 r
.49175 .58001 m
.49169 .58036 L
s
.68 .237 1 r
.59619 .52213 m
.5972 .56249 L
s
.578 .262 1 r
.32742 .52213 m
.32538 .56179 L
s
.649 .244 1 r
.443 .56826 m
.44279 .57663 L
s
.44286 .57621 m
.443 .56826 L
s
.44279 .57663 m
.44301 .56823 L
s
.44301 .56823 m
.44286 .57621 L
s
.777 .214 1 r
.54438 .57021 m
.54442 .57884 L
s
.54448 .57852 m
.54438 .57021 L
s
.69 .234 1 r
.4728 .52193 m
.47239 .56299 L
s
.777 .214 1 r
.54442 .57884 m
.5444 .57018 L
s
.5444 .57018 m
.54448 .57852 L
s
.531 .274 1 r
.53576 .57821 m
.53571 .57853 L
s
.669 .239 1 r
.49569 .55811 m
.4956 .56639 L
s
.49562 .56636 m
.49569 .55811 L
s
.49569 .55811 m
.49558 .5747 L
s
1 .149 .907 r
.35969 .58818 m
.35963 .58816 L
s
.618 .252 1 r
.5884 .56807 m
.58854 .57634 L
s
.58859 .57602 m
.5884 .56807 L
s
.58854 .57634 m
.58842 .56803 L
s
.58842 .56803 m
.58859 .57602 L
s
1 .149 .907 r
.59711 .56023 m
.59727 .56946 L
s
.59729 .56942 m
.59711 .56023 L
s
.59711 .56023 m
.5975 .57841 L
s
.579 .262 1 r
.46499 .5676 m
.46484 .57576 L
s
.4649 .57548 m
.46499 .5676 L
s
.4 .312 1 r
.61822 .52173 m
.61938 .55862 L
s
.845 .199 1 r
.34938 .52173 m
.34748 .56385 L
s
.579 .262 1 r
.46484 .57576 m
.46501 .56757 L
s
.46501 .56757 m
.4649 .57548 L
s
.904 .186 1 r
.52238 .57198 m
.52236 .58082 L
s
.52242 .58063 m
.52238 .57198 L
s
.52236 .58082 m
.5224 .57194 L
s
.5224 .57194 m
.52242 .58063 L
s
1 .143 .88 r
.54914 .5855 m
.54909 .58607 L
s
.45 .297 1 r
.57979 .57641 m
.57974 .57672 L
s
.733 .224 1 r
.5664 .56983 m
.56649 .57832 L
s
.56655 .57813 m
.5664 .56983 L
s
.531 1 .914 r
.43823 .55454 m
.43809 .56007 L
s
.43813 .56019 m
.43823 .55454 L
s
.43809 .56007 m
.43825 .55452 L
s
.43825 .55452 m
.43813 .56019 L
s
.658 .242 1 r
.49481 .52154 m
.49465 .56226 L
s
.733 .224 1 r
.56649 .57832 m
.56642 .5698 L
s
.56642 .5698 m
.56655 .57813 L
s
.777 .214 1 r
.42096 .57058 m
.4207 .57913 L
s
.42076 .57902 m
.42096 .57058 L
s
.504 .282 1 r
.58375 .55406 m
.58385 .56208 L
s
.58387 .56205 m
.58375 .55406 L
s
.58375 .55406 m
.58403 .56969 L
s
.777 .214 1 r
.4207 .57913 m
.42097 .57054 L
s
.42097 .57054 m
.42076 .57902 L
s
.733 .224 1 r
.39427 .55733 m
.39393 .56581 L
s
.39395 .56578 m
.39427 .55733 L
s
.39427 .55733 m
.39367 .57413 L
s
.337 .351 1 r
.64026 .52134 m
.64166 .55892 L
s
.416 .307 1 r
.37136 .52134 m
.36991 .55858 L
s
.7 .232 1 r
.53972 .55693 m
.53973 .56534 L
s
.53975 .56531 m
.53972 .55693 L
s
.53972 .55693 m
.53981 .57359 L
s
.733 .224 1 r
.41627 .55663 m
.41598 .56515 L
s
.416 .56512 m
.41627 .55663 L
s
.41627 .55663 m
.41578 .5734 L
s
.598 .257 1 r
.51682 .52114 m
.51692 .56047 L
s
.638 .247 1 r
.56174 .55613 m
.5618 .56441 L
s
.56182 .56437 m
.56174 .55613 L
s
.56174 .55613 m
.56193 .57251 L
s
.388 .588 1 r
.52634 .55076 m
.52632 .55769 L
s
.52634 .55767 m
.52634 .55076 L
s
.52634 .55076 m
.52636 .56453 L
s
.55 .269 1 r
.66231 .52095 m
.66402 .55993 L
s
.648 .244 1 r
.39335 .52095 m
.39204 .56098 L
s
.618 .252 1 r
.41229 .57975 m
.41224 .57986 L
s
.521 .277 1 r
.38553 .56637 m
.38521 .57435 L
s
.38527 .57418 m
.38553 .56637 L
s
.531 .274 1 r
.60184 .57672 m
.6018 .57714 L
s
.344 .33 1 r
.42956 .56394 m
.42936 .5714 L
s
.42941 .57133 m
.42956 .56394 L
s
.521 .277 1 r
.38521 .57435 m
.38554 .56633 L
s
.38554 .56633 m
.38527 .57418 L
s
.344 .33 1 r
.42936 .5714 m
.42958 .56391 L
s
.42958 .56391 m
.42941 .57133 L
s
.722 .227 1 r
.39027 .58117 m
.39021 .58132 L
s
.342 .378 1 r
.53884 .52075 m
.53915 .55625 L
s
.608 .254 1 r
.50901 .56739 m
.50896 .57559 L
s
.50902 .57541 m
.50901 .56739 L
s
.503 .282 1 r
.53103 .56618 m
.53103 .5741 L
s
.53109 .57399 m
.53103 .56618 L
s
.608 .254 1 r
.43431 .57903 m
.43425 .57921 L
s
.50896 .57559 m
.50902 .56735 L
s
.50902 .56735 m
.50902 .57541 L
s
.503 .282 1 r
.53103 .5741 m
.53105 .56614 L
s
.53105 .56614 m
.53109 .57399 L
s
.476 .29 1 r
.35881 .55339 m
.35842 .56131 L
s
.35843 .56128 m
.35881 .55339 L
s
.35881 .55339 m
.3581 .56893 L
s
.579 .262 1 r
.33679 .55464 m
.33633 .56281 L
s
.33635 .56278 m
.33679 .55464 L
s
.33679 .55464 m
.33596 .5707 L
s
.367 .497 1 r
.61913 .5616 m
.61931 .56871 L
s
.61935 .56864 m
.61913 .5616 L
s
.512 .279 1 r
.41534 .52055 m
.41431 .55954 L
s
.367 .497 1 r
.61931 .56871 m
.61914 .56157 L
s
.61914 .56157 m
.61935 .56864 L
s
.799 .209 1 r
.34145 .56962 m
.34099 .57825 L
s
.34106 .57807 m
.34145 .56962 L
s
.733 .224 1 r
.36348 .56841 m
.36308 .57693 L
s
.36315 .57665 m
.36348 .56841 L
s
.799 .209 1 r
.34099 .57825 m
.34147 .56959 L
s
.34147 .56959 m
.34106 .57807 L
s
.733 .224 1 r
.36308 .57693 m
.36349 .56838 L
s
.36349 .56838 m
.36315 .57665 L
s
.8 .209 1 r
.61049 .5699 m
.61069 .5785 L
s
.61075 .57842 m
.61049 .5699 L
s
.744 .222 1 r
.46028 .55583 m
.4601 .56439 L
s
.46012 .56435 m
.46028 .55583 L
s
.46028 .55583 m
.46 .57263 L
s
.8 .209 1 r
.61069 .5785 m
.61051 .56987 L
s
.61051 .56987 m
.61075 .57842 L
s
.45 .297 1 r
.56088 .52036 m
.56144 .55795 L
s
.638 .247 1 r
.55781 .5806 m
.55775 .58047 L
s
.54 .272 1 r
.43735 .52016 m
.43655 .5595 L
s
.345 .39 1 r
.42485 .55083 m
.42462 .55822 L
s
.42464 .55819 m
.42485 .55083 L
s
.42485 .55083 m
.42446 .56534 L
s
.701 .232 1 r
.4823 .55527 m
.48217 .56372 L
s
.48219 .56369 m
.4823 .55527 L
s
.4823 .55527 m
.48212 .5719 L
s
.559 .267 1 r
.58292 .51996 m
.58375 .55896 L
s
.512 .279 1 r
.47833 .57827 m
.47828 .5781 L
s
.629 .249 1 r
.38079 .55369 m
.38042 .56204 L
s
.38044 .562 m
.38079 .55369 L
s
.38079 .55369 m
.38015 .56993 L
s
.55 .269 1 r
.57511 .56541 m
.57521 .57351 L
s
.57526 .57322 m
.57511 .56541 L
s
.57521 .57351 m
.57513 .56538 L
s
.57513 .56538 m
.57526 .57322 L
s
.733 .224 1 r
.4563 .57969 m
.45624 .57998 L
s
.869 .194 1 r
.60586 .55649 m
.60603 .5653 L
s
.60605 .56527 m
.60586 .55649 L
s
.60586 .55649 m
.60628 .57383 L
s
.369 .505 1 r
.63654 .54734 m
.63675 .55466 L
s
.63677 .55463 m
.63654 .54734 L
s
.63654 .54734 m
.637 .56122 L
s
.485 .287 1 r
.45937 .51977 m
.45884 .55772 L
s
.578 .262 1 r
.50037 .57754 m
.50031 .57772 L
s
.638 .247 1 r
.60498 .51957 m
.60609 .55996 L
s
.658 .242 1 r
.33579 .51957 m
.33378 .56031 L
s
.377 .538 1 r
.44685 .55088 m
.44667 .55784 L
s
.44669 .55781 m
.44685 .55088 L
s
.44685 .55088 m
.44655 .56496 L
s
.35 .413 1 r
.48698 .57129 m
.48693 .5715 L
s
.559 .267 1 r
.54841 .55304 m
.54844 .56118 L
s
.54846 .56115 m
.54841 .55304 L
s
.54841 .55304 m
.54854 .56901 L
s
.367 .322 1 r
.4814 .51937 m
.48112 .55593 L
s
.68 .237 1 r
.45154 .56605 m
.45136 .5745 L
s
.45142 .57407 m
.45154 .56605 L
s
.569 .264 1 r
.40277 .55383 m
.40247 .56193 L
s
.40248 .5619 m
.40277 .55383 L
s
.40277 .55383 m
.40224 .5699 L
s
.81 .206 1 r
.62792 .55628 m
.62815 .56492 L
s
.62817 .56488 m
.62792 .55628 L
s
.62792 .55628 m
.62844 .57345 L
s
.638 .247 1 r
.37677 .5777 m
.37671 .57798 L
s
.68 .237 1 r
.45136 .5745 m
.45156 .56601 L
s
.45156 .56601 m
.45142 .57407 L
s
.744 .222 1 r
.55309 .56801 m
.55315 .5765 L
s
.5532 .57639 m
.55309 .56801 L
s
.55315 .5765 m
.55311 .56797 L
s
.55311 .56797 m
.5532 .57639 L
s
.531 .274 1 r
.47357 .56511 m
.47345 .57311 L
s
.4735 .573 m
.47357 .56511 L
s
.403 .651 1 r
.62704 .51917 m
.62816 .55226 L
s
.638 .247 1 r
.35779 .51917 m
.35607 .55923 L
s
.531 .274 1 r
.47345 .57311 m
.47359 .56508 L
s
.47359 .56508 m
.4735 .573 L
s
.755 .219 1 r
.50432 .55626 m
.50425 .56473 L
s
.50427 .56469 m
.50432 .55626 L
s
.50432 .55626 m
.50425 .57326 L
s
.588 .259 1 r
.34995 .56492 m
.34954 .57312 L
s
.34961 .57281 m
.34995 .56492 L
s
.589 .259 1 r
.50344 .51898 m
.50339 .55799 L
s
.588 .259 1 r
.34954 .57312 m
.34997 .56489 L
s
.34997 .56489 m
.34961 .57281 L
s
.531 1 .914 r
.43813 .56019 m
.43809 .56007 L
s
.476 .29 1 r
.51766 .56324 m
.51764 .57116 L
s
.51769 .57084 m
.51766 .56324 L
s
.51764 .57116 m
.51768 .56321 L
s
.51768 .56321 m
.51769 .57084 L
s
.905 .186 1 r
.40742 .56959 m
.40712 .5784 L
s
.40718 .57832 m
.40742 .56959 L
s
.40712 .5784 m
.40744 .56955 L
s
.40744 .56955 m
.40718 .57832 L
s
1 .116 .73 r
.64912 .51878 m
.65096 .56478 L
s
.424 .305 1 r
.3798 .51878 m
.37844 .55605 L
s
.691 .234 1 r
.57048 .55314 m
.57056 .56163 L
s
.57058 .5616 m
.57048 .55314 L
s
.57048 .55314 m
.57071 .56967 L
s
.66 .241 1 r
.39878 .57766 m
.39871 .57791 L
s
.45 .297 1 r
.34523 .55106 m
.34481 .55892 L
s
.34482 .55889 m
.34523 .55106 L
s
.34523 .55106 m
.34447 .56646 L
s
1 .151 .921 r
.52548 .51858 m
.5257 .56354 L
s
.868 .194 1 r
.35465 .58085 m
.35458 .58104 L
s
.658 .242 1 r
.6712 .51839 m
.67309 .55915 L
s
.618 .252 1 r
.40182 .51839 m
.40062 .5581 L
s
.648 .244 1 r
.37194 .56509 m
.37157 .57344 L
s
.37164 .57312 m
.37194 .56509 L
s
.37157 .57344 m
.37196 .56506 L
s
.37196 .56506 m
.37164 .57312 L
s
.649 .244 1 r
.44286 .57621 m
.44279 .57663 L
s
.723 .226 1 r
.59255 .55296 m
.59269 .56152 L
s
.59271 .56149 m
.59255 .55296 L
s
.59255 .55296 m
.59289 .56963 L
s
.777 .214 1 r
.54754 .51819 m
.54801 .55965 L
s
.618 .252 1 r
.58859 .57602 m
.58854 .57634 L
s
.777 .214 1 r
.54448 .57852 m
.54442 .57884 L
s
.579 .262 1 r
.4649 .57548 m
.46484 .57576 L
s
.669 .239 1 r
.4956 .56639 m
.49552 .57467 L
s
.49558 .5747 m
.4956 .56639 L
s
.868 .194 1 r
.42386 .51799 m
.42282 .56085 L
s
.669 .239 1 r
.49552 .57467 m
.49562 .56636 L
s
.49562 .56636 m
.49558 .5747 L
s
.56961 .51779 m
.57032 .55856 L
s
.388 .588 1 r
.52632 .55769 m
.52632 .56463 L
s
.52636 .56453 m
.52632 .55769 L
s
.52632 .56463 m
.52634 .55767 L
s
.52634 .55767 m
.52636 .56453 L
s
.504 .282 1 r
.58385 .56208 m
.58398 .57011 L
s
.58403 .56969 m
.58385 .56208 L
s
.58398 .57011 m
.58387 .56205 L
s
.58387 .56205 m
.58403 .56969 L
s
.733 .224 1 r
.56655 .57813 m
.56649 .57832 L
s
.904 .186 1 r
.52242 .58063 m
.52236 .58082 L
s
.744 .222 1 r
.61464 .55312 m
.61483 .56169 L
s
.61485 .56166 m
.61464 .55312 L
s
.61464 .55312 m
.61509 .56994 L
s
.754 .219 1 r
.4459 .5176 m
.44515 .55942 L
s
.777 .214 1 r
.42076 .57902 m
.4207 .57913 L
s
.476 .29 1 r
.53505 .5503 m
.53504 .55823 L
s
.53506 .5582 m
.53505 .5503 L
s
.53505 .5503 m
.53511 .56585 L
s
1 .149 .907 r
.59727 .56946 m
.59745 .5787 L
s
.5975 .57841 m
.59727 .56946 L
s
.733 .224 1 r
.39393 .56581 m
.39361 .57431 L
s
.39367 .57413 m
.39393 .56581 L
s
1 .149 .907 r
.59745 .5787 m
.59729 .56942 L
s
.59729 .56942 m
.5975 .57841 L
s
.344 .33 1 r
.42941 .57133 m
.42936 .5714 L
s
.848 .198 1 r
.59169 .5174 m
.59268 .55852 L
s
.669 .239 1 r
.32215 .5174 m
.31995 .55887 L
s
.733 .224 1 r
.39361 .57431 m
.39395 .56578 L
s
.39395 .56578 m
.39367 .57413 L
s
.7 .232 1 r
.53973 .56534 m
.53976 .57377 L
s
.53981 .57359 m
.53973 .56534 L
s
.598 .257 1 r
.38924 .55128 m
.3889 .55953 L
s
.38892 .5595 m
.38924 .55128 L
s
.38924 .55128 m
.38864 .56743 L
s
.337 .354 1 r
.43337 .54883 m
.43315 .55626 L
s
.43317 .55623 m
.43337 .54883 L
s
.43337 .54883 m
.43301 .56353 L
s
.7 .232 1 r
.53976 .57377 m
.53975 .56531 L
s
.53975 .56531 m
.53981 .57359 L
s
.618 .252 1 r
.36717 .55253 m
.36678 .56075 L
s
.3668 .56072 m
.36717 .55253 L
s
.36717 .55253 m
.36646 .56886 L
s
.638 .247 1 r
.49091 .55328 m
.49081 .5615 L
s
.49082 .56146 m
.49091 .55328 L
s
.49091 .55328 m
.49077 .56975 L
s
.857 .196 1 r
.46885 .55452 m
.46868 .56327 L
s
.4687 .56324 m
.46885 .55452 L
s
.46885 .55452 m
.4686 .57188 L
s
.367 .497 1 r
.61935 .56864 m
.61931 .56871 L
s
.638 .247 1 r
.5618 .56441 m
.56188 .57269 L
s
.56193 .57251 m
.5618 .56441 L
s
.521 .277 1 r
.38527 .57418 m
.38521 .57435 L
s
.744 .221 1 r
.46795 .5172 m
.46749 .55798 L
s
.638 .247 1 r
.56188 .57269 m
.56182 .56437 L
s
.56182 .56437 m
.56193 .57251 L
s
.733 .224 1 r
.41598 .56515 m
.41571 .57368 L
s
.41578 .5734 m
.41598 .56515 L
s
.41571 .57368 m
.416 .56512 L
s
.416 .56512 m
.41578 .5734 L
s
.503 .282 1 r
.53109 .57399 m
.53103 .5741 L
s
.99 .169 1 r
.61379 .517 m
.61509 .56023 L
s
.385 .577 1 r
.34418 .517 m
.34258 .55115 L
s
.476 .29 1 r
.35842 .56131 m
.35804 .56924 L
s
.3581 .56893 m
.35842 .56131 L
s
.69 .234 1 r
.51298 .55272 m
.51293 .56111 L
s
.51295 .56108 m
.51298 .55272 L
s
.51298 .55272 m
.51295 .56937 L
s
.608 .254 1 r
.50902 .57541 m
.50896 .57559 L
s
.476 .29 1 r
.35804 .56924 m
.35843 .56128 L
s
.35843 .56128 m
.3581 .56893 L
s
.531 .274 1 r
.55713 .55032 m
.55718 .5584 L
s
.5572 .55837 m
.55713 .55032 L
s
.55713 .55032 m
.55729 .56616 L
s
.579 .262 1 r
.33633 .56281 m
.33589 .57098 L
s
.33596 .5707 m
.33633 .56281 L
s
.442 .3 1 r
.49002 .51681 m
.48982 .55445 L
s
.579 .262 1 r
.33589 .57098 m
.33635 .56278 L
s
.33635 .56278 m
.33596 .5707 L
s
.434 .302 1 r
.60129 .54838 m
.60143 .55624 L
s
.60145 .55621 m
.60129 .54838 L
s
.60129 .54838 m
.60164 .56365 L
s
.345 .39 1 r
.42462 .55822 m
.4244 .56562 L
s
.42446 .56534 m
.42462 .55822 L
s
.4244 .56562 m
.42464 .55819 L
s
.42464 .55819 m
.42446 .56534 L
s
.733 .224 1 r
.36315 .57665 m
.36308 .57693 L
s
.496 .284 1 r
.63589 .51661 m
.63725 .5539 L
s
.588 .259 1 r
.36622 .51661 m
.36459 .55669 L
s
.799 .209 1 r
.34106 .57807 m
.34099 .57825 L
s
.559 .267 1 r
.51209 .51641 m
.51214 .55545 L
s
.8 .209 1 r
.61075 .57842 m
.61069 .5785 L
s
.744 .222 1 r
.4601 .56439 m
.45994 .57295 L
s
.46 .57263 m
.4601 .56439 L
s
.45994 .57295 m
.46012 .56435 L
s
.46012 .56435 m
.46 .57263 L
s
.369 .505 1 r
.63675 .55466 m
.63698 .56198 L
s
.637 .56122 m
.63675 .55466 L
s
.63698 .56198 m
.63677 .55463 L
s
.63677 .55463 m
.637 .56122 L
s
.377 .538 1 r
.44667 .55784 m
.44651 .56479 L
s
.44655 .56496 m
.44667 .55784 L
s
.44651 .56479 m
.44669 .55781 L
s
.44669 .55781 m
.44655 .56496 L
s
.55 .269 1 r
.57526 .57322 m
.57521 .57351 L
s
.45 .297 1 r
.658 .51621 m
.65961 .55386 L
s
.744 .222 1 r
.38827 .51621 m
.38683 .55805 L
s
.68 .237 1 r
.57924 .55066 m
.57934 .55912 L
s
.57936 .55909 m
.57924 .55066 L
s
.57924 .55066 m
.57951 .56717 L
s
.701 .232 1 r
.48217 .56372 m
.48206 .57219 L
s
.48212 .5719 m
.48217 .56372 L
s
.48206 .57219 m
.48219 .56369 L
s
.48219 .56369 m
.48212 .5719 L
s
.68 .236 1 r
.41123 .55279 m
.41093 .56109 L
s
.41095 .56106 m
.41123 .55279 L
s
.41123 .55279 m
.41071 .56949 L
s
.629 .249 1 r
.38042 .56204 m
.38007 .57039 L
s
.38015 .56993 m
.38042 .56204 L
s
1 .151 .921 r
.53418 .51601 m
.5345 .56101 L
s
.494 .284 1 r
.47748 .54918 m
.47735 .55716 L
s
.47737 .55712 m
.47748 .54918 L
s
.47748 .54918 m
.47729 .56485 L
s
.629 .249 1 r
.38007 .57039 m
.38044 .562 L
s
.38044 .562 m
.38015 .56993 L
s
.669 .239 1 r
.45539 .55081 m
.4552 .55921 L
s
.45522 .55917 m
.45539 .55081 L
s
.45539 .55081 m
.45509 .56732 L
s
1 .165 .994 r
.68012 .51582 m
.6822 .55801 L
s
.531 .274 1 r
.41033 .51582 m
.40925 .55451 L
s
.869 .194 1 r
.60603 .5653 m
.60623 .57412 L
s
.60628 .57383 m
.60603 .5653 L
s
.60623 .57412 m
.60605 .56527 L
s
.60605 .56527 m
.60628 .57383 L
s
.531 .274 1 r
.55627 .51562 m
.55681 .55536 L
s
.559 .267 1 r
.54844 .56118 m
.54849 .56933 L
s
.54854 .56901 m
.54844 .56118 L
s
.68 .237 1 r
.45142 .57407 m
.45136 .5745 L
s
.559 .267 1 r
.54849 .56933 m
.54846 .56115 L
s
.54846 .56115 m
.54854 .56901 L
s
.476 .29 1 r
.37569 .54836 m
.37533 .5563 L
s
.37535 .55626 m
.37569 .54836 L
s
.37569 .54836 m
.37505 .56392 L
s
.569 .264 1 r
.40247 .56193 m
.40218 .57004 L
s
.40224 .5699 m
.40247 .56193 L
s
.531 .274 1 r
.4735 .573 m
.47345 .57311 L
s
.569 .264 1 r
.40218 .57004 m
.40248 .5619 L
s
.40248 .5619 m
.40224 .5699 L
s
.608 .254 1 r
.35359 .54982 m
.35317 .55807 L
s
.35318 .55804 m
.35359 .54982 L
s
.35359 .54982 m
.35283 .56605 L
s
.618 .252 1 r
.43239 .51542 m
.43152 .55587 L
s
.476 .29 1 r
.51769 .57084 m
.51764 .57116 L
s
.744 .222 1 r
.5532 .57639 m
.55315 .5765 L
s
.638 .247 1 r
.33148 .55134 m
.331 .55957 L
s
.33102 .55953 m
.33148 .55134 L
s
.33148 .55134 m
.3306 .56783 L
s
.588 .259 1 r
.34961 .57281 m
.34954 .57312 L
s
.81 .206 1 r
.62815 .56492 m
.62839 .57356 L
s
.62844 .57345 m
.62815 .56492 L
s
.62839 .57356 m
.62817 .56488 L
s
.62817 .56488 m
.62844 .57345 L
s
.881 .191 1 r
.57838 .51522 m
.57922 .55742 L
s
.777 .214 1 r
.62348 .5505 m
.62369 .55918 L
s
.62371 .55915 m
.62348 .5505 L
s
.62348 .5505 m
.62397 .56744 L
s
.649 .244 1 r
.64557 .54929 m
.64583 .55768 L
s
.64585 .55765 m
.64557 .54929 L
s
.64557 .54929 m
.64615 .56566 L
s
.755 .219 1 r
.50425 .56473 m
.50419 .5732 L
s
.50425 .57326 m
.50425 .56473 L
s
.50419 .5732 m
.50427 .56469 L
s
.50427 .56469 m
.50425 .57326 L
s
.485 .287 1 r
.45447 .51502 m
.45387 .55408 L
s
.55 .269 1 r
.49956 .55014 m
.49947 .55815 L
s
.49949 .55812 m
.49956 .55014 L
s
.49956 .55014 m
.49946 .5662 L
s
.45 .297 1 r
.34481 .55892 m
.3444 .56678 L
s
.34447 .56646 m
.34481 .55892 L
s
.3444 .56678 m
.34482 .55889 L
s
.34482 .55889 m
.34447 .56646 L
s
.881 .191 1 r
.60049 .51483 m
.60161 .55738 L
s
.559 .267 1 r
.33054 .51483 m
.32852 .55458 L
s
.691 .234 1 r
.57056 .56163 m
.57066 .57013 L
s
.57071 .56967 m
.57056 .56163 L
s
.57066 .57013 m
.57058 .5616 L
s
.57058 .5616 m
.57071 .56967 L
s
.905 .186 1 r
.40718 .57832 m
.40712 .5784 L
s
.57 .264 1 r
.47656 .51463 m
.47622 .55299 L
s
.648 .244 1 r
.37164 .57312 m
.37157 .57344 L
s
.388 .588 1 r
.52636 .56453 m
.52632 .56463 L
s
.357 .448 1 r
.62262 .51443 m
.62373 .54826 L
s
.744 .222 1 r
.3526 .51443 m
.35078 .55559 L
s
.512 .279 1 r
.41981 .54838 m
.41954 .55635 L
s
.41956 .55632 m
.41981 .54838 L
s
.41981 .54838 m
.41936 .56419 L
s
.473 .915 1 r
.53032 .54227 m
.53031 .54831 L
s
.53032 .54829 m
.53032 .54227 L
s
.53032 .54227 m
.53035 .55461 L
s
.723 .226 1 r
.59269 .56152 m
.59284 .57009 L
s
.59289 .56963 m
.59269 .56152 L
s
.628 .249 1 r
.49866 .51423 m
.49855 .5547 L
s
.723 .226 1 r
.59284 .57009 m
.59271 .56149 L
s
.59271 .56149 m
.59289 .56963 L
s
.589 .259 1 r
.56589 .54821 m
.56596 .55644 L
s
.56597 .5564 m
.56589 .54821 L
s
.56589 .54821 m
.56609 .56435 L
s
.504 .282 1 r
.58403 .56969 m
.58398 .57011 L
s
.766 .217 1 r
.39769 .55007 m
.39736 .55869 L
s
.39737 .55865 m
.39769 .55007 L
s
.39769 .55007 m
.3971 .56702 L
s
.669 .239 1 r
.49558 .5747 m
.49552 .57467 L
s
.799 .209 1 r
.52167 .55078 m
.52163 .55943 L
s
.52165 .5594 m
.52167 .55078 L
s
.52167 .55078 m
.52168 .56791 L
s
.68 .237 1 r
.64476 .51403 m
.64633 .5545 L
s
.503 .282 1 r
.37468 .51403 m
.37319 .5531 L
s
.337 .354 1 r
.43315 .55626 m
.43295 .5637 L
s
.43301 .56353 m
.43315 .55626 L
s
.777 .214 1 r
.52077 .51383 m
.52092 .55606 L
s
.337 .354 1 r
.43295 .5637 m
.43317 .55623 L
s
.43317 .55623 m
.43301 .56353 L
s
.476 .29 1 r
.53504 .55823 m
.53506 .56616 L
s
.53511 .56585 m
.53504 .55823 L
s
.53506 .56616 m
.53506 .5582 L
s
.53506 .5582 m
.53511 .56585 L
s
.56 .267 1 r
.66691 .51364 m
.66866 .55236 L
s
.578 .262 1 r
.39676 .51364 m
.3955 .55341 L
s
.744 .222 1 r
.61483 .56169 m
.61504 .57027 L
s
.61509 .56994 m
.61483 .56169 L
s
.61504 .57027 m
.61485 .56166 L
s
.61485 .56166 m
.61509 .56994 L
s
.486 .287 1 r
.48612 .54638 m
.486 .55436 L
s
.48602 .55433 m
.48612 .54638 L
s
.48612 .54638 m
.48597 .56199 L
s
.712 .229 1 r
.58803 .54834 m
.58816 .55688 L
s
.58817 .55685 m
.58803 .54834 L
s
.58803 .54834 m
.58835 .56501 L
s
.733 .224 1 r
.39367 .57413 m
.39361 .57431 L
s
.953 .176 1 r
.5438 .55088 m
.54382 .55988 L
s
.54384 .55985 m
.5438 .55088 L
s
.5438 .55088 m
.54391 .56857 L
s
.7 .232 1 r
.53981 .57359 m
.53976 .57377 L
s
.618 .252 1 r
.36678 .56075 m
.3664 .56897 L
s
.36646 .56886 m
.36678 .56075 L
s
.598 .257 1 r
.3889 .55953 m
.38858 .56779 L
s
.38864 .56743 m
.3889 .55953 L
s
.477 .289 1 r
.5429 .51344 m
.54327 .55112 L
s
.618 .252 1 r
.3664 .56897 m
.3668 .56072 L
s
.3668 .56072 m
.36646 .56886 L
s
.598 .257 1 r
.38858 .56779 m
.38892 .5595 L
s
.38892 .5595 m
.38864 .56743 L
s
.638 .247 1 r
.49081 .5615 m
.49072 .56972 L
s
.49077 .56975 m
.49081 .5615 L
s
.56193 .57251 m
.56188 .57269 L
s
.49072 .56972 m
.49082 .56146 L
s
.49082 .56146 m
.49077 .56975 L
s
.476 .29 1 r
.3581 .56893 m
.35804 .56924 L
s
.345 .39 1 r
.42446 .56534 m
.4244 .56562 L
s
.733 .224 1 r
.41578 .5734 m
.41571 .57368 L
s
.4 .312 1 r
.6544 .54521 m
.65466 .55294 L
s
.65468 .55291 m
.6544 .54521 L
s
.6544 .54521 m
.65497 .56036 L
s
.509 1 .972 r
.68907 .51324 m
.69041 .53908 L
s
.733 .224 1 r
.41885 .51324 m
.41781 .55442 L
s
1 .149 .907 r
.5975 .57841 m
.59745 .5787 L
s
.369 .505 1 r
.637 .56122 m
.63698 .56198 L
s
.531 .274 1 r
.36206 .54664 m
.36167 .55472 L
s
.36168 .55469 m
.36206 .54664 L
s
.36206 .54664 m
.36135 .56249 L
s
.857 .196 1 r
.46868 .56327 m
.46854 .57203 L
s
.4686 .57188 m
.46868 .56327 L
s
.531 .274 1 r
.55718 .5584 m
.55724 .56648 L
s
.55729 .56616 m
.55718 .5584 L
s
.857 .196 1 r
.46854 .57203 m
.4687 .56324 L
s
.4687 .56324 m
.4686 .57188 L
s
.579 .262 1 r
.33596 .5707 m
.33589 .57098 L
s
.531 .274 1 r
.55724 .56648 m
.5572 .55837 L
s
.5572 .55837 m
.55729 .56616 L
s
.733 .224 1 r
.46399 .5487 m
.46382 .55725 L
s
.46383 .55721 m
.46399 .5487 L
s
.46399 .5487 m
.46372 .56551 L
s
.777 .214 1 r
.56503 .51304 m
.5657 .55457 L
s
.69 .234 1 r
.51293 .56111 m
.51289 .56951 L
s
.51295 .56937 m
.51293 .56111 L
s
.434 .302 1 r
.60143 .55624 m
.6016 .5641 L
s
.60164 .56365 m
.60143 .55624 L
s
.377 .538 1 r
.44655 .56496 m
.44651 .56479 L
s
.81 .206 1 r
.44186 .55009 m
.44163 .55874 L
s
.44165 .55871 m
.44186 .55009 L
s
.44186 .55009 m
.44148 .56729 L
s
.69 .234 1 r
.51289 .56951 m
.51295 .56108 L
s
.51295 .56108 m
.51295 .56937 L
s
.434 .302 1 r
.6016 .5641 m
.60145 .55621 L
s
.60145 .55621 m
.60164 .56365 L
s
.55 .269 1 r
.44096 .51284 m
.44021 .55193 L
s
.777 .214 1 r
.3399 .54868 m
.33943 .55733 L
s
.33944 .55729 m
.3399 .54868 L
s
.3399 .54868 m
.33904 .56566 L
s
.385 .576 1 r
.58717 .51264 m
.58792 .54614 L
s
.618 .252 1 r
.31686 .51264 m
.31465 .55313 L
s
.711 .229 1 r
.63233 .54788 m
.63256 .55639 L
s
.63258 .55635 m
.63233 .54788 L
s
.63233 .54788 m
.63286 .56458 L
s
.744 .222 1 r
.46 .57263 m
.45994 .57295 L
s
.868 .194 1 r
.46307 .51244 m
.46252 .55538 L
s
.711 .229 1 r
.50824 .54768 m
.50817 .55619 L
s
.50819 .55616 m
.50824 .54768 L
s
.50824 .54768 m
.50818 .56439 L
s
.648 .244 1 r
.38413 .54707 m
.38377 .55544 L
s
.38378 .55541 m
.38413 .54707 L
s
.38413 .54707 m
.38349 .5635 L
s
.629 .249 1 r
.38015 .56993 m
.38007 .57039 L
s
.494 .284 1 r
.47735 .55716 m
.47724 .56513 L
s
.47729 .56485 m
.47735 .55716 L
s
.881 .191 1 r
.60932 .51225 m
.61054 .55449 L
s
.701 .232 1 r
.48212 .5719 m
.48206 .57219 L
s
.598 .257 1 r
.33895 .51225 m
.33701 .55239 L
s
.494 .284 1 r
.47724 .56513 m
.47737 .55712 L
s
.47737 .55712 m
.47729 .56485 L
s
.68 .237 1 r
.57934 .55912 m
.57946 .56759 L
s
.57951 .56717 m
.57934 .55912 L
s
.57946 .56759 m
.57936 .55909 L
s
.57936 .55909 m
.57951 .56717 L
s
.68 .236 1 r
.41093 .56109 m
.41066 .56939 L
s
.41071 .56949 m
.41093 .56109 L
s
.41066 .56939 m
.41095 .56106 L
s
.41095 .56106 m
.41071 .56949 L
s
.486 .287 1 r
.4852 .51205 m
.48496 .54939 L
s
.868 .194 1 r
.61023 .55027 m
.61041 .559 L
s
.61043 .55896 m
.61023 .55027 L
s
.61023 .55027 m
.61067 .56776 L
s
.669 .239 1 r
.4552 .55921 m
.45503 .56761 L
s
.45509 .56732 m
.4552 .55921 L
s
.559 .267 1 r
.54854 .56901 m
.54849 .56933 L
s
.578 .262 1 r
.63149 .51185 m
.63288 .55164 L
s
.916 .184 1 r
.36105 .51185 m
.35925 .5548 L
s
.669 .239 1 r
.45503 .56761 m
.45522 .55917 L
s
.45522 .55917 m
.45509 .56732 L
s
.441 .3 1 r
.4505 .54449 m
.45031 .55233 L
s
.45033 .5523 m
.4505 .54449 L
s
.4505 .54449 m
.4502 .5599 L
s
.476 .29 1 r
.37533 .5563 m
.37499 .56424 L
s
.37505 .56392 m
.37533 .5563 L
s
.37499 .56424 m
.37535 .55626 L
s
.37535 .55626 m
.37505 .56392 L
s
.569 .264 1 r
.40224 .5699 m
.40218 .57004 L
s
.54 .272 1 r
.42835 .54606 m
.42811 .55411 L
s
.42813 .55408 m
.42835 .54606 L
s
.42835 .54606 m
.42794 .56202 L
s
.766 .217 1 r
.50734 .51165 m
.50733 .5532 L
s
.869 .194 1 r
.60628 .57383 m
.60623 .57412 L
s
.711 .229 1 r
.55252 .5469 m
.55256 .55542 L
s
.55258 .55538 m
.55252 .5469 L
s
.55252 .5469 m
.55267 .56361 L
s
.608 .254 1 r
.35317 .55807 m
.35276 .56633 L
s
.35283 .56605 m
.35317 .55807 L
s
.649 .244 1 r
.57467 .54579 m
.57476 .55419 L
s
.57478 .55416 m
.57467 .54579 L
s
.57467 .54579 m
.57492 .56218 L
s
.608 .254 1 r
.35276 .56633 m
.35318 .55804 L
s
.35318 .55804 m
.35283 .56605 L
s
.722 .227 1 r
.4062 .54769 m
.40589 .55617 L
s
.40591 .55613 m
.4062 .54769 L
s
.4062 .54769 m
.40566 .56451 L
s
.473 .915 1 r
.53031 .54831 m
.53031 .55435 L
s
.53035 .55461 m
.53031 .54831 L
s
.53031 .55435 m
.53032 .54829 L
s
.53032 .54829 m
.53035 .55461 L
s
.4 .312 1 r
.61895 .54346 m
.61914 .55119 L
s
.61915 .55116 m
.61895 .54346 L
s
.61895 .54346 m
.61938 .55862 L
s
.648 .244 1 r
.65366 .51145 m
.65532 .5516 L
s
.669 .239 1 r
.38316 .51145 m
.3817 .5523 L
s
.638 .247 1 r
.331 .55957 m
.33054 .5678 L
s
.3306 .56783 m
.331 .55957 L
s
.33054 .5678 m
.33102 .55953 L
s
.33102 .55953 m
.3306 .56783 L
s
.45 .297 1 r
.34447 .56646 m
.3444 .56678 L
s
.503 .282 1 r
.52948 .51125 m
.52972 .54966 L
s
.81 .206 1 r
.62844 .57345 m
.62839 .57356 L
s
.55 .269 1 r
.49947 .55815 m
.49941 .56617 L
s
.49946 .5662 m
.49947 .55815 L
s
.49941 .56617 m
.49949 .55812 L
s
.49949 .55812 m
.49946 .5662 L
s
.649 .244 1 r
.64583 .55768 m
.64611 .56609 L
s
.64615 .56566 m
.64583 .55768 L
s
.64611 .56609 m
.64585 .55765 L
s
.64585 .55765 m
.64615 .56566 L
s
.834 .201 1 r
.67584 .51105 m
.67786 .55331 L
s
.68 .237 1 r
.40528 .51105 m
.40409 .55156 L
s
.755 .219 1 r
.50425 .57326 m
.50419 .5732 L
s
.777 .214 1 r
.62369 .55918 m
.62393 .56787 L
s
.62397 .56744 m
.62369 .55918 L
s
.578 .262 1 r
.32626 .54564 m
.32578 .5538 L
s
.32579 .55377 m
.32626 .54564 L
s
.32626 .54564 m
.32538 .56179 L
s
.777 .214 1 r
.62393 .56787 m
.62371 .55915 L
s
.62371 .55915 m
.62397 .56744 L
s
.691 .234 1 r
.57071 .56967 m
.57066 .57013 L
s
.416 .307 1 r
.37056 .54331 m
.37019 .55108 L
s
.37021 .55105 m
.37056 .54331 L
s
.37056 .54331 m
.36991 .55858 L
s
.68 .237 1 r
.59684 .54592 m
.59699 .55436 L
s
.59701 .55433 m
.59684 .54592 L
s
.59684 .54592 m
.5972 .56249 L
s
.669 .239 1 r
.55164 .51085 m
.55214 .55136 L
s
.342 .378 1 r
.53908 .54165 m
.53908 .54911 L
s
.5391 .54908 m
.53908 .54165 L
s
.53908 .54165 m
.53915 .55625 L
s
1 .166 .997 r
.69804 .51065 m
.7005 .55643 L
s
.608 .254 1 r
.42741 .51065 m
.42649 .55047 L
s
.512 .279 1 r
.41954 .55635 m
.4193 .56433 L
s
.41936 .56419 m
.41954 .55635 L
s
.337 .351 1 r
.64115 .54404 m
.64137 .55136 L
s
.64139 .55133 m
.64115 .54404 L
s
.64115 .54404 m
.64166 .55892 L
s
.512 .279 1 r
.4193 .56433 m
.41956 .55632 L
s
.41956 .55632 m
.41936 .56419 L
s
.485 .287 1 r
.57381 .51046 m
.57453 .54922 L
s
.723 .226 1 r
.59289 .56963 m
.59284 .57009 L
s
.69 .234 1 r
.47261 .54631 m
.47246 .55472 L
s
.47248 .55469 m
.47261 .54631 L
s
.47261 .54631 m
.47239 .56299 L
s
.337 .354 1 r
.43301 .56353 m
.43295 .5637 L
s
.589 .259 1 r
.56596 .55644 m
.56605 .56467 L
s
.56609 .56435 m
.56596 .55644 L
s
.531 .274 1 r
.44955 .51026 m
.4489 .54902 L
s
.589 .259 1 r
.56605 .56467 m
.56597 .5564 L
s
.56597 .5564 m
.56609 .56435 L
s
.598 .257 1 r
.51693 .54429 m
.51689 .55255 L
s
.51691 .55252 m
.51693 .54429 L
s
.51693 .54429 m
.51692 .56047 L
s
.476 .29 1 r
.53511 .56585 m
.53506 .56616 L
s
.658 .242 1 r
.49477 .54571 m
.49467 .55405 L
s
.49469 .55402 m
.49477 .54571 L
s
.49477 .54571 m
.49465 .56226 L
s
.766 .217 1 r
.39736 .55869 m
.39704 .56731 L
s
.3971 .56702 m
.39736 .55869 L
s
.55 .269 1 r
.66337 .54395 m
.66366 .55208 L
s
.66369 .55205 m
.66337 .54395 L
s
.66337 .54395 m
.66402 .55993 L
s
1 .158 .957 r
.59599 .51006 m
.59709 .55373 L
s
.578 .262 1 r
.32526 .51006 m
.32314 .55058 L
s
.766 .217 1 r
.39704 .56731 m
.39737 .55865 L
s
.39737 .55865 m
.3971 .56702 L
s
.799 .209 1 r
.52163 .55943 m
.52162 .56809 L
s
.52168 .56791 m
.52163 .55943 L
s
.52162 .56809 m
.52165 .5594 L
s
.52165 .5594 m
.52168 .56791 L
s
.845 .199 1 r
.34832 .54656 m
.34786 .55536 L
s
.34787 .55533 m
.34832 .54656 L
s
.34832 .54656 m
.34748 .56385 L
s
.403 .651 1 r
.62775 .53875 m
.62792 .54561 L
s
.62794 .54558 m
.62775 .53875 L
s
.62775 .53875 m
.62816 .55226 L
s
.45 .297 1 r
.56126 .5425 m
.56132 .55038 L
s
.56134 .55035 m
.56126 .5425 L
s
.56126 .5425 m
.56144 .55795 L
s
.405 .662 1 r
.4717 .50986 m
.47136 .54269 L
s
.486 .287 1 r
.486 .55436 m
.48591 .56234 L
s
.48597 .56199 m
.486 .55436 L
s
.648 .244 1 r
.39263 .54454 m
.39229 .55291 L
s
.39231 .55288 m
.39263 .54454 L
s
.39263 .54454 m
.39204 .56098 L
s
.486 .287 1 r
.48591 .56234 m
.48602 .55433 L
s
.48602 .55433 m
.48597 .56199 L
s
.598 .257 1 r
.38864 .56743 m
.38858 .56779 L
s
.744 .222 1 r
.61509 .56994 m
.61504 .57027 L
s
.881 .191 1 r
.61818 .50966 m
.61952 .55263 L
s
.598 .257 1 r
.34739 .50966 m
.34554 .54983 L
s
.618 .252 1 r
.36646 .56886 m
.3664 .56897 L
s
.4 .312 1 r
.65466 .55294 m
.65493 .56067 L
s
.65497 .56036 m
.65466 .55294 L
s
.512 .279 1 r
.41478 .5437 m
.41451 .55169 L
s
.41453 .55166 m
.41478 .5437 L
s
.41478 .5437 m
.41431 .55954 L
s
.4 .312 1 r
.65493 .56067 m
.65468 .55291 L
s
.65468 .55291 m
.65497 .56036 L
s
.638 .247 1 r
.49077 .56975 m
.49072 .56972 L
s
.712 .229 1 r
.58816 .55688 m
.5883 .56543 L
s
.58835 .56501 m
.58816 .55688 L
s
.434 .302 1 r
.60164 .56365 m
.6016 .5641 L
s
.599 .257 1 r
.49387 .50946 m
.49368 .55104 L
s
.712 .229 1 r
.5883 .56543 m
.58817 .55685 L
s
.58817 .55685 m
.58835 .56501 L
s
.531 .274 1 r
.55729 .56616 m
.55724 .56648 L
s
.36167 .55472 m
.36128 .56281 L
s
.36135 .56249 m
.36167 .55472 L
s
.36128 .56281 m
.36168 .55469 L
s
.36168 .55469 m
.36135 .56249 L
s
.711 .229 1 r
.64038 .50926 m
.64192 .55014 L
s
.618 .252 1 r
.36952 .50926 m
.36795 .54909 L
s
.953 .176 1 r
.54382 .55988 m
.54386 .5689 L
s
.54391 .56857 m
.54382 .55988 L
s
.54386 .5689 m
.54384 .55985 L
s
.54384 .55985 m
.54391 .56857 L
s
.485 .287 1 r
.45911 .54209 m
.45894 .55008 L
s
.45896 .55005 m
.45911 .54209 L
s
.45911 .54209 m
.45884 .55772 L
s
.367 .322 1 r
.48128 .54094 m
.48117 .54858 L
s
.48118 .54855 m
.48128 .54094 L
s
.48128 .54094 m
.48112 .55593 L
s
.69 .234 1 r
.51295 .56937 m
.51289 .56951 L
s
.54 .272 1 r
.43693 .54352 m
.43671 .55158 L
s
.43672 .55155 m
.43693 .54352 L
s
.43693 .54352 m
.43655 .5595 L
s
.559 .267 1 r
.58346 .54294 m
.58357 .55111 L
s
.58359 .55107 m
.58346 .54294 L
s
.58346 .54294 m
.58375 .55896 L
s
.857 .196 1 r
.4686 .57188 m
.46854 .57203 L
s
.965 .174 1 r
.51604 .50906 m
.51613 .55415 L
s
.733 .224 1 r
.46382 .55725 m
.46366 .5658 L
s
.46372 .56551 m
.46382 .55725 L
s
.46366 .5658 m
.46383 .55721 L
s
.46383 .55721 m
.46372 .56551 L
s
.81 .206 1 r
.44163 .55874 m
.44142 .56741 L
s
.44148 .56729 m
.44163 .55874 L
s
.44142 .56741 m
.44165 .55871 L
s
.44165 .55871 m
.44148 .56729 L
s
.38 .554 1 r
.66259 .50886 m
.66407 .5424 L
s
.55 .269 1 r
.39167 .50886 m
.39035 .54834 L
s
.777 .214 1 r
.33943 .55733 m
.33896 .56599 L
s
.33904 .56566 m
.33943 .55733 L
s
.618 .252 1 r
.53822 .50866 m
.53856 .5485 L
s
.777 .214 1 r
.33896 .56599 m
.33944 .55729 L
s
.33944 .55729 m
.33904 .56566 L
s
.494 .284 1 r
.47729 .56485 m
.47724 .56513 L
s
.473 .915 1 r
.53035 .55461 m
.53031 .55435 L
s
.711 .229 1 r
.63256 .55639 m
.63282 .5649 L
s
.63286 .56458 m
.63256 .55639 L
s
.63282 .5649 m
.63258 .55635 L
s
.63258 .55635 m
.63286 .56458 L
s
.744 .222 1 r
.68481 .50846 m
.68689 .5497 L
s
.531 .274 1 r
.41383 .50846 m
.41278 .54725 L
s
.648 .244 1 r
.38377 .55544 m
.38343 .56382 L
s
.38349 .5635 m
.38377 .55544 L
s
.68 .237 1 r
.57951 .56717 m
.57946 .56759 L
s
.648 .244 1 r
.38343 .56382 m
.38378 .55541 L
s
.38378 .55541 m
.38349 .5635 L
s
.424 .305 1 r
.37905 .54073 m
.37871 .54855 L
s
.37872 .54851 m
.37905 .54073 L
s
.37905 .54073 m
.37844 .55605 L
s
.711 .229 1 r
.50817 .55619 m
.50812 .56471 L
s
.50818 .56439 m
.50817 .55619 L
s
.50812 .56471 m
.50819 .55616 L
s
.50819 .55616 m
.50818 .56439 L
s
.55 .269 1 r
.56041 .50826 m
.561 .5474 L
s
.638 .247 1 r
.60569 .54352 m
.60585 .55183 L
s
.60587 .55179 m
.60569 .54352 L
s
.60569 .54352 m
.60609 .55996 L
s
.68 .236 1 r
.41071 .56949 m
.41066 .56939 L
s
.476 .29 1 r
.37505 .56392 m
.37499 .56424 L
s
.441 .3 1 r
.45031 .55233 m
.45014 .56018 L
s
.4502 .5599 m
.45031 .55233 L
s
.589 .259 1 r
.50346 .54186 m
.50339 .55013 L
s
.5034 .5501 m
.50346 .54186 L
s
.50346 .54186 m
.50339 .55799 L
s
.441 .3 1 r
.45014 .56018 m
.45033 .5523 L
s
.45033 .5523 m
.4502 .5599 L
s
.658 .242 1 r
.33465 .54376 m
.33418 .55211 L
s
.3342 .55207 m
.33465 .54376 L
s
.33465 .54376 m
.33378 .56031 L
s
.896 .188 1 r
.70704 .50806 m
.70939 .54931 L
s
.811 .206 1 r
.43599 .50806 m
.43514 .54966 L
s
.669 .239 1 r
.45509 .56732 m
.45503 .56761 L
s
.638 .247 1 r
.35683 .54281 m
.35641 .55116 L
s
.35643 .55113 m
.35683 .54281 L
s
.35683 .54281 m
.35607 .55923 L
s
.868 .194 1 r
.61041 .559 m
.61062 .56773 L
s
.61067 .56776 m
.61041 .559 L
s
.54 .272 1 r
.42811 .55411 m
.42788 .56217 L
s
.42794 .56202 m
.42811 .55411 L
s
.868 .194 1 r
.61062 .56773 m
.61043 .55896 L
s
.61043 .55896 m
.61067 .56776 L
s
.8 .209 1 r
.58262 .50786 m
.58351 .54946 L
s
.367 .322 1 r
.31154 .50786 m
.30946 .54491 L
s
.54 .272 1 r
.42788 .56217 m
.42813 .55408 L
s
.42813 .55408 m
.42794 .56202 L
s
.4 .312 1 r
.61914 .55119 m
.61934 .55893 L
s
.61938 .55862 m
.61914 .55119 L
s
.61934 .55893 m
.61915 .55116 L
s
.61915 .55116 m
.61938 .55862 L
s
.608 .254 1 r
.35283 .56605 m
.35276 .56633 L
s
.811 .206 1 r
.45817 .50766 m
.45757 .54961 L
s
.711 .229 1 r
.55256 .55542 m
.55262 .56393 L
s
.55267 .56361 m
.55256 .55542 L
s
.649 .244 1 r
.57476 .55419 m
.57487 .5626 L
s
.57492 .56218 m
.57476 .55419 L
s
.711 .229 1 r
.55262 .56393 m
.55258 .55538 L
s
.55258 .55538 m
.55267 .56361 L
s
.649 .244 1 r
.57487 .5626 m
.57478 .55416 L
s
.57478 .55416 m
.57492 .56218 L
s
.638 .247 1 r
.3306 .56783 m
.33054 .5678 L
s
.722 .227 1 r
.40589 .55617 m
.4056 .56465 L
s
.40566 .56451 m
.40589 .55617 L
s
.711 .229 1 r
.60483 .50746 m
.60596 .54836 L
s
.788 .212 1 r
.33369 .50746 m
.33158 .54977 L
s
.722 .227 1 r
.4056 .56465 m
.40591 .55613 L
s
.40591 .55613 m
.40566 .56451 L
s
.55 .269 1 r
.49946 .5662 m
.49941 .56617 L
s
.385 .577 1 r
.34328 .53728 m
.3429 .54428 L
s
.34291 .54426 m
.34328 .53728 L
s
.34328 .53728 m
.34258 .55115 L
s
.649 .244 1 r
.64615 .56566 m
.64611 .56609 L
s
.342 .378 1 r
.53908 .54911 m
.53911 .55656 L
s
.53915 .55625 m
.53908 .54911 L
s
.53911 .55656 m
.5391 .54908 L
s
.5391 .54908 m
.53915 .55625 L
s
.618 .252 1 r
.40117 .54179 m
.40086 .5501 L
s
.40087 .55007 m
.40117 .54179 L
s
.40117 .54179 m
.40062 .5581 L
s
.416 .307 1 r
.37019 .55108 m
.36985 .55886 L
s
.36991 .55858 m
.37019 .55108 L
s
.67 .239 1 r
.48036 .50726 m
.48001 .54957 L
s
.416 .307 1 r
.36985 .55886 m
.37021 .55105 L
s
.37021 .55105 m
.36991 .55858 L
s
.578 .262 1 r
.32578 .5538 m
.32531 .56197 L
s
.32538 .56179 m
.32578 .5538 L
s
.337 .351 1 r
.64137 .55136 m
.64161 .55868 L
s
.64166 .55892 m
.64137 .55136 L
s
.578 .262 1 r
.32531 .56197 m
.32579 .55377 L
s
.32579 .55377 m
.32538 .56179 L
s
.337 .351 1 r
.64161 .55868 m
.64139 .55133 L
s
.64139 .55133 m
.64166 .55892 L
s
.777 .214 1 r
.62397 .56744 m
.62393 .56787 L
s
.37 .507 1 r
.62706 .50706 m
.62821 .54097 L
s
.648 .244 1 r
.35585 .50706 m
.35407 .54797 L
s
.658 .242 1 r
.67238 .54259 m
.6727 .55094 L
s
.67272 .5509 m
.67238 .54259 L
s
.67238 .54259 m
.67309 .55915 L
s
.68 .237 1 r
.59699 .55436 m
.59716 .56281 L
s
.5972 .56249 m
.59699 .55436 L
s
.512 .279 1 r
.41936 .56419 m
.4193 .56433 L
s
.45 .297 1 r
.50256 .50686 m
.5025 .54462 L
s
.68 .237 1 r
.59716 .56281 m
.59701 .55433 L
s
.59701 .55433 m
.5972 .56249 L
s
.486 .287 1 r
.6493 .50666 m
.65081 .54407 L
s
.767 .216 1 r
.37802 .50666 m
.3764 .55003 L
s
.403 .651 1 r
.62792 .54561 m
.62812 .55246 L
s
.62816 .55226 m
.62792 .54561 L
s
.62812 .55246 m
.62794 .54558 L
s
.62794 .54558 m
.62816 .55226 L
s
.777 .214 1 r
.54788 .54263 m
.54791 .5513 L
s
.54792 .55126 m
.54788 .54263 L
s
.54788 .54263 m
.54801 .55965 L
s
.589 .259 1 r
.56609 .56435 m
.56605 .56467 L
s
.93 .181 1 r
.52477 .50646 m
.52497 .54913 L
s
.69 .234 1 r
.47246 .55472 m
.47233 .56314 L
s
.47239 .56299 m
.47246 .55472 L
s
.47233 .56314 m
.47248 .55469 L
s
.47248 .55469 m
.47239 .56299 L
s
.669 .239 1 r
.57009 .54196 m
.57017 .55035 L
s
.57019 .55032 m
.57009 .54196 L
s
.57009 .54196 m
.57032 .55856 L
s
.496 .284 1 r
.63673 .53829 m
.63697 .54639 L
s
.63698 .54636 m
.63673 .53829 L
s
.63673 .53829 m
.63725 .5539 L
s
.509 1 .972 r
.68987 .52781 m
.69014 .53389 L
s
.69015 .53387 m
.68987 .52781 L
s
.68987 .52781 m
.69041 .53908 L
s
.598 .257 1 r
.51689 .55255 m
.51686 .56083 L
s
.51692 .56047 m
.51689 .55255 L
s
.588 .259 1 r
.67154 .50626 m
.67341 .54648 L
s
.58 .261 1 r
.40021 .50626 m
.39889 .54823 L
s
.442 .3 1 r
.48995 .53901 m
.48985 .54687 L
s
.48987 .54684 m
.48995 .53901 L
s
.48995 .53901 m
.48982 .55445 L
s
.598 .257 1 r
.51686 .56083 m
.51691 .55252 L
s
.51691 .55252 m
.51692 .56047 L
s
.55 .269 1 r
.66366 .55208 m
.66398 .56022 L
s
.66402 .55993 m
.66366 .55208 L
s
.66398 .56022 m
.66369 .55205 L
s
.66369 .55205 m
.66402 .55993 L
s
.486 .287 1 r
.48597 .56199 m
.48591 .56234 L
s
.658 .242 1 r
.49467 .55405 m
.49459 .5624 L
s
.49465 .56226 m
.49467 .55405 L
s
.45 .297 1 r
.56132 .55038 m
.56139 .55827 L
s
.56144 .55795 m
.56132 .55038 L
s
.766 .217 1 r
.3971 .56702 m
.39704 .56731 L
s
.658 .242 1 r
.49459 .5624 m
.49469 .55402 L
s
.49469 .55402 m
.49465 .56226 L
s
.45 .297 1 r
.56139 .55827 m
.56134 .55035 L
s
.56134 .55035 m
.56144 .55795 L
s
.4 .312 1 r
.65497 .56036 m
.65493 .56067 L
s
.468 .292 1 r
.54698 .50606 m
.54741 .54418 L
s
.848 .198 1 r
.59233 .54132 m
.59247 .55024 L
s
.59249 .5502 m
.59233 .54132 L
s
.59233 .54132 m
.59268 .55852 L
s
.799 .209 1 r
.52168 .56791 m
.52162 .56809 L
s
.868 .194 1 r
.4233 .5434 m
.42302 .55222 L
s
.42304 .55218 m
.4233 .5434 L
s
.4233 .5434 m
.42282 .56085 L
s
1 .151 .921 r
.52567 .54527 m
.52565 .55448 L
s
.52567 .55444 m
.52567 .54527 L
s
.52567 .54527 m
.5257 .56354 L
s
1 .116 .73 r
.65027 .54591 m
.65058 .55551 L
s
.6506 .55547 m
.65027 .54591 L
s
.65027 .54591 m
.65096 .56478 L
s
.55 .269 1 r
.6938 .50586 m
.69589 .54538 L
s
.477 .289 1 r
.4224 .50586 m
.42147 .54398 L
s
.744 .221 1 r
.46774 .54113 m
.46757 .54976 L
s
.46759 .54973 m
.46774 .54113 L
s
.46774 .54113 m
.46749 .55798 L
s
.845 .199 1 r
.34786 .55536 m
.34741 .56417 L
s
.34748 .56385 m
.34786 .55536 L
s
.648 .244 1 r
.39229 .55291 m
.39197 .5613 L
s
.39204 .56098 m
.39229 .55291 L
s
.512 .279 1 r
.41451 .55169 m
.41425 .55968 L
s
.41431 .55954 m
.41451 .55169 L
s
.754 .219 1 r
.44551 .54242 m
.44529 .55099 L
s
.44531 .55096 m
.44551 .54242 L
s
.44551 .54242 m
.44515 .55942 L
s
.845 .199 1 r
.34741 .56417 m
.34787 .55533 L
s
.34787 .55533 m
.34748 .56385 L
s
.648 .244 1 r
.39197 .5613 m
.39231 .55288 L
s
.39231 .55288 m
.39204 .56098 L
s
.512 .279 1 r
.41425 .55968 m
.41453 .55166 L
s
.41453 .55166 m
.41431 .55954 L
s
.45 .297 1 r
.659 .53839 m
.65927 .54628 L
s
.65929 .54625 m
.659 .53839 L
s
.659 .53839 m
.65961 .55386 L
s
.416 .307 1 r
.56921 .50566 m
.56987 .54308 L
s
.531 .274 1 r
.36135 .56249 m
.36128 .56281 L
s
.712 .229 1 r
.58835 .56501 m
.5883 .56543 L
s
.669 .239 1 r
.32089 .54219 m
.32039 .55052 L
s
.3204 .55048 m
.32089 .54219 L
s
.32089 .54219 m
.31995 .55887 L
s
.367 .322 1 r
.48117 .54858 m
.48106 .55621 L
s
.48112 .55593 m
.48117 .54858 L
s
.48106 .55621 m
.48118 .54855 L
s
.48118 .54855 m
.48112 .55593 L
s
.559 .267 1 r
.51217 .53941 m
.51212 .54759 L
s
.51214 .54756 m
.51217 .53941 L
s
.51217 .53941 m
.51214 .55545 L
s
.811 .206 1 r
.71607 .50546 m
.71856 .54744 L
s
.649 .244 1 r
.4446 .50546 m
.44388 .54534 L
s
.485 .287 1 r
.45894 .55008 m
.45878 .55807 L
s
.45884 .55772 m
.45894 .55008 L
s
.45878 .55807 m
.45896 .55005 L
s
.45896 .55005 m
.45884 .55772 L
s
.54 .272 1 r
.43671 .55158 m
.4365 .55964 L
s
.43655 .5595 m
.43671 .55158 L
s
.588 .259 1 r
.36531 .54044 m
.36491 .54862 L
s
.36493 .54859 m
.36531 .54044 L
s
.36531 .54044 m
.36459 .55669 L
s
.579 .262 1 r
.59146 .50526 m
.59239 .54444 L
s
.628 .249 1 r
.31996 .50526 m
.31777 .54584 L
s
.54 .272 1 r
.4365 .55964 m
.43672 .55155 L
s
.43672 .55155 m
.43655 .5595 L
s
.559 .267 1 r
.58357 .55111 m
.5837 .55928 L
s
.58375 .55896 m
.58357 .55111 L
s
.5837 .55928 m
.58359 .55107 L
s
.58359 .55107 m
.58375 .55896 L
s
.953 .176 1 r
.54391 .56857 m
.54386 .5689 L
s
.357 .448 1 r
.62332 .53403 m
.6235 .54145 L
s
.62352 .54142 m
.62332 .53403 L
s
.62332 .53403 m
.62373 .54826 L
s
.733 .224 1 r
.46372 .56551 m
.46366 .5658 L
s
.648 .244 1 r
.46681 .50506 m
.46634 .54529 L
s
.531 .274 1 r
.40975 .53862 m
.40946 .54672 L
s
.40947 .54669 m
.40975 .53862 L
s
.40975 .53862 m
.40925 .55451 L
s
.99 .169 1 r
.61461 .54239 m
.61481 .55152 L
s
.61483 .55148 m
.61461 .54239 L
s
.61461 .54239 m
.61509 .56023 L
s
.811 .206 1 r
.61371 .50486 m
.61496 .5465 L
s
.588 .259 1 r
.34214 .50486 m
.34023 .54509 L
s
.81 .206 1 r
.44148 .56729 m
.44142 .56741 L
s
.777 .214 1 r
.33904 .56566 m
.33896 .56599 L
s
.424 .305 1 r
.37871 .54855 m
.37837 .55636 L
s
.37844 .55605 m
.37871 .54855 L
s
.608 .254 1 r
.48904 .50466 m
.48882 .54489 L
s
.711 .229 1 r
.63286 .56458 m
.63282 .5649 L
s
.424 .305 1 r
.37837 .55636 m
.37872 .54851 L
s
.37872 .54851 m
.37844 .55605 L
s
.648 .244 1 r
.38349 .5635 m
.38343 .56382 L
s
.441 .3 1 r
.4502 .5599 m
.45014 .56018 L
s
.691 .234 1 r
.63597 .50446 m
.63744 .5447 L
s
.733 .224 1 r
.36434 .50446 m
.36263 .5461 L
s
.711 .229 1 r
.50818 .56439 m
.50812 .56471 L
s
.744 .222 1 r
.38747 .54109 m
.38711 .54962 L
s
.38713 .54959 m
.38747 .54109 L
s
.38747 .54109 m
.38683 .55805 L
s
.531 .274 1 r
.55665 .53936 m
.55669 .54736 L
s
.55671 .54733 m
.55665 .53936 L
s
.55665 .53936 m
.55681 .55536 L
s
.638 .247 1 r
.60585 .55183 m
.60604 .56014 L
s
.60609 .55996 m
.60585 .55183 L
s
.4 .312 1 r
.61938 .55862 m
.61934 .55893 L
s
.669 .239 1 r
.51127 .50426 m
.51131 .54485 L
s
.638 .247 1 r
.60604 .56014 m
.60587 .55179 L
s
.60587 .55179 m
.60609 .55996 L
s
.589 .259 1 r
.50339 .55013 m
.50333 .55841 L
s
.50339 .55799 m
.50339 .55013 L
s
1 .165 .994 r
.68138 .54023 m
.68177 .54951 L
s
.68179 .54947 m
.68138 .54023 L
s
.68138 .54023 m
.6822 .55801 L
s
.589 .259 1 r
.50333 .55841 m
.5034 .5501 L
s
.5034 .5501 m
.50339 .55799 L
s
.658 .242 1 r
.33418 .55211 m
.33372 .56046 L
s
.33378 .56031 m
.33418 .55211 L
s
.33372 .56046 m
.3342 .55207 L
s
.3342 .55207 m
.33378 .56031 L
s
.54 .272 1 r
.42794 .56202 m
.42788 .56217 L
s
.68 .237 1 r
.65824 .50406 m
.65997 .5443 L
s
.569 .264 1 r
.38655 .50406 m
.38513 .54465 L
s
.385 .577 1 r
.3429 .54428 m
.34253 .55129 L
s
.34258 .55115 m
.3429 .54428 L
s
.34253 .55129 m
.34291 .54426 L
s
.34291 .54426 m
.34258 .55115 L
s
.638 .247 1 r
.35641 .55116 m
.356 .55951 L
s
.35607 .55923 m
.35641 .55116 L
s
.57 .264 1 r
.47642 .53699 m
.47628 .54527 L
s
.4763 .54523 m
.47642 .53699 L
s
.47642 .53699 m
.47622 .55299 L
s
.638 .247 1 r
.356 .55951 m
.35643 .55113 L
s
.35643 .55113 m
.35607 .55923 L
s
.618 .252 1 r
.43193 .53947 m
.43168 .54772 L
s
.4317 .54769 m
.43193 .53947 L
s
.43193 .53947 m
.43152 .55587 L
s
.485 .287 1 r
.45417 .53832 m
.45398 .54621 L
s
.454 .54618 m
.45417 .53832 L
s
.45417 .53832 m
.45387 .55408 L
s
.342 .378 1 r
.53915 .55625 m
.53911 .55656 L
s
.54 .272 1 r
.53352 .50386 m
.5338 .5434 L
s
.649 .244 1 r
.57492 .56218 m
.57487 .5626 L
s
.868 .194 1 r
.61067 .56776 m
.61062 .56773 L
s
.416 .307 1 r
.36991 .55858 m
.36985 .55886 L
s
.522 .277 1 r
.68052 .50365 m
.68245 .54285 L
s
.513 .279 1 r
.40877 .50365 m
.40767 .54215 L
s
.711 .229 1 r
.55267 .56361 m
.55262 .56393 L
s
.337 .351 1 r
.64166 .55892 m
.64161 .55868 L
s
.559 .267 1 r
.3294 .53847 m
.32892 .54658 L
s
.32894 .54654 m
.3294 .53847 L
s
.3294 .53847 m
.32852 .55458 L
s
.722 .227 1 r
.40566 .56451 m
.4056 .56465 L
s
.403 .651 1 r
.62816 .55226 m
.62812 .55246 L
s
.468 .292 1 r
.55578 .50345 m
.5563 .5423 L
s
.881 .191 1 r
.57893 .54 m
.57904 .54892 L
s
.57906 .54888 m
.57893 .54 L
s
.57893 .54 m
.57922 .55742 L
s
.509 1 .972 r
.69014 .53389 m
.69042 .53997 L
s
.69041 .53908 m
.69014 .53389 L
s
.69042 .53997 m
.69015 .53387 L
s
.69015 .53387 m
.69041 .53908 L
s
.618 .252 1 r
.40086 .5501 m
.40055 .55842 L
s
.40062 .5581 m
.40086 .5501 L
s
.578 .262 1 r
.32538 .56179 m
.32531 .56197 L
s
1 .151 .921 r
.53443 .54272 m
.53443 .55194 L
s
.53445 .5519 m
.53443 .54272 L
s
.53443 .54272 m
.5345 .56101 L
s
.618 .252 1 r
.40055 .55842 m
.40087 .55007 L
s
.40087 .55007 m
.40062 .5581 L
s
.385 .576 1 r
.58766 .53233 m
.58776 .53941 L
s
.58778 .53938 m
.58766 .53233 L
s
.58766 .53233 m
.58792 .54614 L
s
.892 .189 1 r
.70282 .50325 m
.70523 .54667 L
s
.744 .221 1 r
.431 .50325 m
.43009 .54456 L
s
.68 .237 1 r
.57804 .50305 m
.57885 .54366 L
s
.468 .292 1 r
.30619 .50305 m
.30399 .54121 L
s
.68 .237 1 r
.5972 .56249 m
.59716 .56281 L
s
.503 .282 1 r
.37384 .53726 m
.37348 .54524 L
s
.37349 .5452 m
.37384 .53726 L
s
.37384 .53726 m
.37319 .5531 L
s
.658 .242 1 r
.6727 .55094 m
.67304 .55929 L
s
.67309 .55915 m
.6727 .55094 L
s
.67304 .55929 m
.67272 .5509 L
s
.67272 .5509 m
.67309 .55915 L
s
.477 .289 1 r
.54317 .53553 m
.54319 .54353 L
s
.5432 .5435 m
.54317 .53553 L
s
.54317 .53553 m
.54327 .55112 L
s
.881 .191 1 r
.60121 .53991 m
.60138 .54881 L
s
.6014 .54877 m
.60121 .53991 L
s
.60121 .53991 m
.60161 .55738 L
s
.744 .222 1 r
.35159 .53869 m
.35114 .5473 L
s
.35115 .54726 m
.35159 .53869 L
s
.35159 .53869 m
.35078 .55559 L
s
.589 .259 1 r
.72512 .50285 m
.72759 .54276 L
s
.618 .252 1 r
.45324 .50285 m
.45261 .54276 L
s
.56 .267 1 r
.66799 .53635 m
.6683 .54456 L
s
.66832 .54453 m
.66799 .53635 L
s
.66799 .53635 m
.66866 .55236 L
s
.628 .249 1 r
.49865 .53826 m
.49856 .54655 L
s
.49858 .54651 m
.49865 .53826 L
s
.49865 .53826 m
.49855 .5547 L
s
.68 .237 1 r
.64574 .53788 m
.64601 .54635 L
s
.64603 .54632 m
.64574 .53788 L
s
.64574 .53788 m
.64633 .5545 L
s
.892 .189 1 r
.60032 .50265 m
.60146 .54608 L
s
.679 .237 1 r
.3284 .50265 m
.32627 .54397 L
s
.442 .3 1 r
.48985 .54687 m
.48977 .55473 L
s
.48982 .55445 m
.48985 .54687 L
s
.45 .297 1 r
.56144 .55795 m
.56139 .55827 L
s
.598 .257 1 r
.51692 .56047 m
.51686 .56083 L
s
.442 .3 1 r
.48977 .55473 m
.48987 .54684 L
s
.48987 .54684 m
.48982 .55445 L
s
.69 .234 1 r
.47239 .56299 m
.47233 .56314 L
s
.777 .214 1 r
.54791 .5513 m
.54795 .55997 L
s
.54801 .55965 m
.54791 .5513 L
s
.55 .269 1 r
.66402 .55993 m
.66398 .56022 L
s
.496 .284 1 r
.63697 .54639 m
.63722 .5545 L
s
.63725 .5539 m
.63697 .54639 L
s
.618 .252 1 r
.47549 .50245 m
.47511 .54236 L
s
.777 .214 1 r
.54795 .55997 m
.54792 .55126 L
s
.54792 .55126 m
.54801 .55965 L
s
.496 .284 1 r
.63722 .5545 m
.63698 .54636 L
s
.63698 .54636 m
.63725 .5539 L
s
.578 .262 1 r
.39607 .53721 m
.39574 .5454 L
s
.39576 .54537 m
.39607 .53721 L
s
.39607 .53721 m
.3955 .55341 L
s
.669 .239 1 r
.57017 .55035 m
.57027 .55874 L
s
.57032 .55856 m
.57017 .55035 L
s
.57027 .55874 m
.57019 .55032 L
s
.57019 .55032 m
.57032 .55856 L
s
.542 .271 1 r
.62261 .50225 m
.62387 .54076 L
s
.468 .292 1 r
.35062 .50225 m
.3489 .54041 L
s
.658 .242 1 r
.49465 .56226 m
.49459 .5624 L
s
.512 .279 1 r
.41431 .55954 m
.41425 .55968 L
s
.799 .209 1 r
.49775 .50205 m
.49762 .54407 L
s
.367 .322 1 r
.48112 .55593 m
.48106 .55621 L
s
.648 .244 1 r
.39204 .56098 m
.39197 .5613 L
s
.45 .297 1 r
.65927 .54628 m
.65957 .55417 L
s
.65961 .55386 m
.65927 .54628 L
s
.65957 .55417 m
.65929 .54625 L
s
.65929 .54625 m
.65961 .55386 L
s
.777 .214 1 r
.52092 .53893 m
.52088 .54755 L
s
.5209 .54751 m
.52092 .53893 L
s
.52092 .53893 m
.52092 .55606 L
s
.55 .269 1 r
.44057 .53591 m
.44035 .54406 L
s
.44037 .54402 m
.44057 .53591 L
s
.44057 .53591 m
.44021 .55193 L
s
.531 1 .913 r
.64491 .50185 m
.64595 .52847 L
s
.777 .214 1 r
.37286 .50184 m
.37121 .54423 L
s
.848 .198 1 r
.59247 .55024 m
.59264 .55916 L
s
.59268 .55852 m
.59247 .55024 L
s
.845 .199 1 r
.34748 .56385 m
.34741 .56417 L
s
.848 .198 1 r
.59264 .55916 m
.59249 .5502 L
s
.59249 .5502 m
.59268 .55852 L
s
.485 .287 1 r
.45884 .55772 m
.45878 .55807 L
s
.868 .194 1 r
.42302 .55222 m
.42276 .56104 L
s
.42282 .56085 m
.42302 .55222 L
s
.754 .219 1 r
.44529 .55099 m
.44509 .55956 L
s
.44515 .55942 m
.44529 .55099 L
s
.744 .221 1 r
.46757 .54976 m
.46742 .55841 L
s
.46749 .55798 m
.46757 .54976 L
s
.868 .194 1 r
.42276 .56104 m
.42304 .55218 L
s
.42304 .55218 m
.42282 .56085 L
s
.754 .219 1 r
.44509 .55956 m
.44531 .55096 L
s
.44531 .55096 m
.44515 .55942 L
s
.744 .221 1 r
.46742 .55841 m
.46759 .54973 L
s
.46759 .54973 m
.46749 .55798 L
s
.669 .239 1 r
.32039 .55052 m
.3199 .55884 L
s
.31995 .55887 m
.32039 .55052 L
s
.486 .287 1 r
.48512 .5338 m
.485 .54188 L
s
.48502 .54184 m
.48512 .5338 L
s
.48512 .5338 m
.48496 .54939 L
s
.733 .224 1 r
.41829 .53755 m
.41801 .54612 L
s
.41803 .54609 m
.41829 .53755 L
s
.41829 .53755 m
.41781 .55442 L
s
.46 .294 1 r
.52002 .50164 m
.52015 .53876 L
s
.669 .239 1 r
.3199 .55884 m
.3204 .55048 L
s
.3204 .55048 m
.31995 .55887 L
s
.559 .267 1 r
.51212 .54759 m
.51208 .55577 L
s
.51214 .55545 m
.51212 .54759 L
s
.357 .448 1 r
.6235 .54145 m
.6237 .54889 L
s
.62373 .54826 m
.6235 .54145 L
s
1 .151 .921 r
.52565 .55448 m
.52564 .56369 L
s
.5257 .56354 m
.52565 .55448 L
s
.559 .267 1 r
.51208 .55577 m
.51214 .54756 L
s
.51214 .54756 m
.51214 .55545 L
s
.357 .448 1 r
.6237 .54889 m
.62352 .54142 L
s
.62352 .54142 m
.62373 .54826 L
s
1 .151 .921 r
.52564 .56369 m
.52567 .55444 L
s
.52567 .55444 m
.5257 .56354 L
s
.54 .272 1 r
.43655 .5595 m
.4365 .55964 L
s
.559 .267 1 r
.58375 .55896 m
.5837 .55928 L
s
.777 .214 1 r
.66722 .50144 m
.6691 .54277 L
s
.503 .282 1 r
.3951 .50144 m
.39386 .53996 L
s
.588 .259 1 r
.36491 .54862 m
.36453 .5568 L
s
.36459 .55669 m
.36491 .54862 L
s
.777 .214 1 r
.56548 .53752 m
.56555 .5462 L
s
.56557 .54617 m
.56548 .53752 L
s
.56548 .53752 m
.5657 .55457 L
s
.588 .259 1 r
.36453 .5568 m
.36493 .54859 L
s
.36493 .54859 m
.36459 .55669 L
s
1 .116 .73 r
.65058 .55551 m
.65091 .56512 L
s
.65096 .56478 m
.65058 .55551 L
s
.65091 .56512 m
.6506 .55547 L
s
.6506 .55547 m
.65096 .56478 L
s
.441 .3 1 r
.5423 .50124 m
.54267 .53907 L
s
.618 .252 1 r
.3156 .53671 m
.31509 .54497 L
s
.3151 .54494 m
.3156 .53671 L
s
.3156 .53671 m
.31465 .55313 L
s
.531 .274 1 r
.40946 .54672 m
.40918 .55483 L
s
.40925 .55451 m
.40946 .54672 L
s
.40918 .55483 m
.40947 .54669 L
s
.40947 .54669 m
.40925 .55451 L
s
.424 .305 1 r
.37844 .55605 m
.37837 .55636 L
s
.503 .282 1 r
.68954 .50104 m
.69153 .53957 L
s
.521 .277 1 r
.41736 .50104 m
.41634 .54027 L
s
.509 1 .972 r
.69041 .53908 m
.69042 .53997 L
s
.598 .257 1 r
.33785 .53608 m
.33739 .5443 L
s
.33741 .54427 m
.33785 .53608 L
s
.33785 .53608 m
.33701 .55239 L
s
.69 .234 1 r
.56459 .50084 m
.56526 .54218 L
s
.385 .577 1 r
.34258 .55115 m
.34253 .55129 L
s
.588 .259 1 r
.71187 .50064 m
.71417 .54022 L
s
.68 .237 1 r
.43962 .50064 m
.43884 .54092 L
s
.99 .169 1 r
.61481 .55152 m
.61504 .56066 L
s
.61509 .56023 m
.61481 .55152 L
s
.405 .662 1 r
.47155 .52921 m
.47142 .53609 L
s
.47144 .53606 m
.47155 .52921 L
s
.47155 .52921 m
.47136 .54269 L
s
.578 .262 1 r
.63237 .53544 m
.63259 .54363 L
s
.63261 .5436 m
.63237 .53544 L
s
.63237 .53544 m
.63288 .55164 L
s
.99 .169 1 r
.61504 .56066 m
.61483 .55148 L
s
.61483 .55148 m
.61509 .56023 L
s
.531 .274 1 r
.55669 .54736 m
.55676 .55537 L
s
.55681 .55536 m
.55669 .54736 L
s
.55676 .55537 m
.55671 .54733 L
s
.55671 .54733 m
.55681 .55536 L
s
.589 .259 1 r
.50339 .55799 m
.50333 .55841 L
s
.503 .282 1 r
.52968 .53388 m
.52966 .54192 L
s
.52968 .54189 m
.52968 .53388 L
s
.52968 .53388 m
.52972 .54966 L
s
.4 .312 1 r
.5869 .50044 m
.58773 .53757 L
s
.628 .249 1 r
.31462 .50043 m
.3123 .54213 L
s
.881 .191 1 r
.6101 .53704 m
.61029 .54598 L
s
.61031 .54594 m
.6101 .53704 L
s
.6101 .53704 m
.61054 .55449 L
s
.638 .247 1 r
.60609 .55996 m
.60604 .56014 L
s
.744 .222 1 r
.38711 .54962 m
.38677 .55816 L
s
.38683 .55805 m
.38711 .54962 L
s
.868 .194 1 r
.46281 .5379 m
.46262 .54673 L
s
.46264 .54669 m
.46281 .5379 L
s
.46281 .5379 m
.46252 .55538 L
s
.744 .222 1 r
.38677 .55816 m
.38713 .54959 L
s
.38713 .54959 m
.38683 .55805 L
s
.86 .196 1 r
.73421 .50023 m
.73687 .54123 L
s
.477 .289 1 r
.4619 .50023 m
.46139 .53842 L
s
.658 .242 1 r
.33378 .56031 m
.33372 .56046 L
s
.485 .287 1 r
.45398 .54621 m
.45382 .55412 L
s
.45387 .55408 m
.45398 .54621 L
s
.638 .247 1 r
.35607 .55923 m
.356 .55951 L
s
.648 .244 1 r
.6547 .53511 m
.65498 .54351 L
s
.655 .54348 m
.6547 .53511 L
s
.6547 .53511 m
.65532 .5516 L
s
.485 .287 1 r
.45382 .55412 m
.454 .54618 L
s
.454 .54618 m
.45387 .55408 L
s
.618 .252 1 r
.43168 .54772 m
.43146 .55598 L
s
.43152 .55587 m
.43168 .54772 L
s
.57 .264 1 r
.47628 .54527 m
.47616 .55356 L
s
.47622 .55299 m
.47628 .54527 L
s
.352 .327 1 r
.60921 .50003 m
.61026 .53612 L
s
.337 .353 1 r
.33687 .50003 m
.3351 .53612 L
s
.618 .252 1 r
.43146 .55598 m
.4317 .54769 L
s
.4317 .54769 m
.43152 .55587 L
s
.57 .264 1 r
.47616 .55356 m
.4763 .54523 L
s
.4763 .54523 m
.47622 .55299 L
s
.766 .217 1 r
.50739 .53618 m
.50732 .54483 L
s
.50734 .54479 m
.50739 .53618 L
s
.50739 .53618 m
.50733 .5532 L
s
.385 .576 1 r
.58776 .53941 m
.58789 .54649 L
s
.58792 .54614 m
.58776 .53941 L
s
.669 .239 1 r
.38235 .53567 m
.38199 .54407 L
s
.382 .54404 m
.38235 .53567 L
s
.38235 .53567 m
.3817 .5523 L
s
.385 .576 1 r
.58789 .54649 m
.58778 .53938 L
s
.58778 .53938 m
.58792 .54614 L
s
.55 .269 1 r
.48419 .49983 m
.48392 .53908 L
s
1 .165 .994 r
.68177 .54951 m
.68217 .5588 L
s
.6822 .55801 m
.68177 .54951 L
s
.916 .184 1 r
.36005 .53717 m
.3596 .54614 L
s
.35962 .5461 m
.36005 .53717 L
s
.36005 .53717 m
.35925 .5548 L
s
1 .165 .994 r
.68217 .5588 m
.68179 .54947 L
s
.68179 .54947 m
.6822 .55801 L
s
.559 .267 1 r
.32892 .54658 m
.32846 .55469 L
s
.32852 .55458 m
.32892 .54658 L
s
.32846 .55469 m
.32894 .54654 L
s
.32894 .54654 m
.32852 .55458 L
s
.68 .237 1 r
.40464 .53492 m
.40432 .5434 L
s
.40434 .54336 m
.40464 .53492 L
s
.40464 .53492 m
.40409 .55156 L
s
.881 .191 1 r
.63154 .49963 m
.63303 .54204 L
s
.476 .29 1 r
.35913 .49963 m
.3575 .53782 L
s
.618 .252 1 r
.40062 .5581 m
.40055 .55842 L
s
.38 .554 1 r
.6635 .5285 m
.66376 .53566 L
s
.66378 .53563 m
.6635 .5285 L
s
.6635 .5285 m
.66407 .5424 L
s
.485 .287 1 r
.57429 .53347 m
.57438 .54141 L
s
.5744 .54138 m
.57429 .53347 L
s
.57429 .53347 m
.57453 .54922 L
s
.669 .239 1 r
.55199 .53476 m
.55203 .5432 L
s
.55205 .54317 m
.55199 .53476 L
s
.55199 .53476 m
.55214 .55136 L
s
.608 .254 1 r
.42692 .53415 m
.42667 .54245 L
s
.42669 .54241 m
.42692 .53415 L
s
.42692 .53415 m
.42649 .55047 L
s
.65 .244 1 r
.50648 .49943 m
.50646 .54008 L
s
.531 .274 1 r
.44922 .5331 m
.44903 .54122 L
s
.44904 .54118 m
.44922 .5331 L
s
.44922 .5331 m
.4489 .54902 L
s
.434 .302 1 r
.65387 .49922 m
.65542 .53637 L
s
.658 .242 1 r
.3814 .49922 m
.37991 .54023 L
s
.881 .191 1 r
.57904 .54892 m
.57917 .55786 L
s
.57922 .55742 m
.57904 .54892 L
s
.503 .282 1 r
.37348 .54524 m
.37313 .55321 L
s
.37319 .5531 m
.37348 .54524 L
s
.881 .191 1 r
.57917 .55786 m
.57906 .54888 L
s
.57906 .54888 m
.57922 .55742 L
s
.503 .282 1 r
.37313 .55321 m
.37349 .5452 L
s
.37349 .5452 m
.37319 .5531 L
s
.834 .201 1 r
.67709 .536 m
.67744 .5448 L
s
.67747 .54476 m
.67709 .536 L
s
.67709 .536 m
.67786 .55331 L
s
.477 .289 1 r
.54319 .54353 m
.54322 .55154 L
s
.54327 .55112 m
.54319 .54353 L
s
.54322 .55154 m
.5432 .5435 L
s
.5432 .5435 m
.54327 .55112 L
s
.868 .194 1 r
.52879 .49902 m
.52904 .54214 L
s
.658 .242 1 r
.67309 .55915 m
.67304 .55929 L
s
1 .151 .921 r
.53443 .55194 m
.53445 .56116 L
s
.5345 .56101 m
.53443 .55194 L
s
.56 .267 1 r
.6683 .54456 m
.66863 .55279 L
s
.66866 .55236 m
.6683 .54456 L
s
1 .151 .921 r
.53445 .56116 m
.53445 .5519 L
s
.53445 .5519 m
.5345 .56101 L
s
.442 .3 1 r
.48982 .55445 m
.48977 .55473 L
s
.56 .267 1 r
.66863 .55279 m
.66832 .54453 L
s
.66832 .54453 m
.66866 .55236 L
s
.496 .284 1 r
.63725 .5539 m
.63722 .5545 L
s
.628 .249 1 r
.49856 .54655 m
.49849 .55484 L
s
.49855 .5547 m
.49856 .54655 L
s
.467 .292 1 r
.67622 .49882 m
.67807 .53737 L
s
1 .164 .985 r
.40368 .49882 m
.40236 .543 L
s
.628 .249 1 r
.49849 .55484 m
.49858 .54651 L
s
.49858 .54651 m
.49855 .5547 L
s
.744 .222 1 r
.35114 .5473 m
.35071 .55591 L
s
.35078 .55559 m
.35114 .5473 L
s
.35071 .55591 m
.35115 .54726 L
s
.35115 .54726 m
.35078 .55559 L
s
.881 .191 1 r
.60138 .54881 m
.60156 .55771 L
s
.60161 .55738 m
.60138 .54881 L
s
.68 .237 1 r
.64601 .54635 m
.64629 .55482 L
s
.64633 .5545 m
.64601 .54635 L
s
.881 .191 1 r
.60156 .55771 m
.6014 .54877 L
s
.6014 .54877 m
.60161 .55738 L
s
.811 .206 1 r
.55111 .49862 m
.55163 .54069 L
s
.68 .237 1 r
.64629 .55482 m
.64603 .54632 L
s
.64603 .54632 m
.64633 .5545 L
s
.578 .262 1 r
.39574 .5454 m
.39543 .55359 L
s
.3955 .55341 m
.39574 .5454 L
s
.777 .214 1 r
.54801 .55965 m
.54795 .55997 L
s
.578 .262 1 r
.32405 .53429 m
.32356 .54241 L
s
.32358 .54238 m
.32405 .53429 L
s
.32405 .53429 m
.32314 .55058 L
s
.39543 .55359 m
.39576 .54537 L
s
.39576 .54537 m
.3955 .55341 L
s
.977 .171 1 r
.69857 .49842 m
.70096 .54225 L
s
.494 .285 1 r
.42597 .49842 m
.42503 .53803 L
s
.669 .239 1 r
.57032 .55856 m
.57027 .55874 L
s
.357 .448 1 r
.62373 .54826 m
.6237 .54889 L
s
.45 .297 1 r
.65961 .55386 m
.65957 .55417 L
s
.598 .257 1 r
.34635 .53351 m
.34591 .54174 L
s
.34592 .54171 m
.34635 .53351 L
s
.34635 .53351 m
.34554 .54983 L
s
.659 .242 1 r
.57344 .49821 m
.57419 .53853 L
s
.392 .315 1 r
.3008 .49821 m
.29855 .53608 L
s
.618 .252 1 r
.36865 .53273 m
.36826 .54107 L
s
.36827 .54103 m
.36865 .53273 L
s
.36865 .53273 m
.36795 .54909 L
s
.966 .173 1 r
.72094 .49801 m
.72355 .5408 L
s
.494 .284 1 r
.44827 .49801 m
.44761 .53658 L
s
.55 .269 1 r
.44035 .54406 m
.44015 .55221 L
s
.44021 .55193 m
.44035 .54406 L
s
.44015 .55221 m
.44037 .54402 L
s
.44037 .54402 m
.44021 .55193 L
s
.848 .198 1 r
.59268 .55852 m
.59264 .55916 L
s
.559 .267 1 r
.51214 .55545 m
.51208 .55577 L
s
.486 .287 1 r
.485 .54188 m
.4849 .54996 L
s
.48496 .54939 m
.485 .54188 L
s
1 .158 .957 r
.59669 .53566 m
.59685 .54493 L
s
.59687 .54489 m
.59669 .53566 L
s
.59669 .53566 m
.59709 .55373 L
s
.711 .229 1 r
.59578 .49781 m
.59681 .53884 L
s
.892 .189 1 r
.32308 .49781 m
.32077 .5413 L
s
.744 .221 1 r
.46749 .55798 m
.46742 .55841 L
s
.486 .287 1 r
.4849 .54996 m
.48502 .54184 L
s
.48502 .54184 m
.48496 .54939 L
s
.777 .214 1 r
.52088 .54755 m
.52086 .55617 L
s
.52092 .55606 m
.52088 .54755 L
s
.52086 .55617 m
.5209 .54751 L
s
.5209 .54751 m
.52092 .55606 L
s
.711 .229 1 r
.64134 .53335 m
.6416 .5419 L
s
.64162 .54187 m
.64134 .53335 L
s
.64134 .53335 m
.64192 .55014 L
s
.754 .219 1 r
.44515 .55942 m
.44509 .55956 L
s
.669 .239 1 r
.31995 .55887 m
.3199 .55884 L
s
.55 .269 1 r
.39095 .53226 m
.39061 .54039 L
s
.39063 .54036 m
.39095 .53226 L
s
.39095 .53226 m
.39035 .54834 L
s
.868 .194 1 r
.42282 .56085 m
.42276 .56104 L
s
.822 .204 1 r
.74332 .49761 m
.74619 .5404 L
s
.477 .289 1 r
.47059 .49761 m
.47018 .53582 L
s
.733 .224 1 r
.41801 .54612 m
.41774 .55471 L
s
.41781 .55442 m
.41801 .54612 L
s
.37 .507 1 r
.62778 .52688 m
.62797 .53415 L
s
.62799 .53412 m
.62778 .52688 L
s
.62778 .52688 m
.62821 .54097 L
s
.733 .224 1 r
.41774 .55471 m
.41803 .54609 L
s
.41803 .54609 m
.41781 .55442 L
s
.588 .259 1 r
.36459 .55669 m
.36453 .5568 L
s
.531 .274 1 r
.41327 .53131 m
.41299 .53944 L
s
.413 .5394 m
.41327 .53131 L
s
.41327 .53131 m
.41278 .54725 L
s
.881 .191 1 r
.61903 .5351 m
.61924 .54397 L
s
.61926 .54394 m
.61903 .5351 L
s
.61903 .5351 m
.61952 .55263 L
s
1 .166 .997 r
.69958 .53824 m
.69999 .54719 L
s
.70002 .54716 m
.69958 .53824 L
s
.69958 .53824 m
.7005 .55643 L
s
.599 .257 1 r
.49381 .53456 m
.49371 .54266 L
s
.49373 .54262 m
.49381 .53456 L
s
.49381 .53456 m
.49368 .55104 L
s
.618 .252 1 r
.53848 .53214 m
.53848 .54047 L
s
.5385 .54044 m
.53848 .53214 L
s
.53848 .53214 m
.53856 .5485 L
s
.408 .31 1 r
.61813 .49741 m
.6193 .53457 L
s
.669 .239 1 r
.34537 .49741 m
.34341 .53914 L
s
.531 .274 1 r
.40925 .55451 m
.40918 .55483 L
s
.367 .322 1 r
.31036 .52982 m
.30987 .53745 L
s
.30989 .53742 m
.31036 .52982 L
s
.31036 .52982 m
.30946 .54491 L
s
.405 .662 1 r
.47142 .53609 m
.47131 .54296 L
s
.47136 .54269 m
.47142 .53609 L
s
.47131 .54296 m
.47144 .53606 L
s
.47144 .53606 m
.47136 .54269 L
s
.777 .214 1 r
.56555 .5462 m
.56565 .5549 L
s
.5657 .55457 m
.56555 .5462 L
s
.618 .252 1 r
.31509 .54497 m
.31459 .55324 L
s
.31465 .55313 m
.31509 .54497 L
s
1 .151 .921 r
.5257 .56354 m
.52564 .56369 L
s
.55 .269 1 r
.56081 .53136 m
.56087 .53952 L
s
.56089 .53949 m
.56081 .53136 L
s
.56081 .53136 m
.561 .5474 L
s
.629 .249 1 r
.49291 .4972 m
.49274 .53719 L
s
.777 .214 1 r
.56565 .5549 m
.56557 .54617 L
s
.56557 .54617 m
.5657 .55457 L
s
.618 .252 1 r
.31459 .55324 m
.3151 .54494 L
s
.3151 .54494 m
.31465 .55313 L
s
.777 .214 1 r
.64049 .497 m
.64206 .53839 L
s
.608 .254 1 r
.36766 .497 m
.36605 .53698 L
s
.598 .257 1 r
.33739 .5443 m
.33695 .55253 L
s
.33701 .55239 m
.33739 .5443 L
s
1 .116 .73 r
.65096 .56478 m
.65091 .56512 L
s
.598 .257 1 r
.33695 .55253 m
.33741 .54427 L
s
.33741 .54427 m
.33701 .55239 L
s
.744 .222 1 r
.68609 .53277 m
.68645 .54139 L
s
.68648 .54136 m
.68609 .53277 L
s
.68609 .53277 m
.68689 .5497 L
s
.755 .219 1 r
.51525 .4968 m
.51532 .5396 L
s
.531 .274 1 r
.55681 .55536 m
.55676 .55537 L
s
.578 .262 1 r
.63259 .54363 m
.63283 .55182 L
s
.63288 .55164 m
.63259 .54363 L
s
.63283 .55182 m
.63261 .5436 L
s
.63261 .5436 m
.63288 .55164 L
s
.385 .576 1 r
.58792 .54614 m
.58789 .54649 L
s
.896 .188 1 r
.70846 .53191 m
.7089 .541 L
s
.70893 .54096 m
.70846 .53191 L
s
.70846 .53191 m
.70939 .54931 L
s
.503 .282 1 r
.52966 .54192 m
.52967 .54997 L
s
.52972 .54966 m
.52966 .54192 L
s
.766 .216 1 r
.66286 .4966 m
.66474 .53905 L
s
.391 .315 1 r
.38997 .4966 m
.38871 .53377 L
s
.503 .282 1 r
.52967 .54997 m
.52968 .54189 L
s
.52968 .54189 m
.52972 .54966 L
s
.99 .169 1 r
.61509 .56023 m
.61504 .56066 L
s
.485 .287 1 r
.45387 .55408 m
.45382 .55412 L
s
.638 .247 1 r
.53759 .49639 m
.53793 .53674 L
s
.811 .206 1 r
.43555 .53247 m
.4353 .54128 L
s
.43532 .54124 m
.43555 .53247 L
s
.43555 .53247 m
.43514 .54966 L
s
.57 .264 1 r
.47622 .55299 m
.47616 .55356 L
s
.744 .222 1 r
.38683 .55805 m
.38677 .55816 L
s
.486 .287 1 r
.65023 .52845 m
.65049 .53654 L
s
.65051 .53651 m
.65023 .52845 L
s
.65023 .52845 m
.65081 .54407 L
s
.45 .297 1 r
.50257 .5291 m
.5025 .53702 L
s
.50252 .53699 m
.50257 .5291 L
s
.50257 .5291 m
.5025 .54462 L
s
.723 .226 1 r
.68525 .49619 m
.6873 .53654 L
s
.638 .247 1 r
.41229 .49619 m
.41118 .53654 L
s
.881 .191 1 r
.61029 .54598 m
.6105 .55492 L
s
.61054 .55449 m
.61029 .54598 L
s
.618 .252 1 r
.43152 .55587 m
.43146 .55598 L
s
.8 .209 1 r
.5832 .53231 m
.58332 .54108 L
s
.58334 .54104 m
.5832 .53231 L
s
.5832 .53231 m
.58351 .54946 L
s
.648 .244 1 r
.65498 .54351 m
.65528 .55192 L
s
.65532 .5516 m
.65498 .54351 L
s
.881 .191 1 r
.6105 .55492 m
.61031 .54594 L
s
.61031 .54594 m
.61054 .55449 L
s
.648 .244 1 r
.65528 .55192 m
.655 .54348 L
s
.655 .54348 m
.65532 .5516 L
s
.965 .174 1 r
.51615 .53614 m
.5161 .54506 L
s
.51612 .54502 m
.51615 .53614 L
s
.51615 .53614 m
.51613 .55415 L
s
.868 .194 1 r
.46262 .54673 m
.46246 .55557 L
s
.46252 .55538 m
.46262 .54673 L
s
.46246 .55557 m
.46264 .54669 L
s
.46264 .54669 m
.46252 .55538 L
s
.38 .554 1 r
.66376 .53566 m
.66404 .54281 L
s
.66407 .5424 m
.66376 .53566 L
s
.66404 .54281 m
.66378 .53563 L
s
.66378 .53563 m
.66407 .5424 L
s
.522 .277 1 r
.55995 .49599 m
.56052 .53493 L
s
.711 .229 1 r
.60556 .53157 m
.60572 .54012 L
s
.60575 .54009 m
.60556 .53157 L
s
.60556 .53157 m
.60596 .54836 L
s
.669 .239 1 r
.38199 .54407 m
.38164 .55248 L
s
.3817 .5523 m
.38199 .54407 L
s
.559 .267 1 r
.32852 .55458 m
.32846 .55469 L
s
.669 .239 1 r
.38164 .55248 m
.382 .54404 L
s
.382 .54404 m
.3817 .5523 L
s
.766 .217 1 r
.50732 .54483 m
.50727 .55349 L
s
.50733 .5532 m
.50732 .54483 L
s
.811 .206 1 r
.45788 .53239 m
.45768 .54116 L
s
.4577 .54113 m
.45788 .53239 L
s
.45788 .53239 m
.45757 .54961 L
s
.881 .191 1 r
.70764 .49579 m
.71009 .5386 L
s
.701 .232 1 r
.43461 .49579 m
.43375 .53684 L
s
.766 .217 1 r
.50727 .55349 m
.50734 .54479 L
s
.50734 .54479 m
.50733 .5532 L
s
1 .165 .994 r
.6822 .55801 m
.68217 .5588 L
s
.485 .287 1 r
.57438 .54141 m
.57448 .54936 L
s
.57453 .54922 m
.57438 .54141 L
s
.57448 .54936 m
.5744 .54138 L
s
.5744 .54138 m
.57453 .54922 L
s
.68 .237 1 r
.40432 .5434 m
.40402 .55188 L
s
.40409 .55156 m
.40432 .5434 L
s
.733 .224 1 r
.58231 .49558 m
.58321 .53805 L
s
.679 .237 1 r
.30925 .49558 m
.30689 .53699 L
s
.68 .237 1 r
.40402 .55188 m
.40434 .54336 L
s
.40434 .54336 m
.40409 .55156 L
s
.916 .184 1 r
.3596 .54614 m
.35917 .55512 L
s
.35925 .5548 m
.3596 .54614 L
s
.608 .254 1 r
.42667 .54245 m
.42643 .55075 L
s
.42649 .55047 m
.42667 .54245 L
s
.531 .274 1 r
.44903 .54122 m
.44884 .54934 L
s
.4489 .54902 m
.44903 .54122 L
s
.477 .289 1 r
.54327 .55112 m
.54322 .55154 L
s
.916 .184 1 r
.35917 .55512 m
.35962 .5461 L
s
.35962 .5461 m
.35925 .5548 L
s
.608 .254 1 r
.42643 .55075 m
.42669 .54241 L
s
.42669 .54241 m
.42649 .55047 L
s
.531 .274 1 r
.44884 .54934 m
.44904 .54118 L
s
.44904 .54118 m
.4489 .54902 L
s
.788 .212 1 r
.3325 .53258 m
.332 .54124 L
s
.33201 .54121 m
.3325 .53258 L
s
.3325 .53258 m
.33158 .54977 L
s
.669 .239 1 r
.55203 .5432 m
.55209 .55165 L
s
.55214 .55136 m
.55203 .5432 L
s
.648 .244 1 r
.35485 .53138 m
.35442 .53973 L
s
.35444 .5397 m
.35485 .53138 L
s
.35485 .53138 m
.35407 .54797 L
s
.503 .282 1 r
.37319 .5531 m
.37313 .55321 L
s
.589 .259 1 r
.73005 .49538 m
.73257 .53503 L
s
.649 .244 1 r
.45695 .49538 m
.45636 .53573 L
s
.669 .239 1 r
.55209 .55165 m
.55205 .54317 L
s
.55205 .54317 m
.55214 .55136 L
s
.468 .292 1 r
.54729 .52855 m
.54731 .53651 L
s
.54733 .53647 m
.54729 .52855 L
s
.54729 .52855 m
.54741 .54418 L
s
.521 .277 1 r
.60469 .49518 m
.60577 .53448 L
s
.531 .274 1 r
.33157 .49518 m
.32962 .53378 L
s
.56 .267 1 r
.66866 .55236 m
.66863 .55279 L
s
.881 .191 1 r
.57922 .55742 m
.57917 .55786 L
s
.477 .289 1 r
.4219 .52832 m
.42165 .53631 L
s
.42166 .53627 m
.4219 .52832 L
s
.4219 .52832 m
.42147 .54398 L
s
.416 .307 1 r
.56965 .52774 m
.56972 .53555 L
s
.56974 .53552 m
.56965 .52774 L
s
.56965 .52774 m
.56987 .54308 L
s
.67 .239 1 r
.4802 .53276 m
.48007 .54105 L
s
.48009 .54101 m
.4802 .53276 L
s
.4802 .53276 m
.48001 .54957 L
s
.516 .279 1 r
.75246 .49497 m
.75507 .53217 L
s
.744 .222 1 r
.4793 .49497 m
.47896 .53639 L
s
.834 .201 1 r
.67744 .5448 m
.67782 .5536 L
s
.67786 .55331 m
.67744 .5448 L
s
.628 .249 1 r
.49855 .5547 m
.49849 .55484 L
s
.834 .201 1 r
.67782 .5536 m
.67747 .54476 L
s
.67747 .54476 m
.67786 .55331 L
s
.744 .222 1 r
.35078 .55559 m
.35071 .55591 L
s
.588 .259 1 r
.67271 .53017 m
.67302 .53838 L
s
.67305 .53834 m
.67271 .53017 L
s
.67271 .53017 m
.67341 .54648 L
s
.813 .206 1 r
.62708 .49477 m
.62848 .53584 L
s
.477 .289 1 r
.35389 .49477 m
.3522 .53302 L
s
.68 .237 1 r
.64633 .5545 m
.64629 .55482 L
s
.578 .262 1 r
.3955 .55341 m
.39543 .55359 L
s
.55 .269 1 r
.69509 .52929 m
.69546 .53742 L
s
.69548 .53739 m
.69509 .52929 L
s
.69509 .52929 m
.69589 .54538 L
s
.578 .262 1 r
.32356 .54241 m
.32309 .55054 L
s
.32314 .55058 m
.32356 .54241 L
s
1 .151 .921 r
.5345 .56101 m
.53445 .56116 L
s
.869 .194 1 r
.50166 .49457 m
.50159 .53704 L
s
.578 .262 1 r
.32309 .55054 m
.32358 .54238 L
s
.32358 .54238 m
.32314 .55058 L
s
.881 .191 1 r
.60161 .55738 m
.60156 .55771 L
s
.93 .181 1 r
.52495 .53147 m
.52492 .54053 L
s
.52494 .54049 m
.52495 .53147 L
s
.52495 .53147 m
.52497 .54913 L
s
.531 1 .913 r
.64555 .51738 m
.64573 .52313 L
s
.64575 .5231 m
.64555 .51738 L
s
.64555 .51738 m
.64595 .52847 L
s
.858 .196 1 r
.64948 .49437 m
.65117 .53614 L
s
.754 .219 1 r
.37622 .49437 m
.37462 .53649 L
s
.598 .257 1 r
.34591 .54174 m
.34548 .54998 L
s
.34554 .54983 m
.34591 .54174 L
s
.34548 .54998 m
.34592 .54171 L
s
.34592 .54171 m
.34554 .54983 L
s
.649 .244 1 r
.44424 .52885 m
.44402 .53731 L
s
.44403 .53727 m
.44424 .52885 L
s
.44424 .52885 m
.44388 .54534 L
s
.579 .262 1 r
.59206 .52827 m
.59219 .53655 L
s
.59221 .53651 m
.59206 .52827 L
s
.59206 .52827 m
.59239 .54444 L
s
.486 .287 1 r
.48496 .54939 m
.4849 .54996 L
s
.55 .269 1 r
.44021 .55193 m
.44015 .55221 L
s
.744 .221 1 r
.52404 .49416 m
.52422 .53559 L
s
.405 .662 1 r
.47136 .54269 m
.47131 .54296 L
s
.767 .216 1 r
.3771 .53279 m
.37672 .54129 L
s
.37674 .54125 m
.3771 .53279 L
s
.3771 .53279 m
.3764 .55003 L
s
.37 .507 1 r
.62797 .53415 m
.62818 .54142 L
s
.62821 .54097 m
.62797 .53415 L
s
.62818 .54142 m
.62799 .53412 L
s
.62799 .53412 m
.62821 .54097 L
s
.618 .252 1 r
.36826 .54107 m
.36788 .54941 L
s
.36795 .54909 m
.36826 .54107 L
s
.58 .261 1 r
.39946 .53177 m
.39915 .53977 L
s
.39917 .53974 m
.39946 .53177 L
s
.39946 .53177 m
.39889 .54823 L
s
.618 .252 1 r
.36788 .54941 m
.36827 .54103 L
s
.36827 .54103 m
.36795 .54909 L
s
.701 .231 1 r
.67189 .49396 m
.6738 .53468 L
s
.608 .254 1 r
.39856 .49396 m
.39729 .53433 L
s
.55 .269 1 r
.39061 .54039 m
.39029 .54852 L
s
.39035 .54834 m
.39061 .54039 L
s
.559 .267 1 r
.54642 .49376 m
.54685 .53307 L
s
.55 .269 1 r
.39029 .54852 m
.39063 .54036 L
s
.39063 .54036 m
.39035 .54834 L
s
.777 .214 1 r
.52092 .55606 m
.52086 .55617 L
s
.367 .322 1 r
.30987 .53745 m
.3094 .54508 L
s
.30946 .54491 m
.30987 .53745 L
s
.628 .249 1 r
.31872 .52935 m
.31821 .53767 L
s
.31822 .53763 m
.31872 .52935 L
s
.31872 .52935 m
.31777 .54584 L
s
.648 .244 1 r
.46659 .52877 m
.46643 .53719 L
s
.46644 .53715 m
.46659 .52877 L
s
.46659 .52877 m
.46634 .54529 L
s
.367 .322 1 r
.3094 .54508 m
.30989 .53742 L
s
.30989 .53742 m
.30946 .54491 L
s
.711 .229 1 r
.6416 .5419 m
.64187 .55046 L
s
.64192 .55014 m
.6416 .5419 L
s
.531 .274 1 r
.41299 .53944 m
.41272 .54757 L
s
.41278 .54725 m
.41299 .53944 L
s
.711 .229 1 r
.64187 .55046 m
.64162 .54187 L
s
.64162 .54187 m
.64192 .55014 L
s
.531 .274 1 r
.41272 .54757 m
.413 .5394 L
s
.413 .5394 m
.41278 .54725 L
s
.733 .224 1 r
.41781 .55442 m
.41774 .55471 L
s
.599 .257 1 r
.49371 .54266 m
.49363 .55076 L
s
.49368 .55104 m
.49371 .54266 L
s
.811 .206 1 r
.71759 .53021 m
.71804 .53898 L
s
.71807 .53895 m
.71759 .53021 L
s
.71759 .53021 m
.71856 .54744 L
s
.649 .244 1 r
.69431 .49355 m
.69642 .53323 L
s
.733 .224 1 r
.42092 .49355 m
.41987 .53534 L
s
.599 .257 1 r
.49363 .55076 m
.49373 .54262 L
s
.49373 .54262 m
.49368 .55104 L
s
.618 .252 1 r
.53848 .54047 m
.53851 .54882 L
s
.53856 .5485 m
.53848 .54047 L
s
.53851 .54882 m
.5385 .54044 L
s
.5385 .54044 m
.53856 .5485 L
s
1 .158 .957 r
.59685 .54493 m
.59704 .5542 L
s
.59709 .55373 m
.59685 .54493 L
s
.588 .259 1 r
.34106 .52878 m
.34061 .53699 L
s
.34063 .53696 m
.34106 .52878 L
s
.34106 .52878 m
.34023 .54509 L
s
1 .158 .957 r
.59704 .5542 m
.59687 .54489 L
s
.59687 .54489 m
.59709 .55373 L
s
.4 .312 1 r
.56881 .49335 m
.56947 .53197 L
s
.342 .378 1 r
.29539 .49335 m
.29321 .52916 L
s
.618 .252 1 r
.31465 .55313 m
.31459 .55324 L
s
.55 .269 1 r
.56087 .53952 m
.56095 .54769 L
s
.561 .5474 m
.56087 .53952 L
s
.56095 .54769 m
.56089 .53949 L
s
.56089 .53949 m
.561 .5474 L
s
.881 .191 1 r
.61924 .54397 m
.61947 .55286 L
s
.61952 .55263 m
.61924 .54397 L
s
.777 .214 1 r
.5657 .55457 m
.56565 .5549 L
s
.881 .191 1 r
.61947 .55286 m
.61926 .54394 L
s
.61926 .54394 m
.61952 .55263 L
s
1 .166 .997 r
.69999 .54719 m
.70043 .55616 L
s
.7005 .55643 m
.69999 .54719 L
s
.608 .254 1 r
.48896 .52851 m
.48885 .53679 L
s
.48887 .53676 m
.48896 .52851 L
s
.48896 .52851 m
.48882 .54489 L
s
1 .166 .997 r
.70043 .55616 m
.70002 .54716 L
s
.70002 .54716 m
.7005 .55643 L
s
.383 .317 1 r
.71674 .49315 m
.71898 .53071 L
s
.58 .261 1 r
.44328 .49315 m
.44257 .53177 L
s
.691 .234 1 r
.63689 .52803 m
.63713 .53659 L
s
.63715 .53656 m
.63689 .52803 L
s
.63689 .52803 m
.63744 .5447 L
s
.811 .206 1 r
.6145 .5293 m
.6147 .53811 L
s
.61472 .53807 m
.6145 .5293 L
s
.6145 .5293 m
.61496 .5465 L
s
.598 .257 1 r
.33701 .55239 m
.33695 .55253 L
s
1 .133 .827 r
.59121 .49294 m
.59232 .53968 L
s
.628 .249 1 r
.31773 .49294 m
.3155 .53368 L
s
.503 .282 1 r
.52972 .54966 m
.52967 .54997 L
s
.578 .262 1 r
.63288 .55164 m
.63283 .55182 L
s
.38 .554 1 r
.66407 .5424 m
.66404 .54281 L
s
.513 .279 1 r
.40818 .5263 m
.40789 .5344 L
s
.4079 .53437 m
.40818 .5263 L
s
.40818 .5263 m
.40767 .54215 L
s
.669 .239 1 r
.51135 .52822 m
.51129 .53667 L
s
.51131 .53664 m
.51135 .52822 L
s
.51135 .52822 m
.51131 .54485 L
s
.45 .297 1 r
.73918 .49274 m
.74167 .53031 L
s
.335 .34 1 r
.46566 .49274 m
.46522 .5289 L
s
.68 .237 1 r
.65931 .52767 m
.65961 .5362 L
s
.65963 .53616 m
.65931 .52767 L
s
.65931 .52767 m
.65997 .5443 L
s
.744 .222 1 r
.68645 .54139 m
.68685 .55002 L
s
.68689 .5497 m
.68645 .54139 L
s
.68685 .55002 m
.68648 .54136 L
s
.68648 .54136 m
.68689 .5497 L
s
.733 .224 1 r
.36338 .52914 m
.36297 .53771 L
s
.36298 .53768 m
.36338 .52914 L
s
.36338 .52914 m
.36263 .5461 L
s
.54 .272 1 r
.53374 .52733 m
.53374 .53544 L
s
.53375 .5354 m
.53374 .52733 L
s
.53374 .52733 m
.5338 .5434 L
s
.892 .189 1 r
.61363 .49254 m
.61494 .5361 L
s
.66 .241 1 r
.34008 .49254 m
.33807 .53399 L
s
.522 .277 1 r
.68172 .52689 m
.68205 .53496 L
s
.68207 .53492 m
.68172 .52689 L
s
.68172 .52689 m
.68245 .54285 L
s
.45 .297 1 r
.5025 .53702 m
.50244 .54493 L
s
.5025 .54462 m
.5025 .53702 L
s
.50244 .54493 m
.50252 .53699 L
s
.50252 .53699 m
.5025 .54462 L
s
.569 .264 1 r
.38575 .52837 m
.38541 .53648 L
s
.38542 .53644 m
.38575 .52837 L
s
.38575 .52837 m
.38513 .54465 L
s
.486 .287 1 r
.65049 .53654 m
.65078 .54463 L
s
.65081 .54407 m
.65049 .53654 L
s
.468 .292 1 r
.55614 .52659 m
.55618 .53448 L
s
.5562 .53445 m
.55614 .52659 L
s
.55614 .52659 m
.5563 .5423 L
s
.36 .324 1 r
.76163 .49233 m
.76426 .5285 L
s
.81 .206 1 r
.48805 .49233 m
.48779 .53519 L
s
.486 .287 1 r
.65078 .54463 m
.65051 .53651 L
s
.65051 .53651 m
.65081 .54407 L
s
.896 .188 1 r
.7089 .541 m
.70937 .55009 L
s
.70939 .54931 m
.7089 .541 L
s
.70937 .55009 m
.70893 .54096 L
s
.70893 .54096 m
.70939 .54931 L
s
.648 .244 1 r
.65532 .5516 m
.65528 .55192 L
s
.468 .292 1 r
.30494 .52556 m
.30442 .53352 L
s
.30444 .53349 m
.30494 .52556 L
s
.30494 .52556 m
.30399 .54121 L
s
.811 .206 1 r
.4353 .54128 m
.43507 .55009 L
s
.43514 .54966 m
.4353 .54128 L
s
.651 .244 1 r
.63605 .49213 m
.6375 .53147 L
s
.522 .277 1 r
.36244 .49213 m
.36081 .53112 L
s
.811 .206 1 r
.43507 .55009 m
.43532 .54124 L
s
.43532 .54124 m
.43514 .54966 L
s
.881 .191 1 r
.61054 .55449 m
.6105 .55492 L
s
.8 .209 1 r
.58332 .54108 m
.58345 .54986 L
s
.58351 .54946 m
.58332 .54108 L
s
.868 .194 1 r
.46252 .55538 m
.46246 .55557 L
s
.524 .276 1 r
.51044 .49193 m
.51048 .53021 L
s
.669 .239 1 r
.3817 .5523 m
.38164 .55248 L
s
.8 .209 1 r
.58345 .54986 m
.58334 .54104 L
s
.58334 .54104 m
.58351 .54946 L
s
.485 .287 1 r
.57453 .54922 m
.57448 .54936 L
s
.965 .174 1 r
.5161 .54506 m
.51607 .55399 L
s
.51613 .55415 m
.5161 .54506 L
s
.711 .229 1 r
.60572 .54012 m
.60591 .54869 L
s
.60596 .54836 m
.60572 .54012 L
s
.965 .174 1 r
.51607 .55399 m
.51612 .54502 L
s
.51612 .54502 m
.51613 .55415 L
s
.766 .217 1 r
.50733 .5532 m
.50727 .55349 L
s
.711 .229 1 r
.60591 .54869 m
.60575 .54009 L
s
.60575 .54009 m
.60596 .54836 L
s
.56 .267 1 r
.65849 .49172 m
.66017 .53071 L
s
.416 .307 1 r
.38481 .49172 m
.38348 .52931 L
s
.531 .274 1 r
.4489 .54902 m
.44884 .54934 L
s
.68 .237 1 r
.40409 .55156 m
.40402 .55188 L
s
.811 .206 1 r
.45768 .54116 m
.45751 .54994 L
s
.45757 .54961 m
.45768 .54116 L
s
.608 .254 1 r
.42649 .55047 m
.42643 .55075 L
s
.531 1 .913 r
.64573 .52313 m
.64593 .52888 L
s
.64595 .52847 m
.64573 .52313 L
s
.811 .206 1 r
.45751 .54994 m
.4577 .54113 L
s
.4577 .54113 m
.45757 .54961 L
s
.531 1 .913 r
.64593 .52888 m
.64575 .5231 L
s
.64575 .5231 m
.64595 .52847 L
s
.744 .221 1 r
.43052 .5276 m
.43026 .53624 L
s
.43028 .5362 m
.43052 .5276 L
s
.43052 .5276 m
.43009 .54456 L
s
.68 .237 1 r
.57858 .52698 m
.57868 .53548 L
s
.5787 .53545 m
.57858 .52698 L
s
.57858 .52698 m
.57885 .54366 L
s
.618 .252 1 r
.45292 .52637 m
.45273 .53472 L
s
.45275 .53469 m
.45292 .52637 L
s
.45292 .52637 m
.45261 .54276 L
s
.904 .186 1 r
.53285 .49152 m
.53316 .53509 L
s
.589 .259 1 r
.72664 .52647 m
.72708 .53472 L
s
.72711 .53469 m
.72664 .52647 L
s
.72664 .52647 m
.72759 .54276 L
s
.669 .239 1 r
.55214 .55136 m
.55209 .55165 L
s
.468 .292 1 r
.54731 .53651 m
.54736 .54446 L
s
.54741 .54418 m
.54731 .53651 L
s
.54736 .54446 m
.54733 .53647 L
s
.54733 .53647 m
.54741 .54418 L
s
.648 .244 1 r
.35442 .53973 m
.35401 .54808 L
s
.35407 .54797 m
.35442 .53973 L
s
.468 .292 1 r
.34966 .52477 m
.34924 .53273 L
s
.34926 .5327 m
.34966 .52477 L
s
.34966 .52477 m
.3489 .54041 L
s
.542 .271 1 r
.6234 .52479 m
.62361 .53301 L
s
.62363 .53297 m
.6234 .52479 L
s
.6234 .52479 m
.62387 .54076 L
s
.648 .244 1 r
.35401 .54808 m
.35444 .5397 L
s
.35444 .5397 m
.35407 .54797 L
s
.916 .184 1 r
.35925 .5548 m
.35917 .55512 L
s
.416 .307 1 r
.56972 .53555 m
.56982 .54336 L
s
.56987 .54308 m
.56972 .53555 L
s
.649 .244 1 r
.68093 .49131 m
.68294 .53172 L
s
.7 .232 1 r
.40719 .49131 m
.40598 .53278 L
s
.416 .307 1 r
.56982 .54336 m
.56974 .53552 L
s
.56974 .53552 m
.56987 .54308 L
s
.788 .212 1 r
.332 .54124 m
.33151 .54992 L
s
.33158 .54977 m
.332 .54124 L
s
.477 .289 1 r
.42165 .53631 m
.4214 .5443 L
s
.42147 .54398 m
.42165 .53631 L
s
.788 .212 1 r
.33151 .54992 m
.33201 .54121 L
s
.33201 .54121 m
.33158 .54977 L
s
.46 .294 1 r
.52015 .52326 m
.52011 .53129 L
s
.52013 .53126 m
.52015 .52326 L
s
.52015 .52326 m
.52015 .53876 L
s
.477 .289 1 r
.4214 .5443 m
.42166 .53627 L
s
.42166 .53627 m
.42147 .54398 L
s
.618 .252 1 r
.47532 .52597 m
.47518 .53432 L
s
.4752 .53429 m
.47532 .52597 L
s
.47532 .52597 m
.47511 .54236 L
s
.93 .181 1 r
.55527 .49111 m
.55586 .53398 L
s
.67 .239 1 r
.48007 .54105 m
.47996 .54933 L
s
.48001 .54957 m
.48007 .54105 L
s
.47996 .54933 m
.48009 .54101 L
s
.48009 .54101 m
.48001 .54957 L
s
.551 .269 1 r
.70339 .49091 m
.70559 .53026 L
s
.638 .247 1 r
.42958 .49091 m
.42866 .53167 L
s
.588 .259 1 r
.67302 .53838 m
.67336 .54659 L
s
.67341 .54648 m
.67302 .53838 L
s
.892 .189 1 r
.70431 .52903 m
.70473 .53792 L
s
.70475 .53788 m
.70431 .52903 L
s
.70431 .52903 m
.70523 .54667 L
s
.834 .201 1 r
.67786 .55331 m
.67782 .5536 L
s
.679 .237 1 r
.32719 .52721 m
.32669 .53564 L
s
.32671 .53561 m
.32719 .52721 L
s
.32719 .52721 m
.32627 .54397 L
s
.588 .259 1 r
.67336 .54659 m
.67305 .53834 L
s
.67305 .53834 m
.67341 .54648 L
s
.37 .507 1 r
.62821 .54097 m
.62818 .54142 L
s
.55 .269 1 r
.69546 .53742 m
.69585 .54556 L
s
.69589 .54538 m
.69546 .53742 L
s
.788 .211 1 r
.5777 .4907 m
.57854 .53253 L
s
.608 .254 1 r
.30386 .4907 m
.30151 .53076 L
s
.55 .269 1 r
.69585 .54556 m
.69548 .53739 L
s
.69548 .53739 m
.69589 .54538 L
s
.578 .262 1 r
.32314 .55058 m
.32309 .55054 L
s
.503 .282 1 r
.39442 .52414 m
.3941 .53221 L
s
.39412 .53218 m
.39442 .52414 L
s
.39442 .52414 m
.39386 .53996 L
s
.648 .244 1 r
.72586 .4905 m
.72838 .53091 L
s
.744 .222 1 r
.45198 .4905 m
.45131 .53197 L
s
.441 .3 1 r
.54257 .52356 m
.54259 .53145 L
s
.5426 .53142 m
.54257 .52356 L
s
.54257 .52356 m
.54267 .53907 L
s
.598 .257 1 r
.34554 .54983 m
.34548 .54998 L
s
.669 .239 1 r
.60014 .49029 m
.60124 .53212 L
s
.608 .254 1 r
.32623 .49029 m
.32408 .53142 L
s
.892 .189 1 r
.60105 .52843 m
.60122 .53732 L
s
.60124 .53729 m
.60105 .52843 L
s
.60105 .52843 m
.60146 .54608 L
s
.579 .262 1 r
.59219 .53655 m
.59234 .54483 L
s
.59239 .54444 m
.59219 .53655 L
s
.59234 .54483 m
.59221 .53651 L
s
.59221 .53651 m
.59239 .54444 L
s
.58 .261 1 r
.39915 .53977 m
.39885 .54778 L
s
.39889 .54823 m
.39915 .53977 L
s
.618 .252 1 r
.36795 .54909 m
.36788 .54941 L
s
.649 .244 1 r
.44402 .53731 m
.44381 .54576 L
s
.44388 .54534 m
.44402 .53731 L
s
.58 .261 1 r
.39885 .54778 m
.39917 .53974 L
s
.39917 .53974 m
.39889 .54823 L
s
.649 .244 1 r
.44381 .54576 m
.44403 .53727 L
s
.44403 .53727 m
.44388 .54534 L
s
.93 .181 1 r
.52492 .54053 m
.52491 .5496 L
s
.52497 .54913 m
.52492 .54053 L
s
.799 .209 1 r
.49773 .52686 m
.49764 .53561 L
s
.49766 .53557 m
.49773 .52686 L
s
.49773 .52686 m
.49762 .54407 L
s
.503 .282 1 r
.69077 .52374 m
.69112 .53181 L
s
.69114 .53178 m
.69077 .52374 L
s
.69077 .52374 m
.69153 .53957 L
s
.367 .322 1 r
.30946 .54491 m
.3094 .54508 L
s
.93 .181 1 r
.52491 .5496 m
.52494 .54049 L
s
.52494 .54049 m
.52497 .54913 L
s
.4 .312 1 r
.74834 .49009 m
.75088 .52699 L
s
.608 .254 1 r
.47439 .49009 m
.474 .53016 L
s
.767 .216 1 r
.37672 .54129 m
.37635 .54979 L
s
.3764 .55003 m
.37672 .54129 L
s
.37635 .54979 m
.37674 .54125 L
s
.37674 .54125 m
.3764 .55003 L
s
.55 .269 1 r
.39035 .54834 m
.39029 .54852 L
s
.4 .312 1 r
.58744 .52231 m
.58756 .53009 L
s
.58757 .53006 m
.58744 .52231 L
s
.58744 .52231 m
.58773 .53757 L
s
.648 .244 1 r
.62259 .48989 m
.62394 .53102 L
s
.598 .257 1 r
.34862 .48989 m
.34676 .53031 L
s
.531 .274 1 r
.41278 .54725 m
.41272 .54757 L
s
.352 .327 1 r
.60987 .52118 m
.61004 .52886 L
s
.61006 .52882 m
.60987 .52118 L
s
.60987 .52118 m
.61026 .53612 L
s
.521 .277 1 r
.41681 .52429 m
.41653 .53237 L
s
.41655 .53234 m
.41681 .52429 L
s
.41681 .52429 m
.41634 .54027 L
s
.337 .353 1 r
.33588 .52132 m
.33545 .52886 L
s
.33547 .52882 m
.33588 .52132 L
s
.33588 .52132 m
.3351 .53612 L
s
.777 .214 1 r
.66838 .5257 m
.66871 .53445 L
s
.66873 .53441 m
.66838 .5257 L
s
.66838 .5257 m
.6691 .54277 L
s
.37194 .52704 m
.37154 .53569 L
s
.37155 .53565 m
.37194 .52704 L
s
.37194 .52704 m
.37121 .54423 L
s
.628 .249 1 r
.31821 .53767 m
.31771 .54599 L
s
.31777 .54584 m
.31821 .53767 L
s
.459 .294 1 r
.77083 .48968 m
.77369 .52764 L
s
.711 .229 1 r
.49682 .48968 m
.49667 .53187 L
s
.64192 .55014 m
.64187 .55046 L
s
.628 .249 1 r
.31771 .54599 m
.31822 .53763 L
s
.31822 .53763 m
.31777 .54584 L
s
.599 .257 1 r
.49368 .55104 m
.49363 .55076 L
s
.648 .244 1 r
.46643 .53719 m
.46628 .54561 L
s
.46634 .54529 m
.46643 .53719 L
s
.46628 .54561 m
.46644 .53715 L
s
.46644 .53715 m
.46634 .54529 L
s
.618 .252 1 r
.53856 .5485 m
.53851 .54882 L
s
.55 .269 1 r
.561 .5474 m
.56095 .54769 L
s
.779 .213 1 r
.64506 .48948 m
.64666 .53026 L
s
.754 .219 1 r
.37101 .48948 m
.36935 .53167 L
s
.588 .259 1 r
.34061 .53699 m
.34017 .5452 L
s
.34023 .54509 m
.34061 .53699 L
s
.34017 .5452 m
.34063 .53696 L
s
.34063 .53696 m
.34023 .54509 L
s
.71328 .52396 m
.7137 .53225 L
s
.71372 .53222 m
.71328 .52396 L
s
.71328 .52396 m
.71417 .54022 L
s
.477 .289 1 r
.46166 .52273 m
.46149 .53073 L
s
.4615 .5307 m
.46166 .52273 L
s
.46166 .52273 m
.46139 .53842 L
s
.811 .206 1 r
.71804 .53898 m
.71852 .54777 L
s
.71856 .54744 m
.71804 .53898 L
s
.71852 .54777 m
.71807 .53895 L
s
.71807 .53895 m
.71856 .54744 L
s
.411 .309 1 r
.51925 .48927 m
.51938 .52513 L
s
.68 .237 1 r
.43922 .52427 m
.43899 .53281 L
s
.439 .53278 m
.43922 .52427 L
s
.43922 .52427 m
.43884 .54092 L
s
.608 .254 1 r
.48885 .53679 m
.48876 .54507 L
s
.48882 .54489 m
.48885 .53679 L
s
.48876 .54507 m
.48887 .53676 L
s
.48887 .53676 m
.48882 .54489 L
s
1 .158 .957 r
.59709 .55373 m
.59704 .5542 L
s
.881 .191 1 r
.61952 .55263 m
.61947 .55286 L
s
.344 .388 1 r
.66753 .48907 m
.66911 .52352 L
s
.733 .224 1 r
.39342 .48907 m
.39204 .53091 L
s
.691 .234 1 r
.63713 .53659 m
.6374 .54516 L
s
.63744 .5447 m
.63713 .53659 L
s
.69 .234 1 r
.56504 .52538 m
.56511 .53385 L
s
.56513 .53381 m
.56504 .52538 L
s
.56504 .52538 m
.56526 .54218 L
s
.531 1 .913 r
.64595 .52847 m
.64593 .52888 L
s
.691 .234 1 r
.6374 .54516 m
.63715 .53656 L
s
.63715 .53656 m
.63744 .5447 L
s
.811 .206 1 r
.6147 .53811 m
.61492 .54693 L
s
.61496 .5465 m
.6147 .53811 L
s
.513 .279 1 r
.40789 .5344 m
.40761 .54251 L
s
.40767 .54215 m
.40789 .5344 L
s
1 .166 .997 r
.7005 .55643 m
.70043 .55616 L
s
.383 .317 1 r
.5417 .48887 m
.54206 .52648 L
s
.811 .206 1 r
.61492 .54693 m
.61472 .53807 L
s
.61472 .53807 m
.61496 .5465 L
s
.513 .279 1 r
.40761 .54251 m
.4079 .53437 L
s
.4079 .53437 m
.40767 .54215 L
s
.86 .196 1 r
.73581 .52394 m
.73632 .53297 L
s
.73634 .53294 m
.73581 .52394 L
s
.73581 .52394 m
.73687 .54123 L
s
.476 .29 1 r
.35823 .52213 m
.35782 .53013 L
s
.35784 .5301 m
.35823 .52213 L
s
.35823 .52213 m
.3575 .53782 L
s
.45 .297 1 r
.5025 .54462 m
.50244 .54493 L
s
.434 .302 1 r
.65483 .52096 m
.6551 .52889 L
s
.65512 .52886 m
.65483 .52096 L
s
.65483 .52096 m
.65542 .53637 L
s
.486 .287 1 r
.65081 .54407 m
.65078 .54463 L
s
.744 .222 1 r
.68689 .5497 m
.68685 .55002 L
s
.669 .239 1 r
.51129 .53667 m
.51125 .54514 L
s
.51131 .54485 m
.51129 .53667 L
s
.54 .272 1 r
.53374 .53544 m
.53375 .54354 L
s
.5338 .5434 m
.53374 .53544 L
s
.467 .292 1 r
.69001 .48866 m
.69201 .52699 L
s
.822 .204 1 r
.41584 .48866 m
.4147 .53157 L
s
.55 .269 1 r
.48408 .52299 m
.48396 .53117 L
s
.48398 .53114 m
.48408 .52299 L
s
.48408 .52299 m
.48392 .53908 L
s
.669 .239 1 r
.51125 .54514 m
.51131 .53664 L
s
.51131 .53664 m
.51131 .54485 L
s
.54 .272 1 r
.53375 .54354 m
.53375 .5354 L
s
.53375 .5354 m
.5338 .5434 L
s
.68 .237 1 r
.65961 .5362 m
.65993 .54473 L
s
.65997 .5443 m
.65961 .5362 L
s
.522 .277 1 r
.68205 .53496 m
.68241 .54303 L
s
.68245 .54285 m
.68205 .53496 L
s
.68 .237 1 r
.65993 .54473 m
.65963 .53616 L
s
.65963 .53616 m
.65997 .5443 L
s
.522 .277 1 r
.68241 .54303 m
.68207 .53492 L
s
.68207 .53492 m
.68245 .54285 L
s
.468 .292 1 r
.55618 .53448 m
.55625 .54238 L
s
.5563 .5423 m
.55618 .53448 L
s
.55625 .54238 m
.5562 .53445 L
s
.5562 .53445 m
.5563 .5423 L
s
.733 .224 1 r
.36297 .53771 m
.36256 .54628 L
s
.36263 .5461 m
.36297 .53771 L
s
.569 .264 1 r
.38541 .53648 m
.38508 .54459 L
s
.38513 .54465 m
.38541 .53648 L
s
.432 .302 1 r
.56415 .48846 m
.56479 .52961 L
s
.494 .284 1 r
.28995 .48846 m
.28743 .52854 L
s
.733 .224 1 r
.36256 .54628 m
.36298 .53768 L
s
.36298 .53768 m
.36263 .5461 L
s
.569 .264 1 r
.38508 .54459 m
.38542 .53644 L
s
.38542 .53644 m
.38513 .54465 L
s
.468 .292 1 r
.30442 .53352 m
.30391 .54149 L
s
.30399 .54121 m
.30442 .53352 L
s
.30391 .54149 m
.30444 .53349 L
s
.30444 .53349 m
.30399 .54121 L
s
.628 .249 1 r
.31328 .5255 m
.31276 .53373 L
s
.31278 .53369 m
.31328 .5255 L
s
.31328 .5255 m
.3123 .54213 L
s
.896 .188 1 r
.70939 .54931 m
.70937 .55009 L
s
.777 .214 1 r
.71251 .48825 m
.71494 .52975 L
s
.345 .39 1 r
.43827 .48825 m
.43755 .52412 L
s
.811 .206 1 r
.43514 .54966 m
.43507 .55009 L
s
.375 .32 1 r
.58662 .48805 m
.58745 .52497 L
s
.669 .239 1 r
.31235 .48805 m
.30999 .5299 L
s
.8 .209 1 r
.58351 .54946 m
.58345 .54986 L
s
.7 .232 1 r
.73501 .48784 m
.73771 .52935 L
s
.559 .267 1 r
.4607 .48784 m
.46017 .52723 L
s
.711 .229 1 r
.60596 .54836 m
.60591 .54869 L
s
.65 .244 1 r
.50652 .52349 m
.50645 .53189 L
s
.50647 .53186 m
.50652 .52349 L
s
.50652 .52349 m
.50646 .54008 L
s
.467 .292 1 r
.67737 .52167 m
.67769 .52961 L
s
.67771 .52958 m
.67737 .52167 L
s
.67737 .52167 m
.67807 .53737 L
s
.468 .292 1 r
.54741 .54418 m
.54736 .54446 L
s
.416 .307 1 r
.56987 .54308 m
.56982 .54336 L
s
.609 .254 1 r
.6091 .48764 m
.61025 .52738 L
s
.744 .221 1 r
.33476 .48764 m
.33267 .5295 L
s
.881 .191 1 r
.63247 .52452 m
.63272 .53349 L
s
.63274 .53346 m
.63247 .52452 L
s
.63247 .52452 m
.63303 .54204 L
s
.468 .292 1 r
.34924 .53273 m
.34884 .54069 L
s
.3489 .54041 m
.34924 .53273 L
s
.34884 .54069 m
.34926 .5327 L
s
.34926 .5327 m
.3489 .54041 L
s
.477 .289 1 r
.42147 .54398 m
.4214 .5443 L
s
.811 .206 1 r
.45757 .54961 m
.45751 .54994 L
s
.589 .259 1 r
.72708 .53472 m
.72755 .54298 L
s
.72759 .54276 m
.72708 .53472 L
s
.618 .252 1 r
.45273 .53472 m
.45255 .54308 L
s
.45261 .54276 m
.45273 .53472 L
s
.965 .174 1 r
.51613 .55415 m
.51607 .55399 L
s
.589 .259 1 r
.72755 .54298 m
.72711 .53469 L
s
.72711 .53469 m
.72759 .54276 L
s
.618 .252 1 r
.45255 .54308 m
.45275 .53469 L
s
.45275 .53469 m
.45261 .54276 L
s
.658 .242 1 r
.38057 .52357 m
.3802 .53197 L
s
.38022 .53194 m
.38057 .52357 L
s
.38057 .52357 m
.37991 .54023 L
s
.68 .237 1 r
.57868 .53548 m
.5788 .54398 L
s
.57885 .54366 m
.57868 .53548 L
s
.542 .271 1 r
.62361 .53301 m
.62383 .54122 L
s
.62387 .54076 m
.62361 .53301 L
s
.531 .274 1 r
.75753 .48743 m
.7603 .52612 L
s
.822 .204 1 r
.48315 .48743 m
.48284 .53036 L
s
.648 .244 1 r
.35407 .54797 m
.35401 .54808 L
s
.68 .237 1 r
.5788 .54398 m
.5787 .53545 L
s
.5787 .53545 m
.57885 .54366 L
s
.542 .271 1 r
.62383 .54122 m
.62363 .53297 L
s
.62363 .53297 m
.62387 .54076 L
s
.744 .221 1 r
.43026 .53624 m
.43002 .54489 L
s
.43009 .54456 m
.43026 .53624 L
s
.46 .294 1 r
.52011 .53129 m
.5201 .53933 L
s
.52015 .53876 m
.52011 .53129 L
s
.744 .221 1 r
.43002 .54489 m
.43028 .5362 L
s
.43028 .5362 m
.43009 .54456 L
s
.46 .294 1 r
.5201 .53933 m
.52013 .53126 L
s
.52013 .53126 m
.52015 .53876 L
s
.392 .315 1 r
.29952 .52076 m
.299 .52845 L
s
.29901 .52842 m
.29952 .52076 L
s
.29952 .52076 m
.29855 .53608 L
s
.357 .448 1 r
.63159 .48723 m
.6328 .52134 L
s
.723 .226 1 r
.35718 .48723 m
.35542 .52804 L
s
.788 .212 1 r
.33158 .54977 m
.33151 .54992 L
s
.618 .252 1 r
.47518 .53432 m
.47505 .54268 L
s
.47511 .54236 m
.47518 .53432 L
s
.47505 .54268 m
.4752 .53429 L
s
.4752 .53429 m
.47511 .54236 L
s
.67 .239 1 r
.48001 .54957 m
.47996 .54933 L
s
.494 .284 1 r
.78006 .48702 m
.78307 .52572 L
s
.55 .269 1 r
.50562 .48702 m
.50558 .52748 L
s
.494 .284 1 r
.44794 .52077 m
.44774 .52881 L
s
.44775 .52878 m
.44794 .52077 L
s
.44794 .52077 m
.44761 .53658 L
s
.494 .285 1 r
.42546 .52211 m
.42521 .53005 L
s
.42523 .53002 m
.42546 .52211 L
s
.42546 .52211 m
.42503 .53803 L
s
.588 .259 1 r
.67341 .54648 m
.67336 .54659 L
s
.55 .269 1 r
.69589 .54538 m
.69585 .54556 L
s
.408 .31 1 r
.61887 .51926 m
.61905 .52709 L
s
.61907 .52706 m
.61887 .51926 L
s
.61887 .51926 m
.6193 .53457 L
s
.711 .229 1 r
.65409 .48682 m
.65585 .52904 L
s
.485 .287 1 r
.37961 .48682 m
.37817 .52587 L
s
.679 .237 1 r
.32669 .53564 m
.32621 .54408 L
s
.32627 .54397 m
.32669 .53564 L
s
.659 .242 1 r
.57394 .52194 m
.57403 .53041 L
s
.57405 .53038 m
.57394 .52194 L
s
.57394 .52194 m
.57419 .53853 L
s
.679 .237 1 r
.32621 .54408 m
.32671 .53561 L
s
.32671 .53561 m
.32627 .54397 L
s
.477 .289 1 r
.4704 .52012 m
.47025 .52813 L
s
.47027 .5281 m
.4704 .52012 L
s
.4704 .52012 m
.47018 .53582 L
s
.441 .3 1 r
.54259 .53145 m
.54262 .53935 L
s
.54267 .53907 m
.54259 .53145 L
s
.868 .194 1 r
.529 .52458 m
.52898 .53345 L
s
.529 .53342 m
.529 .52458 L
s
.529 .52458 m
.52904 .54214 L
s
.441 .3 1 r
.54262 .53935 m
.5426 .53142 L
s
.5426 .53142 m
.54267 .53907 L
s
.811 .206 1 r
.55147 .52342 m
.55151 .53221 L
s
.55153 .53218 m
.55147 .52342 L
s
.55147 .52342 m
.55163 .54069 L
s
.503 .282 1 r
.3941 .53221 m
.39379 .54028 L
s
.39386 .53996 m
.3941 .53221 L
s
.892 .189 1 r
.52809 .48661 m
.52833 .53026 L
s
.503 .282 1 r
.39379 .54028 m
.39412 .53218 L
s
.39412 .53218 m
.39386 .53996 L
s
.892 .189 1 r
.70473 .53792 m
.70518 .54682 L
s
.70523 .54667 m
.70473 .53792 L
s
.70518 .54682 m
.70475 .53788 L
s
.70475 .53788 m
.70523 .54667 L
s
.579 .262 1 r
.59239 .54444 m
.59234 .54483 L
s
.977 .171 1 r
.6766 .48641 m
.67877 .53147 L
s
.335 .341 1 r
.40206 .48641 m
.40093 .52335 L
s
.58 .261 1 r
.39889 .54823 m
.39885 .54778 L
s
.649 .244 1 r
.44388 .54534 m
.44381 .54576 L
s
1 .164 .985 r
.40296 .52491 m
.40262 .5341 L
s
.40263 .53406 m
.40296 .52491 L
s
.40296 .52491 m
.40236 .543 L
s
.503 .282 1 r
.69112 .53181 m
.6915 .53989 L
s
.69153 .53957 m
.69112 .53181 L
s
.788 .212 1 r
.55057 .4862 m
.55108 .52879 L
s
.503 .282 1 r
.6915 .53989 m
.69114 .53178 L
s
.69114 .53178 m
.69153 .53957 L
s
.4 .312 1 r
.58756 .53009 m
.58769 .53788 L
s
.58773 .53757 m
.58756 .53009 L
s
.352 .327 1 r
.61004 .52886 m
.61022 .53654 L
s
.61026 .53612 m
.61004 .52886 L
s
.337 .353 1 r
.33545 .52886 m
.33504 .5364 L
s
.3351 .53612 m
.33545 .52886 L
s
.711 .229 1 r
.59644 .52199 m
.59659 .53057 L
s
.59661 .53054 m
.59644 .52199 L
s
.59644 .52199 m
.59681 .53884 L
s
.4 .312 1 r
.58769 .53788 m
.58757 .53006 L
s
.58757 .53006 m
.58773 .53757 L
s
.337 .353 1 r
.33504 .5364 m
.33547 .52882 L
s
.33547 .52882 m
.3351 .53612 L
s
.352 .327 1 r
.61022 .53654 m
.61006 .52882 L
s
.61006 .52882 m
.61026 .53612 L
s
.648 .244 1 r
.69912 .486 m
.70134 .52647 L
s
.589 .259 1 r
.42451 .486 m
.42356 .52576 L
s
.391 .315 1 r
.38928 .51853 m
.38896 .52629 L
s
.38897 .52626 m
.38928 .51853 L
s
.38928 .51853 m
.38871 .53377 L
s
.892 .189 1 r
.60122 .53732 m
.6014 .54623 L
s
.60146 .54608 m
.60122 .53732 L
s
.93 .181 1 r
.52497 .54913 m
.52491 .5496 L
s
.521 .277 1 r
.41653 .53237 m
.41628 .54045 L
s
.41634 .54027 m
.41653 .53237 L
s
.966 .173 1 r
.72253 .52299 m
.72301 .53218 L
s
.72304 .53214 m
.72253 .52299 L
s
.72253 .52299 m
.72355 .5408 L
s
.767 .216 1 r
.3764 .55003 m
.37635 .54979 L
s
.892 .189 1 r
.6014 .54623 m
.60124 .53729 L
s
.60124 .53729 m
.60146 .54608 L
s
.977 .171 1 r
.70004 .5243 m
.70047 .53342 L
s
.70049 .53338 m
.70004 .5243 L
s
.70004 .5243 m
.70096 .54225 L
s
.521 .277 1 r
.41628 .54045 m
.41655 .53234 L
s
.41655 .53234 m
.41634 .54027 L
s
.799 .209 1 r
.49764 .53561 m
.49756 .54436 L
s
.49762 .54407 m
.49764 .53561 L
s
.49756 .54436 m
.49766 .53557 L
s
.49766 .53557 m
.49762 .54407 L
s
.629 .249 1 r
.49286 .52073 m
.49276 .52913 L
s
.49278 .5291 m
.49286 .52073 L
s
.49286 .52073 m
.49274 .53719 L
s
1 1 1 r
.44702 .48515 m
.44698 .4867 L
s
.44698 .48669 m
.44702 .48515 L
s
.44702 .48515 m
.44698 .48697 L
s
.789 .211 1 r
.57306 .48579 m
.57385 .52803 L
s
.743 .222 1 r
.29843 .48579 m
.29585 .52839 L
s
.628 .249 1 r
.31777 .54584 m
.31771 .54599 L
s
.648 .244 1 r
.46634 .54529 m
.46628 .54561 L
s
.608 .254 1 r
.36677 .5206 m
.36637 .52893 L
s
.36639 .5289 m
.36677 .5206 L
s
.36677 .5206 m
.36605 .53698 L
s
.339 .362 1 r
.72165 .48559 m
.72378 .52008 L
s
1 1 1 r
.44698 .48559 m
.44698 .48697 L
s
.777 .214 1 r
.37154 .53569 m
.37115 .54434 L
s
.37121 .54423 m
.37154 .53569 L
s
.66871 .53445 m
.66906 .54321 L
s
.6691 .54277 m
.66871 .53445 L
s
.477 .289 1 r
.46149 .53073 m
.46134 .53874 L
s
.46139 .53842 m
.46149 .53073 L
s
.777 .214 1 r
.37115 .54434 m
.37155 .53565 L
s
.37155 .53565 m
.37121 .54423 L
s
.66906 .54321 m
.66873 .53441 L
s
.66873 .53441 m
.6691 .54277 L
s
.588 .259 1 r
.34023 .54509 m
.34017 .5452 L
s
.477 .289 1 r
.46134 .53874 m
.4615 .5307 L
s
.4615 .5307 m
.46139 .53842 L
s
.588 .259 1 r
.7137 .53225 m
.71414 .54054 L
s
.71417 .54022 m
.7137 .53225 L
s
.658 .242 1 r
.59557 .48538 m
.5966 .52657 L
s
.578 .262 1 r
.32086 .48538 m
.31866 .52622 L
s
.588 .259 1 r
.71414 .54054 m
.71372 .53222 L
s
.71372 .53222 m
.71417 .54022 L
s
.669 .239 1 r
.34425 .52236 m
.3438 .53073 L
s
.34381 .5307 m
.34425 .52236 L
s
.34425 .52236 m
.34341 .53914 L
s
.892 .189 1 r
.32177 .52363 m
.32123 .53254 L
s
.32125 .5325 m
.32177 .52363 L
s
.32177 .52363 m
.32077 .5413 L
s
.822 .204 1 r
.74508 .52301 m
.7456 .53177 L
s
.74563 .53174 m
.74508 .52301 L
s
.74508 .52301 m
.74619 .5404 L
s
.608 .254 1 r
.48882 .54489 m
.48876 .54507 L
s
.811 .206 1 r
.71856 .54744 m
.71852 .54777 L
s
.777 .214 1 r
.64147 .52129 m
.64173 .53005 L
s
.64176 .53002 m
.64147 .52129 L
s
.64147 .52129 m
.64206 .53839 L
s
1 .158 .958 r
.74419 .48518 m
.74716 .52884 L
s
.928 .181 1 r
.46946 .48518 m
.46896 .52919 L
s
.68 .237 1 r
.43899 .53281 m
.43877 .54135 L
s
.43884 .54092 m
.43899 .53281 L
s
.513 .279 1 r
.40767 .54215 m
.40761 .54251 L
s
.691 .234 1 r
.63744 .5447 m
.6374 .54516 L
s
.68 .237 1 r
.43877 .54135 m
.439 .53278 L
s
.439 .53278 m
.43884 .54092 L
s
1 1 1 r
.44698 .4867 m
.44695 .48824 L
s
.44698 .48697 m
.44698 .4867 L
s
.44695 .48824 m
.44698 .48669 L
s
.44698 .48669 m
.44698 .48697 L
s
1 .154 .934 r
.61808 .48497 m
.61951 .53041 L
s
.46 .294 1 r
.34331 .48497 m
.34146 .52405 L
s
.69 .234 1 r
.56511 .53385 m
.5652 .54233 L
s
.56526 .54218 m
.56511 .53385 L
s
.476 .29 1 r
.35782 .53013 m
.35743 .53814 L
s
.3575 .53782 m
.35782 .53013 L
s
1 1 1 r
.44698 .48697 m
.44695 .48824 L
s
.434 .302 1 r
.6551 .52889 m
.65539 .53683 L
s
.65542 .53637 m
.6551 .52889 L
s
.69 .234 1 r
.5652 .54233 m
.56513 .53381 L
s
.56513 .53381 m
.56526 .54218 L
s
.476 .29 1 r
.35743 .53814 m
.35784 .5301 L
s
.35784 .5301 m
.3575 .53782 L
s
.434 .302 1 r
.65539 .53683 m
.65512 .52886 L
s
.65512 .52886 m
.65542 .53637 L
s
.638 .247 1 r
.53785 .5202 m
.53785 .52861 L
s
.53787 .52858 m
.53785 .5202 L
s
.53785 .5202 m
.53793 .53674 L
s
.522 .277 1 r
.56034 .51897 m
.5604 .52709 L
s
.56042 .52705 m
.56034 .51897 L
s
.56034 .51897 m
.56052 .53493 L
s
.811 .206 1 r
.61496 .5465 m
.61492 .54693 L
s
.54 .272 1 r
.5338 .5434 m
.53375 .54354 L
s
.723 .226 1 r
.6865 .51972 m
.68687 .52841 L
s
.6869 .52837 m
.6865 .51972 L
s
.6865 .51972 m
.6873 .53654 L
s
.522 .277 1 r
.68245 .54285 m
.68241 .54303 L
s
.811 .206 1 r
.76675 .48477 m
.76986 .52667 L
s
.367 .322 1 r
.49194 .48477 m
.49177 .52208 L
s
.468 .292 1 r
.5563 .5423 m
.55625 .54238 L
s
.669 .239 1 r
.51131 .54485 m
.51125 .54514 L
s
.55 .269 1 r
.48396 .53117 m
.48386 .53936 L
s
.48392 .53908 m
.48396 .53117 L
s
.68 .237 1 r
.65997 .5443 m
.65993 .54473 L
s
.55 .269 1 r
.48386 .53936 m
.48398 .53114 L
s
.48398 .53114 m
.48392 .53908 L
s
.468 .292 1 r
.30399 .54121 m
.30391 .54149 L
s
.638 .247 1 r
.41169 .52 m
.41139 .52841 L
s
.41141 .52838 m
.41169 .52 L
s
.41169 .52 m
.41118 .53654 L
s
.516 .279 1 r
.75402 .51642 m
.75454 .52468 L
s
.75456 .52465 m
.75402 .51642 L
s
.75402 .51642 m
.75507 .53217 L
s
.648 .244 1 r
.64061 .48456 m
.64215 .52505 L
s
.618 .252 1 r
.36577 .48456 m
.36413 .5247 L
s
.569 .264 1 r
.38513 .54465 m
.38508 .54459 L
s
.86 .196 1 r
.73632 .53297 m
.73686 .54202 L
s
.73687 .54123 m
.73632 .53297 L
s
.733 .224 1 r
.36263 .5461 m
.36256 .54628 L
s
.86 .196 1 r
.73686 .54202 m
.73634 .53294 L
s
.73634 .53294 m
.73687 .54123 L
s
.755 .219 1 r
.51535 .52242 m
.5153 .53097 L
s
.51532 .53094 m
.51535 .52242 L
s
.51535 .52242 m
.51532 .5396 L
s
.628 .249 1 r
.31276 .53373 m
.31226 .54196 L
s
.3123 .54213 m
.31276 .53373 L
s
.766 .216 1 r
.66403 .52187 m
.66435 .53049 L
s
.66437 .53046 m
.66403 .52187 L
s
.66403 .52187 m
.66474 .53905 L
s
.384 .317 1 r
.78931 .48436 m
.79225 .52062 L
s
.638 .247 1 r
.51444 .48436 m
.51451 .52591 L
s
.628 .249 1 r
.31226 .54196 m
.31278 .53369 L
s
.31278 .53369 m
.3123 .54213 L
s
.531 .274 1 r
.33048 .51781 m
.33 .526 L
s
.33002 .52597 m
.33048 .51781 L
s
.33048 .51781 m
.32962 .53378 L
s
.701 .232 1 r
.66315 .48415 m
.66498 .52535 L
s
.441 .3 1 r
.38824 .48415 m
.38692 .52253 L
s
.589 .259 1 r
.73158 .51874 m
.73205 .52705 L
s
.73207 .52701 m
.73158 .51874 L
s
.73158 .51874 m
.73257 .53503 L
s
.701 .232 1 r
.43416 .52002 m
.43391 .52857 L
s
.43393 .52853 m
.43416 .52002 L
s
.43416 .52002 m
.43375 .53684 L
s
.467 .292 1 r
.67769 .52961 m
.67803 .53755 L
s
.67807 .53737 m
.67769 .52961 L
s
.45 .297 1 r
.53695 .48395 m
.53727 .52162 L
s
.467 .292 1 r
.67803 .53755 m
.67771 .52958 L
s
.67771 .52958 m
.67807 .53737 L
s
.521 .277 1 r
.60539 .51847 m
.60554 .52656 L
s
.60556 .52653 m
.60539 .51847 L
s
.60539 .51847 m
.60577 .53448 L
s
.649 .244 1 r
.45666 .51916 m
.45647 .52761 L
s
.45649 .52757 m
.45666 .51916 L
s
.45666 .51916 m
.45636 .53573 L
s
.468 .292 1 r
.3489 .54041 m
.34884 .54069 L
s
.477 .289 1 r
.35295 .5173 m
.35253 .52532 L
s
.35255 .52529 m
.35295 .5173 L
s
.35295 .5173 m
.3522 .53302 L
s
.65 .244 1 r
.50645 .53189 m
.5064 .5403 L
s
.50646 .54008 m
.50645 .53189 L
s
.46 .294 1 r
.52015 .53876 m
.5201 .53933 L
s
.836 .201 1 r
.68569 .48374 m
.68782 .5253 L
s
.69 .234 1 r
.41072 .48374 m
.40956 .5253 L
s
.65 .244 1 r
.5064 .5403 m
.50647 .53186 L
s
.50647 .53186 m
.50646 .54008 L
s
.542 .271 1 r
.62387 .54076 m
.62383 .54122 L
s
.679 .237 1 r
.30791 .5202 m
.30736 .52865 L
s
.30737 .52861 m
.30791 .5202 L
s
.30791 .5202 m
.30689 .53699 L
s
.589 .259 1 r
.72759 .54276 m
.72755 .54298 L
s
.618 .252 1 r
.45261 .54276 m
.45255 .54308 L
s
.392 .315 1 r
.299 .52845 m
.2985 .53615 L
s
.29855 .53608 m
.299 .52845 L
s
.2985 .53615 m
.29901 .52842 L
s
.29901 .52842 m
.29855 .53608 L
s
.881 .191 1 r
.70914 .52102 m
.70958 .52997 L
s
.7096 .52993 m
.70914 .52102 L
s
.70914 .52102 m
.71009 .5386 L
s
.904 .186 1 r
.55947 .48353 m
.56011 .52722 L
s
.441 .3 1 r
.28447 .48353 m
.282 .52192 L
s
.68 .237 1 r
.57885 .54366 m
.5788 .54398 L
s
.658 .242 1 r
.3802 .53197 m
.37985 .54038 L
s
.37991 .54023 m
.3802 .53197 L
s
.37985 .54038 m
.38022 .53194 L
s
.38022 .53194 m
.37991 .54023 L
s
.744 .221 1 r
.43009 .54456 m
.43002 .54489 L
s
.55 .269 1 r
.70825 .48333 m
.71054 .52313 L
s
.857 .196 1 r
.43322 .48333 m
.43228 .52666 L
s
.881 .191 1 r
.63272 .53349 m
.63299 .54247 L
s
.63303 .54204 m
.63272 .53349 L
s
.733 .224 1 r
.5829 .52097 m
.58301 .52949 L
s
.58304 .52945 m
.5829 .52097 L
s
.5829 .52097 m
.58321 .53805 L
s
.881 .191 1 r
.63299 .54247 m
.63274 .53346 L
s
.63274 .53346 m
.63303 .54204 L
s
.618 .252 1 r
.47511 .54236 m
.47505 .54268 L
s
.813 .206 1 r
.62796 .51865 m
.62819 .52756 L
s
.62821 .52753 m
.62796 .51865 L
s
.62796 .51865 m
.62848 .53584 L
s
.744 .222 1 r
.47916 .51938 m
.47902 .52805 L
s
.47904 .52801 m
.47916 .51938 L
s
.47916 .51938 m
.47896 .53639 L
s
.494 .285 1 r
.42521 .53005 m
.42498 .538 L
s
.42503 .53803 m
.42521 .53005 L
s
.494 .284 1 r
.44774 .52881 m
.44755 .53686 L
s
.44761 .53658 m
.44774 .52881 L
s
.765 .217 1 r
.582 .48312 m
.5829 .5254 L
s
.766 .217 1 r
.30693 .48312 m
.30451 .52505 L
s
.342 .378 1 r
.29416 .51444 m
.29364 .52195 L
s
.29365 .52192 m
.29416 .51444 L
s
.29416 .51444 m
.29321 .52916 L
s
.494 .285 1 r
.42498 .538 m
.42523 .53002 L
s
.42523 .53002 m
.42503 .53803 L
s
.494 .284 1 r
.44755 .53686 m
.44775 .52878 L
s
.44775 .52878 m
.44761 .53658 L
s
.408 .31 1 r
.61905 .52709 m
.61926 .53493 L
s
.6193 .53457 m
.61905 .52709 L
s
.61926 .53493 m
.61907 .52706 L
s
.61907 .52706 m
.6193 .53457 L
s
.441 .3 1 r
.54267 .53907 m
.54262 .53935 L
s
1 .123 .772 r
.73082 .48292 m
.73378 .52909 L
s
.494 .284 1 r
.45572 .48292 m
.45514 .52166 L
s
.503 .282 1 r
.39386 .53996 m
.39379 .54028 L
s
.477 .289 1 r
.47025 .52813 m
.47012 .53614 L
s
.47018 .53582 m
.47025 .52813 L
s
.47012 .53614 m
.47027 .5281 L
s
.47027 .5281 m
.47018 .53582 L
s
.679 .237 1 r
.32627 .54397 m
.32621 .54408 L
s
.87 .194 1 r
.60454 .48271 m
.60573 .52534 L
s
.857 .196 1 r
.32941 .48271 m
.32718 .52605 L
s
.659 .242 1 r
.57403 .53041 m
.57414 .53889 L
s
.57419 .53853 m
.57403 .53041 L
s
.57414 .53889 m
.57405 .53038 L
s
.57405 .53038 m
.57419 .53853 L
s
.337 .353 1 r
.3351 .53612 m
.33504 .5364 L
s
.352 .327 1 r
.61026 .53612 m
.61022 .53654 L
s
.858 .196 1 r
.65053 .51874 m
.65082 .52773 L
s
.65084 .52769 m
.65053 .51874 L
s
.65053 .51874 m
.65117 .53614 L
s
.559 .267 1 r
.54673 .51692 m
.54675 .52516 L
s
.54677 .52512 m
.54673 .51692 L
s
.54673 .51692 m
.54685 .53307 L
s
.4 .312 1 r
.58773 .53757 m
.58769 .53788 L
s
.559 .267 1 r
.7534 .48251 m
.75623 .52267 L
s
.811 .206 1 r
.47823 .48251 m
.47788 .52444 L
s
.869 .194 1 r
.50168 .51953 m
.50159 .52849 L
s
.50161 .52845 m
.50168 .51953 L
s
.50168 .51953 m
.50159 .53704 L
s
.503 .282 1 r
.69153 .53957 m
.6915 .53989 L
s
.868 .194 1 r
.52898 .53345 m
.52898 .54233 L
s
.52904 .54214 m
.52898 .53345 L
s
.811 .206 1 r
.55151 .53221 m
.55157 .54102 L
s
.55163 .54069 m
.55151 .53221 L
s
.335 .34 1 r
.46545 .51404 m
.4653 .52163 L
s
.46532 .5216 m
.46545 .51404 L
s
.46545 .51404 m
.46522 .5289 L
s
.868 .194 1 r
.52898 .54233 m
.529 .53342 L
s
.529 .53342 m
.52904 .54214 L
s
.811 .206 1 r
.55157 .54102 m
.55153 .53218 L
s
.55153 .53218 m
.55163 .54069 L
s
.701 .231 1 r
.67307 .51789 m
.6734 .52648 L
s
.67342 .52644 m
.67307 .51789 L
s
.67307 .51789 m
.6738 .53468 L
s
.608 .254 1 r
.39787 .51789 m
.39754 .5262 L
s
.39756 .52616 m
.39787 .51789 L
s
.39787 .51789 m
.39729 .53433 L
s
.892 .189 1 r
.70523 .54667 m
.70518 .54682 L
s
.744 .221 1 r
.5242 .51858 m
.52418 .52724 L
s
.5242 .52721 m
.5242 .51858 L
s
.5242 .51858 m
.52422 .53559 L
s
.383 .317 1 r
.71812 .51545 m
.71851 .52315 L
s
.71854 .52312 m
.71812 .51545 L
s
.71812 .51545 m
.71898 .53071 L
s
.649 .244 1 r
.6956 .51672 m
.69599 .52524 L
s
.69601 .5252 m
.6956 .51672 L
s
.6956 .51672 m
.69642 .53323 L
s
.418 .307 1 r
.6271 .4823 m
.62836 .51893 L
s
.754 .219 1 r
.35189 .4823 m
.34999 .52459 L
s
.37533 .51937 m
.37494 .528 L
s
.37495 .52797 m
.37533 .51937 L
s
.37533 .51937 m
.37462 .53649 L
s
.58 .261 1 r
.44293 .51562 m
.44271 .52399 L
s
.44273 .52396 m
.44293 .51562 L
s
.44293 .51562 m
.44257 .53177 L
s
.391 .315 1 r
.38896 .52629 m
.38865 .53405 L
s
.38871 .53377 m
.38896 .52629 L
s
.38865 .53405 m
.38897 .52626 L
s
.38897 .52626 m
.38871 .53377 L
s
.521 .277 1 r
.41634 .54027 m
.41628 .54045 L
s
.4 .312 1 r
.56926 .51652 m
.56933 .52419 L
s
.56935 .52416 m
.56926 .51652 L
s
.56926 .51652 m
.56947 .53197 L
s
.916 .184 1 r
.77599 .48209 m
.77938 .52615 L
s
.468 .292 1 r
.50076 .48209 m
.50068 .5205 L
s
.36 .324 1 r
.76322 .51349 m
.76372 .52122 L
s
.76374 .52119 m
.76322 .51349 L
s
.76322 .51349 m
.76426 .5285 L
s
.45 .297 1 r
.74069 .51477 m
.74116 .52275 L
s
.74118 .52272 m
.74069 .51477 L
s
.74069 .51477 m
.74167 .53031 L
s
.711 .229 1 r
.59659 .53057 m
.59676 .53916 L
s
.59681 .53884 m
.59659 .53057 L
s
.59676 .53916 m
.59661 .53054 L
s
.59661 .53054 m
.59681 .53884 L
s
.846 .199 1 r
.64966 .48189 m
.65138 .52418 L
s
.467 .292 1 r
.37439 .48189 m
.3729 .52064 L
s
1 .164 .985 r
.40262 .5341 m
.40229 .5433 L
s
.40236 .543 m
.40262 .5341 L
s
.477 .289 1 r
.46139 .53842 m
.46134 .53874 L
s
.799 .209 1 r
.49762 .54407 m
.49756 .54436 L
s
.629 .249 1 r
.49276 .52913 m
.49268 .53754 L
s
.49274 .53719 m
.49276 .52913 L
s
1 .164 .985 r
.40229 .5433 m
.40263 .53406 L
s
.40263 .53406 m
.40236 .543 L
s
.629 .249 1 r
.49268 .53754 m
.49278 .5291 L
s
.49278 .5291 m
.49274 .53719 L
s
.892 .189 1 r
.60146 .54608 m
.6014 .54623 L
s
.57 .264 1 r
.7986 .48168 m
.80184 .52044 L
s
.846 .199 1 r
.52329 .48168 m
.52348 .52362 L
s
.608 .254 1 r
.36637 .52893 m
.36598 .53727 L
s
.36605 .53698 m
.36637 .52893 L
s
.733 .224 1 r
.42036 .51832 m
.42007 .52692 L
s
.42009 .52688 m
.42036 .51832 L
s
.42036 .51832 m
.41987 .53534 L
s
.608 .254 1 r
.36598 .53727 m
.36639 .5289 L
s
.36639 .5289 m
.36605 .53698 L
s
.588 .259 1 r
.71417 .54022 m
.71414 .54054 L
s
.977 .171 1 r
.70047 .53342 m
.70092 .54255 L
s
.70096 .54225 m
.70047 .53342 L
s
.966 .173 1 r
.72301 .53218 m
.72353 .54137 L
s
.72355 .5408 m
.72301 .53218 L
s
.777 .214 1 r
.6691 .54277 m
.66906 .54321 L
s
.977 .171 1 r
.70092 .54255 m
.70049 .53338 L
s
.70049 .53338 m
.70096 .54225 L
s
.966 .173 1 r
.72353 .54137 m
.72304 .53214 L
s
.72304 .53214 m
.72355 .5408 L
s
.868 .194 1 r
.67223 .48148 m
.67428 .52483 L
s
.441 .3 1 r
.3969 .48148 m
.39567 .51988 L
s
.777 .214 1 r
.37121 .54423 m
.37115 .54434 L
s
.669 .239 1 r
.3438 .53073 m
.34336 .53911 L
s
.34341 .53914 m
.3438 .53073 L
s
.434 .302 1 r
.65542 .53637 m
.65539 .53683 L
s
.823 .204 1 r
.54584 .48127 m
.5463 .52321 L
s
.669 .239 1 r
.34336 .53911 m
.34381 .5307 L
s
.34381 .5307 m
.34341 .53914 L
s
.628 .249 1 r
.31646 .51713 m
.31594 .52547 L
s
.31596 .52544 m
.31646 .51713 L
s
.31646 .51713 m
.3155 .53368 L
s
.68 .237 1 r
.43884 .54092 m
.43877 .54135 L
s
.476 .29 1 r
.3575 .53782 m
.35743 .53814 L
s
.822 .204 1 r
.7456 .53177 m
.74615 .54055 L
s
.74619 .5404 m
.7456 .53177 L
s
.74615 .54055 m
.74563 .53174 L
s
.74563 .53174 m
.74619 .5404 L
s
.618 .252 1 r
.69482 .48106 m
.69696 .52089 L
s
.701 .232 1 r
.41942 .48106 m
.41834 .52301 L
s
.524 .276 1 r
.51052 .5143 m
.51046 .5225 L
s
.51048 .52247 m
.51052 .5143 L
s
.51052 .5143 m
.51048 .53021 L
s
.892 .189 1 r
.32123 .53254 m
.3207 .54145 L
s
.32077 .5413 m
.32123 .53254 L
s
.777 .214 1 r
.64173 .53005 m
.64202 .53882 L
s
.64206 .53839 m
.64173 .53005 L
s
.651 .244 1 r
.63695 .51499 m
.6372 .52355 L
s
.63722 .52351 m
.63695 .51499 L
s
.63695 .51499 m
.6375 .53147 L
s
.892 .189 1 r
.3207 .54145 m
.32125 .5325 L
s
.32125 .5325 m
.32077 .5413 L
s
.777 .214 1 r
.64202 .53882 m
.64176 .53002 L
s
.64176 .53002 m
.64206 .53839 L
s
.522 .277 1 r
.36153 .51514 m
.36113 .52327 L
s
.36114 .52323 m
.36153 .51514 L
s
.36153 .51514 m
.36081 .53112 L
s
.416 .307 1 r
.38408 .5139 m
.38374 .52174 L
s
.38375 .52171 m
.38408 .5139 L
s
.38408 .5139 m
.38348 .52931 L
s
.522 .277 1 r
.5604 .52709 m
.56047 .53521 L
s
.56052 .53493 m
.5604 .52709 L
s
.56047 .53521 m
.56042 .52705 L
s
.56042 .52705 m
.56052 .53493 L
s
.69 .234 1 r
.56526 .54218 m
.5652 .54233 L
s
.55 .269 1 r
.48392 .53908 m
.48386 .53936 L
s
.658 .242 1 r
.5684 .48086 m
.56911 .5221 L
s
.416 .307 1 r
.29296 .48086 m
.29061 .51892 L
s
.638 .247 1 r
.53785 .52861 m
.53787 .53702 L
s
.53793 .53674 m
.53785 .52861 L
s
.53787 .53702 m
.53787 .52858 L
s
.53787 .52858 m
.53793 .53674 L
s
.99 .169 1 r
.71742 .48065 m
.72007 .52473 L
s
.765 .217 1 r
.44195 .48065 m
.44114 .52296 L
s
.56 .267 1 r
.65953 .51459 m
.65982 .52286 L
s
.65984 .52283 m
.65953 .51459 L
s
.65953 .51459 m
.66017 .53071 L
s
.723 .226 1 r
.68687 .52841 m
.68727 .53711 L
s
.6873 .53654 m
.68687 .52841 L
s
.638 .247 1 r
.41139 .52841 m
.41111 .53682 L
s
.41118 .53654 m
.41139 .52841 L
s
.516 .279 1 r
.75454 .52468 m
.75507 .53295 L
s
.75507 .53217 m
.75454 .52468 L
s
.638 .247 1 r
.41111 .53682 m
.41141 .52838 L
s
.41141 .52838 m
.41118 .53654 L
s
.723 .226 1 r
.68727 .53711 m
.6869 .52837 L
s
.6869 .52837 m
.6873 .53654 L
s
.516 .279 1 r
.75507 .53295 m
.75456 .52465 L
s
.75456 .52465 m
.75507 .53217 L
s
.66 .241 1 r
.33894 .51724 m
.33847 .52563 L
s
.33849 .5256 m
.33894 .51724 L
s
.33894 .51724 m
.33807 .53399 L
s
.991 .169 1 r
.59097 .48044 m
.59202 .52488 L
s
.669 .239 1 r
.31547 .48044 m
.31318 .52169 L
s
.86 .196 1 r
.73687 .54123 m
.73686 .54202 L
s
.628 .249 1 r
.3123 .54213 m
.31226 .54196 L
s
.755 .219 1 r
.5153 .53097 m
.51527 .53954 L
s
.51532 .5396 m
.5153 .53097 L
s
.531 .274 1 r
.33 .526 m
.32954 .5342 L
s
.32962 .53378 m
.33 .526 L
s
.755 .219 1 r
.51527 .53954 m
.51532 .53094 L
s
.51532 .53094 m
.51532 .5396 L
s
.766 .217 1 r
.74002 .48024 m
.74282 .5222 L
s
.559 .267 1 r
.46449 .48024 m
.46399 .51972 L
s
.531 .274 1 r
.32954 .5342 m
.33002 .52597 L
s
.33002 .52597 m
.32962 .53378 L
s
.766 .216 1 r
.66435 .53049 m
.66468 .53913 L
s
.66474 .53905 m
.66435 .53049 L
s
.467 .292 1 r
.67807 .53737 m
.67803 .53755 L
s
.766 .216 1 r
.66468 .53913 m
.66437 .53046 L
s
.66437 .53046 m
.66474 .53905 L
s
.589 .259 1 r
.73205 .52705 m
.73253 .53535 L
s
.73257 .53503 m
.73205 .52705 L
s
.628 .249 1 r
.61355 .48003 m
.61478 .52093 L
s
.722 .227 1 r
.33798 .48003 m
.33592 .52199 L
s
.589 .259 1 r
.73253 .53535 m
.73207 .52701 L
s
.73207 .52701 m
.73257 .53503 L
s
.892 .189 1 r
.61446 .51839 m
.61466 .52732 L
s
.61469 .52728 m
.61446 .51839 L
s
.61446 .51839 m
.61494 .5361 L
s
.521 .277 1 r
.60554 .52656 m
.60572 .53466 L
s
.60577 .53448 m
.60554 .52656 L
s
.477 .289 1 r
.35253 .52532 m
.35213 .53334 L
s
.3522 .53302 m
.35253 .52532 L
s
.81 .206 1 r
.48795 .51781 m
.48784 .52656 L
s
.48786 .52652 m
.48795 .51781 L
s
.48795 .51781 m
.48779 .53519 L
s
.521 .277 1 r
.60572 .53466 m
.60556 .52653 L
s
.60556 .52653 m
.60577 .53448 L
s
.477 .289 1 r
.35213 .53334 m
.35255 .52529 L
s
.35255 .52529 m
.3522 .53302 L
s
.701 .232 1 r
.43391 .52857 m
.43368 .53713 L
s
.43375 .53684 m
.43391 .52857 L
s
.392 .315 1 r
.29855 .53608 m
.2985 .53615 L
s
.701 .232 1 r
.43368 .53713 m
.43393 .52853 L
s
.43393 .52853 m
.43375 .53684 L
s
1 .138 .854 r
.76264 .47983 m
.76595 .52498 L
s
.955 .176 1 r
.48704 .47983 m
.48675 .52569 L
s
.65 .244 1 r
.50646 .54008 m
.5064 .5403 L
s
.649 .244 1 r
.45647 .52761 m
.4563 .53606 L
s
.45636 .53573 m
.45647 .52761 L
s
.4563 .53606 m
.45649 .52757 L
s
.45649 .52757 m
.45636 .53573 L
s
.68217 .51512 m
.68252 .52358 L
s
.68254 .52355 m
.68217 .51512 L
s
.68217 .51512 m
.68294 .53172 L
s
.551 .269 1 r
.70474 .51413 m
.70514 .52234 L
s
.70516 .5223 m
.70474 .51413 L
s
.70474 .51413 m
.70559 .53026 L
s
.56 .267 1 r
.63614 .47962 m
.63758 .51876 L
s
.569 .264 1 r
.3605 .47962 m
.35879 .51982 L
s
.679 .237 1 r
.30736 .52865 m
.30683 .5371 L
s
.30689 .53699 m
.30736 .52865 L
s
.4 .312 1 r
.74988 .51172 m
.75036 .51956 L
s
.75038 .51953 m
.74988 .51172 L
s
.74988 .51172 m
.75088 .52699 L
s
.679 .237 1 r
.30683 .5371 m
.30737 .52861 L
s
.30737 .52861 m
.30689 .53699 L
s
.342 .378 1 r
.29364 .52195 m
.29314 .52947 L
s
.29321 .52916 m
.29364 .52195 L
s
.29314 .52947 m
.29365 .52192 L
s
.29365 .52192 m
.29321 .52916 L
s
.408 .31 1 r
.6193 .53457 m
.61926 .53493 L
s
.433 .302 1 r
.78527 .47941 m
.78828 .51714 L
s
.811 .206 1 r
.5096 .47941 m
.50962 .52173 L
s
.658 .242 1 r
.37991 .54023 m
.37985 .54038 L
s
1 .133 .827 r
.59193 .52086 m
.59208 .53025 L
s
.59211 .53021 m
.59193 .52086 L
s
.59193 .52086 m
.59232 .53968 L
s
.344 .388 1 r
.66849 .50896 m
.66878 .51659 L
s
.6688 .51656 m
.66849 .50896 L
s
.66849 .50896 m
.66911 .52352 L
s
.7 .232 1 r
.40653 .51589 m
.40622 .52442 L
s
.40623 .52439 m
.40653 .51589 L
s
.40653 .51589 m
.40598 .53278 L
s
.494 .284 1 r
.44761 .53658 m
.44755 .53686 L
s
.494 .285 1 r
.42503 .53803 m
.42498 .538 L
s
.881 .191 1 r
.70958 .52997 m
.71005 .53893 L
s
.71009 .5386 m
.70958 .52997 L
s
.411 .309 1 r
.51938 .50993 m
.51934 .51791 L
s
.51936 .51788 m
.51938 .50993 L
s
.51938 .50993 m
.51938 .52513 L
s
.608 .254 1 r
.30253 .51435 m
.30197 .5227 L
s
.30199 .52266 m
.30253 .51435 L
s
.30253 .51435 m
.30151 .53076 L
s
.881 .191 1 r
.71005 .53893 m
.7096 .52993 L
s
.7096 .52993 m
.71009 .5386 L
s
.355 .437 1 r
.65874 .47921 m
.66024 .51376 L
s
.588 .259 1 r
.38304 .47921 m
.38157 .51976 L
s
.733 .224 1 r
.58301 .52949 m
.58315 .53802 L
s
.58321 .53805 m
.58301 .52949 L
s
.638 .247 1 r
.42909 .51507 m
.42883 .52346 L
s
.42885 .52342 m
.42909 .51507 L
s
.42909 .51507 m
.42866 .53167 L
s
.881 .191 1 r
.63303 .54204 m
.63299 .54247 L
s
.733 .224 1 r
.58315 .53802 m
.58304 .52945 L
s
.58304 .52945 m
.58321 .53805 L
s
.477 .289 1 r
.47018 .53582 m
.47012 .53614 L
s
.42 .723 1 r
.80791 .479 m
.81071 .51144 L
s
.45 .297 1 r
.53218 .479 m
.53244 .51708 L
s
.904 .186 1 r
.53309 .51735 m
.53309 .52631 L
s
.53311 .52627 m
.53309 .51735 L
s
.53309 .51735 m
.53316 .53509 L
s
.744 .222 1 r
.47902 .52805 m
.4789 .53671 L
s
.47896 .53639 m
.47902 .52805 L
s
.4789 .53671 m
.47904 .52801 L
s
.47904 .52801 m
.47896 .53639 L
s
.648 .244 1 r
.7274 .51432 m
.72786 .52277 L
s
.72789 .52274 m
.7274 .51432 L
s
.7274 .51432 m
.72838 .53091 L
s
.93 .181 1 r
.55568 .51624 m
.55573 .52534 L
s
.55575 .52531 m
.55568 .51624 L
s
.55568 .51624 m
.55586 .53398 L
s
.813 .206 1 r
.62819 .52756 m
.62845 .53648 L
s
.62848 .53584 m
.62819 .52756 L
s
.62845 .53648 m
.62821 .52753 L
s
.62821 .52753 m
.62848 .53584 L
s
.459 .294 1 r
.77256 .51201 m
.7731 .52 L
s
.77312 .51997 m
.77256 .51201 L
s
.77256 .51201 m
.77369 .52764 L
s
.541 .272 1 r
.68135 .47879 m
.68327 .51723 L
s
.588 .259 1 r
.40558 .47879 m
.40441 .51864 L
s
.788 .211 1 r
.57825 .51532 m
.57836 .5241 L
s
.57838 .52406 m
.57825 .51532 L
s
.57825 .51532 m
.57854 .53253 L
s
.335 .34 1 r
.4653 .52163 m
.46517 .52922 L
s
.46522 .5289 m
.4653 .52163 L
s
.659 .242 1 r
.57419 .53853 m
.57414 .53889 L
s
.335 .34 1 r
.46517 .52922 m
.46532 .5216 L
s
.46532 .5216 m
.46522 .5289 L
s
.744 .222 1 r
.45165 .51494 m
.45144 .52362 L
s
.45146 .52358 m
.45165 .51494 L
s
.45165 .51494 m
.45131 .53197 L
s
.383 .317 1 r
.71851 .52315 m
.71894 .53085 L
s
.71898 .53071 m
.71851 .52315 L
s
.391 .315 1 r
.38871 .53377 m
.38865 .53405 L
s
.608 .254 1 r
.47422 .51374 m
.47407 .52209 L
s
.47409 .52206 m
.47422 .51374 L
s
.47422 .51374 m
.474 .53016 L
s
.904 .186 1 r
.55476 .47858 m
.55534 .52233 L
s
.468 .292 1 r
.27896 .47858 m
.27645 .51667 L
s
.383 .317 1 r
.71894 .53085 m
.71854 .52312 L
s
.71854 .52312 m
.71898 .53071 L
s
.559 .267 1 r
.54675 .52516 m
.5468 .5334 L
s
.54685 .53307 m
.54675 .52516 L
s
.5468 .5334 m
.54677 .52512 L
s
.54677 .52512 m
.54685 .53307 L
s
.4 .312 1 r
.56933 .52419 m
.56942 .53187 L
s
.56947 .53197 m
.56933 .52419 L
s
.618 .252 1 r
.70397 .47838 m
.70624 .51859 L
s
.679 .237 1 r
.42814 .47838 m
.42717 .52036 L
s
.4 .312 1 r
.56942 .53187 m
.56935 .52416 L
s
.56935 .52416 m
.56947 .53197 L
s
.608 .254 1 r
.39754 .5262 m
.39723 .53451 L
s
.39729 .53433 m
.39754 .5262 L
s
.325 .51488 m
.3245 .52313 L
s
.32452 .5231 m
.325 .51488 L
s
.325 .51488 m
.32408 .53142 L
s
.36 .324 1 r
.76372 .52122 m
.76424 .52896 L
s
.76426 .5285 m
.76372 .52122 L
s
.608 .254 1 r
.39723 .53451 m
.39756 .52616 L
s
.39756 .52616 m
.39729 .53433 L
s
.811 .206 1 r
.55163 .54069 m
.55157 .54102 L
s
.36 .324 1 r
.76424 .52896 m
.76374 .52119 L
s
.76374 .52119 m
.76426 .5285 L
s
.598 .257 1 r
.34757 .51388 m
.34713 .52217 L
s
.34714 .52213 m
.34757 .51388 L
s
.34757 .51388 m
.34676 .53031 L
s
.858 .196 1 r
.65082 .52773 m
.65114 .53672 L
s
.65117 .53614 m
.65082 .52773 L
s
.701 .231 1 r
.6734 .52648 m
.67376 .53508 L
s
.6738 .53468 m
.6734 .52648 L
s
.649 .244 1 r
.69599 .52524 m
.6964 .53376 L
s
.69642 .53323 m
.69599 .52524 L
s
.58 .261 1 r
.44271 .52399 m
.4425 .53237 L
s
.44257 .53177 m
.44271 .52399 L
s
.868 .194 1 r
.52904 .54214 m
.52898 .54233 L
s
.45 .297 1 r
.74116 .52275 m
.74164 .53074 L
s
.74167 .53031 m
.74116 .52275 L
s
.765 .217 1 r
.57736 .47817 m
.5782 .52122 L
s
.559 .267 1 r
.30149 .47817 m
.29914 .51768 L
s
.858 .196 1 r
.65114 .53672 m
.65084 .52769 L
s
.65084 .52769 m
.65117 .53614 L
s
.701 .231 1 r
.67376 .53508 m
.67342 .52644 L
s
.67342 .52644 m
.6738 .53468 L
s
.649 .244 1 r
.6964 .53376 m
.69601 .5252 L
s
.69601 .5252 m
.69642 .53323 L
s
.58 .261 1 r
.4425 .53237 m
.44273 .52396 L
s
.44273 .52396 m
.44257 .53177 L
s
.45 .297 1 r
.74164 .53074 m
.74118 .52272 L
s
.74118 .52272 m
.74167 .53031 L
s
.869 .194 1 r
.50159 .52849 m
.50153 .53744 L
s
.50159 .53704 m
.50159 .52849 L
s
.744 .221 1 r
.52418 .52724 m
.52417 .53591 L
s
.52422 .53559 m
.52418 .52724 L
s
.669 .239 1 r
.60085 .5153 m
.60101 .52369 L
s
.60103 .52366 m
.60085 .5153 L
s
.60085 .5153 m
.60124 .53212 L
s
.869 .194 1 r
.50153 .53744 m
.50161 .52845 L
s
.50161 .52845 m
.50159 .53704 L
s
.744 .221 1 r
.52417 .53591 m
.5242 .52721 L
s
.5242 .52721 m
.52422 .53559 L
s
.754 .219 1 r
.37494 .528 m
.37456 .53664 L
s
.37462 .53649 m
.37494 .528 L
s
.37456 .53664 m
.37495 .52797 L
s
.37495 .52797 m
.37462 .53649 L
s
.648 .244 1 r
.62345 .51434 m
.62366 .52273 L
s
.62368 .52269 m
.62345 .51434 L
s
.62345 .51434 m
.62394 .53102 L
s
.383 .317 1 r
.54196 .5112 m
.54197 .51891 L
s
.54199 .51888 m
.54196 .5112 L
s
.54196 .5112 m
.54206 .52648 L
s
.56 .267 1 r
.72661 .47796 m
.72907 .51712 L
s
.7 .232 1 r
.45071 .47796 m
.45002 .5196 L
s
.711 .229 1 r
.59681 .53884 m
.59676 .53916 L
s
.345 .39 1 r
.43789 .50941 m
.43768 .5169 L
s
.4377 .51687 m
.43789 .50941 L
s
.43789 .50941 m
.43755 .52412 L
s
.779 .213 1 r
.64605 .51319 m
.64633 .52204 L
s
.64635 .52201 m
.64605 .51319 L
s
.64605 .51319 m
.64666 .53026 L
s
.629 .249 1 r
.49274 .53719 m
.49268 .53754 L
s
.68 .237 1 r
.59996 .47776 m
.60104 .51868 L
s
.658 .242 1 r
.32403 .47776 m
.32184 .51904 L
s
.467 .292 1 r
.69124 .51127 m
.6916 .51927 L
s
.69162 .51924 m
.69124 .51127 L
s
.69124 .51127 m
.69201 .52699 L
s
.608 .254 1 r
.36605 .53698 m
.36598 .53727 L
s
.357 .448 1 r
.63234 .50699 m
.63255 .51448 L
s
.63257 .51445 m
.63234 .50699 L
s
.63234 .50699 m
.6328 .52134 L
s
.629 .249 1 r
.74925 .47755 m
.752 .51707 L
s
.777 .214 1 r
.47328 .47755 m
.47286 .51954 L
s
1 .164 .985 r
.40236 .543 m
.40229 .5433 L
s
.375 .32 1 r
.58716 .50979 m
.58728 .51754 L
s
.58729 .51751 m
.58716 .50979 L
s
.58716 .50979 m
.58745 .52497 L
s
.711 .229 1 r
.49679 .51487 m
.49669 .52337 L
s
.49671 .52333 m
.49679 .51487 L
s
.49679 .51487 m
.49667 .53187 L
s
.733 .224 1 r
.42007 .52692 m
.41981 .53552 L
s
.41987 .53534 m
.42007 .52692 L
s
.433 .302 1 r
.62258 .47734 m
.62384 .5158 L
s
.822 .204 1 r
.34658 .47734 m
.34457 .5204 L
s
.733 .224 1 r
.41981 .53552 m
.42009 .52688 L
s
.42009 .52688 m
.41987 .53534 L
s
.966 .173 1 r
.72355 .5408 m
.72353 .54137 L
s
.754 .219 1 r
.37008 .51452 m
.36968 .52317 L
s
.36969 .52313 m
.37008 .51452 L
s
.37008 .51452 m
.36935 .53167 L
s
.977 .171 1 r
.70096 .54225 m
.70092 .54255 L
s
.669 .239 1 r
.34341 .53914 m
.34336 .53911 L
s
.628 .249 1 r
.31594 .52547 m
.31544 .53383 L
s
.3155 .53368 m
.31594 .52547 L
s
.416 .307 1 r
.38374 .52174 m
.38341 .52959 L
s
.38348 .52931 m
.38374 .52174 L
s
.881 .191 1 r
.77191 .47714 m
.77513 .51949 L
s
.953 .176 1 r
.49587 .47714 m
.49572 .5209 L
s
.628 .249 1 r
.31544 .53383 m
.31596 .52544 L
s
.31596 .52544 m
.3155 .53368 L
s
.522 .277 1 r
.56052 .53493 m
.56047 .53521 L
s
.416 .307 1 r
.38341 .52959 m
.38375 .52171 L
s
.38375 .52171 m
.38348 .52931 L
s
.524 .276 1 r
.51046 .5225 m
.51042 .53071 L
s
.51048 .53021 m
.51046 .5225 L
s
.51042 .53071 m
.51048 .52247 L
s
.51048 .52247 m
.51048 .53021 L
s
.522 .277 1 r
.36113 .52327 m
.36074 .5314 L
s
.36081 .53112 m
.36113 .52327 L
s
.733 .224 1 r
.39266 .51387 m
.39231 .52248 L
s
.39233 .52245 m
.39266 .51387 L
s
.39266 .51387 m
.39204 .53091 L
s
.522 .277 1 r
.36074 .5314 m
.36114 .52323 L
s
.36114 .52323 m
.36081 .53112 L
s
.777 .214 1 r
.64206 .53839 m
.64202 .53882 L
s
.516 .279 1 r
.75507 .53217 m
.75507 .53295 L
s
.799 .209 1 r
.64521 .47693 m
.64689 .51964 L
s
.494 .284 1 r
.36914 .47693 m
.36757 .5161 L
s
.822 .204 1 r
.74619 .5404 m
.74615 .54055 L
s
.651 .244 1 r
.6372 .52355 m
.63747 .53211 L
s
.6375 .53147 m
.6372 .52355 L
s
.638 .247 1 r
.53793 .53674 m
.53787 .53702 L
s
.651 .244 1 r
.63747 .53211 m
.63722 .52351 L
s
.63722 .52351 m
.6375 .53147 L
s
.892 .189 1 r
.32077 .5413 m
.3207 .54145 L
s
.494 .284 1 r
.28849 .51253 m
.28793 .52047 L
s
.28794 .52043 m
.28849 .51253 L
s
.28849 .51253 m
.28743 .52854 L
s
.486 .287 1 r
.79458 .47672 m
.79772 .51483 L
s
.811 .206 1 r
.51847 .47672 m
.5186 .51908 L
s
.638 .247 1 r
.41118 .53654 m
.41111 .53682 L
s
.723 .226 1 r
.6873 .53654 m
.68727 .53711 L
s
.56 .267 1 r
.65982 .52286 m
.66013 .53114 L
s
.66017 .53071 m
.65982 .52286 L
s
.66013 .53114 m
.65984 .52283 L
s
.65984 .52283 m
.66017 .53071 L
s
.559 .267 1 r
.46044 .51105 m
.46027 .5193 L
s
.46029 .51927 m
.46044 .51105 L
s
.46044 .51105 m
.46017 .52723 L
s
.608 .254 1 r
.66785 .47651 m
.66969 .51675 L
s
.712 .229 1 r
.39171 .47651 m
.39031 .51816 L
s
.66 .241 1 r
.33847 .52563 m
.33801 .53403 L
s
.33807 .53399 m
.33847 .52563 L
s
.531 .274 1 r
.32962 .53378 m
.32954 .5342 L
s
.66 .241 1 r
.33801 .53403 m
.33849 .5256 L
s
.33849 .5256 m
.33807 .53399 L
s
.777 .214 1 r
.71399 .51261 m
.71444 .52139 L
s
.71446 .52136 m
.71399 .51261 L
s
.71399 .51261 m
.71494 .52975 L
s
.531 .274 1 r
.75921 .51012 m
.75973 .51833 L
s
.75975 .5183 m
.75921 .51012 L
s
.75921 .51012 m
.7603 .52612 L
s
.355 .437 1 r
.81725 .47631 m
.82034 .51089 L
s
.88 .191 1 r
.54109 .47631 m
.54149 .51938 L
s
.822 .204 1 r
.41522 .51413 m
.41492 .52292 L
s
.41493 .52289 m
.41522 .51413 L
s
.41522 .51413 m
.4147 .53157 L
s
.609 .254 1 r
.60983 .51098 m
.61001 .51938 L
s
.61003 .51934 m
.60983 .51098 L
s
.60983 .51098 m
.61025 .52738 L
s
.477 .289 1 r
.3522 .53302 m
.35213 .53334 L
s
.589 .259 1 r
.73257 .53503 m
.73253 .53535 L
s
.432 .302 1 r
.56459 .51375 m
.56465 .52131 L
s
.56467 .52128 m
.56459 .51375 L
s
.56459 .51375 m
.56479 .52961 L
s
.521 .277 1 r
.60577 .53448 m
.60572 .53466 L
s
.733 .224 1 r
.6905 .4761 m
.69268 .51776 L
s
.777 .214 1 r
.41429 .4761 m
.41316 .51811 L
s
.755 .219 1 r
.51532 .5396 m
.51527 .53954 L
s
.766 .216 1 r
.66474 .53905 m
.66468 .53913 L
s
.342 .378 1 r
.29321 .52916 m
.29314 .52947 L
s
.339 .362 1 r
.72293 .50543 m
.72334 .51314 L
s
.72336 .51311 m
.72293 .50543 L
s
.72293 .50543 m
.72378 .52008 L
s
.919 .183 1 r
.56371 .47589 m
.56439 .51826 L
s
.701 .232 1 r
.43375 .53684 m
.43368 .53713 L
s
.733 .224 1 r
.28747 .47589 m
.2848 .5179 L
s
.494 .284 1 r
.78189 .50986 m
.78245 .51793 L
s
.78248 .5179 m
.78189 .50986 L
s
.78189 .50986 m
.78307 .52572 L
s
.669 .239 1 r
.31099 .51307 m
.31046 .52147 L
s
.31047 .52143 m
.31099 .51307 L
s
.31099 .51307 m
.30999 .5299 L
s
.7 .232 1 r
.73667 .51245 m
.73715 .52099 L
s
.73718 .52095 m
.73667 .51245 L
s
.73667 .51245 m
.73771 .52935 L
s
.649 .244 1 r
.45636 .53573 m
.4563 .53606 L
s
.4 .312 1 r
.75036 .51956 m
.75086 .52741 L
s
.75088 .52699 m
.75036 .51956 L
s
.75086 .52741 m
.75038 .51953 L
s
.75038 .51953 m
.75088 .52699 L
s
.81 .206 1 r
.48784 .52656 m
.48774 .53531 L
s
.48779 .53519 m
.48784 .52656 L
s
.335 .341 1 r
.40144 .50838 m
.40115 .51592 L
s
.40116 .51588 m
.40144 .50838 L
s
.40144 .50838 m
.40093 .52335 L
s
.81 .206 1 r
.48774 .53531 m
.48786 .52652 L
s
.48786 .52652 m
.48779 .53519 L
s
.37 .507 1 r
.71316 .47568 m
.71518 .50992 L
s
.868 .194 1 r
.43689 .47568 m
.43597 .51983 L
s
.344 .388 1 r
.66878 .51659 m
.66909 .52422 L
s
.66911 .52352 m
.66878 .51659 L
s
.892 .189 1 r
.61466 .52732 m
.61489 .53625 L
s
.61494 .5361 m
.61466 .52732 L
s
.344 .388 1 r
.66909 .52422 m
.6688 .51656 L
s
.6688 .51656 m
.66911 .52352 L
s
.649 .244 1 r
.68252 .52358 m
.6829 .53204 L
s
.68294 .53172 m
.68252 .52358 L
s
.551 .269 1 r
.70514 .52234 m
.70555 .53055 L
s
.70559 .53026 m
.70514 .52234 L
s
.892 .189 1 r
.61489 .53625 m
.61469 .52728 L
s
.61469 .52728 m
.61494 .5361 L
s
.649 .244 1 r
.6829 .53204 m
.68254 .52355 L
s
.68254 .52355 m
.68294 .53172 L
s
.551 .269 1 r
.70555 .53055 m
.70516 .5223 L
s
.70516 .5223 m
.70559 .53026 L
s
.723 .226 1 r
.35621 .51113 m
.35577 .51982 L
s
.35578 .51978 m
.35621 .51113 L
s
.35621 .51113 m
.35542 .52804 L
s
.744 .221 1 r
.33358 .51241 m
.33309 .52106 L
s
.3331 .52103 m
.33358 .51241 L
s
.33358 .51241 m
.33267 .5295 L
s
.679 .237 1 r
.30689 .53699 m
.30683 .5371 L
s
.485 .287 1 r
.37881 .51 m
.37845 .51801 L
s
.37847 .51797 m
.37881 .51 L
s
.37881 .51 m
.37817 .52587 L
s
.352 .327 1 r
.58634 .47548 m
.58718 .51325 L
s
.578 .262 1 r
.31004 .47548 m
.30774 .51572 L
s
.411 .309 1 r
.51934 .51791 m
.51933 .52591 L
s
.51938 .52513 m
.51934 .51791 L
s
.51933 .52591 m
.51936 .51788 L
s
.51936 .51788 m
.51938 .52513 L
s
.965 .174 1 r
.73583 .47527 m
.73874 .51977 L
s
.648 .244 1 r
.45949 .47527 m
.45892 .51587 L
s
.7 .232 1 r
.40622 .52442 m
.40592 .53296 L
s
.40598 .53278 m
.40622 .52442 L
s
.55 .269 1 r
.50565 .51122 m
.50558 .51933 L
s
.50559 .5193 m
.50565 .51122 L
s
.50565 .51122 m
.50558 .52748 L
s
.7 .232 1 r
.40592 .53296 m
.40623 .52439 L
s
.40623 .52439 m
.40598 .53278 L
s
.335 .34 1 r
.46522 .5289 m
.46517 .52922 L
s
.608 .254 1 r
.30197 .5227 m
.30143 .53105 L
s
.30151 .53076 m
.30197 .5227 L
s
.30143 .53105 m
.30199 .52266 L
s
.30199 .52266 m
.30151 .53076 L
s
.638 .247 1 r
.42883 .52346 m
.4286 .53185 L
s
.42866 .53167 m
.42883 .52346 L
s
.531 .274 1 r
.60898 .47506 m
.61015 .51531 L
s
.658 .242 1 r
.33261 .47506 m
.33052 .51638 L
s
.638 .247 1 r
.4286 .53185 m
.42885 .52342 L
s
.42885 .52342 m
.42866 .53167 L
s
.881 .191 1 r
.71009 .5386 m
.71005 .53893 L
s
.822 .204 1 r
.48303 .51291 m
.4829 .52171 L
s
.48291 .52167 m
.48303 .51291 L
s
.48303 .51291 m
.48284 .53036 L
s
.733 .224 1 r
.58321 .53805 m
.58315 .53802 L
s
.459 .294 1 r
.7731 .52 m
.77366 .528 L
s
.77369 .52764 m
.7731 .52 L
s
.77366 .528 m
.77312 .51997 L
s
.77312 .51997 m
.77369 .52764 L
s
.383 .317 1 r
.71898 .53071 m
.71894 .53085 L
s
.744 .222 1 r
.47896 .53639 m
.4789 .53671 L
s
.977 .171 1 r
.75851 .47485 m
.76169 .51901 L
s
.916 .184 1 r
.48211 .47485 m
.48178 .5183 L
s
.813 .206 1 r
.62848 .53584 m
.62845 .53648 L
s
1 .133 .827 r
.59208 .53025 m
.59225 .53966 L
s
.59232 .53968 m
.59208 .53025 L
s
.648 .244 1 r
.72786 .52277 m
.72835 .53124 L
s
.72838 .53091 m
.72786 .52277 L
s
1 .133 .827 r
.59225 .53966 m
.59211 .53021 L
s
.59211 .53021 m
.59232 .53968 L
s
.648 .244 1 r
.72835 .53124 m
.72789 .52274 L
s
.72789 .52274 m
.72838 .53091 L
s
.36 .324 1 r
.76426 .5285 m
.76424 .52896 L
s
.559 .267 1 r
.54685 .53307 m
.5468 .5334 L
s
.669 .239 1 r
.63164 .47465 m
.63311 .51597 L
s
.55 .269 1 r
.3552 .47465 m
.35344 .51455 L
s
.4 .312 1 r
.56947 .53197 m
.56942 .53187 L
s
.904 .186 1 r
.53309 .52631 m
.5331 .53528 L
s
.53316 .53509 m
.53309 .52631 L
s
.5331 .53528 m
.53311 .52627 L
s
.53311 .52627 m
.53316 .53509 L
s
.589 .259 1 r
.42401 .50943 m
.42374 .51776 L
s
.42376 .51772 m
.42401 .50943 L
s
.42401 .50943 m
.42356 .52576 L
s
.608 .254 1 r
.47407 .52209 m
.47395 .53045 L
s
.474 .53016 m
.47407 .52209 L
s
.711 .229 1 r
.65519 .51203 m
.65548 .52054 L
s
.6555 .5205 m
.65519 .51203 L
s
.65519 .51203 m
.65585 .52904 L
s
.608 .254 1 r
.47395 .53045 m
.47409 .52206 L
s
.47409 .52206 m
.474 .53016 L
s
.45 .297 1 r
.74167 .53031 m
.74164 .53074 L
s
.93 .181 1 r
.55573 .52534 m
.5558 .53446 L
s
.55586 .53398 m
.55573 .52534 L
s
.788 .211 1 r
.57836 .5241 m
.57848 .53289 L
s
.57854 .53253 m
.57836 .5241 L
s
.93 .181 1 r
.5558 .53446 m
.55575 .52531 L
s
.55575 .52531 m
.55586 .53398 L
s
.55 .269 1 r
.78121 .47444 m
.78431 .51399 L
s
.531 .274 1 r
.50474 .47444 m
.50469 .51399 L
s
.788 .211 1 r
.57848 .53289 m
.57838 .52406 L
s
.57838 .52406 m
.57854 .53253 L
s
.744 .222 1 r
.45144 .52362 m
.45125 .5323 L
s
.45131 .53197 m
.45144 .52362 L
s
.58 .261 1 r
.44257 .53177 m
.4425 .53237 L
s
.744 .222 1 r
.45125 .5323 m
.45146 .52358 L
s
.45146 .52358 m
.45131 .53197 L
s
.608 .254 1 r
.39729 .53433 m
.39723 .53451 L
s
.648 .244 1 r
.70048 .50985 m
.70088 .51832 L
s
.7009 .51828 m
.70048 .50985 L
s
.70048 .50985 m
.70134 .52647 L
s
.608 .254 1 r
.3245 .52313 m
.32402 .53139 L
s
.32408 .53142 m
.3245 .52313 L
s
.345 .39 1 r
.43768 .5169 m
.43749 .5244 L
s
.43755 .52412 m
.43768 .5169 L
s
.608 .254 1 r
.32402 .53139 m
.32452 .5231 L
s
.32452 .5231 m
.32408 .53142 L
s
.649 .244 1 r
.69642 .53323 m
.6964 .53376 L
s
.345 .39 1 r
.43749 .5244 m
.4377 .51687 L
s
.4377 .51687 m
.43755 .52412 L
s
.383 .317 1 r
.54197 .51891 m
.54201 .52662 L
s
.54206 .52648 m
.54197 .51891 L
s
.777 .214 1 r
.6543 .47423 m
.65607 .51626 L
s
.58 .262 1 r
.3778 .47423 m
.37627 .51485 L
s
.383 .317 1 r
.54201 .52662 m
.54199 .51888 L
s
.54199 .51888 m
.54206 .52648 L
s
.701 .231 1 r
.6738 .53468 m
.67376 .53508 L
s
.598 .257 1 r
.34713 .52217 m
.3467 .53046 L
s
.34676 .53031 m
.34713 .52217 L
s
.3467 .53046 m
.34714 .52213 L
s
.34714 .52213 m
.34676 .53031 L
s
.858 .196 1 r
.65117 .53614 m
.65114 .53672 L
s
.744 .221 1 r
.52422 .53559 m
.52417 .53591 L
s
.669 .239 1 r
.60101 .52369 m
.60118 .53209 L
s
.60124 .53212 m
.60101 .52369 L
s
.384 .317 1 r
.79107 .50546 m
.79164 .51332 L
s
.79166 .51329 m
.79107 .50546 L
s
.79107 .50546 m
.79225 .52062 L
s
.57 .264 1 r
.80391 .47402 m
.80726 .51322 L
s
1 .136 .841 r
.52737 .47402 m
.52763 .51961 L
s
.669 .239 1 r
.60118 .53209 m
.60103 .52366 L
s
.60103 .52366 m
.60124 .53212 L
s
.892 .189 1 r
.52829 .51252 m
.52827 .52146 L
s
.52829 .52142 m
.52829 .51252 L
s
.52829 .51252 m
.52833 .53026 L
s
.869 .194 1 r
.50159 .53704 m
.50153 .53744 L
s
.367 .322 1 r
.49189 .50689 m
.49179 .51457 L
s
.49181 .51454 m
.49189 .50689 L
s
.49189 .50689 m
.49177 .52208 L
s
.357 .448 1 r
.63255 .51448 m
.63278 .52198 L
s
.6328 .52134 m
.63255 .51448 L
s
.754 .219 1 r
.37462 .53649 m
.37456 .53664 L
s
.648 .244 1 r
.62366 .52273 m
.62389 .53113 L
s
.62394 .53102 m
.62366 .52273 L
s
.357 .448 1 r
.63278 .52198 m
.63257 .51445 L
s
.63257 .51445 m
.6328 .52134 L
s
.648 .244 1 r
.62389 .53113 m
.62368 .52269 L
s
.62368 .52269 m
.62394 .53102 L
s
.788 .212 1 r
.55093 .51148 m
.55097 .52021 L
s
.55099 .52017 m
.55093 .51148 L
s
.55093 .51148 m
.55108 .52879 L
s
.649 .244 1 r
.67698 .47381 m
.67896 .51444 L
s
.344 .33 1 r
.40041 .47381 m
.39926 .5109 L
s
.467 .292 1 r
.6916 .51927 m
.69197 .52727 L
s
.69201 .52699 m
.6916 .51927 L
s
.69197 .52727 m
.69162 .51924 L
s
.69162 .51924 m
.69201 .52699 L
s
.375 .32 1 r
.58728 .51754 m
.58741 .52529 L
s
.58745 .52497 m
.58728 .51754 L
s
.58741 .52529 m
.58729 .51751 L
s
.58729 .51751 m
.58745 .52497 L
s
.779 .213 1 r
.64633 .52204 m
.64663 .53091 L
s
.64666 .53026 m
.64633 .52204 L
s
.81 .206 1 r
.82663 .47361 m
.83058 .51671 L
s
.777 .214 1 r
.55002 .47361 m
.55053 .51565 L
s
.367 .322 1 r
.27342 .47361 m
.27083 .51175 L
s
.789 .211 1 r
.57359 .51076 m
.57368 .51952 L
s
.5737 .51948 m
.57359 .51076 L
s
.57359 .51076 m
.57385 .52803 L
s
.779 .213 1 r
.64663 .53091 m
.64635 .52201 L
s
.64635 .52201 m
.64666 .53026 L
s
.46 .294 1 r
.34226 .50827 m
.34182 .51618 L
s
.34184 .51615 m
.34226 .50827 L
s
.34226 .50827 m
.34146 .52405 L
s
.578 .262 1 r
.3196 .5098 m
.3191 .51799 L
s
.31911 .51796 m
.3196 .5098 L
s
.3196 .5098 m
.31866 .52622 L
s
.416 .307 1 r
.38348 .52931 m
.38341 .52959 L
s
.658 .242 1 r
.59623 .50983 m
.59638 .51827 L
s
.5964 .51824 m
.59623 .50983 L
s
.59623 .50983 m
.5966 .52657 L
s
.723 .226 1 r
.69967 .4734 m
.70192 .51403 L
s
.391 .315 1 r
.42303 .4734 m
.42208 .5119 L
s
.743 .222 1 r
.29695 .51122 m
.29637 .5198 L
s
.29638 .51977 m
.29695 .51122 L
s
.29695 .51122 m
.29585 .52839 L
s
.524 .276 1 r
.51048 .53021 m
.51042 .53071 L
s
.711 .229 1 r
.49669 .52337 m
.49662 .53188 L
s
.49667 .53187 m
.49669 .52337 L
s
.977 .171 1 r
.67795 .51333 m
.67832 .52238 L
s
.67834 .52235 m
.67795 .51333 L
s
.67795 .51333 m
.67877 .53147 L
s
.733 .224 1 r
.41987 .53534 m
.41981 .53552 L
s
.711 .229 1 r
.49662 .53188 m
.49671 .52333 L
s
.49671 .52333 m
.49667 .53187 L
s
.953 .176 1 r
.57268 .47319 m
.5735 .51701 L
s
.54 .272 1 r
.29601 .47319 m
.29357 .51311 L
s
.522 .277 1 r
.36081 .53112 m
.36074 .5314 L
s
.628 .249 1 r
.3155 .53368 m
.31544 .53383 L
s
.45 .297 1 r
.53719 .50603 m
.53719 .51404 L
s
.53721 .514 m
.53719 .50603 L
s
.53719 .50603 m
.53727 .52162 L
s
.754 .219 1 r
.36968 .52317 m
.36928 .53182 L
s
.36935 .53167 m
.36968 .52317 L
s
.36928 .53182 m
.36969 .52313 L
s
.36969 .52313 m
.36935 .53167 L
s
.441 .3 1 r
.38751 .5069 m
.38718 .5148 L
s
.38719 .51477 m
.38751 .5069 L
s
.38751 .5069 m
.38692 .52253 L
s
.651 .244 1 r
.6375 .53147 m
.63747 .53211 L
s
.618 .252 1 r
.36486 .50821 m
.36445 .51661 L
s
.36447 .51658 m
.36486 .50821 L
s
.36486 .50821 m
.36413 .5247 L
s
.335 .34 1 r
.72237 .47298 m
.7246 .50901 L
s
.868 .194 1 r
.44566 .47298 m
.44486 .51716 L
s
.648 .244 1 r
.64157 .50842 m
.64183 .5169 L
s
.64185 .51686 m
.64157 .50842 L
s
.64157 .50842 m
.64215 .52505 L
s
.494 .284 1 r
.28793 .52047 m
.28738 .5284 L
s
.28743 .52854 m
.28793 .52047 L
s
.28738 .5284 m
.28794 .52043 L
s
.28794 .52043 m
.28743 .52854 L
s
.733 .224 1 r
.39231 .52248 m
.39197 .5311 L
s
.39204 .53091 m
.39231 .52248 L
s
.767 .216 1 r
.59535 .47277 m
.59639 .51412 L
s
.512 .279 1 r
.31862 .47277 m
.31643 .5127 L
s
.733 .224 1 r
.39197 .5311 m
.39233 .52245 L
s
.39233 .52245 m
.39204 .53091 L
s
.56 .267 1 r
.66017 .53071 m
.66013 .53114 L
s
.811 .206 1 r
.76863 .50936 m
.76922 .51823 L
s
.76924 .51819 m
.76863 .50936 L
s
.76863 .50936 m
.76986 .52667 L
s
1 .158 .958 r
.74598 .51067 m
.74655 .52004 L
s
.74657 .52 m
.74598 .51067 L
s
.74598 .51067 m
.74716 .52884 L
s
.682 .236 1 r
.74508 .47257 m
.74781 .51249 L
s
.916 .184 1 r
.46831 .47257 m
.46781 .51604 L
s
.559 .267 1 r
.46027 .5193 m
.46011 .52755 L
s
.46017 .52723 m
.46027 .5193 L
s
.46011 .52755 m
.46029 .51927 L
s
.46029 .51927 m
.46017 .52723 L
s
.432 .302 1 r
.56465 .52131 m
.56473 .52888 L
s
.56479 .52961 m
.56465 .52131 L
s
.56473 .52888 m
.56467 .52128 L
s
.56467 .52128 m
.56479 .52961 L
s
.928 .181 1 r
.46922 .5113 m
.46905 .52032 L
s
.46907 .52028 m
.46922 .5113 L
s
.46922 .5113 m
.46896 .52919 L
s
.441 .3 1 r
.28306 .50629 m
.28249 .51419 L
s
.2825 .51416 m
.28306 .50629 L
s
.28306 .50629 m
.282 .52192 L
s
.66 .241 1 r
.33807 .53399 m
.33801 .53403 L
s
.531 .274 1 r
.75973 .51833 m
.76028 .52655 L
s
.7603 .52612 m
.75973 .51833 L
s
.801 .208 1 r
.61804 .47236 m
.61934 .51335 L
s
.459 .295 1 r
.34123 .47236 m
.33936 .51123 L
s
.531 .274 1 r
.76028 .52655 m
.75975 .5183 L
s
.75975 .5183 m
.7603 .52612 L
s
.344 .388 1 r
.66911 .52352 m
.66909 .52422 L
s
.701 .232 1 r
.66428 .50847 m
.6646 .51705 L
s
.66462 .51702 m
.66428 .50847 L
s
.66428 .50847 m
.66498 .52535 L
s
.638 .247 1 r
.51454 .5092 m
.51448 .51754 L
s
.5145 .5175 m
.51454 .5092 L
s
.51454 .5092 m
.51451 .52591 L
s
.609 .254 1 r
.61001 .51938 m
.61021 .52778 L
s
.61025 .52738 m
.61001 .51938 L
s
.456 .855 1 r
.7678 .47215 m
.77008 .50254 L
s
.559 .267 1 r
.49096 .47215 m
.49076 .51173 L
s
.339 .362 1 r
.72334 .51314 m
.72377 .52085 L
s
.72378 .52008 m
.72334 .51314 L
s
.609 .254 1 r
.61021 .52778 m
.61003 .51934 L
s
.61003 .51934 m
.61025 .52738 L
s
.4 .312 1 r
.75088 .52699 m
.75086 .52741 L
s
.777 .214 1 r
.71444 .52139 m
.71491 .53019 L
s
.71494 .52975 m
.71444 .52139 L
s
.339 .362 1 r
.72377 .52085 m
.72336 .51311 L
s
.72336 .51311 m
.72378 .52008 L
s
.777 .214 1 r
.71491 .53019 m
.71446 .52136 L
s
.71446 .52136 m
.71494 .52975 L
s
.335 .341 1 r
.40115 .51592 m
.40087 .52345 L
s
.40093 .52335 m
.40115 .51592 L
s
.40087 .52345 m
.40116 .51588 L
s
.40116 .51588 m
.40093 .52335 L
s
.822 .204 1 r
.41492 .52292 m
.41463 .53172 L
s
.4147 .53157 m
.41492 .52292 L
s
.494 .284 1 r
.78245 .51793 m
.78304 .52601 L
s
.78307 .52572 m
.78245 .51793 L
s
.822 .204 1 r
.41463 .53172 m
.41493 .52289 L
s
.41493 .52289 m
.4147 .53157 L
s
.869 .194 1 r
.64073 .47194 m
.64237 .51507 L
s
.588 .259 1 r
.36386 .47194 m
.36216 .51259 L
s
.494 .284 1 r
.78304 .52601 m
.78248 .5179 L
s
.78248 .5179 m
.78307 .52572 L
s
.836 .201 1 r
.68699 .50795 m
.68738 .51693 L
s
.6874 .51689 m
.68699 .50795 L
s
.68699 .50795 m
.68782 .5253 L
s
.418 .307 1 r
.62788 .50359 m
.62809 .51156 L
s
.62811 .51153 m
.62788 .50359 L
s
.62788 .50359 m
.62836 .51893 L
s
.411 .309 1 r
.51938 .52513 m
.51933 .52591 L
s
.55 .269 1 r
.70966 .50692 m
.71007 .51511 L
s
.71009 .51508 m
.70966 .50692 L
s
.70966 .50692 m
.71054 .52313 L
s
1 .154 .934 r
.61899 .51197 m
.61921 .52125 L
s
.61923 .52121 m
.61899 .51197 L
s
.61899 .51197 m
.61951 .53041 L
s
.669 .239 1 r
.31046 .52147 m
.30993 .52987 L
s
.30999 .5299 m
.31046 .52147 L
s
.551 .269 1 r
.70559 .53026 m
.70555 .53055 L
s
.618 .252 1 r
.79053 .47173 m
.79381 .51202 L
s
1 .151 .919 r
.51363 .47173 m
.5137 .51628 L
s
.669 .239 1 r
.30993 .52987 m
.31047 .52143 L
s
.31047 .52143 m
.30999 .5299 L
s
.494 .284 1 r
.45543 .50578 m
.45524 .51386 L
s
.45526 .51383 m
.45543 .50578 L
s
.45543 .50578 m
.45514 .52166 L
s
.7 .232 1 r
.73715 .52099 m
.73767 .52953 L
s
.73771 .52935 m
.73715 .52099 L
s
.69 .234 1 r
.41009 .50841 m
.40978 .51693 L
s
.4098 .51689 m
.41009 .50841 L
s
.41009 .50841 m
.40956 .5253 L
s
.7 .232 1 r
.73767 .52953 m
.73718 .52095 L
s
.73718 .52095 m
.73771 .52935 L
s
.649 .244 1 r
.68294 .53172 m
.6829 .53204 L
s
.485 .287 1 r
.37845 .51801 m
.37811 .52601 L
s
.37817 .52587 m
.37845 .51801 L
s
.37811 .52601 m
.37847 .51797 L
s
.37847 .51797 m
.37817 .52587 L
s
.459 .295 1 r
.66343 .47152 m
.66517 .5104 L
s
.733 .224 1 r
.38649 .47152 m
.38501 .51359 L
s
.81 .206 1 r
.48779 .53519 m
.48774 .53531 L
s
.892 .189 1 r
.61494 .5361 m
.61489 .53625 L
s
.744 .221 1 r
.33309 .52106 m
.3326 .52972 L
s
.33267 .5295 m
.33309 .52106 L
s
.723 .226 1 r
.35577 .51982 m
.35534 .52851 L
s
.35542 .52804 m
.35577 .51982 L
s
.352 .327 1 r
.81327 .47131 m
.81648 .50772 L
s
.629 .249 1 r
.5363 .47131 m
.53663 .51126 L
s
.744 .221 1 r
.3326 .52972 m
.3331 .52103 L
s
.3331 .52103 m
.33267 .5295 L
s
.723 .226 1 r
.35534 .52851 m
.35578 .51978 L
s
.35578 .51978 m
.35542 .52804 L
s
.55 .269 1 r
.50558 .51933 m
.50552 .52745 L
s
.50558 .52748 m
.50558 .51933 L
s
.50552 .52745 m
.50559 .5193 L
s
.50559 .5193 m
.50558 .52748 L
s
.608 .254 1 r
.30151 .53076 m
.30143 .53105 L
s
.459 .294 1 r
.77369 .52764 m
.77366 .528 L
s
.7 .232 1 r
.40598 .53278 m
.40592 .53296 L
s
.811 .206 1 r
.68615 .47111 m
.68831 .51318 L
s
.503 .282 1 r
.40914 .47111 m
.40799 .51105 L
s
.638 .247 1 r
.42866 .53167 m
.4286 .53185 L
s
.766 .217 1 r
.30556 .50787 m
.30499 .5166 L
s
.30501 .51656 m
.30556 .50787 L
s
.30556 .50787 m
.30451 .52505 L
s
.468 .292 1 r
.50076 .50475 m
.50068 .51277 L
s
.5007 .51273 m
.50076 .50475 L
s
.50076 .50475 m
.50068 .5205 L
s
.34 .331 1 r
.83603 .4709 m
.83938 .50624 L
s
.68 .237 1 r
.55899 .4709 m
.55959 .51191 L
s
.531 .274 1 r
.28195 .4709 m
.27939 .51014 L
s
.904 .186 1 r
.55991 .50943 m
.55997 .51841 L
s
.55999 .51838 m
.55991 .50943 L
s
.55991 .50943 m
.56011 .52722 L
s
.765 .217 1 r
.58259 .50818 m
.5827 .51688 L
s
.58273 .51684 m
.58259 .50818 L
s
.58259 .50818 m
.5829 .5254 L
s
.648 .244 1 r
.72838 .53091 m
.72835 .53124 L
s
.559 .267 1 r
.75513 .50638 m
.75565 .51458 L
s
.75567 .51454 m
.75513 .50638 L
s
.75513 .50638 m
.75623 .52267 L
s
.345 .39 1 r
.43755 .52412 m
.43749 .5244 L
s
.857 .196 1 r
.43272 .50905 m
.43246 .51793 L
s
.43248 .51789 m
.43272 .50905 L
s
.43272 .50905 m
.43228 .52666 L
s
.822 .204 1 r
.4829 .52171 m
.48278 .53051 L
s
.48284 .53036 m
.4829 .52171 L
s
.48278 .53051 m
.48291 .52167 L
s
.48291 .52167 m
.48284 .53036 L
s
.379 .548 1 r
.70887 .47069 m
.71083 .50427 L
s
.712 .229 1 r
.4318 .47069 m
.4309 .5117 L
s
.467 .292 1 r
.37356 .50486 m
.37319 .51284 L
s
.37321 .51281 m
.37356 .50486 L
s
.37356 .50486 m
.3729 .52064 L
s
.57 .264 1 r
.80054 .50427 m
.80117 .51264 L
s
.8012 .5126 m
.80054 .50427 L
s
.80054 .50427 m
.80184 .52044 L
s
.608 .254 1 r
.474 .53016 m
.47395 .53045 L
s
.357 .448 1 r
.6328 .52134 m
.63278 .52198 L
s
.383 .317 1 r
.54206 .52648 m
.54201 .52662 L
s
.589 .259 1 r
.42374 .51776 m
.42349 .52609 L
s
.42356 .52576 m
.42374 .51776 L
s
.618 .252 1 r
.58169 .47048 m
.58254 .51043 L
s
.669 .239 1 r
.30458 .47048 m
.30217 .5115 L
s
.589 .259 1 r
.42349 .52609 m
.42376 .51772 L
s
.42376 .51772 m
.42356 .52576 L
s
.811 .206 1 r
.47808 .50711 m
.47794 .51599 L
s
.47796 .51595 m
.47808 .50711 L
s
.47808 .50711 m
.47788 .52444 L
s
.87 .194 1 r
.6053 .50777 m
.60548 .51675 L
s
.6055 .51671 m
.6053 .50777 L
s
.6053 .50777 m
.60573 .52534 L
s
.711 .229 1 r
.65548 .52054 m
.65579 .52905 L
s
.65585 .52904 m
.65548 .52054 L
s
.788 .211 1 r
.57854 .53253 m
.57848 .53289 L
s
.711 .229 1 r
.65579 .52905 m
.6555 .5205 L
s
.6555 .5205 m
.65585 .52904 L
s
.904 .186 1 r
.53316 .53509 m
.5331 .53528 L
s
.441 .3 1 r
.39622 .50424 m
.39591 .51215 L
s
.39592 .51212 m
.39622 .50424 L
s
.39622 .50424 m
.39567 .51988 L
s
.744 .222 1 r
.45131 .53197 m
.45125 .5323 L
s
.608 .254 1 r
.32408 .53142 m
.32402 .53139 L
s
.881 .191 1 r
.73161 .47027 m
.73437 .51307 L
s
.442 .299 1 r
.45447 .47027 m
.45389 .5081 L
s
.93 .181 1 r
.55586 .53398 m
.5558 .53446 L
s
1 .133 .827 r
.59232 .53968 m
.59225 .53966 L
s
.648 .244 1 r
.70088 .51832 m
.7013 .52679 L
s
.70134 .52647 m
.70088 .51832 L
s
.367 .322 1 r
.49179 .51457 m
.49171 .52225 L
s
.49177 .52208 m
.49179 .51457 L
s
.384 .317 1 r
.79164 .51332 m
.79224 .52118 L
s
.79225 .52062 m
.79164 .51332 L
s
.598 .257 1 r
.34676 .53031 m
.3467 .53046 L
s
.648 .244 1 r
.7013 .52679 m
.7009 .51828 L
s
.7009 .51828 m
.70134 .52647 L
s
.367 .322 1 r
.49171 .52225 m
.49181 .51454 L
s
.49181 .51454 m
.49177 .52208 L
s
.384 .317 1 r
.79224 .52118 m
.79166 .51329 L
s
.79166 .51329 m
.79225 .52062 L
s
.857 .196 1 r
.32814 .50844 m
.32762 .51732 L
s
.32764 .51728 m
.32814 .50844 L
s
.32814 .50844 m
.32718 .52605 L
s
.55 .269 1 r
.60439 .47006 m
.6055 .51002 L
s
.36 .325 1 r
.32722 .47006 m
.32522 .50825 L
s
.375 .32 1 r
.58745 .52497 m
.58741 .52529 L
s
.754 .219 1 r
.35082 .5074 m
.35037 .51606 L
s
.35038 .51603 m
.35082 .5074 L
s
.35082 .5074 m
.34999 .52459 L
s
.467 .292 1 r
.69201 .52699 m
.69197 .52727 L
s
.669 .239 1 r
.60124 .53212 m
.60118 .53209 L
s
.4 .64 1 r
.75436 .46985 m
.75667 .50238 L
s
.648 .244 1 r
.62394 .53102 m
.62389 .53113 L
s
.754 .219 1 r
.47715 .46985 m
.47676 .5123 L
s
.416 .307 1 r
.29162 .50342 m
.29108 .51126 L
s
.29109 .51122 m
.29162 .50342 L
s
.29162 .50342 m
.29061 .51892 L
s
.46 .294 1 r
.34182 .51618 m
.3414 .52409 L
s
.34146 .52405 m
.34182 .51618 L
s
.846 .199 1 r
.65073 .50671 m
.65102 .51566 L
s
.65105 .51562 m
.65073 .50671 L
s
.65073 .50671 m
.65138 .52418 L
s
.46 .294 1 r
.3414 .52409 m
.34184 .51615 L
s
.34184 .51615 m
.34146 .52405 L
s
.846 .199 1 r
.52346 .50619 m
.52343 .51517 L
s
.52345 .51514 m
.52346 .50619 L
s
.52346 .50619 m
.52348 .52362 L
s
.711 .229 1 r
.62711 .46964 m
.62853 .51103 L
s
.503 .282 1 r
.34987 .46964 m
.34806 .50925 L
s
.892 .189 1 r
.52827 .52146 m
.52827 .53041 L
s
.52833 .53026 m
.52827 .52146 L
s
.788 .212 1 r
.55097 .52021 m
.55103 .52894 L
s
.55108 .52879 m
.55097 .52021 L
s
.618 .252 1 r
.69613 .50442 m
.69652 .51287 L
s
.69654 .51283 m
.69613 .50442 L
s
.69613 .50442 m
.69696 .52089 L
s
.42 .723 1 r
.8096 .49812 m
.81013 .50492 L
s
.81015 .50489 m
.8096 .49812 L
s
.8096 .49812 m
.81071 .51144 L
s
.779 .213 1 r
.64666 .53026 m
.64663 .53091 L
s
1 .123 .772 r
.73263 .51014 m
.73317 .51978 L
s
.73319 .51974 m
.73263 .51014 L
s
.73263 .51014 m
.73378 .52909 L
s
.892 .189 1 r
.52827 .53041 m
.52829 .52142 L
s
.52829 .52142 m
.52833 .53026 L
s
.788 .212 1 r
.55103 .52894 m
.55099 .52017 L
s
.55099 .52017 m
.55108 .52879 L
s
.578 .262 1 r
.3191 .51799 m
.31861 .52618 L
s
.31866 .52622 m
.3191 .51799 L
s
.589 .259 1 r
.77712 .46943 m
.78019 .50905 L
s
.618 .252 1 r
.49984 .46943 m
.49974 .50976 L
s
.578 .262 1 r
.31861 .52618 m
.31911 .51796 L
s
.31911 .51796 m
.31866 .52622 L
s
.355 .437 1 r
.65966 .4993 m
.65993 .50681 L
s
.65995 .50678 m
.65966 .4993 L
s
.65966 .4993 m
.66024 .51376 L
s
.789 .211 1 r
.57368 .51952 m
.5738 .52829 L
s
.57385 .52803 m
.57368 .51952 L
s
.658 .242 1 r
.59638 .51827 m
.59655 .52672 L
s
.5966 .52657 m
.59638 .51827 L
s
.789 .211 1 r
.5738 .52829 m
.5737 .51948 L
s
.5737 .51948 m
.57385 .52803 L
s
.658 .242 1 r
.59655 .52672 m
.5964 .51824 L
s
.5964 .51824 m
.5966 .52657 L
s
.916 .184 1 r
.77806 .50828 m
.77868 .51727 L
s
.77871 .51723 m
.77806 .50828 L
s
.77806 .50828 m
.77938 .52615 L
s
.45 .297 1 r
.53719 .51404 m
.53721 .52205 L
s
.53727 .52162 m
.53719 .51404 L
s
.383 .565 1 r
.64985 .46923 m
.65126 .50388 L
s
.342 .377 1 r
.37254 .46923 m
.37114 .50494 L
s
.823 .204 1 r
.54617 .50585 m
.5462 .51476 L
s
.54622 .51472 m
.54617 .50585 L
s
.54617 .50585 m
.5463 .52321 L
s
.45 .297 1 r
.53721 .52205 m
.53721 .514 L
s
.53721 .514 m
.53727 .52162 L
s
.743 .222 1 r
.29637 .5198 m
.29579 .52839 L
s
.29585 .52839 m
.29637 .5198 L
s
.441 .3 1 r
.38718 .5148 m
.38686 .52271 L
s
.38692 .52253 m
.38718 .5148 L
s
.743 .222 1 r
.29579 .52839 m
.29638 .51977 L
s
.29638 .51977 m
.29585 .52839 L
s
.441 .3 1 r
.38686 .52271 m
.38719 .51477 L
s
.38719 .51477 m
.38692 .52253 L
s
.711 .229 1 r
.49667 .53187 m
.49662 .53188 L
s
.392 .608 1 r
.79989 .46902 m
.80266 .50191 L
s
1 .111 .702 r
.52254 .46902 m
.52274 .5161 L
s
.494 .284 1 r
.28743 .52854 m
.28738 .5284 L
s
.754 .219 1 r
.36935 .53167 m
.36928 .53182 L
s
.618 .252 1 r
.36445 .51661 m
.36406 .52502 L
s
.36413 .5247 m
.36445 .51661 L
s
.868 .194 1 r
.6735 .50718 m
.67385 .51609 L
s
.67387 .51606 m
.6735 .50718 L
s
.6735 .50718 m
.67428 .52483 L
s
.618 .252 1 r
.36406 .52502 m
.36447 .51658 L
s
.36447 .51658 m
.36413 .5247 L
s
.977 .171 1 r
.67832 .52238 m
.67871 .53145 L
s
.67877 .53147 m
.67832 .52238 L
s
.658 .242 1 r
.56888 .50534 m
.56896 .51379 L
s
.56898 .51376 m
.56888 .50534 L
s
.56888 .50534 m
.56911 .5221 L
s
.559 .267 1 r
.46425 .5035 m
.46408 .51177 L
s
.4641 .51173 m
.46425 .5035 L
s
.46425 .5035 m
.46399 .51972 L
s
.701 .232 1 r
.41883 .50603 m
.41855 .51456 L
s
.41857 .51452 m
.41883 .50603 L
s
.41883 .50603 m
.41834 .52301 L
s
.977 .171 1 r
.67871 .53145 m
.67834 .52235 L
s
.67834 .52235 m
.67877 .53147 L
s
.846 .199 1 r
.67259 .46881 m
.6746 .51127 L
s
.433 .302 1 r
.39521 .46881 m
.39395 .50736 L
s
.648 .244 1 r
.64183 .5169 m
.64211 .52538 L
s
.64215 .52505 m
.64183 .5169 L
s
.432 .302 1 r
.56479 .52961 m
.56473 .52888 L
s
.648 .244 1 r
.64211 .52538 m
.64185 .51686 L
s
.64185 .51686 m
.64215 .52505 L
s
.339 .362 1 r
.72378 .52008 m
.72377 .52085 L
s
.733 .224 1 r
.39204 .53091 m
.39197 .5311 L
s
.559 .267 1 r
.46017 .52723 m
.46011 .52755 L
s
.442 .299 1 r
.82267 .4686 m
.82611 .50645 L
s
.811 .206 1 r
.54526 .4686 m
.54571 .5107 L
s
.467 .292 1 r
.26785 .4686 m
.26514 .50751 L
s
.531 .274 1 r
.7603 .52612 m
.76028 .52655 L
s
.441 .3 1 r
.28249 .51419 m
.28193 .5221 L
s
.282 .52192 m
.28249 .51419 L
s
.433 .302 1 r
.78709 .5016 m
.78766 .50955 L
s
.78768 .50951 m
.78709 .5016 L
s
.78709 .5016 m
.78828 .51714 L
s
.441 .3 1 r
.28193 .5221 m
.2825 .51416 L
s
.2825 .51416 m
.282 .52192 L
s
.669 .239 1 r
.31417 .50489 m
.31363 .51338 L
s
.31365 .51335 m
.31417 .50489 L
s
.31417 .50489 m
.31318 .52169 L
s
.811 .206 1 r
.76922 .51823 m
.76983 .5271 L
s
.76986 .52667 m
.76922 .51823 L
s
.638 .247 1 r
.69534 .46839 m
.69759 .51014 L
s
.777 .214 1 r
.4179 .46839 m
.41679 .51085 L
s
.811 .206 1 r
.76983 .5271 m
.76924 .51819 L
s
.76924 .51819 m
.76986 .52667 L
s
.335 .341 1 r
.40093 .52335 m
.40087 .52345 L
s
.56 .267 1 r
.63704 .50257 m
.63728 .51088 L
s
.6373 .51084 m
.63704 .50257 L
s
.63704 .50257 m
.63758 .51876 L
s
.765 .217 1 r
.44153 .50573 m
.44129 .51443 L
s
.44131 .51439 m
.44153 .50573 L
s
.44153 .50573 m
.44114 .52296 L
s
.609 .254 1 r
.61025 .52738 m
.61021 .52778 L
s
.359 .46 1 r
.84546 .46818 m
.84881 .50249 L
s
.69 .234 1 r
.56798 .46818 m
.56869 .50923 L
s
.648 .244 1 r
.2905 .46818 m
.28795 .50887 L
s
1 .158 .958 r
.74655 .52004 m
.74713 .52942 L
s
.74716 .52884 m
.74655 .52004 L
s
.638 .247 1 r
.51448 .51754 m
.51445 .52588 L
s
.51451 .52591 m
.51448 .51754 L
s
.494 .284 1 r
.78307 .52572 m
.78304 .52601 L
s
1 .158 .958 r
.74713 .52942 m
.74657 .52 L
s
.74657 .52 m
.74716 .52884 L
s
.628 .249 1 r
.61434 .50431 m
.61452 .51269 L
s
.61454 .51266 m
.61434 .50431 L
s
.61434 .50431 m
.61478 .52093 L
s
.638 .247 1 r
.51445 .52588 m
.5145 .5175 L
s
.5145 .5175 m
.51451 .52591 L
s
.766 .217 1 r
.74173 .505 m
.74224 .51374 L
s
.74227 .51371 m
.74173 .505 L
s
.74173 .505 m
.74282 .5222 L
s
.701 .232 1 r
.6646 .51705 m
.66494 .52564 L
s
.66498 .52535 m
.6646 .51705 L
s
.66494 .52564 m
.66462 .51702 L
s
.66462 .51702 m
.66498 .52535 L
s
.928 .181 1 r
.46905 .52032 m
.4689 .52935 L
s
.46896 .52919 m
.46905 .52032 L
s
.777 .214 1 r
.71494 .52975 m
.71491 .53019 L
s
.928 .181 1 r
.4689 .52935 m
.46907 .52028 L
s
.46907 .52028 m
.46896 .52919 L
s
.45 .297 1 r
.53239 .50143 m
.53238 .50942 L
s
.5324 .50938 m
.53239 .50143 L
s
.53239 .50143 m
.53244 .51708 L
s
.418 .307 1 r
.62809 .51156 m
.62832 .51954 L
s
.62836 .51893 m
.62809 .51156 L
s
.56 .267 1 r
.7181 .46797 m
.72049 .50725 L
s
.669 .239 1 r
.44059 .46797 m
.43978 .50937 L
s
.418 .307 1 r
.62832 .51954 m
.62811 .51153 L
s
.62811 .51153 m
.62836 .51893 L
s
.99 .169 1 r
.71904 .50663 m
.71952 .51584 L
s
.71954 .5158 m
.71904 .50663 L
s
.71904 .50663 m
.72007 .52473 L
s
.569 .264 1 r
.35954 .50348 m
.35913 .51172 L
s
.35915 .51168 m
.35954 .50348 L
s
.35954 .50348 m
.35879 .51982 L
s
.722 .227 1 r
.33682 .50494 m
.33633 .51354 L
s
.33634 .5135 m
.33682 .50494 L
s
.33682 .50494 m
.33592 .52199 L
s
.541 .272 1 r
.68252 .50119 m
.68287 .50949 L
s
.68289 .50946 m
.68252 .50119 L
s
.68252 .50119 m
.68327 .51723 L
s
.55 .269 1 r
.71007 .51511 m
.71049 .52331 L
s
.71054 .52313 m
.71007 .51511 L
s
.494 .284 1 r
.45524 .51386 m
.45508 .52195 L
s
.45514 .52166 m
.45524 .51386 L
s
.4 .312 1 r
.59072 .46776 m
.59162 .50562 L
s
.669 .239 1 r
.31317 .46776 m
.31084 .50917 L
s
.55 .269 1 r
.71049 .52331 m
.71009 .51508 L
s
.71009 .51508 m
.71054 .52313 L
s
.485 .287 1 r
.37817 .52587 m
.37811 .52601 L
s
.494 .284 1 r
.45508 .52195 m
.45526 .51383 L
s
.45526 .51383 m
.45514 .52166 L
s
.822 .204 1 r
.4147 .53157 m
.41463 .53172 L
s
.669 .239 1 r
.30999 .5299 m
.30993 .52987 L
s
.468 .292 1 r
.27754 .50095 m
.27695 .509 L
s
.27696 .50897 m
.27754 .50095 L
s
.27754 .50095 m
.27645 .51667 L
s
.7 .232 1 r
.73771 .52935 m
.73767 .52953 L
s
.516 1 .954 r
.74088 .46755 m
.74274 .49516 L
s
.494 .285 1 r
.4633 .46755 m
.46279 .50683 L
s
.991 .169 1 r
.59165 .50675 m
.5918 .51592 L
s
.59182 .51588 m
.59165 .50675 L
s
.59165 .50675 m
.59202 .52488 L
s
.69 .234 1 r
.40978 .51693 m
.40949 .52545 L
s
.40956 .5253 m
.40978 .51693 L
s
.836 .201 1 r
.68738 .51693 m
.68779 .52591 L
s
.68782 .5253 m
.68738 .51693 L
s
.69 .234 1 r
.40949 .52545 m
.4098 .51689 L
s
.4098 .51689 m
.40956 .5253 L
s
.836 .201 1 r
.68779 .52591 m
.6874 .51689 L
s
.6874 .51689 m
.68782 .5253 L
s
.588 .259 1 r
.38222 .50332 m
.38186 .51159 L
s
.38188 .51156 m
.38222 .50332 L
s
.38222 .50332 m
.38157 .51976 L
s
.766 .216 1 r
.61346 .46734 m
.61476 .51018 L
s
.7 .232 1 r
.33585 .46734 m
.33377 .50911 L
s
.723 .226 1 r
.35542 .52804 m
.35534 .52851 L
s
.55 .269 1 r
.50558 .52748 m
.50552 .52745 L
s
1 .154 .934 r
.61921 .52125 m
.61945 .53053 L
s
.61951 .53041 m
.61921 .52125 L
s
.588 .259 1 r
.40495 .50227 m
.40464 .51062 L
s
.40465 .51058 m
.40495 .50227 L
s
.40495 .50227 m
.40441 .51864 L
s
1 .154 .934 r
.61945 .53053 m
.61923 .52121 L
s
.61923 .52121 m
.61951 .53041 L
s
.744 .221 1 r
.33267 .5295 m
.3326 .52972 L
s
.811 .206 1 r
.50967 .50436 m
.50961 .51321 L
s
.50963 .51317 m
.50967 .50436 L
s
.50967 .50436 m
.50962 .52173 L
s
.45 .297 1 r
.76367 .46713 m
.76646 .505 L
s
.36 .325 1 r
.48602 .46713 m
.48578 .50394 L
s
.468 .292 1 r
.50068 .51277 m
.50062 .52078 L
s
.50068 .5205 m
.50068 .51277 L
s
.50062 .52078 m
.5007 .51273 L
s
.5007 .51273 m
.50068 .5205 L
s
.352 .327 1 r
.63622 .46692 m
.63758 .50373 L
s
.733 .224 1 r
.35854 .46692 m
.35672 .50905 L
s
1 .138 .854 r
.76464 .50634 m
.76527 .51587 L
s
.76529 .51583 m
.76464 .50634 L
s
.76464 .50634 m
.76595 .52498 L
s
.559 .267 1 r
.75565 .51458 m
.75618 .52278 L
s
.75623 .52267 m
.75565 .51458 L
s
.75618 .52278 m
.75567 .51454 L
s
.75567 .51454 m
.75623 .52267 L
s
.766 .217 1 r
.30499 .5166 m
.30443 .52534 L
s
.30451 .52505 m
.30499 .5166 L
s
.618 .252 1 r
.70536 .50207 m
.70577 .51049 L
s
.70579 .51046 m
.70536 .50207 L
s
.70536 .50207 m
.70624 .51859 L
s
.467 .292 1 r
.37319 .51284 m
.37284 .52082 L
s
.3729 .52064 m
.37319 .51284 L
s
.559 .267 1 r
.30016 .50145 m
.29961 .50972 L
s
.29962 .50969 m
.30016 .50145 L
s
.30016 .50145 m
.29914 .51768 L
s
.68 .237 1 r
.78646 .46671 m
.78974 .50742 L
s
.531 .274 1 r
.50875 .46671 m
.50876 .506 L
s
.766 .217 1 r
.30443 .52534 m
.30501 .51656 L
s
.30501 .51656 m
.30451 .52505 L
s
.467 .292 1 r
.37284 .52082 m
.37321 .51281 L
s
.37321 .51281 m
.3729 .52064 L
s
.56 .267 1 r
.72811 .50093 m
.72856 .50924 L
s
.72859 .5092 m
.72811 .50093 L
s
.72811 .50093 m
.72907 .51712 L
s
.765 .217 1 r
.5827 .51688 m
.58284 .52558 L
s
.5829 .5254 m
.5827 .51688 L
s
.384 .317 1 r
.79225 .52062 m
.79224 .52118 L
s
.765 .217 1 r
.58284 .52558 m
.58273 .51684 L
s
.58273 .51684 m
.5829 .5254 L
s
.589 .259 1 r
.42356 .52576 m
.42349 .52609 L
s
.57 .264 1 r
.80117 .51264 m
.80183 .52101 L
s
.80184 .52044 m
.80117 .51264 L
s
.367 .322 1 r
.49177 .52208 m
.49171 .52225 L
s
.589 .259 1 r
.65899 .4665 m
.66071 .5058 L
s
.598 .257 1 r
.38124 .4665 m
.37975 .50721 L
s
.57 .264 1 r
.80183 .52101 m
.8012 .5126 L
s
.8012 .5126 m
.80184 .52044 L
s
.822 .204 1 r
.48284 .53036 m
.48278 .53051 L
s
.904 .186 1 r
.55997 .51841 m
.56005 .52741 L
s
.56011 .52722 m
.55997 .51841 L
s
.441 .3 1 r
.39591 .51215 m
.39561 .52006 L
s
.39567 .51988 m
.39591 .51215 L
s
.904 .186 1 r
.56005 .52741 m
.55999 .51838 L
s
.55999 .51838 m
.56011 .52722 L
s
.441 .3 1 r
.39561 .52006 m
.39592 .51212 L
s
.39592 .51212 m
.39567 .51988 L
s
.857 .196 1 r
.43246 .51793 m
.43222 .52681 L
s
.43228 .52666 m
.43246 .51793 L
s
.355 .437 1 r
.8191 .49642 m
.8197 .50393 L
s
.81973 .5039 m
.8191 .49642 L
s
.8191 .49642 m
.82034 .51089 L
s
.857 .196 1 r
.43222 .52681 m
.43248 .51789 L
s
.43248 .51789 m
.43228 .52666 L
s
.448 .828 1 r
.80927 .46629 m
.81195 .49709 L
s
.347 .402 1 r
.53149 .46629 m
.53173 .50417 L
s
.42 .723 1 r
.81013 .50492 m
.81069 .51172 L
s
.81071 .51144 m
.81013 .50492 L
s
.81069 .51172 m
.81015 .50489 L
s
.81015 .50489 m
.81071 .51144 L
s
.955 .176 1 r
.48692 .5075 m
.48679 .51644 L
s
.48682 .5164 m
.48692 .5075 L
s
.48692 .5075 m
.48675 .52569 L
s
.629 .249 1 r
.75091 .50058 m
.75143 .50911 L
s
.75146 .50907 m
.75091 .50058 L
s
.75091 .50058 m
.752 .51707 L
s
.648 .244 1 r
.70134 .52647 m
.7013 .52679 L
s
.711 .229 1 r
.65585 .52904 m
.65579 .52905 L
s
.811 .206 1 r
.47794 .51599 m
.47781 .52487 L
s
.47788 .52444 m
.47794 .51599 L
s
.433 .302 1 r
.62338 .50017 m
.62358 .50806 L
s
.6236 .50802 m
.62338 .50017 L
s
.62338 .50017 m
.62384 .5158 L
s
.711 .229 1 r
.68177 .46608 m
.68385 .50751 L
s
.777 .214 1 r
.40396 .46608 m
.40269 .50822 L
s
.811 .206 1 r
.47781 .52487 m
.47796 .51595 L
s
.47796 .51595 m
.47788 .52444 L
s
.679 .237 1 r
.42762 .50344 m
.42735 .5119 L
s
.42737 .51186 m
.42762 .50344 L
s
.42762 .50344 m
.42717 .52036 L
s
.87 .194 1 r
.60548 .51675 m
.60568 .52575 L
s
.60573 .52534 m
.60548 .51675 L
s
.60568 .52575 m
.6055 .51671 L
s
.6055 .51671 m
.60573 .52534 L
s
.416 .307 1 r
.29108 .51126 m
.29054 .5191 L
s
.29061 .51892 m
.29108 .51126 L
s
.29054 .5191 m
.29109 .51122 L
s
.29109 .51122 m
.29061 .51892 L
s
.68 .237 1 r
.60066 .50187 m
.60081 .51044 L
s
.60084 .5104 m
.60066 .50187 L
s
.60066 .50187 m
.60104 .51868 L
s
.858 .196 1 r
.83209 .46587 m
.83607 .50837 L
s
.531 .274 1 r
.55424 .46587 m
.55476 .50482 L
s
.425 .304 1 r
.27639 .46587 m
.27388 .5034 L
s
.46 .294 1 r
.34146 .52405 m
.3414 .52409 L
s
.904 .186 1 r
.55517 .50452 m
.55522 .51352 L
s
.55524 .51348 m
.55517 .50452 L
s
.55517 .50452 m
.55534 .52233 L
s
.7 .232 1 r
.45035 .50264 m
.45015 .51121 L
s
.45016 .51117 m
.45035 .50264 L
s
.45035 .50264 m
.45002 .5196 L
s
.37 .507 1 r
.71439 .49569 m
.71477 .50303 L
s
.71478 .503 m
.71439 .49569 L
s
.71439 .49569 m
.71518 .50992 L
s
.857 .196 1 r
.32762 .51732 m
.32711 .5262 L
s
.32718 .52605 m
.32762 .51732 L
s
.754 .219 1 r
.35037 .51606 m
.34992 .52473 L
s
.34999 .52459 m
.35037 .51606 L
s
.486 .287 1 r
.79647 .49903 m
.79708 .50716 L
s
.7971 .50712 m
.79647 .49903 L
s
.79647 .49903 m
.79772 .51483 L
s
.857 .196 1 r
.32711 .5262 m
.32764 .51728 L
s
.32764 .51728 m
.32718 .52605 L
s
.754 .219 1 r
.34992 .52473 m
.35038 .51603 L
s
.35038 .51603 m
.34999 .52459 L
s
.658 .242 1 r
.32278 .50226 m
.32227 .51072 L
s
.32229 .51069 m
.32278 .50226 L
s
.32278 .50226 m
.32184 .51904 L
s
1 .161 .972 r
.70456 .46566 m
.70713 .51101 L
s
.459 .295 1 r
.42668 .46566 m
.42576 .50461 L
s
.355 .437 1 r
.65993 .50681 m
.66022 .51432 L
s
.66024 .51376 m
.65993 .50681 L
s
.66022 .51432 m
.65995 .50678 L
s
.65995 .50678 m
.66024 .51376 L
s
.765 .217 1 r
.57792 .5039 m
.57802 .51254 L
s
.57804 .5125 m
.57792 .5039 L
s
.57792 .5039 m
.5782 .52122 L
s
.494 .284 1 r
.36826 .50014 m
.36788 .50821 L
s
.36789 .50817 m
.36826 .50014 L
s
.36826 .50014 m
.36757 .5161 L
s
.45 .297 1 r
.53727 .52162 m
.53721 .52205 L
s
.618 .252 1 r
.69652 .51287 m
.69693 .52132 L
s
.69696 .52089 m
.69652 .51287 L
s
.503 .282 1 r
.85492 .46545 m
.85882 .5044 L
s
.618 .252 1 r
.577 .46545 m
.57781 .50582 L
s
.868 .194 1 r
.29909 .46545 m
.29645 .50902 L
s
.618 .252 1 r
.69693 .52132 m
.69654 .51283 L
s
.69654 .51283 m
.69696 .52089 L
s
.578 .262 1 r
.31866 .52622 m
.31861 .52618 L
s
.788 .212 1 r
.55108 .52879 m
.55103 .52894 L
s
.777 .214 1 r
.4731 .5023 m
.47294 .51108 L
s
.47296 .51104 m
.4731 .5023 L
s
.4731 .5023 m
.47286 .51954 L
s
.441 .3 1 r
.38692 .52253 m
.38686 .52271 L
s
.846 .199 1 r
.65102 .51566 m
.65134 .52461 L
s
.65138 .52418 m
.65102 .51566 L
s
.65134 .52461 m
.65105 .51562 L
s
.65105 .51562 m
.65138 .52418 L
s
.892 .189 1 r
.52833 .53026 m
.52827 .53041 L
s
.846 .199 1 r
.52343 .51517 m
.52342 .52416 L
s
.52348 .52362 m
.52343 .51517 L
s
.811 .206 1 r
.72737 .46524 m
.73004 .50739 L
s
.337 .353 1 r
.44941 .46524 m
.44879 .50171 L
s
.846 .199 1 r
.52342 .52416 m
.52345 .51514 L
s
.52345 .51514 m
.52348 .52362 L
s
.658 .242 1 r
.5966 .52657 m
.59655 .52672 L
s
.789 .211 1 r
.57385 .52803 m
.5738 .52829 L
s
.393 .314 1 r
.59978 .46503 m
.60075 .5015 L
s
.799 .209 1 r
.32179 .46503 m
.31948 .50789 L
s
.743 .222 1 r
.29585 .52839 m
.29579 .52839 L
s
.881 .191 1 r
.77385 .50189 m
.77446 .51096 L
s
.77449 .51092 m
.77385 .50189 L
s
.77385 .50189 m
.77513 .51949 L
s
.618 .252 1 r
.36413 .5247 m
.36406 .52502 L
s
1 .123 .772 r
.73317 .51978 m
.73373 .52942 L
s
.73378 .52909 m
.73317 .51978 L
s
.916 .184 1 r
.77868 .51727 m
.77933 .52627 L
s
.77938 .52615 m
.77868 .51727 L
s
.823 .204 1 r
.5462 .51476 m
.54624 .52368 L
s
.5463 .52321 m
.5462 .51476 L
s
1 .123 .772 r
.73373 .52942 m
.73319 .51974 L
s
.73319 .51974 m
.73378 .52909 L
s
.916 .184 1 r
.77933 .52627 m
.77871 .51723 L
s
.77871 .51723 m
.77938 .52615 L
s
.608 .254 1 r
.66899 .50026 m
.66931 .50865 L
s
.66933 .50861 m
.66899 .50026 L
s
.66899 .50026 m
.66969 .51675 L
s
.375 .532 1 r
.75018 .46482 m
.75263 .49988 L
s
.569 .264 1 r
.47216 .46482 m
.47174 .5052 L
s
.823 .204 1 r
.54624 .52368 m
.54622 .51472 L
s
.54622 .51472 m
.5463 .52321 L
s
.559 .267 1 r
.46408 .51177 m
.46393 .52004 L
s
.46399 .51972 m
.46408 .51177 L
s
.822 .204 1 r
.34545 .5029 m
.34497 .51172 L
s
.34498 .51169 m
.34545 .5029 L
s
.34545 .5029 m
.34457 .5204 L
s
.648 .244 1 r
.64215 .52505 m
.64211 .52538 L
s
.559 .267 1 r
.46393 .52004 m
.4641 .51173 L
s
.4641 .51173 m
.46399 .51972 L
s
.441 .3 1 r
.282 .52192 m
.28193 .5221 L
s
.658 .242 1 r
.56896 .51379 m
.56906 .52225 L
s
.56911 .5221 m
.56896 .51379 L
s
.56906 .52225 m
.56898 .51376 L
s
.56898 .51376 m
.56911 .5221 L
s
.701 .232 1 r
.41855 .51456 m
.41828 .52309 L
s
.41834 .52301 m
.41855 .51456 L
s
.433 .302 1 r
.78766 .50955 m
.78825 .5175 L
s
.78828 .51714 m
.78766 .50955 L
s
.701 .232 1 r
.41828 .52309 m
.41857 .51452 L
s
.41857 .51452 m
.41834 .52301 L
s
.777 .214 1 r
.62256 .46461 m
.62396 .50677 L
s
.503 .282 1 r
.34451 .46461 m
.34263 .50428 L
s
.433 .302 1 r
.78825 .5175 m
.78768 .50951 L
s
.78768 .50951 m
.78828 .51714 L
s
.868 .194 1 r
.67385 .51609 m
.67423 .52502 L
s
.67428 .52483 m
.67385 .51609 L
s
.67423 .52502 m
.67387 .51606 L
s
.67387 .51606 m
.67428 .52483 L
s
.799 .209 1 r
.64626 .50224 m
.64654 .51103 L
s
.64656 .51099 m
.64626 .50224 L
s
.64626 .50224 m
.64689 .51964 L
s
.953 .176 1 r
.49584 .50294 m
.49574 .51208 L
s
.49576 .51204 m
.49584 .50294 L
s
.49584 .50294 m
.49572 .5209 L
s
.811 .206 1 r
.51861 .50169 m
.51856 .51054 L
s
.51858 .51051 m
.51861 .50169 L
s
.51861 .50169 m
.5186 .51908 L
s
.377 .542 1 r
.773 .4644 m
.77561 .4984 L
s
.384 .317 1 r
.49492 .4644 m
.49477 .50159 L
s
.977 .171 1 r
.67877 .53147 m
.67871 .53145 L
s
.712 .229 1 r
.39094 .50116 m
.39059 .50977 L
s
.3906 .50973 m
.39094 .50116 L
s
.39094 .50116 m
.39031 .51816 L
s
.352 .327 1 r
.58689 .49804 m
.587 .50564 L
s
.58702 .50561 m
.58689 .49804 L
s
.58689 .49804 m
.58718 .51325 L
s
.418 .307 1 r
.62836 .51893 m
.62832 .51954 L
s
.669 .239 1 r
.31363 .51338 m
.31311 .52187 L
s
.31318 .52169 m
.31363 .51338 L
s
.56 .267 1 r
.63728 .51088 m
.63754 .51918 L
s
.63758 .51876 m
.63728 .51088 L
s
.811 .206 1 r
.76986 .52667 m
.76983 .5271 L
s
.669 .239 1 r
.31311 .52187 m
.31365 .51335 L
s
.31365 .51335 m
.31318 .52169 L
s
.56 .267 1 r
.63754 .51918 m
.6373 .51084 L
s
.6373 .51084 m
.63758 .51876 L
s
.834 .201 1 r
.64536 .46419 m
.64706 .50707 L
s
.494 .284 1 r
.36724 .46419 m
.36565 .50316 L
s
.765 .217 1 r
.44129 .51443 m
.44108 .52314 L
s
.44114 .52296 m
.44129 .51443 L
s
.45 .297 1 r
.53238 .50942 m
.53239 .5174 L
s
.53244 .51708 m
.53238 .50942 L
s
.765 .217 1 r
.44108 .52314 m
.44131 .51439 L
s
.44131 .51439 m
.44114 .52296 L
s
.45 .297 1 r
.53239 .5174 m
.5324 .50938 L
s
.5324 .50938 m
.53244 .51708 L
s
.638 .247 1 r
.51451 .52591 m
.51445 .52588 L
s
.628 .249 1 r
.61452 .51269 m
.61473 .52108 L
s
.61478 .52093 m
.61452 .51269 L
s
.733 .224 1 r
.69184 .50069 m
.69223 .50936 L
s
.69225 .50933 m
.69184 .50069 L
s
.69184 .50069 m
.69268 .51776 L
s
.425 .305 1 r
.79584 .46398 m
.79896 .50153 L
s
.701 .232 1 r
.66498 .52535 m
.66494 .52564 L
s
.68 .237 1 r
.51768 .46398 m
.5178 .50508 L
s
.628 .249 1 r
.61473 .52108 m
.61454 .51266 L
s
.61454 .51266 m
.61478 .52093 L
s
.494 .284 1 r
.45514 .52166 m
.45508 .52195 L
s
.777 .214 1 r
.41369 .50086 m
.41338 .50964 L
s
.4134 .50961 m
.41369 .50086 L
s
.41369 .50086 m
.41316 .51811 L
s
.569 .264 1 r
.35913 .51172 m
.35873 .51996 L
s
.35879 .51982 m
.35913 .51172 L
s
.35873 .51996 m
.35915 .51168 L
s
.35915 .51168 m
.35879 .51982 L
s
.55 .269 1 r
.71054 .52313 m
.71049 .52331 L
s
1 .158 .958 r
.74716 .52884 m
.74713 .52942 L
s
.766 .217 1 r
.74224 .51374 m
.74278 .52249 L
s
.74282 .5222 m
.74224 .51374 L
s
.88 .191 1 r
.54139 .5017 m
.5414 .5107 L
s
.54142 .51066 m
.54139 .5017 L
s
.54139 .5017 m
.54149 .51938 L
s
.722 .227 1 r
.66817 .46377 m
.67011 .50594 L
s
.578 .262 1 r
.38998 .46377 m
.38857 .50487 L
s
.766 .217 1 r
.74278 .52249 m
.74227 .51371 L
s
.74227 .51371 m
.74282 .5222 L
s
.919 .183 1 r
.56417 .50054 m
.56424 .50972 L
s
.56426 .50968 m
.56417 .50054 L
s
.56417 .50054 m
.56439 .51826 L
s
.578 .262 1 r
.30873 .49933 m
.3082 .50762 L
s
.30821 .50758 m
.30873 .49933 L
s
.30873 .49933 m
.30774 .51572 L
s
.541 .272 1 r
.68287 .50949 m
.68324 .5178 L
s
.68327 .51723 m
.68287 .50949 L
s
.68324 .5178 m
.68289 .50946 L
s
.68289 .50946 m
.68327 .51723 L
s
.928 .181 1 r
.46896 .52919 m
.4689 .52935 L
s
.468 .292 1 r
.27695 .509 m
.27637 .51706 L
s
.27645 .51667 m
.27695 .509 L
s
.733 .224 1 r
.28595 .50079 m
.28533 .50944 L
s
.28535 .5094 m
.28595 .50079 L
s
.28595 .50079 m
.2848 .5179 L
s
.468 .292 1 r
.27637 .51706 m
.27696 .50897 L
s
.27696 .50897 m
.27645 .51667 L
s
.722 .227 1 r
.33633 .51354 m
.33585 .52214 L
s
.33592 .52199 m
.33633 .51354 L
s
.38 .554 1 r
.81869 .46356 m
.82177 .49792 L
s
.744 .221 1 r
.54046 .46356 m
.54085 .50537 L
s
.69 .234 1 r
.26224 .46356 m
.25926 .50537 L
s
.722 .227 1 r
.33585 .52214 m
.33634 .5135 L
s
.33634 .5135 m
.33592 .52199 L
s
.648 .244 1 r
.45922 .4992 m
.45903 .50769 L
s
.45905 .50766 m
.45922 .4992 L
s
.45922 .4992 m
.45892 .51587 L
s
.99 .169 1 r
.71952 .51584 m
.72003 .52506 L
s
.72007 .52473 m
.71952 .51584 L
s
.69 .234 1 r
.40956 .5253 m
.40949 .52545 L
s
.836 .201 1 r
.68782 .5253 m
.68779 .52591 L
s
.456 .855 1 r
.76917 .48991 m
.76961 .49643 L
s
.76963 .49641 m
.76917 .48991 L
s
.76917 .48991 m
.77008 .50254 L
s
.99 .169 1 r
.72003 .52506 m
.71954 .5158 L
s
.71954 .5158 m
.72007 .52473 L
s
.403 .652 1 r
.69099 .46335 m
.69275 .49665 L
s
.512 .279 1 r
.41273 .46335 m
.41163 .50303 L
s
.588 .259 1 r
.38186 .51159 m
.38151 .51987 L
s
.38157 .51976 m
.38186 .51159 L
s
.38151 .51987 m
.38188 .51156 L
s
.38188 .51156 m
.38157 .51976 L
s
.468 .292 1 r
.50068 .5205 m
.50062 .52078 L
s
.531 .274 1 r
.60973 .4991 m
.6099 .5072 L
s
.60992 .50717 m
.60973 .4991 L
s
.60973 .4991 m
.61015 .51531 L
s
.588 .259 1 r
.40464 .51062 m
.40434 .51897 L
s
.40441 .51864 m
.40464 .51062 L
s
.953 .176 1 r
.84155 .46314 m
.84575 .50674 L
s
.669 .239 1 r
.56325 .46314 m
.56391 .50425 L
s
.722 .227 1 r
.28496 .46314 m
.28224 .50531 L
s
.588 .259 1 r
.40434 .51897 m
.40465 .51058 L
s
.40465 .51058 m
.40441 .51864 L
s
.991 .169 1 r
.5918 .51592 m
.59197 .52511 L
s
.59202 .52488 m
.5918 .51592 L
s
.42 .723 1 r
.81071 .51144 m
.81069 .51172 L
s
.991 .169 1 r
.59197 .52511 m
.59182 .51588 L
s
.59182 .51588 m
.59202 .52488 L
s
.55 .269 1 r
.35422 .4983 m
.35379 .50651 L
s
.3538 .50648 m
.35422 .4983 L
s
.35422 .4983 m
.35344 .51455 L
s
.658 .242 1 r
.33143 .49959 m
.33094 .50805 L
s
.33095 .50802 m
.33143 .49959 L
s
.33143 .49959 m
.33052 .51638 L
s
.344 .33 1 r
.39978 .49579 m
.39948 .50343 L
s
.3995 .5034 m
.39978 .49579 L
s
.39978 .49579 m
.39926 .5109 L
s
.55 .269 1 r
.78309 .49778 m
.78367 .50603 L
s
.7837 .50599 m
.78309 .49778 L
s
.78309 .49778 m
.78431 .51399 L
s
.966 .173 1 r
.71382 .46293 m
.71641 .50653 L
s
.569 .264 1 r
.43549 .46293 m
.43464 .50333 L
s
.531 .274 1 r
.50477 .49785 m
.50469 .50603 L
s
.50471 .50599 m
.50477 .49785 L
s
.50477 .49785 m
.50469 .51399 L
s
.467 .292 1 r
.3729 .52064 m
.37284 .52082 L
s
.811 .206 1 r
.50961 .51321 m
.50956 .52206 L
s
.50962 .52173 m
.50961 .51321 L
s
.559 .267 1 r
.75623 .52267 m
.75618 .52278 L
s
.811 .206 1 r
.50956 .52206 m
.50963 .51317 L
s
.50963 .51317 m
.50962 .52173 L
s
1 .154 .934 r
.61951 .53041 m
.61945 .53053 L
s
.932 .18 1 r
.86442 .46272 m
.86877 .5049 L
s
.559 .267 1 r
.58606 .46272 m
.58695 .50241 L
s
.628 .249 1 r
.3077 .46272 m
.30531 .50383 L
s
.355 .437 1 r
.8197 .50393 m
.82034 .51145 L
s
.82034 .51089 m
.8197 .50393 L
s
.57 .264 1 r
.80592 .49697 m
.80657 .50533 L
s
.80659 .5053 m
.80592 .49697 L
s
.80592 .49697 m
.80726 .51322 L
s
.868 .194 1 r
.4364 .50206 m
.43615 .51093 L
s
.43617 .51089 m
.4364 .50206 L
s
.4364 .50206 m
.43597 .51983 L
s
.355 .437 1 r
.82034 .51145 m
.81973 .5039 L
s
.81973 .5039 m
.82034 .51089 L
s
.559 .267 1 r
.29961 .50972 m
.29906 .518 L
s
.29914 .51768 m
.29961 .50972 L
s
.57 .264 1 r
.80184 .52044 m
.80183 .52101 L
s
.559 .267 1 r
.29906 .518 m
.29962 .50969 L
s
.29962 .50969 m
.29914 .51768 L
s
.441 .3 1 r
.39567 .51988 m
.39561 .52006 L
s
.618 .252 1 r
.70577 .51049 m
.7062 .51891 L
s
.70624 .51859 m
.70577 .51049 L
s
.56 .267 1 r
.72856 .50924 m
.72904 .51755 L
s
.72907 .51712 m
.72856 .50924 L
s
.766 .217 1 r
.30451 .52505 m
.30443 .52534 L
s
.669 .239 1 r
.63256 .49914 m
.6328 .50764 L
s
.63282 .5076 m
.63256 .49914 L
s
.63256 .49914 m
.63311 .51597 L
s
.618 .252 1 r
.7062 .51891 m
.70579 .51046 L
s
.70579 .51046 m
.70624 .51859 L
s
.56 .267 1 r
.72904 .51755 m
.72859 .5092 L
s
.72859 .5092 m
.72907 .51712 L
s
.335 .34 1 r
.72372 .49409 m
.72414 .50176 L
s
.72416 .50173 m
.72372 .49409 L
s
.72372 .49409 m
.7246 .50901 L
s
.346 .329 1 r
.73666 .46251 m
.73901 .49794 L
s
1 .126 .786 r
.45826 .46251 m
.45758 .50932 L
s
.765 .217 1 r
.5829 .5254 m
.58284 .52558 L
s
.367 .322 1 r
.27192 .49643 m
.27135 .50407 L
s
.27136 .50404 m
.27192 .49643 L
s
.27192 .49643 m
.27083 .51175 L
s
.58 .262 1 r
.37695 .49841 m
.37657 .50667 L
s
.37659 .50663 m
.37695 .49841 L
s
.37695 .49841 m
.37627 .51485 L
s
.64 .246 1 r
.60887 .4623 m
.61003 .50199 L
s
.916 .184 1 r
.33044 .4623 m
.3282 .5059 L
s
.965 .174 1 r
.73762 .50168 m
.73814 .5108 L
s
.73817 .51076 m
.73762 .50168 L
s
.73762 .50168 m
.73874 .51977 L
s
.433 .302 1 r
.62358 .50806 m
.62379 .51594 L
s
.62384 .5158 m
.62358 .50806 L
s
.916 .184 1 r
.48198 .50046 m
.48184 .50954 L
s
.48186 .5095 m
.48198 .50046 L
s
.48198 .50046 m
.48178 .5183 L
s
.37 .507 1 r
.71477 .50303 m
.71516 .51038 L
s
.71518 .50992 m
.71477 .50303 L
s
.355 .437 1 r
.66024 .51376 m
.66022 .51432 L
s
.433 .302 1 r
.62379 .51594 m
.6236 .50802 L
s
.6236 .50802 m
.62384 .5158 L
s
.37 .507 1 r
.71516 .51038 m
.71478 .503 L
s
.71478 .503 m
.71518 .50992 L
s
.416 .307 1 r
.29061 .51892 m
.29054 .5191 L
s
1 .138 .854 r
.76527 .51587 m
.76592 .52542 L
s
.76595 .52498 m
.76527 .51587 L
s
.904 .186 1 r
.56011 .52722 m
.56005 .52741 L
s
.857 .196 1 r
.43228 .52666 m
.43222 .52681 L
s
1 .138 .854 r
.76592 .52542 m
.76529 .51583 L
s
.76529 .51583 m
.76595 .52498 L
s
.485 .287 1 r
.75951 .46209 m
.76243 .5025 L
s
.608 .254 1 r
.48105 .46209 m
.48073 .5025 L
s
.629 .249 1 r
.75143 .50911 m
.75198 .51764 L
s
.752 .51707 m
.75143 .50911 L
s
.391 .315 1 r
.42251 .49643 m
.42226 .50415 L
s
.42228 .50412 m
.42251 .49643 L
s
.42251 .49643 m
.42208 .5119 L
s
.777 .214 1 r
.65541 .499 m
.65571 .50779 L
s
.65573 .50776 m
.65541 .499 L
s
.65541 .499 m
.65607 .51626 L
s
.977 .171 1 r
.76045 .50092 m
.76104 .51011 L
s
.76106 .51007 m
.76045 .50092 L
s
.76045 .50092 m
.76169 .51901 L
s
.649 .244 1 r
.6782 .49775 m
.67855 .50625 L
s
.67857 .50622 m
.6782 .49775 L
s
.6782 .49775 m
.67896 .51444 L
s
.629 .249 1 r
.75198 .51764 m
.75146 .50907 L
s
.75146 .50907 m
.752 .51707 L
s
.811 .206 1 r
.47788 .52444 m
.47781 .52487 L
s
.679 .237 1 r
.42735 .5119 m
.42711 .52036 L
s
.42717 .52036 m
.42735 .5119 L
s
.416 .307 1 r
.63169 .46188 m
.63305 .4998 L
s
.503 .282 1 r
.3532 .46187 m
.35145 .50087 L
s
.679 .237 1 r
.42711 .52036 m
.42737 .51186 L
s
.42737 .51186 m
.42717 .52036 L
s
.955 .176 1 r
.48679 .51644 m
.48669 .52538 L
s
.48675 .52569 m
.48679 .51644 L
s
.48669 .52538 m
.48682 .5164 L
s
.48682 .5164 m
.48675 .52569 L
s
.87 .194 1 r
.60573 .52534 m
.60568 .52575 L
s
.486 .287 1 r
.79708 .50716 m
.79771 .51529 L
s
.79772 .51483 m
.79708 .50716 L
s
.79771 .51529 m
.7971 .50712 L
s
.7971 .50712 m
.79772 .51483 L
s
.723 .226 1 r
.70104 .49709 m
.70145 .50584 L
s
.70148 .50581 m
.70104 .49709 L
s
.70104 .49709 m
.70192 .51403 L
s
.68 .237 1 r
.60081 .51044 m
.60099 .51901 L
s
.60104 .51868 m
.60081 .51044 L
s
.342 .378 1 r
.78237 .46166 m
.78521 .49746 L
s
.857 .196 1 r
.50384 .46166 m
.50378 .50528 L
s
.68 .237 1 r
.60099 .51901 m
.60084 .5104 L
s
.60084 .5104 m
.60104 .51868 L
s
.7 .232 1 r
.45015 .51121 m
.44995 .51978 L
s
.45002 .5196 m
.45015 .51121 L
s
.44995 .51978 m
.45016 .51117 L
s
.45016 .51117 m
.45002 .5196 L
s
.754 .219 1 r
.34999 .52459 m
.34992 .52473 L
s
.658 .242 1 r
.32227 .51072 m
.32177 .51919 L
s
.32184 .51904 m
.32227 .51072 L
s
.494 .284 1 r
.36788 .50821 m
.36751 .51628 L
s
.36757 .5161 m
.36788 .50821 L
s
.658 .242 1 r
.32177 .51919 m
.32229 .51069 L
s
.32229 .51069 m
.32184 .51904 L
s
.618 .252 1 r
.69696 .52089 m
.69693 .52132 L
s
.494 .284 1 r
.36751 .51628 m
.36789 .50817 L
s
.36789 .50817 m
.36757 .5161 L
s
.54 .272 1 r
.29462 .49689 m
.29405 .50507 L
s
.29407 .50504 m
.29462 .49689 L
s
.29462 .49689 m
.29357 .51311 L
s
.857 .196 1 r
.32718 .52605 m
.32711 .5262 L
s
.383 .317 1 r
.65453 .46145 m
.65617 .50045 L
s
.45 .297 1 r
.37596 .46145 m
.3745 .49974 L
s
.904 .186 1 r
.55522 .51352 m
.55529 .52252 L
s
.55534 .52233 m
.55522 .51352 L
s
.55529 .52252 m
.55524 .51348 L
s
.55524 .51348 m
.55534 .52233 L
s
.777 .214 1 r
.55038 .49839 m
.55042 .50718 L
s
.55044 .50714 m
.55038 .49839 L
s
.55038 .49839 m
.55053 .51565 L
s
.765 .217 1 r
.57802 .51254 m
.57815 .52119 L
s
.5782 .52122 m
.57802 .51254 L
s
.57815 .52119 m
.57804 .5125 L
s
.57804 .5125 m
.5782 .52122 L
s
.531 .274 1 r
.80525 .46124 m
.8086 .50024 L
s
.67 .239 1 r
.52665 .46124 m
.52687 .50202 L
s
.846 .199 1 r
.65138 .52418 m
.65134 .52461 L
s
.52348 .52362 m
.52342 .52416 L
s
.682 .236 1 r
.74673 .49577 m
.74725 .50445 L
s
.74727 .50442 m
.74673 .49577 L
s
.74673 .49577 m
.74781 .51249 L
s
.777 .214 1 r
.47294 .51108 m
.4728 .51987 L
s
.47286 .51954 m
.47294 .51108 L
s
.88 .191 1 r
.67737 .46103 m
.67949 .5043 L
s
.94 .179 1 r
.39874 .46103 m
.39733 .50537 L
s
.777 .214 1 r
.4728 .51987 m
.47296 .51104 L
s
.47296 .51104 m
.47286 .51954 L
s
.379 .548 1 r
.71006 .49022 m
.71042 .49751 L
s
.71044 .49748 m
.71006 .49022 L
s
.71006 .49022 m
.71083 .50427 L
s
.512 .279 1 r
.31737 .49658 m
.31686 .50466 L
s
.31688 .50462 m
.31737 .49658 L
s
.31737 .49658 m
.31643 .5127 L
s
.81 .206 1 r
.82903 .49923 m
.82976 .50803 L
s
.82979 .50799 m
.82903 .49923 L
s
.82903 .49923 m
.83058 .51671 L
s
.459 .295 1 r
.34017 .49543 m
.33973 .5034 L
s
.33974 .50337 m
.34017 .49543 L
s
.34017 .49543 m
.33936 .51123 L
s
.433 .302 1 r
.78828 .51714 m
.78825 .5175 L
s
.559 .267 1 r
.46399 .51972 m
.46393 .52004 L
s
.767 .216 1 r
.59602 .49696 m
.59617 .50579 L
s
.5962 .50575 m
.59602 .49696 L
s
.59602 .49696 m
.59639 .51412 L
s
.99 .169 1 r
.82813 .46082 m
.8322 .50481 L
s
.503 .282 1 r
.54947 .46082 m
.54993 .49982 L
s
.711 .229 1 r
.2708 .46082 m
.2679 .50302 L
s
1 .136 .841 r
.52759 .50087 m
.52756 .51042 L
s
.52759 .51038 m
.52759 .50087 L
s
.52759 .50087 m
.52763 .51961 L
s
.34 .331 1 r
.83802 .49134 m
.8387 .49913 L
s
.83872 .4991 m
.83802 .49134 L
s
.83802 .49134 m
.83938 .50624 L
s
.352 .327 1 r
.8152 .49265 m
.81582 .50039 L
s
.81584 .50036 m
.8152 .49265 L
s
.8152 .49265 m
.81648 .50772 L
s
.608 .254 1 r
.66931 .50865 m
.66965 .51704 L
s
.66969 .51675 m
.66931 .50865 L
s
.823 .204 1 r
.5463 .52321 m
.54624 .52368 L
s
.608 .254 1 r
.66965 .51704 m
.66933 .50861 L
s
.66933 .50861 m
.66969 .51675 L
s
.559 .267 1 r
.4909 .49547 m
.4908 .50376 L
s
.49081 .50372 m
.4909 .49547 L
s
.4909 .49547 m
.49076 .51173 L
s
.352 .327 1 r
.587 .50564 m
.58713 .51324 L
s
.58718 .51325 m
.587 .50564 L
s
.801 .208 1 r
.61885 .49613 m
.61907 .50509 L
s
.61909 .50506 m
.61885 .49613 L
s
.61885 .49613 m
.61934 .51335 L
s
.788 .211 1 r
.70023 .46061 m
.70257 .50282 L
s
.598 .257 1 r
.42153 .46061 m
.4205 .50139 L
s
.658 .242 1 r
.56911 .5221 m
.56906 .52225 L
s
.352 .327 1 r
.58713 .51324 m
.58702 .50561 L
s
.58702 .50561 m
.58718 .51325 L
s
.881 .191 1 r
.77446 .51096 m
.77511 .52003 L
s
.77513 .51949 m
.77446 .51096 L
s
.4 .64 1 r
.75575 .48874 m
.7562 .49584 L
s
.75622 .49581 m
.75575 .48874 L
s
.75575 .48874 m
.75667 .50238 L
s
.916 .184 1 r
.77938 .52615 m
.77933 .52627 L
s
.701 .232 1 r
.41834 .52301 m
.41828 .52309 L
s
.881 .191 1 r
.77511 .52003 m
.77449 .51092 L
s
.77449 .51092 m
.77513 .51949 L
s
.822 .204 1 r
.34497 .51172 m
.3445 .52055 L
s
.34457 .5204 m
.34497 .51172 L
s
.953 .176 1 r
.57322 .49902 m
.57332 .50818 L
s
.57334 .50814 m
.57322 .49902 L
s
.57322 .49902 m
.5735 .51701 L
s
.822 .204 1 r
.3445 .52055 m
.34498 .51169 L
s
.34498 .51169 m
.34457 .5204 L
s
.881 .191 1 r
.85103 .4604 m
.85529 .50332 L
s
.648 .244 1 r
.5723 .4604 m
.57305 .50118 L
s
.628 .249 1 r
.29356 .4604 m
.291 .50154 L
s
.56 .267 1 r
.63758 .51876 m
.63754 .51918 L
s
1 .123 .772 r
.73378 .52909 m
.73373 .52942 L
s
.45 .297 1 r
.53244 .51708 m
.53239 .5174 L
s
.868 .194 1 r
.67428 .52483 m
.67423 .52502 L
s
.857 .196 1 r
.7231 .46019 m
.72577 .50311 L
s
.54 .272 1 r
.44433 .46019 m
.44359 .50026 L
s
.669 .239 1 r
.31318 .52169 m
.31311 .52187 L
s
.456 .855 1 r
.76961 .49643 m
.77007 .50295 L
s
.77008 .50254 m
.76961 .49643 L
s
.799 .209 1 r
.64654 .51103 m
.64684 .51982 L
s
.64689 .51964 m
.64654 .51103 L
s
.712 .229 1 r
.39059 .50977 m
.39025 .51838 L
s
.39031 .51816 m
.39059 .50977 L
s
.456 .855 1 r
.77007 .50295 m
.76963 .49641 L
s
.76963 .49641 m
.77008 .50254 L
s
.799 .209 1 r
.64684 .51982 m
.64656 .51099 L
s
.64656 .51099 m
.64689 .51964 L
s
.459 .295 1 r
.66451 .4946 m
.66481 .50257 L
s
.66483 .50254 m
.66451 .4946 L
s
.66451 .4946 m
.66517 .5104 L
s
.712 .229 1 r
.39025 .51838 m
.3906 .50973 L
s
.3906 .50973 m
.39031 .51816 L
s
.811 .206 1 r
.51856 .51054 m
.51854 .51941 L
s
.5186 .51908 m
.51856 .51054 L
s
.51854 .51941 m
.51858 .51051 L
s
.51858 .51051 m
.5186 .51908 L
s
.588 .259 1 r
.3629 .4961 m
.36249 .5044 L
s
.36251 .50436 m
.3629 .4961 L
s
.3629 .4961 m
.36216 .51259 L
s
.618 .252 1 r
.79252 .49547 m
.79314 .50391 L
s
.79316 .50387 m
.79252 .49547 L
s
.79252 .49547 m
.79381 .51202 L
s
1 .153 .933 r
.87394 .45998 m
.87867 .50468 L
s
.35 .415 1 r
.59514 .45997 m
.59604 .49579 L
s
.788 .212 1 r
.31633 .45997 m
.31395 .5029 L
s
.953 .176 1 r
.49574 .51208 m
.49566 .52124 L
s
.49572 .5209 m
.49574 .51208 L
s
.868 .194 1 r
.44524 .49938 m
.44501 .50825 L
s
.44503 .50822 m
.44524 .49938 L
s
.44524 .49938 m
.44486 .51716 L
s
.628 .249 1 r
.61478 .52093 m
.61473 .52108 L
s
.953 .176 1 r
.49566 .52124 m
.49576 .51204 L
s
.49576 .51204 m
.49572 .5209 L
s
.916 .184 1 r
.46807 .49819 m
.4679 .50728 L
s
.46792 .50724 m
.46807 .49819 L
s
.46807 .49819 m
.46781 .51604 L
s
.541 .272 1 r
.68327 .51723 m
.68324 .5178 L
s
.765 .217 1 r
.44114 .52296 m
.44108 .52314 L
s
.569 .264 1 r
.35879 .51982 m
.35873 .51996 L
s
.468 .292 1 r
.27645 .51667 m
.27637 .51706 L
s
.55 .269 1 r
.74598 .45976 m
.74871 .49949 L
s
.391 .315 1 r
.46714 .45976 m
.46669 .49736 L
s
.629 .249 1 r
.53655 .49471 m
.53655 .50321 L
s
.53657 .50318 m
.53655 .49471 L
s
.53655 .49471 m
.53663 .51126 L
s
.733 .224 1 r
.69223 .50936 m
.69264 .51805 L
s
.69268 .51776 m
.69223 .50936 L
s
.69264 .51805 m
.69225 .50933 L
s
.69225 .50933 m
.69268 .51776 L
s
.578 .262 1 r
.3082 .50762 m
.30767 .5159 L
s
.30774 .51572 m
.3082 .50762 L
s
.766 .217 1 r
.74282 .5222 m
.74278 .52249 L
s
.578 .262 1 r
.30767 .5159 m
.30821 .50758 L
s
.30821 .50758 m
.30774 .51572 L
s
.777 .214 1 r
.41338 .50964 m
.41309 .51844 L
s
.41316 .51811 m
.41338 .50964 L
s
.516 1 .954 r
.742 .48366 m
.74236 .48962 L
s
.74237 .48959 m
.742 .48366 L
s
.742 .48366 m
.74274 .49516 L
s
.836 .201 1 r
.61799 .45955 m
.61932 .50141 L
s
.845 .199 1 r
.33912 .45955 m
.33698 .5032 L
s
.392 .608 1 r
.80155 .48812 m
.80209 .4953 L
s
.80211 .49527 m
.80155 .48812 L
s
.80155 .48812 m
.80266 .50191 L
s
.777 .214 1 r
.41309 .51844 m
.4134 .50961 L
s
.4134 .50961 m
.41316 .51811 L
s
.531 .274 1 r
.2805 .49402 m
.2799 .50223 L
s
.27991 .5022 m
.2805 .49402 L
s
.2805 .49402 m
.27939 .51014 L
s
.722 .227 1 r
.33592 .52199 m
.33585 .52214 L
s
.88 .191 1 r
.5414 .5107 m
.54144 .51971 L
s
.54149 .51938 m
.5414 .5107 L
s
.733 .224 1 r
.28533 .50944 m
.28473 .51809 L
s
.2848 .5179 m
.28533 .50944 L
s
.869 .194 1 r
.64176 .4974 m
.64203 .50638 L
s
.64205 .50634 m
.64176 .4974 L
s
.64176 .4974 m
.64237 .51507 L
s
.88 .191 1 r
.54144 .51971 m
.54142 .51066 L
s
.54142 .51066 m
.54149 .51938 L
s
.523 .277 1 r
.76887 .45934 m
.77179 .49801 L
s
.42 .723 1 r
.48996 .45934 m
.48979 .49197 L
s
.733 .224 1 r
.28473 .51809 m
.28535 .5094 L
s
.28535 .5094 m
.2848 .5179 L
s
.503 .282 1 r
.40851 .49496 m
.40822 .503 L
s
.40823 .50297 m
.40851 .49496 L
s
.40851 .49496 m
.40799 .51105 L
s
.648 .244 1 r
.45903 .50769 m
.45886 .5162 L
s
.45892 .51587 m
.45903 .50769 L
s
.442 .299 1 r
.45418 .49248 m
.454 .50048 L
s
.45401 .50045 m
.45418 .49248 L
s
.45418 .49248 m
.45389 .5081 L
s
.588 .259 1 r
.38157 .51976 m
.38151 .51987 L
s
.648 .244 1 r
.45886 .5162 m
.45905 .50766 L
s
.45905 .50766 m
.45892 .51587 L
s
.355 .437 1 r
.82034 .51089 m
.82034 .51145 L
s
.919 .183 1 r
.56424 .50972 m
.56434 .51891 L
s
.56439 .51826 m
.56424 .50972 L
s
.531 .274 1 r
.6099 .5072 m
.61009 .51531 L
s
.61015 .51531 m
.6099 .5072 L
s
.344 .33 1 r
.39948 .50343 m
.3992 .51107 L
s
.39926 .5109 m
.39948 .50343 L
s
.919 .183 1 r
.56434 .51891 m
.56426 .50968 L
s
.56426 .50968 m
.56439 .51826 L
s
.733 .224 1 r
.38567 .49646 m
.3853 .50511 L
s
.38532 .50508 m
.38567 .49646 L
s
.38567 .49646 m
.38501 .51359 L
s
.588 .259 1 r
.40441 .51864 m
.40434 .51897 L
s
.531 .274 1 r
.61009 .51531 m
.60992 .50717 L
s
.60992 .50717 m
.61015 .51531 L
s
.344 .33 1 r
.3992 .51107 m
.3995 .5034 L
s
.3995 .5034 m
.39926 .5109 L
s
.4 .312 1 r
.64085 .45913 m
.64229 .49673 L
s
.777 .214 1 r
.36191 .45913 m
.36012 .50135 L
s
.383 .565 1 r
.65073 .48977 m
.65097 .49691 L
s
.65098 .49688 m
.65073 .48977 L
s
.65073 .48977 m
.65126 .50388 L
s
.99 .169 1 r
.72007 .52473 m
.72003 .52506 L
s
.68 .237 1 r
.5594 .49507 m
.55946 .50365 L
s
.55948 .50361 m
.5594 .49507 L
s
.5594 .49507 m
.55959 .51191 L
s
.55 .269 1 r
.35379 .50651 m
.35338 .51473 L
s
.35344 .51455 m
.35379 .50651 L
s
.45 .297 1 r
.79177 .45892 m
.79489 .49688 L
s
.99 .169 1 r
.5128 .45892 m
.51286 .50328 L
s
.55 .269 1 r
.35338 .51473 m
.3538 .50648 L
s
.3538 .50648 m
.35344 .51455 L
s
.811 .206 1 r
.68747 .4958 m
.68786 .5047 L
s
.68788 .50467 m
.68747 .4958 L
s
.68747 .4958 m
.68831 .51318 L
s
.618 .252 1 r
.58224 .49391 m
.58235 .50239 L
s
.58237 .50235 m
.58224 .49391 L
s
.58224 .49391 m
.58254 .51043 L
s
.531 .274 1 r
.50469 .50603 m
.50464 .51421 L
s
.50469 .51399 m
.50469 .50603 L
s
.55 .269 1 r
.78367 .50603 m
.78428 .51428 L
s
.78431 .51399 m
.78367 .50603 L
s
.342 .377 1 r
.37177 .49015 m
.37142 .49776 L
s
.37143 .49773 m
.37177 .49015 L
s
.37177 .49015 m
.37114 .50494 L
s
.531 .274 1 r
.50464 .51421 m
.50471 .50599 L
s
.50471 .50599 m
.50469 .51399 L
s
.55 .269 1 r
.78428 .51428 m
.7837 .50599 L
s
.7837 .50599 m
.78431 .51399 L
s
1 .151 .919 r
.51373 .49785 m
.51367 .5073 L
s
.51369 .50726 m
.51373 .49785 L
s
.51373 .49785 m
.5137 .51628 L
s
.658 .242 1 r
.33094 .50805 m
.33046 .51652 L
s
.33052 .51638 m
.33094 .50805 L
s
.37 .507 1 r
.71518 .50992 m
.71516 .51038 L
s
.712 .229 1 r
.43133 .49475 m
.43107 .50344 L
s
.43109 .5034 m
.43133 .49475 L
s
.43133 .49475 m
.4309 .5117 L
s
.335 .34 1 r
.72414 .50176 m
.72457 .50944 L
s
.7246 .50901 m
.72414 .50176 L
s
.658 .242 1 r
.33046 .51652 m
.33095 .50802 L
s
.33095 .50802 m
.33052 .51638 L
s
.335 .34 1 r
.72457 .50944 m
.72416 .50173 L
s
.72416 .50173 m
.7246 .50901 L
s
.36 .325 1 r
.32607 .49294 m
.32561 .50056 L
s
.32563 .50053 m
.32607 .49294 L
s
.32607 .49294 m
.32522 .50825 L
s
.559 .267 1 r
.29914 .51768 m
.29906 .518 L
s
.868 .194 1 r
.66372 .45871 m
.66568 .50236 L
s
.69 .234 1 r
.38471 .45871 m
.38321 .50058 L
s
.56 .267 1 r
.72907 .51712 m
.72904 .51755 L
s
.991 .169 1 r
.59202 .52488 m
.59197 .52511 L
s
.811 .206 1 r
.50962 .52173 m
.50956 .52206 L
s
.618 .252 1 r
.70624 .51859 m
.7062 .51891 L
s
.57 .264 1 r
.80657 .50533 m
.80724 .51369 L
s
.80726 .51322 m
.80657 .50533 L
s
.367 .322 1 r
.27135 .50407 m
.27078 .51171 L
s
.27083 .51175 m
.27135 .50407 L
s
.57 .264 1 r
.80724 .51369 m
.80659 .5053 L
s
.80659 .5053 m
.80726 .51322 L
s
.367 .322 1 r
.27078 .51171 m
.27136 .50404 L
s
.27136 .50404 m
.27083 .51175 L
s
.669 .239 1 r
.30322 .49469 m
.30265 .50323 L
s
.30266 .5032 m
.30322 .49469 L
s
.30322 .49469 m
.30217 .5115 L
s
1 .154 .933 r
.81468 .45849 m
.81868 .50358 L
s
.448 .828 1 r
.53564 .45849 m
.53589 .48972 L
s
.503 .282 1 r
.2566 .45849 m
.2537 .49824 L
s
.433 .302 1 r
.62384 .5158 m
.62379 .51594 L
s
.669 .239 1 r
.6328 .50764 m
.63306 .51615 L
s
.63311 .51597 m
.6328 .50764 L
s
.63306 .51615 m
.63282 .5076 L
s
.63282 .5076 m
.63311 .51597 L
s
.55 .269 1 r
.60511 .49375 m
.60527 .50197 L
s
.60529 .50194 m
.60511 .49375 L
s
.60511 .49375 m
.6055 .51002 L
s
.868 .194 1 r
.43615 .51093 m
.43591 .5198 L
s
.43597 .51983 m
.43615 .51093 L
s
.359 .46 1 r
.84745 .48809 m
.84812 .49559 L
s
.84815 .49556 m
.84745 .48809 L
s
.84745 .48809 m
.84881 .50249 L
s
.868 .194 1 r
.43591 .5198 m
.43617 .51089 L
s
.43617 .51089 m
.43597 .51983 L
s
.701 .232 1 r
.68661 .45828 m
.68875 .49981 L
s
.512 .279 1 r
.40753 .45828 m
.40637 .49803 L
s
.58 .262 1 r
.37657 .50667 m
.37621 .51493 L
s
.37627 .51485 m
.37657 .50667 L
s
.391 .315 1 r
.42226 .50415 m
.42203 .51186 L
s
.42208 .5119 m
.42226 .50415 L
s
.58 .262 1 r
.37621 .51493 m
.37659 .50663 L
s
.37659 .50663 m
.37627 .51485 L
s
.391 .315 1 r
.42203 .51186 m
.42228 .50412 L
s
.42228 .50412 m
.42208 .5119 L
s
.629 .249 1 r
.752 .51707 m
.75198 .51764 L
s
.919 .183 1 r
.83761 .45807 m
.84168 .50066 L
s
.811 .206 1 r
.5585 .45807 m
.55912 .50031 L
s
.833 .201 1 r
.27939 .45807 m
.27652 .50138 L
s
.503 .282 1 r
.34885 .49319 m
.34842 .50128 L
s
.34843 .50124 m
.34885 .49319 L
s
.34885 .49319 m
.34806 .50925 L
s
.486 .287 1 r
.79772 .51483 m
.79771 .51529 L
s
.589 .259 1 r
.77898 .49267 m
.77956 .50107 L
s
.77958 .50103 m
.77898 .49267 L
s
.77898 .49267 m
.78019 .50905 L
s
.581 .261 1 r
.7095 .45786 m
.7118 .49725 L
s
.383 .317 1 r
.43036 .45786 m
.4295 .49583 L
s
.881 .191 1 r
.73329 .49539 m
.7338 .50444 L
s
.73382 .5044 m
.73329 .49539 L
s
.73329 .49539 m
.73437 .51307 L
s
.649 .244 1 r
.67855 .50625 m
.67892 .51476 L
s
.67896 .51444 m
.67855 .50625 L
s
.67892 .51476 m
.67857 .50622 L
s
.67857 .50622 m
.67896 .51444 L
s
.965 .174 1 r
.73814 .5108 m
.73869 .51993 L
s
.73874 .51977 m
.73814 .5108 L
s
.916 .184 1 r
.48184 .50954 m
.48172 .51863 L
s
.48178 .5183 m
.48184 .50954 L
s
.965 .174 1 r
.73869 .51993 m
.73817 .51076 L
s
.73817 .51076 m
.73874 .51977 L
s
.916 .184 1 r
.48172 .51863 m
.48186 .5095 L
s
.48186 .5095 m
.48178 .5183 L
s
.679 .237 1 r
.42717 .52036 m
.42711 .52036 L
s
.777 .214 1 r
.65571 .50779 m
.65603 .51659 L
s
.65607 .51626 m
.65571 .50779 L
s
.618 .252 1 r
.49984 .49319 m
.49975 .50163 L
s
.49977 .5016 m
.49984 .49319 L
s
.49984 .49319 m
.49974 .50976 L
s
.68 .237 1 r
.86054 .45765 m
.86471 .49847 L
s
.57 .264 1 r
.58137 .45765 m
.5822 .49704 L
s
.638 .247 1 r
.30219 .45765 m
.29975 .49847 L
s
.777 .214 1 r
.65603 .51659 m
.65573 .50776 L
s
.65573 .50776 m
.65607 .51626 L
s
1 .138 .854 r
.76595 .52498 m
.76592 .52542 L
s
.494 .284 1 r
.36757 .5161 m
.36751 .51628 L
s
.68 .237 1 r
.60104 .51868 m
.60099 .51901 L
s
.442 .299 1 r
.82474 .49082 m
.8254 .49883 L
s
.82542 .49879 m
.82474 .49082 L
s
.82474 .49082 m
.82611 .50645 L
s
.711 .229 1 r
.62801 .49403 m
.62824 .50269 L
s
.62826 .50265 m
.62801 .49403 L
s
.62801 .49403 m
.62853 .51103 L
s
.977 .171 1 r
.76104 .51011 m
.76165 .5193 L
s
.76169 .51901 m
.76104 .51011 L
s
.7 .232 1 r
.45002 .5196 m
.44995 .51978 L
s
.433 .302 1 r
.39452 .4917 m
.3942 .4996 L
s
.39421 .49957 m
.39452 .4917 L
s
.39452 .4917 m
.39395 .50736 L
s
.54 .272 1 r
.29405 .50507 m
.2935 .51326 L
s
.29357 .51311 m
.29405 .50507 L
s
.977 .171 1 r
.76165 .5193 m
.76106 .51007 L
s
.76106 .51007 m
.76169 .51901 L
s
.826 .203 1 r
.73241 .45743 m
.73509 .49861 L
s
.766 .217 1 r
.4532 .45743 m
.45252 .49968 L
s
.658 .242 1 r
.32184 .51904 m
.32177 .51919 L
s
.955 .176 1 r
.48675 .52569 m
.48669 .52538 L
s
.54 .272 1 r
.2935 .51326 m
.29407 .50504 L
s
.29407 .50504 m
.29357 .51311 L
s
.379 .548 1 r
.71042 .49751 m
.71081 .50481 L
s
.71083 .50427 m
.71042 .49751 L
s
.723 .226 1 r
.70145 .50584 m
.70189 .5146 L
s
.70192 .51403 m
.70145 .50584 L
s
.379 .548 1 r
.71081 .50481 m
.71044 .49748 L
s
.71044 .49748 m
.71083 .50427 L
s
.754 .219 1 r
.47698 .49505 m
.47683 .50374 L
s
.47685 .50371 m
.47698 .49505 L
s
.47698 .49505 m
.47676 .5123 L
s
.723 .226 1 r
.70189 .5146 m
.70148 .50581 L
s
.70148 .50581 m
.70192 .51403 L
s
.448 .828 1 r
.81088 .4843 m
.8114 .4909 L
s
.81142 .49087 m
.81088 .4843 L
s
.81088 .4843 m
.81195 .49709 L
s
.711 .229 1 r
.88349 .45722 m
.888 .49876 L
s
.503 .282 1 r
.60424 .45722 m
.60533 .49627 L
s
.588 .259 1 r
.325 .45722 m
.32287 .49733 L
s
.467 .292 1 r
.2663 .49166 m
.26568 .49967 L
s
.2657 .49964 m
.2663 .49166 L
s
.2663 .49166 m
.26514 .50751 L
s
.456 .855 1 r
.77008 .50254 m
.77007 .50295 L
s
.904 .186 1 r
.55534 .52233 m
.55529 .52252 L
s
.777 .214 1 r
.55042 .50718 m
.55047 .51598 L
s
.55053 .51565 m
.55042 .50718 L
s
.512 .279 1 r
.31686 .50466 m
.31637 .51274 L
s
.31643 .5127 m
.31686 .50466 L
s
.459 .295 1 r
.33973 .5034 m
.33929 .51137 L
s
.33936 .51123 m
.33973 .5034 L
s
.513 .279 1 r
.75533 .45701 m
.7581 .4957 L
s
.408 .673 1 r
.47605 .45701 m
.47573 .49073 L
s
.777 .214 1 r
.55047 .51598 m
.55044 .50714 L
s
.55044 .50714 m
.55053 .51565 L
s
.512 .279 1 r
.31637 .51274 m
.31688 .50462 L
s
.31688 .50462 m
.31643 .5127 L
s
.459 .295 1 r
.33929 .51137 m
.33974 .50337 L
s
.33974 .50337 m
.33936 .51123 L
s
.4 .64 1 r
.7562 .49584 m
.75667 .50294 L
s
.75667 .50238 m
.7562 .49584 L
s
.765 .217 1 r
.5782 .52122 m
.57815 .52119 L
s
.4 .64 1 r
.75667 .50294 m
.75622 .49581 L
s
.75622 .49581 m
.75667 .50238 L
s
.352 .327 1 r
.81582 .50039 m
.81647 .50814 L
s
.81648 .50772 m
.81582 .50039 L
s
.34 .331 1 r
.8387 .49913 m
.83939 .50692 L
s
.83938 .50624 m
.8387 .49913 L
s
.352 .327 1 r
.81647 .50814 m
.81584 .50036 L
s
.81584 .50036 m
.81648 .50772 L
s
.34 .331 1 r
.83939 .50692 m
.83872 .4991 L
s
.83872 .4991 m
.83938 .50624 L
s
.777 .214 1 r
.47286 .51954 m
.4728 .51987 L
s
.352 .327 1 r
.58718 .51325 m
.58713 .51324 L
s
.682 .236 1 r
.74725 .50445 m
.7478 .51314 L
s
.74781 .51249 m
.74725 .50445 L
s
.845 .199 1 r
.62713 .4568 m
.62861 .49976 L
s
.658 .242 1 r
.34782 .4568 m
.34589 .49834 L
s
.682 .236 1 r
.7478 .51314 m
.74727 .50442 L
s
.74727 .50442 m
.74781 .51249 L
s
.608 .254 1 r
.66969 .51675 m
.66965 .51704 L
s
.4 .312 1 r
.5913 .49016 m
.59143 .498 L
s
.59145 .49796 m
.5913 .49016 L
s
.5913 .49016 m
.59162 .50562 L
s
.81 .206 1 r
.82976 .50803 m
.83053 .51683 L
s
.83058 .51671 m
.82976 .50803 L
s
.516 1 .954 r
.74236 .48962 m
.74273 .49557 L
s
.74274 .49516 m
.74236 .48962 L
s
.81 .206 1 r
.83053 .51683 m
.82979 .50799 L
s
.82979 .50799 m
.83058 .51671 L
s
.34 .364 1 r
.77826 .45659 m
.78104 .49208 L
s
1 .156 .947 r
.49891 .45659 m
.49878 .50205 L
s
.516 1 .954 r
.74273 .49557 m
.74237 .48959 L
s
.74237 .48959 m
.74274 .49516 L
s
.56 .267 1 r
.71956 .491 m
.71999 .49934 L
s
.72002 .4993 m
.71956 .491 L
s
.71956 .491 m
.72049 .50725 L
s
.559 .267 1 r
.4908 .50376 m
.49071 .51205 L
s
.49076 .51173 m
.4908 .50376 L
s
.49071 .51205 m
.49081 .50372 L
s
.49081 .50372 m
.49076 .51173 L
s
.767 .216 1 r
.59617 .50579 m
.59635 .51463 L
s
.59639 .51412 m
.59617 .50579 L
s
.846 .199 1 r
.67383 .49373 m
.67419 .50271 L
s
.67421 .50267 m
.67383 .49373 L
s
.67383 .49373 m
.6746 .51127 L
s
.767 .216 1 r
.59635 .51463 m
.5962 .50575 L
s
.5962 .50575 m
.59639 .51412 L
s
.36 .325 1 r
.48593 .48877 m
.48582 .49653 L
s
.48584 .4965 m
.48593 .48877 L
s
.48593 .48877 m
.48578 .50394 L
s
.766 .217 1 r
.65003 .45637 m
.65177 .49863 L
s
.559 .267 1 r
.37065 .45637 m
.36907 .49614 L
s
.811 .206 1 r
.54558 .49331 m
.54561 .50222 L
s
.54563 .50218 m
.54558 .49331 L
s
.54558 .49331 m
.54571 .5107 L
s
.648 .244 1 r
.28906 .49216 m
.28846 .50067 L
s
.28847 .50064 m
.28906 .49216 L
s
.28906 .49216 m
.28795 .50887 L
s
.881 .191 1 r
.77513 .51949 m
.77511 .52003 L
s
.69 .234 1 r
.56846 .49233 m
.56854 .50096 L
s
.56856 .50092 m
.56846 .49233 L
s
.56846 .49233 m
.56869 .50923 L
s
.801 .208 1 r
.61907 .50509 m
.6193 .51407 L
s
.61934 .51335 m
.61907 .50509 L
s
.459 .295 1 r
.66481 .50257 m
.66512 .51054 L
s
.66517 .5104 m
.66481 .50257 L
s
.352 .327 1 r
.63708 .4886 m
.6373 .49632 L
s
.63732 .49629 m
.63708 .4886 L
s
.63708 .4886 m
.63758 .50373 L
s
.705 .231 1 r
.8012 .45616 m
.80456 .49557 L
s
.658 .242 1 r
.52178 .45616 m
.52194 .49771 L
s
.801 .208 1 r
.6193 .51407 m
.61909 .50506 L
s
.61909 .50506 m
.61934 .51335 L
s
.459 .295 1 r
.66512 .51054 m
.66483 .50254 L
s
.66483 .50254 m
.66517 .5104 L
s
.822 .204 1 r
.34457 .5204 m
.3445 .52055 L
s
.45 .297 1 r
.76536 .48933 m
.76589 .49738 L
s
.76591 .49734 m
.76536 .48933 L
s
.76536 .48933 m
.76646 .505 L
s
1 .136 .841 r
.52756 .51042 m
.52756 .51998 L
s
.52763 .51961 m
.52756 .51042 L
s
.52756 .51998 m
.52759 .51038 L
s
.52759 .51038 m
.52763 .51961 L
s
.638 .247 1 r
.69674 .49335 m
.69712 .50173 L
s
.69715 .50169 m
.69674 .49335 L
s
.69674 .49335 m
.69759 .51014 L
s
.392 .608 1 r
.80209 .4953 m
.80266 .50247 L
s
.80266 .50191 m
.80209 .4953 L
s
.494 .285 1 r
.46305 .49083 m
.46288 .49892 L
s
.4629 .49889 m
.46305 .49083 L
s
.46305 .49083 m
.46279 .50683 L
s
.712 .229 1 r
.39031 .51816 m
.39025 .51838 L
s
.392 .608 1 r
.80266 .50247 m
.80211 .49527 L
s
.80211 .49527 m
.80266 .50191 L
s
1 .153 .933 r
.67295 .45595 m
.67509 .50071 L
s
.928 .181 1 r
.3935 .45595 m
.39202 .50035 L
s
.777 .214 1 r
.4173 .49352 m
.417 .50229 L
s
.41702 .50226 m
.4173 .49352 L
s
.4173 .49352 m
.41679 .51085 L
s
.953 .176 1 r
.57332 .50818 m
.57344 .51734 L
s
.5735 .51701 m
.57332 .50818 L
s
.588 .259 1 r
.36249 .5044 m
.3621 .5127 L
s
.36216 .51259 m
.36249 .5044 L
s
.799 .209 1 r
.64689 .51964 m
.64684 .51982 L
s
.953 .176 1 r
.57344 .51734 m
.57334 .50814 L
s
.57334 .50814 m
.5735 .51701 L
s
.588 .259 1 r
.3621 .5127 m
.36251 .50436 L
s
.36251 .50436 m
.36216 .51259 L
s
.811 .206 1 r
.5186 .51908 m
.51854 .51941 L
s
.618 .252 1 r
.79314 .50391 m
.79378 .51235 L
s
.79381 .51202 m
.79314 .50391 L
s
.669 .239 1 r
.44017 .49251 m
.43994 .50103 L
s
.43995 .501 m
.44017 .49251 L
s
.44017 .49251 m
.43978 .50937 L
s
.618 .252 1 r
.79378 .51235 m
.79316 .50387 L
s
.79316 .50387 m
.79381 .51202 L
s
.744 .221 1 r
.82415 .45574 m
.82796 .49729 L
s
.68 .237 1 r
.54466 .45574 m
.5451 .49693 L
s
.521 .277 1 r
.26518 .45574 m
.26238 .49551 L
s
.578 .262 1 r
.30774 .51572 m
.30767 .5159 L
s
.669 .239 1 r
.31185 .4923 m
.3113 .50082 L
s
.31132 .50079 m
.31185 .4923 L
s
.31185 .4923 m
.31084 .50917 L
s
.953 .176 1 r
.49572 .5209 m
.49566 .52124 L
s
.868 .194 1 r
.44501 .50825 m
.4448 .51713 L
s
.44486 .51716 m
.44501 .50825 L
s
.733 .224 1 r
.69268 .51776 m
.69264 .51805 L
s
.629 .249 1 r
.53655 .50321 m
.53658 .51173 L
s
.53663 .51126 m
.53655 .50321 L
s
.868 .194 1 r
.4448 .51713 m
.44503 .50822 L
s
.44503 .50822 m
.44486 .51716 L
s
.4 .641 1 r
.69587 .45552 m
.69772 .48961 L
s
.679 .237 1 r
.41635 .45552 m
.41523 .49744 L
s
.383 .565 1 r
.65097 .49691 m
.65122 .50405 L
s
.65126 .50388 m
.65097 .49691 L
s
.629 .249 1 r
.53658 .51173 m
.53657 .50318 L
s
.53657 .50318 m
.53663 .51126 L
s
.344 .33 1 r
.39926 .5109 m
.3992 .51107 L
s
.383 .565 1 r
.65122 .50405 m
.65098 .49688 L
s
.65098 .49688 m
.65126 .50388 L
s
.916 .184 1 r
.4679 .50728 m
.46774 .51637 L
s
.46781 .51604 m
.4679 .50728 L
s
.531 .274 1 r
.2799 .50223 m
.27931 .51046 L
s
.27939 .51014 m
.2799 .50223 L
s
.916 .184 1 r
.46774 .51637 m
.46792 .50724 L
s
.46792 .50724 m
.46781 .51604 L
s
.777 .214 1 r
.41316 .51811 m
.41309 .51844 L
s
.531 .274 1 r
.27931 .51046 m
.27991 .5022 L
s
.27991 .5022 m
.27939 .51014 L
s
.503 .282 1 r
.40822 .503 m
.40794 .51105 L
s
.40799 .51105 m
.40822 .503 L
s
.442 .299 1 r
.454 .50048 m
.45382 .50849 L
s
.45389 .5081 m
.454 .50048 L
s
1 .159 .959 r
.84711 .45531 m
.85151 .50008 L
s
.857 .196 1 r
.56756 .45531 m
.5683 .4983 L
s
.744 .221 1 r
.288 .45531 m
.28533 .49723 L
s
.503 .282 1 r
.40794 .51105 m
.40823 .50297 L
s
.40823 .50297 m
.40799 .51105 L
s
.442 .299 1 r
.45382 .50849 m
.45401 .50045 L
s
.45401 .50045 m
.45389 .5081 L
s
1 .111 .702 r
.52272 .49681 m
.52269 .5066 L
s
.52271 .50656 m
.52272 .49681 L
s
.52272 .49681 m
.52274 .5161 L
s
.648 .244 1 r
.45892 .51587 m
.45886 .5162 L
s
.531 .274 1 r
.50881 .48986 m
.50874 .49809 L
s
.50876 .49806 m
.50881 .48986 L
s
.50881 .48986 m
.50876 .506 L
s
.61015 .51531 m
.61009 .51531 L
s
.733 .224 1 r
.2848 .5179 m
.28473 .51809 L
s
.335 .34 1 r
.7246 .50901 m
.72457 .50944 L
s
.589 .259 1 r
.66005 .48944 m
.66035 .49788 L
s
.66037 .49785 m
.66005 .48944 L
s
.66005 .48944 m
.66071 .5058 L
s
.744 .221 1 r
.7188 .4551 m
.72134 .49666 L
s
.342 .378 1 r
.43922 .4551 m
.43849 .49132 L
s
.342 .377 1 r
.37142 .49776 m
.37107 .50537 L
s
.37114 .50494 m
.37142 .49776 L
s
.88 .191 1 r
.54149 .51938 m
.54144 .51971 L
s
.342 .377 1 r
.37107 .50537 m
.37143 .49773 L
s
.37143 .49773 m
.37114 .50494 L
s
.7 .232 1 r
.33468 .4921 m
.33418 .50069 L
s
.3342 .50066 m
.33468 .4921 L
s
.33468 .4921 m
.33377 .50911 L
s
.919 .183 1 r
.56439 .51826 m
.56434 .51891 L
s
.36 .325 1 r
.32561 .50056 m
.32517 .50818 L
s
.32522 .50825 m
.32561 .50056 L
s
.55 .269 1 r
.35344 .51455 m
.35338 .51473 L
s
.425 .304 1 r
.27498 .48787 m
.27438 .49585 L
s
.27439 .49581 m
.27498 .48787 L
s
.27498 .48787 m
.27388 .5034 L
s
.36 .325 1 r
.32517 .50818 m
.32563 .50053 L
s
.32563 .50053 m
.32522 .50825 L
s
.869 .194 1 r
.64203 .50638 m
.64233 .51536 L
s
.64237 .51507 m
.64203 .50638 L
s
.733 .224 1 r
.3853 .50511 m
.38495 .51378 L
s
.38501 .51359 m
.3853 .50511 L
s
.531 .274 1 r
.50469 .51399 m
.50464 .51421 L
s
.347 .402 1 r
.53168 .4892 m
.53167 .49654 L
s
.53169 .49651 m
.53168 .4892 L
s
.53168 .4892 m
.53173 .50417 L
s
.55 .269 1 r
.78431 .51399 m
.78428 .51428 L
s
.869 .194 1 r
.64233 .51536 m
.64205 .50634 L
s
.64205 .50634 m
.64237 .51507 L
s
.461 .294 1 r
.87009 .45489 m
.87397 .49182 L
s
1 .128 .799 r
.59046 .45489 m
.59156 .50073 L
s
.55 .269 1 r
.31084 .45489 m
.30857 .49467 L
s
.733 .224 1 r
.38495 .51378 m
.38532 .50508 L
s
.38532 .50508 m
.38501 .51359 L
s
.68 .237 1 r
.78844 .4906 m
.78906 .49922 L
s
.78909 .49919 m
.78844 .4906 L
s
.78844 .4906 m
.78974 .50742 L
s
.367 .322 1 r
.27083 .51175 m
.27078 .51171 L
s
.68 .237 1 r
.55946 .50365 m
.55954 .51223 L
s
.55959 .51191 m
.55946 .50365 L
s
.618 .252 1 r
.58235 .50239 m
.58249 .51086 L
s
.58254 .51043 m
.58235 .50239 L
s
.766 .216 1 r
.61429 .49284 m
.61449 .50154 L
s
.61451 .50151 m
.61429 .49284 L
s
.61429 .49284 m
.61476 .51018 L
s
.679 .237 1 r
.74175 .45467 m
.7446 .49695 L
s
.629 .249 1 r
.46209 .45467 m
.46153 .49624 L
s
.658 .242 1 r
.33052 .51638 m
.33046 .51652 L
s
.68 .237 1 r
.55954 .51223 m
.55948 .50361 L
s
.55948 .50361 m
.55959 .51191 L
s
.618 .252 1 r
.58249 .51086 m
.58237 .50235 L
s
.58237 .50235 m
.58254 .51043 L
s
.57 .264 1 r
.80726 .51322 m
.80724 .51369 L
s
.359 .46 1 r
.84812 .49559 m
.84882 .50309 L
s
.84881 .50249 m
.84812 .49559 L
s
.84882 .50309 m
.84815 .49556 L
s
.84815 .49556 m
.84881 .50249 L
s
.337 .353 1 r
.4491 .48675 m
.44891 .49437 L
s
.44893 .49434 m
.4491 .48675 L
s
.4491 .48675 m
.44879 .50171 L
s
.531 .274 1 r
.5546 .48871 m
.55465 .49698 L
s
.55467 .49694 m
.5546 .48871 L
s
.5546 .48871 m
.55476 .50482 L
s
.733 .224 1 r
.35752 .49189 m
.35708 .50056 L
s
.35709 .50052 m
.35752 .49189 L
s
.35752 .49189 m
.35672 .50905 L
s
.377 .542 1 r
.77458 .48427 m
.77508 .49156 L
s
.7751 .49153 m
.77458 .48427 L
s
.77458 .48427 m
.77561 .4984 L
s
.598 .257 1 r
.38041 .49067 m
.38004 .49901 L
s
.38006 .49898 m
.38041 .49067 L
s
.38041 .49067 m
.37975 .50721 L
s
.811 .206 1 r
.68786 .5047 m
.68827 .51362 L
s
.68831 .51318 m
.68786 .5047 L
s
.393 .314 1 r
.6004 .48622 m
.60055 .49416 L
s
.60056 .49413 m
.6004 .48622 L
s
.6004 .48622 m
.60075 .5015 L
s
.712 .229 1 r
.43107 .50344 m
.43083 .51214 L
s
.4309 .5117 m
.43107 .50344 L
s
.375 .532 1 r
.75168 .4856 m
.75212 .49283 L
s
.75215 .4928 m
.75168 .4856 L
s
.75168 .4856 m
.75263 .49988 L
s
.845 .199 1 r
.89307 .45446 m
.89787 .49746 L
s
.368 .322 1 r
.61338 .45446 m
.61451 .4914 L
s
.857 .196 1 r
.33369 .45446 m
.33148 .49817 L
s
.811 .206 1 r
.68827 .51362 m
.68788 .50467 L
s
.68788 .50467 m
.68831 .51318 L
s
.712 .229 1 r
.43083 .51214 m
.43109 .5034 L
s
.43109 .5034 m
.4309 .5117 L
s
.391 .315 1 r
.42208 .5119 m
.42203 .51186 L
s
.669 .239 1 r
.30265 .50323 m
.30209 .51179 L
s
.30217 .5115 m
.30265 .50323 L
s
.55 .269 1 r
.60527 .50197 m
.60545 .5102 L
s
.6055 .51002 m
.60527 .50197 L
s
.409 .309 1 r
.76471 .45425 m
.76746 .49119 L
s
.485 .287 1 r
.48498 .45425 m
.48471 .49368 L
s
.669 .239 1 r
.63311 .51597 m
.63306 .51615 L
s
.30209 .51179 m
.30266 .5032 L
s
.30266 .5032 m
.30217 .5115 L
s
.55 .269 1 r
.60545 .5102 m
.60529 .50194 L
s
.60529 .50194 m
.6055 .51002 L
s
.58 .262 1 r
.37627 .51485 m
.37621 .51493 L
s
.459 .295 1 r
.42619 .48879 m
.42594 .49677 L
s
.42595 .49673 m
.42619 .48879 L
s
.42619 .48879 m
.42576 .50461 L
s
1 .151 .919 r
.51367 .5073 m
.51364 .51676 L
s
.5137 .51628 m
.51367 .5073 L
s
.51364 .51676 m
.51369 .50726 L
s
.51369 .50726 m
.5137 .51628 L
s
.448 .828 1 r
.8114 .4909 m
.81195 .49751 L
s
.81195 .49709 m
.8114 .4909 L
s
.379 .548 1 r
.71083 .50427 m
.71081 .50481 L
s
.448 .828 1 r
.81195 .49751 m
.81142 .49087 L
s
.81142 .49087 m
.81195 .49709 L
s
.503 .282 1 r
.85727 .4884 m
.85803 .49656 L
s
.85805 .49652 m
.85727 .4884 L
s
.85727 .4884 m
.85882 .5044 L
s
.618 .252 1 r
.63631 .45404 m
.63781 .49454 L
s
.608 .254 1 r
.35655 .45404 m
.35475 .4949 L
s
.503 .282 1 r
.34842 .50128 m
.348 .50936 L
s
.34806 .50925 m
.34842 .50128 L
s
.711 .229 1 r
.68305 .4905 m
.68342 .49916 L
s
.68344 .49913 m
.68305 .4905 L
s
.68305 .4905 m
.68385 .50751 L
s
.503 .282 1 r
.348 .50936 m
.34843 .50124 L
s
.34843 .50124 m
.34806 .50925 L
s
.868 .194 1 r
.43597 .51983 m
.43591 .5198 L
s
.516 1 .954 r
.74274 .49516 m
.74273 .49557 L
s
1 .125 .781 r
.78768 .45382 m
.79129 .49826 L
s
.55 .269 1 r
.50788 .45382 m
.50787 .49469 L
s
.589 .259 1 r
.77956 .50107 m
.78017 .50948 L
s
.78019 .50905 m
.77956 .50107 L
s
.777 .214 1 r
.40327 .49092 m
.40293 .49973 L
s
.40295 .49969 m
.40327 .49092 L
s
.40327 .49092 m
.40269 .50822 L
s
.649 .244 1 r
.67896 .51444 m
.67892 .51476 L
s
.589 .259 1 r
.78017 .50948 m
.77958 .50103 L
s
.77958 .50103 m
.78019 .50905 L
s
.4 .64 1 r
.75667 .50238 m
.75667 .50294 L
s
.618 .252 1 r
.57753 .48924 m
.57764 .49769 L
s
.57766 .49766 m
.57753 .48924 L
s
.57753 .48924 m
.57781 .50582 L
s
.442 .299 1 r
.8254 .49883 m
.82609 .50684 L
s
.82611 .50645 m
.8254 .49883 L
s
.733 .224 1 r
.65925 .45361 m
.66108 .49555 L
s
.777 .214 1 r
.37942 .45361 m
.37784 .4959 L
s
.403 .652 1 r
.69207 .48295 m
.69238 .48996 L
s
.6924 .48993 m
.69207 .48295 L
s
.69207 .48295 m
.69275 .49665 L
s
.442 .299 1 r
.82609 .50684 m
.82542 .49879 L
s
.82542 .49879 m
.82611 .50645 L
s
.433 .302 1 r
.3942 .4996 m
.39389 .50751 L
s
.39395 .50736 m
.3942 .4996 L
s
.384 .317 1 r
.49489 .48627 m
.49479 .49411 L
s
.49481 .49407 m
.49489 .48627 L
s
.49489 .48627 m
.49477 .50159 L
s
.433 .302 1 r
.39389 .50751 m
.39421 .49957 L
s
.39421 .49957 m
.39395 .50736 L
s
.858 .196 1 r
.83448 .49078 m
.83525 .4998 L
s
.83528 .49977 m
.83448 .49078 L
s
.83448 .49078 m
.83607 .50837 L
s
.618 .252 1 r
.49975 .50163 m
.49969 .51008 L
s
.49974 .50976 m
.49975 .50163 L
s
.38 .554 1 r
.82055 .48378 m
.82114 .49101 L
s
.82116 .49098 m
.82055 .48378 L
s
.82055 .48378 m
.82177 .49792 L
s
.777 .214 1 r
.65607 .51626 m
.65603 .51659 L
s
.54 .272 1 r
.29357 .51311 m
.2935 .51326 L
s
.618 .252 1 r
.49969 .51008 m
.49977 .5016 L
s
.49977 .5016 m
.49974 .50976 L
s
.916 .184 1 r
.48178 .5183 m
.48172 .51863 L
s
.57 .264 1 r
.81066 .4534 m
.81412 .49284 L
s
1 .164 .984 r
.53079 .4534 m
.53108 .49891 L
s
.638 .247 1 r
.25093 .4534 m
.24785 .49462 L
s
.34 .331 1 r
.83938 .50624 m
.83939 .50692 L
s
.881 .191 1 r
.7338 .50444 m
.73434 .5135 L
s
.73437 .51307 m
.7338 .50444 L
s
.73434 .5135 m
.73382 .5044 L
s
.73382 .5044 m
.73437 .51307 L
s
.723 .226 1 r
.70192 .51403 m
.70189 .5146 L
s
.965 .174 1 r
.73874 .51977 m
.73869 .51993 L
s
.352 .327 1 r
.81648 .50772 m
.81647 .50814 L
s
.711 .229 1 r
.62824 .50269 m
.62849 .51135 L
s
.62853 .51103 m
.62824 .50269 L
s
.62849 .51135 m
.62826 .50265 L
s
.62826 .50265 m
.62853 .51103 L
s
.467 .292 1 r
.26568 .49967 m
.26508 .50769 L
s
.26514 .50751 m
.26568 .49967 L
s
.701 .232 1 r
.6822 .45318 m
.6843 .49477 L
s
.691 .234 1 r
.4023 .45318 m
.40098 .49584 L
s
.467 .292 1 r
.26508 .50769 m
.2657 .49964 L
s
.2657 .49964 m
.26514 .50751 L
s
.459 .295 1 r
.33936 .51123 m
.33929 .51137 L
s
.754 .219 1 r
.47683 .50374 m
.4767 .51245 L
s
.47676 .5123 m
.47683 .50374 L
s
.977 .171 1 r
.76169 .51901 m
.76165 .5193 L
s
.754 .219 1 r
.4767 .51245 m
.47685 .50371 L
s
.47685 .50371 m
.47676 .5123 L
s
.425 .305 1 r
.79772 .48599 m
.79832 .49397 L
s
.79835 .49394 m
.79772 .48599 L
s
.79772 .48599 m
.79896 .50153 L
s
.512 .279 1 r
.31643 .5127 m
.31637 .51274 L
s
.477 .289 1 r
.83365 .45297 m
.83727 .49135 L
s
.4 .312 1 r
.55371 .45297 m
.55421 .49064 L
s
.744 .221 1 r
.27378 .45297 m
.27093 .49491 L
s
.811 .206 1 r
.72899 .48998 m
.72949 .4989 L
s
.72951 .49886 m
.72899 .48998 L
s
.72899 .48998 m
.73004 .50739 L
s
.569 .264 1 r
.47196 .48879 m
.47181 .49707 L
s
.47183 .49703 m
.47196 .48879 L
s
.47196 .48879 m
.47174 .5052 L
s
.503 .282 1 r
.34345 .4882 m
.343 .49629 L
s
.34302 .49626 m
.34345 .4882 L
s
.34345 .4882 m
.34263 .50428 L
s
.777 .214 1 r
.55053 .51565 m
.55047 .51598 L
s
.682 .236 1 r
.74781 .51249 m
.7478 .51314 L
s
.4 .312 1 r
.59143 .498 m
.59157 .50583 L
s
.59162 .50562 m
.59143 .498 L
s
.382 .563 1 r
.70516 .45276 m
.70706 .48581 L
s
.512 .279 1 r
.4252 .45276 m
.42424 .49257 L
s
.494 .284 1 r
.36636 .48718 m
.36596 .49531 L
s
.36598 .49528 m
.36636 .48718 L
s
.36636 .48718 m
.36565 .50316 L
s
.4 .312 1 r
.59157 .50583 m
.59145 .49796 L
s
.59145 .49796 m
.59162 .50562 L
s
.392 .608 1 r
.80266 .50191 m
.80266 .50247 L
s
.868 .194 1 r
.29759 .49128 m
.29698 .50024 L
s
.29699 .5002 m
.29759 .49128 L
s
.29759 .49128 m
.29645 .50902 L
s
.559 .267 1 r
.49076 .51173 m
.49071 .51205 L
s
.36 .325 1 r
.48582 .49653 m
.48573 .50429 L
s
.48578 .50394 m
.48582 .49653 L
s
.357 .451 1 r
.85665 .45255 m
.86024 .48808 L
s
1 .149 .907 r
.57665 .45254 m
.57755 .49807 L
s
.916 .184 1 r
.29665 .45254 m
.29389 .49735 L
s
.36 .325 1 r
.48573 .50429 m
.48584 .4965 L
s
.48584 .4965 m
.48578 .50394 L
s
.56 .267 1 r
.71999 .49934 m
.72046 .50767 L
s
.72049 .50725 m
.71999 .49934 L
s
.799 .209 1 r
.32048 .49044 m
.31994 .49926 L
s
.31996 .49922 m
.32048 .49044 L
s
.32048 .49044 m
.31948 .50789 L
s
.56 .267 1 r
.72046 .50767 m
.72002 .4993 L
s
.72002 .4993 m
.72049 .50725 L
s
.352 .327 1 r
.6373 .49632 m
.63754 .50404 L
s
.63758 .50373 m
.6373 .49632 L
s
.767 .216 1 r
.59639 .51412 m
.59635 .51463 L
s
.953 .176 1 r
.72814 .45233 m
.73093 .49607 L
s
.977 .171 1 r
.4481 .45233 m
.44732 .49714 L
s
.346 .329 1 r
.73807 .48298 m
.73852 .49082 L
s
.73854 .49078 m
.73807 .48298 L
s
.73807 .48298 m
.73901 .49794 L
s
.81 .206 1 r
.83058 .51671 m
.83053 .51683 L
s
.352 .327 1 r
.63754 .50404 m
.63732 .49629 L
s
.63732 .49629 m
.63758 .50373 L
s
.459 .295 1 r
.66517 .5104 m
.66512 .51054 L
s
1 .161 .972 r
.70615 .49261 m
.7066 .50186 L
s
.70662 .50183 m
.70615 .49261 L
s
.70615 .49261 m
.70713 .51101 L
s
.777 .214 1 r
.62344 .48946 m
.62366 .49827 L
s
.62369 .49824 m
.62344 .48946 L
s
.62344 .48946 m
.62396 .50677 L
s
.45 .297 1 r
.76589 .49738 m
.76644 .50543 L
s
.76646 .505 m
.76589 .49738 L
s
.638 .247 1 r
.87966 .45212 m
.88406 .49301 L
s
1 .143 .88 r
.59959 .45212 m
.60079 .49729 L
s
.588 .259 1 r
.31952 .45212 m
.31733 .49229 L
s
.45 .297 1 r
.76644 .50543 m
.76591 .49734 L
s
.76591 .49734 m
.76646 .505 L
s
.801 .208 1 r
.61934 .51335 m
.6193 .51407 L
s
.648 .244 1 r
.28846 .50067 m
.28787 .5092 L
s
.28795 .50887 m
.28846 .50067 L
s
.28787 .5092 m
.28847 .50064 L
s
.28847 .50064 m
.28795 .50887 L
s
.383 .565 1 r
.65126 .50388 m
.65122 .50405 L
s
.846 .199 1 r
.67419 .50271 m
.67457 .5117 L
s
.6746 .51127 m
.67419 .50271 L
s
.494 .285 1 r
.46288 .49892 m
.46273 .50701 L
s
.46279 .50683 m
.46288 .49892 L
s
.846 .199 1 r
.67457 .5117 m
.67421 .50267 L
s
.67421 .50267 m
.6746 .51127 L
s
.494 .285 1 r
.46273 .50701 m
.4629 .49889 L
s
.4629 .49889 m
.46279 .50683 L
s
.811 .206 1 r
.54561 .50222 m
.54565 .51114 L
s
.54571 .5107 m
.54561 .50222 L
s
.69 .234 1 r
.56854 .50096 m
.56864 .50959 L
s
.56869 .50923 m
.56854 .50096 L
s
.68 .237 1 r
.51781 .4882 m
.51777 .4968 L
s
.51778 .49676 m
.51781 .4882 L
s
.51781 .4882 m
.5178 .50508 L
s
.4 .64 1 r
.75112 .45191 m
.75343 .48461 L
s
.777 .214 1 r
.47102 .4519 m
.47055 .49458 L
s
.811 .206 1 r
.54565 .51114 m
.54563 .50218 L
s
.54563 .50218 m
.54571 .5107 L
s
.69 .234 1 r
.56864 .50959 m
.56856 .50092 L
s
.56856 .50092 m
.56869 .50923 L
s
.638 .247 1 r
.69712 .50173 m
.69753 .51011 L
s
.69759 .51014 m
.69712 .50173 L
s
.69753 .51011 m
.69715 .50169 L
s
.69715 .50169 m
.69759 .51014 L
s
.588 .259 1 r
.36216 .51259 m
.3621 .5127 L
s
.618 .252 1 r
.79381 .51202 m
.79378 .51235 L
s
.941 .179 1 r
.90269 .45169 m
.90773 .4958 L
s
.765 .217 1 r
.62255 .45169 m
.62398 .49508 L
s
.598 .257 1 r
.34241 .45169 m
.34044 .49258 L
s
.512 .279 1 r
.41213 .48691 m
.41184 .49504 L
s
.41186 .49501 m
.41213 .48691 L
s
.41213 .48691 m
.41163 .50303 L
s
.834 .201 1 r
.64642 .4895 m
.6467 .49843 L
s
.64673 .49839 m
.64642 .4895 L
s
.64642 .4895 m
.64706 .50707 L
s
.777 .214 1 r
.417 .50229 m
.41672 .51107 L
s
.41679 .51085 m
.417 .50229 L
s
.669 .239 1 r
.43994 .50103 m
.43972 .50956 L
s
.43978 .50937 m
.43994 .50103 L
s
.777 .214 1 r
.41672 .51107 m
.41702 .50226 L
s
.41702 .50226 m
.41679 .51085 L
s
.669 .239 1 r
.43972 .50956 m
.43995 .501 L
s
.43995 .501 m
.43978 .50937 L
s
.578 .262 1 r
.38919 .48835 m
.38884 .49659 L
s
.38886 .49655 m
.38919 .48835 L
s
.38919 .48835 m
.38857 .50487 L
s
.629 .249 1 r
.53663 .51126 m
.53658 .51173 L
s
.953 .176 1 r
.5735 .51701 m
.57344 .51734 L
s
.442 .299 1 r
.45389 .5081 m
.45382 .50849 L
s
.342 .377 1 r
.37114 .50494 m
.37107 .50537 L
s
1 .136 .841 r
.52763 .51961 m
.52756 .51998 L
s
.649 .244 1 r
.77412 .45148 m
.77725 .49201 L
s
1 .131 .814 r
.49394 .45148 m
.49374 .49845 L
s
.531 .274 1 r
.27939 .51014 m
.27931 .51046 L
s
.669 .239 1 r
.3113 .50082 m
.31077 .50935 L
s
.31084 .50917 m
.3113 .50082 L
s
.31077 .50935 m
.31132 .50079 L
s
.31132 .50079 m
.31084 .50917 L
s
.503 .282 1 r
.40799 .51105 m
.40794 .51105 L
s
.722 .227 1 r
.66938 .4888 m
.66971 .49744 L
s
.66973 .4974 m
.66938 .4888 L
s
.66938 .4888 m
.67011 .50594 L
s
.744 .221 1 r
.54075 .4882 m
.54077 .49695 L
s
.54079 .49691 m
.54075 .4882 L
s
.54075 .4882 m
.54085 .50537 L
s
.347 .402 1 r
.53167 .49654 m
.53168 .50388 L
s
.53173 .50417 m
.53167 .49654 L
s
.869 .194 1 r
.64552 .45126 m
.64724 .49466 L
s
.648 .244 1 r
.36531 .45126 m
.36358 .49287 L
s
.347 .402 1 r
.53168 .50388 m
.53169 .49651 L
s
.53169 .49651 m
.53173 .50417 L
s
.342 .378 1 r
.78409 .48264 m
.78463 .49026 L
s
.78465 .49023 m
.78409 .48264 L
s
.78409 .48264 m
.78521 .49746 L
s
.69 .234 1 r
.26053 .48838 m
.25986 .49695 L
s
.25987 .49691 m
.26053 .48838 L
s
.26053 .48838 m
.25926 .50537 L
s
.36 .325 1 r
.32522 .50825 m
.32517 .50818 L
s
.359 .46 1 r
.84881 .50249 m
.84882 .50309 L
s
.531 .274 1 r
.50874 .49809 m
.5087 .50632 L
s
.50876 .506 m
.50874 .49809 L
s
.868 .194 1 r
.44486 .51716 m
.4448 .51713 L
s
.531 .274 1 r
.5087 .50632 m
.50876 .49806 L
s
.50876 .49806 m
.50876 .506 L
s
.559 .267 1 r
.58664 .4861 m
.58676 .49442 L
s
.58678 .49438 m
.58664 .4861 L
s
.58664 .4861 m
.58695 .50241 L
s
.916 .184 1 r
.46781 .51604 m
.46774 .51637 L
s
.669 .239 1 r
.5637 .4874 m
.56376 .49597 L
s
.56379 .49593 m
.5637 .4874 L
s
.5637 .4874 m
.56391 .50425 L
s
.68 .237 1 r
.79712 .45105 m
.80055 .49195 L
s
.754 .219 1 r
.51688 .45105 m
.51699 .49373 L
s
.425 .304 1 r
.27438 .49585 m
.2738 .50383 L
s
.27388 .5034 m
.27438 .49585 L
s
.569 .264 1 r
.43504 .48691 m
.4348 .49519 L
s
.43482 .49516 m
.43504 .48691 L
s
.43504 .48691 m
.43464 .50333 L
s
.448 .828 1 r
.81195 .49709 m
.81195 .49751 L
s
.425 .304 1 r
.2738 .50383 m
.27439 .49581 L
s
.27439 .49581 m
.27388 .5034 L
s
.589 .259 1 r
.66035 .49788 m
.66067 .50633 L
s
.66071 .5058 m
.66035 .49788 L
s
.375 .532 1 r
.75212 .49283 m
.75259 .50005 L
s
.75263 .49988 m
.75212 .49283 L
s
.377 .542 1 r
.77508 .49156 m
.7756 .49886 L
s
.77561 .4984 m
.77508 .49156 L
s
.589 .259 1 r
.66067 .50633 m
.66037 .49785 L
s
.66037 .49785 m
.66071 .5058 L
s
.375 .532 1 r
.75259 .50005 m
.75215 .4928 L
s
.75215 .4928 m
.75263 .49988 L
s
.377 .542 1 r
.7756 .49886 m
.7751 .49153 L
s
.7751 .49153 m
.77561 .4984 L
s
.56 .267 1 r
.66849 .45084 m
.67033 .49031 L
s
.845 .199 1 r
.38822 .45084 m
.38672 .49388 L
s
.7 .232 1 r
.33418 .50069 m
.3337 .50929 L
s
.33377 .50911 m
.33418 .50069 L
s
.64 .246 1 r
.6096 .4854 m
.60979 .494 L
s
.60981 .49396 m
.6096 .4854 L
s
.6096 .4854 m
.61003 .50199 L
s
.337 .353 1 r
.44891 .49437 m
.44874 .502 L
s
.44879 .50171 m
.44891 .49437 L
s
.7 .232 1 r
.3337 .50929 m
.3342 .50066 L
s
.3342 .50066 m
.33377 .50911 L
s
.337 .353 1 r
.44874 .502 m
.44893 .49434 L
s
.44893 .49434 m
.44879 .50171 L
s
.416 .307 1 r
.63254 .48425 m
.63276 .49217 L
s
.63278 .49213 m
.63254 .48425 L
s
.63254 .48425 m
.63305 .4998 L
s
.733 .224 1 r
.38501 .51359 m
.38495 .51378 L
s
.618 .252 1 r
.58254 .51043 m
.58249 .51086 L
s
.722 .227 1 r
.2834 .48817 m
.28278 .49682 L
s
.28279 .49678 m
.2834 .48817 L
s
.2834 .48817 m
.28224 .50531 L
s
.365 .486 1 r
.82014 .45062 m
.82333 .48583 L
s
.701 .232 1 r
.53983 .45062 m
.54021 .49296 L
s
.69 .234 1 r
.25952 .45062 m
.25649 .4926 L
s
.869 .194 1 r
.64237 .51507 m
.64233 .51536 L
s
.68 .237 1 r
.55959 .51191 m
.55954 .51223 L
s
.78906 .49922 m
.78972 .50785 L
s
.78974 .50742 m
.78906 .49922 L
s
.932 .18 1 r
.867 .48711 m
.86788 .4964 L
s
.8679 .49636 m
.867 .48711 L
s
.867 .48711 m
.86877 .5049 L
s
.628 .249 1 r
.30634 .48712 m
.30578 .49555 L
s
.3058 .49551 m
.30634 .48712 L
s
.30634 .48712 m
.30531 .50383 L
s
.393 .314 1 r
.60055 .49416 m
.60071 .50211 L
s
.60075 .5015 m
.60055 .49416 L
s
.68 .237 1 r
.78972 .50785 m
.78909 .49919 L
s
.78909 .49919 m
.78974 .50742 L
s
.393 .314 1 r
.60071 .50211 m
.60056 .49413 L
s
.60056 .49413 m
.60075 .5015 L
s
.531 .274 1 r
.55465 .49698 m
.55471 .50525 L
s
.55476 .50482 m
.55465 .49698 L
s
.503 .282 1 r
.35222 .48484 m
.35179 .49301 L
s
.35181 .49298 m
.35222 .48484 L
s
.35222 .48484 m
.35145 .50087 L
s
.461 .294 1 r
.69148 .45041 m
.69346 .4874 L
s
.777 .214 1 r
.41114 .45041 m
.40992 .49346 L
s
1 .111 .702 r
.52269 .5066 m
.52267 .5164 L
s
.52274 .5161 m
.52269 .5066 L
s
.953 .176 1 r
.84407 .48873 m
.84489 .49795 L
s
.84491 .49791 m
.84407 .48873 L
s
.84407 .48873 m
.84575 .50674 L
s
.531 .274 1 r
.55471 .50525 m
.55467 .49694 L
s
.55467 .49694 m
.55476 .50482 L
s
.766 .216 1 r
.61449 .50154 m
.6147 .51026 L
s
.61476 .51018 m
.61449 .50154 L
s
.712 .229 1 r
.4309 .5117 m
.43083 .51214 L
s
.598 .257 1 r
.38004 .49901 m
.37968 .50736 L
s
.37975 .50721 m
.38004 .49901 L
s
1 .111 .702 r
.52267 .5164 m
.52271 .50656 L
s
.52271 .50656 m
.52274 .5161 L
s
.766 .216 1 r
.6147 .51026 m
.61451 .50151 L
s
.61451 .50151 m
.61476 .51018 L
s
.598 .257 1 r
.37968 .50736 m
.38006 .49898 L
s
.38006 .49898 m
.37975 .50721 L
s
.811 .206 1 r
.68831 .51318 m
.68827 .51362 L
s
.55 .269 1 r
.6055 .51002 m
.60545 .5102 L
s
.733 .224 1 r
.35708 .50056 m
.35665 .50923 L
s
.35672 .50905 m
.35708 .50056 L
s
.459 .295 1 r
.42594 .49677 m
.4257 .50475 L
s
.42576 .50461 m
.42594 .49677 L
s
.45 .297 1 r
.37516 .484 m
.37479 .49203 L
s
.3748 .492 m
.37516 .484 L
s
.37516 .484 m
.3745 .49974 L
s
.608 .254 1 r
.48092 .48593 m
.48078 .49436 L
s
.4808 .49432 m
.48092 .48593 L
s
.48092 .48593 m
.48073 .5025 L
s
.966 .173 1 r
.7154 .48849 m
.71588 .49774 L
s
.7159 .4977 m
.7154 .48849 L
s
.7154 .48849 m
.71641 .50653 L
s
.337 .353 1 r
.84317 .4502 m
.84673 .48683 L
s
.917 .184 1 r
.56279 .4502 m
.56348 .4936 L
s
.628 .249 1 r
.28241 .4502 m
.27971 .49146 L
s
.733 .224 1 r
.35665 .50923 m
.35709 .50052 L
s
.35709 .50052 m
.35672 .50905 L
s
.459 .295 1 r
.4257 .50475 m
.42595 .49673 L
s
.42595 .49673 m
.42576 .50461 L
s
.669 .239 1 r
.30217 .5115 m
.30209 .51179 L
s
.403 .652 1 r
.69238 .48996 m
.69272 .49696 L
s
.69275 .49665 m
.69238 .48996 L
s
.69272 .49696 m
.6924 .48993 L
s
.6924 .48993 m
.69275 .49665 L
s
.503 .282 1 r
.34806 .50925 m
.348 .50936 L
s
.85803 .49656 m
.8588 .50472 L
s
.85882 .5044 m
.85803 .49656 L
s
.424 .305 1 r
.71449 .44998 m
.71676 .48804 L
s
.648 .244 1 r
.43407 .44998 m
.43319 .49089 L
s
.485 .287 1 r
.76132 .48639 m
.76183 .49436 L
s
.76186 .49432 m
.76132 .48639 L
s
.76132 .48639 m
.76243 .5025 L
s
.503 .282 1 r
.8588 .50472 m
.85805 .49652 L
s
.85805 .49652 m
.85882 .5044 L
s
.38 .554 1 r
.82114 .49101 m
.82175 .49824 L
s
.82177 .49792 m
.82114 .49101 L
s
.82175 .49824 m
.82116 .49098 L
s
.82116 .49098 m
.82177 .49792 L
s
.531 .274 1 r
.80727 .48411 m
.80791 .49239 L
s
.80794 .49235 m
.80727 .48411 L
s
.80727 .48411 m
.8086 .50024 L
s
.442 .299 1 r
.82611 .50645 m
.82609 .50684 L
s
.589 .259 1 r
.78019 .50905 m
.78017 .50948 L
s
.99 .169 1 r
.86621 .44977 m
.87084 .49425 L
s
.846 .199 1 r
.58577 .44977 m
.58673 .49283 L
s
.559 .267 1 r
.30532 .44977 m
.3029 .49068 L
s
.383 .317 1 r
.65556 .48492 m
.65582 .4926 L
s
.65585 .49256 m
.65556 .48492 L
s
.65556 .48492 m
.65617 .50045 L
s
.42 .723 1 r
.48991 .47858 m
.48982 .48541 L
s
.48983 .48538 m
.48991 .47858 L
s
.48991 .47858 m
.48979 .49197 L
s
1 .151 .919 r
.5137 .51628 m
.51364 .51676 L
s
.433 .302 1 r
.39395 .50736 m
.39389 .50751 L
s
.711 .229 1 r
.68342 .49916 m
.68381 .50784 L
s
.68385 .50751 m
.68342 .49916 L
s
.384 .317 1 r
.49479 .49411 m
.49472 .50195 L
s
.49477 .50159 m
.49479 .49411 L
s
.711 .229 1 r
.68381 .50784 m
.68344 .49913 L
s
.68344 .49913 m
.68385 .50751 L
s
.384 .317 1 r
.49472 .50195 m
.49481 .49407 L
s
.49481 .49407 m
.49477 .50159 L
s
.46 .294 1 r
.7375 .44956 m
.74001 .48726 L
s
.531 .274 1 r
.45702 .44955 m
.45641 .48976 L
s
.916 .184 1 r
.32918 .488 m
.32864 .49711 L
s
.32866 .49708 m
.32918 .488 L
s
.32918 .488 m
.3282 .5059 L
s
.35 .415 1 r
.59572 .48106 m
.59585 .48858 L
s
.59586 .48855 m
.59572 .48106 L
s
.59572 .48106 m
.59604 .49579 L
s
.618 .252 1 r
.49974 .50976 m
.49969 .51008 L
s
.57764 .49769 m
.57776 .50615 L
s
.57781 .50582 m
.57764 .49769 L
s
.57776 .50615 m
.57766 .49766 L
s
.57766 .49766 m
.57781 .50582 L
s
.777 .214 1 r
.40293 .49973 m
.40262 .50855 L
s
.40269 .50822 m
.40293 .49973 L
s
.503 .282 1 r
.5498 .4838 m
.54983 .49197 L
s
.54985 .49193 m
.5498 .4838 L
s
.5498 .4838 m
.54993 .49982 L
s
.579 .262 1 r
.88927 .44934 m
.89371 .48955 L
s
.476 .29 1 r
.60875 .44934 m
.60988 .48812 L
s
.367 .322 1 r
.32823 .44934 m
.32628 .48669 L
s
.777 .214 1 r
.40262 .50855 m
.40295 .49969 L
s
.40295 .49969 m
.40269 .50822 L
s
.448 .828 1 r
.53583 .47685 m
.53583 .48344 L
s
.53585 .48341 m
.53583 .47685 L
s
.53583 .47685 m
.53589 .48972 L
s
.67 .239 1 r
.52684 .4852 m
.52682 .4938 L
s
.52683 .49377 m
.52684 .4852 L
s
.52684 .4852 m
.52687 .50202 L
s
.467 .292 1 r
.26514 .50751 m
.26508 .50769 L
s
.471 .907 1 r
.76052 .44913 m
.76271 .47902 L
s
.531 .274 1 r
.47997 .44913 m
.47965 .48862 L
s
.711 .229 1 r
.62853 .51103 m
.62849 .51135 L
s
.425 .305 1 r
.79832 .49397 m
.79895 .50196 L
s
.79896 .50153 m
.79832 .49397 L
s
.881 .191 1 r
.73437 .51307 m
.73434 .5135 L
s
.425 .305 1 r
.79895 .50196 m
.79835 .49394 L
s
.79835 .49394 m
.79896 .50153 L
s
.858 .196 1 r
.83525 .4998 m
.83606 .50884 L
s
.83607 .50837 m
.83525 .4998 L
s
.83606 .50884 m
.83528 .49977 L
s
.83528 .49977 m
.83607 .50837 L
s
.4 .312 1 r
.59162 .50562 m
.59157 .50583 L
s
.531 .274 1 r
.91233 .44891 m
.91692 .48805 L
s
.35 .414 1 r
.63175 .44891 m
.63302 .48449 L
s
.599 .257 1 r
.35116 .44891 m
.34937 .48841 L
s
.503 .282 1 r
.343 .49629 m
.34257 .50439 L
s
.34263 .50428 m
.343 .49629 L
s
.36 .325 1 r
.48578 .50394 m
.48573 .50429 L
s
.503 .282 1 r
.34257 .50439 m
.34302 .49626 L
s
.34302 .49626 m
.34263 .50428 L
s
.754 .219 1 r
.47676 .5123 m
.4767 .51245 L
s
.569 .264 1 r
.47181 .49707 m
.47168 .50535 L
s
.47174 .5052 m
.47181 .49707 L
s
.47168 .50535 m
.47183 .49703 L
s
.47183 .49703 m
.47174 .5052 L
s
.857 .196 1 r
.50387 .48755 m
.50379 .49649 L
s
.50381 .49645 m
.50387 .48755 L
s
.50387 .48755 m
.50378 .50528 L
s
.494 .284 1 r
.36596 .49531 m
.36558 .50344 L
s
.36565 .50316 m
.36596 .49531 L
s
.486 .956 1 r
.78356 .4487 m
.78589 .47788 L
s
.512 .279 1 r
.50294 .4487 m
.50287 .48855 L
s
.391 .315 1 r
.46693 .48194 m
.46678 .48979 L
s
.46679 .48976 m
.46693 .48194 L
s
.46693 .48194 m
.46669 .49736 L
s
.494 .284 1 r
.36558 .50344 m
.36598 .49528 L
s
.36598 .49528 m
.36565 .50316 L
s
1 .126 .786 r
.45793 .49025 m
.45771 .49988 L
s
.45773 .49984 m
.45793 .49025 L
s
.45793 .49025 m
.45758 .50932 L
s
.352 .327 1 r
.63758 .50373 m
.63754 .50404 L
s
.598 .257 1 r
.42098 .48482 m
.4207 .49318 L
s
.42072 .49314 m
.42098 .48482 L
s
.42098 .48482 m
.4205 .50139 L
s
.811 .206 1 r
.72949 .4989 m
.73001 .50783 L
s
.73004 .50739 m
.72949 .4989 L
s
.638 .247 1 r
.65475 .44848 m
.65649 .48941 L
s
.823 .204 1 r
.3741 .44848 m
.37245 .49084 L
s
.811 .206 1 r
.73001 .50783 m
.72951 .49886 L
s
.72951 .49886 m
.73004 .50739 L
s
.56 .267 1 r
.72049 .50725 m
.72046 .50767 L
s
.346 .329 1 r
.73852 .49082 m
.739 .49865 L
s
.73901 .49794 m
.73852 .49082 L
s
.648 .244 1 r
.5728 .48443 m
.57289 .49297 L
s
.57291 .49293 m
.5728 .48443 L
s
.5728 .48443 m
.57305 .50118 L
s
.346 .329 1 r
.739 .49865 m
.73854 .49078 L
s
.73854 .49078 m
.73901 .49794 L
s
.45 .297 1 r
.76646 .505 m
.76644 .50543 L
s
.54 .272 1 r
.44394 .48398 m
.44373 .49219 L
s
.44374 .49216 m
.44394 .48398 L
s
.44394 .48398 m
.44359 .50026 L
s
.88 .191 1 r
.67868 .48654 m
.67905 .49558 L
s
.67907 .49554 m
.67868 .48654 L
s
.67868 .48654 m
.67949 .5043 L
s
.711 .229 1 r
.26913 .48591 m
.26848 .49452 L
s
.26849 .49448 m
.26913 .48591 L
s
.26913 .48591 m
.2679 .50302 L
s
.393 .314 1 r
.8066 .44827 m
.80979 .48492 L
s
.99 .169 1 r
.52591 .44827 m
.52614 .49349 L
s
.476 .29 1 r
.24522 .44827 m
.2422 .48777 L
s
.788 .211 1 r
.70167 .48545 m
.70209 .49431 L
s
.70211 .49427 m
.70167 .48545 L
s
.70167 .48545 m
.70257 .50282 L
s
.628 .249 1 r
.2921 .48482 m
.29151 .49325 L
s
.29153 .49321 m
.2921 .48482 L
s
.2921 .48482 m
.291 .50154 L
s
.868 .194 1 r
.29698 .50024 m
.29638 .50921 L
s
.29645 .50902 m
.29698 .50024 L
s
.29638 .50921 m
.29699 .5002 L
s
.29699 .5002 m
.29645 .50902 L
s
.4 .312 1 r
.64175 .48127 m
.64199 .48916 L
s
.64201 .48913 m
.64175 .48127 L
s
.64175 .48127 m
.64229 .49673 L
s
.55 .269 1 r
.74764 .48321 m
.74815 .49149 L
s
.74817 .49146 m
.74764 .48321 L
s
.74764 .48321 m
.74871 .49949 L
s
.869 .194 1 r
.67777 .44806 m
.67991 .49149 L
s
.744 .222 1 r
.39704 .44806 m
.39569 .49006 L
s
.523 .277 1 r
.77063 .48194 m
.77119 .49022 L
s
.77121 .49019 m
.77063 .48194 L
s
.77063 .48194 m
.77179 .49801 L
s
.494 .285 1 r
.46279 .50683 m
.46273 .50701 L
s
.799 .209 1 r
.31994 .49926 m
.31941 .50808 L
s
.31948 .50789 m
.31994 .49926 L
s
.31941 .50808 m
.31996 .49922 L
s
.31996 .49922 m
.31948 .50789 L
s
.648 .244 1 r
.28795 .50887 m
.28787 .5092 L
s
.99 .169 1 r
.83058 .48664 m
.83137 .49594 L
s
.8314 .4959 m
.83058 .48664 L
s
.83058 .48664 m
.8322 .50481 L
s
.94 .179 1 r
.39797 .48731 m
.39761 .49643 L
s
.39763 .49639 m
.39797 .48731 L
s
.39797 .48731 m
.39733 .50537 L
s
.777 .214 1 r
.62366 .49827 m
.62391 .5071 L
s
.62396 .50677 m
.62366 .49827 L
s
.485 .287 1 r
.82966 .44784 m
.83334 .48735 L
s
.608 .254 1 r
.5489 .44784 m
.54938 .48842 L
s
.459 .295 1 r
.26814 .44784 m
.26541 .48699 L
s
.777 .214 1 r
.62391 .5071 m
.62369 .49824 L
s
.62369 .49824 m
.62396 .50677 L
s
.881 .191 1 r
.85359 .48559 m
.85441 .49467 L
s
.85444 .49463 m
.85359 .48559 L
s
.85359 .48559 m
.85529 .50332 L
s
.69 .234 1 r
.56869 .50923 m
.56864 .50959 L
s
.45 .297 1 r
.79365 .48117 m
.79425 .48923 L
s
.79427 .4892 m
.79365 .48117 L
s
.79365 .48117 m
.79489 .49688 L
s
.846 .199 1 r
.6746 .51127 m
.67457 .5117 L
s
.811 .206 1 r
.54571 .5107 m
.54565 .51114 L
s
1 .161 .972 r
.7066 .50186 m
.70708 .51113 L
s
.70713 .51101 m
.7066 .50186 L
s
.638 .247 1 r
.69759 .51014 m
.69753 .51011 L
s
.68 .237 1 r
.51777 .4968 m
.51774 .50541 L
s
.5178 .50508 m
.51777 .4968 L
s
1 .161 .972 r
.70708 .51113 m
.70662 .50183 L
s
.70662 .50183 m
.70713 .51101 L
s
.848 .198 1 r
.7008 .44763 m
.70316 .48964 L
s
.578 .262 1 r
.42 .44763 m
.41896 .48821 L
s
.68 .237 1 r
.51774 .50541 m
.51778 .49676 L
s
.51778 .49676 m
.5178 .50508 L
s
.347 .402 1 r
.53173 .50417 m
.53168 .50388 L
s
.512 .279 1 r
.41184 .49504 m
.41157 .50318 L
s
.41163 .50303 m
.41184 .49504 L
s
.857 .196 1 r
.72473 .48545 m
.72521 .49446 L
s
.72524 .49442 m
.72473 .48545 L
s
.72473 .48545 m
.72577 .50311 L
s
.512 .279 1 r
.41157 .50318 m
.41186 .49501 L
s
.41186 .49501 m
.41163 .50303 L
s
.377 .542 1 r
.77561 .4984 m
.7756 .49886 L
s
.578 .262 1 r
.38884 .49659 m
.38851 .50484 L
s
.38857 .50487 m
.38884 .49659 L
s
.388 .587 1 r
.85273 .44741 m
.85612 .48123 L
s
.588 .259 1 r
.5719 .44741 m
.57265 .48764 L
s
.342 .378 1 r
.78463 .49026 m
.7852 .49789 L
s
.78521 .49746 m
.78463 .49026 L
s
.503 .282 1 r
.29107 .44741 m
.28853 .48764 L
s
.669 .239 1 r
.43978 .50937 m
.43972 .50956 L
s
.578 .262 1 r
.38851 .50484 m
.38886 .49655 L
s
.38886 .49655 m
.38857 .50487 L
s
.342 .378 1 r
.7852 .49789 m
.78465 .49023 L
s
.78465 .49023 m
.78521 .49746 L
s
.836 .201 1 r
.61883 .48394 m
.61904 .49298 L
s
.61906 .49294 m
.61883 .48394 L
s
.61883 .48394 m
.61932 .50141 L
s
.375 .532 1 r
.75263 .49988 m
.75259 .50005 L
s
.777 .214 1 r
.41679 .51085 m
.41672 .51107 L
s
.788 .212 1 r
.31498 .48545 m
.31442 .49425 L
s
.31444 .49421 m
.31498 .48545 L
s
.31498 .48545 m
.31395 .5029 L
s
.425 .304 1 r
.27388 .5034 m
.2738 .50383 L
s
.45 .297 1 r
.72384 .4472 m
.72625 .48564 L
s
.733 .224 1 r
.44298 .4472 m
.44217 .48957 L
s
.669 .239 1 r
.31084 .50917 m
.31077 .50935 L
s
.531 .274 1 r
.50876 .506 m
.5087 .50632 L
s
.834 .201 1 r
.6467 .49843 m
.64701 .50736 L
s
.64706 .50707 m
.6467 .49843 L
s
.64701 .50736 m
.64673 .49839 L
s
.64673 .49839 m
.64706 .50707 L
s
.337 .353 1 r
.44879 .50171 m
.44874 .502 L
s
.722 .227 1 r
.66971 .49744 m
.67006 .50609 L
s
.67011 .50594 m
.66971 .49744 L
s
.408 .673 1 r
.47591 .47703 m
.47579 .48395 L
s
.4758 .48392 m
.47591 .47703 L
s
.47591 .47703 m
.47573 .49073 L
s
.848 .198 1 r
.87581 .44698 m
.88031 .489 L
s
.619 .251 1 r
.59491 .44698 m
.59593 .48758 L
s
.648 .244 1 r
.31402 .44698 m
.31164 .489 L
s
.722 .227 1 r
.67006 .50609 m
.66973 .4974 L
s
.66973 .4974 m
.67011 .50594 L
s
.589 .259 1 r
.66071 .5058 m
.66067 .50633 L
s
.69 .234 1 r
.25986 .49695 m
.25919 .50552 L
s
.25926 .50537 m
.25986 .49695 L
s
.744 .221 1 r
.54077 .49695 m
.5408 .5057 L
s
.54085 .50537 m
.54077 .49695 L
s
.559 .267 1 r
.58676 .49442 m
.5869 .50273 L
s
.58695 .50241 m
.58676 .49442 L
s
.69 .234 1 r
.25919 .50552 m
.25987 .49691 L
s
.25987 .49691 m
.25926 .50537 L
s
.744 .221 1 r
.5408 .5057 m
.54079 .49691 L
s
.54079 .49691 m
.54085 .50537 L
s
.559 .267 1 r
.5869 .50273 m
.58678 .49438 L
s
.58678 .49438 m
.58695 .50241 L
s
.393 .314 1 r
.60075 .5015 m
.60071 .50211 L
s
.569 .264 1 r
.4348 .49519 m
.43458 .50347 L
s
.43464 .50333 m
.4348 .49519 L
s
1 .153 .933 r
.87678 .48623 m
.8777 .49567 L
s
.87773 .49563 m
.87678 .48623 L
s
.87678 .48623 m
.87867 .50468 L
s
.569 .264 1 r
.43458 .50347 m
.43482 .49516 L
s
.43482 .49516 m
.43464 .50333 L
s
.669 .239 1 r
.56376 .49597 m
.56385 .50454 L
s
.56391 .50425 m
.56376 .49597 L
s
.416 .307 1 r
.63276 .49217 m
.633 .50009 L
s
.63305 .4998 m
.63276 .49217 L
s
.496 .284 1 r
.74689 .44677 m
.74951 .48451 L
s
.485 .287 1 r
.46596 .44677 m
.46547 .48629 L
s
.669 .239 1 r
.56385 .50454 m
.56379 .49593 L
s
.56379 .49593 m
.56391 .50425 L
s
.403 .652 1 r
.69275 .49665 m
.69272 .49696 L
s
.416 .307 1 r
.633 .50009 m
.63278 .49213 L
s
.63278 .49213 m
.63305 .4998 L
s
.777 .214 1 r
.36092 .48401 m
.36048 .49284 L
s
.36049 .49281 m
.36092 .48401 L
s
.36092 .48401 m
.36012 .50135 L
s
.503 .282 1 r
.25493 .48212 m
.25428 .49023 L
s
.25429 .4902 m
.25493 .48212 L
s
.25493 .48212 m
.2537 .49824 L
s
.845 .199 1 r
.3379 .48549 m
.3374 .4944 L
s
.33742 .49436 m
.3379 .48549 L
s
.3379 .48549 m
.33698 .5032 L
s
.7 .232 1 r
.33377 .50911 m
.3337 .50929 L
s
.383 .317 1 r
.4299 .4804 m
.42966 .48818 L
s
.42968 .48815 m
.4299 .4804 L
s
.4299 .4804 m
.4295 .49583 L
s
.468 .292 1 r
.8989 .44655 m
.90331 .48537 L
s
.777 .214 1 r
.61794 .44655 m
.61928 .48858 L
s
.512 .279 1 r
.33697 .44655 m
.33498 .48643 L
s
.64 .246 1 r
.60979 .494 m
.60999 .5026 L
s
.61003 .50199 m
.60979 .494 L
s
.531 .274 1 r
.55476 .50482 m
.55471 .50525 L
s
.512 .279 1 r
.4069 .48188 m
.4066 .49002 L
s
.40661 .48999 m
.4069 .48188 L
s
.4069 .48188 m
.40637 .49803 L
s
.68 .237 1 r
.78974 .50742 m
.78972 .50785 L
s
.64 .246 1 r
.60999 .5026 m
.60981 .49396 L
s
.60981 .49396 m
.61003 .50199 L
s
.38 .554 1 r
.82177 .49792 m
.82175 .49824 L
s
.722 .227 1 r
.28278 .49682 m
.28217 .50546 L
s
.28224 .50531 m
.28278 .49682 L
s
.628 .249 1 r
.30578 .49555 m
.30524 .50398 L
s
.30531 .50383 m
.30578 .49555 L
s
.503 .282 1 r
.35179 .49301 m
.35138 .50119 L
s
.35145 .50087 m
.35179 .49301 L
s
.744 .221 1 r
.76995 .44634 m
.77312 .48801 L
s
.69 .234 1 r
.48895 .44634 m
.48871 .48837 L
s
.722 .227 1 r
.28217 .50546 m
.28279 .49678 L
s
.28279 .49678 m
.28224 .50531 L
s
.581 .261 1 r
.7109 .48088 m
.71133 .48932 L
s
.71135 .48928 m
.7109 .48088 L
s
.7109 .48088 m
.7118 .49725 L
s
.628 .249 1 r
.30524 .50398 m
.3058 .49551 L
s
.3058 .49551 m
.30531 .50383 L
s
.503 .282 1 r
.35138 .50119 m
.35181 .49298 L
s
.35181 .49298 m
.35145 .50087 L
s
.42 .723 1 r
.48982 .48541 m
.48974 .49225 L
s
.48979 .49197 m
.48982 .48541 L
s
.48974 .49225 m
.48983 .48538 L
s
.48983 .48538 m
.48979 .49197 L
s
.459 .295 1 r
.42576 .50461 m
.4257 .50475 L
s
.69 .234 1 r
.38388 .48356 m
.38351 .49214 L
s
.38353 .49211 m
.38388 .48356 L
s
.38388 .48356 m
.38321 .50058 L
s
.598 .257 1 r
.37975 .50721 m
.37968 .50736 L
s
.34 .364 1 r
.77993 .47724 m
.78047 .48494 L
s
.78049 .48491 m
.77993 .47724 L
s
.77993 .47724 m
.78104 .49208 L
s
.45 .297 1 r
.37479 .49203 m
.37443 .50006 L
s
.3745 .49974 m
.37479 .49203 L
s
.37443 .50006 m
.3748 .492 L
s
.3748 .492 m
.3745 .49974 L
s
.541 .272 1 r
.92201 .44613 m
.92676 .48566 L
s
1 .161 .972 r
.64097 .44613 m
.64272 .49173 L
s
.799 .209 1 r
.35993 .44613 m
.35808 .48923 L
s
.57 .264 1 r
.58191 .48071 m
.58203 .48911 L
s
.58204 .48907 m
.58191 .48071 L
s
.58191 .48071 m
.5822 .49704 L
s
.503 .282 1 r
.85882 .5044 m
.8588 .50472 L
s
.766 .216 1 r
.61476 .51018 m
.6147 .51026 L
s
.701 .232 1 r
.68793 .48279 m
.6883 .49144 L
s
.68833 .4914 m
.68793 .48279 L
s
.68793 .48279 m
.68875 .49981 L
s
.448 .828 1 r
.53583 .48344 m
.53585 .49003 L
s
.53589 .48972 m
.53583 .48344 L
s
.608 .254 1 r
.48078 .49436 m
.48067 .50279 L
s
.48073 .5025 m
.48078 .49436 L
s
.485 .287 1 r
.76183 .49436 m
.76237 .50232 L
s
.76243 .5025 m
.76183 .49436 L
s
.448 .828 1 r
.53585 .49003 m
.53585 .48341 L
s
.53585 .48341 m
.53589 .48972 L
s
.733 .224 1 r
.35672 .50905 m
.35665 .50923 L
s
.608 .254 1 r
.48067 .50279 m
.4808 .49432 L
s
.4808 .49432 m
.48073 .5025 L
s
.485 .287 1 r
.76237 .50232 m
.76186 .49432 L
s
.76186 .49432 m
.76243 .5025 L
s
.932 .18 1 r
.86788 .4964 m
.86879 .5057 L
s
.86877 .5049 m
.86788 .4964 L
s
.383 .317 1 r
.65582 .4926 m
.65611 .50027 L
s
.65617 .50045 m
.65582 .4926 L
s
.845 .199 1 r
.79303 .44591 m
.79659 .48901 L
s
.559 .267 1 r
.51196 .44591 m
.512 .48651 L
s
.932 .18 1 r
.86879 .5057 m
.8679 .49636 L
s
.8679 .49636 m
.86877 .5049 L
s
.383 .317 1 r
.65611 .50027 m
.65585 .49256 L
s
.65585 .49256 m
.65617 .50045 L
s
.384 .317 1 r
.49477 .50159 m
.49472 .50195 L
s
.99 .169 1 r
.5129 .48507 m
.51283 .49434 L
s
.51285 .4943 m
.5129 .48507 L
s
.5129 .48507 m
.51286 .50328 L
s
.953 .176 1 r
.84489 .49795 m
.84573 .50718 L
s
.84575 .50674 m
.84489 .49795 L
s
.84573 .50718 m
.84491 .49791 L
s
.84491 .49791 m
.84575 .50674 L
s
.868 .194 1 r
.66494 .48458 m
.66528 .49356 L
s
.6653 .49352 m
.66494 .48458 L
s
.66494 .48458 m
.66568 .50236 L
s
.531 .274 1 r
.80791 .49239 m
.80858 .50067 L
s
.8086 .50024 m
.80791 .49239 L
s
.503 .282 1 r
.60494 .48022 m
.6051 .4884 L
s
.60512 .48837 m
.60494 .48022 L
s
.60494 .48022 m
.60533 .49627 L
s
.654 .243 1 r
.66402 .4457 m
.6658 .48487 L
s
.69 .234 1 r
.38291 .4457 m
.38138 .48773 L
s
.35 .415 1 r
.59585 .48858 m
.59599 .49611 L
s
.59604 .49579 m
.59585 .48858 L
s
.531 .274 1 r
.80858 .50067 m
.80794 .49235 L
s
.80794 .49235 m
.8086 .50024 L
s
.919 .183 1 r
.84004 .48285 m
.84084 .49208 L
s
.84087 .49204 m
.84004 .48285 L
s
.84004 .48285 m
.84168 .50066 L
s
.811 .206 1 r
.55892 .48286 m
.55898 .4918 L
s
.559 .49176 m
.55892 .48286 L
s
.55892 .48286 m
.55912 .50031 L
s
.513 .279 1 r
.75701 .47966 m
.75753 .48791 L
s
.75755 .48788 m
.75701 .47966 L
s
.75701 .47966 m
.7581 .4957 L
s
.68 .237 1 r
.86304 .48159 m
.86385 .49024 L
s
.86388 .49021 m
.86304 .48159 L
s
.86304 .48159 m
.86471 .49847 L
s
1 .111 .702 r
.52274 .5161 m
.52267 .5164 L
s
.35 .415 1 r
.59599 .49611 m
.59586 .48855 L
s
.59586 .48855 m
.59604 .49579 L
s
.966 .173 1 r
.71588 .49774 m
.71638 .50701 L
s
.71641 .50653 m
.71588 .49774 L
s
.638 .247 1 r
.30081 .48174 m
.30024 .49024 L
s
.30025 .49021 m
.30081 .48174 L
s
.30081 .48174 m
.29975 .49847 L
s
.966 .173 1 r
.71638 .50701 m
.7159 .4977 L
s
.7159 .4977 m
.71641 .50653 L
s
.826 .203 1 r
.73402 .48123 m
.73454 .49032 L
s
.73456 .49028 m
.73402 .48123 L
s
.73402 .48123 m
.73509 .49861 L
s
.63 .249 1 r
.81611 .44548 m
.81972 .48573 L
s
.658 .242 1 r
.53497 .44548 m
.53529 .48716 L
s
.754 .219 1 r
.25383 .44548 m
.25067 .48823 L
s
.711 .229 1 r
.68385 .50751 m
.68381 .50784 L
s
.588 .259 1 r
.3238 .48086 m
.32329 .48926 L
s
.32331 .48922 m
.3238 .48086 L
s
.3238 .48086 m
.32287 .49733 L
s
.4 .641 1 r
.69701 .47576 m
.69734 .48276 L
s
.69736 .48273 m
.69701 .47576 L
s
.69701 .47576 m
.69772 .48961 L
s
.618 .252 1 r
.57781 .50582 m
.57776 .50615 L
s
.503 .282 1 r
.54983 .49197 m
.54988 .50014 L
s
.54993 .49982 m
.54983 .49197 L
s
.425 .305 1 r
.79896 .50153 m
.79895 .50196 L
s
.733 .224 1 r
.68707 .44527 m
.68931 .48838 L
s
.41 .683 1 r
.4059 .44527 m
.40492 .47839 L
s
.503 .282 1 r
.54988 .50014 m
.54985 .49193 L
s
.54985 .49193 m
.54993 .49982 L
s
.833 .201 1 r
.27775 .48374 m
.27709 .49265 L
s
.27711 .49261 m
.27775 .48374 L
s
.27775 .48374 m
.27652 .50138 L
s
1 .154 .933 r
.8171 .48507 m
.81786 .49449 L
s
.81789 .49445 m
.8171 .48507 L
s
.8171 .48507 m
.81868 .50358 L
s
.777 .214 1 r
.40269 .50822 m
.40262 .50855 L
s
.424 .305 1 r
.83921 .44505 m
.84288 .48316 L
s
.418 .307 1 r
.558 .44505 m
.55854 .48174 L
s
.477 .289 1 r
.27679 .44505 m
.27418 .48388 L
s
.67 .239 1 r
.52682 .4938 m
.52681 .50242 L
s
.52687 .50202 m
.52682 .4938 L
s
.711 .229 1 r
.88621 .4817 m
.88708 .49039 L
s
.88711 .49035 m
.88621 .4817 L
s
.88621 .4817 m
.888 .49876 L
s
.67 .239 1 r
.52681 .50242 m
.52683 .49377 L
s
.52683 .49377 m
.52687 .50202 L
s
.766 .217 1 r
.45286 .48237 m
.45265 .49117 L
s
.45267 .49113 m
.45286 .48237 L
s
.45286 .48237 m
.45252 .49968 L
s
.916 .184 1 r
.32864 .49711 m
.32812 .50624 L
s
.3282 .5059 m
.32864 .49711 L
s
.32812 .50624 m
.32866 .49708 L
s
.32866 .49708 m
.3282 .5059 L
s
.503 .282 1 r
.34263 .50428 m
.34257 .50439 L
s
.735 .224 1 r
.71014 .44484 m
.71255 .48581 L
s
.81 .206 1 r
.4289 .44484 m
.42789 .48831 L
s
.705 .231 1 r
.80318 .47878 m
.80387 .48764 L
s
.80389 .4876 m
.80318 .47878 L
s
.80318 .47878 m
.80456 .49557 L
s
.346 .329 1 r
.73901 .49794 m
.739 .49865 L
s
.494 .284 1 r
.36565 .50316 m
.36558 .50344 L
s
.391 .315 1 r
.46678 .48979 m
.46664 .49764 L
s
.46669 .49736 m
.46678 .48979 L
s
.46664 .49764 m
.46679 .48976 L
s
.46679 .48976 m
.46669 .49736 L
s
.858 .196 1 r
.83607 .50837 m
.83606 .50884 L
s
.569 .264 1 r
.47174 .5052 m
.47168 .50535 L
s
.559 .267 1 r
.36978 .4798 m
.36938 .48813 L
s
.3694 .4881 m
.36978 .4798 L
s
.36978 .4798 m
.36907 .49614 L
s
.893 .189 1 r
.86232 .44462 m
.86672 .48738 L
s
.777 .214 1 r
.58104 .44462 m
.58194 .48702 L
s
.588 .259 1 r
.29976 .44462 m
.29732 .48488 L
s
.658 .242 1 r
.34673 .48146 m
.34627 .48997 L
s
.34628 .48993 m
.34673 .48146 L
s
.34673 .48146 m
.34589 .49834 L
s
.953 .176 1 r
.73322 .44441 m
.73611 .4886 L
s
.608 .254 1 r
.45191 .44441 m
.45124 .48503 L
s
.342 .378 1 r
.43884 .47643 m
.43863 .48403 L
s
.43865 .484 m
.43884 .47643 L
s
.43884 .47643 m
.43849 .49132 L
s
.598 .257 1 r
.4207 .49318 m
.42044 .50154 L
s
.4205 .50139 m
.4207 .49318 L
s
.42044 .50154 m
.42072 .49314 L
s
.42072 .49314 m
.4205 .50139 L
s
.857 .196 1 r
.50379 .49649 m
.50372 .50543 L
s
.50378 .50528 m
.50379 .49649 L
s
.50372 .50543 m
.50381 .49645 L
s
.50381 .49645 m
.50378 .50528 L
s
.811 .206 1 r
.73004 .50739 m
.73001 .50783 L
s
.54 .272 1 r
.44373 .49219 m
.44353 .50041 L
s
.44359 .50026 m
.44373 .49219 L
s
.461 .294 1 r
.87238 .47618 m
.87318 .48439 L
s
.8732 .48436 m
.87238 .47618 L
s
.87238 .47618 m
.87397 .49182 L
s
.559 .267 1 r
.88544 .44419 m
.88982 .4841 L
s
.477 .289 1 r
.60409 .44419 m
.6052 .48446 L
s
.638 .247 1 r
.32274 .44419 m
.32053 .48517 L
s
.54 .272 1 r
.44353 .50041 m
.44374 .49216 L
s
.44374 .49216 m
.44359 .50026 L
s
.648 .244 1 r
.57289 .49297 m
.573 .50151 L
s
.57305 .50118 m
.57289 .49297 L
s
.4 .312 1 r
.64199 .48916 m
.64225 .49705 L
s
.64229 .49673 m
.64199 .48916 L
s
.845 .199 1 r
.62807 .48212 m
.6283 .49111 L
s
.62833 .49107 m
.62807 .48212 L
s
.62807 .48212 m
.62861 .49976 L
s
.648 .244 1 r
.573 .50151 m
.57291 .49293 L
s
.57291 .49293 m
.57305 .50118 L
s
.4 .312 1 r
.64225 .49705 m
.64201 .48913 L
s
.64201 .48913 m
.64229 .49673 L
s
.711 .229 1 r
.26848 .49452 m
.26783 .50314 L
s
.2679 .50302 m
.26848 .49452 L
s
.628 .249 1 r
.29151 .49325 m
.29094 .50169 L
s
.291 .50154 m
.29151 .49325 L
s
.38 .553 1 r
.75631 .44397 m
.7588 .47854 L
s
.54 .272 1 r
.47493 .44397 m
.47454 .48424 L
s
.711 .229 1 r
.26783 .50314 m
.26849 .49448 L
s
.26849 .49448 m
.2679 .50302 L
s
.628 .249 1 r
.29094 .50169 m
.29153 .49321 L
s
.29153 .49321 m
.291 .50154 L
s
.55 .269 1 r
.74815 .49149 m
.74867 .49978 L
s
.74871 .49949 m
.74815 .49149 L
s
.523 .277 1 r
.77119 .49022 m
.77177 .49851 L
s
.77179 .49801 m
.77119 .49022 L
s
.521 .277 1 r
.26357 .47931 m
.26294 .4875 L
s
.26295 .48746 m
.26357 .47931 L
s
.26357 .47931 m
.26238 .49551 L
s
1 .126 .786 r
.45771 .49988 m
.45752 .50951 L
s
.45758 .50932 m
.45771 .49988 L
s
.55 .269 1 r
.74867 .49978 m
.74817 .49146 L
s
.74817 .49146 m
.74871 .49949 L
s
.523 .277 1 r
.77177 .49851 m
.77121 .49019 L
s
.77121 .49019 m
.77179 .49801 L
s
.766 .217 1 r
.65112 .48132 m
.65141 .49012 L
s
.65143 .49008 m
.65112 .48132 L
s
.65112 .48132 m
.65177 .49863 L
s
1 .126 .786 r
.45752 .50951 m
.45773 .49984 L
s
.45773 .49984 m
.45758 .50932 L
s
.658 .242 1 r
.52193 .48083 m
.5219 .48934 L
s
.52192 .4893 m
.52193 .48083 L
s
.52193 .48083 m
.52194 .49771 L
s
.88 .191 1 r
.67905 .49558 m
.67945 .50463 L
s
.67949 .5043 m
.67905 .49558 L
s
.788 .211 1 r
.70209 .49431 m
.70254 .50318 L
s
.70257 .50282 m
.70209 .49431 L
s
.342 .378 1 r
.78521 .49746 m
.7852 .49789 L
s
.868 .194 1 r
.29645 .50902 m
.29638 .50921 L
s
.45 .297 1 r
.79425 .48923 m
.79487 .4973 L
s
.79489 .49688 m
.79425 .48923 L
s
.88 .191 1 r
.67945 .50463 m
.67907 .49554 L
s
.67907 .49554 m
.67949 .5043 L
s
.559 .267 1 r
.90857 .44376 m
.91322 .48367 L
s
.62715 .44376 m
.62853 .48367 L
s
.494 .284 1 r
.34574 .44376 m
.34388 .48296 L
s
.788 .211 1 r
.70254 .50318 m
.70211 .49427 L
s
.70211 .49427 m
.70257 .50282 L
s
.45 .297 1 r
.79487 .4973 m
.79427 .4892 L
s
.79427 .4892 m
.79489 .49688 L
s
.799 .209 1 r
.31948 .50789 m
.31941 .50808 L
s
.777 .214 1 r
.62396 .50677 m
.62391 .5071 L
s
.368 .322 1 r
.6141 .47614 m
.61427 .48397 L
s
.61429 .48393 m
.6141 .47614 L
s
.6141 .47614 m
.61451 .4914 L
s
.68 .237 1 r
.54498 .48001 m
.545 .48863 L
s
.54502 .4886 m
.54498 .48001 L
s
.54498 .48001 m
.5451 .49693 L
s
.512 .279 1 r
.41163 .50303 m
.41157 .50318 L
s
.357 .45 1 r
.77941 .44354 m
.78223 .47918 L
s
.658 .242 1 r
.49796 .44354 m
.49783 .48525 L
s
.408 .673 1 r
.47579 .48395 m
.47568 .49086 L
s
.47573 .49073 m
.47579 .48395 L
s
.744 .221 1 r
.82644 .48012 m
.82717 .48892 L
s
.8272 .48888 m
.82644 .48012 L
s
.82644 .48012 m
.82796 .49729 L
s
.68 .237 1 r
.5178 .50508 m
.51774 .50541 L
s
.408 .673 1 r
.47568 .49086 m
.4758 .48392 L
s
.4758 .48392 m
.47573 .49073 L
s
.409 .309 1 r
.76636 .47576 m
.76689 .48376 L
s
.76692 .48372 m
.76636 .47576 L
s
.76636 .47576 m
.76746 .49119 L
s
.94 .179 1 r
.39761 .49643 m
.39727 .50556 L
s
.39733 .50537 m
.39761 .49643 L
s
.39727 .50556 m
.39763 .49639 L
s
.39763 .49639 m
.39733 .50537 L
s
.523 .277 1 r
.93171 .44333 m
.9365 .48218 L
s
.952 .176 1 r
.65023 .44333 m
.65209 .48861 L
s
.722 .227 1 r
.36874 .44333 m
.36702 .48575 L
s
.99 .169 1 r
.83137 .49594 m
.83218 .50525 L
s
.8322 .50481 m
.83137 .49594 L
s
.881 .191 1 r
.85441 .49467 m
.85527 .50376 L
s
.85529 .50332 m
.85441 .49467 L
s
.578 .262 1 r
.38857 .50487 m
.38851 .50484 L
s
.99 .169 1 r
.83218 .50525 m
.8314 .4959 L
s
.8314 .4959 m
.8322 .50481 L
s
.881 .191 1 r
.85527 .50376 m
.85444 .49463 L
s
.85444 .49463 m
.85529 .50332 L
s
.382 .563 1 r
.70631 .47181 m
.70667 .47916 L
s
.70669 .47913 m
.70631 .47181 L
s
.70631 .47181 m
.70706 .48581 L
s
.376 .534 1 r
.80253 .44311 m
.80532 .47554 L
s
.522 .277 1 r
.52101 .44311 m
.52115 .48303 L
s
.977 .171 1 r
.23948 .44311 m
.23597 .48804 L
s
.55 .269 1 r
.30956 .47836 m
.30902 .48666 L
s
.30903 .48662 m
.30956 .47836 L
s
.30956 .47836 m
.30857 .49467 L
s
1 .161 .972 r
.70713 .51101 m
.70708 .51113 L
s
1 .156 .947 r
.4989 .48353 m
.4988 .49288 L
s
.49882 .49284 m
.4989 .48353 L
s
.4989 .48353 m
.49878 .50205 L
s
.857 .196 1 r
.72521 .49446 m
.72573 .50348 L
s
.72577 .50311 m
.72521 .49446 L
s
.72573 .50348 m
.72524 .49442 L
s
.72524 .49442 m
.72577 .50311 L
s
.679 .237 1 r
.41574 .48044 m
.41545 .48899 L
s
.41547 .48896 m
.41574 .48044 L
s
.41574 .48044 m
.41523 .49744 L
s
.42 .723 1 r
.48979 .49197 m
.48974 .49225 L
s
.416 .307 1 r
.63305 .4998 m
.633 .50009 L
s
.744 .221 1 r
.28649 .48001 m
.28586 .48878 L
s
.28588 .48874 m
.28649 .48001 L
s
.28649 .48001 m
.28533 .49723 L
s
.559 .267 1 r
.58695 .50241 m
.5869 .50273 L
s
.504 .282 1 r
.67331 .4429 m
.67518 .48175 L
s
.69 .234 1 r
.39175 .4429 m
.39033 .48497 L
s
.744 .221 1 r
.72035 .47949 m
.72082 .48829 L
s
.72084 .48825 m
.72035 .47949 L
s
.72035 .47949 m
.72134 .49666 L
s
.788 .212 1 r
.31442 .49425 m
.31388 .50305 L
s
.31395 .5029 m
.31442 .49425 L
s
.448 .828 1 r
.53589 .48972 m
.53585 .49003 L
s
.836 .201 1 r
.61904 .49298 m
.61928 .50203 L
s
.61932 .50141 m
.61904 .49298 L
s
.834 .201 1 r
.64706 .50707 m
.64701 .50736 L
s
.788 .212 1 r
.31388 .50305 m
.31444 .49421 L
s
.31444 .49421 m
.31395 .5029 L
s
.836 .201 1 r
.61928 .50203 m
.61906 .49294 L
s
.61906 .49294 m
.61932 .50141 L
s
.569 .264 1 r
.43464 .50333 m
.43458 .50347 L
s
1 .153 .933 r
.67427 .48223 m
.67464 .49169 L
s
.67467 .49165 m
.67427 .48223 L
s
.67427 .48223 m
.67509 .50071 L
s
.722 .227 1 r
.67011 .50594 m
.67006 .50609 L
s
.928 .181 1 r
.39268 .4823 m
.39231 .4914 L
s
.39232 .49136 m
.39268 .4823 L
s
.39268 .4823 m
.39202 .50035 L
s
.69 .234 1 r
.25926 .50537 m
.25919 .50552 L
s
.744 .221 1 r
.54085 .50537 m
.5408 .5057 L
s
.383 .317 1 r
.42966 .48818 m
.42944 .49597 L
s
.4295 .49583 m
.42966 .48818 L
s
.82565 .44268 m
.82911 .48011 L
s
.7 .232 1 r
.54406 .44268 m
.5445 .48475 L
s
.512 .279 1 r
.26247 .44268 m
.25961 .48261 L
s
.383 .317 1 r
.42944 .49597 m
.42968 .48815 L
s
.42968 .48815 m
.4295 .49583 L
s
.669 .239 1 r
.56391 .50425 m
.56385 .50454 L
s
.503 .282 1 r
.25428 .49023 m
.25364 .49834 L
s
.2537 .49824 m
.25428 .49023 L
s
.857 .196 1 r
.56805 .48061 m
.56814 .48964 L
s
.56816 .4896 m
.56805 .48061 L
s
.56805 .48061 m
.5683 .4983 L
s
.503 .282 1 r
.25364 .49834 m
.25429 .4902 L
s
.25429 .4902 m
.2537 .49824 L
s
.485 .287 1 r
.48488 .47766 m
.48476 .48574 L
s
.48478 .48571 m
.48488 .47766 L
s
.48488 .47766 m
.48471 .49368 L
s
.64 .246 1 r
.61003 .50199 m
.60999 .5026 L
s
.352 .327 1 r
.69641 .44247 m
.69844 .47954 L
s
.375 .32 1 r
.41478 .44247 m
.41377 .47989 L
s
.512 .279 1 r
.4066 .49002 m
.40631 .49817 L
s
.40637 .49803 m
.4066 .49002 L
s
.503 .282 1 r
.35145 .50087 m
.35138 .50119 L
s
.34 .364 1 r
.78047 .48494 m
.78103 .49265 L
s
.78104 .49208 m
.78047 .48494 L
s
.512 .279 1 r
.40631 .49817 m
.40661 .48999 L
s
.40661 .48999 m
.40637 .49803 L
s
.34 .364 1 r
.78103 .49265 m
.78049 .48491 L
s
.78049 .48491 m
.78104 .49208 L
s
.4 .64 1 r
.75251 .4709 m
.75296 .47803 L
s
.75298 .478 m
.75251 .4709 L
s
.75251 .4709 m
.75343 .48461 L
s
.45 .297 1 r
.3745 .49974 m
.37443 .50006 L
s
.777 .214 1 r
.36048 .49284 m
.36005 .50168 L
s
.36012 .50135 m
.36048 .49284 L
s
.391 .315 1 r
.84879 .44225 m
.85253 .48004 L
s
.468 .292 1 r
.56713 .44225 m
.56779 .48075 L
s
.67 .239 1 r
.28547 .44225 m
.28274 .48433 L
s
.777 .214 1 r
.36005 .50168 m
.36049 .49281 L
s
.36049 .49281 m
.36012 .50135 L
s
.629 .249 1 r
.46181 .47945 m
.46163 .48787 L
s
.46165 .48783 m
.46181 .47945 L
s
.46181 .47945 m
.46153 .49624 L
s
.628 .249 1 r
.30531 .50383 m
.30524 .50398 L
s
1 .153 .933 r
.8777 .49567 m
.87866 .50513 L
s
.87867 .50468 m
.8777 .49567 L
s
.845 .199 1 r
.3374 .4944 m
.33691 .50331 L
s
.33698 .5032 m
.3374 .4944 L
s
.581 .261 1 r
.71133 .48932 m
.71178 .49776 L
s
.7118 .49725 m
.71133 .48932 L
s
1 .153 .933 r
.87866 .50513 m
.87773 .49563 L
s
.87773 .49563 m
.87867 .50468 L
s
.845 .199 1 r
.33691 .50331 m
.33742 .49436 L
s
.33742 .49436 m
.33698 .5032 L
s
.722 .227 1 r
.28224 .50531 m
.28217 .50546 L
s
1 .159 .959 r
.84976 .48167 m
.85061 .49106 L
s
.85063 .49102 m
.84976 .48167 L
s
.84976 .48167 m
.85151 .50008 L
s
.581 .261 1 r
.71178 .49776 m
.71135 .48928 L
s
.71135 .48928 m
.7118 .49725 L
s
.35 .415 1 r
.59604 .49579 m
.59599 .49611 L
s
.383 .317 1 r
.65617 .50045 m
.65611 .50027 L
s
.618 .252 1 r
.63725 .4779 m
.6375 .48638 L
s
.63752 .48635 m
.63725 .4779 L
s
.63725 .4779 m
.63781 .49454 L
s
.415 .702 1 r
.71951 .44204 m
.72149 .47412 L
s
.904 .186 1 r
.43782 .44203 m
.43691 .48626 L
s
.357 .451 1 r
.85881 .47347 m
.8595 .48093 L
s
.85953 .4809 m
.85881 .47347 L
s
.85881 .47347 m
.86024 .48808 L
s
.679 .237 1 r
.74351 .47991 m
.74402 .48843 L
s
.74404 .4884 m
.74351 .47991 L
s
.74351 .47991 m
.7446 .49695 L
s
.69 .234 1 r
.38351 .49214 m
.38315 .50073 L
s
.38321 .50058 m
.38351 .49214 L
s
.485 .287 1 r
.76243 .5025 m
.76237 .50232 L
s
.69 .234 1 r
.38315 .50073 m
.38353 .49211 L
s
.38353 .49211 m
.38321 .50058 L
s
.608 .254 1 r
.48073 .5025 m
.48067 .50279 L
s
.57 .264 1 r
.58203 .48911 m
.58216 .49751 L
s
.5822 .49704 m
.58203 .48911 L
s
.4 .641 1 r
.69734 .48276 m
.69768 .48975 L
s
.69772 .48961 m
.69734 .48276 L
s
.608 .254 1 r
.35554 .47826 m
.35511 .48667 L
s
.35512 .48663 m
.35554 .47826 L
s
.35554 .47826 m
.35475 .4949 L
s
.57 .264 1 r
.58216 .49751 m
.58204 .48907 L
s
.58204 .48907 m
.5822 .49704 L
s
.4 .641 1 r
.69768 .48975 m
.69736 .48273 L
s
.69736 .48273 m
.69772 .48961 L
s
.4 .312 1 r
.55406 .47516 m
.5541 .48306 L
s
.55412 .48302 m
.55406 .47516 L
s
.55406 .47516 m
.55421 .49064 L
s
.965 .174 1 r
.87194 .44182 m
.87669 .48677 L
s
.916 .184 1 r
.59021 .44182 m
.59125 .48569 L
s
.337 .353 1 r
.30848 .44182 m
.30634 .47854 L
s
.57 .264 1 r
.81274 .47649 m
.81341 .4849 L
s
.81343 .48486 m
.81274 .47649 L
s
.81274 .47649 m
.81412 .49284 L
s
.531 .274 1 r
.8086 .50024 m
.80858 .50067 L
s
.845 .199 1 r
.89596 .4798 m
.89689 .48879 L
s
.89691 .48875 m
.89596 .4798 L
s
.89596 .4798 m
.89787 .49746 L
s
.701 .232 1 r
.6883 .49144 m
.68871 .5001 L
s
.68875 .49981 m
.6883 .49144 L
s
.932 .18 1 r
.86877 .5049 m
.86879 .5057 L
s
.701 .232 1 r
.68871 .5001 m
.68833 .4914 L
s
.68833 .4914 m
.68875 .49981 L
s
.477 .289 1 r
.83582 .47547 m
.83653 .48363 L
s
.83655 .48359 m
.83582 .47547 L
s
.83582 .47547 m
.83727 .49135 L
s
.503 .282 1 r
.6051 .4884 m
.60528 .49659 L
s
.60533 .49627 m
.6051 .4884 L
s
.438 .79 1 r
.74263 .4416 m
.74476 .47263 L
s
.476 .29 1 r
.46087 .4416 m
.46032 .48118 L
s
.503 .282 1 r
.60528 .49659 m
.60512 .48837 L
s
.60512 .48837 m
.60533 .49627 L
s
.55 .269 1 r
.50793 .47826 m
.50786 .48645 L
s
.50788 .48642 m
.50793 .47826 L
s
.50793 .47826 m
.50787 .49469 L
s
.513 .279 1 r
.75753 .48791 m
.75808 .49617 L
s
.7581 .4957 m
.75753 .48791 L
s
.75808 .49617 m
.75755 .48788 L
s
.75755 .48788 m
.7581 .4957 L
s
.857 .196 1 r
.33244 .48041 m
.33191 .48936 L
s
.33193 .48932 m
.33244 .48041 L
s
.33244 .48041 m
.33148 .49817 L
s
.953 .176 1 r
.84575 .50674 m
.84573 .50718 L
s
1 .128 .799 r
.59117 .48177 m
.59133 .49149 L
s
.59135 .49145 m
.59117 .48177 L
s
.59117 .48177 m
.59156 .50073 L
s
.494 .284 1 r
.8951 .44139 m
.89951 .48061 L
s
.834 .201 1 r
.6133 .44139 m
.61461 .48419 L
s
.765 .217 1 r
.3315 .44139 m
.32929 .48419 L
s
.68 .237 1 r
.86385 .49024 m
.8647 .4989 L
s
.86471 .49847 m
.86385 .49024 L
s
.638 .247 1 r
.30024 .49024 m
.29968 .49876 L
s
.29975 .49847 m
.30024 .49024 L
s
.503 .282 1 r
.54993 .49982 m
.54988 .50014 L
s
.638 .247 1 r
.29968 .49876 m
.30025 .49021 L
s
.30025 .49021 m
.29975 .49847 L
s
.68 .237 1 r
.8647 .4989 m
.86388 .49021 L
s
.86388 .49021 m
.86471 .49847 L
s
.868 .194 1 r
.66528 .49356 m
.66563 .50255 L
s
.66568 .50236 m
.66528 .49356 L
s
.66563 .50255 m
.6653 .49352 L
s
.6653 .49352 m
.66568 .50236 L
s
.99 .169 1 r
.51283 .49434 m
.51279 .50362 L
s
.51286 .50328 m
.51283 .49434 L
s
.811 .206 1 r
.55898 .4918 m
.55906 .50075 L
s
.55912 .50031 m
.55898 .4918 L
s
.588 .259 1 r
.32329 .48926 m
.3228 .49766 L
s
.32287 .49733 m
.32329 .48926 L
s
.966 .173 1 r
.71641 .50653 m
.71638 .50701 L
s
.733 .224 1 r
.66039 .47836 m
.6607 .4871 L
s
.66073 .48706 m
.66039 .47836 L
s
.66039 .47836 m
.66108 .49555 L
s
.99 .169 1 r
.51279 .50362 m
.51285 .4943 L
s
.51285 .4943 m
.51286 .50328 L
s
.56 .267 1 r
.76576 .44117 m
.76873 .48076 L
s
.834 .201 1 r
.48393 .44117 m
.48361 .48505 L
s
.811 .206 1 r
.55906 .50075 m
.559 .49176 L
s
.559 .49176 m
.55912 .50031 L
s
.588 .259 1 r
.3228 .49766 m
.32331 .48922 L
s
.32331 .48922 m
.32287 .49733 L
s
.638 .247 1 r
.24916 .47783 m
.24847 .48632 L
s
.24848 .48628 m
.24916 .47783 L
s
.24916 .47783 m
.24785 .49462 L
s
.777 .214 1 r
.37855 .47854 m
.37815 .48738 L
s
.37817 .48734 m
.37855 .47854 L
s
.37855 .47854 m
.37784 .4959 L
s
.919 .183 1 r
.84084 .49208 m
.84168 .50132 L
s
.84168 .50066 m
.84084 .49208 L
s
.84168 .50132 m
.84087 .49204 L
s
.84087 .49204 m
.84168 .50066 L
s
.826 .203 1 r
.73454 .49032 m
.73508 .49941 L
s
.73509 .49861 m
.73454 .49032 L
s
1 .125 .781 r
.78982 .47941 m
.79054 .4893 L
s
.79057 .48926 m
.78982 .47941 L
s
.78982 .47941 m
.79129 .49826 L
s
.391 .315 1 r
.46669 .49736 m
.46664 .49764 L
s
.7 .232 1 r
.91827 .44096 m
.92329 .48305 L
s
.367 .322 1 r
.6364 .44096 m
.63783 .47947 L
s
.45 .297 1 r
.35453 .44096 m
.35281 .47947 L
s
.826 .203 1 r
.73508 .49941 m
.73456 .49028 L
s
.73456 .49028 m
.73509 .49861 L
s
.512 .279 1 r
.42468 .47639 m
.42442 .48455 L
s
.42444 .48451 m
.42468 .47639 L
s
.42468 .47639 m
.42424 .49257 L
s
.67 .239 1 r
.52687 .50202 m
.52681 .50242 L
s
.701 .232 1 r
.68349 .47773 m
.68386 .48639 L
s
.68389 .48635 m
.68349 .47773 L
s
.68349 .47773 m
.6843 .49477 L
s
.833 .201 1 r
.27709 .49265 m
.27644 .50156 L
s
.27652 .50138 m
.27709 .49265 L
s
.27644 .50156 m
.27711 .49261 L
s
.27711 .49261 m
.27652 .50138 L
s
.559 .267 1 r
.78891 .44074 m
.79217 .48069 L
s
.67 .239 1 r
.507 .44074 m
.50697 .48391 L
s
.711 .229 1 r
.88708 .49039 m
.88798 .49909 L
s
.888 .49876 m
.88708 .49039 L
s
.342 .378 1 r
.43863 .48403 m
.43843 .49164 L
s
.43849 .49132 m
.43863 .48403 L
s
.711 .229 1 r
.88798 .49909 m
.88711 .49035 L
s
.88711 .49035 m
.888 .49876 L
s
.342 .378 1 r
.43843 .49164 m
.43865 .484 L
s
.43865 .484 m
.43849 .49132 L
s
.766 .217 1 r
.45265 .49117 m
.45246 .49997 L
s
.45252 .49968 m
.45265 .49117 L
s
.744 .221 1 r
.27217 .47769 m
.2715 .48646 L
s
.27152 .48643 m
.27217 .47769 L
s
.27217 .47769 m
.27093 .49491 L
s
.916 .184 1 r
.3282 .5059 m
.32812 .50624 L
s
.778 .214 1 r
.94145 .44052 m
.94697 .48441 L
s
.513 .279 1 r
.65951 .44052 m
.66124 .47976 L
s
.744 .221 1 r
.37757 .44052 m
.37597 .48262 L
s
.766 .217 1 r
.45246 .49997 m
.45267 .49113 L
s
.45267 .49113 m
.45252 .49968 L
s
1 .154 .933 r
.81786 .49449 m
.81865 .50391 L
s
.81868 .50358 m
.81786 .49449 L
s
.559 .267 1 r
.36938 .48813 m
.369 .49646 L
s
.36907 .49614 m
.36938 .48813 L
s
1 .154 .933 r
.81865 .50391 m
.81789 .49445 L
s
.81789 .49445 m
.81868 .50358 L
s
.559 .267 1 r
.369 .49646 m
.3694 .4881 L
s
.3694 .4881 m
.36907 .49614 L
s
.705 .231 1 r
.80387 .48764 m
.80458 .49651 L
s
.80456 .49557 m
.80387 .48764 L
s
.80458 .49651 m
.80389 .4876 L
s
.80389 .4876 m
.80456 .49557 L
s
.691 .234 1 r
.40157 .47872 m
.40124 .48724 L
s
.40126 .48721 m
.40157 .47872 L
s
.40157 .47872 m
.40098 .49584 L
s
.471 .907 1 r
.76185 .46659 m
.76226 .47301 L
s
.76228 .47298 m
.76185 .46659 L
s
.76185 .46659 m
.76271 .47902 L
s
.4 .312 1 r
.64229 .49673 m
.64225 .49705 L
s
.346 .329 1 r
.81206 .44031 m
.81525 .47633 L
s
.347 .403 1 r
.53008 .44031 m
.53032 .47704 L
s
.416 .307 1 r
.24811 .44031 m
.24522 .47847 L
s
.598 .257 1 r
.4205 .50139 m
.42044 .50154 L
s
.588 .259 1 r
.31829 .47579 m
.31776 .4842 L
s
.31778 .48416 m
.31829 .47579 L
s
.31829 .47579 m
.31733 .49229 L
s
.658 .242 1 r
.34627 .48997 m
.34582 .49849 L
s
.34589 .49834 m
.34627 .48997 L
s
.365 .486 1 r
.82207 .47135 m
.82268 .47875 L
s
.8227 .47871 m
.82207 .47135 L
s
.82207 .47135 m
.82333 .48583 L
s
.658 .242 1 r
.34582 .49849 m
.34628 .48993 L
s
.34628 .48993 m
.34589 .49834 L
s
.54 .272 1 r
.44359 .50026 m
.44353 .50041 L
s
.408 .673 1 r
.47573 .49073 m
.47568 .49086 L
s
.486 .956 1 r
.78496 .46574 m
.78541 .47202 L
s
.78543 .47199 m
.78496 .46574 L
s
.78496 .46574 m
.78589 .47788 L
s
.461 .294 1 r
.87318 .48439 m
.874 .49261 L
s
.87397 .49182 m
.87318 .48439 L
s
.375 .532 1 r
.68264 .44009 m
.68446 .47612 L
s
.822 .204 1 r
.40063 .44009 m
.39926 .48363 L
s
.461 .294 1 r
.874 .49261 m
.8732 .48436 L
s
.8732 .48436 m
.87397 .49182 L
s
.648 .244 1 r
.57305 .50118 m
.573 .50151 L
s
.523 .277 1 r
.77179 .49801 m
.77177 .49851 L
s
.638 .247 1 r
.88231 .47625 m
.88316 .48477 L
s
.88319 .48473 m
.88231 .47625 L
s
.88231 .47625 m
.88406 .49301 L
s
.45 .297 1 r
.79489 .49688 m
.79487 .4973 L
s
.55 .269 1 r
.74871 .49949 m
.74867 .49978 L
s
.857 .196 1 r
.50378 .50528 m
.50372 .50543 L
s
1 .143 .881 r
.83522 .43987 m
.83957 .48557 L
s
.559 .267 1 r
.55318 .43987 m
.5537 .47983 L
s
.69 .234 1 r
.27114 .43987 m
.26828 .48126 L
s
.628 .249 1 r
.291 .50154 m
.29094 .50169 L
s
.521 .277 1 r
.26294 .4875 m
.26231 .49569 L
s
.26238 .49551 m
.26294 .4875 L
s
1 .164 .984 r
.53103 .48048 m
.53101 .48973 L
s
.53104 .48969 m
.53103 .48048 L
s
.53103 .48048 m
.53108 .49891 L
s
.521 .277 1 r
.26231 .49569 m
.26295 .48746 L
s
.26295 .48746 m
.26238 .49551 L
s
.711 .229 1 r
.2679 .50302 m
.26783 .50314 L
s
.461 .294 1 r
.69268 .47173 m
.69305 .47995 L
s
.69307 .47992 m
.69268 .47173 L
s
.69268 .47173 m
.69346 .4874 L
s
.368 .322 1 r
.61427 .48397 m
.61447 .49179 L
s
.61451 .4914 m
.61427 .48397 L
s
.99 .169 1 r
.70577 .43966 m
.70834 .48427 L
s
.904 .186 1 r
.42369 .43966 m
.4226 .48391 L
s
.368 .322 1 r
.61447 .49179 m
.61429 .48393 L
s
.61429 .48393 m
.61451 .4914 L
s
.845 .199 1 r
.6283 .49111 m
.62856 .5001 L
s
.62861 .49976 m
.6283 .49111 L
s
.62856 .5001 m
.62833 .49107 L
s
.62833 .49107 m
.62861 .49976 L
s
.658 .242 1 r
.5219 .48934 m
.52188 .49786 L
s
.52194 .49771 m
.5219 .48934 L
s
.788 .211 1 r
.70257 .50282 m
.70254 .50318 L
s
.649 .244 1 r
.77601 .47526 m
.7766 .48385 L
s
.77663 .48381 m
.77601 .47526 L
s
.77601 .47526 m
.77725 .49201 L
s
.658 .242 1 r
.52188 .49786 m
.52192 .4893 L
s
.52192 .4893 m
.52194 .49771 L
s
.382 .563 1 r
.70667 .47916 m
.70705 .48652 L
s
.70706 .48581 m
.70667 .47916 L
s
.598 .257 1 r
.3413 .47596 m
.34083 .48434 L
s
.34085 .48431 m
.3413 .47596 L
s
.3413 .47596 m
.34044 .49258 L
s
.766 .217 1 r
.65141 .49012 m
.65172 .49893 L
s
.65177 .49863 m
.65141 .49012 L
s
.382 .563 1 r
.70705 .48652 m
.70669 .47913 L
s
.70669 .47913 m
.70706 .48581 L
s
.409 .309 1 r
.76689 .48376 m
.76745 .49176 L
s
.76746 .49119 m
.76689 .48376 L
s
.99 .169 1 r
.8584 .43944 m
.86295 .48406 L
s
.723 .226 1 r
.57629 .43944 m
.57713 .48263 L
s
.494 .285 1 r
.29417 .43944 m
.2917 .47904 L
s
.766 .217 1 r
.65172 .49893 m
.65143 .49008 L
s
.65143 .49008 m
.65177 .49863 L
s
.953 .176 1 r
.72984 .47801 m
.73035 .48725 L
s
.73038 .48721 m
.72984 .47801 L
s
.72984 .47801 m
.73093 .49607 L
s
.88 .191 1 r
.67949 .5043 m
.67945 .50463 L
s
.409 .309 1 r
.76745 .49176 m
.76692 .48372 L
s
.76692 .48372 m
.76746 .49119 L
s
.337 .353 1 r
.84532 .4718 m
.846 .47946 L
s
.84603 .47942 m
.84532 .4718 L
s
.84532 .4718 m
.84673 .48683 L
s
.68 .237 1 r
.545 .48863 m
.54504 .49726 L
s
.5451 .49693 m
.545 .48863 L
s
.72892 .43923 m
.73158 .48062 L
s
.69 .234 1 r
.44677 .43923 m
.44601 .48134 L
s
.68 .237 1 r
.54504 .49726 m
.54502 .4886 L
s
.54502 .4886 m
.5451 .49693 L
s
.777 .214 1 r
.4708 .47716 m
.47064 .48598 L
s
.47066 .48594 m
.4708 .47716 L
s
.4708 .47716 m
.47055 .49458 L
s
.56 .267 1 r
.66963 .47399 m
.66995 .48236 L
s
.66997 .48233 m
.66963 .47399 L
s
.66963 .47399 m
.67033 .49031 L
s
1 .126 .786 r
.45758 .50932 m
.45752 .50951 L
s
.744 .221 1 r
.82717 .48892 m
.82794 .49773 L
s
.82796 .49729 m
.82717 .48892 L
s
.916 .184 1 r
.29507 .47928 m
.29444 .48832 L
s
.29446 .48828 m
.29507 .47928 L
s
.29507 .47928 m
.29389 .49735 L
s
.744 .221 1 r
.82794 .49773 m
.8272 .48888 L
s
.8272 .48888 m
.82796 .49729 L
s
1 .149 .907 r
.57724 .47942 m
.57736 .48889 L
s
.57738 .48885 m
.57724 .47942 L
s
.57724 .47942 m
.57755 .49807 L
s
.965 .174 1 r
.88159 .43901 m
.88647 .48399 L
s
.441 .3 1 r
.5994 .43901 m
.60043 .47755 L
s
.433 .302 1 r
.31722 .43901 m
.3151 .47719 L
s
.977 .171 1 r
.4477 .47889 m
.44747 .48811 L
s
.44749 .48807 m
.4477 .47889 L
s
.4477 .47889 m
.44732 .49714 L
s
.68 .237 1 r
.79919 .47504 m
.79985 .48371 L
s
.79987 .48367 m
.79919 .47504 L
s
.79919 .47504 m
.80055 .49195 L
s
.55 .269 1 r
.30902 .48666 m
.30849 .49496 L
s
.30857 .49467 m
.30902 .48666 L
s
.881 .191 1 r
.85529 .50332 m
.85527 .50376 L
s
.55 .269 1 r
.30849 .49496 m
.30903 .48662 L
s
.30903 .48662 m
.30857 .49467 L
s
.94 .179 1 r
.39733 .50537 m
.39727 .50556 L
s
.99 .169 1 r
.8322 .50481 m
.83218 .50525 L
s
.383 .317 1 r
.4295 .49583 m
.42944 .49597 L
s
.648 .244 1 r
.36434 .476 m
.36392 .48449 L
s
.36394 .48445 m
.36434 .476 L
s
.36434 .476 m
.36358 .49287 L
s
1 .143 .88 r
.60036 .4786 m
.60054 .48818 L
s
.60056 .48814 m
.60036 .4786 L
s
.60036 .4786 m
.60079 .49729 L
s
.799 .209 1 r
.75208 .43879 m
.75512 .48163 L
s
.7 .232 1 r
.46986 .43879 m
.46939 .48091 L
s
.34 .364 1 r
.78104 .49208 m
.78103 .49265 L
s
.4 .64 1 r
.75296 .47803 m
.75342 .48517 L
s
.75343 .48461 m
.75296 .47803 L
s
.679 .237 1 r
.41545 .48899 m
.41517 .49755 L
s
.41523 .49744 m
.41545 .48899 L
s
.4 .64 1 r
.75342 .48517 m
.75298 .478 L
s
.75298 .478 m
.75343 .48461 L
s
.857 .196 1 r
.72577 .50311 m
.72573 .50348 L
s
.679 .237 1 r
.41517 .49755 m
.41547 .48896 L
s
.41547 .48896 m
.41523 .49744 L
s
.424 .305 1 r
.71588 .4724 m
.71629 .48038 L
s
.71632 .48034 m
.71588 .4724 L
s
.71588 .4724 m
.71676 .48804 L
s
.765 .217 1 r
.62346 .47762 m
.62368 .48633 L
s
.6237 .4863 m
.62346 .47762 L
s
.62346 .47762 m
.62398 .49508 L
s
.836 .201 1 r
.61932 .50141 m
.61928 .50203 L
s
.941 .179 1 r
.90572 .47773 m
.9067 .48691 L
s
.90673 .48687 m
.90572 .47773 L
s
.90572 .47773 m
.90773 .4958 L
s
.503 .282 1 r
.2537 .49824 m
.25364 .49834 L
s
.6 .256 1 r
.90479 .43858 m
.90941 .47855 L
s
.35 .415 1 r
.62253 .43858 m
.62373 .47462 L
s
.55 .269 1 r
.34028 .43858 m
.33831 .4789 L
s
.744 .221 1 r
.28586 .48878 m
.28525 .49756 L
s
.28533 .49723 m
.28586 .48878 L
s
.788 .212 1 r
.31395 .5029 m
.31388 .50305 L
s
.744 .221 1 r
.28525 .49756 m
.28588 .48874 L
s
.28588 .48874 m
.28533 .49723 L
s
.46 .294 1 r
.73902 .47151 m
.73949 .47967 L
s
.73952 .47964 m
.73902 .47151 L
s
.73902 .47151 m
.74001 .48726 L
s
.744 .221 1 r
.72082 .48829 m
.72131 .4971 L
s
.72134 .49666 m
.72082 .48829 L
s
.485 .287 1 r
.48476 .48574 m
.48466 .49383 L
s
.48471 .49368 m
.48476 .48574 L
s
.744 .221 1 r
.72131 .4971 m
.72084 .48825 L
s
.72084 .48825 m
.72134 .49666 L
s
.4 .641 1 r
.69772 .48961 m
.69768 .48975 L
s
.485 .287 1 r
.48466 .49383 m
.48478 .48571 L
s
.48478 .48571 m
.48471 .49368 L
s
1 .156 .947 r
.4988 .49288 m
.49872 .50224 L
s
.49878 .50205 m
.4988 .49288 L
s
.35 .414 1 r
.63255 .46975 m
.63276 .47733 L
s
.63278 .4773 m
.63255 .46975 L
s
.63255 .46975 m
.63302 .48449 L
s
.512 .279 1 r
.40637 .49803 m
.40631 .49817 L
s
.869 .194 1 r
.64659 .47688 m
.64688 .48591 L
s
.64691 .48588 m
.64659 .47688 L
s
.64659 .47688 m
.64724 .49466 L
s
1 .156 .947 r
.49872 .50224 m
.49882 .49284 L
s
.49882 .49284 m
.49878 .50205 L
s
.347 .401 1 r
.77525 .43836 m
.778 .47369 L
s
1 .161 .972 r
.49296 .43836 m
.49276 .48335 L
s
.754 .219 1 r
.517 .47639 m
.51696 .48513 L
s
.51698 .48509 m
.517 .47639 L
s
.517 .47639 m
.51699 .49373 L
s
.357 .451 1 r
.8595 .48093 m
.86022 .4884 L
s
.86024 .48808 m
.8595 .48093 L
s
.86022 .4884 m
.85953 .4809 L
s
.85953 .4809 m
.86024 .48808 L
s
.367 .322 1 r
.32714 .47137 m
.32667 .47918 L
s
.32668 .47914 m
.32714 .47137 L
s
.32714 .47137 m
.32628 .48669 L
s
.928 .181 1 r
.39231 .4914 m
.39195 .50051 L
s
.39202 .50035 m
.39231 .4914 L
s
.39195 .50051 m
.39232 .49136 L
s
.39232 .49136 m
.39202 .50035 L
s
.811 .206 1 r
.928 .43814 m
.93319 .48063 L
s
.638 .247 1 r
.64567 .43814 m
.64735 .48027 L
s
.559 .267 1 r
.36335 .43814 m
.36167 .47812 L
s
.581 .261 1 r
.7118 .49725 m
.71178 .49776 L
s
.857 .196 1 r
.56814 .48964 m
.56824 .49867 L
s
.5683 .4983 m
.56814 .48964 L
s
.69 .234 1 r
.25778 .47554 m
.2571 .48414 L
s
.25711 .4841 m
.25778 .47554 L
s
.25778 .47554 m
.25649 .4926 L
s
.857 .196 1 r
.56824 .49867 m
.56816 .4896 L
s
.56816 .4896 m
.5683 .4983 L
s
.845 .199 1 r
.3874 .47621 m
.38702 .4852 L
s
.38703 .48517 m
.3874 .47621 L
s
.3874 .47621 m
.38672 .49388 L
s
1 .153 .933 r
.67464 .49169 m
.67504 .50115 L
s
.67509 .50071 m
.67464 .49169 L
s
.629 .249 1 r
.46163 .48787 m
.46147 .49629 L
s
.46153 .49624 m
.46163 .48787 L
s
1 .153 .933 r
.67504 .50115 m
.67467 .49165 L
s
.67467 .49165 m
.67509 .50071 L
s
.777 .214 1 r
.36012 .50135 m
.36005 .50168 L
s
.629 .249 1 r
.46147 .49629 m
.46165 .48783 L
s
.46165 .48783 m
.46153 .49624 L
s
.701 .232 1 r
.54012 .47582 m
.54013 .48443 L
s
.54015 .48439 m
.54012 .47582 L
s
.54012 .47582 m
.54021 .49296 L
s
.659 .242 1 r
.79843 .43793 m
.8019 .47898 L
s
.68 .237 1 r
.51607 .43793 m
.51617 .47898 L
s
.701 .232 1 r
.23371 .43792 m
.23037 .4797 L
s
.57 .264 1 r
.5822 .49704 m
.58216 .49751 L
s
.4 .312 1 r
.5541 .48306 m
.55416 .49096 L
s
.55421 .49064 m
.5541 .48306 L
s
.628 .249 1 r
.28087 .47469 m
.28025 .48315 L
s
.28026 .48311 m
.28087 .47469 L
s
.28087 .47469 m
.27971 .49146 L
s
.648 .244 1 r
.43361 .47409 m
.43336 .48265 L
s
.43338 .48261 m
.43361 .47409 L
s
.43361 .47409 m
.43319 .49089 L
s
.476 .29 1 r
.60947 .47218 m
.60964 .48031 L
s
.60966 .48028 m
.60947 .47218 L
s
.60947 .47218 m
.60988 .48812 L
s
.4 .312 1 r
.55416 .49096 m
.55412 .48302 L
s
.55412 .48302 m
.55421 .49064 L
s
.618 .252 1 r
.6375 .48638 m
.63777 .49487 L
s
.63781 .49454 m
.6375 .48638 L
s
.63777 .49487 m
.63752 .48635 L
s
.63752 .48635 m
.63781 .49454 L
s
.69 .234 1 r
.38321 .50058 m
.38315 .50073 L
s
.679 .237 1 r
.74402 .48843 m
.74455 .49696 L
s
.7446 .49695 m
.74402 .48843 L
s
.845 .199 1 r
.33698 .5032 m
.33691 .50331 L
s
.834 .201 1 r
.95122 .43771 m
.95679 .48092 L
s
.403 .651 1 r
.66883 .43771 m
.67038 .4709 L
s
.823 .204 1 r
.38643 .43771 m
.38493 .4802 L
s
.679 .237 1 r
.74455 .49696 m
.74404 .4884 L
s
.74404 .4884 m
.7446 .49695 L
s
.608 .254 1 r
.35511 .48667 m
.35469 .49508 L
s
.35475 .4949 m
.35511 .48667 L
s
.503 .282 1 r
.60533 .49627 m
.60528 .49659 L
s
.608 .254 1 r
.35469 .49508 m
.35512 .48663 L
s
.35512 .48663 m
.35475 .4949 L
s
1 .153 .933 r
.87867 .50468 m
.87866 .50513 L
s
.513 .279 1 r
.7581 .4957 m
.75808 .49617 L
s
.57 .264 1 r
.81341 .4849 m
.8141 .49331 L
s
.81412 .49284 m
.81341 .4849 L
s
.477 .289 1 r
.83653 .48363 m
.83726 .49178 L
s
.83727 .49135 m
.83653 .48363 L
s
.57 .264 1 r
.8141 .49331 m
.81343 .48486 L
s
.81343 .48486 m
.81412 .49284 L
s
.477 .289 1 r
.83726 .49178 m
.83655 .48359 L
s
.83655 .48359 m
.83727 .49135 L
s
.393 .314 1 r
.80851 .46956 m
.80913 .47755 L
s
.80916 .47751 m
.80851 .46956 L
s
.80851 .46956 m
.80979 .48492 L
s
.777 .214 1 r
.41048 .476 m
.41016 .48478 L
s
.41018 .48474 m
.41048 .476 L
s
.41048 .476 m
.40992 .49346 L
s
.531 .274 1 r
.45671 .47346 m
.45653 .48166 L
s
.45654 .48162 m
.45671 .47346 L
s
.45671 .47346 m
.45641 .48976 L
s
.392 .314 1 r
.82162 .43749 m
.82505 .47497 L
s
.701 .232 1 r
.68875 .49981 m
.68871 .5001 L
s
.799 .209 1 r
.53919 .43749 m
.53958 .4807 L
s
.512 .279 1 r
.25676 .43749 m
.25383 .47748 L
s
.559 .267 1 r
.30393 .4742 m
.30338 .48244 L
s
.3034 .4824 m
.30393 .4742 L
s
.30393 .4742 m
.3029 .49068 L
s
.55 .269 1 r
.50786 .48645 m
.50781 .49465 L
s
.50787 .49469 m
.50786 .48645 L
s
1 .131 .814 r
.49389 .47939 m
.49377 .48897 L
s
.4938 .48893 m
.49389 .47939 L
s
.49389 .47939 m
.49374 .49845 L
s
.388 .587 1 r
.85476 .4672 m
.85542 .47443 L
s
.85545 .47439 m
.85476 .4672 L
s
.85476 .4672 m
.85612 .48123 L
s
.55 .269 1 r
.50781 .49465 m
.50788 .48642 L
s
.50788 .48642 m
.50787 .49469 L
s
1 .159 .959 r
.85061 .49106 m
.85148 .50045 L
s
.85151 .50008 m
.85061 .49106 L
s
.531 .274 1 r
.47984 .47239 m
.4797 .48067 L
s
.47972 .48063 m
.47984 .47239 L
s
.47984 .47239 m
.47965 .48862 L
s
.579 .262 1 r
.89194 .47307 m
.8928 .48145 L
s
.89283 .48141 m
.89194 .47307 L
s
.89194 .47307 m
.89371 .48955 L
s
.917 .184 1 r
.56326 .47568 m
.56333 .48486 L
s
.56336 .48482 m
.56326 .47568 L
s
.56326 .47568 m
.56348 .4936 L
s
1 .159 .959 r
.85148 .50045 m
.85063 .49102 L
s
.85063 .49102 m
.85151 .50008 L
s
.531 .274 1 r
.91508 .47186 m
.91598 .48017 L
s
.91601 .48014 m
.91508 .47186 L
s
.91508 .47186 m
.91692 .48805 L
s
.599 .257 1 r
.35017 .47193 m
.34972 .48046 L
s
.34973 .48042 m
.35017 .47193 L
s
.35017 .47193 m
.34937 .48841 L
s
.541 .272 1 r
.69199 .43727 m
.6941 .47654 L
s
.459 .295 1 r
.40953 .43727 m
.40839 .47655 L
s
.845 .199 1 r
.89689 .48879 m
.89785 .49779 L
s
.89787 .49746 m
.89689 .48879 L
s
.89785 .49779 m
.89691 .48875 L
s
.89691 .48875 m
.89787 .49746 L
s
.68 .237 1 r
.86471 .49847 m
.8647 .4989 L
s
.638 .247 1 r
.29975 .49847 m
.29968 .49876 L
s
.588 .259 1 r
.32287 .49733 m
.3228 .49766 L
s
.471 .907 1 r
.76226 .47301 m
.7627 .47943 L
s
.76271 .47902 m
.76226 .47301 L
s
.7627 .47943 m
.76228 .47298 L
s
.76228 .47298 m
.76271 .47902 L
s
.639 .247 1 r
.84483 .43706 m
.84882 .47776 L
s
.811 .206 1 r
.56233 .43706 m
.563 .47991 L
s
.722 .227 1 r
.27983 .43706 m
.277 .47956 L
s
.846 .199 1 r
.5864 .47515 m
.58653 .48415 L
s
.58655 .48411 m
.5864 .47515 L
s
.5864 .47515 m
.58673 .49283 L
s
.857 .196 1 r
.33191 .48936 m
.33141 .49832 L
s
.33148 .49817 m
.33191 .48936 L
s
.486 .956 1 r
.78541 .47202 m
.78588 .4783 L
s
.78589 .47788 m
.78541 .47202 L
s
.857 .196 1 r
.33141 .49832 m
.33193 .48932 L
s
.33193 .48932 m
.33148 .49817 L
s
.486 .956 1 r
.78588 .4783 m
.78543 .47199 L
s
.78543 .47199 m
.78589 .47788 L
s
.811 .206 1 r
.55912 .50031 m
.55906 .50075 L
s
.342 .378 1 r
.43849 .49132 m
.43843 .49164 L
s
.638 .247 1 r
.24847 .48632 m
.24778 .49481 L
s
.24785 .49462 m
.24847 .48632 L
s
.868 .194 1 r
.66568 .50236 m
.66563 .50255 L
s
.845 .199 1 r
.71517 .43684 m
.71777 .48006 L
s
.799 .209 1 r
.43263 .43684 m
.43168 .48006 L
s
.638 .247 1 r
.24778 .49481 m
.24848 .48628 L
s
.24848 .48628 m
.24785 .49462 L
s
.733 .224 1 r
.6607 .4871 m
.66104 .49584 L
s
.66108 .49555 m
.6607 .4871 L
s
.826 .203 1 r
.73509 .49861 m
.73508 .49941 L
s
.512 .279 1 r
.42442 .48455 m
.42418 .49271 L
s
.42424 .49257 m
.42442 .48455 L
s
.50295 .47236 m
.50288 .48053 L
s
.50289 .48049 m
.50295 .47236 L
s
.50295 .47236 m
.50287 .48855 L
s
.733 .224 1 r
.66104 .49584 m
.66073 .48706 L
s
.66073 .48706 m
.66108 .49555 L
s
.512 .279 1 r
.42418 .49271 m
.42444 .48451 L
s
.42444 .48451 m
.42424 .49257 L
s
.919 .183 1 r
.84168 .50066 m
.84168 .50132 L
s
.99 .169 1 r
.51286 .50328 m
.51279 .50362 L
s
.777 .214 1 r
.37815 .48738 m
.37777 .49623 L
s
.37784 .4959 m
.37815 .48738 L
s
.88 .191 1 r
.86804 .43662 m
.87261 .4802 L
s
.599 .257 1 r
.58547 .43662 m
.58638 .47662 L
s
.649 .244 1 r
.3029 .43662 m
.30045 .47769 L
s
.777 .214 1 r
.37777 .49623 m
.37817 .48734 L
s
.37817 .48734 m
.37784 .4959 L
s
.99 .169 1 r
.869 .47599 m
.86989 .48528 L
s
.86992 .48524 m
.869 .47599 L
s
.869 .47599 m
.87084 .49425 L
s
1 .128 .799 r
.59133 .49149 m
.59151 .50122 L
s
.59156 .50073 m
.59133 .49149 L
s
.701 .232 1 r
.68386 .48639 m
.68425 .49506 L
s
.6843 .49477 m
.68386 .48639 L
s
1 .128 .799 r
.59151 .50122 m
.59135 .49145 L
s
.59135 .49145 m
.59156 .50073 L
s
.701 .232 1 r
.68425 .49506 m
.68389 .48635 L
s
.68389 .48635 m
.6843 .49477 L
s
.365 .486 1 r
.82268 .47875 m
.82331 .48614 L
s
.82333 .48583 m
.82268 .47875 L
s
.82331 .48614 m
.8227 .47871 L
s
.8227 .47871 m
.82333 .48583 L
s
.559 .267 1 r
.36907 .49614 m
.369 .49646 L
s
.476 .29 1 r
.24348 .47176 m
.24281 .47982 L
s
.24282 .47978 m
.24348 .47176 L
s
.24348 .47176 m
.2422 .48777 L
s
.488 .286 1 r
.73835 .43641 m
.74088 .4739 L
s
1 .131 .814 r
.45575 .43641 m
.45502 .48358 L
s
.711 .229 1 r
.888 .49876 m
.88798 .49909 L
s
.705 .231 1 r
.80456 .49557 m
.80458 .49651 L
s
.833 .201 1 r
.27652 .50138 m
.27644 .50156 L
s
.461 .294 1 r
.87397 .49182 m
.874 .49261 L
s
.638 .247 1 r
.65583 .47264 m
.65613 .48117 L
s
.65615 .48113 m
.65583 .47264 L
s
.65583 .47264 m
.65649 .48941 L
s
.766 .217 1 r
.45252 .49968 m
.45246 .49997 L
s
.904 .186 1 r
.89127 .43619 m
.89617 .48013 L
s
.744 .221 1 r
.60863 .43619 m
.60986 .47798 L
s
.359 .325 1 r
.32599 .43619 m
.32398 .47404 L
s
.744 .221 1 r
.2715 .48646 m
.27085 .49524 L
s
.27093 .49491 m
.2715 .48646 L
s
.382 .563 1 r
.70706 .48581 m
.70705 .48652 L
s
.459 .295 1 r
.26658 .47108 m
.26596 .47911 L
s
.26597 .47907 m
.26658 .47108 L
s
.26658 .47108 m
.26541 .48699 L
s
.744 .221 1 r
.27085 .49524 m
.27152 .48643 L
s
.27152 .48643 m
.27093 .49491 L
s
.691 .234 1 r
.40124 .48724 m
.40093 .49578 L
s
.40098 .49584 m
.40124 .48724 L
s
.40093 .49578 m
.40126 .48721 L
s
.40126 .48721 m
.40098 .49584 L
s
1 .125 .781 r
.79054 .4893 m
.7913 .4992 L
s
.79129 .49826 m
.79054 .4893 L
s
.485 .287 1 r
.8319 .4713 m
.83259 .47939 L
s
.83261 .47936 m
.8319 .4713 L
s
.8319 .4713 m
.83334 .48735 L
s
.588 .259 1 r
.31776 .4842 m
.31725 .49262 L
s
.31733 .49229 m
.31776 .4842 L
s
1 .125 .781 r
.7913 .4992 m
.79057 .48926 L
s
.79057 .48926 m
.79129 .49826 L
s
.638 .247 1 r
.76155 .43597 m
.76458 .47705 L
s
.733 .224 1 r
.47888 .43597 m
.47852 .47813 L
s
.658 .242 1 r
.34589 .49834 m
.34582 .49849 L
s
.823 .204 1 r
.3732 .4733 m
.37278 .48231 L
s
.37279 .48227 m
.3732 .4733 L
s
.3732 .4733 m
.37245 .49084 L
s
.588 .259 1 r
.31725 .49262 m
.31778 .48416 L
s
.31778 .48416 m
.31733 .49229 L
s
1 .154 .933 r
.81868 .50358 m
.81865 .50391 L
s
.368 .322 1 r
.61451 .4914 m
.61447 .49179 L
s
.521 .277 1 r
.26238 .49551 m
.26231 .49569 L
s
.45 .297 1 r
.72531 .46984 m
.72575 .4779 L
s
.72577 .47787 m
.72531 .46984 L
s
.72531 .46984 m
.72625 .48564 L
s
.608 .254 1 r
.54924 .47179 m
.54927 .48025 L
s
.54929 .48021 m
.54924 .47179 L
s
.54924 .47179 m
.54938 .48842 L
s
.618 .252 1 r
.91451 .43575 m
.91933 .47647 L
s
.658 .242 1 r
.6318 .43575 m
.6333 .47755 L
s
.733 .224 1 r
.34909 .43575 m
.34712 .47827 L
s
.496 .284 1 r
.74846 .4686 m
.74897 .47691 L
s
.749 .47688 m
.74846 .4686 L
s
.74846 .4686 m
.74951 .48451 L
s
.638 .247 1 r
.88316 .48477 m
.88404 .4933 L
s
.88406 .49301 m
.88316 .48477 L
s
.409 .309 1 r
.76746 .49119 m
.76745 .49176 L
s
.638 .247 1 r
.88404 .4933 m
.88319 .48473 L
s
.88319 .48473 m
.88406 .49301 L
s
.744 .222 1 r
.39631 .47281 m
.39595 .4816 L
s
.39597 .48156 m
.39631 .47281 L
s
.39631 .47281 m
.39569 .49006 L
s
.461 .294 1 r
.69305 .47995 m
.69345 .48818 L
s
.69346 .4874 m
.69305 .47995 L
s
.766 .217 1 r
.78476 .43554 m
.78818 .47805 L
s
.659 .242 1 r
.50202 .43554 m
.50193 .47805 L
s
.461 .294 1 r
.69345 .48818 m
.69307 .47992 L
s
.69307 .47992 m
.69346 .4874 L
s
.578 .262 1 r
.41944 .47168 m
.41916 .48003 L
s
.41918 .48 m
.41944 .47168 L
s
.41944 .47168 m
.41896 .48821 L
s
.337 .353 1 r
.846 .47946 m
.84671 .48711 L
s
.84673 .48683 m
.846 .47946 L
s
.588 .259 1 r
.5724 .47111 m
.57249 .47954 L
s
.57251 .4795 m
.5724 .47111 L
s
.5724 .47111 m
.57265 .48764 L
s
.4 .64 1 r
.75343 .48461 m
.75342 .48517 L
s
.337 .353 1 r
.84671 .48711 m
.84603 .47942 L
s
.84603 .47942 m
.84673 .48683 L
s
.41 .683 1 r
.40537 .46475 m
.40511 .47173 L
s
.40512 .4717 m
.40537 .46475 L
s
.40537 .46475 m
.40492 .47839 L
s
.589 .259 1 r
.93776 .43532 m
.94277 .47533 L
s
.777 .214 1 r
.65498 .43532 m
.65679 .47748 L
s
.765 .217 1 r
.3722 .43532 m
.3705 .4782 L
s
.658 .242 1 r
.52194 .49771 m
.52188 .49786 L
s
.848 .198 1 r
.70223 .47206 m
.70267 .48117 L
s
.70269 .48113 m
.70223 .47206 L
s
.70223 .47206 m
.70316 .48964 L
s
.503 .282 1 r
.28961 .47143 m
.28904 .47954 L
s
.28905 .4795 m
.28961 .47143 L
s
.28961 .47143 m
.28853 .48764 L
s
.598 .257 1 r
.34083 .48434 m
.34038 .49273 L
s
.34044 .49258 m
.34083 .48434 L
s
.845 .199 1 r
.62861 .49976 m
.62856 .5001 L
s
.598 .257 1 r
.34038 .49273 m
.34085 .48431 L
s
.34085 .48431 m
.34044 .49258 L
s
.649 .244 1 r
.7766 .48385 m
.77722 .49245 L
s
.77725 .49201 m
.7766 .48385 L
s
.766 .217 1 r
.65177 .49863 m
.65172 .49893 L
s
.649 .244 1 r
.77722 .49245 m
.77663 .48381 L
s
.77663 .48381 m
.77725 .49201 L
s
1 .164 .984 r
.53101 .48973 m
.53102 .49899 L
s
.53108 .49891 m
.53101 .48973 L
s
.869 .194 1 r
.67909 .47369 m
.67946 .48274 L
s
.67949 .4827 m
.67909 .47369 L
s
.67909 .47369 m
.67991 .49149 L
s
1 .164 .984 r
.53102 .49899 m
.53104 .48969 L
s
.53104 .48969 m
.53108 .49891 L
s
.459 .294 1 r
.80798 .4351 m
.81135 .47368 L
s
.857 .196 1 r
.52517 .4351 m
.52538 .47906 L
s
.766 .217 1 r
.24235 .4351 m
.23906 .47762 L
s
.68 .237 1 r
.5451 .49693 m
.54504 .49726 L
s
.468 .292 1 r
.90155 .46945 m
.9024 .47755 L
s
.90243 .47752 m
.90155 .46945 L
s
.90155 .46945 m
.90331 .48537 L
s
.56 .267 1 r
.66995 .48236 m
.6703 .49074 L
s
.67033 .49031 m
.66995 .48236 L
s
.6703 .49074 m
.66997 .48233 L
s
.66997 .48233 m
.67033 .49031 L
s
.485 .287 1 r
.46572 .47023 m
.46556 .47833 L
s
.46558 .4783 m
.46572 .47023 L
s
.46572 .47023 m
.46547 .48629 L
s
.619 .251 1 r
.59557 .4709 m
.59572 .4794 L
s
.59574 .47936 m
.59557 .4709 L
s
.59557 .4709 m
.59593 .48758 L
s
.55 .269 1 r
.30857 .49467 m
.30849 .49496 L
s
1 .164 .985 r
.96102 .43489 m
.96696 .47992 L
s
.56 .267 1 r
.67817 .43488 m
.68014 .47454 L
s
.722 .227 1 r
.39532 .43488 m
.39392 .47741 L
s
.744 .221 1 r
.82796 .49729 m
.82794 .49773 L
s
.953 .176 1 r
.73035 .48725 m
.73089 .49651 L
s
.73093 .49607 m
.73035 .48725 L
s
.777 .214 1 r
.47064 .48598 m
.47049 .4948 L
s
.47055 .49458 m
.47064 .48598 L
s
.953 .176 1 r
.73089 .49651 m
.73038 .48721 L
s
.73038 .48721 m
.73093 .49607 L
s
.777 .214 1 r
.47049 .4948 m
.47066 .48594 L
s
.47066 .48594 m
.47055 .49458 L
s
.99 .169 1 r
.52611 .47514 m
.52608 .48437 L
s
.52611 .48433 m
.52611 .47514 L
s
.52611 .47514 m
.52614 .49349 L
s
.424 .305 1 r
.71629 .48038 m
.71673 .48836 L
s
.71676 .48804 m
.71629 .48038 L
s
.496 .284 1 r
.83121 .43467 m
.83482 .47289 L
s
.648 .244 1 r
.54833 .43467 m
.54881 .47576 L
s
.578 .262 1 r
.26545 .43467 m
.26251 .47612 L
s
.357 .451 1 r
.86024 .48808 m
.86022 .4884 L
s
.424 .305 1 r
.71673 .48836 m
.71632 .48034 L
s
.71632 .48034 m
.71676 .48804 L
s
.848 .198 1 r
.87849 .47142 m
.87938 .48054 L
s
.87941 .4805 m
.87849 .47142 L
s
.87849 .47142 m
.88031 .489 L
s
.68 .237 1 r
.79985 .48371 m
.80053 .49238 L
s
.80055 .49195 m
.79985 .48371 L
s
.512 .279 1 r
.33585 .47023 m
.33538 .4784 L
s
.33539 .47837 m
.33585 .47023 L
s
.33585 .47023 m
.33498 .48643 L
s
.35 .414 1 r
.63276 .47733 m
.63299 .48491 L
s
.63302 .48449 m
.63276 .47733 L
s
.68 .237 1 r
.80053 .49238 m
.79987 .48367 L
s
.79987 .48367 m
.80055 .49195 L
s
.916 .184 1 r
.29444 .48832 m
.29383 .49736 L
s
.29389 .49735 m
.29444 .48832 L
s
.35 .414 1 r
.63299 .48491 m
.63278 .4773 L
s
.63278 .4773 m
.63302 .48449 L
s
.648 .244 1 r
.36392 .48449 m
.36352 .49299 L
s
.36358 .49287 m
.36392 .48449 L
s
.916 .184 1 r
.29383 .49736 m
.29446 .48828 L
s
.29446 .48828 m
.29389 .49735 L
s
.648 .244 1 r
.36352 .49299 m
.36394 .48445 L
s
.36394 .48445 m
.36358 .49287 L
s
.733 .224 1 r
.44256 .47231 m
.44232 .48103 L
s
.44234 .48099 m
.44256 .47231 L
s
.44256 .47231 m
.44217 .48957 L
s
.679 .237 1 r
.41523 .49744 m
.41517 .49755 L
s
.723 .226 1 r
.70138 .43445 m
.70371 .4759 L
s
.569 .264 1 r
.41846 .43445 m
.41739 .47519 L
s
.485 .287 1 r
.48471 .49368 m
.48466 .49383 L
s
.46 .294 1 r
.73949 .47967 m
.74 .48783 L
s
.74001 .48726 m
.73949 .47967 L
s
.541 .272 1 r
.92485 .46938 m
.92578 .47769 L
s
.92581 .47766 m
.92485 .46938 L
s
.92485 .46938 m
.92676 .48566 L
s
.977 .171 1 r
.44747 .48811 m
.44725 .49733 L
s
.44732 .49714 m
.44747 .48811 L
s
.46 .294 1 r
.74 .48783 m
.73952 .47964 L
s
.73952 .47964 m
.74001 .48726 L
s
.418 .307 1 r
.55837 .46626 m
.55842 .47436 L
s
.55844 .47432 m
.55837 .46626 L
s
.55837 .46626 m
.55854 .48174 L
s
.977 .171 1 r
.44725 .49733 m
.44749 .48807 L
s
.44749 .48807 m
.44732 .49714 L
s
.648 .244 1 r
.31266 .47207 m
.31211 .48053 L
s
.31213 .4805 m
.31266 .47207 L
s
.31266 .47207 m
.31164 .489 L
s
.367 .322 1 r
.32667 .47918 m
.32621 .48698 L
s
.32628 .48669 m
.32667 .47918 L
s
.654 .243 1 r
.66511 .46823 m
.66543 .47698 L
s
.66545 .47694 m
.66511 .46823 L
s
.66511 .46823 m
.6658 .48487 L
s
1 .149 .907 r
.57736 .48889 m
.57749 .49837 L
s
.57755 .49807 m
.57736 .48889 L
s
.367 .322 1 r
.32621 .48698 m
.32668 .47914 L
s
.32668 .47914 m
.32628 .48669 L
s
.765 .217 1 r
.62368 .48633 m
.62392 .49505 L
s
.62398 .49508 m
.62368 .48633 L
s
.744 .221 1 r
.28533 .49723 m
.28525 .49756 L
s
1 .149 .907 r
.57749 .49837 m
.57738 .48885 L
s
.57738 .48885 m
.57755 .49807 L
s
.765 .217 1 r
.62392 .49505 m
.6237 .4863 L
s
.6237 .4863 m
.62398 .49508 L
s
.722 .227 1 r
.85446 .43423 m
.85875 .47676 L
s
.8 .209 1 r
.5715 .43423 m
.57229 .47712 L
s
.69 .234 1 r
.28855 .43423 m
.28585 .4764 L
s
.744 .221 1 r
.72134 .49666 m
.72131 .4971 L
s
.777 .214 1 r
.61878 .47121 m
.619 .48011 L
s
.61902 .48007 m
.61878 .47121 L
s
.61878 .47121 m
.61928 .48858 L
s
.471 .907 1 r
.76271 .47902 m
.7627 .47943 L
s
.4 .312 1 r
.55421 .49064 m
.55416 .49096 L
s
.834 .201 1 r
.72459 .43401 m
.72732 .47727 L
s
.54 .272 1 r
.4416 .43401 m
.44081 .4744 L
s
1 .143 .88 r
.60054 .48818 m
.60074 .49777 L
s
.60079 .49729 m
.60054 .48818 L
s
.941 .179 1 r
.9067 .48691 m
.90771 .49609 L
s
.90773 .4958 m
.9067 .48691 L
s
.744 .221 1 r
.77187 .47079 m
.77247 .47961 L
s
.7725 .47958 m
.77187 .47079 L
s
.77187 .47079 m
.77312 .48801 L
s
.486 .956 1 r
.78589 .47788 m
.78588 .4783 L
s
1 .143 .88 r
.60074 .49777 m
.60056 .48814 L
s
.60056 .48814 m
.60079 .49729 L
s
.941 .179 1 r
.90771 .49609 m
.90673 .48687 L
s
.90673 .48687 m
.90773 .4958 L
s
.754 .219 1 r
.51696 .48513 m
.51693 .49388 L
s
.51699 .49373 m
.51696 .48513 L
s
.51693 .49388 m
.51698 .48509 L
s
.51698 .48509 m
.51699 .49373 L
s
.869 .194 1 r
.64688 .48591 m
.64719 .49496 L
s
.64724 .49466 m
.64688 .48591 L
s
.64719 .49496 m
.64691 .48588 L
s
.64691 .48588 m
.64724 .49466 L
s
.629 .249 1 r
.46153 .49624 m
.46147 .49629 L
s
.531 .274 1 r
.87771 .4338 m
.88199 .47346 L
s
.649 .244 1 r
.59469 .4338 m
.59572 .47454 L
s
.578 .262 1 r
.31166 .4338 m
.30933 .47454 L
s
.376 .534 1 r
.80416 .4615 m
.80475 .46902 L
s
.80477 .46899 m
.80416 .4615 L
s
.80416 .4615 m
.80532 .47554 L
s
1 .156 .947 r
.49878 .50205 m
.49872 .50224 L
s
.388 .587 1 r
.85542 .47443 m
.85611 .48165 L
s
.85612 .48123 m
.85542 .47443 L
s
.69 .234 1 r
.2571 .48414 m
.25642 .49275 L
s
.25649 .4926 m
.2571 .48414 L
s
.388 .587 1 r
.85611 .48165 m
.85545 .47439 L
s
.85545 .47439 m
.85612 .48123 L
s
.476 .29 1 r
.60964 .48031 m
.60984 .48844 L
s
.60988 .48812 m
.60964 .48031 L
s
.69 .234 1 r
.48887 .47129 m
.48875 .4799 L
s
.48877 .47986 m
.48887 .47129 L
s
.48887 .47129 m
.48871 .48837 L
s
.857 .196 1 r
.5683 .4983 m
.56824 .49867 L
s
.69 .234 1 r
.25642 .49275 m
.25711 .4841 L
s
.25711 .4841 m
.25649 .4926 L
s
.559 .267 1 r
.51204 .47005 m
.51198 .47833 L
s
.512 .4783 m
.51204 .47005 L
s
.51204 .47005 m
.512 .48651 L
s
.476 .29 1 r
.60984 .48844 m
.60966 .48028 L
s
.60966 .48028 m
.60988 .48812 L
s
.424 .305 1 r
.84142 .4675 m
.84212 .47549 L
s
.84215 .47546 m
.84142 .4675 L
s
.84142 .4675 m
.84288 .48316 L
s
.38 .553 1 r
.75782 .46431 m
.75829 .47158 L
s
.75831 .47155 m
.75782 .46431 L
s
.75782 .46431 m
.7588 .47854 L
s
.618 .252 1 r
.63781 .49454 m
.63777 .49487 L
s
.928 .181 1 r
.39202 .50035 m
.39195 .50051 L
s
.477 .289 1 r
.83727 .49135 m
.83726 .49178 L
s
.701 .232 1 r
.54013 .48443 m
.54016 .49304 L
s
.54021 .49296 m
.54013 .48443 L
s
.628 .249 1 r
.28025 .48315 m
.27964 .49161 L
s
.27971 .49146 m
.28025 .48315 L
s
.701 .232 1 r
.54016 .49304 m
.54015 .48439 L
s
.54015 .48439 m
.54021 .49296 L
s
.953 .176 1 r
.74782 .43358 m
.75091 .47791 L
s
.833 .201 1 r
.46476 .43358 m
.4642 .47719 L
s
.628 .249 1 r
.27964 .49161 m
.28026 .48311 L
s
.28026 .48311 m
.27971 .49146 L
s
.57 .264 1 r
.81412 .49284 m
.8141 .49331 L
s
.63 .249 1 r
.81828 .46905 m
.81898 .47762 L
s
.819 .47758 m
.81828 .46905 L
s
.81828 .46905 m
.81972 .48573 L
s
.845 .199 1 r
.38702 .4852 m
.38665 .49421 L
s
.38672 .49388 m
.38702 .4852 L
s
.648 .244 1 r
.43336 .48265 m
.43313 .49122 L
s
.43319 .49089 m
.43336 .48265 L
s
.393 .314 1 r
.80913 .47755 m
.80979 .48553 L
s
.80979 .48492 m
.80913 .47755 L
s
.845 .199 1 r
.38665 .49421 m
.38703 .48517 L
s
.38703 .48517 m
.38672 .49388 L
s
.608 .254 1 r
.35475 .4949 m
.35469 .49508 L
s
.648 .244 1 r
.43313 .49122 m
.43338 .48261 L
s
.43338 .48261 m
.43319 .49089 L
s
1 .153 .933 r
.67509 .50071 m
.67504 .50115 L
s
.477 .289 1 r
.27531 .46792 m
.2747 .47606 L
s
.27472 .47602 m
.27531 .46792 L
s
.27531 .46792 m
.27418 .48388 L
s
.393 .314 1 r
.80979 .48553 m
.80916 .47751 L
s
.80916 .47751 m
.80979 .48492 L
s
.679 .237 1 r
.7446 .49695 m
.74455 .49696 L
s
.531 .274 1 r
.45653 .48166 m
.45636 .48987 L
s
.45641 .48976 m
.45653 .48166 L
s
.424 .305 1 r
.90098 .43336 m
.90536 .4716 L
s
.352 .327 1 r
.61789 .43336 m
.61907 .47017 L
s
.467 .292 1 r
.33479 .43336 m
.33276 .47339 L
s
.531 .274 1 r
.45636 .48987 m
.45654 .48162 L
s
.45654 .48162 m
.45641 .48976 L
s
.559 .267 1 r
.30338 .48244 m
.30285 .49068 L
s
.3029 .49068 m
.30338 .48244 L
s
.55 .269 1 r
.50787 .49469 m
.50781 .49465 L
s
.559 .267 1 r
.30285 .49068 m
.3034 .4824 L
s
.3034 .4824 m
.3029 .49068 L
s
.531 .274 1 r
.4797 .48067 m
.47959 .48894 L
s
.47965 .48862 m
.4797 .48067 L
s
.799 .209 1 r
.35889 .47167 m
.35844 .48054 L
s
.35846 .4805 m
.35889 .47167 L
s
.35889 .47167 m
.35808 .48923 L
s
.531 .274 1 r
.47959 .48894 m
.47972 .48063 L
s
.47972 .48063 m
.47965 .48862 L
s
.579 .262 1 r
.8928 .48145 m
.89369 .48984 L
s
.89371 .48955 m
.8928 .48145 L
s
.531 .274 1 r
.91598 .48017 m
.91692 .48848 L
s
.91692 .48805 m
.91598 .48017 L
s
.846 .199 1 r
.77105 .43314 m
.77435 .47605 L
s
.744 .221 1 r
.48792 .43314 m
.48768 .47497 L
s
.579 .262 1 r
.89369 .48984 m
.89283 .48141 L
s
.89283 .48141 m
.89371 .48955 L
s
.531 .274 1 r
.91692 .48848 m
.91601 .48014 L
s
.91601 .48014 m
.91692 .48805 L
s
.777 .214 1 r
.41016 .48478 m
.40986 .49357 L
s
.40992 .49346 m
.41016 .48478 L
s
.69 .234 1 r
.38206 .47065 m
.38168 .47926 L
s
.3817 .47922 m
.38206 .47065 L
s
.38206 .47065 m
.38138 .48773 L
s
.777 .214 1 r
.40986 .49357 m
.41018 .48474 L
s
.41018 .48474 m
.40992 .49346 L
s
.845 .199 1 r
.79519 .47132 m
.79586 .48033 L
s
.79589 .48029 m
.79519 .47132 L
s
.79519 .47132 m
.79659 .48901 L
s
.599 .257 1 r
.34972 .48046 m
.34928 .48899 L
s
.34937 .48841 m
.34972 .48046 L
s
.34928 .48899 m
.34973 .48042 L
s
.34973 .48042 m
.34937 .48841 L
s
.658 .242 1 r
.53522 .47022 m
.53522 .47876 L
s
.53524 .47873 m
.53522 .47022 L
s
.53522 .47022 m
.53529 .48716 L
s
.599 .257 1 r
.92426 .43292 m
.92912 .47296 L
s
.505 .281 1 r
.6411 .43292 m
.64259 .47117 L
s
.8 .209 1 r
.35793 .43292 m
.35605 .47583 L
s
.357 .45 1 r
.78112 .46452 m
.78165 .47201 L
s
.78167 .47197 m
.78112 .46452 L
s
.78112 .46452 m
.78223 .47918 L
s
.365 .486 1 r
.82333 .48583 m
.82331 .48614 L
s
.845 .199 1 r
.89787 .49746 m
.89785 .49779 L
s
1 .159 .959 r
.85151 .50008 m
.85148 .50045 L
s
.735 .224 1 r
.71161 .46869 m
.71205 .47755 L
s
.71208 .47752 m
.71161 .46869 L
s
.71161 .46869 m
.71255 .48581 L
s
.917 .184 1 r
.56333 .48486 m
.56343 .49404 L
s
.56348 .4936 m
.56333 .48486 L
s
.512 .279 1 r
.42424 .49257 m
.42418 .49271 L
s
.917 .184 1 r
.56343 .49404 m
.56336 .48482 L
s
.56336 .48482 m
.56348 .4936 L
s
.503 .282 1 r
.7943 .43271 m
.79758 .47203 L
s
.811 .206 1 r
.5111 .43271 m
.51114 .47562 L
s
.551 .269 1 r
.2279 .43271 m
.22466 .47238 L
s
.638 .247 1 r
.24785 .49462 m
.24778 .49481 L
s
.512 .279 1 r
.50288 .48053 m
.50282 .4887 L
s
.50287 .48855 m
.50288 .48053 L
s
.754 .219 1 r
.25202 .47086 m
.2513 .47962 L
s
.25132 .47958 m
.25202 .47086 L
s
.25202 .47086 m
.25067 .48823 L
s
1 .131 .814 r
.49377 .48897 m
.49368 .49857 L
s
.49374 .49845 m
.49377 .48897 L
s
.512 .279 1 r
.50282 .4887 m
.50289 .48049 L
s
.50289 .48049 m
.50287 .48855 L
s
.588 .259 1 r
.29838 .46834 m
.29781 .47677 L
s
.29782 .47673 m
.29838 .46834 L
s
.29838 .46834 m
.29732 .48488 L
s
.415 .702 1 r
.72071 .46066 m
.72108 .46767 L
s
.7211 .46764 m
.72071 .46066 L
s
.72071 .46066 m
.72149 .47412 L
s
1 .131 .814 r
.49368 .49857 m
.4938 .48893 L
s
.4938 .48893 m
.49374 .49845 L
s
.733 .224 1 r
.66108 .49555 m
.66104 .49584 L
s
.857 .196 1 r
.33148 .49817 m
.33141 .49832 L
s
.375 .32 1 r
.94755 .43249 m
.95245 .47074 L
s
.638 .247 1 r
.66432 .43249 m
.66619 .47361 L
s
.441 .3 1 r
.38108 .43249 m
.37965 .4711 L
s
.438 .79 1 r
.74391 .4596 m
.74432 .46639 L
s
.74434 .46636 m
.74391 .4596 L
s
.74391 .4596 m
.74476 .47263 L
s
.846 .199 1 r
.58653 .48415 m
.58668 .49316 L
s
.58673 .49283 m
.58653 .48415 L
s
1 .161 .972 r
.64207 .47323 m
.64236 .48254 L
s
.64238 .4825 m
.64207 .47323 L
s
.64207 .47323 m
.64272 .49173 L
s
.846 .199 1 r
.58668 .49316 m
.58655 .48411 L
s
.58655 .48411 m
.58673 .49283 L
s
.476 .29 1 r
.24281 .47982 m
.24214 .48788 L
s
.2422 .48777 m
.24281 .47982 L
s
.777 .214 1 r
.37784 .4959 m
.37777 .49623 L
s
.476 .29 1 r
.24214 .48788 m
.24282 .47978 L
s
.24282 .47978 m
.2422 .48777 L
s
.559 .267 1 r
.88807 .4677 m
.88892 .47606 L
s
.88894 .47602 m
.88807 .4677 L
s
.88807 .4677 m
.88982 .4841 L
s
.608 .254 1 r
.45157 .46838 m
.45137 .47684 L
s
.45139 .47681 m
.45157 .46838 L
s
.45157 .46838 m
.45124 .48503 L
s
.383 .317 1 r
.81757 .43227 m
.82095 .46981 L
s
.701 .232 1 r
.6843 .49477 m
.68425 .49506 L
s
.788 .212 1 r
.53429 .43227 m
.53462 .47554 L
s
.588 .259 1 r
.25102 .43227 m
.24799 .47267 L
s
.733 .224 1 r
.68846 .47103 m
.68884 .47969 L
s
.68887 .47965 m
.68846 .47103 L
s
.68846 .47103 m
.68931 .48838 L
s
.459 .295 1 r
.26596 .47911 m
.26535 .48714 L
s
.26541 .48699 m
.26596 .47911 L
s
.55 .269 1 r
.97085 .43205 m
.97625 .4721 L
s
.608 .254 1 r
.68755 .43205 m
.68973 .47389 L
s
.754 .219 1 r
.40424 .43205 m
.40294 .47497 L
s
.494 .284 1 r
.3447 .46689 m
.34425 .47507 L
s
.34427 .47503 m
.3447 .46689 L
s
.3447 .46689 m
.34388 .48296 L
s
.459 .295 1 r
.26535 .48714 m
.26597 .47907 L
s
.26597 .47907 m
.26541 .48699 L
s
.638 .247 1 r
.65613 .48117 m
.65645 .4897 L
s
.65649 .48941 m
.65613 .48117 L
s
.893 .189 1 r
.86495 .46957 m
.86582 .47877 L
s
.86585 .47873 m
.86495 .46957 L
s
.86495 .46957 m
.86672 .48738 L
s
.777 .214 1 r
.58163 .46961 m
.58175 .47848 L
s
.58177 .47844 m
.58163 .46961 L
s
.58163 .46961 m
.58194 .48702 L
s
.638 .247 1 r
.65645 .4897 m
.65615 .48113 L
s
.65615 .48113 m
.65649 .48941 L
s
.477 .289 1 r
.60481 .46834 m
.60497 .47635 L
s
.60499 .47631 m
.60481 .46834 L
s
.60481 .46834 m
.6052 .48446 L
s
.638 .247 1 r
.3215 .46837 m
.32097 .47692 L
s
.32099 .47688 m
.3215 .46837 L
s
.3215 .46837 m
.32053 .48517 L
s
.485 .287 1 r
.83259 .47939 m
.83331 .48749 L
s
.83334 .48735 m
.83259 .47939 L
s
.588 .259 1 r
.31733 .49229 m
.31725 .49262 L
s
.485 .287 1 r
.83331 .48749 m
.83261 .47936 L
s
.83261 .47936 m
.83334 .48735 L
s
.41 .683 1 r
.40511 .47173 m
.40486 .4787 L
s
.40492 .47839 m
.40511 .47173 L
s
.99 .169 1 r
.86989 .48528 m
.87081 .49459 L
s
.87084 .49425 m
.86989 .48528 L
s
.54 .272 1 r
.47475 .46788 m
.47461 .47613 L
s
.47462 .4761 m
.47475 .46788 L
s
.47475 .46788 m
.47454 .48424 L
s
.744 .221 1 r
.27093 .49491 m
.27085 .49524 L
s
1 .128 .799 r
.59156 .50073 m
.59151 .50122 L
s
.41 .683 1 r
.40486 .4787 m
.40512 .4717 L
s
.40512 .4717 m
.40492 .47839 L
s
.559 .267 1 r
.91136 .46727 m
.91226 .47563 L
s
.91229 .4756 m
.91136 .46727 L
s
.91136 .46727 m
.91322 .48367 L
s
.62802 .46727 m
.62824 .47563 L
s
.62827 .4756 m
.62802 .46727 L
s
.62802 .46727 m
.62853 .48367 L
s
.99 .169 1 r
.87081 .49459 m
.86992 .48524 L
s
.86992 .48524 m
.87084 .49425 L
s
.522 .277 1 r
.84084 .43183 m
.84469 .47153 L
s
.551 .269 1 r
.5575 .43183 m
.55807 .47152 L
s
.638 .247 1 r
.27416 .43183 m
.27132 .47332 L
s
.523 .277 1 r
.93456 .46603 m
.93552 .47436 L
s
.93555 .47432 m
.93456 .46603 L
s
.93456 .46603 m
.9365 .48218 L
s
.461 .294 1 r
.69346 .4874 m
.69345 .48818 L
s
.81 .206 1 r
.42836 .47068 m
.42808 .47955 L
s
.4281 .47951 m
.42836 .47068 L
s
.42836 .47068 m
.42789 .48831 L
s
.691 .234 1 r
.40098 .49584 m
.40093 .49578 L
s
.337 .353 1 r
.84673 .48683 m
.84671 .48711 L
s
.45 .297 1 r
.72575 .4779 m
.72621 .48597 L
s
.72625 .48564 m
.72575 .4779 L
s
.72621 .48597 m
.72577 .47787 L
s
.72577 .47787 m
.72625 .48564 L
s
1 .141 .868 r
.71079 .43162 m
.71352 .47777 L
s
.658 .242 1 r
.42741 .43162 m
.42642 .47346 L
s
.496 .284 1 r
.74897 .47691 m
.74951 .48522 L
s
.74951 .48451 m
.74897 .47691 L
s
.638 .247 1 r
.88406 .49301 m
.88404 .4933 L
s
.383 .317 1 r
.82774 .46469 m
.8284 .47257 L
s
.82842 .47254 m
.82774 .46469 L
s
.82774 .46469 m
.82911 .48011 L
s
.496 .284 1 r
.74951 .48522 m
.749 .47688 L
s
.749 .47688 m
.74951 .48451 L
s
.608 .254 1 r
.54927 .48025 m
.54933 .48871 L
s
.54938 .48842 m
.54927 .48025 L
s
1 .125 .781 r
.79129 .49826 m
.7913 .4992 L
s
.608 .254 1 r
.54933 .48871 m
.54929 .48021 L
s
.54929 .48021 m
.54938 .48842 L
s
.823 .204 1 r
.37278 .48231 m
.37237 .49132 L
s
.37245 .49084 m
.37278 .48231 L
s
.352 .327 1 r
.69765 .4643 m
.69802 .47208 L
s
.69804 .47204 m
.69765 .4643 L
s
.69765 .4643 m
.69844 .47954 L
s
.823 .204 1 r
.86412 .4314 m
.86851 .47361 L
s
.368 .322 1 r
.58071 .4314 m
.5815 .46894 L
s
.788 .212 1 r
.2973 .4314 m
.29463 .47468 L
s
.823 .204 1 r
.37237 .49132 m
.37279 .48227 L
s
.37279 .48227 m
.37245 .49084 L
s
.504 .282 1 r
.67446 .46568 m
.67479 .47393 L
s
.67481 .47389 m
.67446 .46568 L
s
.67446 .46568 m
.67518 .48175 L
s
.375 .32 1 r
.41424 .46451 m
.41396 .47236 L
s
.41398 .47233 m
.41424 .46451 L
s
.41424 .46451 m
.41377 .47989 L
s
.578 .262 1 r
.41916 .48003 m
.4189 .48839 L
s
.41896 .48821 m
.41916 .48003 L
s
.4189 .48839 m
.41918 .48 L
s
.41918 .48 m
.41896 .48821 L
s
.953 .176 1 r
.73499 .47046 m
.73551 .47969 L
s
.73554 .47965 m
.73499 .47046 L
s
.73499 .47046 m
.73611 .4886 L
s
.588 .259 1 r
.57249 .47954 m
.5726 .48797 L
s
.57265 .48764 m
.57249 .47954 L
s
.503 .282 1 r
.28904 .47954 m
.28848 .48764 L
s
.28853 .48764 m
.28904 .47954 L
s
.712 .229 1 r
.73405 .43118 m
.73678 .47267 L
s
.845 .199 1 r
.4506 .43118 m
.44987 .47447 L
s
.588 .259 1 r
.5726 .48797 m
.57251 .4795 L
s
.57251 .4795 m
.57265 .48764 L
s
.503 .282 1 r
.28848 .48764 m
.28905 .4795 L
s
.28905 .4795 m
.28853 .48764 L
s
.744 .222 1 r
.39595 .4816 m
.39562 .49039 L
s
.39569 .49006 m
.39595 .4816 L
s
.522 .277 1 r
.52115 .46677 m
.52111 .47499 L
s
.52113 .47496 m
.52115 .46677 L
s
.52115 .46677 m
.52115 .48303 L
s
.744 .222 1 r
.39562 .49039 m
.39597 .48156 L
s
.39597 .48156 m
.39569 .49006 L
s
.598 .257 1 r
.34044 .49258 m
.34038 .49273 L
s
.649 .244 1 r
.77725 .49201 m
.77722 .49245 L
s
.658 .242 1 r
.49794 .4683 m
.49785 .47684 L
s
.49787 .47681 m
.49794 .4683 L
s
.49794 .4683 m
.49783 .48525 L
s
.777 .214 1 r
.88742 .43096 m
.89213 .47353 L
s
.691 .234 1 r
.60394 .43096 m
.60508 .47174 L
s
.649 .244 1 r
.32045 .43096 m
.31824 .47138 L
s
.35 .414 1 r
.63302 .48449 m
.63299 .48491 L
s
.391 .315 1 r
.85105 .46454 m
.85176 .47243 L
s
.85179 .4724 m
.85105 .46454 L
s
.85105 .46454 m
.85253 .48004 L
s
.56 .267 1 r
.67033 .49031 m
.6703 .49074 L
s
.468 .292 1 r
.9024 .47755 m
.90329 .48565 L
s
.90331 .48537 m
.9024 .47755 L
s
.90329 .48565 m
.90243 .47752 L
s
.90243 .47752 m
.90331 .48537 L
s
.485 .287 1 r
.46556 .47833 m
.46541 .48643 L
s
.46547 .48629 m
.46556 .47833 L
s
.337 .353 1 r
.30727 .46348 m
.30677 .47115 L
s
.30678 .47112 m
.30727 .46348 L
s
.30727 .46348 m
.30634 .47854 L
s
.485 .287 1 r
.46541 .48643 m
.46558 .4783 L
s
.46558 .4783 m
.46547 .48629 L
s
.424 .305 1 r
.71676 .48804 m
.71673 .48836 L
s
.468 .292 1 r
.56757 .46485 m
.56765 .473 L
s
.56767 .47296 m
.56757 .46485 L
s
.56757 .46485 m
.56779 .48075 L
s
.589 .259 1 r
.75731 .43074 m
.76023 .4708 L
s
.811 .206 1 r
.47379 .43074 m
.47336 .47367 L
s
.848 .198 1 r
.70267 .48117 m
.70313 .49029 L
s
.70316 .48964 m
.70267 .48117 L
s
.512 .279 1 r
.26083 .46638 m
.26018 .47457 L
s
.2602 .47453 m
.26083 .46638 L
s
.26083 .46638 m
.25961 .48261 L
s
.848 .198 1 r
.70313 .49029 m
.70269 .48113 L
s
.70269 .48113 m
.70316 .48964 L
s
.619 .251 1 r
.59572 .4794 m
.59589 .48791 L
s
.59593 .48758 m
.59572 .4794 L
s
.59589 .48791 m
.59574 .47936 L
s
.59574 .47936 m
.59593 .48758 L
s
.722 .227 1 r
.36778 .46851 m
.36735 .4772 L
s
.36737 .47716 m
.36778 .46851 L
s
.36778 .46851 m
.36702 .48575 L
s
.869 .194 1 r
.67946 .48274 m
.67986 .49179 L
s
.67991 .49149 m
.67946 .48274 L
s
.46 .294 1 r
.74001 .48726 m
.74 .48783 L
s
.869 .194 1 r
.67986 .49179 m
.67949 .4827 L
s
.67949 .4827 m
.67991 .49149 L
s
.579 .262 1 r
.91073 .43052 m
.91547 .47095 L
s
.811 .206 1 r
.62717 .43052 m
.62865 .4731 L
s
.701 .232 1 r
.34362 .43052 m
.34161 .47238 L
s
1 .164 .984 r
.53108 .49891 m
.53102 .49899 L
s
.367 .322 1 r
.32628 .48669 m
.32621 .48698 L
s
.512 .279 1 r
.33538 .4784 m
.33492 .48658 L
s
.33498 .48643 m
.33538 .4784 L
s
.68 .237 1 r
.80055 .49195 m
.80053 .49238 L
s
.512 .279 1 r
.33492 .48658 m
.33539 .47837 L
s
.33539 .47837 m
.33498 .48643 L
s
.777 .214 1 r
.47055 .49458 m
.47049 .4948 L
s
.388 .587 1 r
.85612 .48123 m
.85611 .48165 L
s
.953 .176 1 r
.73093 .49607 m
.73089 .49651 L
s
.416 .307 1 r
.78059 .4303 m
.78363 .46858 L
s
.701 .232 1 r
.497 .4303 m
.49686 .47252 L
s
.648 .244 1 r
.36358 .49287 m
.36352 .49299 L
s
.69 .234 1 r
.39097 .46787 m
.39061 .47649 L
s
.39062 .47645 m
.39097 .46787 L
s
.39097 .46787 m
.39033 .48497 L
s
.418 .307 1 r
.55842 .47436 m
.5585 .48245 L
s
.55854 .48174 m
.55842 .47436 L
s
.5585 .48245 m
.55844 .47432 L
s
.55844 .47432 m
.55854 .48174 L
s
.541 .272 1 r
.92578 .47769 m
.92675 .48602 L
s
.92676 .48566 m
.92578 .47769 L
s
.92675 .48602 m
.92581 .47766 L
s
.92581 .47766 m
.92676 .48566 L
s
.733 .224 1 r
.44232 .48103 m
.44211 .48976 L
s
.44217 .48957 m
.44232 .48103 L
s
.722 .227 1 r
.93404 .43009 m
.93925 .47195 L
s
.425 .304 1 r
.65042 .43009 m
.652 .468 L
s
.638 .247 1 r
.3668 .43009 m
.36505 .47231 L
s
.733 .224 1 r
.44211 .48976 m
.44234 .48099 L
s
.44234 .48099 m
.44217 .48957 L
s
.99 .169 1 r
.52608 .48437 m
.52608 .49361 L
s
.52614 .49349 m
.52608 .48437 L
s
.848 .198 1 r
.87938 .48054 m
.88032 .48966 L
s
.88031 .489 m
.87938 .48054 L
s
.648 .244 1 r
.31211 .48053 m
.31158 .48901 L
s
.31164 .489 m
.31211 .48053 L
s
.7 .232 1 r
.54438 .46762 m
.5444 .47627 L
s
.54442 .47624 m
.54438 .46762 L
s
.54438 .46762 m
.5445 .48475 L
s
.99 .169 1 r
.52608 .49361 m
.52611 .48433 L
s
.52611 .48433 m
.52614 .49349 L
s
.648 .244 1 r
.31158 .48901 m
.31213 .4805 L
s
.31213 .4805 m
.31164 .489 L
s
.848 .198 1 r
.88032 .48966 m
.87941 .4805 L
s
.87941 .4805 m
.88031 .489 L
s
.38 .553 1 r
.75829 .47158 m
.75878 .47886 L
s
.7588 .47854 m
.75829 .47158 L
s
.916 .184 1 r
.29389 .49735 m
.29383 .49736 L
s
.376 .534 1 r
.80475 .46902 m
.80536 .47655 L
s
.80532 .47554 m
.80475 .46902 L
s
.38 .553 1 r
.75878 .47886 m
.75831 .47155 L
s
.75831 .47155 m
.7588 .47854 L
s
.376 .534 1 r
.80536 .47655 m
.80477 .46899 L
s
.80477 .46899 m
.80532 .47554 L
s
.654 .243 1 r
.66543 .47698 m
.66578 .48574 L
s
.6658 .48487 m
.66543 .47698 L
s
.368 .322 1 r
.80388 .42987 m
.80712 .46743 L
s
.559 .267 1 r
.52022 .42987 m
.52036 .46994 L
s
.433 .302 1 r
.23656 .42987 m
.23347 .46886 L
s
.654 .243 1 r
.66578 .48574 m
.66545 .47694 L
s
.66545 .47694 m
.6658 .48487 L
s
.765 .217 1 r
.62398 .49508 m
.62392 .49505 L
s
.977 .171 1 r
.44732 .49714 m
.44725 .49733 L
s
.476 .29 1 r
.60988 .48812 m
.60984 .48844 L
s
.393 .314 1 r
.80979 .48492 m
.80979 .48553 L
s
.346 .329 1 r
.81397 .46123 m
.8146 .46908 L
s
.81462 .46905 m
.81397 .46123 L
s
.81397 .46123 m
.81525 .47633 L
s
.476 .29 1 r
.4606 .46514 m
.46042 .47321 L
s
.46044 .47318 m
.4606 .46514 L
s
.4606 .46514 m
.46032 .48118 L
s
.424 .305 1 r
.84212 .47549 m
.84286 .48348 L
s
.84288 .48316 m
.84212 .47549 L
s
.799 .209 1 r
.95737 .42965 m
.96314 .47367 L
s
.858 .196 1 r
.67368 .42965 m
.67576 .47259 L
s
.523 .277 1 r
.38999 .42965 m
.38859 .47008 L
s
.494 .284 1 r
.89775 .46453 m
.89861 .47271 L
s
.89863 .47268 m
.89775 .46453 L
s
.89775 .46453 m
.89951 .48061 L
s
1 .149 .907 r
.57755 .49807 m
.57749 .49837 L
s
.952 .176 1 r
.6514 .47035 m
.6517 .47948 L
s
.65172 .47944 m
.6514 .47035 L
s
.6514 .47035 m
.65209 .48861 L
s
.424 .305 1 r
.84286 .48348 m
.84215 .47546 L
s
.84215 .47546 m
.84288 .48316 L
s
.977 .171 1 r
.23747 .46974 m
.23667 .47898 L
s
.23669 .47894 m
.23747 .46974 L
s
.23747 .46974 m
.23597 .48804 L
s
.777 .214 1 r
.619 .48011 m
.61923 .48902 L
s
.61928 .48858 m
.619 .48011 L
s
.61923 .48902 m
.61902 .48007 L
s
.61902 .48007 m
.61928 .48858 L
s
.67 .239 1 r
.2839 .46729 m
.28328 .47585 L
s
.2833 .47581 m
.2839 .46729 L
s
.2839 .46729 m
.28274 .48433 L
s
.754 .219 1 r
.51699 .49373 m
.51693 .49388 L
s
.744 .221 1 r
.77247 .47961 m
.7731 .48845 L
s
.77312 .48801 m
.77247 .47961 L
s
.559 .267 1 r
.51198 .47833 m
.51194 .48662 L
s
.512 .48651 m
.51198 .47833 L
s
.744 .221 1 r
.7731 .48845 m
.7725 .47958 L
s
.7725 .47958 m
.77312 .48801 L
s
.559 .267 1 r
.51194 .48662 m
.512 .4783 L
s
.512 .4783 m
.512 .48651 L
s
.941 .179 1 r
.90773 .4958 m
.90771 .49609 L
s
.69 .234 1 r
.25649 .4926 m
.25642 .49275 L
s
.45 .297 1 r
.35357 .46364 m
.35315 .47172 L
s
.35316 .47168 m
.35357 .46364 L
s
.35357 .46364 m
.35281 .47947 L
s
.486 .287 1 r
.82718 .42943 m
.83075 .46771 L
s
.335 .34 1 r
.54345 .42943 m
.54383 .46628 L
s
.701 .232 1 r
.25972 .42943 m
.25666 .47166 L
s
.869 .194 1 r
.64724 .49466 m
.64719 .49496 L
s
.69 .234 1 r
.48875 .4799 m
.48865 .48852 L
s
.48871 .48837 m
.48875 .4799 L
s
.56 .267 1 r
.76756 .46439 m
.76812 .47278 L
s
.76815 .47275 m
.76756 .46439 L
s
.76756 .46439 m
.76873 .48076 L
s
.628 .249 1 r
.27971 .49146 m
.27964 .49161 L
s
1 .143 .88 r
.60079 .49729 m
.60074 .49777 L
s
.477 .289 1 r
.2747 .47606 m
.2741 .4842 L
s
.27418 .48388 m
.2747 .47606 L
s
.69 .234 1 r
.48865 .48852 m
.48877 .47986 L
s
.48877 .47986 m
.48871 .48837 L
s
.648 .244 1 r
.43319 .49089 m
.43313 .49122 L
s
.477 .289 1 r
.2741 .4842 m
.27472 .47602 L
s
.27472 .47602 m
.27418 .48388 L
s
.701 .232 1 r
.54021 .49296 m
.54016 .49304 L
s
.531 .274 1 r
.45641 .48976 m
.45636 .48987 L
s
.367 .322 1 r
.6373 .464 m
.63753 .47172 L
s
.63755 .47168 m
.6373 .464 L
s
.6373 .464 m
.63783 .47947 L
s
.63 .249 1 r
.81898 .47762 m
.8197 .4862 L
s
.81972 .48573 m
.81898 .47762 L
s
.347 .403 1 r
.53027 .46212 m
.53026 .46965 L
s
.53028 .46962 m
.53027 .46212 L
s
.53027 .46212 m
.53032 .47704 L
s
.57 .264 1 r
.69695 .42921 m
.69915 .46893 L
s
.649 .244 1 r
.41319 .42921 m
.41204 .47072 L
s
.63 .249 1 r
.8197 .4862 m
.819 .47758 L
s
.819 .47758 m
.81972 .48573 L
s
.531 .274 1 r
.47965 .48862 m
.47959 .48894 L
s
.91692 .48805 m
.91692 .48848 L
s
.845 .199 1 r
.38672 .49388 m
.38665 .49421 L
s
.375 .532 1 r
.68377 .46166 m
.68408 .46887 L
s
.6841 .46883 m
.68377 .46166 L
s
.68377 .46166 m
.68446 .47612 L
s
.357 .45 1 r
.78165 .47201 m
.7822 .47949 L
s
.78223 .47918 m
.78165 .47201 L
s
.559 .267 1 r
.3029 .49068 m
.30285 .49068 L
s
.357 .45 1 r
.7822 .47949 m
.78167 .47197 L
s
.78167 .47197 m
.78223 .47918 L
s
.579 .262 1 r
.89371 .48955 m
.89369 .48984 L
s
.415 .702 1 r
.72108 .46767 m
.72148 .47468 L
s
.72149 .47412 m
.72108 .46767 L
s
.438 .79 1 r
.74432 .46639 m
.74475 .47319 L
s
.74476 .47263 m
.74432 .46639 L
s
.415 .702 1 r
.72148 .47468 m
.7211 .46764 L
s
.7211 .46764 m
.72149 .47412 L
s
.438 .79 1 r
.74475 .47319 m
.74434 .46636 L
s
.74434 .46636 m
.74476 .47263 L
s
.398 .631 1 r
.85049 .42899 m
.85392 .46334 L
s
.45 .297 1 r
.56669 .42899 m
.56735 .46764 L
s
.733 .224 1 r
.28289 .42899 m
.28009 .47158 L
s
.599 .257 1 r
.34937 .48841 m
.34928 .48899 L
s
.416 .307 1 r
.24646 .46282 m
.2458 .47079 L
s
.24581 .47075 m
.24646 .46282 L
s
.24646 .46282 m
.24522 .47847 L
s
.513 .279 1 r
.66058 .4636 m
.66088 .47186 L
s
.6609 .47182 m
.66058 .4636 L
s
.66058 .4636 m
.66124 .47976 L
s
.559 .267 1 r
.79088 .46427 m
.7915 .47264 L
s
.79152 .4726 m
.79088 .46427 L
s
.79088 .46427 m
.79217 .48069 L
s
.953 .176 1 r
.72024 .42877 m
.72296 .47281 L
s
.628 .249 1 r
.4364 .42877 m
.43553 .47029 L
s
.799 .209 1 r
.35844 .48054 m
.35801 .48941 L
s
.35808 .48923 m
.35844 .48054 L
s
.904 .186 1 r
.43734 .46825 m
.43708 .47734 L
s
.4371 .47731 m
.43734 .46825 L
s
.43734 .46825 m
.43691 .48626 L
s
.69 .234 1 r
.38168 .47926 m
.38131 .48788 L
s
.38138 .48773 m
.38168 .47926 L
s
.777 .214 1 r
.40992 .49346 m
.40986 .49357 L
s
.916 .184 1 r
.59089 .46768 m
.59103 .47685 L
s
.59105 .47681 m
.59089 .46768 L
s
.59089 .46768 m
.59125 .48569 L
s
.799 .209 1 r
.35801 .48941 m
.35846 .4805 L
s
.35846 .4805 m
.35808 .48923 L
s
.69 .234 1 r
.38131 .48788 m
.3817 .47922 L
s
.3817 .47922 m
.38138 .48773 L
s
.658 .242 1 r
.53522 .47876 m
.53524 .48731 L
s
.53529 .48716 m
.53522 .47876 L
s
.53524 .48731 m
.53524 .47873 L
s
.53524 .47873 m
.53529 .48716 L
s
.834 .201 1 r
.61413 .46654 m
.61433 .47556 L
s
.61435 .47552 m
.61413 .46654 L
s
.61413 .46654 m
.61461 .48419 L
s
.512 .279 1 r
.50287 .48855 m
.50282 .4887 L
s
1 .103 .659 r
.87382 .42855 m
.87905 .47763 L
s
.54 .272 1 r
.58995 .42855 m
.59091 .469 L
s
.754 .219 1 r
.30608 .42855 m
.30354 .47151 L
s
.845 .199 1 r
.79586 .48033 m
.79656 .48935 L
s
.79659 .48901 m
.79586 .48033 L
s
.765 .217 1 r
.33025 .46676 m
.32973 .47556 L
s
.32975 .47552 m
.33025 .46676 L
s
.33025 .46676 m
.32929 .48419 L
s
.41 .683 1 r
.40492 .47839 m
.40486 .4787 L
s
.845 .199 1 r
.79656 .48935 m
.79589 .48029 L
s
.79589 .48029 m
.79659 .48901 L
s
.588 .259 1 r
.29781 .47677 m
.29724 .48521 L
s
.29732 .48488 m
.29781 .47677 L
s
.64 .246 1 r
.74353 .42833 m
.74629 .46842 L
s
.4 .312 1 r
.45962 .42833 m
.45909 .46627 L
s
.588 .259 1 r
.29724 .48521 m
.29782 .47673 L
s
.29782 .47673 m
.29732 .48488 L
s
.476 .29 1 r
.2422 .48777 m
.24214 .48788 L
s
.917 .184 1 r
.56348 .4936 m
.56343 .49404 L
s
.735 .224 1 r
.71205 .47755 m
.71253 .48642 L
s
.71255 .48581 m
.71205 .47755 L
s
.7 .232 1 r
.9213 .4659 m
.92226 .47456 L
s
.92229 .47453 m
.9213 .4659 L
s
.9213 .4659 m
.92329 .48305 L
s
.965 .174 1 r
.87482 .46849 m
.87571 .4777 L
s
.87574 .47766 m
.87482 .46849 L
s
.87482 .46849 m
.87669 .48677 L
s
.735 .224 1 r
.71253 .48642 m
.71208 .47752 L
s
.71208 .47752 m
.71255 .48581 L
s
.754 .219 1 r
.2513 .47962 m
.2506 .48838 L
s
.25067 .48823 m
.2513 .47962 L
s
.2506 .48838 m
.25132 .47958 L
s
.25132 .47958 m
.25067 .48823 L
s
1 .146 .894 r
.89715 .42811 m
.90236 .47396 L
s
.335 .34 1 r
.61321 .42811 m
.61433 .46462 L
s
.589 .259 1 r
.32927 .42811 m
.32714 .46893 L
s
.559 .267 1 r
.88892 .47606 m
.8898 .48442 L
s
.88982 .4841 m
.88892 .47606 L
s
.459 .295 1 r
.26541 .48699 m
.26535 .48714 L
s
.846 .199 1 r
.58673 .49283 m
.58668 .49316 L
s
.559 .267 1 r
.8898 .48442 m
.88894 .47602 L
s
.88894 .47602 m
.88982 .4841 L
s
.608 .254 1 r
.45137 .47684 m
.45118 .48532 L
s
.45124 .48503 m
.45137 .47684 L
s
.45118 .48532 m
.45139 .47681 L
s
.45139 .47681 m
.45124 .48503 L
s
.744 .221 1 r
.37669 .46533 m
.37629 .47414 L
s
.3763 .4741 m
.37669 .46533 L
s
.37669 .46533 m
.37597 .48262 L
s
.477 .289 1 r
.60497 .47635 m
.60515 .48435 L
s
.6052 .48446 m
.60497 .47635 L
s
.834 .201 1 r
.4838 .46729 m
.48367 .47621 L
s
.48369 .47617 m
.4838 .46729 L
s
.4838 .46729 m
.48361 .48505 L
s
.494 .284 1 r
.34425 .47507 m
.34381 .48325 L
s
.34388 .48296 m
.34425 .47507 L
s
.559 .267 1 r
.55355 .46341 m
.55359 .47178 L
s
.55361 .47175 m
.55355 .46341 L
s
.55355 .46341 m
.5537 .47983 L
s
.347 .401 1 r
.7769 .45891 m
.77743 .46658 L
s
.77746 .46655 m
.7769 .45891 L
s
.7769 .45891 m
.778 .47369 L
s
.58 .261 1 r
.76684 .4279 m
.76982 .46727 L
s
1 .161 .972 r
.48286 .4279 m
.48252 .47374 L
s
.477 .289 1 r
.60515 .48435 m
.60499 .47631 L
s
.60499 .47631 m
.6052 .48446 L
s
.485 .287 1 r
.83334 .48735 m
.83331 .48749 L
s
.494 .284 1 r
.34381 .48325 m
.34427 .47503 L
s
.34427 .47503 m
.34388 .48296 L
s
.733 .224 1 r
.68884 .47969 m
.68925 .48835 L
s
.68931 .48838 m
.68884 .47969 L
s
.68925 .48835 m
.68887 .47965 L
s
.68887 .47965 m
.68931 .48838 L
s
1 .131 .814 r
.49374 .49845 m
.49368 .49857 L
s
.403 .651 1 r
.66978 .45713 m
.67006 .46423 L
s
.67008 .4642 m
.66978 .45713 L
s
.66978 .45713 m
.67038 .4709 L
s
.638 .247 1 r
.65649 .48941 m
.65645 .4897 L
s
.35 .415 1 r
.62329 .45979 m
.62348 .46736 L
s
.6235 .46733 m
.62329 .45979 L
s
.62329 .45979 m
.62373 .47462 L
s
.45 .297 1 r
.72625 .48564 m
.72621 .48597 L
s
1 .161 .972 r
.64236 .48254 m
.64267 .49185 L
s
.64272 .49173 m
.64236 .48254 L
s
.54 .272 1 r
.47461 .47613 m
.47448 .48439 L
s
.47454 .48424 m
.47461 .47613 L
s
1 .161 .972 r
.64267 .49185 m
.64238 .4825 L
s
.64238 .4825 m
.64272 .49173 L
s
.496 .284 1 r
.74951 .48451 m
.74951 .48522 L
s
.692 .234 1 r
.9205 .42768 m
.92546 .46885 L
s
.99 .169 1 r
.63649 .42768 m
.6382 .47352 L
s
.4 .312 1 r
.35248 .42768 m
.35075 .46562 L
s
.54 .272 1 r
.47448 .48439 m
.47462 .4761 L
s
.47462 .4761 m
.47454 .48424 L
s
.638 .247 1 r
.32097 .47692 m
.32046 .48546 L
s
.32053 .48517 m
.32097 .47692 L
s
.559 .267 1 r
.91226 .47563 m
.9132 .484 L
s
.91322 .48367 m
.91226 .47563 L
s
.62824 .47563 m
.62849 .484 L
s
.62853 .48367 m
.62824 .47563 L
s
.523 .277 1 r
.93552 .47436 m
.93651 .48268 L
s
.9365 .48218 m
.93552 .47436 L
s
.638 .247 1 r
.32046 .48546 m
.32099 .47688 L
s
.32099 .47688 m
.32053 .48517 L
s
.433 .302 1 r
.31603 .46146 m
.31552 .4695 L
s
.31553 .46947 m
.31603 .46146 L
s
.31603 .46146 m
.3151 .47719 L
s
.559 .267 1 r
.9132 .484 m
.91229 .4756 L
s
.91229 .4756 m
.91322 .48367 L
s
.62849 .484 m
.62827 .4756 L
s
.62827 .4756 m
.62853 .48367 L
s
.523 .277 1 r
.93651 .48268 m
.93555 .47432 L
s
.93555 .47432 m
.9365 .48218 L
s
.383 .317 1 r
.8284 .47257 m
.82909 .48046 L
s
.82911 .48011 m
.8284 .47257 L
s
.67 .239 1 r
.50704 .46675 m
.50697 .47521 L
s
.50699 .47517 m
.50704 .46675 L
s
.50704 .46675 m
.50697 .48391 L
s
.494 .285 1 r
.29277 .46292 m
.29219 .47107 L
s
.29221 .47103 m
.29277 .46292 L
s
.29277 .46292 m
.2917 .47904 L
s
.383 .317 1 r
.82909 .48046 m
.82842 .47254 L
s
.82842 .47254 m
.82911 .48011 L
s
.69 .234 1 r
.26952 .46423 m
.26885 .47293 L
s
.26887 .47289 m
.26952 .46423 L
s
.26952 .46423 m
.26828 .48126 L
s
.777 .214 1 r
.58175 .47848 m
.58189 .48736 L
s
.58194 .48702 m
.58175 .47848 L
s
.352 .327 1 r
.69802 .47208 m
.6984 .47986 L
s
.69844 .47954 m
.69802 .47208 L
s
.777 .214 1 r
.79016 .42746 m
.79366 .47007 L
s
.648 .244 1 r
.50611 .42746 m
.50608 .46863 L
s
.522 .277 1 r
.22206 .42746 m
.21861 .46863 L
s
.777 .214 1 r
.58189 .48736 m
.58177 .47844 L
s
.58177 .47844 m
.58194 .48702 L
s
.441 .3 1 r
.60006 .46174 m
.60021 .46979 L
s
.60023 .46975 m
.60006 .46174 L
s
.60006 .46174 m
.60043 .47755 L
s
.352 .327 1 r
.6984 .47986 m
.69804 .47204 L
s
.69804 .47204 m
.69844 .47954 L
s
.893 .189 1 r
.86582 .47877 m
.86672 .48797 L
s
.86672 .48738 m
.86582 .47877 L
s
.608 .254 1 r
.54938 .48842 m
.54933 .48871 L
s
.99 .169 1 r
.87084 .49425 m
.87081 .49459 L
s
.375 .32 1 r
.41396 .47236 m
.4137 .48021 L
s
.41377 .47989 m
.41396 .47236 L
s
.893 .189 1 r
.86672 .48797 m
.86585 .47873 L
s
.86585 .47873 m
.86672 .48738 L
s
.375 .32 1 r
.4137 .48021 m
.41398 .47233 L
s
.41398 .47233 m
.41377 .47989 L
s
.81 .206 1 r
.42808 .47955 m
.42783 .48843 L
s
.42789 .48831 m
.42808 .47955 L
s
.42783 .48843 m
.4281 .47951 L
s
.4281 .47951 m
.42789 .48831 L
s
.733 .224 1 r
.94386 .42724 m
.94923 .4695 L
s
.671 .239 1 r
.65978 .42724 m
.66161 .46878 L
s
.588 .259 1 r
.37569 .42724 m
.3741 .46842 L
s
.504 .282 1 r
.67479 .47393 m
.67514 .48218 L
s
.67518 .48175 m
.67479 .47393 L
s
.778 .214 1 r
.94481 .46682 m
.94584 .47556 L
s
.94587 .47553 m
.94481 .46682 L
s
.94481 .46682 m
.94697 .48441 L
s
.504 .282 1 r
.67514 .48218 m
.67481 .47389 L
s
.67481 .47389 m
.67518 .48175 L
s
.578 .262 1 r
.41896 .48821 m
.4189 .48839 L
s
.823 .204 1 r
.37245 .49084 m
.37237 .49132 L
s
.588 .259 1 r
.57265 .48764 m
.5726 .48797 L
s
.503 .282 1 r
.28853 .48764 m
.28848 .48764 L
s
.659 .242 1 r
.81348 .42702 m
.8173 .47 L
s
.766 .217 1 r
.52937 .42702 m
.52963 .46964 L
s
.467 .292 1 r
.24525 .42702 m
.24222 .4664 L
s
.522 .277 1 r
.52111 .47499 m
.5211 .48321 L
s
.52115 .48303 m
.52111 .47499 L
s
.822 .204 1 r
.39988 .46593 m
.39953 .47485 L
s
.39954 .47481 m
.39988 .46593 L
s
.39988 .46593 m
.39926 .48363 L
s
.391 .315 1 r
.85176 .47243 m
.85251 .48032 L
s
.85253 .48004 m
.85176 .47243 L
s
.337 .353 1 r
.30677 .47115 m
.30627 .47882 L
s
.30634 .47854 m
.30677 .47115 L
s
.522 .277 1 r
.5211 .48321 m
.52113 .47496 L
s
.52113 .47496 m
.52115 .48303 L
s
.468 .292 1 r
.90331 .48537 m
.90329 .48565 L
s
.391 .315 1 r
.85251 .48032 m
.85179 .4724 L
s
.85179 .4724 m
.85253 .48004 L
s
.337 .353 1 r
.30627 .47882 m
.30678 .47112 L
s
.30678 .47112 m
.30634 .47854 L
s
.744 .222 1 r
.39569 .49006 m
.39562 .49039 L
s
.68 .237 1 r
.73054 .46362 m
.73103 .47228 L
s
.73105 .47224 m
.73054 .46362 L
s
.73054 .46362 m
.73158 .48062 L
s
.833 .201 1 r
.96723 .4268 m
.97318 .47122 L
s
.649 .244 1 r
.68308 .4268 m
.68517 .46762 L
s
.712 .229 1 r
.39892 .4268 m
.39757 .46906 L
s
.485 .287 1 r
.46547 .48629 m
.46541 .48643 L
s
.658 .242 1 r
.49785 .47684 m
.49778 .4854 L
s
.49783 .48525 m
.49785 .47684 L
s
.6 .256 1 r
.90755 .46198 m
.90846 .4705 L
s
.90849 .47046 m
.90755 .46198 L
s
.90755 .46198 m
.90941 .47855 L
s
.468 .292 1 r
.56765 .473 m
.56774 .48115 L
s
.56779 .48075 m
.56765 .473 L
s
.376 .534 1 r
.80532 .47554 m
.80536 .47655 L
s
.658 .242 1 r
.49778 .4854 m
.49787 .47681 L
s
.49787 .47681 m
.49783 .48525 L
s
.468 .292 1 r
.56774 .48115 m
.56767 .47296 L
s
.56767 .47296 m
.56779 .48075 L
s
.346 .329 1 r
.83683 .42658 m
.84031 .46274 L
s
1 .163 .984 r
.55264 .42658 m
.55322 .47136 L
s
.711 .229 1 r
.26845 .42658 m
.26543 .46956 L
s
.953 .176 1 r
.73551 .47969 m
.73607 .48894 L
s
.73611 .4886 m
.73551 .47969 L
s
.512 .279 1 r
.26018 .47457 m
.25955 .48275 L
s
.25961 .48261 m
.26018 .47457 L
s
.69 .234 1 r
.44638 .46422 m
.44616 .47285 L
s
.44617 .47281 m
.44638 .46422 L
s
.44638 .46422 m
.44601 .48134 L
s
.953 .176 1 r
.73607 .48894 m
.73554 .47965 L
s
.73554 .47965 m
.73611 .4886 L
s
.512 .279 1 r
.25955 .48275 m
.2602 .47453 L
s
.2602 .47453 m
.25961 .48261 L
s
.418 .307 1 r
.55854 .48174 m
.5585 .48245 L
s
.619 .251 1 r
.59593 .48758 m
.59589 .48791 L
s
.38 .553 1 r
.7588 .47854 m
.75878 .47886 L
s
.55 .269 1 r
.33917 .46248 m
.3387 .47078 L
s
.33871 .47074 m
.33917 .46248 L
s
.33917 .46248 m
.33831 .4789 L
s
.848 .198 1 r
.70316 .48964 m
.70313 .49029 L
s
.512 .279 1 r
.33498 .48643 m
.33492 .48658 L
s
1 .126 .785 r
.70639 .42636 m
.70909 .47294 L
s
.754 .219 1 r
.42216 .42636 m
.42108 .46935 L
s
.904 .186 1 r
.42311 .46589 m
.42281 .47499 L
s
.42283 .47495 m
.42311 .46589 L
s
.42311 .46589 m
.4226 .48391 L
s
.723 .226 1 r
.57685 .46529 m
.57695 .47392 L
s
.57697 .47389 m
.57685 .46529 L
s
.57685 .46529 m
.57713 .48263 L
s
.99 .169 1 r
.70734 .46596 m
.70781 .47528 L
s
.70783 .47524 m
.70734 .46596 L
s
.70734 .46596 m
.70834 .48427 L
s
.392 .314 1 r
.82368 .45949 m
.82434 .46743 L
s
.82437 .46739 m
.82368 .45949 L
s
.82368 .45949 m
.82505 .47497 L
s
1 .143 .881 r
.83785 .46678 m
.83868 .47635 L
s
.83871 .47631 m
.83785 .46678 L
s
.83785 .46678 m
.83957 .48557 L
s
.722 .227 1 r
.36735 .4772 m
.36695 .4859 L
s
.36702 .48575 m
.36735 .4772 L
s
.559 .267 1 r
.36242 .46169 m
.362 .47007 L
s
.36201 .47003 m
.36242 .46169 L
s
.36242 .46169 m
.36167 .47812 L
s
.693 .233 1 r
.86018 .42614 m
.86432 .46625 L
s
.476 .29 1 r
.57592 .42614 m
.57669 .46518 L
s
.669 .239 1 r
.29166 .42614 m
.28901 .46805 L
s
.722 .227 1 r
.36695 .4859 m
.36737 .47716 L
s
.36737 .47716 m
.36702 .48575 L
s
.541 .272 1 r
.92676 .48566 m
.92675 .48602 L
s
.869 .194 1 r
.67991 .49149 m
.67986 .49179 L
s
.7 .232 1 r
.46964 .46376 m
.46947 .47242 L
s
.46949 .47238 m
.46964 .46376 L
s
.46964 .46376 m
.46939 .48091 L
s
.99 .169 1 r
.86114 .46574 m
.86201 .47506 L
s
.86204 .47502 m
.86114 .46574 L
s
.86114 .46574 m
.86295 .48406 L
s
.799 .209 1 r
.75393 .46407 m
.75449 .47299 L
s
.75452 .47296 m
.75393 .46407 L
s
.75393 .46407 m
.75512 .48163 L
s
.488 .286 1 r
.72971 .42592 m
.73214 .46317 L
s
.488 .964 1 r
.44542 .42592 m
.44487 .45565 L
s
.69 .234 1 r
.39061 .47649 m
.39026 .48511 L
s
.39033 .48497 m
.39061 .47649 L
s
.654 .243 1 r
.6658 .48487 m
.66578 .48574 L
s
.438 .79 1 r
.74476 .47263 m
.74475 .47319 L
s
.69 .234 1 r
.39026 .48511 m
.39062 .47645 L
s
.39062 .47645 m
.39033 .48497 L
s
.733 .224 1 r
.44217 .48957 m
.44211 .48976 L
s
.424 .305 1 r
.84288 .48316 m
.84286 .48348 L
s
.415 .702 1 r
.72149 .47412 m
.72148 .47468 L
s
.848 .198 1 r
.88031 .489 m
.88032 .48966 L
s
.648 .244 1 r
.31164 .489 m
.31158 .48901 L
s
.531 .274 1 r
.88354 .4257 m
.88802 .46653 L
s
.733 .224 1 r
.59921 .4257 m
.60034 .46798 L
s
.857 .196 1 r
.31488 .4257 m
.31243 .46906 L
s
.346 .329 1 r
.8146 .46908 m
.81525 .47694 L
s
.81525 .47633 m
.8146 .46908 L
s
.68 .237 1 r
.51619 .46201 m
.51614 .47071 L
s
.51616 .47067 m
.51619 .46201 L
s
.51619 .46201 m
.51617 .47898 L
s
.346 .329 1 r
.81525 .47694 m
.81462 .46905 L
s
.81462 .46905 m
.81525 .47633 L
s
.7 .232 1 r
.5444 .47627 m
.54444 .48494 L
s
.5445 .48475 m
.5444 .47627 L
s
.659 .242 1 r
.80053 .46208 m
.80118 .47071 L
s
.80121 .47067 m
.80053 .46208 L
s
.80053 .46208 m
.8019 .47898 L
s
.7 .232 1 r
.54444 .48494 m
.54442 .47624 L
s
.54442 .47624 m
.5445 .48475 L
s
.476 .29 1 r
.46042 .47321 m
.46026 .48129 L
s
.46032 .48118 m
.46042 .47321 L
s
.541 .272 1 r
.69328 .46026 m
.69366 .46864 L
s
.69368 .4686 m
.69328 .46026 L
s
.69328 .46026 m
.6941 .47654 L
s
.476 .29 1 r
.46026 .48129 m
.46044 .47318 L
s
.46044 .47318 m
.46032 .48118 L
s
.494 .284 1 r
.89861 .47271 m
.89949 .4809 L
s
.89951 .48061 m
.89861 .47271 L
s
.591 .259 1 r
.75305 .42548 m
.75588 .46488 L
s
.953 .176 1 r
.46868 .42548 m
.46817 .46992 L
s
.375 .532 1 r
.68408 .46887 m
.68441 .47607 L
s
.68446 .47612 m
.68408 .46887 L
s
.357 .45 1 r
.78223 .47918 m
.7822 .47949 L
s
.494 .284 1 r
.89949 .4809 m
.89863 .47268 L
s
.89863 .47268 m
.89951 .48061 L
s
.811 .206 1 r
.9311 .46307 m
.93213 .47207 L
s
.93216 .47203 m
.9311 .46307 L
s
.9311 .46307 m
.93319 .48063 L
s
.375 .532 1 r
.68441 .47607 m
.6841 .46883 L
s
.6841 .46883 m
.68446 .47612 L
s
.965 .174 1 r
.88454 .46571 m
.88547 .47492 L
s
.8855 .47488 m
.88454 .46571 L
s
.88454 .46571 m
.88647 .48399 L
s
.99 .169 1 r
.52614 .49349 m
.52608 .49361 L
s
.347 .403 1 r
.53026 .46965 m
.53027 .47718 L
s
.53032 .47704 m
.53026 .46965 L
s
.512 .279 1 r
.25508 .46123 m
.25442 .46942 L
s
.25443 .46939 m
.25508 .46123 L
s
.25508 .46123 m
.25383 .47748 L
s
.459 .295 1 r
.40891 .46059 m
.40861 .46864 L
s
.40863 .4686 m
.40891 .46059 L
s
.40891 .46059 m
.40839 .47655 L
s
.488 .286 1 r
.73987 .45802 m
.74036 .46635 L
s
.74038 .46632 m
.73987 .45802 L
s
.73987 .45802 m
.74088 .4739 L
s
.477 .289 1 r
.27418 .48388 m
.2741 .4842 L
s
.701 .232 1 r
.2318 .46258 m
.23104 .47128 L
s
.23105 .47124 m
.2318 .46258 L
s
.2318 .46258 m
.23037 .4797 L
s
.347 .403 1 r
.53027 .47718 m
.53028 .46962 L
s
.53028 .46962 m
.53032 .47704 L
s
.559 .267 1 r
.512 .48651 m
.51194 .48662 L
s
.45 .297 1 r
.35315 .47172 m
.35274 .47979 L
s
.35281 .47947 m
.35315 .47172 L
s
.367 .322 1 r
.63753 .47172 m
.63777 .47943 L
s
.63783 .47947 m
.63753 .47172 L
s
.638 .247 1 r
.64673 .46333 m
.647 .47178 L
s
.64702 .47174 m
.64673 .46333 L
s
.64673 .46333 m
.64735 .48027 L
s
.367 .322 1 r
.63777 .47943 m
.63755 .47168 L
s
.63755 .47168 m
.63783 .47947 L
s
.45 .297 1 r
.35274 .47979 m
.35316 .47168 L
s
.35316 .47168 m
.35281 .47947 L
s
.777 .214 1 r
.61928 .48858 m
.61923 .48902 L
s
.711 .229 1 r
.90692 .42526 m
.9118 .46718 L
s
.494 .284 1 r
.62252 .42526 m
.62386 .46574 L
s
.744 .221 1 r
.77312 .48801 m
.7731 .48845 L
s
.36 .462 1 r
.33812 .42526 m
.33634 .46108 L
s
.67 .239 1 r
.28328 .47585 m
.28267 .48441 L
s
.28274 .48433 m
.28328 .47585 L
s
.28267 .48441 m
.2833 .47581 L
s
.2833 .47581 m
.28274 .48433 L
s
.56 .267 1 r
.76812 .47278 m
.76871 .48119 L
s
.76873 .48076 m
.76812 .47278 L
s
.63 .249 1 r
.81972 .48573 m
.8197 .4862 L
s
.56 .267 1 r
.76871 .48119 m
.76815 .47275 L
s
.76815 .47275 m
.76873 .48076 L
s
.69 .234 1 r
.48871 .48837 m
.48865 .48852 L
s
.768 .216 1 r
.77639 .42504 m
.77966 .4666 L
s
.711 .229 1 r
.49196 .42504 m
.49176 .46696 L
s
.823 .204 1 r
.38562 .4626 m
.38523 .47163 L
s
.38524 .4716 m
.38562 .4626 L
s
.38562 .4626 m
.38493 .4802 L
s
.952 .176 1 r
.6517 .47948 m
.65203 .48862 L
s
.65209 .48861 m
.6517 .47948 L
s
.65203 .48862 m
.65172 .47944 L
s
.65172 .47944 m
.65209 .48861 L
s
.977 .171 1 r
.23667 .47898 m
.23589 .48823 L
s
.23597 .48804 m
.23667 .47898 L
s
.23589 .48823 m
.23669 .47894 L
s
.23669 .47894 m
.23597 .48804 L
s
.639 .247 1 r
.84723 .46097 m
.848 .46956 L
s
.84803 .46953 m
.84723 .46097 L
s
.84723 .46097 m
.84882 .47776 L
s
1 .161 .972 r
.4929 .46488 m
.49279 .47428 L
s
.49281 .47424 m
.4929 .46488 L
s
.4929 .46488 m
.49276 .48335 L
s
.416 .307 1 r
.2458 .47079 m
.24514 .47876 L
s
.24522 .47847 m
.2458 .47079 L
s
.712 .229 1 r
.93031 .42482 m
.93544 .46639 L
s
.744 .221 1 r
.64583 .42482 m
.64752 .46675 L
s
.638 .247 1 r
.36136 .42482 m
.35958 .46638 L
s
.416 .307 1 r
.24514 .47876 m
.24581 .47075 L
s
.24581 .47075 m
.24522 .47847 L
s
.359 .325 1 r
.32485 .45866 m
.32438 .46642 L
s
.32439 .46639 m
.32485 .45866 L
s
.32485 .45866 m
.32398 .47404 L
s
.834 .201 1 r
.95457 .46321 m
.95565 .47221 L
s
.95568 .47217 m
.95457 .46321 L
s
.95457 .46321 m
.95679 .48092 L
s
.599 .257 1 r
.58606 .46004 m
.58619 .46856 L
s
.58621 .46852 m
.58606 .46004 L
s
.58606 .46004 m
.58638 .47662 L
s
.513 .279 1 r
.66088 .47186 m
.6612 .48012 L
s
.66124 .47976 m
.66088 .47186 L
s
.385 .575 1 r
.79975 .4246 m
.80266 .45863 L
s
.744 .222 1 r
.51524 .4246 m
.51533 .46689 L
s
.638 .247 1 r
.23074 .4246 m
.22736 .46617 L
s
.513 .279 1 r
.6612 .48012 m
.6609 .47182 L
s
.6609 .47182 m
.66124 .47976 L
s
.559 .267 1 r
.7915 .47264 m
.79214 .48101 L
s
.79217 .48069 m
.7915 .47264 L
s
.79214 .48101 m
.79152 .4726 L
s
.79152 .4726 m
.79217 .48069 L
s
.799 .209 1 r
.53948 .4631 m
.53949 .47199 L
s
.53951 .47195 m
.53948 .4631 L
s
.53948 .4631 m
.53958 .4807 L
s
.69 .234 1 r
.38138 .48773 m
.38131 .48788 L
s
.347 .402 1 r
.95371 .42438 m
.95869 .46272 L
s
1 .161 .972 r
.66916 .42438 m
.67127 .46919 L
s
.788 .212 1 r
.38462 .42438 m
.38305 .46775 L
s
.658 .242 1 r
.53529 .48716 m
.53524 .48731 L
s
.799 .209 1 r
.35808 .48923 m
.35801 .48941 L
s
.649 .244 1 r
.30152 .46082 m
.30094 .46942 L
s
.30095 .46938 m
.30152 .46082 L
s
.30152 .46082 m
.30045 .47769 L
s
.588 .259 1 r
.29732 .48488 m
.29724 .48521 L
s
.403 .651 1 r
.67006 .46423 m
.67035 .47132 L
s
.67038 .4709 m
.67006 .46423 L
s
.722 .227 1 r
.27821 .46228 m
.27756 .47099 L
s
.27758 .47095 m
.27821 .46228 L
s
.27821 .46228 m
.277 .47956 L
s
.811 .206 1 r
.56279 .46231 m
.56286 .47128 L
s
.56288 .47124 m
.56279 .46231 L
s
.56279 .46231 m
.563 .47991 L
s
.403 .651 1 r
.67035 .47132 m
.67008 .4642 L
s
.67008 .4642 m
.67038 .4709 L
s
.397 .628 1 r
.82312 .42416 m
.82617 .45712 L
s
.789 .211 1 r
.53854 .42416 m
.53892 .46825 L
s
.521 .277 1 r
.25396 .42416 m
.25098 .46429 L
s
.904 .186 1 r
.43708 .47734 m
.43684 .48645 L
s
.43691 .48626 m
.43708 .47734 L
s
.845 .199 1 r
.79659 .48901 m
.79656 .48935 L
s
.904 .186 1 r
.43684 .48645 m
.4371 .47731 L
s
.4371 .47731 m
.43691 .48626 L
s
.735 .224 1 r
.71255 .48581 m
.71253 .48642 L
s
.916 .184 1 r
.59103 .47685 m
.5912 .48602 L
s
.59125 .48569 m
.59103 .47685 L
s
.765 .217 1 r
.32973 .47556 m
.32922 .48438 L
s
.32929 .48419 m
.32973 .47556 L
s
.834 .201 1 r
.61433 .47556 m
.61456 .48459 L
s
.61461 .48419 m
.61433 .47556 L
s
.916 .184 1 r
.5912 .48602 m
.59105 .47681 L
s
.59105 .47681 m
.59125 .48569 L
s
.765 .217 1 r
.32922 .48438 m
.32975 .47552 L
s
.32975 .47552 m
.32929 .48419 L
s
.834 .201 1 r
.61456 .48459 m
.61435 .47552 L
s
.61435 .47552 m
.61461 .48419 L
s
.347 .401 1 r
.77743 .46658 m
.77799 .47426 L
s
.778 .47369 m
.77743 .46658 L
s
.77799 .47426 m
.77746 .46655 L
s
.77746 .46655 m
.778 .47369 L
s
.559 .267 1 r
.88982 .4841 m
.8898 .48442 L
s
.45 .297 1 r
.6925 .42394 m
.69457 .46228 L
s
.589 .259 1 r
.40789 .42394 m
.4067 .46444 L
s
.35 .415 1 r
.62348 .46736 m
.62369 .47493 L
s
.62373 .47462 m
.62348 .46736 L
s
.62369 .47493 m
.6235 .46733 L
s
.6235 .46733 m
.62373 .47462 L
s
.7 .232 1 r
.92226 .47456 m
.92325 .48323 L
s
.92329 .48305 m
.92226 .47456 L
s
.494 .284 1 r
.34388 .48296 m
.34381 .48325 L
s
.845 .199 1 r
.71676 .46231 m
.71723 .47135 L
s
.71726 .47131 m
.71676 .46231 L
s
.71676 .46231 m
.71777 .48006 L
s
.7 .232 1 r
.92325 .48323 m
.92229 .47453 L
s
.92229 .47453 m
.92329 .48305 L
s
.754 .219 1 r
.25067 .48823 m
.2506 .48838 L
s
.608 .254 1 r
.45124 .48503 m
.45118 .48532 L
s
.477 .289 1 r
.6052 .48446 m
.60515 .48435 L
s
.799 .209 1 r
.43213 .46245 m
.43186 .47135 L
s
.43188 .47131 m
.43213 .46245 L
s
.43213 .46245 m
.43168 .48006 L
s
.679 .237 1 r
.8465 .42372 m
.85068 .46602 L
s
.869 .194 1 r
.56185 .42372 m
.56254 .46746 L
s
.342 .378 1 r
.2772 .42372 m
.27474 .46027 L
s
.744 .221 1 r
.60941 .46071 m
.6096 .46956 L
s
.60962 .46952 m
.60941 .46071 L
s
.60941 .46071 m
.60986 .47798 L
s
.383 .317 1 r
.82911 .48011 m
.82909 .48046 L
s
.559 .267 1 r
.55359 .47178 m
.55365 .48016 L
s
.5537 .47983 m
.55359 .47178 L
s
.352 .327 1 r
.69844 .47954 m
.6984 .47986 L
s
.559 .267 1 r
.55365 .48016 m
.55361 .47175 L
s
.55361 .47175 m
.5537 .47983 L
s
.523 .277 1 r
.9365 .48218 m
.93651 .48268 L
s
.965 .174 1 r
.87571 .4777 m
.87664 .48692 L
s
.87669 .48677 m
.87571 .4777 L
s
.638 .247 1 r
.76339 .46021 m
.76396 .46877 L
s
.76398 .46874 m
.76339 .46021 L
s
.76339 .46021 m
.76458 .47705 L
s
.965 .174 1 r
.87664 .48692 m
.87574 .47766 L
s
.87574 .47766 m
.87669 .48677 L
s
.54 .272 1 r
.47454 .48424 m
.47448 .48439 L
s
.88 .191 1 r
.87079 .46231 m
.87167 .47142 L
s
.8717 .47138 m
.87079 .46231 L
s
.87079 .46231 m
.87261 .4802 L
s
.459 .294 1 r
.81002 .45779 m
.81066 .46592 L
s
.81068 .46588 m
.81002 .45779 L
s
.81002 .45779 m
.81135 .47368 L
s
.559 .267 1 r
.91322 .48367 m
.9132 .484 L
s
.62853 .48367 m
.62849 .484 L
s
.618 .252 1 r
.9174 .45975 m
.91834 .46827 L
s
.91837 .46823 m
.9174 .45975 L
s
.9174 .45975 m
.91933 .47647 L
s
.433 .302 1 r
.31552 .4695 m
.31502 .47755 L
s
.3151 .47719 m
.31552 .4695 L
s
.56 .267 1 r
.71586 .4235 m
.71827 .46328 L
s
.589 .259 1 r
.43117 .4235 m
.43026 .464 L
s
.433 .302 1 r
.31502 .47755 m
.31553 .46947 L
s
.31553 .46947 m
.3151 .47719 L
s
.375 .32 1 r
.41377 .47989 m
.4137 .48021 L
s
.744 .221 1 r
.37629 .47414 m
.3759 .48295 L
s
.37597 .48262 m
.37629 .47414 L
s
.733 .224 1 r
.68931 .48838 m
.68925 .48835 L
s
.638 .247 1 r
.32053 .48517 m
.32046 .48546 L
s
.744 .221 1 r
.3759 .48295 m
.3763 .4741 L
s
.3763 .4741 m
.37597 .48262 L
s
.834 .201 1 r
.48367 .47621 m
.48355 .48514 L
s
.48361 .48505 m
.48367 .47621 L
s
.494 .285 1 r
.29219 .47107 m
.29163 .47923 L
s
.2917 .47904 m
.29219 .47107 L
s
.441 .3 1 r
.60021 .46979 m
.60038 .47783 L
s
.60043 .47755 m
.60021 .46979 L
s
.834 .201 1 r
.48355 .48514 m
.48369 .47617 L
s
.48369 .47617 m
.48361 .48505 L
s
.589 .259 1 r
.94075 .45878 m
.94174 .46727 L
s
.94177 .46724 m
.94075 .45878 L
s
.94075 .45878 m
.94277 .47533 L
s
.494 .285 1 r
.29163 .47923 m
.29221 .47103 L
s
.29221 .47103 m
.2917 .47904 L
s
.441 .3 1 r
.60038 .47783 m
.60023 .46975 L
s
.60023 .46975 m
.60043 .47755 L
s
.496 .284 1 r
.83337 .45689 m
.83408 .4652 L
s
.8341 .46516 m
.83337 .45689 L
s
.83337 .45689 m
.83482 .47289 L
s
.733 .224 1 r
.47872 .46085 m
.47858 .46963 L
s
.4786 .46959 m
.47872 .46085 L
s
.47872 .46085 m
.47852 .47813 L
s
1 .128 .8 r
.8699 .42328 m
.8749 .47063 L
s
.7 .232 1 r
.58518 .42328 m
.58612 .46558 L
s
.638 .247 1 r
.30045 .42328 m
.29788 .46558 L
s
.67 .239 1 r
.50697 .47521 m
.50692 .48366 L
s
.50697 .48391 m
.50697 .47521 L
s
.50692 .48366 m
.50699 .47517 L
s
.50699 .47517 m
.50697 .48391 L
s
.504 .282 1 r
.67518 .48175 m
.67514 .48218 L
s
.337 .353 1 r
.30634 .47854 m
.30627 .47882 L
s
.777 .214 1 r
.58194 .48702 m
.58189 .48736 L
s
.658 .242 1 r
.63275 .46056 m
.63299 .46913 L
s
.63301 .46909 m
.63275 .46056 L
s
.63275 .46056 m
.6333 .47755 L
s
.69 .234 1 r
.26885 .47293 m
.26819 .48163 L
s
.26828 .48126 m
.26885 .47293 L
s
.391 .315 1 r
.85253 .48004 m
.85251 .48032 L
s
.712 .229 1 r
.73922 .42306 m
.74203 .46465 L
s
.638 .247 1 r
.45446 .42306 m
.45381 .46429 L
s
.69 .234 1 r
.26819 .48163 m
.26887 .47289 L
s
.26887 .47289 m
.26828 .48126 L
s
1 .161 .972 r
.64272 .49173 m
.64267 .49185 L
s
.56 .267 1 r
.67938 .45814 m
.67973 .46656 L
s
.67975 .46652 m
.67938 .45814 L
s
.67938 .45814 m
.68014 .47454 L
s
.904 .186 1 r
.89422 .46213 m
.89517 .47127 L
s
.8952 .47123 m
.89422 .46213 L
s
.89422 .46213 m
.89617 .48013 L
s
.893 .189 1 r
.86672 .48738 m
.86672 .48797 L
s
.733 .224 1 r
.34798 .46095 m
.34751 .4697 L
s
.34752 .46966 m
.34798 .46095 L
s
.34798 .46095 m
.34712 .47827 L
s
.522 .277 1 r
.52115 .48303 m
.5211 .48321 L
s
.375 .532 1 r
.8933 .42284 m
.89737 .45904 L
s
.416 .307 1 r
.60851 .42284 m
.60963 .46119 L
s
.618 .252 1 r
.32372 .42284 m
.32151 .46371 L
s
.81 .206 1 r
.42789 .48831 m
.42783 .48843 L
s
.766 .217 1 r
.78684 .46063 m
.78748 .46949 L
s
.78751 .46945 m
.78684 .46063 L
s
.78684 .46063 m
.78818 .47805 L
s
.778 .214 1 r
.94584 .47556 m
.9469 .48432 L
s
.94697 .48441 m
.94584 .47556 L
s
.468 .292 1 r
.56779 .48075 m
.56774 .48115 L
s
.777 .214 1 r
.6561 .46006 m
.65641 .46898 L
s
.65643 .46895 m
.6561 .46006 L
s
.6561 .46006 m
.65679 .47748 L
s
.778 .214 1 r
.9469 .48432 m
.94587 .47553 L
s
.94587 .47553 m
.94697 .48441 L
s
.531 .274 1 r
.76259 .42262 m
.76556 .46241 L
s
.845 .199 1 r
.47777 .42262 m
.47738 .46601 L
s
.659 .242 1 r
.50202 .46099 m
.50194 .46949 L
s
.50196 .46945 m
.50202 .46099 L
s
.50202 .46099 m
.50193 .47805 L
s
.822 .204 1 r
.39953 .47485 m
.39919 .48378 L
s
.39926 .48363 m
.39953 .47485 L
s
.68 .237 1 r
.73103 .47228 m
.73154 .48095 L
s
.73158 .48062 m
.73103 .47228 L
s
.512 .279 1 r
.25961 .48261 m
.25955 .48275 L
s
.822 .204 1 r
.39919 .48378 m
.39954 .47481 L
s
.39954 .47481 m
.39926 .48363 L
s
.588 .259 1 r
.91672 .4224 m
.92156 .46291 L
s
.68 .237 1 r
.63185 .4224 m
.63336 .46399 L
s
.765 .217 1 r
.34699 .4224 m
.34492 .46615 L
s
.658 .242 1 r
.49783 .48525 m
.49778 .4854 L
s
.68 .237 1 r
.73154 .48095 m
.73105 .47224 L
s
.73105 .47224 m
.73158 .48062 L
s
.765 .217 1 r
.37125 .46073 m
.37083 .46955 L
s
.37085 .46952 m
.37125 .46073 L
s
.37125 .46073 m
.3705 .4782 L
s
.6 .256 1 r
.90846 .4705 m
.90941 .47902 L
s
.90941 .47855 m
.90846 .4705 L
s
.352 .327 1 r
.61863 .45493 m
.61882 .46276 L
s
.61884 .46273 m
.61863 .45493 L
s
.61863 .45493 m
.61907 .47017 L
s
.648 .244 1 r
.54867 .45888 m
.5487 .46748 L
s
.54872 .46744 m
.54867 .45888 L
s
.54867 .45888 m
.54881 .47576 L
s
.6 .256 1 r
.90941 .47902 m
.90849 .47046 L
s
.90849 .47046 m
.90941 .47855 L
s
.766 .217 1 r
.24047 .4602 m
.23972 .46905 L
s
.23973 .46902 m
.24047 .4602 L
s
.24047 .4602 m
.23906 .47762 L
s
.392 .314 1 r
.82434 .46743 m
.82503 .47537 L
s
.82505 .47497 m
.82434 .46743 L
s
.82503 .47537 m
.82437 .46739 L
s
.82437 .46739 m
.82505 .47497 L
s
.55 .269 1 r
.3387 .47078 m
.33824 .47909 L
s
.33831 .4789 m
.3387 .47078 L
s
.389 .315 1 r
.78598 .42218 m
.78886 .45731 L
s
.799 .209 1 r
.50108 .42217 m
.50098 .46629 L
s
.589 .259 1 r
.21618 .42217 m
.21269 .46305 L
s
.55 .269 1 r
.33824 .47909 m
.33871 .47074 L
s
.33871 .47074 m
.33831 .4789 L
s
.69 .234 1 r
.44616 .47285 m
.44595 .48149 L
s
.44601 .48134 m
.44616 .47285 L
s
1 .131 .814 r
.45538 .46443 m
.45516 .47406 L
s
.45518 .47402 m
.45538 .46443 L
s
.45538 .46443 m
.45502 .48358 L
s
.569 .264 1 r
.41788 .45863 m
.41759 .46698 L
s
.41761 .46694 m
.41788 .45863 L
s
.41788 .45863 m
.41739 .47519 L
s
.69 .234 1 r
.44595 .48149 m
.44617 .47281 L
s
.44617 .47281 m
.44601 .48134 L
s
.723 .226 1 r
.7028 .45873 m
.70323 .46755 L
s
.70325 .46751 m
.7028 .45873 L
s
.7028 .45873 m
.70371 .4759 L
s
.578 .262 1 r
.26375 .45945 m
.26309 .46776 L
s
.26311 .46773 m
.26375 .45945 L
s
.26375 .45945 m
.26251 .47612 L
s
.953 .176 1 r
.73611 .4886 m
.73607 .48894 L
s
.722 .227 1 r
.39455 .46012 m
.39419 .46884 L
s
.39421 .4688 m
.39455 .46012 L
s
.39455 .46012 m
.39392 .47741 L
s
.346 .329 1 r
.81525 .47633 m
.81525 .47694 L
s
.845 .199 1 r
.94015 .42195 m
.94563 .46535 L
s
.599 .257 1 r
.65521 .42195 m
.65694 .46211 L
s
.588 .259 1 r
.37028 .42195 m
.36864 .46247 L
s
.723 .226 1 r
.57695 .47392 m
.57707 .48256 L
s
.57713 .48263 m
.57695 .47392 L
s
.559 .267 1 r
.362 .47007 m
.36159 .47844 L
s
.36167 .47812 m
.362 .47007 L
s
.723 .226 1 r
.57707 .48256 m
.57697 .47389 L
s
.57697 .47389 m
.57713 .48263 L
s
.559 .267 1 r
.36159 .47844 m
.36201 .47003 L
s
.36201 .47003 m
.36167 .47812 L
s
.531 .274 1 r
.88029 .45716 m
.88111 .46548 L
s
.88114 .46544 m
.88029 .45716 L
s
.88029 .45716 m
.88199 .47346 L
s
.424 .305 1 r
.90361 .45588 m
.90446 .4639 L
s
.90449 .46387 m
.90361 .45588 L
s
.90361 .45588 m
.90536 .4716 L
s
.722 .227 1 r
.36702 .48575 m
.36695 .4859 L
s
.857 .196 1 r
.52535 .46119 m
.52533 .4702 L
s
.52535 .47016 m
.52535 .46119 L
s
.52535 .46119 m
.52538 .47906 L
s
.375 .532 1 r
.68446 .47612 m
.68441 .47607 L
s
.54 .272 1 r
.44119 .45799 m
.44096 .46626 L
s
.44098 .46623 m
.44119 .45799 L
s
.44119 .45799 m
.44081 .4744 L
s
.56 .267 1 r
.80938 .42173 m
.81289 .46154 L
s
.733 .224 1 r
.52441 .42173 m
.52461 .46406 L
s
.433 .302 1 r
.23944 .42173 m
.23636 .46082 L
s
.904 .186 1 r
.42281 .47499 m
.42253 .4841 L
s
.4226 .48391 m
.42281 .47499 L
s
.7 .232 1 r
.46947 .47242 m
.46932 .48109 L
s
.46939 .48091 m
.46947 .47242 L
s
.904 .186 1 r
.42253 .4841 m
.42283 .47495 L
s
.42283 .47495 m
.4226 .48391 L
s
.7 .232 1 r
.46932 .48109 m
.46949 .47238 L
s
.46949 .47238 m
.46939 .48091 L
s
.347 .403 1 r
.53032 .47704 m
.53027 .47718 L
s
.649 .244 1 r
.59535 .45769 m
.5955 .46633 L
s
.59552 .46629 m
.59535 .45769 L
s
.59535 .45769 m
.59572 .47454 L
s
.505 .281 1 r
.64202 .45512 m
.64228 .46347 L
s
.6423 .46343 m
.64202 .45512 L
s
.64202 .45512 m
.64259 .47117 L
s
.99 .169 1 r
.70781 .47528 m
.70829 .48461 L
s
.70834 .48427 m
.70781 .47528 L
s
.69 .234 1 r
.39033 .48497 m
.39026 .48511 L
s
.99 .169 1 r
.70829 .48461 m
.70783 .47524 L
s
.70783 .47524 m
.70834 .48427 L
s
.711 .229 1 r
.96359 .42151 m
.96918 .46348 L
s
.802 .208 1 r
.67858 .42151 m
.68068 .46348 L
s
.965 .174 1 r
.39357 .42151 m
.39205 .46672 L
s
.476 .29 1 r
.46032 .48118 m
.46026 .48129 L
s
.578 .262 1 r
.31034 .45794 m
.30979 .46633 L
s
.30981 .46629 m
.31034 .45794 L
s
.31034 .45794 m
.30933 .47454 L
s
.494 .284 1 r
.89951 .48061 m
.89949 .4809 L
s
.69 .234 1 r
.287 .45926 m
.28638 .46791 L
s
.2864 .46787 m
.287 .45926 L
s
.287 .45926 m
.28585 .4764 L
s
.799 .209 1 r
.75449 .47299 m
.75508 .48192 L
s
.75512 .48163 m
.75449 .47299 L
s
.367 .322 1 r
.63783 .47947 m
.63777 .47943 L
s
.45 .297 1 r
.35281 .47947 m
.35274 .47979 L
s
.799 .209 1 r
.75508 .48192 m
.75452 .47296 L
s
.75452 .47296 m
.75512 .48163 L
s
1 .143 .881 r
.83868 .47635 m
.83954 .48594 L
s
.83957 .48557 m
.83868 .47635 L
s
.99 .169 1 r
.86201 .47506 m
.86292 .4844 L
s
.86295 .48406 m
.86201 .47506 L
s
.722 .227 1 r
.85706 .45948 m
.85787 .46819 L
s
.85789 .46815 m
.85706 .45948 L
s
.85706 .45948 m
.85875 .47676 L
s
.7 .232 1 r
.5445 .48475 m
.54444 .48494 L
s
1 .164 .985 r
.96459 .46147 m
.96574 .47084 L
s
.96578 .4708 m
.96459 .46147 L
s
.96459 .46147 m
.96696 .47992 L
s
.459 .295 1 r
.40861 .46864 m
.40833 .47669 L
s
.40839 .47655 m
.40861 .46864 L
s
.541 .272 1 r
.69366 .46864 m
.69407 .47702 L
s
.6941 .47654 m
.69366 .46864 L
s
.8 .209 1 r
.57203 .45955 m
.57212 .46848 L
s
.57215 .46844 m
.57203 .45955 L
s
.57203 .45955 m
.57229 .47712 L
s
1 .143 .881 r
.83954 .48594 m
.83871 .47631 L
s
.83871 .47631 m
.83957 .48557 L
s
.99 .169 1 r
.86292 .4844 m
.86204 .47502 L
s
.86204 .47502 m
.86295 .48406 L
s
.45 .297 1 r
.83279 .42129 m
.83644 .45966 L
s
.733 .224 1 r
.54775 .42129 m
.54824 .46362 L
s
.68 .237 1 r
.26271 .42129 m
.25972 .4629 L
s
.459 .295 1 r
.40833 .47669 m
.40863 .4686 L
s
.40863 .4686 m
.40839 .47655 L
s
.541 .272 1 r
.69407 .47702 m
.69368 .4686 L
s
.69368 .4686 m
.6941 .47654 L
s
.659 .242 1 r
.80118 .47071 m
.80187 .47934 L
s
.8019 .47898 m
.80118 .47071 L
s
.68 .237 1 r
.51614 .47071 m
.51611 .47942 L
s
.51617 .47898 m
.51614 .47071 L
s
.512 .279 1 r
.25442 .46942 m
.25376 .47762 L
s
.25383 .47748 m
.25442 .46942 L
s
.659 .242 1 r
.80187 .47934 m
.80121 .47067 L
s
.80121 .47067 m
.8019 .47898 L
s
.68 .237 1 r
.51611 .47942 m
.51616 .47067 L
s
.51616 .47067 m
.51617 .47898 L
s
.512 .279 1 r
.25376 .47762 m
.25443 .46939 L
s
.25443 .46939 m
.25383 .47748 L
s
.488 .286 1 r
.74036 .46635 m
.74087 .47469 L
s
.74088 .4739 m
.74036 .46635 L
s
.467 .292 1 r
.33363 .4573 m
.33316 .46533 L
s
.33318 .46529 m
.33363 .4573 L
s
.33363 .4573 m
.33276 .47339 L
s
.488 .286 1 r
.74087 .47469 m
.74038 .46632 L
s
.74038 .46632 m
.74088 .4739 L
s
.904 .186 1 r
.70196 .42107 m
.70448 .46556 L
s
.81 .206 1 r
.41688 .42107 m
.41571 .46484 L
s
.56 .267 1 r
.76873 .48076 m
.76871 .48119 L
s
.638 .247 1 r
.647 .47178 m
.6473 .48024 L
s
.64735 .48027 m
.647 .47178 L
s
.6473 .48024 m
.64702 .47174 L
s
.64702 .47174 m
.64735 .48027 L
s
.383 .317 1 r
.81961 .45434 m
.82026 .46225 L
s
.82028 .46222 m
.81961 .45434 L
s
.81961 .45434 m
.82095 .46981 L
s
.834 .201 1 r
.72626 .45954 m
.72675 .46855 L
s
.72678 .46851 m
.72626 .45954 L
s
.72626 .45954 m
.72732 .47727 L
s
.701 .232 1 r
.23104 .47128 m
.23029 .47999 L
s
.23037 .4797 m
.23104 .47128 L
s
.599 .257 1 r
.92716 .45637 m
.92813 .4649 L
s
.92815 .46486 m
.92716 .45637 L
s
.92716 .45637 m
.92912 .47296 L
s
.701 .232 1 r
.23029 .47999 m
.23105 .47124 L
s
.23105 .47124 m
.23037 .4797 L
s
.416 .307 1 r
.24522 .47847 m
.24514 .47876 L
s
.67 .239 1 r
.28274 .48433 m
.28267 .48441 L
s
.811 .206 1 r
.93213 .47207 m
.93319 .48107 L
s
.93319 .48063 m
.93213 .47207 L
s
.503 .282 1 r
.79629 .45587 m
.79691 .46411 L
s
.79693 .46407 m
.79629 .45587 L
s
.79629 .45587 m
.79758 .47203 L
s
.375 .32 1 r
.95051 .45523 m
.95144 .46304 L
s
.95147 .463 m
.95051 .45523 L
s
.95051 .45523 m
.95245 .47074 L
s
.777 .214 1 r
.85621 .42085 m
.86053 .46318 L
s
.68 .237 1 r
.5711 .42085 m
.57187 .46246 L
s
.608 .254 1 r
.28599 .42085 m
.28333 .46174 L
s
.811 .206 1 r
.93319 .48107 m
.93216 .47203 L
s
.93216 .47203 m
.93319 .48063 L
s
.441 .3 1 r
.38029 .45527 m
.37993 .46332 L
s
.37995 .46329 m
.38029 .45527 L
s
.38029 .45527 m
.37965 .4711 L
s
.551 .269 1 r
.22606 .456 m
.22531 .46439 L
s
.22532 .46436 m
.22606 .456 L
s
.22606 .456 m
.22466 .47238 L
s
.403 .651 1 r
.67038 .4709 m
.67035 .47132 L
s
.359 .325 1 r
.32438 .46642 m
.32392 .47418 L
s
.32398 .47404 m
.32438 .46642 L
s
.965 .174 1 r
.88547 .47492 m
.88643 .48415 L
s
.88647 .48399 m
.88547 .47492 L
s
.359 .325 1 r
.32392 .47418 m
.32439 .46639 L
s
.32439 .46639 m
.32398 .47404 L
s
.965 .174 1 r
.88643 .48415 m
.8855 .47488 L
s
.8855 .47488 m
.88647 .48399 L
s
.486 .287 1 r
.72535 .42063 m
.72782 .45936 L
s
.69 .234 1 r
.4402 .42063 m
.43936 .46296 L
s
.744 .221 1 r
.48784 .45768 m
.48772 .46654 L
s
.48774 .4665 m
.48784 .45768 L
s
.48784 .45768 m
.48768 .47497 L
s
.513 .279 1 r
.66124 .47976 m
.6612 .48012 L
s
.639 .247 1 r
.848 .46956 m
.8488 .47816 L
s
.84882 .47776 m
.848 .46956 L
s
.8488 .47816 m
.84803 .46953 L
s
.84803 .46953 m
.84882 .47776 L
s
.823 .204 1 r
.38523 .47163 m
.38485 .48067 L
s
.38493 .4802 m
.38523 .47163 L
s
.559 .267 1 r
.79217 .48069 m
.79214 .48101 L
s
.733 .224 1 r
.87965 .42041 m
.88425 .46275 L
s
.711 .229 1 r
.59446 .42041 m
.59553 .46311 L
s
.733 .224 1 r
.30928 .42041 m
.30679 .4631 L
s
.823 .204 1 r
.38485 .48067 m
.38524 .4716 L
s
.38524 .4716 m
.38493 .4802 L
s
.833 .201 1 r
.46449 .45943 m
.4643 .4684 L
s
.46432 .46836 m
.46449 .45943 L
s
.46449 .45943 m
.4642 .47719 L
s
.347 .401 1 r
.778 .47369 m
.77799 .47426 L
s
.952 .176 1 r
.65209 .48861 m
.65203 .48862 L
s
.599 .257 1 r
.58619 .46856 m
.58633 .47709 L
s
.58638 .47662 m
.58619 .46856 L
s
.58633 .47709 m
.58621 .46852 L
s
.58621 .46852 m
.58638 .47662 L
s
.977 .171 1 r
.23597 .48804 m
.23589 .48823 L
s
.846 .199 1 r
.77305 .45832 m
.77367 .4674 L
s
.77369 .46736 m
.77305 .45832 L
s
.77305 .45832 m
.77435 .47605 L
s
.953 .176 1 r
.7497 .45971 m
.75027 .46897 L
s
.7503 .46893 m
.7497 .45971 L
s
.7497 .45971 m
.75091 .47791 L
s
.35 .415 1 r
.62373 .47462 m
.62369 .47493 L
s
.811 .206 1 r
.74876 .42019 m
.75177 .46289 L
s
.904 .186 1 r
.46354 .42019 m
.46295 .46469 L
s
.834 .201 1 r
.95565 .47221 m
.95677 .48121 L
s
.95679 .48092 m
.95565 .47221 L
s
.95677 .48121 m
.95568 .47217 L
s
.95568 .47217 m
.95679 .48092 L
s
.588 .259 1 r
.2493 .45607 m
.2486 .46453 L
s
.24861 .4645 m
.2493 .45607 L
s
.2493 .45607 m
.24799 .47267 L
s
1 .161 .972 r
.49279 .47428 m
.49269 .48369 L
s
.49276 .48335 m
.49279 .47428 L
s
.638 .247 1 r
.66548 .45675 m
.6658 .46532 L
s
.66582 .46529 m
.66548 .45675 L
s
.66548 .45675 m
.66619 .47361 L
s
.368 .322 1 r
.58123 .45354 m
.58133 .46139 L
s
.58135 .46135 m
.58123 .45354 L
s
.58123 .45354 m
.5815 .46894 L
s
1 .161 .972 r
.49269 .48369 m
.49281 .47424 L
s
.49281 .47424 m
.49276 .48335 L
s
.8 .209 1 r
.35688 .45825 m
.35642 .46718 L
s
.35644 .46715 m
.35688 .45825 L
s
.35688 .45825 m
.35605 .47583 L
s
.649 .244 1 r
.90309 .41997 m
.90782 .46087 L
s
.55 .269 1 r
.97409 .45568 m
.97515 .46403 L
s
.97518 .464 m
.97409 .45568 L
s
.97409 .45568 m
.97625 .4721 L
s
.608 .254 1 r
.61784 .41996 m
.61915 .46087 L
s
.579 .262 1 r
.33258 .41996 m
.3305 .46051 L
s
.799 .209 1 r
.53949 .47199 m
.53952 .48089 L
s
.53958 .4807 m
.53949 .47199 L
s
.649 .244 1 r
.30094 .46942 m
.30037 .47802 L
s
.30045 .47769 m
.30094 .46942 L
s
.551 .269 1 r
.55789 .45514 m
.55795 .46353 L
s
.55796 .46349 m
.55789 .45514 L
s
.55789 .45514 m
.55807 .47152 L
s
.799 .209 1 r
.53952 .48089 m
.53951 .47195 L
s
.53951 .47195 m
.53958 .4807 L
s
.649 .244 1 r
.30037 .47802 m
.30095 .46938 L
s
.30095 .46938 m
.30045 .47769 L
s
.522 .277 1 r
.84316 .45525 m
.8439 .46353 L
s
.84392 .4635 m
.84316 .45525 L
s
.84316 .45525 m
.84469 .47153 L
s
.722 .227 1 r
.27756 .47099 m
.27693 .47971 L
s
.277 .47956 m
.27756 .47099 L
s
.811 .206 1 r
.51119 .45799 m
.51112 .46697 L
s
.51114 .46693 m
.51119 .45799 L
s
.51119 .45799 m
.51114 .47562 L
s
.376 .32 1 r
.77217 .41974 m
.77506 .45705 L
s
.355 .437 1 r
.48688 .41974 m
.48667 .45526 L
s
.722 .227 1 r
.27693 .47971 m
.27758 .47095 L
s
.27758 .47095 m
.277 .47956 L
s
.765 .217 1 r
.32929 .48419 m
.32922 .48438 L
s
.834 .201 1 r
.61461 .48419 m
.61456 .48459 L
s
.811 .206 1 r
.56286 .47128 m
.56295 .48024 L
s
.563 .47991 m
.56286 .47128 L
s
.56295 .48024 m
.56288 .47124 L
s
.56288 .47124 m
.563 .47991 L
s
.904 .186 1 r
.43691 .48626 m
.43684 .48645 L
s
.433 .302 1 r
.3151 .47719 m
.31502 .47755 L
s
.7 .232 1 r
.92329 .48305 m
.92325 .48323 L
s
.559 .267 1 r
.5537 .47983 m
.55365 .48016 L
s
.916 .184 1 r
.59125 .48569 m
.5912 .48602 L
s
.503 .282 1 r
.92655 .41952 m
.93138 .45899 L
s
.712 .229 1 r
.64122 .41952 m
.64284 .46115 L
s
.485 .287 1 r
.35589 .41952 m
.35412 .45935 L
s
.459 .294 1 r
.81066 .46592 m
.81133 .47404 L
s
.81135 .47368 m
.81066 .46592 L
s
.441 .3 1 r
.60043 .47755 m
.60038 .47783 L
s
.459 .294 1 r
.81133 .47404 m
.81068 .46588 L
s
.81068 .46588 m
.81135 .47368 L
s
.649 .244 1 r
.7956 .4193 m
.79904 .46021 L
s
.579 .262 1 r
.51024 .4193 m
.51026 .45985 L
s
.638 .247 1 r
.22487 .4193 m
.22142 .46093 L
s
.494 .285 1 r
.2917 .47904 m
.29163 .47923 L
s
.845 .199 1 r
.71723 .47135 m
.71773 .48039 L
s
.71777 .48006 m
.71723 .47135 L
s
.799 .209 1 r
.43186 .47135 m
.43161 .48024 L
s
.43168 .48006 m
.43186 .47135 L
s
.638 .247 1 r
.76396 .46877 m
.76455 .47734 L
s
.76458 .47705 m
.76396 .46877 L
s
.608 .254 1 r
.68891 .45707 m
.68928 .46546 L
s
.6893 .46542 m
.68891 .45707 L
s
.68891 .45707 m
.68973 .47389 L
s
.638 .247 1 r
.27254 .45642 m
.27189 .46496 L
s
.2719 .46492 m
.27254 .45642 L
s
.27254 .45642 m
.27132 .47332 L
s
.845 .199 1 r
.71773 .48039 m
.71726 .47131 L
s
.71726 .47131 m
.71777 .48006 L
s
.799 .209 1 r
.43161 .48024 m
.43188 .47131 L
s
.43188 .47131 m
.43168 .48006 L
s
.638 .247 1 r
.76455 .47734 m
.76398 .46874 L
s
.76398 .46874 m
.76458 .47705 L
s
.744 .221 1 r
.6096 .46956 m
.60981 .47842 L
s
.60986 .47798 m
.6096 .46956 L
s
.618 .252 1 r
.91834 .46827 m
.91931 .4768 L
s
.91933 .47647 m
.91834 .46827 L
s
.744 .221 1 r
.60981 .47842 m
.60962 .46952 L
s
.60962 .46952 m
.60986 .47798 L
s
.618 .252 1 r
.91931 .4768 m
.91837 .46823 L
s
.91837 .46823 m
.91933 .47647 L
s
.788 .212 1 r
.53455 .45795 m
.53454 .46682 L
s
.53456 .46678 m
.53455 .45795 L
s
.53455 .45795 m
.53462 .47554 L
s
.744 .221 1 r
.37597 .48262 m
.3759 .48295 L
s
.496 .284 1 r
.83408 .4652 m
.83482 .47351 L
s
.83482 .47289 m
.83408 .4652 L
s
.588 .259 1 r
.95002 .41908 m
.95526 .45963 L
s
.536 1 .899 r
.66462 .41908 m
.6658 .44458 L
s
.69 .234 1 r
.37922 .41908 m
.37762 .46143 L
s
.496 .284 1 r
.83482 .47351 m
.8341 .46516 L
s
.8341 .46516 m
.83482 .47289 L
s
.589 .259 1 r
.94174 .46727 m
.94277 .47576 L
s
.94277 .47533 m
.94174 .46727 L
s
.754 .219 1 r
.40353 .45752 m
.40319 .46632 L
s
.40321 .46628 m
.40353 .45752 L
s
.40353 .45752 m
.40294 .47497 L
s
.589 .259 1 r
.94277 .47576 m
.94177 .46724 L
s
.94177 .46724 m
.94277 .47533 L
s
.965 .174 1 r
.87669 .48677 m
.87664 .48692 L
s
.658 .242 1 r
.42688 .45645 m
.42661 .46503 L
s
.42663 .46499 m
.42688 .45645 L
s
.42688 .45645 m
.42642 .47346 L
s
.67 .239 1 r
.50697 .48391 m
.50692 .48366 L
s
.88 .191 1 r
.87167 .47142 m
.87258 .48054 L
s
.87261 .4802 m
.87167 .47142 L
s
.649 .244 1 r
.31923 .45456 m
.31868 .46324 L
s
.3187 .4632 m
.31923 .45456 L
s
.31923 .45456 m
.31824 .47138 L
s
.834 .201 1 r
.48361 .48505 m
.48355 .48514 L
s
.88 .191 1 r
.87258 .48054 m
.8717 .47138 L
s
.8717 .47138 m
.87261 .4802 L
s
.463 .881 1 r
.81904 .41886 m
.82182 .44936 L
s
.425 .304 1 r
.5336 .41886 m
.53389 .4569 L
s
.953 .176 1 r
.24817 .41886 m
.24472 .4641 L
s
.733 .224 1 r
.47858 .46963 m
.47845 .47842 L
s
.47852 .47813 m
.47858 .46963 L
s
.69 .234 1 r
.26828 .48126 m
.26819 .48163 L
s
.823 .204 1 r
.86674 .45602 m
.86761 .4651 L
s
.86764 .46506 m
.86674 .45602 L
s
.86674 .45602 m
.86851 .47361 L
s
.691 .234 1 r
.60466 .45473 m
.60484 .46352 L
s
.60486 .46348 m
.60466 .45473 L
s
.60466 .45473 m
.60508 .47174 L
s
.733 .224 1 r
.47845 .47842 m
.4786 .46959 L
s
.4786 .46959 m
.47852 .47813 L
s
.658 .242 1 r
.63299 .46913 m
.63325 .4777 L
s
.6333 .47755 m
.63299 .46913 L
s
.416 .307 1 r
.78244 .45288 m
.783 .46087 L
s
.78303 .46084 m
.78244 .45288 L
s
.78244 .45288 m
.78363 .46858 L
s
.56 .267 1 r
.67973 .46656 m
.6801 .47498 L
s
.68014 .47454 m
.67973 .46656 L
s
.712 .229 1 r
.73571 .45552 m
.73622 .46431 L
s
.73624 .46427 m
.73571 .45552 L
s
.73571 .45552 m
.73678 .47267 L
s
.589 .259 1 r
.75908 .45424 m
.75962 .46273 L
s
.75965 .4627 m
.75908 .45424 L
s
.75908 .45424 m
.76023 .4708 L
s
.658 .242 1 r
.63325 .4777 m
.63301 .46909 L
s
.63301 .46909 m
.6333 .47755 L
s
.425 .304 1 r
.6514 .45231 m
.65167 .46037 L
s
.65169 .46033 m
.6514 .45231 L
s
.6514 .45231 m
.652 .468 L
s
.56 .267 1 r
.6801 .47498 m
.67975 .46652 L
s
.67975 .46652 m
.68014 .47454 L
s
.733 .224 1 r
.68803 .41864 m
.69026 .461 L
s
.618 .252 1 r
.40256 .41864 m
.40127 .46028 L
s
.398 .631 1 r
.85257 .44935 m
.85322 .45643 L
s
.85324 .4564 m
.85257 .44935 L
s
.85257 .44935 m
.85392 .46334 L
s
.368 .322 1 r
.80584 .45202 m
.80645 .45987 L
s
.80648 .45984 m
.80584 .45202 L
s
.80584 .45202 m
.80712 .46743 L
s
.733 .224 1 r
.34751 .4697 m
.34705 .47845 L
s
.34712 .47827 m
.34751 .4697 L
s
.579 .262 1 r
.84249 .41841 m
.84646 .45898 L
s
.559 .267 1 r
.55698 .41841 m
.55756 .45861 L
s
.4 .312 1 r
.27148 .41841 m
.26884 .45646 L
s
.733 .224 1 r
.34705 .47845 m
.34752 .46966 L
s
.34752 .46966 m
.34712 .47827 L
s
.392 .314 1 r
.82505 .47497 m
.82503 .47537 L
s
.352 .327 1 r
.61882 .46276 m
.61903 .4706 L
s
.61907 .47017 m
.61882 .46276 L
s
.904 .186 1 r
.89517 .47127 m
.89614 .48043 L
s
.89617 .48013 m
.89517 .47127 L
s
.352 .327 1 r
.61903 .4706 m
.61884 .46273 L
s
.61884 .46273 m
.61907 .47017 L
s
.579 .262 1 r
.91358 .45438 m
.9145 .4628 L
s
.91453 .46277 m
.91358 .45438 L
s
.91358 .45438 m
.91547 .47095 L
s
.335 .34 1 r
.54373 .45113 m
.54375 .45886 L
s
.54376 .45883 m
.54373 .45113 L
s
.54373 .45113 m
.54383 .46628 L
s
.904 .186 1 r
.89614 .48043 m
.8952 .47123 L
s
.8952 .47123 m
.89617 .48013 L
s
.788 .212 1 r
.29578 .45709 m
.29516 .46596 L
s
.29518 .46592 m
.29578 .45709 L
s
.29578 .45709 m
.29463 .47468 L
s
.778 .214 1 r
.94697 .48441 m
.9469 .48432 L
s
.766 .217 1 r
.78748 .46949 m
.78815 .47835 L
s
.78818 .47805 m
.78748 .46949 L
s
.659 .242 1 r
.50194 .46949 m
.50187 .47799 L
s
.50193 .47805 m
.50194 .46949 L
s
.6 .256 1 r
.90941 .47855 m
.90941 .47902 L
s
.425 .305 1 r
.71145 .41819 m
.71372 .45624 L
s
.659 .242 1 r
.50187 .47799 m
.50196 .46945 L
s
.50196 .46945 m
.50193 .47805 L
s
.679 .237 1 r
.42591 .41819 m
.42488 .46056 L
s
.766 .217 1 r
.78815 .47835 m
.78751 .46945 L
s
.78751 .46945 m
.78818 .47805 L
s
.777 .214 1 r
.65641 .46898 m
.65674 .47792 L
s
.65679 .47748 m
.65641 .46898 L
s
.68 .237 1 r
.73158 .48062 m
.73154 .48095 L
s
.845 .199 1 r
.45023 .45669 m
.45001 .46574 L
s
.45003 .4657 m
.45023 .45669 L
s
.45023 .45669 m
.44987 .47447 L
s
.777 .214 1 r
.65674 .47792 m
.65643 .46895 L
s
.65643 .46895 m
.65679 .47748 L
s
.89025 .45605 m
.89116 .46495 L
s
.89119 .46491 m
.89025 .45605 L
s
.89025 .45605 m
.89213 .47353 L
s
.55 .269 1 r
.33831 .4789 m
.33824 .47909 L
s
.433 .302 1 r
.23478 .45302 m
.23409 .46101 L
s
.2341 .46097 m
.23478 .45302 L
s
.23478 .45302 m
.23347 .46886 L
s
.486 .287 1 r
.82931 .45173 m
.83002 .46001 L
s
.83004 .45997 m
.82931 .45173 L
s
.82931 .45173 m
.83075 .46771 L
s
.46 .294 1 r
.86595 .41797 m
.86994 .45602 L
s
.618 .252 1 r
.58038 .41797 m
.58124 .4589 L
s
.2948 .41797 m
.29224 .4589 L
s
.822 .204 1 r
.39926 .48363 m
.39919 .48378 L
s
.648 .244 1 r
.5487 .46748 m
.54876 .47609 L
s
.54881 .47576 m
.5487 .46748 L
s
.54876 .47609 m
.54872 .46744 L
s
.54872 .46744 m
.54881 .47576 L
s
.701 .232 1 r
.34249 .45523 m
.34201 .46395 L
s
.34202 .46391 m
.34249 .45523 L
s
.34249 .45523 m
.34161 .47238 L
s
.765 .217 1 r
.37083 .46955 m
.37043 .47838 L
s
.3705 .4782 m
.37083 .46955 L
s
.569 .264 1 r
.41759 .46698 m
.41733 .47533 L
s
.41739 .47519 m
.41759 .46698 L
s
.765 .217 1 r
.37043 .47838 m
.37085 .46952 L
s
.37085 .46952 m
.3705 .4782 L
s
.569 .264 1 r
.41733 .47533 m
.41761 .46694 L
s
.41761 .46694 m
.41739 .47519 L
s
.69 .234 1 r
.44601 .48134 m
.44595 .48149 L
s
.766 .217 1 r
.23972 .46905 m
.23897 .47792 L
s
.23906 .47762 m
.23972 .46905 L
s
.811 .206 1 r
.4736 .45604 m
.47344 .46502 L
s
.47346 .46498 m
.4736 .45604 L
s
.4736 .45604 m
.47336 .47367 L
s
.578 .262 1 r
.26309 .46776 m
.26245 .47608 L
s
.26251 .47612 m
.26309 .46776 L
s
.559 .267 1 r
.36167 .47812 m
.36159 .47844 L
s
.52036 .45347 m
.52032 .46187 L
s
.52034 .46183 m
.52036 .45347 L
s
.52036 .45347 m
.52036 .46994 L
s
.424 .305 1 r
.90446 .4639 m
.90535 .47192 L
s
.90536 .4716 m
.90446 .4639 L
s
.788 .211 1 r
.73488 .41775 m
.73783 .46228 L
s
.628 .249 1 r
.44927 .41775 m
.44855 .4594 L
s
.766 .217 1 r
.23897 .47792 m
.23973 .46902 L
s
.23973 .46902 m
.23906 .47762 L
s
.578 .262 1 r
.26245 .47608 m
.26311 .46773 L
s
.26311 .46773 m
.26251 .47612 L
s
.424 .305 1 r
.90535 .47192 m
.90449 .46387 L
s
.90449 .46387 m
.90536 .4716 L
s
.811 .206 1 r
.6281 .45551 m
.62834 .46452 L
s
.62837 .46448 m
.6281 .45551 L
s
.6281 .45551 m
.62865 .4731 L
s
1 .141 .868 r
.71246 .45886 m
.71295 .46846 L
s
.71298 .46842 m
.71246 .45886 L
s
.71246 .45886 m
.71352 .47777 L
s
.531 .274 1 r
.88111 .46548 m
.88197 .47379 L
s
.88199 .47346 m
.88111 .46548 L
s
.88197 .47379 m
.88114 .46544 L
s
.88114 .46544 m
.88199 .47346 L
s
.722 .227 1 r
.39419 .46884 m
.39385 .47756 L
s
.39392 .47741 m
.39419 .46884 L
s
.723 .226 1 r
.70323 .46755 m
.70368 .47638 L
s
.70371 .4759 m
.70323 .46755 L
s
.54 .272 1 r
.44096 .46626 m
.44075 .47454 L
s
.44081 .4744 m
.44096 .46626 L
s
.503 .282 1 r
.88943 .41753 m
.89384 .45702 L
s
.56 .267 1 r
.60378 .41753 m
.6049 .45738 L
s
.618 .252 1 r
.31813 .41753 m
.31585 .45846 L
s
.722 .227 1 r
.39385 .47756 m
.39421 .4688 L
s
.39421 .4688 m
.39392 .47741 L
s
.723 .226 1 r
.70368 .47638 m
.70325 .46751 L
s
.70325 .46751 m
.70371 .4759 L
s
.54 .272 1 r
.44075 .47454 m
.44098 .46623 L
s
.44098 .46623 m
.44081 .4744 L
s
.701 .232 1 r
.49698 .45533 m
.49688 .46401 L
s
.4969 .46398 m
.49698 .45533 L
s
.49698 .45533 m
.49686 .47252 L
s
.723 .226 1 r
.57713 .48263 m
.57707 .48256 L
s
.722 .227 1 r
.93716 .45472 m
.93818 .46351 L
s
.93821 .46348 m
.93716 .45472 L
s
.93716 .45472 m
.93925 .47195 L
s
.7 .232 1 r
.46939 .48091 m
.46932 .48109 L
s
.505 .281 1 r
.64228 .46347 m
.64255 .47182 L
s
.64259 .47117 m
.64228 .46347 L
s
.45 .297 1 r
.56714 .45175 m
.56721 .45986 L
s
.56723 .45982 m
.56714 .45175 L
s
.56714 .45175 m
.56735 .46764 L
s
.523 .277 1 r
.38921 .45372 m
.38886 .46194 L
s
.38888 .4619 m
.38921 .45372 L
s
.38921 .45372 m
.38859 .47008 L
s
.68 .237 1 r
.75833 .41731 m
.76135 .4586 L
s
.352 .327 1 r
.47264 .41731 m
.47224 .45572 L
s
.57 .264 1 r
.69829 .45246 m
.69869 .46093 L
s
.69871 .46089 m
.69829 .45246 L
s
.69829 .45246 m
.69915 .46893 L
s
.505 .281 1 r
.64255 .47182 m
.6423 .46343 L
s
.6423 .46343 m
.64259 .47117 L
s
.488 .286 1 r
.74088 .4739 m
.74087 .47469 L
s
.459 .295 1 r
.40839 .47655 m
.40833 .47669 L
s
.541 .272 1 r
.6941 .47654 m
.69407 .47702 L
s
1 .131 .814 r
.45516 .47406 m
.45495 .4837 L
s
.45502 .48358 m
.45516 .47406 L
s
.857 .196 1 r
.52533 .4702 m
.52532 .47921 L
s
.52538 .47906 m
.52533 .4702 L
s
.649 .244 1 r
.5955 .46633 m
.59567 .47498 L
s
.59572 .47454 m
.5955 .46633 L
s
.578 .262 1 r
.30979 .46633 m
.30926 .47472 L
s
.30933 .47454 m
.30979 .46633 L
s
1 .131 .814 r
.45495 .4837 m
.45518 .47402 L
s
.45518 .47402 m
.45502 .48358 L
s
.857 .196 1 r
.52532 .47921 m
.52535 .47016 L
s
.52535 .47016 m
.52538 .47906 L
s
.638 .247 1 r
.36581 .45533 m
.36539 .4638 L
s
.36541 .46376 m
.36581 .45533 L
s
.36581 .45533 m
.36505 .47231 L
s
.649 .244 1 r
.59567 .47498 m
.59552 .46629 L
s
.59552 .46629 m
.59572 .47454 L
s
.578 .262 1 r
.30926 .47472 m
.30981 .46629 L
s
.30981 .46629 m
.30933 .47454 L
s
.335 .34 1 r
.61392 .4495 m
.6141 .45727 L
s
.61412 .45724 m
.61392 .4495 L
s
.61392 .4495 m
.61433 .46462 L
s
.904 .186 1 r
.4226 .48391 m
.42253 .4841 L
s
.512 .279 1 r
.25383 .47748 m
.25376 .47762 L
s
.588 .259 1 r
.91291 .41708 m
.9178 .45838 L
s
.669 .239 1 r
.62719 .41708 m
.62864 .45874 L
s
.494 .284 1 r
.34147 .41708 m
.33954 .45658 L
s
.69 .234 1 r
.28638 .46791 m
.28578 .47655 L
s
.28585 .4764 m
.28638 .46791 L
s
.467 .292 1 r
.33316 .46533 m
.33271 .47336 L
s
.33276 .47339 m
.33316 .46533 L
s
.69 .234 1 r
.28578 .47655 m
.2864 .46787 L
s
.2864 .46787 m
.28585 .4764 L
s
.659 .242 1 r
.8019 .47898 m
.80187 .47934 L
s
.68 .237 1 r
.51617 .47898 m
.51611 .47942 L
s
.467 .292 1 r
.33271 .47336 m
.33318 .46529 L
s
.33318 .46529 m
.33276 .47339 L
s
.799 .209 1 r
.75512 .48163 m
.75508 .48192 L
s
.99 .169 1 r
.70834 .48427 m
.70829 .48461 L
s
.383 .317 1 r
.82026 .46225 m
.82093 .47017 L
s
.82095 .46981 m
.82026 .46225 L
s
.488 .964 1 r
.44514 .44343 m
.44498 .44968 L
s
.44499 .44965 m
.44514 .44343 L
s
.44514 .44343 m
.44487 .45565 L
s
.383 .317 1 r
.82093 .47017 m
.82028 .46222 L
s
.82028 .46222 m
.82095 .46981 L
s
.722 .227 1 r
.85787 .46819 m
.8587 .47691 L
s
.85875 .47676 m
.85787 .46819 L
s
.375 .32 1 r
.95144 .46304 m
.95241 .47085 L
s
.95245 .47074 m
.95144 .46304 L
s
.359 .325 1 r
.32398 .47404 m
.32392 .47418 L
s
.4 .312 1 r
.45936 .45068 m
.45919 .45863 L
s
.4592 .4586 m
.45936 .45068 L
s
.45936 .45068 m
.45909 .46627 L
s
.81 .206 1 r
.78178 .41686 m
.78529 .46069 L
s
.352 .327 1 r
.49603 .41686 m
.49589 .4542 L
s
.711 .229 1 r
.21027 .41686 m
.2066 .45888 L
s
.722 .227 1 r
.8587 .47691 m
.85789 .46815 L
s
.85789 .46815 m
.85875 .47676 L
s
.375 .32 1 r
.95241 .47085 m
.95147 .463 L
s
.95147 .463 m
.95245 .47074 L
s
.8 .209 1 r
.57212 .46848 m
.57224 .47742 L
s
.57229 .47712 m
.57212 .46848 L
s
.858 .196 1 r
.67496 .45481 m
.67533 .46394 L
s
.67535 .4639 m
.67496 .45481 L
s
.67496 .45481 m
.67576 .47259 L
s
.99 .169 1 r
.86295 .48406 m
.86292 .4844 L
s
.441 .3 1 r
.37993 .46332 m
.37958 .47138 L
s
.37965 .4711 m
.37993 .46332 L
s
.8 .209 1 r
.57224 .47742 m
.57215 .46844 L
s
.57215 .46844 m
.57229 .47712 L
s
.441 .3 1 r
.37958 .47138 m
.37995 .46329 L
s
.37995 .46329 m
.37965 .4711 L
s
.638 .247 1 r
.64735 .48027 m
.6473 .48024 L
s
.503 .282 1 r
.79691 .46411 m
.79756 .47235 L
s
.79758 .47203 m
.79691 .46411 L
s
.744 .221 1 r
.93641 .41664 m
.94173 .45902 L
s
.823 .204 1 r
.65062 .41664 m
.65239 .45902 L
s
.659 .242 1 r
.36483 .41664 m
.36304 .45902 L
s
.701 .232 1 r
.23037 .4797 m
.23029 .47999 L
s
1 .143 .881 r
.83957 .48557 m
.83954 .48594 L
s
.503 .282 1 r
.79756 .47235 m
.79693 .46407 L
s
.79693 .46407 m
.79758 .47203 L
s
.649 .244 1 r
.41257 .45377 m
.41226 .46236 L
s
.41228 .46232 m
.41257 .45377 L
s
.41257 .45377 m
.41204 .47072 L
s
.701 .232 1 r
.25797 .45446 m
.25727 .46315 L
s
.25728 .46311 m
.25797 .45446 L
s
.25797 .45446 m
.25666 .47166 L
s
.599 .257 1 r
.92813 .4649 m
.92912 .47343 L
s
.92912 .47296 m
.92813 .4649 L
s
.92912 .47343 m
.92815 .46486 L
s
.92815 .46486 m
.92912 .47296 L
s
1 .164 .985 r
.96574 .47084 m
.96694 .48022 L
s
.96696 .47992 m
.96574 .47084 L
s
.551 .269 1 r
.22531 .46439 m
.22457 .47279 L
s
.22466 .47238 m
.22531 .46439 L
s
1 .164 .985 r
.96694 .48022 m
.96578 .4708 L
s
.96578 .4708 m
.96696 .47992 L
s
.811 .206 1 r
.93319 .48063 m
.93319 .48107 L
s
.551 .269 1 r
.22457 .47279 m
.22532 .46436 L
s
.22532 .46436 m
.22466 .47238 L
s
.893 .189 1 r
.80525 .41642 m
.80904 .45988 L
s
.391 .315 1 r
.51942 .41642 m
.51955 .45448 L
s
.335 .341 1 r
.23359 .41642 m
.23056 .45412 L
s
.834 .201 1 r
.72675 .46855 m
.72728 .47756 L
s
.72732 .47727 m
.72675 .46855 L
s
.64 .246 1 r
.7452 .45166 m
.74572 .46035 L
s
.74575 .46031 m
.7452 .45166 L
s
.7452 .45166 m
.74629 .46842 L
s
.834 .201 1 r
.72728 .47756 m
.72678 .46851 L
s
.72678 .46851 m
.72732 .47727 L
s
.639 .247 1 r
.84882 .47776 m
.8488 .47816 L
s
.54 .272 1 r
.59057 .45256 m
.5907 .46085 L
s
.59072 .46081 m
.59057 .45256 L
s
.59057 .45256 m
.59091 .469 L
s
.599 .257 1 r
.58638 .47662 m
.58633 .47709 L
s
.4 .312 1 r
.35152 .45002 m
.35109 .45798 L
s
.35111 .45795 m
.35152 .45002 L
s
.35152 .45002 m
.35075 .46562 L
s
.477 .289 1 r
.95992 .4162 m
.9651 .45534 L
s
.559 .267 1 r
.67406 .4162 m
.67601 .45642 L
s
.433 .302 1 r
.38819 .4162 m
.38681 .45534 L
s
.799 .209 1 r
.96087 .45596 m
.96196 .4648 L
s
.96199 .46476 m
.96087 .45596 L
s
.96087 .45596 m
.96314 .47367 L
s
.58 .261 1 r
.76863 .4508 m
.76921 .45934 L
s
.76923 .4593 m
.76863 .4508 L
s
.76863 .4508 m
.76982 .46727 L
s
.628 .249 1 r
.43594 .45342 m
.43569 .46193 L
s
.43571 .46189 m
.43594 .45342 L
s
.43594 .45342 m
.43553 .47029 L
s
.965 .174 1 r
.88647 .48399 m
.88643 .48415 L
s
.744 .221 1 r
.48772 .46654 m
.48762 .47541 L
s
.48768 .47497 m
.48772 .46654 L
s
.368 .322 1 r
.58133 .46139 m
.58146 .46923 L
s
.5815 .46894 m
.58133 .46139 L
s
.823 .204 1 r
.38493 .4802 m
.38485 .48067 L
s
.744 .221 1 r
.48762 .47541 m
.48774 .4665 L
s
.48774 .4665 m
.48768 .47497 L
s
.733 .224 1 r
.28129 .45424 m
.28065 .463 L
s
.28066 .46296 m
.28129 .45424 L
s
.28129 .45424 m
.28009 .47158 L
s
.368 .322 1 r
.58146 .46923 m
.58135 .46135 L
s
.58135 .46135 m
.5815 .46894 L
s
.34 .366 1 r
.82873 .41597 m
.83223 .45332 L
s
.559 .267 1 r
.54283 .41597 m
.54324 .4562 L
s
.638 .247 1 r
.25693 .41597 m
.2538 .45836 L
s
.833 .201 1 r
.4643 .4684 m
.46414 .47738 L
s
.4642 .47719 m
.4643 .4684 L
s
.346 .329 1 r
.8389 .44758 m
.83959 .45546 L
s
.83962 .45543 m
.8389 .44758 L
s
.8389 .44758 m
.84031 .46274 L
s
.588 .259 1 r
.2486 .46453 m
.24791 .473 L
s
.24799 .47267 m
.2486 .46453 L
s
.833 .201 1 r
.46414 .47738 m
.46432 .46836 L
s
.46432 .46836 m
.4642 .47719 L
s
1 .118 .742 r
.69751 .41575 m
.70009 .46211 L
s
.94 .179 1 r
.41157 .41575 m
.4103 .46067 L
s
.588 .259 1 r
.24791 .473 m
.24861 .4645 L
s
.24861 .4645 m
.24799 .47267 L
s
.589 .259 1 r
.32807 .45227 m
.32756 .4607 L
s
.32758 .46067 m
.32807 .45227 L
s
.32807 .45227 m
.32714 .46893 L
s
.638 .247 1 r
.6658 .46532 m
.66614 .4739 L
s
.66619 .47361 m
.6658 .46532 L
s
.55 .269 1 r
.97515 .46403 m
.97624 .47239 L
s
.97625 .4721 m
.97515 .46403 L
s
.834 .201 1 r
.95679 .48092 m
.95677 .48121 L
s
.649 .244 1 r
.30045 .47769 m
.30037 .47802 L
s
.638 .247 1 r
.66614 .4739 m
.66582 .46529 L
s
.66582 .46529 m
.66619 .47361 L
s
.55 .269 1 r
.97624 .47239 m
.97518 .464 L
s
.97518 .464 m
.97625 .4721 L
s
.846 .199 1 r
.77367 .4674 m
.77432 .47649 L
s
.77435 .47605 m
.77367 .4674 L
s
.522 .277 1 r
.8439 .46353 m
.84466 .47181 L
s
.84469 .47153 m
.8439 .46353 L
s
.551 .269 1 r
.55795 .46353 m
.55802 .47192 L
s
.55807 .47152 m
.55795 .46353 L
s
.846 .199 1 r
.77432 .47649 m
.77369 .46736 L
s
.77369 .46736 m
.77435 .47605 L
s
.522 .277 1 r
.84466 .47181 m
.84392 .4635 L
s
.84392 .4635 m
.84469 .47153 L
s
.551 .269 1 r
.55802 .47192 m
.55796 .46349 L
s
.55796 .46349 m
.55807 .47152 L
s
.336 .332 1 r
.85222 .41553 m
.85605 .4536 L
s
.648 .244 1 r
.56625 .41553 m
.56695 .45684 L
s
.638 .247 1 r
.28028 .41553 m
.27749 .4572 L
s
.953 .176 1 r
.7219 .45462 m
.7224 .46393 L
s
.72243 .46389 m
.7219 .45462 L
s
.7219 .45462 m
.72296 .47281 L
s
.75027 .46897 m
.75088 .47825 L
s
.75091 .47791 m
.75027 .46897 L
s
.754 .219 1 r
.30463 .45405 m
.30404 .46285 L
s
.30406 .46282 m
.30463 .45405 L
s
.30463 .45405 m
.30354 .47151 L
s
.799 .209 1 r
.53958 .4807 m
.53952 .48089 L
s
.953 .176 1 r
.75088 .47825 m
.7503 .46893 L
s
.7503 .46893 m
.75091 .47791 L
s
1 .161 .972 r
.49276 .48335 m
.49269 .48369 L
s
.8 .209 1 r
.35642 .46718 m
.35597 .47613 L
s
.35605 .47583 m
.35642 .46718 L
s
.459 .294 1 r
.81135 .47368 m
.81133 .47404 L
s
.722 .227 1 r
.277 .47956 m
.27693 .47971 L
s
.8 .209 1 r
.35597 .47613 m
.35644 .46715 L
s
.35644 .46715 m
.35605 .47583 L
s
.337 .351 1 r
.72097 .41531 m
.72322 .45122 L
s
.701 .232 1 r
.43496 .41531 m
.43406 .45734 L
s
.692 .234 1 r
.92346 .45179 m
.92445 .46055 L
s
.92447 .46051 m
.92346 .45179 L
s
.92346 .45179 m
.92546 .46885 L
s
.811 .206 1 r
.563 .47991 m
.56295 .48024 L
s
.51112 .46697 m
.51108 .47595 L
s
.51114 .47562 m
.51112 .46697 L
s
.51108 .47595 m
.51114 .46693 L
s
.51114 .46693 m
.51114 .47562 L
s
.496 .284 1 r
.83482 .47289 m
.83482 .47351 L
s
.811 .206 1 r
.87572 .41508 m
.88037 .45821 L
s
.477 .289 1 r
.58968 .41508 m
.59061 .45388 L
s
.904 .186 1 r
.30364 .41508 m
.30096 .45965 L
s
.467 .292 1 r
.24351 .45036 m
.24283 .45847 L
s
.24284 .45844 m
.24351 .45036 L
s
.24351 .45036 m
.24222 .4664 L
s
.638 .247 1 r
.76458 .47705 m
.76455 .47734 L
s
.648 .244 1 r
.50615 .45172 m
.50608 .46034 L
s
.5061 .4603 m
.50615 .45172 L
s
.50615 .45172 m
.50608 .46863 L
s
.608 .254 1 r
.68928 .46546 m
.68967 .47386 L
s
.68973 .47389 m
.68928 .46546 L
s
.618 .252 1 r
.91933 .47647 m
.91931 .4768 L
s
.488 .286 1 r
.73116 .44728 m
.73164 .45567 L
s
.73166 .45563 m
.73116 .44728 L
s
.73116 .44728 m
.73214 .46317 L
s
.608 .254 1 r
.68967 .47386 m
.6893 .46542 L
s
.6893 .46542 m
.68973 .47389 L
s
.398 .631 1 r
.85322 .45643 m
.85389 .46351 L
s
.85392 .46334 m
.85322 .45643 L
s
.638 .247 1 r
.27189 .46496 m
.27125 .4735 L
s
.27132 .47332 m
.27189 .46496 L
s
.398 .631 1 r
.85389 .46351 m
.85324 .4564 L
s
.85324 .4564 m
.85392 .46334 L
s
.589 .259 1 r
.94277 .47533 m
.94277 .47576 L
s
.496 .284 1 r
.74444 .41486 m
.74711 .4533 L
s
.45 .297 1 r
.45836 .41486 m
.4578 .45366 L
s
.744 .221 1 r
.60986 .47798 m
.60981 .47842 L
s
.638 .247 1 r
.27125 .4735 m
.2719 .46492 L
s
.2719 .46492 m
.27132 .47332 L
s
.845 .199 1 r
.71777 .48006 m
.71773 .48039 L
s
.799 .209 1 r
.43168 .48006 m
.43161 .48024 L
s
.522 .277 1 r
.22005 .45218 m
.2193 .46033 L
s
.21931 .4603 m
.22005 .45218 L
s
.22005 .45218 m
.21861 .46863 L
s
.588 .259 1 r
.3748 .45172 m
.37441 .46012 L
s
.37443 .46008 m
.3748 .45172 L
s
.3748 .45172 m
.3741 .46842 L
s
.671 .239 1 r
.66092 .45175 m
.66123 .46041 L
s
.66125 .46037 m
.66092 .45175 L
s
.66092 .45175 m
.66161 .46878 L
s
.416 .307 1 r
.783 .46087 m
.7836 .46887 L
s
.78363 .46858 m
.783 .46087 L
s
.638 .247 1 r
.89924 .41464 m
.90397 .45596 L
s
.4 .312 1 r
.61312 .41464 m
.6143 .45272 L
s
.766 .217 1 r
.32701 .41464 m
.32474 .45741 L
s
.56 .267 1 r
.68014 .47454 m
.6801 .47498 L
s
.416 .307 1 r
.7836 .46887 m
.78303 .46084 L
s
.78303 .46084 m
.78363 .46858 L
s
.788 .212 1 r
.53454 .46682 m
.53456 .4757 L
s
.53462 .47554 m
.53454 .46682 L
s
.425 .304 1 r
.65167 .46037 m
.65196 .46843 L
s
.652 .468 m
.65167 .46037 L
s
.788 .212 1 r
.53456 .4757 m
.53456 .46678 L
s
.53456 .46678 m
.53462 .47554 L
s
.777 .214 1 r
.79228 .45257 m
.79294 .46148 L
s
.79297 .46144 m
.79228 .45257 L
s
.79228 .45257 m
.79366 .47007 L
s
.425 .304 1 r
.65196 .46843 m
.65169 .46033 L
s
.65169 .46033 m
.652 .468 L
s
.754 .219 1 r
.40319 .46632 m
.40287 .47512 L
s
.40294 .47497 m
.40319 .46632 L
s
.352 .327 1 r
.61907 .47017 m
.61903 .4706 L
s
.658 .242 1 r
.42661 .46503 m
.42636 .47361 L
s
.42642 .47346 m
.42661 .46503 L
s
.368 .322 1 r
.80645 .45987 m
.80709 .46772 L
s
.80712 .46743 m
.80645 .45987 L
s
.649 .244 1 r
.68436 .45074 m
.68473 .4594 L
s
.68476 .45936 m
.68436 .45074 L
s
.68436 .45074 m
.68517 .46762 L
s
.754 .219 1 r
.40287 .47512 m
.40321 .46628 L
s
.40321 .46628 m
.40294 .47497 L
s
.658 .242 1 r
.42636 .47361 m
.42663 .46499 L
s
.42663 .46499 m
.42642 .47346 L
s
.368 .322 1 r
.80709 .46772 m
.80648 .45984 L
s
.80648 .45984 m
.80712 .46743 L
s
.733 .224 1 r
.47852 .47813 m
.47845 .47842 L
s
.649 .244 1 r
.31868 .46324 m
.31815 .47192 L
s
.31824 .47138 m
.31868 .46324 L
s
.733 .224 1 r
.94709 .45218 m
.94813 .46098 L
s
.94816 .46094 m
.94709 .45218 L
s
.94709 .45218 m
.94923 .4695 L
s
.628 .249 1 r
.76793 .41442 m
.77105 .45538 L
s
1 .154 .933 r
.48178 .41442 m
.48142 .46007 L
s
.658 .242 1 r
.6333 .47755 m
.63325 .4777 L
s
.649 .244 1 r
.31815 .47192 m
.3187 .4632 L
s
.3187 .4632 m
.31824 .47138 L
s
.36 .462 1 r
.33712 .44638 m
.33669 .45387 L
s
.3367 .45384 m
.33712 .44638 L
s
.33712 .44638 m
.33634 .46108 L
s
.88 .191 1 r
.87261 .4802 m
.87258 .48054 L
s
.589 .259 1 r
.75962 .46273 m
.7602 .47124 L
s
.76023 .4708 m
.75962 .46273 L
s
.385 .575 1 r
.8015 .44448 m
.80206 .45179 L
s
.80208 .45176 m
.8015 .44448 L
s
.8015 .44448 m
.80266 .45863 L
s
.335 .34 1 r
.54375 .45886 m
.54378 .4666 L
s
.54383 .46628 m
.54375 .45886 L
s
.589 .259 1 r
.7602 .47124 m
.75965 .4627 L
s
.75965 .4627 m
.76023 .4708 L
s
.397 .628 1 r
.82493 .44326 m
.82554 .45049 L
s
.82556 .45046 m
.82493 .44326 L
s
.82493 .44326 m
.82617 .45712 L
s
.476 .29 1 r
.57643 .44913 m
.57653 .45731 L
s
.57655 .45728 m
.57643 .44913 L
s
.57643 .44913 m
.57669 .46518 L
s
.335 .34 1 r
.54378 .4666 m
.54376 .45883 L
s
.54376 .45883 m
.54383 .46628 L
s
.691 .234 1 r
.60484 .46352 m
.60504 .47232 L
s
.60508 .47174 m
.60484 .46352 L
s
.60504 .47232 m
.60486 .46348 L
s
.60486 .46348 m
.60508 .47174 L
s
1 .146 .894 r
.90028 .45514 m
.90129 .46471 L
s
.90132 .46467 m
.90028 .45514 L
s
.90028 .45514 m
.90236 .47396 L
s
.693 .233 1 r
.86263 .4493 m
.86347 .45817 L
s
.86349 .45814 m
.86263 .4493 L
s
.86263 .4493 m
.86432 .46625 L
s
.712 .229 1 r
.73622 .46431 m
.73675 .47311 L
s
.73678 .47267 m
.73622 .46431 L
s
.589 .259 1 r
.92277 .41419 m
.92766 .45444 L
s
.513 .279 1 r
.63658 .41419 m
.63806 .45336 L
s
.54 .272 1 r
.35039 .41419 m
.34851 .4548 L
s
.712 .229 1 r
.73675 .47311 m
.73624 .46427 L
s
.73624 .46427 m
.73678 .47267 L
s
.823 .204 1 r
.86761 .4651 m
.86851 .47419 L
s
.86851 .47361 m
.86761 .4651 L
s
.86851 .47419 m
.86764 .46506 L
s
.86764 .46506 m
.86851 .47361 L
s
.766 .217 1 r
.52958 .45217 m
.52957 .46105 L
s
.52959 .46101 m
.52958 .45217 L
s
.52958 .45217 m
.52963 .46964 L
s
.733 .224 1 r
.34712 .47827 m
.34705 .47845 L
s
.579 .262 1 r
.9145 .4628 m
.91545 .47124 L
s
.91547 .47095 m
.9145 .4628 L
s
.733 .224 1 r
.79142 .41397 m
.79503 .45747 L
s
.68 .237 1 r
.5052 .41397 m
.50516 .45566 L
s
.639 .247 1 r
.21898 .41397 m
.21541 .45602 L
s
.579 .262 1 r
.91545 .47124 m
.91453 .46277 L
s
.91453 .46277 m
.91547 .47095 L
s
.712 .229 1 r
.39819 .45181 m
.39784 .46054 L
s
.39785 .4605 m
.39819 .45181 L
s
.39819 .45181 m
.39757 .46906 L
s
.433 .302 1 r
.23409 .46101 m
.2334 .46901 L
s
.23347 .46886 m
.23409 .46101 L
s
1 .161 .972 r
.48272 .45514 m
.48257 .4645 L
s
.4826 .46445 m
.48272 .45514 L
s
.48272 .45514 m
.48252 .47374 L
s
.433 .302 1 r
.2334 .46901 m
.2341 .46097 L
s
.2341 .46097 m
.23347 .46886 L
s
.659 .242 1 r
.50193 .47805 m
.50187 .47799 L
s
.766 .217 1 r
.78818 .47805 m
.78815 .47835 L
s
.424 .305 1 r
.90536 .4716 m
.90535 .47192 L
s
.777 .214 1 r
.65679 .47748 m
.65674 .47792 L
s
.904 .186 1 r
.89617 .48013 m
.89614 .48043 L
s
.486 .287 1 r
.83002 .46001 m
.83075 .46829 L
s
.83075 .46771 m
.83002 .46001 L
s
.468 .292 1 r
.94631 .41375 m
.95129 .45256 L
s
.723 .226 1 r
.66005 .41375 m
.66189 .45508 L
s
.7 .232 1 r
.37379 .41375 m
.37211 .45616 L
s
.659 .242 1 r
.81583 .45285 m
.81652 .46133 L
s
.81655 .4613 m
.81583 .45285 L
s
.81583 .45285 m
.8173 .47 L
s
.486 .287 1 r
.83075 .46829 m
.83004 .45997 L
s
.83004 .45997 m
.83075 .46771 L
s
.788 .212 1 r
.29516 .46596 m
.29456 .47483 L
s
.29463 .47468 m
.29516 .46596 L
s
.488 .964 1 r
.44498 .44968 m
.44482 .45592 L
s
.44487 .45565 m
.44498 .44968 L
s
.591 .259 1 r
.75475 .44836 m
.75529 .45695 L
s
.75532 .45691 m
.75475 .44836 L
s
.75475 .44836 m
.75588 .46488 L
s
.488 .964 1 r
.44482 .45592 m
.44499 .44965 L
s
.44499 .44965 m
.44487 .45565 L
s
.788 .212 1 r
.29456 .47483 m
.29518 .46592 L
s
.29518 .46592 m
.29463 .47468 L
s
.648 .244 1 r
.54881 .47576 m
.54876 .47609 L
s
.569 .264 1 r
.41739 .47519 m
.41733 .47533 L
s
.99 .169 1 r
.63757 .45503 m
.63784 .46428 L
s
.63787 .46424 m
.63757 .45503 L
s
.63757 .45503 m
.6382 .47352 L
s
.777 .214 1 r
.89116 .46495 m
.89211 .47386 L
s
.89213 .47353 m
.89116 .46495 L
s
1 .126 .786 r
.81493 .41352 m
.81917 .46064 L
s
.766 .217 1 r
.52864 .41352 m
.52889 .45666 L
s
.701 .232 1 r
.24234 .41352 m
.23903 .45594 L
s
.777 .214 1 r
.89211 .47386 m
.89119 .46491 L
s
.89119 .46491 m
.89213 .47353 L
s
1 .103 .659 r
.877 .45785 m
.87797 .46773 L
s
.878 .46768 m
.877 .45785 L
s
.877 .45785 m
.87905 .47763 L
s
.531 .274 1 r
.88199 .47346 m
.88197 .47379 L
s
.845 .199 1 r
.45001 .46574 m
.4498 .4748 L
s
.44987 .47447 m
.45001 .46574 L
s
.578 .262 1 r
.26251 .47612 m
.26245 .47608 L
s
.559 .267 1 r
.52032 .46187 m
.52031 .47026 L
s
.52036 .46994 m
.52032 .46187 L
s
.845 .199 1 r
.4498 .4748 m
.45003 .4657 L
s
.45003 .4657 m
.44987 .47447 L
s
.559 .267 1 r
.52031 .47026 m
.52034 .46183 L
s
.52034 .46183 m
.52036 .46994 L
s
.765 .217 1 r
.3705 .4782 m
.37043 .47838 L
s
.701 .232 1 r
.34201 .46395 m
.34153 .47268 L
s
.34161 .47238 m
.34201 .46395 L
s
.711 .229 1 r
.26671 .45223 m
.26603 .4609 L
s
.26605 .46086 m
.26671 .45223 L
s
.26671 .45223 m
.26543 .46956 L
s
.766 .217 1 r
.23906 .47762 m
.23897 .47792 L
s
.701 .232 1 r
.34153 .47268 m
.34202 .46391 L
s
.34202 .46391 m
.34161 .47238 L
s
.54 .272 1 r
.44081 .4744 m
.44075 .47454 L
s
.669 .239 1 r
.29015 .45098 m
.28953 .4596 L
s
.28955 .45957 m
.29015 .45098 L
s
.29015 .45098 m
.28901 .46805 L
s
.505 .281 1 r
.64259 .47117 m
.64255 .47182 L
s
.45 .297 1 r
.68353 .4133 m
.68552 .45212 L
s
.588 .259 1 r
.39719 .4133 m
.39587 .45392 L
s
.723 .226 1 r
.70371 .4759 m
.70368 .47638 L
s
.754 .219 1 r
.42158 .45187 m
.42129 .46068 L
s
.42131 .46064 m
.42158 .45187 L
s
.42158 .45187 m
.42108 .46935 L
s
.811 .206 1 r
.47344 .46502 m
.4733 .47401 L
s
.47336 .47367 m
.47344 .46502 L
s
.45 .297 1 r
.56721 .45986 m
.5673 .46796 L
s
.56735 .46764 m
.56721 .45986 L
s
.722 .227 1 r
.39392 .47741 m
.39385 .47756 L
s
.833 .201 1 r
.97084 .45334 m
.97196 .46226 L
s
.97199 .46222 m
.97084 .45334 L
s
.97084 .45334 m
.97318 .47122 L
s
.531 .274 1 r
.88627 .45008 m
.8871 .45831 L
s
.88713 .45827 m
.88627 .45008 L
s
.88627 .45008 m
.88802 .46653 L
s
.335 .34 1 r
.6141 .45727 m
.61429 .46505 L
s
.61433 .46462 m
.6141 .45727 L
s
.811 .206 1 r
.4733 .47401 m
.47346 .46498 L
s
.47346 .46498 m
.47336 .47367 L
s
.45 .297 1 r
.5673 .46796 m
.56723 .45982 L
s
.56723 .45982 m
.56735 .46764 L
s
.335 .34 1 r
.61429 .46505 m
.61412 .45724 L
s
.61412 .45724 m
.61433 .46462 L
s
.811 .206 1 r
.62834 .46452 m
.62861 .47354 L
s
.62865 .4731 m
.62834 .46452 L
s
.523 .277 1 r
.38886 .46194 m
.38853 .47016 L
s
.38859 .47008 m
.38886 .46194 L
s
.384 .317 1 r
.83845 .41308 m
.84204 .4501 L
s
.648 .244 1 r
.55209 .41308 m
.55262 .45442 L
s
.344 .33 1 r
.26572 .41308 m
.26298 .45154 L
s
.811 .206 1 r
.62861 .47354 m
.62837 .46448 L
s
.62837 .46448 m
.62865 .4731 L
s
.523 .277 1 r
.38853 .47016 m
.38888 .4619 L
s
.38888 .4619 m
.38859 .47008 L
s
.383 .317 1 r
.82095 .46981 m
.82093 .47017 L
s
1 .163 .984 r
.55304 .4529 m
.55309 .46233 L
s
.55311 .46229 m
.55304 .4529 L
s
.55304 .4529 m
.55322 .47136 L
s
.701 .232 1 r
.49688 .46401 m
.4968 .47271 L
s
.49686 .47252 m
.49688 .46401 L
s
.4968 .47271 m
.4969 .46398 L
s
.4969 .46398 m
.49686 .47252 L
s
.722 .227 1 r
.93818 .46351 m
.93924 .47232 L
s
.93925 .47195 m
.93818 .46351 L
s
.649 .244 1 r
.59572 .47454 m
.59567 .47498 L
s
.578 .262 1 r
.30933 .47454 m
.30926 .47472 L
s
.57 .264 1 r
.69869 .46093 m
.69911 .4694 L
s
.69915 .46893 m
.69869 .46093 L
s
.722 .227 1 r
.93924 .47232 m
.93821 .46348 L
s
.93821 .46348 m
.93925 .47195 L
s
.57 .264 1 r
.69911 .4694 m
.69871 .46089 L
s
.69871 .46089 m
.69915 .46893 L
s
.375 .32 1 r
.95245 .47074 m
.95241 .47085 L
s
.467 .292 1 r
.33276 .47339 m
.33271 .47336 L
s
.733 .224 1 r
.59993 .45065 m
.6001 .45946 L
s
.60012 .45942 m
.59993 .45065 L
s
.59993 .45065 m
.60034 .46798 L
s
.551 .269 1 r
.70702 .41286 m
.7094 .45384 L
s
.618 .252 1 r
.42061 .41286 m
.41956 .45384 L
s
.638 .247 1 r
.36539 .4638 m
.36499 .47228 L
s
.36505 .47231 m
.36539 .4638 L
s
.494 .284 1 r
.62338 .44947 m
.62358 .45759 L
s
.6236 .45755 m
.62338 .44947 L
s
.62338 .44947 m
.62386 .46574 L
s
.4 .312 1 r
.45919 .45863 m
.45903 .46659 L
s
.45909 .46627 m
.45919 .45863 L
s
.638 .247 1 r
.36499 .47228 m
.36541 .46376 L
s
.36541 .46376 m
.36505 .47231 L
s
1 .141 .868 r
.71295 .46846 m
.71347 .47808 L
s
.71352 .47777 m
.71295 .46846 L
s
.4 .312 1 r
.45903 .46659 m
.4592 .4586 L
s
.4592 .4586 m
.45909 .46627 L
s
1 .141 .868 r
.71347 .47808 m
.71298 .46842 L
s
.71298 .46842 m
.71352 .47777 L
s
.441 .3 1 r
.37965 .4711 m
.37958 .47138 L
s
.69 .234 1 r
.28585 .4764 m
.28578 .47655 L
s
.857 .196 1 r
.52538 .47906 m
.52532 .47921 L
s
.541 .272 1 r
.86198 .41263 m
.86626 .45398 L
s
.522 .277 1 r
.57555 .41263 m
.57633 .45254 L
s
.744 .221 1 r
.28911 .41263 m
.28636 .45542 L
s
.342 .378 1 r
.2758 .44524 m
.27523 .45291 L
s
.27524 .45288 m
.2758 .44524 L
s
.2758 .44524 m
.27474 .46027 L
s
.768 .216 1 r
.77836 .44924 m
.77899 .45823 L
s
.77901 .45819 m
.77836 .44924 L
s
.77836 .44924 m
.77966 .4666 L
s
.857 .196 1 r
.31351 .45122 m
.31292 .46032 L
s
.31294 .46028 m
.31351 .45122 L
s
.31351 .45122 m
.31243 .46906 L
s
.503 .282 1 r
.79758 .47203 m
.79756 .47235 L
s
.711 .229 1 r
.90985 .44996 m
.9108 .45873 L
s
.91083 .4587 m
.90985 .44996 L
s
.90985 .44996 m
.9118 .46718 L
s
.722 .227 1 r
.85875 .47676 m
.8587 .47691 L
s
.347 .402 1 r
.95676 .44757 m
.95767 .455 L
s
.95769 .45496 m
.95676 .44757 L
s
.95676 .44757 m
.95869 .46272 L
s
.599 .257 1 r
.92912 .47296 m
.92912 .47343 L
s
.658 .242 1 r
.73052 .41241 m
.73326 .45448 L
s
.467 .292 1 r
.44404 .41241 m
.44331 .4516 L
s
.551 .269 1 r
.22466 .47238 m
.22457 .47279 L
s
.45 .297 1 r
.69377 .44641 m
.69414 .45456 L
s
.69417 .45453 m
.69377 .44641 L
s
.69377 .44641 m
.69457 .46228 L
s
1 .131 .814 r
.45502 .48358 m
.45495 .4837 L
s
.711 .229 1 r
.4919 .44974 m
.49179 .45852 L
s
.49181 .45848 m
.4919 .44974 L
s
.4919 .44974 m
.49176 .46696 L
s
.8 .209 1 r
.57229 .47712 m
.57224 .47742 L
s
1 .126 .785 r
.70804 .45375 m
.70853 .46355 L
s
.70856 .4635 m
.70804 .45375 L
s
.70804 .45375 m
.70909 .47294 L
s
.712 .229 1 r
.93337 .44921 m
.93439 .45801 L
s
.93442 .45797 m
.93337 .44921 L
s
.93337 .44921 m
.93544 .46639 L
s
.649 .244 1 r
.41226 .46236 m
.41197 .47095 L
s
.41204 .47072 m
.41226 .46236 L
s
.881 .191 1 r
.88553 .41219 m
.89039 .45607 L
s
.392 .314 1 r
.59902 .41219 m
.60003 .44993 L
s
.88 .191 1 r
.31251 .41219 m
.30999 .45607 L
s
.649 .244 1 r
.41197 .47095 m
.41228 .46232 L
s
.41228 .46232 m
.41204 .47072 L
s
.744 .221 1 r
.64689 .44942 m
.64717 .4583 L
s
.64719 .45826 m
.64689 .44942 L
s
.64689 .44942 m
.64752 .46675 L
s
.368 .322 1 r
.5815 .46894 m
.58146 .46923 L
s
.701 .232 1 r
.25727 .46315 m
.25658 .47184 L
s
.25666 .47166 m
.25727 .46315 L
s
.638 .247 1 r
.36036 .44946 m
.35993 .45801 L
s
.35994 .45797 m
.36036 .44946 L
s
.36036 .44946 m
.35958 .46638 L
s
.4 .312 1 r
.35109 .45798 m
.35068 .46594 L
s
.35075 .46562 m
.35109 .45798 L
s
.701 .232 1 r
.25658 .47184 m
.25728 .46311 L
s
.25728 .46311 m
.25666 .47166 L
s
.4 .312 1 r
.35068 .46594 m
.35111 .45795 L
s
.35111 .45795 m
.35075 .46562 L
s
.858 .196 1 r
.67533 .46394 m
.67572 .47307 L
s
.67576 .47259 m
.67533 .46394 L
s
.67572 .47307 m
.67535 .4639 L
s
.67535 .4639 m
.67576 .47259 L
s
.953 .176 1 r
.46844 .45167 m
.46826 .46096 L
s
.46828 .46092 m
.46844 .45167 L
s
.46844 .45167 m
.46817 .46992 L
s
.54 .272 1 r
.5907 .46085 m
.59086 .46914 L
s
.59091 .469 m
.5907 .46085 L
s
.712 .229 1 r
.75403 .41196 m
.75704 .45368 L
s
.811 .206 1 r
.46749 .41196 m
.46698 .45476 L
s
.54 .272 1 r
.59086 .46914 m
.59072 .46081 L
s
.59072 .46081 m
.59091 .469 L
s
.389 .315 1 r
.78767 .44206 m
.78827 .45024 L
s
.78829 .45021 m
.78767 .44206 L
s
.78767 .44206 m
.78886 .45731 L
s
.638 .247 1 r
.2288 .44924 m
.22804 .45779 L
s
.22805 .45775 m
.2288 .44924 L
s
.2288 .44924 m
.22736 .46617 L
s
.64 .246 1 r
.74572 .46035 m
.74628 .46904 L
s
.74629 .46842 m
.74572 .46035 L
s
.521 .277 1 r
.25225 .44795 m
.25157 .45621 L
s
.25159 .45617 m
.25225 .44795 L
s
.25225 .44795 m
.25098 .46429 L
s
.834 .201 1 r
.72732 .47727 m
.72728 .47756 L
s
1 .164 .985 r
.96696 .47992 m
.96694 .48022 L
s
.64 .246 1 r
.74628 .46904 m
.74575 .46031 L
s
.74575 .46031 m
.74629 .46842 L
s
.628 .249 1 r
.43569 .46193 m
.43546 .47044 L
s
.43553 .47029 m
.43569 .46193 L
s
.744 .222 1 r
.51536 .44952 m
.5153 .45837 L
s
.51532 .45833 m
.51536 .44952 L
s
.51536 .44952 m
.51533 .46689 L
s
.58 .261 1 r
.76921 .45934 m
.76981 .46789 L
s
.76982 .46727 m
.76921 .45934 L
s
.916 .184 1 r
.90908 .41174 m
.91429 .45599 L
s
1 .163 .984 r
.6225 .41174 m
.62401 .45671 L
s
.868 .194 1 r
.33592 .41174 m
.33368 .45599 L
s
.346 .329 1 r
.83959 .45546 m
.84031 .46335 L
s
.84031 .46274 m
.83959 .45546 L
s
.744 .221 1 r
.48768 .47497 m
.48762 .47541 L
s
.628 .249 1 r
.43546 .47044 m
.43571 .46189 L
s
.43571 .46189 m
.43553 .47029 L
s
.58 .261 1 r
.76981 .46789 m
.76923 .4593 L
s
.76923 .4593 m
.76982 .46727 L
s
.346 .329 1 r
.84031 .46335 m
.83962 .45543 L
s
.83962 .45543 m
.84031 .46274 L
s
.375 .532 1 r
.89578 .44451 m
.89654 .45175 L
s
.89656 .45172 m
.89578 .44451 L
s
.89578 .44451 m
.89737 .45904 L
s
.589 .259 1 r
.40725 .4478 m
.40693 .45628 L
s
.40695 .45624 m
.40725 .4478 L
s
.40725 .4478 m
.4067 .46444 L
s
.799 .209 1 r
.96196 .4648 m
.96308 .47365 L
s
.96314 .47367 m
.96196 .4648 L
s
.536 1 .899 r
.66533 .43348 m
.66556 .43946 L
s
.66557 .43943 m
.66533 .43348 L
s
.66533 .43348 m
.6658 .44458 L
s
.799 .209 1 r
.96308 .47365 m
.96199 .46476 L
s
.96199 .46476 m
.96314 .47367 L
s
.588 .259 1 r
.24799 .47267 m
.24791 .473 L
s
.733 .224 1 r
.28065 .463 m
.28002 .47177 L
s
.28009 .47158 m
.28065 .463 L
s
.55 .269 1 r
.97625 .4721 m
.97624 .47239 L
s
.4 .312 1 r
.77756 .41152 m
.78057 .44963 L
s
.477 .289 1 r
.49094 .41152 m
.49075 .45035 L
s
.588 .259 1 r
.20432 .41152 m
.2007 .45215 L
s
.733 .224 1 r
.28002 .47177 m
.28066 .46296 L
s
.28066 .46296 m
.28009 .47158 L
s
.522 .277 1 r
.84469 .47153 m
.84466 .47181 L
s
.551 .269 1 r
.55807 .47152 m
.55802 .47192 L
s
.56 .267 1 r
.71733 .44683 m
.71777 .45527 L
s
.7178 .45523 m
.71733 .44683 L
s
.71733 .44683 m
.71827 .46328 L
s
.638 .247 1 r
.66619 .47361 m
.66614 .4739 L
s
.589 .259 1 r
.32756 .4607 m
.32707 .46915 L
s
.32714 .46893 m
.32756 .4607 L
s
.32707 .46915 m
.32758 .46067 L
s
.32758 .46067 m
.32714 .46893 L
s
.398 .631 1 r
.85392 .46334 m
.85389 .46351 L
s
.917 .184 1 r
.93265 .41129 m
.93812 .45518 L
s
.531 .274 1 r
.646 .41129 m
.64761 .45121 L
s
.569 .264 1 r
.35934 .41129 m
.35755 .45229 L
s
.833 .201 1 r
.4642 .47719 m
.46414 .47738 L
s
.589 .259 1 r
.43069 .44736 m
.43043 .45584 L
s
.43045 .4558 m
.43069 .44736 L
s
.43069 .44736 m
.43026 .464 L
s
.846 .199 1 r
.77435 .47605 m
.77432 .47649 L
s
.416 .307 1 r
.60923 .44546 m
.6094 .45347 L
s
.60942 .45343 m
.60923 .44546 L
s
.60923 .44546 m
.60963 .46119 L
s
.788 .212 1 r
.38375 .45012 m
.38336 .45901 L
s
.38338 .45897 m
.38375 .45012 L
s
.38375 .45012 m
.38305 .46775 L
s
.562 .266 1 r
.8011 .41107 m
.80447 .45027 L
s
.531 .274 1 r
.51441 .41107 m
.51448 .45099 L
s
.788 .212 1 r
.22771 .41107 m
.22413 .4546 L
s
.8 .209 1 r
.35605 .47583 m
.35597 .47613 L
s
.754 .219 1 r
.30404 .46285 m
.30347 .47166 L
s
.30354 .47151 m
.30404 .46285 L
s
.30347 .47166 m
.30406 .46282 L
s
.30406 .46282 m
.30354 .47151 L
s
.953 .176 1 r
.75091 .47791 m
.75088 .47825 L
s
.467 .292 1 r
.24283 .45847 m
.24215 .46658 L
s
.24222 .4664 m
.24283 .45847 L
s
.522 .277 1 r
.95623 .41085 m
.96144 .45041 L
s
.811 .206 1 r
.66951 .41085 m
.67153 .45366 L
s
.7 .232 1 r
.38278 .41085 m
.38121 .4533 L
s
1 .161 .972 r
.67047 .45069 m
.67083 .46016 L
s
.67086 .46011 m
.67047 .45069 L
s
.67047 .45069 m
.67127 .46919 L
s
.467 .292 1 r
.24215 .46658 m
.24284 .45844 L
s
.24284 .45844 m
.24222 .4664 L
s
.692 .234 1 r
.92445 .46055 m
.92546 .46933 L
s
.92546 .46885 m
.92445 .46055 L
s
.679 .237 1 r
.84904 .44886 m
.84982 .45749 L
s
.84985 .45746 m
.84904 .44886 L
s
.84904 .44886 m
.85068 .46602 L
s
.692 .234 1 r
.92546 .46933 m
.92447 .46051 L
s
.92447 .46051 m
.92546 .46885 L
s
.953 .176 1 r
.7224 .46393 m
.72293 .47325 L
s
.72296 .47281 m
.7224 .46393 L
s
.811 .206 1 r
.51114 .47562 m
.51108 .47595 L
s
.953 .176 1 r
.72293 .47325 m
.72243 .46389 L
s
.72243 .46389 m
.72296 .47281 L
s
.416 .307 1 r
.78363 .46858 m
.7836 .46887 L
s
.425 .304 1 r
.652 .468 m
.65196 .46843 L
s
.488 .286 1 r
.73164 .45567 m
.73214 .46407 L
s
.73214 .46317 m
.73164 .45567 L
s
.37 .507 1 r
.82464 .41062 m
.82786 .44515 L
s
.608 .254 1 r
.68973 .47389 m
.68967 .47386 L
s
.357 .451 1 r
.53788 .41062 m
.5382 .44659 L
s
.965 .174 1 r
.25112 .41062 m
.24769 .45597 L
s
.488 .964 1 r
.44487 .45565 m
.44482 .45592 L
s
.385 .575 1 r
.80206 .45179 m
.80265 .45909 L
s
.80266 .45863 m
.80206 .45179 L
s
.397 .628 1 r
.82554 .45049 m
.82617 .45773 L
s
.82617 .45712 m
.82554 .45049 L
s
.488 .286 1 r
.73214 .46407 m
.73166 .45563 L
s
.73166 .45563 m
.73214 .46317 L
s
.368 .322 1 r
.80712 .46743 m
.80709 .46772 L
s
.638 .247 1 r
.27132 .47332 m
.27125 .4735 L
s
.648 .244 1 r
.50608 .46034 m
.50602 .46896 L
s
.50608 .46863 m
.50608 .46034 L
s
.385 .575 1 r
.80265 .45909 m
.80208 .45176 L
s
.80208 .45176 m
.80266 .45863 L
s
.522 .277 1 r
.2193 .46033 m
.21856 .46849 L
s
.21861 .46863 m
.2193 .46033 L
s
.789 .211 1 r
.53883 .45054 m
.53884 .45936 L
s
.53886 .45932 m
.53883 .45054 L
s
.53883 .45054 m
.53892 .46825 L
s
.397 .628 1 r
.82617 .45773 m
.82556 .45046 L
s
.82556 .45046 m
.82617 .45712 L
s
.36 .462 1 r
.33669 .45387 m
.33627 .46136 L
s
.33634 .46108 m
.33669 .45387 L
s
.648 .244 1 r
.50602 .46896 m
.5061 .4603 L
s
.5061 .4603 m
.50608 .46863 L
s
.522 .277 1 r
.21856 .46849 m
.21931 .4603 L
s
.21931 .4603 m
.21861 .46863 L
s
.531 .274 1 r
.76439 .44606 m
.76495 .4544 L
s
.76497 .45436 m
.76439 .44606 L
s
.76439 .44606 m
.76556 .46241 L
s
.638 .247 1 r
.45414 .44739 m
.45394 .45598 L
s
.45395 .45594 m
.45414 .44739 L
s
.45414 .44739 m
.45381 .46429 L
s
.36 .462 1 r
.33627 .46136 m
.3367 .45384 L
s
.3367 .45384 m
.33634 .46108 L
s
.335 .34 1 r
.54383 .46628 m
.54378 .4666 L
s
.712 .229 1 r
.74093 .44745 m
.74145 .45627 L
s
.74148 .45623 m
.74093 .44745 L
s
.74093 .44745 m
.74203 .46465 L
s
.618 .252 1 r
.32248 .44692 m
.32195 .45547 L
s
.32197 .45543 m
.32248 .44692 L
s
.32248 .44692 m
.32151 .46371 L
s
.869 .194 1 r
.56232 .44953 m
.56239 .45864 L
s
.56241 .4586 m
.56232 .44953 L
s
.56232 .44953 m
.56254 .46746 L
s
.669 .239 1 r
.69302 .4104 m
.69529 .45213 L
s
.822 .204 1 r
.40623 .4104 m
.40491 .4543 L
s
.588 .259 1 r
.37441 .46012 m
.37403 .46853 L
s
.3741 .46842 m
.37441 .46012 L
s
.7 .232 1 r
.5858 .44835 m
.58592 .45706 L
s
.58594 .45702 m
.5858 .44835 L
s
.5858 .44835 m
.58612 .46558 L
s
.588 .259 1 r
.37403 .46853 m
.37443 .46008 L
s
.37443 .46008 m
.3741 .46842 L
s
.638 .247 1 r
.29897 .44857 m
.29839 .45706 L
s
.2984 .45702 m
.29897 .44857 L
s
.29897 .44857 m
.29788 .46558 L
s
.649 .244 1 r
.31824 .47138 m
.31815 .47192 L
s
.671 .239 1 r
.66123 .46041 m
.66157 .46908 L
s
.66161 .46878 m
.66123 .46041 L
s
.589 .259 1 r
.76023 .4708 m
.7602 .47124 L
s
.362 .473 1 r
.84821 .41018 m
.85153 .44326 L
s
.68 .237 1 r
.56137 .41017 m
.56202 .45191 L
s
.733 .224 1 r
.27454 .41017 m
.2716 .45299 L
s
.658 .242 1 r
.42642 .47346 m
.42636 .47361 L
s
.671 .239 1 r
.66157 .46908 m
.66125 .46037 L
s
.66125 .46037 m
.66161 .46878 L
s
.476 .29 1 r
.57653 .45731 m
.57664 .4655 L
s
.57669 .46518 m
.57653 .45731 L
s
.788 .212 1 r
.53462 .47554 m
.53456 .4757 L
s
.588 .259 1 r
.91962 .44627 m
.92057 .45475 L
s
.9206 .45471 m
.91962 .44627 L
s
.91962 .44627 m
.92156 .46291 L
s
.476 .29 1 r
.57664 .4655 m
.57655 .45728 L
s
.57655 .45728 m
.57669 .46518 L
s
.754 .219 1 r
.40294 .47497 m
.40287 .47512 L
s
.691 .234 1 r
.60508 .47174 m
.60504 .47232 L
s
.649 .244 1 r
.68473 .4594 m
.68513 .46806 L
s
.68517 .46762 m
.68473 .4594 L
s
.68513 .46806 m
.68476 .45936 L
s
.68476 .45936 m
.68517 .46762 L
s
.777 .214 1 r
.79294 .46148 m
.79363 .4704 L
s
.79366 .47007 m
.79294 .46148 L
s
.871 .193 1 r
.71656 .40995 m
.71918 .45277 L
s
.733 .224 1 r
.42969 .40995 m
.4287 .45277 L
s
.777 .214 1 r
.79363 .4704 m
.79297 .46144 L
s
.79297 .46144 m
.79366 .47007 L
s
.733 .224 1 r
.94813 .46098 m
.94922 .46979 L
s
.94923 .4695 m
.94813 .46098 L
s
.712 .229 1 r
.73678 .47267 m
.73675 .47311 L
s
.733 .224 1 r
.94922 .46979 m
.94816 .46094 L
s
.94816 .46094 m
.94923 .4695 L
s
.433 .302 1 r
.23347 .46886 m
.2334 .46901 L
s
.599 .257 1 r
.65628 .44547 m
.65658 .45403 L
s
.6566 .45399 m
.65628 .44547 L
s
.65628 .44547 m
.65694 .46211 L
s
.579 .262 1 r
.91547 .47095 m
.91545 .47124 L
s
.486 .287 1 r
.83075 .46771 m
.83075 .46829 L
s
.823 .204 1 r
.86851 .47361 m
.86851 .47419 L
s
.433 .302 1 r
.23767 .44494 m
.23698 .45295 L
s
.23699 .45291 m
.23767 .44494 L
s
.23767 .44494 m
.23636 .46082 L
s
.68 .237 1 r
.6328 .4469 m
.63304 .45561 L
s
.63307 .45557 m
.6328 .4469 L
s
.6328 .4469 m
.63336 .46399 L
s
.701 .232 1 r
.87178 .40973 m
.87627 .45183 L
s
.448 .827 1 r
.58487 .40973 m
.58559 .44175 L
s
.68 .237 1 r
.29797 .40973 m
.29539 .45147 L
s
.589 .259 1 r
.21418 .44636 m
.21339 .45482 L
s
.2134 .45478 m
.21418 .44636 L
s
.21418 .44636 m
.21269 .46305 L
s
.56 .267 1 r
.81149 .44507 m
.81217 .45352 L
s
.81219 .45348 m
.81149 .44507 L
s
.81149 .44507 m
.81289 .46154 L
s
.45 .297 1 r
.83498 .44378 m
.83569 .45194 L
s
.83571 .4519 m
.83498 .44378 L
s
.83498 .44378 m
.83644 .45966 L
s
.693 .233 1 r
.86347 .45817 m
.86434 .46705 L
s
.86432 .46625 m
.86347 .45817 L
s
.86434 .46705 m
.86349 .45814 L
s
.86349 .45814 m
.86432 .46625 L
s
.463 .881 1 r
.82071 .43668 m
.82125 .44323 L
s
.82127 .4432 m
.82071 .43668 L
s
.82071 .43668 m
.82182 .44936 L
s
.588 .259 1 r
.36937 .44583 m
.36896 .45431 L
s
.36898 .45427 m
.36937 .44583 L
s
.36937 .44583 m
.36864 .46247 L
s
.766 .217 1 r
.52957 .46105 m
.52957 .46993 L
s
.52963 .46964 m
.52957 .46105 L
s
.845 .199 1 r
.7401 .4095 m
.74306 .45305 L
s
.868 .194 1 r
.45316 .4095 m
.45244 .45378 L
s
.766 .217 1 r
.52957 .46993 m
.52959 .46101 L
s
.52959 .46101 m
.52963 .46964 L
s
.712 .229 1 r
.39784 .46054 m
.39751 .46928 L
s
.39757 .46906 m
.39784 .46054 L
s
.845 .199 1 r
.4776 .44819 m
.47745 .45726 L
s
.47747 .45722 m
.4776 .44819 L
s
.4776 .44819 m
.47738 .46601 L
s
.712 .229 1 r
.39751 .46928 m
.39785 .4605 L
s
.39785 .4605 m
.39757 .46906 L
s
.659 .242 1 r
.81652 .46133 m
.81723 .46982 L
s
.8173 .47 m
.81652 .46133 L
s
.81723 .46982 m
.81655 .4613 L
s
.81655 .4613 m
.8173 .47 L
s
.335 .34 1 r
.61433 .46462 m
.61429 .46505 L
s
1 .146 .894 r
.90129 .46471 m
.90234 .4743 L
s
.90236 .47396 m
.90129 .46471 L
s
.559 .267 1 r
.52036 .46994 m
.52031 .47026 L
s
.591 .259 1 r
.75529 .45695 m
.75586 .46554 L
s
.75588 .46488 m
.75529 .45695 L
s
1 .146 .894 r
.90234 .4743 m
.90132 .46467 L
s
.90132 .46467 m
.90236 .47396 L
s
.881 .191 1 r
.89536 .40928 m
.9004 .45355 L
s
.756 .219 1 r
.60839 .40928 m
.60963 .45139 L
s
.648 .244 1 r
.32141 .40928 m
.31914 .45066 L
s
.591 .259 1 r
.75586 .46554 m
.75532 .45691 L
s
.75532 .45691 m
.75588 .46488 L
s
.788 .212 1 r
.29463 .47468 m
.29456 .47483 L
s
.45 .297 1 r
.56735 .46764 m
.5673 .46796 L
s
.777 .214 1 r
.89213 .47353 m
.89211 .47386 L
s
1 .161 .972 r
.48257 .4645 m
.48245 .47386 L
s
.48252 .47374 m
.48257 .4645 L
s
.48245 .47386 m
.4826 .46445 L
s
.4826 .46445 m
.48252 .47374 L
s
.476 .29 1 r
.76365 .40906 m
.76664 .449 L
s
.441 .3 1 r
.47664 .40906 m
.47628 .44792 L
s
.701 .232 1 r
.34161 .47238 m
.34153 .47268 L
s
.355 .437 1 r
.48681 .4405 m
.4867 .44811 L
s
.48672 .44808 m
.48681 .4405 L
s
.48681 .4405 m
.48667 .45526 L
s
.845 .199 1 r
.44987 .47447 m
.4498 .4748 L
s
.711 .229 1 r
.26603 .4609 m
.26537 .46957 L
s
.26543 .46956 m
.26603 .4609 L
s
.669 .239 1 r
.28953 .4596 m
.28893 .46823 L
s
.28901 .46805 m
.28953 .4596 L
s
.531 .274 1 r
.8871 .45831 m
.88796 .46654 L
s
.88802 .46653 m
.8871 .45831 L
s
.486 .287 1 r
.72685 .4433 m
.72731 .45157 L
s
.72733 .45153 m
.72685 .4433 L
s
.72685 .4433 m
.72782 .45936 L
s
.765 .217 1 r
.34581 .44854 m
.34533 .45733 L
s
.34535 .45729 m
.34581 .44854 L
s
.34581 .44854 m
.34492 .46615 L
s
.711 .229 1 r
.26537 .46957 m
.26605 .46086 L
s
.26605 .46086 m
.26543 .46956 L
s
.802 .208 1 r
.67986 .44595 m
.68024 .45503 L
s
.68027 .45499 m
.67986 .44595 L
s
.67986 .44595 m
.68068 .46348 L
s
.669 .239 1 r
.28893 .46823 m
.28955 .45957 L
s
.28955 .45957 m
.28901 .46805 L
s
.523 .277 1 r
.38859 .47008 m
.38853 .47016 L
s
.531 .274 1 r
.88796 .46654 m
.88713 .45827 L
s
.88713 .45827 m
.88802 .46653 L
s
.99 .169 1 r
.63784 .46428 m
.63814 .47354 L
s
.6382 .47352 m
.63784 .46428 L
s
.63814 .47354 m
.63787 .46424 L
s
.63787 .46424 m
.6382 .47352 L
s
.733 .224 1 r
.52459 .44671 m
.52456 .45553 L
s
.52458 .45549 m
.52459 .44671 L
s
.52459 .44671 m
.52461 .46406 L
s
.4 .312 1 r
.45909 .46627 m
.45903 .46659 L
s
.376 .32 1 r
.91896 .40883 m
.92356 .44698 L
s
.388 .587 1 r
.63191 .40883 m
.63317 .44337 L
s
.503 .282 1 r
.34486 .40883 m
.34296 .44842 L
s
.57 .264 1 r
.69915 .46893 m
.69911 .4694 L
s
1 .128 .8 r
.87293 .45137 m
.87387 .46107 L
s
.8739 .46103 m
.87293 .45137 L
s
.87293 .45137 m
.8749 .47063 L
s
.845 .199 1 r
.94344 .44753 m
.94451 .45661 L
s
.94454 .45657 m
.94344 .44753 L
s
.94344 .44753 m
.94563 .46535 L
s
.711 .229 1 r
.96694 .44624 m
.96803 .45502 L
s
.96806 .45498 m
.96694 .44624 L
s
.96694 .44624 m
.96918 .46348 L
s
.811 .206 1 r
.47336 .47367 m
.4733 .47401 L
s
.754 .219 1 r
.42129 .46068 m
.42102 .4695 L
s
.42108 .46935 m
.42129 .46068 L
s
.811 .206 1 r
.62865 .4731 m
.62861 .47354 L
s
.342 .378 1 r
.27523 .45291 m
.27466 .46059 L
s
.27474 .46027 m
.27523 .45291 L
s
.754 .219 1 r
.42102 .4695 m
.42131 .46064 L
s
.42131 .46064 m
.42108 .46935 L
s
.342 .378 1 r
.27466 .46059 m
.27524 .45288 L
s
.27524 .45288 m
.27474 .46027 L
s
.701 .232 1 r
.49686 .47252 m
.4968 .47271 L
s
.68 .237 1 r
.26101 .44581 m
.26032 .45452 L
s
.26033 .45448 m
.26101 .44581 L
s
.26101 .44581 m
.25972 .4629 L
s
.494 .284 1 r
.62358 .45759 m
.62381 .46571 L
s
.62386 .46574 m
.62358 .45759 L
s
.347 .402 1 r
.95767 .455 m
.9586 .46242 L
s
.95869 .46272 m
.95767 .455 L
s
.722 .227 1 r
.93925 .47195 m
.93924 .47232 L
s
.648 .244 1 r
.78722 .40861 m
.79067 .45072 L
s
.822 .204 1 r
.50013 .40861 m
.50002 .45253 L
s
.701 .232 1 r
.21305 .40861 m
.20933 .45145 L
s
.494 .284 1 r
.62381 .46571 m
.6236 .45755 L
s
.6236 .45755 m
.62386 .46574 L
s
.347 .402 1 r
.9586 .46242 m
.95769 .45496 L
s
.95769 .45496 m
.95869 .46272 L
s
.833 .201 1 r
.97196 .46226 m
.97312 .47119 L
s
.97318 .47122 m
.97196 .46226 L
s
.799 .209 1 r
.50108 .44854 m
.50099 .4574 L
s
.50101 .45736 m
.50108 .44854 L
s
.50108 .44854 m
.50098 .46629 L
s
.833 .201 1 r
.97312 .47119 m
.97199 .46222 L
s
.97199 .46222 m
.97318 .47122 L
s
.536 1 .899 r
.66556 .43946 m
.6658 .44543 L
s
.6658 .44458 m
.66556 .43946 L
s
.6658 .44543 m
.66557 .43943 L
s
.66557 .43943 m
.6658 .44458 L
s
1 .103 .659 r
.87797 .46773 m
.87898 .47761 L
s
.87905 .47763 m
.87797 .46773 L
s
.376 .32 1 r
.77392 .44161 m
.77447 .44954 L
s
.77449 .44951 m
.77392 .44161 L
s
.77392 .44161 m
.77506 .45705 L
s
.638 .247 1 r
.36505 .47231 m
.36499 .47228 L
s
1 .103 .659 r
.87898 .47761 m
.878 .46768 L
s
.878 .46768 m
.87905 .47763 L
s
.733 .224 1 r
.5481 .44627 m
.54813 .45509 L
s
.54815 .45505 m
.5481 .44627 L
s
.5481 .44627 m
.54824 .46362 L
s
.608 .254 1 r
.28448 .44498 m
.28386 .45351 L
s
.28387 .45347 m
.28448 .44498 L
s
.28448 .44498 m
.28333 .46174 L
s
.845 .199 1 r
.94257 .40838 m
.94813 .45195 L
s
.777 .214 1 r
.65545 .40838 m
.65732 .45195 L
s
.765 .217 1 r
.36832 .40838 m
.36655 .45158 L
s
.733 .224 1 r
.6001 .45946 m
.60028 .46827 L
s
.60034 .46798 m
.6001 .45946 L
s
.60028 .46827 m
.60012 .45942 L
s
.60012 .45942 m
.60034 .46798 L
s
1 .163 .984 r
.55309 .46233 m
.55316 .47177 L
s
.55322 .47136 m
.55309 .46233 L
s
.68 .237 1 r
.57161 .44537 m
.5717 .45408 L
s
.57172 .45404 m
.57161 .44537 L
s
.57161 .44537 m
.57187 .46246 L
s
.45 .297 1 r
.69414 .45456 m
.69454 .46271 L
s
.69457 .46228 m
.69414 .45456 L
s
.4 .312 1 r
.35075 .46562 m
.35068 .46594 L
s
1 .163 .984 r
.55316 .47177 m
.55311 .46229 L
s
.55311 .46229 m
.55322 .47136 L
s
.352 .427 1 r
.8108 .40816 m
.81406 .44487 L
s
.559 .267 1 r
.52364 .40816 m
.52382 .44847 L
s
.522 .277 1 r
.23648 .40816 m
.23329 .44811 L
s
.45 .297 1 r
.69454 .46271 m
.69417 .45453 L
s
.69417 .45453 m
.69457 .46228 L
s
.711 .229 1 r
.9108 .45873 m
.91179 .46751 L
s
.9118 .46718 m
.9108 .45873 L
s
.777 .214 1 r
.8588 .44569 m
.85964 .45465 L
s
.85967 .45461 m
.8588 .44569 L
s
.8588 .44569 m
.86053 .46318 L
s
.711 .229 1 r
.91179 .46751 m
.91083 .4587 L
s
.91083 .4587 m
.9118 .46718 L
s
.346 .329 1 r
.84031 .46274 m
.84031 .46335 L
s
.768 .216 1 r
.77899 .45823 m
.77965 .46722 L
s
.77966 .4666 m
.77899 .45823 L
s
1 .141 .868 r
.71352 .47777 m
.71347 .47808 L
s
.777 .214 1 r
.679 .40793 m
.68113 .45042 L
s
.569 .264 1 r
.3918 .40793 m
.39039 .44897 L
s
.375 .532 1 r
.89654 .45175 m
.89732 .459 L
s
.89737 .45904 m
.89654 .45175 L
s
.768 .216 1 r
.77965 .46722 m
.77901 .45819 L
s
.77901 .45819 m
.77966 .4666 L
s
.857 .196 1 r
.31292 .46032 m
.31235 .46943 L
s
.31243 .46906 m
.31292 .46032 L
s
.375 .532 1 r
.89732 .459 m
.89656 .45172 L
s
.89656 .45172 m
.89737 .45904 L
s
.649 .244 1 r
.41204 .47072 m
.41197 .47095 L
s
.857 .196 1 r
.31235 .46943 m
.31294 .46028 L
s
.31294 .46028 m
.31243 .46906 L
s
.711 .229 1 r
.49179 .45852 m
.4917 .46729 L
s
.49176 .46696 m
.49179 .45852 L
s
.4917 .46729 m
.49181 .45848 L
s
.49181 .45848 m
.49176 .46696 L
s
.54 .272 1 r
.59091 .469 m
.59086 .46914 L
s
.701 .232 1 r
.25666 .47166 m
.25658 .47184 L
s
.712 .229 1 r
.93439 .45801 m
.93543 .46683 L
s
.93544 .46639 m
.93439 .45801 L
s
.638 .247 1 r
.35993 .45801 m
.35951 .46657 L
s
.35958 .46638 m
.35993 .45801 L
s
.64 .246 1 r
.74629 .46842 m
.74628 .46904 L
s
.629 .249 1 r
.83439 .40771 m
.83826 .44803 L
s
.337 .353 1 r
.54716 .40771 m
.54758 .44479 L
s
.459 .295 1 r
.25993 .40771 m
.25703 .44731 L
s
.389 .315 1 r
.78827 .45024 m
.78889 .45842 L
s
.78886 .45731 m
.78827 .45024 L
s
.712 .229 1 r
.93543 .46683 m
.93442 .45797 L
s
.93442 .45797 m
.93544 .46639 L
s
.638 .247 1 r
.35951 .46657 m
.35994 .45797 L
s
.35994 .45797 m
.35958 .46638 L
s
.389 .315 1 r
.78889 .45842 m
.78829 .45021 L
s
.78829 .45021 m
.78886 .45731 L
s
.965 .174 1 r
.39274 .44834 m
.39235 .4576 L
s
.39237 .45756 m
.39274 .44834 L
s
.39274 .44834 m
.39205 .46672 L
s
.521 .277 1 r
.25157 .45621 m
.25091 .46448 L
s
.25098 .46429 m
.25157 .45621 L
s
.58 .261 1 r
.76982 .46727 m
.76981 .46789 L
s
.69 .234 1 r
.43976 .44576 m
.43952 .45443 L
s
.43954 .45439 m
.43976 .44576 L
s
.43976 .44576 m
.43936 .46296 L
s
.81 .206 1 r
.41625 .44708 m
.41594 .45602 L
s
.41596 .45598 m
.41625 .44708 L
s
.41625 .44708 m
.41571 .46484 L
s
.521 .277 1 r
.25091 .46448 m
.25159 .45617 L
s
.25159 .45617 m
.25098 .46429 L
s
.858 .196 1 r
.67576 .47259 m
.67572 .47307 L
s
.579 .262 1 r
.33141 .44389 m
.33091 .45234 L
s
.33092 .4523 m
.33141 .44389 L
s
.33141 .44389 m
.3305 .46051 L
s
.744 .221 1 r
.64717 .4583 m
.64748 .46719 L
s
.64752 .46675 m
.64717 .4583 L
s
.649 .244 1 r
.90592 .44396 m
.90685 .45263 L
s
.90688 .45259 m
.90592 .44396 L
s
.90592 .44396 m
.90782 .46087 L
s
.744 .221 1 r
.64748 .46719 m
.64719 .45826 L
s
.64719 .45826 m
.64752 .46675 L
s
.638 .247 1 r
.22804 .45779 m
.22729 .46635 L
s
.22736 .46617 m
.22804 .45779 L
s
.503 .282 1 r
.92945 .44277 m
.93039 .45104 L
s
.93042 .45101 m
.92945 .44277 L
s
.92945 .44277 m
.93138 .45899 L
s
.733 .224 1 r
.88242 .44539 m
.8833 .45422 L
s
.88333 .45418 m
.88242 .44539 L
s
.88242 .44539 m
.88425 .46275 L
s
.608 .254 1 r
.61867 .4441 m
.61887 .45263 L
s
.61889 .45259 m
.61867 .4441 L
s
.61867 .4441 m
.61915 .46087 L
s
.552 .269 1 r
.70256 .40749 m
.7048 .44672 L
s
.512 .279 1 r
.41529 .40749 m
.41418 .44781 L
s
.638 .247 1 r
.22729 .46635 m
.22805 .45775 L
s
.22805 .45775 m
.22736 .46617 L
s
.904 .186 1 r
.70351 .44744 m
.70396 .45659 L
s
.70398 .45655 m
.70351 .44744 L
s
.70351 .44744 m
.70448 .46556 L
s
.628 .249 1 r
.43553 .47029 m
.43546 .47044 L
s
.733 .224 1 r
.30786 .44571 m
.30728 .4545 L
s
.3073 .45446 m
.30786 .44571 L
s
.30786 .44571 m
.30679 .4631 L
s
.425 .304 1 r
.53383 .44115 m
.53382 .44924 L
s
.53384 .4492 m
.53383 .44115 L
s
.53383 .44115 m
.53389 .4569 L
s
.485 .287 1 r
.35489 .44316 m
.35447 .45133 L
s
.35448 .45129 m
.35489 .44316 L
s
.35489 .44316 m
.35412 .45935 L
s
.711 .229 1 r
.59516 .44579 m
.59531 .4545 L
s
.59533 .45446 m
.59516 .44579 L
s
.59516 .44579 m
.59553 .46311 L
s
.589 .259 1 r
.40693 .45628 m
.40663 .46476 L
s
.4067 .46444 m
.40693 .45628 L
s
.355 .437 1 r
.85799 .40726 m
.86173 .44362 L
s
.55 .269 1 r
.57069 .40726 m
.57143 .44759 L
s
.467 .292 1 r
.28338 .40726 m
.28071 .44759 L
s
1 .126 .785 r
.70853 .46355 m
.70905 .47336 L
s
.70909 .47294 m
.70853 .46355 L
s
.589 .259 1 r
.40663 .46476 m
.40695 .45624 L
s
.40695 .45624 m
.4067 .46444 L
s
.811 .206 1 r
.75058 .44524 m
.75115 .45428 L
s
.75117 .45424 m
.75058 .44524 L
s
.75058 .44524 m
.75177 .46289 L
s
.953 .176 1 r
.46826 .46096 m
.4681 .47025 L
s
.46817 .46992 m
.46826 .46096 L
s
.744 .222 1 r
.5153 .45837 m
.51527 .46722 L
s
.51533 .46689 m
.5153 .45837 L
s
1 .126 .785 r
.70905 .47336 m
.70856 .4635 L
s
.70856 .4635 m
.70909 .47294 L
s
.953 .176 1 r
.4681 .47025 m
.46828 .46092 L
s
.46828 .46092 m
.46817 .46992 L
s
.744 .222 1 r
.51527 .46722 m
.51532 .45833 L
s
.51532 .45833 m
.51533 .46689 L
s
.397 .628 1 r
.82617 .45712 m
.82617 .45773 L
s
.589 .259 1 r
.32714 .46893 m
.32707 .46915 L
s
.56 .267 1 r
.71777 .45527 m
.71824 .46372 L
s
.71827 .46328 m
.71777 .45527 L
s
.733 .224 1 r
.28009 .47158 m
.28002 .47177 L
s
.56 .267 1 r
.71824 .46372 m
.7178 .45523 L
s
.7178 .45523 m
.71827 .46328 L
s
.385 .575 1 r
.80266 .45863 m
.80265 .45909 L
s
.799 .209 1 r
.96314 .47367 m
.96308 .47365 L
s
.416 .307 1 r
.6094 .45347 m
.60959 .46148 L
s
.60963 .46119 m
.6094 .45347 L
s
.613 .253 1 r
.72613 .40704 m
.72861 .44556 L
s
.589 .259 1 r
.43879 .40704 m
.43797 .44736 L
s
.416 .307 1 r
.60959 .46148 m
.60942 .45343 L
s
.60942 .45343 m
.60963 .46119 L
s
.579 .262 1 r
.51031 .44323 m
.51025 .45168 L
s
.51027 .45165 m
.51031 .44323 L
s
.51031 .44323 m
.51026 .45985 L
s
.712 .229 1 r
.64223 .44394 m
.64251 .45276 L
s
.64253 .45273 m
.64223 .44394 L
s
.64223 .44394 m
.64284 .46115 L
s
.649 .244 1 r
.79768 .4433 m
.79834 .45197 L
s
.79836 .45193 m
.79768 .4433 L
s
.79768 .4433 m
.79904 .46021 L
s
.589 .259 1 r
.43043 .45584 m
.43019 .46433 L
s
.43026 .464 m
.43043 .45584 L
s
.4 .312 1 r
.26998 .44082 m
.26937 .4488 L
s
.26938 .44876 m
.26998 .44082 L
s
.26998 .44082 m
.26884 .45646 L
s
.559 .267 1 r
.88161 .40681 m
.8861 .44787 L
s
.362 .474 1 r
.59423 .40681 m
.59513 .44246 L
s
.352 .327 1 r
.30685 .40681 m
.30466 .4439 L
s
.36 .462 1 r
.33634 .46108 m
.33627 .46136 L
s
.589 .259 1 r
.43019 .46433 m
.43045 .4558 L
s
.43045 .4558 m
.43026 .464 L
s
.467 .292 1 r
.24222 .4664 m
.24215 .46658 L
s
.488 .286 1 r
.73214 .46317 m
.73214 .46407 L
s
.588 .259 1 r
.95316 .44297 m
.95419 .45146 L
s
.95422 .45143 m
.95316 .44297 L
s
.95316 .44297 m
.95526 .45963 L
s
.425 .305 1 r
.71283 .44049 m
.71325 .44858 L
s
.71327 .44854 m
.71283 .44049 L
s
.71283 .44049 m
.71372 .45624 L
s
.425 .304 1 r
.74971 .40659 m
.75242 .44475 L
s
.425 .305 1 r
.4623 .40659 m
.46178 .44511 L
s
.788 .212 1 r
.38336 .45901 m
.38298 .4679 L
s
.38305 .46775 m
.38336 .45901 L
s
.904 .186 1 r
.46325 .44656 m
.46306 .45572 L
s
.46308 .45568 m
.46325 .44656 L
s
.46325 .44656 m
.46295 .46469 L
s
.638 .247 1 r
.22289 .44397 m
.22211 .45254 L
s
.22212 .4525 m
.22289 .44397 L
s
.22289 .44397 m
.22142 .46093 L
s
.788 .212 1 r
.38298 .4679 m
.38338 .45897 L
s
.38338 .45897 m
.38305 .46775 L
s
.692 .234 1 r
.92546 .46885 m
.92546 .46933 L
s
.46 .294 1 r
.86833 .44013 m
.86913 .44836 L
s
.86915 .44832 m
.86833 .44013 L
s
.86833 .44013 m
.86994 .45602 L
s
.754 .219 1 r
.30354 .47151 m
.30347 .47166 L
s
.708 1 .681 r
.90523 .40636 m
.90733 .42409 L
s
.477 .289 1 r
.61778 .40636 m
.61904 .44525 L
s
.892 .189 1 r
.33033 .40636 m
.328 .45104 L
s
.522 .277 1 r
.21861 .46863 m
.21856 .46849 L
s
.679 .237 1 r
.84982 .45749 m
.85064 .46613 L
s
.85068 .46602 m
.84982 .45749 L
s
.85064 .46613 m
.84985 .45746 L
s
.84985 .45746 m
.85068 .46602 L
s
.648 .244 1 r
.50608 .46863 m
.50602 .46896 L
s
.463 .881 1 r
.82125 .44323 m
.82181 .44978 L
s
.82182 .44936 m
.82125 .44323 L
s
.531 .274 1 r
.76495 .4544 m
.76552 .46274 L
s
.76556 .46241 m
.76495 .4544 L
s
.463 .881 1 r
.82181 .44978 m
.82127 .4432 L
s
.82127 .4432 m
.82182 .44936 L
s
.531 .274 1 r
.76552 .46274 m
.76497 .45436 L
s
.76497 .45436 m
.76556 .46241 L
s
.559 .267 1 r
.55738 .4421 m
.55743 .45052 L
s
.55745 .45048 m
.55738 .4421 L
s
.55738 .4421 m
.55756 .45861 L
s
.953 .176 1 r
.72296 .47281 m
.72293 .47325 L
s
.846 .199 1 r
.77331 .40614 m
.77668 .44937 L
s
1 .126 .786 r
.48582 .40614 m
.48551 .45371 L
s
.433 .302 1 r
.19834 .40614 m
.19476 .44539 L
s
.638 .247 1 r
.45394 .45598 m
.45375 .46458 L
s
.45381 .46429 m
.45394 .45598 L
s
.69 .234 1 r
.37833 .44422 m
.37793 .4529 L
s
.37795 .45286 m
.37833 .44422 L
s
.37833 .44422 m
.37762 .46143 L
s
.588 .259 1 r
.3741 .46842 m
.37403 .46853 L
s
.638 .247 1 r
.45375 .46458 m
.45395 .45594 L
s
.45395 .45594 m
.45381 .46429 L
s
.476 .29 1 r
.57669 .46518 m
.57664 .4655 L
s
.789 .211 1 r
.53884 .45936 m
.53886 .46819 L
s
.53892 .46825 m
.53884 .45936 L
s
.579 .262 1 r
.84489 .44235 m
.84564 .45081 L
s
.84567 .45077 m
.84489 .44235 L
s
.84489 .44235 m
.84646 .45898 L
s
.618 .252 1 r
.32195 .45547 m
.32143 .46404 L
s
.32151 .46371 m
.32195 .45547 L
s
.789 .211 1 r
.53886 .46819 m
.53886 .45932 L
s
.53886 .45932 m
.53892 .46825 L
s
.618 .252 1 r
.32143 .46404 m
.32197 .45543 L
s
.32197 .45543 m
.32151 .46371 L
s
1 .161 .972 r
.67083 .46016 m
.67123 .46964 L
s
.67127 .46919 m
.67083 .46016 L
s
.712 .229 1 r
.74145 .45627 m
.742 .46508 L
s
.74203 .46465 m
.74145 .45627 L
s
1 .161 .972 r
.67123 .46964 m
.67086 .46011 L
s
.67086 .46011 m
.67127 .46919 L
s
.56 .267 1 r
.92887 .40591 m
.93382 .44589 L
s
.869 .194 1 r
.64135 .40591 m
.64306 .44951 L
s
.659 .242 1 r
.35383 .40591 m
.35187 .44879 L
s
.712 .229 1 r
.742 .46508 m
.74148 .45623 L
s
.74148 .45623 m
.74203 .46465 L
s
.671 .239 1 r
.66161 .46878 m
.66157 .46908 L
s
.7 .232 1 r
.58592 .45706 m
.58607 .46577 L
s
.58612 .46558 m
.58592 .45706 L
s
.638 .247 1 r
.29839 .45706 m
.29782 .46555 L
s
.29788 .46558 m
.29839 .45706 L
s
.536 1 .899 r
.6658 .44458 m
.6658 .44543 L
s
.638 .247 1 r
.29782 .46555 m
.2984 .45702 L
s
.2984 .45702 m
.29788 .46558 L
s
.7 .232 1 r
.58607 .46577 m
.58594 .45702 L
s
.58594 .45702 m
.58612 .46558 L
s
.618 .252 1 r
.40185 .44339 m
.40152 .45189 L
s
.40154 .45185 m
.40185 .44339 L
s
.40185 .44339 m
.40127 .46028 L
s
.649 .244 1 r
.68517 .46762 m
.68513 .46806 L
s
.869 .194 1 r
.56239 .45864 m
.56248 .46776 L
s
.56254 .46746 m
.56239 .45864 L
s
.588 .259 1 r
.92057 .45475 m
.92154 .46324 L
s
.92156 .46291 m
.92057 .45475 L
s
.733 .224 1 r
.6894 .44363 m
.68979 .45246 L
s
.68982 .45242 m
.6894 .44363 L
s
.6894 .44363 m
.69026 .461 L
s
.869 .194 1 r
.56248 .46776 m
.56241 .4586 L
s
.56241 .4586 m
.56254 .46746 L
s
.57 .264 1 r
.79692 .40569 m
.80028 .44531 L
s
.485 .287 1 r
.50936 .40569 m
.50937 .44567 L
s
.418 .713 1 r
.2218 .40569 m
.21901 .43882 L
s
.588 .259 1 r
.92154 .46324 m
.9206 .45471 L
s
.9206 .45471 m
.92156 .46291 L
s
.433 .302 1 r
.23698 .45295 m
.23629 .46096 L
s
.23636 .46082 m
.23698 .45295 L
s
.23629 .46096 m
.23699 .45291 L
s
.23699 .45291 m
.23636 .46082 L
s
.777 .214 1 r
.79366 .47007 m
.79363 .4704 L
s
.733 .224 1 r
.94923 .4695 m
.94922 .46979 L
s
.693 .233 1 r
.86432 .46625 m
.86434 .46705 L
s
.618 .252 1 r
.58094 .44208 m
.58106 .45065 L
s
.58108 .45061 m
.58094 .44208 L
s
.58094 .44208 m
.58124 .4589 L
s
.29335 .44208 m
.29275 .45065 L
s
.29276 .45061 m
.29335 .44208 L
s
.29335 .44208 m
.29224 .4589 L
s
.503 .282 1 r
.89208 .44079 m
.89293 .44907 L
s
.89296 .44903 m
.89208 .44079 L
s
.89208 .44079 m
.89384 .45702 L
s
.45 .297 1 r
.83569 .45194 m
.83642 .4601 L
s
.83644 .45966 m
.83569 .45194 L
s
.352 .327 1 r
.496 .43885 m
.49591 .44668 L
s
.49593 .44665 m
.496 .43885 L
s
.496 .43885 m
.49589 .4542 L
s
.722 .226 1 r
.95252 .40546 m
.95802 .44762 L
s
.788 .212 1 r
.66493 .40546 m
.66693 .44906 L
s
.416 .307 1 r
.37733 .40546 m
.37583 .44436 L
s
.45 .297 1 r
.83642 .4601 m
.83571 .4519 L
s
.83571 .4519 m
.83644 .45966 L
s
.56 .267 1 r
.60449 .4409 m
.60466 .44935 L
s
.60468 .44932 m
.60449 .4409 L
s
.60449 .4409 m
.6049 .45738 L
s
.352 .327 1 r
.47245 .44025 m
.47231 .44798 L
s
.47233 .44795 m
.47245 .44025 L
s
.47245 .44025 m
.47224 .45572 L
s
.599 .257 1 r
.65658 .45403 m
.65691 .46259 L
s
.65694 .46211 m
.65658 .45403 L
s
.65691 .46259 m
.6566 .45399 L
s
.6566 .45399 m
.65694 .46211 L
s
.589 .259 1 r
.21339 .45482 m
.21261 .46327 L
s
.21269 .46305 m
.21339 .45482 L
s
.56 .267 1 r
.81217 .45352 m
.81287 .46197 L
s
.81289 .46154 m
.81217 .45352 L
s
.589 .259 1 r
.21261 .46327 m
.2134 .45478 L
s
.2134 .45478 m
.21269 .46305 L
s
.56 .267 1 r
.81287 .46197 m
.81219 .45348 L
s
.81219 .45348 m
.81289 .46154 L
s
.68 .237 1 r
.63304 .45561 m
.63331 .46432 L
s
.63336 .46399 m
.63304 .45561 L
s
.588 .259 1 r
.36896 .45431 m
.36857 .4628 L
s
.36864 .46247 m
.36896 .45431 L
s
.88 .191 1 r
.82054 .40524 m
.82466 .45029 L
s
.559 .267 1 r
.5329 .40524 m
.5332 .44559 L
s
.953 .176 1 r
.24527 .40524 m
.24176 .45065 L
s
.68 .237 1 r
.63331 .46432 m
.63307 .45557 L
s
.63307 .45557 m
.63336 .46399 L
s
.588 .259 1 r
.36857 .4628 m
.36898 .45427 L
s
.36898 .45427 m
.36864 .46247 L
s
.591 .259 1 r
.75588 .46488 m
.75586 .46554 L
s
.679 .237 1 r
.42536 .44337 m
.42508 .45202 L
s
.4251 .45198 m
.42536 .44337 L
s
.42536 .44337 m
.42488 .46056 L
s
.766 .217 1 r
.52963 .46964 m
.52957 .46993 L
s
.355 .437 1 r
.4867 .44811 m
.48661 .45572 L
s
.48667 .45526 m
.4867 .44811 L
s
.712 .229 1 r
.39757 .46906 m
.39751 .46928 L
s
.355 .437 1 r
.48661 .45572 m
.48672 .44808 L
s
.48672 .44808 m
.48667 .45526 L
s
.618 .252 1 r
.31685 .44164 m
.3163 .45021 L
s
.31632 .45017 m
.31685 .44164 L
s
.31685 .44164 m
.31585 .45846 L
s
.344 .33 1 r
.68852 .40501 m
.6905 .44248 L
s
.69 .234 1 r
.40085 .40501 m
.3995 .44753 L
s
.494 .284 1 r
.34039 .44039 m
.33992 .44863 L
s
.33994 .44859 m
.34039 .44039 L
s
.34039 .44039 m
.33954 .45658 L
s
.659 .242 1 r
.8173 .47 m
.81723 .46982 L
s
.953 .176 1 r
.24619 .44574 m
.24541 .45498 L
s
.24543 .45494 m
.24619 .44574 L
s
.24619 .44574 m
.24472 .4641 L
s
.628 .249 1 r
.4489 .44247 m
.44868 .45101 L
s
.4487 .45097 m
.4489 .44247 L
s
.4489 .44247 m
.44855 .4594 L
s
.342 .378 1 r
.27474 .46027 m
.27466 .46059 L
s
.335 .341 1 r
.23184 .43884 m
.23116 .44653 L
s
.23118 .4465 m
.23184 .43884 L
s
.23184 .43884 m
.23056 .45412 L
s
.766 .217 1 r
.84417 .40479 m
.8484 .44767 L
s
1 .161 .972 r
.55646 .40479 m
.55711 .45021 L
s
.733 .224 1 r
.26876 .40479 m
.26577 .44731 L
s
.391 .315 1 r
.51955 .43887 m
.51951 .44682 L
s
.51953 .44678 m
.51955 .43887 L
s
.51955 .43887 m
.51955 .45448 L
s
.68 .237 1 r
.76016 .44153 m
.76073 .45028 L
s
.76075 .45024 m
.76016 .44153 L
s
.76016 .44153 m
.76135 .4586 L
s
.845 .199 1 r
.47745 .45726 m
.47732 .46634 L
s
.47738 .46601 m
.47745 .45726 L
s
.347 .402 1 r
.95869 .46272 m
.9586 .46242 L
s
.845 .199 1 r
.47732 .46634 m
.47747 .45722 L
s
.47747 .45722 m
.47738 .46601 L
s
.531 .274 1 r
.88802 .46653 m
.88796 .46654 L
s
.486 .287 1 r
.72731 .45157 m
.72779 .45984 L
s
.72782 .45936 m
.72731 .45157 L
s
.72779 .45984 m
.72733 .45153 L
s
.72733 .45153 m
.72782 .45936 L
s
.46 .294 1 r
.71212 .40456 m
.71441 .44275 L
s
.54 .272 1 r
.42438 .40456 m
.42337 .44528 L
s
.669 .239 1 r
.28901 .46805 m
.28893 .46823 L
s
1 .146 .894 r
.90236 .47396 m
.90234 .4743 L
s
.337 .351 1 r
.72233 .43616 m
.72275 .444 L
s
.72277 .44396 m
.72233 .43616 L
s
.72233 .43616 m
.72322 .45122 L
s
.34 .366 1 r
.83086 .43815 m
.83151 .4458 L
s
.83154 .44577 m
.83086 .43815 L
s
.83086 .43815 m
.83223 .45332 L
s
.711 .229 1 r
.26543 .46956 m
.26537 .46957 L
s
.494 .284 1 r
.62386 .46574 m
.62381 .46571 L
s
.765 .217 1 r
.34533 .45733 m
.34486 .46612 L
s
.34492 .46615 m
.34533 .45733 L
s
.588 .259 1 r
.91587 .44163 m
.9168 .45006 L
s
.91683 .45002 m
.91587 .44163 L
s
.91587 .44163 m
.9178 .45838 L
s
.669 .239 1 r
.62811 .44167 m
.62834 .45035 L
s
.62836 .45031 m
.62811 .44167 L
s
.62811 .44167 m
.62864 .45874 L
s
.376 .32 1 r
.77447 .44954 m
.77504 .45748 L
s
.77506 .45705 m
.77447 .44954 L
s
.765 .217 1 r
.34486 .46612 m
.34535 .45729 L
s
.34535 .45729 m
.34492 .46615 L
s
1 .146 .894 r
.86781 .40434 m
.87269 .45049 L
s
.711 .229 1 r
.58003 .40434 m
.58093 .4465 L
s
.8 .209 1 r
.29226 .40434 m
.28954 .44723 L
s
1 .161 .972 r
.48252 .47374 m
.48245 .47386 L
s
.376 .32 1 r
.77504 .45748 m
.77449 .44951 L
s
.77449 .44951 m
.77506 .45705 L
s
.733 .224 1 r
.52456 .45553 m
.52455 .46435 L
s
.52461 .46406 m
.52456 .45553 L
s
.52455 .46435 m
.52458 .45549 L
s
.52458 .45549 m
.52461 .46406 L
s
.477 .289 1 r
.96303 .43925 m
.96404 .44746 L
s
.96407 .44742 m
.96303 .43925 L
s
.96303 .43925 m
.9651 .45534 L
s
.754 .219 1 r
.42108 .46935 m
.42102 .4695 L
s
.802 .208 1 r
.68024 .45503 m
.68065 .46411 L
s
.68068 .46348 m
.68024 .45503 L
s
.711 .229 1 r
.96803 .45502 m
.96916 .46381 L
s
.96918 .46348 m
.96803 .45502 L
s
.802 .208 1 r
.68065 .46411 m
.68027 .45499 L
s
.68027 .45499 m
.68068 .46348 L
s
.711 .229 1 r
.96916 .46381 m
.96806 .45498 L
s
.96806 .45498 m
.96918 .46348 L
s
.45 .297 1 r
.69457 .46228 m
.69454 .46271 L
s
.375 .532 1 r
.89737 .45904 m
.89732 .459 L
s
.68 .237 1 r
.26032 .45452 m
.25963 .46323 L
s
.25972 .4629 m
.26032 .45452 L
s
.433 .302 1 r
.38743 .43943 m
.38708 .44746 L
s
.3871 .44742 m
.38743 .43943 L
s
.38743 .43943 m
.38681 .45534 L
s
.477 .289 1 r
.73573 .40411 m
.73834 .44303 L
s
.904 .186 1 r
.44792 .40411 m
.44713 .44845 L
s
.68 .237 1 r
.25963 .46323 m
.26033 .45448 L
s
.26033 .45448 m
.25972 .4629 L
s
.99 .169 1 r
.6382 .47352 m
.63814 .47354 L
s
.845 .199 1 r
.94451 .45661 m
.94561 .46569 L
s
.94563 .46535 m
.94451 .45661 L
s
.94561 .46569 m
.94454 .45657 L
s
.94454 .45657 m
.94563 .46535 L
s
.711 .229 1 r
.20817 .44162 m
.20734 .45041 L
s
.20735 .45037 m
.20817 .44162 L
s
.20817 .44162 m
.2066 .45888 L
s
.389 .315 1 r
.78886 .45731 m
.78889 .45842 L
s
.799 .209 1 r
.50099 .4574 m
.50092 .46626 L
s
.50098 .46629 m
.50099 .4574 L
s
.608 .254 1 r
.28386 .45351 m
.28325 .46204 L
s
.28333 .46174 m
.28386 .45351 L
s
.799 .209 1 r
.50092 .46626 m
.50101 .45736 L
s
.50101 .45736 m
.50098 .46629 L
s
.608 .254 1 r
.28325 .46204 m
.28387 .45347 L
s
.28387 .45347 m
.28333 .46174 L
s
.833 .201 1 r
.97318 .47122 m
.97312 .47119 L
s
.733 .224 1 r
.60034 .46798 m
.60028 .46827 L
s
.559 .267 1 r
.67527 .43989 m
.67561 .44832 L
s
.67563 .44828 m
.67527 .43989 L
s
.67527 .43989 m
.67601 .45642 L
s
.788 .211 1 r
.73671 .4445 m
.73722 .4533 L
s
.73724 .45326 m
.73671 .4445 L
s
.73671 .4445 m
.73783 .46228 L
s
.755 .219 1 r
.89147 .40389 m
.89626 .44642 L
s
.649 .244 1 r
.60362 .40389 m
.60477 .44497 L
s
.733 .224 1 r
.31577 .40389 m
.31334 .44678 L
s
.54813 .45509 m
.54818 .46392 L
s
.54824 .46362 m
.54813 .45509 L
s
.823 .204 1 r
.65172 .44136 m
.65202 .45048 L
s
.65205 .45044 m
.65172 .44136 L
s
.65172 .44136 m
.65239 .45902 L
s
.733 .224 1 r
.54818 .46392 m
.54815 .45505 L
s
.54815 .45505 m
.54824 .46362 L
s
1 .128 .8 r
.87387 .46107 m
.87485 .47079 L
s
.8749 .47063 m
.87387 .46107 L
s
.87485 .47079 m
.8739 .46103 L
s
.8739 .46103 m
.8749 .47063 L
s
.336 .332 1 r
.85456 .43824 m
.85527 .44593 L
s
.85529 .4459 m
.85456 .43824 L
s
.85456 .43824 m
.85605 .4536 L
s
.68 .237 1 r
.5717 .45408 m
.57181 .46279 L
s
.57187 .46246 m
.5717 .45408 L
s
.744 .221 1 r
.9396 .44161 m
.94064 .45048 L
s
.94067 .45044 m
.9396 .44161 L
s
.9396 .44161 m
.94173 .45902 L
s
.559 .267 1 r
.54313 .43967 m
.54315 .4481 L
s
.54317 .44806 m
.54313 .43967 L
s
.54313 .43967 m
.54324 .4562 L
s
.541 .272 1 r
.75936 .40366 m
.76229 .4433 L
s
.521 .277 1 r
.47147 .40366 m
.47103 .44403 L
s
.711 .229 1 r
.9118 .46718 m
.91179 .46751 L
s
.68 .237 1 r
.57181 .46279 m
.57172 .45404 L
s
.57172 .45404 m
.57187 .46246 L
s
.768 .216 1 r
.77966 .4666 m
.77965 .46722 L
s
.659 .242 1 r
.36382 .4419 m
.36339 .45048 L
s
.36341 .45044 m
.36382 .4419 L
s
.36382 .4419 m
.36304 .45902 L
s
1 .163 .984 r
.55322 .47136 m
.55316 .47177 L
s
.521 .277 1 r
.25098 .46429 m
.25091 .46448 L
s
.569 .264 1 r
.91513 .40344 m
.91996 .44381 L
s
.744 .222 1 r
.62721 .40344 m
.6287 .44597 L
s
.559 .267 1 r
.33929 .40344 m
.33729 .4438 L
s
.711 .229 1 r
.49176 .46696 m
.4917 .46729 L
s
.777 .214 1 r
.85964 .45465 m
.86051 .46362 L
s
.86053 .46318 m
.85964 .45465 L
s
.712 .229 1 r
.93544 .46639 m
.93543 .46683 L
s
.638 .247 1 r
.35958 .46638 m
.35951 .46657 L
s
.857 .196 1 r
.31243 .46906 m
.31235 .46943 L
s
.81 .206 1 r
.78392 .44291 m
.78457 .45185 L
s
.78459 .45181 m
.78392 .44291 L
s
.78392 .44291 m
.78529 .46069 L
s
.777 .214 1 r
.86051 .46362 m
.85967 .45461 L
s
.85967 .45461 m
.86053 .46318 L
s
1 .103 .659 r
.87905 .47763 m
.87898 .47761 L
s
.477 .289 1 r
.59028 .43783 m
.59041 .44607 L
s
.59043 .44603 m
.59028 .43783 L
s
.59028 .43783 m
.59061 .45388 L
s
.496 .284 1 r
.74605 .43721 m
.74656 .44556 L
s
.74658 .44552 m
.74605 .43721 L
s
.74605 .43721 m
.74711 .4533 L
s
.579 .262 1 r
.33091 .45234 m
.33042 .4608 L
s
.3305 .46051 m
.33091 .45234 L
s
.503 .282 1 r
.93039 .45104 m
.93137 .45932 L
s
.93138 .45899 m
.93039 .45104 L
s
.591 .259 1 r
.78299 .40321 m
.78621 .44286 L
s
.68 .237 1 r
.49504 .40321 m
.49487 .44503 L
s
.744 .221 1 r
.64752 .46675 m
.64748 .46719 L
s
.722 .227 1 r
.20708 .40321 m
.20327 .44611 L
s
.893 .189 1 r
.80753 .44189 m
.80826 .45112 L
s
.80829 .45108 m
.80753 .44189 L
s
.80753 .44189 m
.80904 .45988 L
s
.579 .262 1 r
.33042 .4608 m
.33092 .4523 L
s
.33092 .4523 m
.3305 .46051 L
s
.503 .282 1 r
.93137 .45932 m
.93042 .45101 L
s
.93042 .45101 m
.93138 .45899 L
s
.69 .234 1 r
.43952 .45443 m
.4393 .46311 L
s
.43936 .46296 m
.43952 .45443 L
s
.638 .247 1 r
.22736 .46617 m
.22729 .46635 L
s
.425 .304 1 r
.53382 .44924 m
.53384 .45733 L
s
.53389 .4569 m
.53382 .44924 L
s
.69 .234 1 r
.4393 .46311 m
.43954 .45439 L
s
.43954 .45439 m
.43936 .46296 L
s
.425 .304 1 r
.53384 .45733 m
.53384 .4492 L
s
.53384 .4492 m
.53389 .4569 L
s
.608 .254 1 r
.61887 .45263 m
.6191 .46116 L
s
.61915 .46087 m
.61887 .45263 L
s
.649 .244 1 r
.90685 .45263 m
.90782 .46131 L
s
.90782 .46087 m
.90685 .45263 L
s
.485 .287 1 r
.35447 .45133 m
.35405 .4595 L
s
.35412 .45935 m
.35447 .45133 L
s
.463 .881 1 r
.82182 .44936 m
.82181 .44978 L
s
.608 .254 1 r
.6191 .46116 m
.61889 .45259 L
s
.61889 .45259 m
.61915 .46087 L
s
.649 .244 1 r
.90782 .46131 m
.90688 .45259 L
s
.90688 .45259 m
.90782 .46087 L
s
.589 .259 1 r
.4067 .46444 m
.40663 .46476 L
s
.485 .287 1 r
.35405 .4595 m
.35448 .45129 L
s
.35448 .45129 m
.35412 .45935 L
s
.416 .307 1 r
.60963 .46119 m
.60959 .46148 L
s
.81 .206 1 r
.41594 .45602 m
.41564 .46496 L
s
.41571 .46484 m
.41594 .45602 L
s
.45 .297 1 r
.45809 .43771 m
.4579 .44585 L
s
.45792 .44581 m
.45809 .43771 L
s
.45809 .43771 m
.4578 .45366 L
s
.4 .312 1 r
.61387 .43707 m
.61405 .44505 L
s
.61407 .44502 m
.61387 .43707 L
s
.61387 .43707 m
.6143 .45272 L
s
.81 .206 1 r
.41564 .46496 m
.41596 .45598 L
s
.41596 .45598 m
.41571 .46484 L
s
.977 .171 1 r
.93881 .40299 m
.94457 .44843 L
s
1 .156 .946 r
.65082 .40299 m
.65274 .44879 L
s
.588 .259 1 r
.36283 .40299 m
.36108 .44372 L
s
.56 .267 1 r
.71827 .46328 m
.71824 .46372 L
s
.733 .224 1 r
.8833 .45422 m
.88422 .46304 L
s
.88425 .46275 m
.8833 .45422 L
s
.88422 .46304 m
.88333 .45418 L
s
.88333 .45418 m
.88425 .46275 L
s
.648 .244 1 r
.56672 .43987 m
.5668 .44852 L
s
.56682 .44848 m
.56672 .43987 L
s
.56672 .43987 m
.56695 .45684 L
s
.965 .174 1 r
.39235 .4576 m
.39198 .46688 L
s
.39205 .46672 m
.39235 .4576 L
s
.39198 .46688 m
.39237 .45756 L
s
.39237 .45756 m
.39205 .46672 L
s
.638 .247 1 r
.25512 .44131 m
.25443 .44982 L
s
.25444 .44978 m
.25512 .44131 L
s
.25512 .44131 m
.2538 .45836 L
s
.744 .222 1 r
.51533 .46689 m
.51527 .46722 L
s
.711 .229 1 r
.59531 .4545 m
.59548 .46322 L
s
.59553 .46311 m
.59531 .4545 L
s
.733 .224 1 r
.30728 .4545 m
.30672 .46329 L
s
.30679 .4631 m
.30728 .4545 L
s
.869 .194 1 r
.80664 .40276 m
.8105 .44676 L
s
.342 .377 1 r
.51861 .40276 m
.51873 .43916 L
s
.425 .305 1 r
.23058 .40276 m
.22743 .44133 L
s
.711 .229 1 r
.59548 .46322 m
.59533 .45446 L
s
.59533 .45446 m
.59553 .46311 L
s
.733 .224 1 r
.30672 .46329 m
.3073 .45446 L
s
.3073 .45446 m
.30679 .4631 L
s
.904 .186 1 r
.70396 .45659 m
.70443 .46575 L
s
.70448 .46556 m
.70396 .45659 L
s
.638 .247 1 r
.27869 .44023 m
.27805 .4488 L
s
.27806 .44877 m
.27869 .44023 L
s
.27869 .44023 m
.27749 .4572 L
s
.4 .312 1 r
.26937 .4488 m
.26876 .45678 L
s
.26884 .45646 m
.26937 .4488 L
s
.904 .186 1 r
.70443 .46575 m
.70398 .45655 L
s
.70398 .45655 m
.70448 .46556 L
s
.4 .312 1 r
.26876 .45678 m
.26938 .44876 L
s
.26938 .44876 m
.26884 .45646 L
s
.589 .259 1 r
.43026 .464 m
.43019 .46433 L
s
.953 .176 1 r
.46817 .46992 m
.4681 .47025 L
s
.811 .206 1 r
.75115 .45428 m
.75174 .46333 L
s
.75177 .46289 m
.75115 .45428 L
s
.579 .262 1 r
.51025 .45168 m
.5102 .46014 L
s
.51026 .45985 m
.51025 .45168 L
s
.928 .181 1 r
.67444 .40254 m
.67664 .44762 L
s
.744 .222 1 r
.38637 .40254 m
.38485 .44508 L
s
.811 .206 1 r
.75174 .46333 m
.75117 .45424 L
s
.75117 .45424 m
.75177 .46289 L
s
.579 .262 1 r
.5102 .46014 m
.51027 .45165 L
s
.51027 .45165 m
.51026 .45985 L
s
.425 .305 1 r
.71325 .44858 m
.71369 .45667 L
s
.71372 .45624 m
.71325 .44858 L
s
.71369 .45667 m
.71327 .44854 L
s
.71327 .44854 m
.71372 .45624 L
s
.701 .232 1 r
.43449 .44011 m
.43423 .44887 L
s
.43425 .44883 m
.43449 .44011 L
s
.43449 .44011 m
.43406 .45734 L
s
.649 .244 1 r
.79834 .45197 m
.79902 .46065 L
s
.79904 .46021 m
.79834 .45197 L
s
1 .126 .785 r
.70909 .47294 m
.70905 .47336 L
s
.649 .244 1 r
.79902 .46065 m
.79836 .45193 L
s
.79836 .45193 m
.79904 .46021 L
s
.712 .229 1 r
.64251 .45276 m
.6428 .46159 L
s
.64284 .46115 m
.64251 .45276 L
s
.588 .259 1 r
.95419 .45146 m
.95525 .45996 L
s
.95526 .45963 m
.95419 .45146 L
s
.375 .532 1 r
.8303 .40231 m
.83368 .43799 L
s
.618 .252 1 r
.5422 .40231 m
.54261 .44305 L
s
.352 .327 1 r
.2541 .40231 m
.25124 .44052 L
s
.712 .229 1 r
.6428 .46159 m
.64253 .45273 L
s
.64253 .45273 m
.64284 .46115 L
s
.588 .259 1 r
.95525 .45996 m
.95422 .45143 L
s
.95422 .45143 m
.95526 .45963 L
s
.513 .279 1 r
.6375 .43712 m
.63775 .44547 L
s
.63777 .44544 m
.6375 .43712 L
s
.6375 .43712 m
.63806 .45336 L
s
.46 .294 1 r
.86913 .44836 m
.86995 .4566 L
s
.86994 .45602 m
.86913 .44836 L
s
.86995 .4566 m
.86915 .44832 L
s
.86915 .44832 m
.86994 .45602 L
s
.638 .247 1 r
.22211 .45254 m
.22134 .46112 L
s
.22142 .46093 m
.22211 .45254 L
s
.34 .366 1 r
.69807 .40208 m
.70021 .44066 L
s
.811 .206 1 r
.40993 .40208 m
.40868 .44536 L
s
.638 .247 1 r
.22134 .46112 m
.22212 .4525 L
s
.22212 .4525 m
.22142 .46093 L
s
.531 .274 1 r
.76556 .46241 m
.76552 .46274 L
s
.788 .212 1 r
.38305 .46775 m
.38298 .4679 L
s
.638 .247 1 r
.90209 .43902 m
.903 .44764 L
s
.90303 .4476 m
.90209 .43902 L
s
.90209 .43902 m
.90397 .45596 L
s
.94 .179 1 r
.41088 .44237 m
.41054 .45161 L
s
.41056 .45157 m
.41088 .44237 L
s
.41088 .44237 m
.4103 .46067 L
s
.589 .259 1 r
.92569 .4378 m
.92666 .44633 L
s
.92669 .4463 m
.92569 .4378 L
s
.92569 .4378 m
.92766 .45444 L
s
.468 .292 1 r
.94929 .43653 m
.95027 .44474 L
s
.9503 .44471 m
.94929 .43653 L
s
.94929 .43653 m
.95129 .45256 L
s
.628 .249 1 r
.76982 .43852 m
.7704 .44713 L
s
.77043 .44709 m
.76982 .43852 L
s
.76982 .43852 m
.77105 .45538 L
s
.679 .237 1 r
.85068 .46602 m
.85064 .46613 L
s
.811 .206 1 r
.87852 .4405 m
.87942 .44951 L
s
.87945 .44947 m
.87852 .4405 L
s
.87852 .4405 m
.88037 .45821 L
s
.384 .317 1 r
.8406 .43462 m
.84131 .44265 L
s
.84133 .44261 m
.8406 .43462 L
s
.8406 .43462 m
.84204 .4501 L
s
.579 .262 1 r
.85398 .40186 m
.85812 .44261 L
s
.68 .237 1 r
.5658 .40186 m
.56651 .44369 L
s
.754 .219 1 r
.27762 .40186 m
.27468 .44514 L
s
.904 .186 1 r
.46306 .45572 m
.46289 .46488 L
s
.46295 .46469 m
.46306 .45572 L
s
.559 .267 1 r
.55743 .45052 m
.55751 .45894 L
s
.55756 .45861 m
.55743 .45052 L
s
.904 .186 1 r
.46289 .46488 m
.46308 .45568 L
s
.46308 .45568 m
.46295 .46469 L
s
.638 .247 1 r
.45381 .46429 m
.45375 .46458 L
s
.559 .267 1 r
.55751 .45894 m
.55745 .45048 L
s
.55745 .45048 m
.55756 .45861 L
s
.618 .252 1 r
.32151 .46371 m
.32143 .46404 L
s
1 .118 .742 r
.69908 .44279 m
.69955 .45276 L
s
.69958 .45272 m
.69908 .44279 L
s
.69908 .44279 m
.70009 .46211 L
s
.54 .272 1 r
.34933 .4383 m
.34888 .44662 L
s
.3489 .44658 m
.34933 .4383 L
s
.34933 .4383 m
.34851 .4548 L
s
.579 .262 1 r
.84564 .45081 m
.84643 .45927 L
s
.84646 .45898 m
.84564 .45081 L
s
.965 .174 1 r
.72171 .40163 m
.72452 .44637 L
s
1 .151 .921 r
.4335 .40163 m
.43247 .44818 L
s
.579 .262 1 r
.84643 .45927 m
.84567 .45077 L
s
.84567 .45077 m
.84646 .45898 L
s
.69 .234 1 r
.37793 .4529 m
.37755 .46158 L
s
.37762 .46143 m
.37793 .4529 L
s
.712 .229 1 r
.74203 .46465 m
.742 .46508 L
s
.69 .234 1 r
.37755 .46158 m
.37795 .45286 L
s
.37795 .45286 m
.37762 .46143 L
s
.433 .302 1 r
.23636 .46082 m
.23629 .46096 L
s
.766 .217 1 r
.32573 .43988 m
.32519 .44879 L
s
.32521 .44875 m
.32573 .43988 L
s
.32573 .43988 m
.32474 .45741 L
s
.588 .259 1 r
.92156 .46291 m
.92154 .46324 L
s
.45 .297 1 r
.83644 .45966 m
.83642 .4601 L
s
.638 .247 1 r
.29788 .46558 m
.29782 .46555 L
s
.7 .232 1 r
.58612 .46558 m
.58607 .46577 L
s
.618 .252 1 r
.40152 .45189 m
.4012 .46039 L
s
.40127 .46028 m
.40152 .45189 L
s
.789 .211 1 r
.53892 .46825 m
.53886 .46819 L
s
.352 .327 1 r
.47231 .44798 m
.47218 .45572 L
s
.47224 .45572 m
.47231 .44798 L
s
.45 .297 1 r
.68476 .43616 m
.68511 .4443 L
s
.68513 .44427 m
.68476 .43616 L
s
.68476 .43616 m
.68552 .45212 L
s
.352 .327 1 r
.49591 .44668 m
.49584 .45452 L
s
.49589 .4542 m
.49591 .44668 L
s
.467 .292 1 r
.87766 .40141 m
.88193 .44071 L
s
.522 .277 1 r
.58941 .40141 m
.59036 .44107 L
s
.375 .32 1 r
.30116 .40141 m
.29886 .43927 L
s
.618 .252 1 r
.4012 .46039 m
.40154 .45185 L
s
.40154 .45185 m
.40127 .46028 L
s
.708 1 .681 r
.90639 .41586 m
.9069 .42054 L
s
.90691 .42052 m
.90639 .41586 L
s
.90639 .41586 m
.90733 .42409 L
s
.352 .327 1 r
.47218 .45572 m
.47233 .44795 L
s
.47233 .44795 m
.47224 .45572 L
s
.49584 .45452 m
.49593 .44665 L
s
.49593 .44665 m
.49589 .4542 L
s
.904 .186 1 r
.30212 .4415 m
.3015 .45066 L
s
.30151 .45062 m
.30212 .4415 L
s
.30212 .4415 m
.30096 .45965 L
s
.355 .437 1 r
.48667 .45526 m
.48661 .45572 L
s
1 .161 .972 r
.67127 .46919 m
.67123 .46964 L
s
.723 .226 1 r
.66118 .43785 m
.66151 .44675 L
s
.66153 .44672 m
.66118 .43785 L
s
.66118 .43785 m
.66189 .45508 L
s
.68 .237 1 r
.50524 .43853 m
.50516 .44726 L
s
.50518 .44722 m
.50524 .43853 L
s
.50524 .43853 m
.50516 .45566 L
s
.599 .257 1 r
.65694 .46211 m
.65691 .46259 L
s
.503 .282 1 r
.89293 .44907 m
.89382 .45734 L
s
.89384 .45702 m
.89293 .44907 L
s
.658 .242 1 r
.74537 .40118 m
.74831 .44338 L
s
.359 .46 1 r
.45708 .40118 m
.45657 .4358 L
s
.56 .267 1 r
.81289 .46154 m
.81287 .46197 L
s
.503 .282 1 r
.89382 .45734 m
.89296 .44903 L
s
.89296 .44903 m
.89384 .45702 L
s
.869 .194 1 r
.56254 .46746 m
.56248 .46776 L
s
.733 .224 1 r
.68979 .45246 m
.69021 .46129 L
s
.69026 .461 m
.68979 .45246 L
s
.344 .33 1 r
.26413 .43609 m
.26352 .44379 L
s
.26354 .44376 m
.26413 .43609 L
s
.26413 .43609 m
.26298 .45154 L
s
.733 .224 1 r
.69021 .46129 m
.68982 .45242 L
s
.68982 .45242 m
.69026 .461 L
s
.618 .252 1 r
.58106 .45065 m
.58119 .45923 L
s
.58124 .4589 m
.58106 .45065 L
s
.29275 .45065 m
.29216 .45923 L
s
.29224 .4589 m
.29275 .45065 L
s
.589 .259 1 r
.21269 .46305 m
.21261 .46327 L
s
.56 .267 1 r
.60466 .44935 m
.60485 .45781 L
s
.6049 .45738 m
.60466 .44935 L
s
.618 .252 1 r
.58119 .45923 m
.58108 .45061 L
s
.58108 .45061 m
.58124 .4589 L
s
.588 .259 1 r
.36864 .46247 m
.36857 .4628 L
s
.618 .252 1 r
.29216 .45923 m
.29276 .45061 L
s
.29276 .45061 m
.29224 .4589 L
s
.56 .267 1 r
.60485 .45781 m
.60468 .44932 L
s
.60468 .44932 m
.6049 .45738 L
s
.639 .247 1 r
.21691 .439 m
.21612 .44755 L
s
.21613 .44751 m
.21691 .439 L
s
.21691 .439 m
.21541 .45602 L
s
.722 .227 1 r
.90136 .40095 m
.90632 .44388 L
s
.881 .191 1 r
.61304 .40095 m
.61439 .44461 L
s
.744 .221 1 r
.32471 .40095 m
.3224 .44388 L
s
.68 .237 1 r
.63336 .46399 m
.63331 .46432 L
s
.588 .259 1 r
.39648 .43723 m
.39613 .44574 L
s
.39615 .4457 m
.39648 .43723 L
s
.39648 .43723 m
.39587 .45392 L
s
.335 .341 1 r
.23116 .44653 m
.23049 .45423 L
s
.23056 .45412 m
.23116 .44653 L
s
.23049 .45423 m
.23118 .4465 L
s
.23118 .4465 m
.23056 .45412 L
s
.494 .284 1 r
.33992 .44863 m
.33947 .45687 L
s
.33954 .45658 m
.33992 .44863 L
s
.618 .252 1 r
.76903 .40073 m
.77219 .44185 L
s
.669 .239 1 r
.48067 .40073 m
.48033 .44293 L
s
.608 .254 1 r
.19232 .40073 m
.18846 .44221 L
s
.494 .284 1 r
.33947 .45687 m
.33994 .44859 L
s
.33994 .44859 m
.33954 .45658 L
s
.679 .237 1 r
.42508 .45202 m
.42482 .46067 L
s
.42488 .46056 m
.42508 .45202 L
s
.7 .232 1 r
.37286 .43889 m
.37244 .44762 L
s
.37246 .44758 m
.37286 .43889 L
s
.37286 .43889 m
.37211 .45616 L
s
.391 .315 1 r
.51951 .44682 m
.51949 .45477 L
s
.51955 .45448 m
.51951 .44682 L
s
.392 .314 1 r
.59967 .43434 m
.59981 .44233 L
s
.59983 .4423 m
.59967 .43434 L
s
.59967 .43434 m
.60003 .44993 L
s
.679 .237 1 r
.42482 .46067 m
.4251 .45198 L
s
.4251 .45198 m
.42488 .46056 L
s
.391 .315 1 r
.51949 .45477 m
.51953 .44678 L
s
.51953 .44678 m
.51955 .45448 L
s
.618 .252 1 r
.3163 .45021 m
.31577 .45879 L
s
.31585 .45846 m
.3163 .45021 L
s
.486 .287 1 r
.72782 .45936 m
.72779 .45984 L
s
.618 .252 1 r
.31577 .45879 m
.31632 .45017 L
s
.31632 .45017 m
.31585 .45846 L
s
.628 .249 1 r
.44868 .45101 m
.44848 .45955 L
s
.44855 .4594 m
.44868 .45101 L
s
.34 .366 1 r
.83151 .4458 m
.8322 .45346 L
s
.83223 .45332 m
.83151 .4458 L
s
.8 .209 1 r
.92507 .4005 m
.93059 .44561 L
s
.811 .206 1 r
.63667 .4005 m
.6383 .44344 L
s
.733 .224 1 r
.34828 .4005 m
.34627 .44307 L
s
.628 .249 1 r
.44848 .45955 m
.4487 .45097 L
s
.4487 .45097 m
.44855 .4594 L
s
.34 .366 1 r
.8322 .45346 m
.83154 .44577 L
s
.83154 .44577 m
.83223 .45332 L
s
.733 .224 1 r
.79363 .43997 m
.79428 .4487 L
s
.79431 .44866 m
.79363 .43997 L
s
.79363 .43997 m
.79503 .45747 L
s
.701 .232 1 r
.24044 .43866 m
.2397 .44739 L
s
.23971 .44735 m
.24044 .43866 L
s
.24044 .43866 m
.23903 .45594 L
s
1 .154 .933 r
.48163 .44133 m
.48148 .45087 L
s
.4815 .45082 m
.48163 .44133 L
s
.48163 .44133 m
.48142 .46007 L
s
.376 .32 1 r
.77506 .45705 m
.77504 .45748 L
s
.362 .473 1 r
.85014 .42887 m
.85085 .43661 L
s
.85087 .43658 m
.85014 .42887 L
s
.85014 .42887 m
.85153 .44326 L
s
.337 .351 1 r
.72275 .444 m
.7232 .45183 L
s
.72322 .45122 m
.72275 .444 L
s
.648 .244 1 r
.55246 .43744 m
.5525 .44609 L
s
.55252 .44605 m
.55246 .43744 L
s
.55246 .43744 m
.55262 .45442 L
s
.337 .351 1 r
.7232 .45183 m
.72277 .44396 L
s
.72277 .44396 m
.72322 .45122 L
s
.522 .277 1 r
.57607 .43618 m
.57616 .4445 L
s
.57619 .44446 m
.57607 .43618 L
s
.57607 .43618 m
.57633 .45254 L
s
.467 .292 1 r
.44366 .43553 m
.44345 .44371 L
s
.44346 .44367 m
.44366 .43553 L
s
.44366 .43553 m
.44331 .4516 L
s
.618 .252 1 r
.42005 .437 m
.41977 .44558 L
s
.41978 .44554 m
.42005 .437 L
s
.42005 .437 m
.41956 .45384 L
s
.953 .176 1 r
.79271 .40028 m
.79646 .44502 L
s
.711 .229 1 r
.50428 .40028 m
.50423 .44249 L
s
.494 .285 1 r
.21585 .40028 m
.2124 .44031 L
s
.766 .217 1 r
.52885 .43909 m
.52883 .44797 L
s
.52885 .44793 m
.52885 .43909 L
s
.52885 .43909 m
.52889 .45666 L
s
.68 .237 1 r
.76073 .45028 m
.76133 .45904 L
s
.76135 .4586 m
.76073 .45028 L
s
.845 .199 1 r
.47738 .46601 m
.47732 .46634 L
s
.68 .237 1 r
.76133 .45904 m
.76075 .45024 L
s
.76075 .45024 m
.76135 .4586 L
s
.953 .176 1 r
.24541 .45498 m
.24465 .46422 L
s
.24472 .4641 m
.24541 .45498 L
s
.37 .507 1 r
.82656 .43069 m
.8272 .4382 L
s
.82722 .43817 m
.82656 .43069 L
s
.82656 .43069 m
.82786 .44515 L
s
.551 .269 1 r
.70849 .43725 m
.70891 .44558 L
s
.70893 .44554 m
.70849 .43725 L
s
.70849 .43725 m
.7094 .45384 L
s
.953 .176 1 r
.24465 .46422 m
.24543 .45494 L
s
.24543 .45494 m
.24472 .4641 L
s
1 .123 .772 r
.94879 .40005 m
.95501 .44807 L
s
.799 .209 1 r
.66032 .40005 m
.66227 .44371 L
s
.777 .214 1 r
.37185 .40005 m
.37013 .44299 L
s
.588 .259 1 r
.9168 .45006 m
.91776 .45849 L
s
.9178 .45838 m
.9168 .45006 L
s
.433 .302 1 r
.38708 .44746 m
.38675 .45548 L
s
.38681 .45534 m
.38708 .44746 L
s
.477 .289 1 r
.96404 .44746 m
.96509 .45567 L
s
.9651 .45534 m
.96404 .44746 L
s
.588 .259 1 r
.91776 .45849 m
.91683 .45002 L
s
.91683 .45002 m
.9178 .45838 L
s
.433 .302 1 r
.38675 .45548 m
.3871 .44742 L
s
.3871 .44742 m
.38681 .45534 L
s
.477 .289 1 r
.96509 .45567 m
.96407 .44742 L
s
.96407 .44742 m
.9651 .45534 L
s
.733 .224 1 r
.52461 .46406 m
.52455 .46435 L
s
.669 .239 1 r
.62834 .45035 m
.62859 .45904 L
s
.62864 .45874 m
.62834 .45035 L
s
.448 .827 1 r
.58534 .42866 m
.58544 .43531 L
s
.58546 .43528 m
.58534 .42866 L
s
.58534 .42866 m
.58559 .44175 L
s
.4 .312 1 r
.77939 .43396 m
.77995 .44196 L
s
.77997 .44192 m
.77939 .43396 L
s
.77939 .43396 m
.78057 .44963 L
s
.802 .208 1 r
.68068 .46348 m
.68065 .46411 L
s
.869 .194 1 r
.8164 .39982 m
.82037 .44349 L
s
.579 .262 1 r
.5279 .39982 m
.52813 .44132 L
s
.81 .206 1 r
.23939 .39982 m
.2359 .44385 L
s
.711 .229 1 r
.96918 .46348 m
.96916 .46381 L
s
.669 .239 1 r
.62859 .45904 m
.62836 .45031 L
s
.62836 .45031 m
.62864 .45874 L
s
.765 .217 1 r
.34492 .46615 m
.34486 .46612 L
s
.68 .237 1 r
.25972 .4629 m
.25963 .46323 L
s
.541 .272 1 r
.8646 .43739 m
.86539 .44565 L
s
.86541 .44561 m
.8646 .43739 L
s
.8646 .43739 m
.86626 .45398 L
s
.336 .332 1 r
.85527 .44593 m
.85601 .45363 L
s
.85605 .4536 m
.85527 .44593 L
s
.85601 .45363 m
.85529 .4459 L
s
.85529 .4459 m
.85605 .4536 L
s
.608 .254 1 r
.28333 .46174 m
.28325 .46204 L
s
.477 .289 1 r
.49088 .43428 m
.49078 .44253 L
s
.49079 .4425 m
.49088 .43428 L
s
.49088 .43428 m
.49075 .45035 L
s
.503 .282 1 r
.68398 .3996 m
.68603 .43928 L
s
.733 .224 1 r
.39544 .3996 m
.39403 .44218 L
s
.357 .451 1 r
.53812 .43179 m
.53812 .43935 L
s
.53814 .43932 m
.53812 .43179 L
s
.53812 .43179 m
.5382 .44659 L
s
.559 .267 1 r
.67561 .44832 m
.67597 .45675 L
s
.67601 .45642 m
.67561 .44832 L
s
.845 .199 1 r
.94563 .46535 m
.94561 .46569 L
s
.559 .267 1 r
.67597 .45675 m
.67563 .44828 L
s
.67563 .44828 m
.67601 .45642 L
s
.711 .229 1 r
.20734 .45041 m
.20651 .45921 L
s
.2066 .45888 m
.20734 .45041 L
s
.744 .221 1 r
.28754 .43795 m
.28691 .4468 L
s
.28692 .44676 m
.28754 .43795 L
s
.28754 .43795 m
.28636 .45542 L
s
.711 .229 1 r
.20651 .45921 m
.20735 .45037 L
s
.20735 .45037 m
.2066 .45888 L
s
.658 .242 1 r
.7322 .43738 m
.73269 .446 L
s
.73272 .44597 m
.7322 .43738 L
s
.7322 .43738 m
.73326 .45448 L
s
.733 .224 1 r
.54824 .46362 m
.54818 .46392 L
s
.799 .209 1 r
.50098 .46629 m
.50092 .46626 L
s
.845 .199 1 r
.8401 .39937 m
.84437 .44304 L
s
.4 .312 1 r
.55153 .39937 m
.55201 .43725 L
s
.521 .277 1 r
.26295 .39937 m
.26003 .43978 L
s
.788 .211 1 r
.73722 .4533 m
.73776 .46211 L
s
.73783 .46228 m
.73722 .4533 L
s
.68 .237 1 r
.57187 .46246 m
.57181 .46279 L
s
.559 .267 1 r
.54315 .4481 m
.54319 .45653 L
s
.54324 .4562 m
.54315 .4481 L
s
.788 .211 1 r
.73776 .46211 m
.73724 .45326 L
s
.73724 .45326 m
.73783 .46228 L
s
.559 .267 1 r
.54319 .45653 m
.54317 .44806 L
s
.54317 .44806 m
.54324 .4562 L
s
.712 .229 1 r
.75586 .43643 m
.75642 .44527 L
s
.75645 .44523 m
.75586 .43643 L
s
.75586 .43643 m
.75704 .45368 L
s
.562 .266 1 r
.80312 .43383 m
.80378 .44238 L
s
.8038 .44234 m
.80312 .43383 L
s
.80312 .43383 m
.80447 .45027 L
s
.425 .304 1 r
.53389 .4569 m
.53384 .45733 L
s
.777 .214 1 r
.70765 .39914 m
.71017 .44209 L
s
.335 .34 1 r
.41904 .39914 m
.41806 .4363 L
s
.823 .204 1 r
.65202 .45048 m
.65236 .45961 L
s
.65239 .45902 m
.65202 .45048 L
s
.744 .221 1 r
.94064 .45048 m
.94171 .45935 L
s
.94173 .45902 m
.94064 .45048 L
s
.659 .242 1 r
.36339 .45048 m
.36298 .45906 L
s
.36304 .45902 m
.36339 .45048 L
s
.503 .282 1 r
.93138 .45899 m
.93137 .45932 L
s
1 .126 .786 r
.81749 .44134 m
.81829 .45114 L
s
.81833 .45109 m
.81749 .44134 L
s
.81749 .44134 m
.81917 .46064 L
s
.823 .204 1 r
.65236 .45961 m
.65205 .45044 L
s
.65205 .45044 m
.65239 .45902 L
s
.744 .221 1 r
.94171 .45935 m
.94067 .45044 L
s
.94067 .45044 m
.94173 .45902 L
s
.659 .242 1 r
.36298 .45906 m
.36341 .45044 L
s
.36341 .45044 m
.36304 .45902 L
s
.588 .259 1 r
.20225 .43546 m
.20142 .44397 L
s
.20144 .44393 m
.20225 .43546 L
s
.20225 .43546 m
.2007 .45215 L
s
.531 .274 1 r
.64701 .43481 m
.64728 .44317 L
s
.6473 .44314 m
.64701 .43481 L
s
.64701 .43481 m
.64761 .45121 L
s
.477 .289 1 r
.59041 .44607 m
.59057 .45432 L
s
.59061 .45388 m
.59041 .44607 L
s
.579 .262 1 r
.3305 .46051 m
.33042 .4608 L
s
.477 .289 1 r
.59057 .45432 m
.59043 .44603 L
s
.59043 .44603 m
.59061 .45388 L
s
.777 .214 1 r
.86053 .46318 m
.86051 .46362 L
s
.708 1 .681 r
.9069 .42054 m
.90742 .42522 L
s
.90733 .42409 m
.9069 .42054 L
s
.90742 .42522 m
.90691 .42052 L
s
.90691 .42052 m
.90733 .42409 L
s
.496 .284 1 r
.74656 .44556 m
.7471 .45392 L
s
.74711 .4533 m
.74656 .44556 L
s
.56 .267 1 r
.86382 .39892 m
.86801 .43897 L
s
.599 .257 1 r
.57517 .39892 m
.57598 .44005 L
s
1 .154 .933 r
.28652 .39892 m
.28352 .44477 L
s
.485 .287 1 r
.35412 .45935 m
.35405 .4595 L
s
.811 .206 1 r
.46725 .43708 m
.46707 .44614 L
s
.46709 .4461 m
.46725 .43708 L
s
.46725 .43708 m
.46698 .45476 L
s
.496 .284 1 r
.7471 .45392 m
.74658 .44552 L
s
.74658 .44552 m
.74711 .4533 L
s
.4 .312 1 r
.61405 .44505 m
.61425 .45304 L
s
.6143 .45272 m
.61405 .44505 L
s
1 .128 .8 r
.8749 .47063 m
.87485 .47079 L
s
.531 .274 1 r
.51451 .43459 m
.51445 .44295 L
s
.51447 .44291 m
.51451 .43459 L
s
.51451 .43459 m
.51448 .45099 L
s
.4 .312 1 r
.61425 .45304 m
.61407 .44502 L
s
.61407 .44502 m
.6143 .45272 L
s
.608 .254 1 r
.61915 .46087 m
.6191 .46116 L
s
.649 .244 1 r
.90782 .46087 m
.90782 .46131 L
s
.45 .297 1 r
.4579 .44585 m
.45774 .45399 L
s
.4578 .45366 m
.4579 .44585 L
s
.45774 .45399 m
.45792 .44581 L
s
.45792 .44581 m
.4578 .45366 L
s
.522 .277 1 r
.95934 .43408 m
.96037 .44244 L
s
.9604 .4424 m
.95934 .43408 L
s
.95934 .43408 m
.96144 .45041 L
s
.81 .206 1 r
.78457 .45185 m
.78524 .4608 L
s
.78529 .46069 m
.78457 .45185 L
s
.69 .234 1 r
.43936 .46296 m
.4393 .46311 L
s
.88 .191 1 r
.31109 .43805 m
.31049 .44722 L
s
.31051 .44718 m
.31109 .43805 L
s
.31109 .43805 m
.30999 .45607 L
s
.881 .191 1 r
.88845 .43805 m
.88939 .44722 L
s
.88942 .44718 m
.88845 .43805 L
s
.88845 .43805 m
.89039 .45607 L
s
.4 .312 1 r
.26884 .45646 m
.26876 .45678 L
s
.81 .206 1 r
.78524 .4608 m
.78459 .45181 L
s
.78459 .45181 m
.78529 .46069 L
s
1 .166 .996 r
.73134 .39869 m
.73428 .44346 L
s
1 .156 .946 r
.44265 .39869 m
.44173 .446 L
s
.569 .264 1 r
.35834 .43563 m
.3579 .44403 L
s
.35792 .444 m
.35834 .43563 L
s
.35834 .43563 m
.35755 .45229 L
s
.733 .224 1 r
.88425 .46275 m
.88422 .46304 L
s
.425 .305 1 r
.71372 .45624 m
.71369 .45667 L
s
.777 .214 1 r
.88754 .39846 m
.89242 .44215 L
s
.354 .436 1 r
.59882 .39846 m
.59984 .43744 L
s
.522 .277 1 r
.3101 .39846 m
.30776 .43853 L
s
.81 .206 1 r
.41571 .46484 m
.41564 .46496 L
s
.893 .189 1 r
.80826 .45112 m
.80902 .46037 L
s
.80904 .45988 m
.80826 .45112 L
s
.638 .247 1 r
.25443 .44982 m
.25374 .45833 L
s
.2538 .45836 m
.25443 .44982 L
s
.648 .244 1 r
.5668 .44852 m
.5669 .45717 L
s
.56695 .45684 m
.5668 .44852 L
s
.893 .189 1 r
.80902 .46037 m
.80829 .45108 L
s
.80829 .45108 m
.80904 .45988 L
s
.638 .247 1 r
.25374 .45833 m
.25444 .44978 L
s
.25444 .44978 m
.2538 .45836 L
s
.648 .244 1 r
.5669 .45717 m
.56682 .44848 L
s
.56682 .44848 m
.56695 .45684 L
s
.711 .229 1 r
.59553 .46311 m
.59548 .46322 L
s
.733 .224 1 r
.30679 .4631 m
.30672 .46329 L
s
.579 .262 1 r
.51026 .45985 m
.5102 .46014 L
s
.638 .247 1 r
.27805 .4488 m
.27742 .45739 L
s
.27749 .4572 m
.27805 .4488 L
s
.46 .294 1 r
.86994 .45602 m
.86995 .4566 L
s
.991 .169 1 r
.75503 .39824 m
.75829 .44301 L
s
.36 .324 1 r
.46627 .39824 m
.46582 .43541 L
s
.638 .247 1 r
.27742 .45739 m
.27806 .44877 L
s
.27806 .44877 m
.27749 .4572 L
s
.388 .587 1 r
.6327 .42916 m
.6329 .43643 L
s
.63292 .43639 m
.6327 .42916 L
s
.6327 .42916 m
.63317 .44337 L
s
.916 .184 1 r
.91221 .43782 m
.91322 .44707 L
s
.91325 .44702 m
.91221 .43782 L
s
.91221 .43782 m
.91429 .45599 L
s
.965 .174 1 r
.39205 .46672 m
.39198 .46688 L
s
.649 .244 1 r
.79904 .46021 m
.79902 .46065 L
s
.811 .206 1 r
.75177 .46289 m
.75174 .46333 L
s
.868 .194 1 r
.33466 .43796 m
.33413 .44706 L
s
.33414 .44702 m
.33466 .43796 L
s
.33466 .43796 m
.33368 .45599 L
s
.588 .259 1 r
.95526 .45963 m
.95525 .45996 L
s
.904 .186 1 r
.70448 .46556 m
.70443 .46575 L
s
.857 .196 1 r
.91128 .39801 m
.91655 .44242 L
s
.777 .214 1 r
.62249 .39801 m
.62393 .44097 L
s
.67 .239 1 r
.33369 .39801 m
.33156 .43952 L
s
1 .163 .984 r
.62345 .43817 m
.6237 .44764 L
s
.62372 .4476 m
.62345 .43817 L
s
.62345 .43817 m
.62401 .45671 L
s
.712 .229 1 r
.64284 .46115 m
.6428 .46159 L
s
.513 .279 1 r
.63775 .44547 m
.63802 .45383 L
s
.63806 .45336 m
.63775 .44547 L
s
.63802 .45383 m
.63777 .44544 L
s
.63777 .44544 m
.63806 .45336 L
s
.701 .232 1 r
.43423 .44887 m
.43399 .45764 L
s
.43406 .45734 m
.43423 .44887 L
s
.917 .184 1 r
.93592 .43705 m
.937 .44634 L
s
.93703 .44629 m
.93592 .43705 L
s
.93592 .43705 m
.93812 .45518 L
s
.701 .232 1 r
.43399 .45764 m
.43425 .44883 L
s
.43425 .44883 m
.43406 .45734 L
s
1 .133 .827 r
.77874 .39778 m
.78256 .44583 L
s
.777 .214 1 r
.48991 .39778 m
.48967 .44148 L
s
.578 .262 1 r
.20107 .39778 m
.19728 .43966 L
s
.811 .206 1 r
.67076 .43597 m
.67111 .44503 L
s
.67114 .44499 m
.67076 .43597 L
s
.67076 .43597 m
.67153 .45366 L
s
.638 .247 1 r
.22142 .46093 m
.22134 .46112 L
s
.7 .232 1 r
.38191 .436 m
.38152 .44474 L
s
.38154 .4447 m
.38191 .436 L
s
.38191 .436 m
.38121 .4533 L
s
.384 .317 1 r
.84131 .44265 m
.84205 .45067 L
s
.84204 .4501 m
.84131 .44265 L
s
.84205 .45067 m
.84133 .44261 L
s
.84133 .44261 m
.84204 .4501 L
s
.468 .292 1 r
.95027 .44474 m
.95129 .45296 L
s
.95129 .45256 m
.95027 .44474 L
s
.788 .212 1 r
.22565 .43691 m
.22485 .44583 L
s
.22486 .44579 m
.22565 .43691 L
s
.22565 .43691 m
.22413 .4546 L
s
.468 .292 1 r
.95129 .45296 m
.9503 .44471 L
s
.9503 .44471 m
.95129 .45256 L
s
.559 .267 1 r
.55756 .45861 m
.55751 .45894 L
s
.669 .239 1 r
.69442 .43503 m
.69482 .44372 L
s
.69484 .44369 m
.69442 .43503 L
s
.69442 .43503 m
.69529 .45213 L
s
.579 .262 1 r
.93503 .39756 m
.94016 .43835 L
s
1 .098 .63 r
.64616 .39756 m
.64816 .4467 L
s
.36 .462 1 r
.35729 .39756 m
.35567 .43401 L
s
.638 .247 1 r
.903 .44764 m
.90395 .45626 L
s
.90397 .45596 m
.903 .44764 L
s
.589 .259 1 r
.92666 .44633 m
.92766 .45488 L
s
.92766 .45444 m
.92666 .44633 L
s
.352 .327 1 r
.49589 .4542 m
.49584 .45452 L
s
.638 .247 1 r
.90395 .45626 m
.90303 .4476 L
s
.90303 .4476 m
.90397 .45596 L
s
.589 .259 1 r
.92766 .45488 m
.92669 .4463 L
s
.92669 .4463 m
.92766 .45444 L
s
.628 .249 1 r
.7704 .44713 m
.77102 .45575 L
s
.77105 .45538 m
.7704 .44713 L
s
.579 .262 1 r
.84646 .45898 m
.84643 .45927 L
s
.628 .249 1 r
.77102 .45575 m
.77043 .44709 L
s
.77043 .44709 m
.77105 .45538 L
s
.352 .327 1 r
.47224 .45572 m
.47218 .45572 L
s
.68 .237 1 r
.56182 .43477 m
.56188 .4435 L
s
.5619 .44346 m
.56182 .43477 L
s
.56182 .43477 m
.56202 .45191 L
s
.54 .272 1 r
.34888 .44662 m
.34845 .45495 L
s
.34851 .4548 m
.34888 .44662 L
s
.618 .252 1 r
.80246 .39733 m
.80603 .43849 L
s
.671 .239 1 r
.51355 .39733 m
.51363 .43813 L
s
.823 .204 1 r
.22465 .39733 m
.22106 .4403 L
s
.54 .272 1 r
.34845 .45495 m
.3489 .44658 L
s
.3489 .44658 m
.34851 .4548 L
s
.811 .206 1 r
.87942 .44951 m
.88035 .45854 L
s
.88037 .45821 m
.87942 .44951 L
s
.45 .297 1 r
.68511 .4443 m
.68548 .45244 L
s
.68552 .45212 m
.68511 .4443 L
s
.811 .206 1 r
.88035 .45854 m
.87945 .44947 L
s
.87945 .44947 m
.88037 .45821 L
s
.904 .186 1 r
.46295 .46469 m
.46289 .46488 L
s
.45 .297 1 r
.68548 .45244 m
.68513 .44427 L
s
.68513 .44427 m
.68552 .45212 L
s
.94 .179 1 r
.41054 .45161 m
.41023 .46086 L
s
.4103 .46067 m
.41054 .45161 L
s
.69 .234 1 r
.37762 .46143 m
.37755 .46158 L
s
.344 .33 1 r
.26352 .44379 m
.26293 .4515 L
s
.26298 .45154 m
.26352 .44379 L
s
.94 .179 1 r
.41023 .46086 m
.41056 .45157 L
s
.41056 .45157 m
.4103 .46067 L
s
.589 .259 1 r
.66985 .3971 m
.67178 .43754 L
s
.588 .259 1 r
.38091 .3971 m
.37938 .4379 L
s
.441 .3 1 r
.47648 .43198 m
.47634 .44009 L
s
.47636 .44006 m
.47648 .43198 L
s
.47648 .43198 m
.47628 .44792 L
s
.344 .33 1 r
.26293 .4515 m
.26354 .44376 L
s
.26354 .44376 m
.26298 .45154 L
s
.708 1 .681 r
.90733 .42409 m
.90742 .42522 L
s
.618 .252 1 r
.40127 .46028 m
.4012 .46039 L
s
.376 .32 1 r
.92173 .4314 m
.92262 .4393 L
s
.92264 .43926 m
.92173 .4314 L
s
.92173 .4314 m
.92356 .44698 L
s
.503 .282 1 r
.89384 .45702 m
.89382 .45734 L
s
.871 .193 1 r
.71815 .4349 m
.71864 .44414 L
s
.71866 .4441 m
.71815 .4349 L
s
.71815 .4349 m
.71918 .45277 L
s
.733 .224 1 r
.27286 .43555 m
.27218 .44436 L
s
.2722 .44432 m
.27286 .43555 L
s
.27286 .43555 m
.2716 .45299 L
s
.766 .217 1 r
.32519 .44879 m
.32466 .4577 L
s
.32474 .45741 m
.32519 .44879 L
s
.68 .237 1 r
.29651 .43432 m
.2959 .44306 L
s
.29592 .44302 m
.29651 .43432 L
s
.29651 .43432 m
.29539 .45147 L
s
.337 .332 1 r
.82619 .39688 m
.82961 .43334 L
s
.433 .302 1 r
.53721 .39688 m
.53754 .43551 L
s
.494 .284 1 r
.24823 .39688 m
.24516 .43695 L
s
.766 .217 1 r
.32466 .4577 m
.32521 .44875 L
s
.32521 .44875 m
.32474 .45741 L
s
.56 .267 1 r
.6049 .45738 m
.60485 .45781 L
s
.335 .341 1 r
.23056 .45412 m
.23049 .45423 L
s
.822 .204 1 r
.40551 .43645 m
.40517 .44545 L
s
.40518 .44541 m
.40551 .43645 L
s
.40551 .43645 m
.40491 .4543 L
s
.352 .427 1 r
.81278 .42991 m
.81339 .43748 L
s
.81341 .43744 m
.81278 .42991 L
s
.81278 .42991 m
.81406 .44487 L
s
.701 .232 1 r
.87449 .43457 m
.87535 .44335 L
s
.87538 .44331 m
.87449 .43457 L
s
.87449 .43457 m
.87627 .45183 L
s
.618 .252 1 r
.58124 .4589 m
.58119 .45923 L
s
.29224 .4589 m
.29216 .45923 L
s
.733 .224 1 r
.42916 .43533 m
.42889 .44414 L
s
.4289 .4441 m
.42916 .43533 L
s
.42916 .43533 m
.4287 .45277 L
s
.69026 .461 m
.69021 .46129 L
s
.68 .237 1 r
.50516 .44726 m
.5051 .45599 L
s
.50516 .45566 m
.50516 .44726 L
s
.476 .29 1 r
.76549 .4328 m
.76603 .44096 L
s
.76605 .44092 m
.76549 .4328 L
s
.76549 .4328 m
.76664 .449 L
s
.503 .282 1 r
.3438 .43215 m
.34334 .44044 L
s
.34335 .44041 m
.3438 .43215 L
s
.3438 .43215 m
.34296 .44842 L
s
.391 .315 1 r
.51955 .45448 m
.51949 .45477 L
s
.589 .259 1 r
.69355 .39665 m
.69577 .43709 L
s
.916 .184 1 r
.40454 .39665 m
.40318 .44108 L
s
.337 .351 1 r
.72322 .45122 m
.7232 .45183 L
s
.68 .237 1 r
.5051 .45599 m
.50518 .44722 L
s
.50518 .44722 m
.50516 .45566 L
s
.904 .186 1 r
.3015 .45066 m
.30089 .45984 L
s
.30096 .45965 m
.3015 .45066 L
s
.723 .226 1 r
.66151 .44675 m
.66186 .45567 L
s
.66189 .45508 m
.66151 .44675 L
s
.965 .174 1 r
.24915 .43753 m
.24838 .44682 L
s
.24839 .44678 m
.24915 .43753 L
s
.24915 .43753 m
.24769 .45597 L
s
.494 .284 1 r
.33954 .45658 m
.33947 .45687 L
s
.904 .186 1 r
.30089 .45984 m
.30151 .45062 L
s
.30151 .45062 m
.30096 .45965 L
s
.34 .366 1 r
.83223 .45332 m
.8322 .45346 L
s
.723 .226 1 r
.66186 .45567 m
.66153 .44672 L
s
.66153 .44672 m
.66189 .45508 L
s
.648 .244 1 r
.32013 .43366 m
.31959 .44233 L
s
.3196 .44229 m
.32013 .43366 L
s
.32013 .43366 m
.31914 .45066 L
s
1 .118 .742 r
.69955 .45276 m
.70005 .46275 L
s
.70009 .46211 m
.69955 .45276 L
s
.639 .247 1 r
.21612 .44755 m
.21534 .4561 L
s
.21541 .45602 m
.21612 .44755 L
s
1 .118 .742 r
.70005 .46275 m
.69958 .45272 L
s
.69958 .45272 m
.70009 .46211 L
s
.392 .314 1 r
.59981 .44233 m
.59998 .45033 L
s
.60003 .44993 m
.59981 .44233 L
s
.639 .247 1 r
.21534 .4561 m
.21613 .44751 L
s
.21613 .44751 m
.21541 .45602 L
s
.392 .314 1 r
.59998 .45033 m
.59983 .4423 L
s
.59983 .4423 m
.60003 .44993 L
s
.588 .259 1 r
.39613 .44574 m
.3958 .45425 L
s
.39587 .45392 m
.39613 .44574 L
s
.811 .206 1 r
.84994 .39642 m
.8543 .43976 L
s
.618 .252 1 r
.56088 .39642 m
.56152 .43723 L
s
.658 .242 1 r
.27183 .39642 m
.26888 .43868 L
s
.756 .219 1 r
.60918 .43394 m
.60937 .4429 L
s
.60939 .44286 m
.60918 .43394 L
s
.60918 .43394 m
.60963 .45139 L
s
.588 .259 1 r
.3958 .45425 m
.39615 .4457 L
s
.39615 .4457 m
.39587 .45392 L
s
.362 .473 1 r
.85085 .43661 m
.85159 .44436 L
s
.85153 .44326 m
.85085 .43661 L
s
.448 .827 1 r
.58544 .43531 m
.58555 .44195 L
s
.58559 .44175 m
.58544 .43531 L
s
.58555 .44195 m
.58546 .43528 L
s
.58546 .43528 m
.58559 .44175 L
s
.362 .473 1 r
.85159 .44436 m
.85087 .43658 L
s
.85087 .43658 m
.85153 .44326 L
s
.618 .252 1 r
.31585 .45846 m
.31577 .45879 L
s
.337 .353 1 r
.54746 .42958 m
.54749 .43732 L
s
.54751 .43729 m
.54746 .42958 L
s
.54746 .42958 m
.54758 .44479 L
s
.37 .507 1 r
.8272 .4382 m
.82786 .44572 L
s
.82786 .44515 m
.8272 .4382 L
s
.679 .237 1 r
.42488 .46056 m
.42482 .46067 L
s
.37 .507 1 r
.82786 .44572 m
.82722 .43817 L
s
.82722 .43817 m
.82786 .44515 L
s
.649 .244 1 r
.71727 .39619 m
.71983 .43773 L
s
.425 .305 1 r
.42818 .39619 m
.42727 .43483 L
s
.7 .232 1 r
.37244 .44762 m
.37205 .45635 L
s
.37211 .45616 m
.37244 .44762 L
s
.628 .249 1 r
.44855 .4594 m
.44848 .45955 L
s
.467 .292 1 r
.44345 .44371 m
.44324 .45189 L
s
.44331 .4516 m
.44345 .44371 L
s
.845 .199 1 r
.74191 .43517 m
.74245 .44428 L
s
.74248 .44423 m
.74191 .43517 L
s
.74191 .43517 m
.74306 .45305 L
s
.7 .232 1 r
.37205 .45635 m
.37246 .44758 L
s
.37246 .44758 m
.37211 .45616 L
s
.467 .292 1 r
.44324 .45189 m
.44346 .44367 L
s
.44346 .44367 m
.44331 .4516 L
s
.522 .277 1 r
.57616 .4445 m
.57628 .45283 L
s
.57633 .45254 m
.57616 .4445 L
s
.355 .437 1 r
.86025 .42873 m
.86096 .4363 L
s
.86099 .43627 m
.86025 .42873 L
s
.86025 .42873 m
.86173 .44362 L
s
.522 .277 1 r
.57628 .45283 m
.57619 .44446 L
s
.57619 .44446 m
.57633 .45254 L
s
.789 .211 1 r
.87369 .39597 m
.87829 .43859 L
s
.36 .462 1 r
.58457 .39597 m
.58538 .43208 L
s
.904 .186 1 r
.29544 .39597 m
.29263 .44077 L
s
.733 .224 1 r
.79428 .4487 m
.79497 .45744 L
s
.79503 .45747 m
.79428 .4487 L
s
.701 .232 1 r
.2397 .44739 m
.23896 .45613 L
s
.23903 .45594 m
.2397 .44739 L
s
.648 .244 1 r
.5525 .44609 m
.55256 .45475 L
s
.55262 .45442 m
.5525 .44609 L
s
.733 .224 1 r
.79497 .45744 m
.79431 .44866 L
s
.79431 .44866 m
.79503 .45747 L
s
.68 .237 1 r
.76135 .4586 m
.76133 .45904 L
s
.701 .232 1 r
.23896 .45613 m
.23971 .44735 L
s
.23971 .44735 m
.23903 .45594 L
s
.648 .244 1 r
.55256 .45475 m
.55252 .44605 L
s
.55252 .44605 m
.55262 .45442 L
s
.433 .302 1 r
.38681 .45534 m
.38675 .45548 L
s
.477 .289 1 r
.9651 .45534 m
.96509 .45567 L
s
.362 .474 1 r
.59481 .42776 m
.59494 .43528 L
s
.59496 .43525 m
.59481 .42776 L
s
.59481 .42776 m
.59513 .44246 L
s
.522 .277 1 r
.23466 .43173 m
.23393 .44007 L
s
.23394 .44003 m
.23466 .43173 L
s
.23466 .43173 m
.23329 .44811 L
s
.618 .252 1 r
.41977 .44558 m
.41949 .45417 L
s
.41956 .45384 m
.41977 .44558 L
s
.551 .269 1 r
.70891 .44558 m
.70935 .45392 L
s
.7094 .45384 m
.70891 .44558 L
s
.868 .194 1 r
.45279 .43574 m
.45257 .44485 L
s
.45259 .44481 m
.45279 .43574 L
s
.45279 .43574 m
.45244 .45378 L
s
.618 .252 1 r
.41949 .45417 m
.41978 .44554 L
s
.41978 .44554 m
.41956 .45384 L
s
.551 .269 1 r
.70935 .45392 m
.70893 .44554 L
s
.70893 .44554 m
.7094 .45384 L
s
.559 .267 1 r
.52381 .43191 m
.52378 .44035 L
s
.5238 .44031 m
.52381 .43191 L
s
.52381 .43191 m
.52382 .44847 L
s
.336 .332 1 r
.85605 .4536 m
.85601 .45363 L
s
.514 .279 1 r
.74099 .39574 m
.7437 .4351 L
s
1 .146 .894 r
.45183 .39574 m
.45106 .442 L
s
.4 .312 1 r
.77995 .44196 m
.78054 .44996 L
s
.78057 .44963 m
.77995 .44196 L
s
.357 .451 1 r
.53812 .43935 m
.53815 .44691 L
s
.5382 .44659 m
.53812 .43935 L
s
.588 .259 1 r
.9178 .45838 m
.91776 .45849 L
s
.4 .312 1 r
.78054 .44996 m
.77997 .44192 L
s
.77997 .44192 m
.78057 .44963 L
s
.766 .217 1 r
.52883 .44797 m
.52883 .45685 L
s
.52889 .45666 m
.52883 .44797 L
s
.357 .451 1 r
.53815 .44691 m
.53814 .43932 L
s
.53814 .43932 m
.5382 .44659 L
s
.881 .191 1 r
.8984 .43548 m
.89937 .44463 L
s
.89939 .44459 m
.8984 .43548 L
s
.8984 .43548 m
.9004 .45355 L
s
.766 .217 1 r
.52883 .45685 m
.52885 .44793 L
s
.52885 .44793 m
.52889 .45666 L
s
.552 .269 1 r
.70392 .43031 m
.70434 .43882 L
s
.70436 .43879 m
.70392 .43031 L
s
.70392 .43031 m
.7048 .44672 L
s
.613 .253 1 r
.7276 .42901 m
.7281 .43781 L
s
.72812 .43777 m
.7276 .42901 L
s
.7276 .42901 m
.72861 .44556 L
s
.648 .244 1 r
.78932 .43364 m
.78996 .44224 L
s
.78998 .4422 m
.78932 .43364 L
s
.78932 .43364 m
.79067 .45072 L
s
.399 .312 1 r
.89746 .39551 m
.90193 .43452 L
s
.588 .259 1 r
.60826 .39551 m
.60946 .43633 L
s
.522 .277 1 r
.31906 .39551 m
.3168 .43596 L
s
1 .154 .933 r
.48148 .45087 m
.48135 .46041 L
s
.48142 .46007 m
.48148 .45087 L
s
.418 .713 1 r
.22021 .42518 m
.21957 .43216 L
s
.21958 .43213 m
.22021 .42518 L
s
.22021 .42518 m
.21901 .43882 L
s
.669 .239 1 r
.62864 .45874 m
.62859 .45904 L
s
.541 .272 1 r
.86539 .44565 m
.8662 .45391 L
s
.86626 .45398 m
.86539 .44565 L
s
.352 .327 1 r
.30563 .42854 m
.3051 .43643 L
s
.30511 .4364 m
.30563 .42854 L
s
.30563 .42854 m
.30466 .4439 L
s
1 .154 .933 r
.48135 .46041 m
.4815 .45082 L
s
.4815 .45082 m
.48142 .46007 L
s
.629 .249 1 r
.8367 .43121 m
.83746 .43991 L
s
.83749 .43987 m
.8367 .43121 L
s
.8367 .43121 m
.83826 .44803 L
s
.459 .295 1 r
.25827 .43122 m
.25761 .43933 L
s
.25763 .4393 m
.25827 .43122 L
s
.25827 .43122 m
.25703 .44731 L
s
.541 .272 1 r
.8662 .45391 m
.86541 .44561 L
s
.86541 .44561 m
.86626 .45398 L
s
.953 .176 1 r
.24472 .4641 m
.24465 .46422 L
s
.477 .289 1 r
.49078 .44253 m
.49069 .45079 L
s
.49075 .45035 m
.49078 .44253 L
s
.49069 .45079 m
.49079 .4425 L
s
.49079 .4425 m
.49075 .45035 L
s
.559 .267 1 r
.67601 .45642 m
.67597 .45675 L
s
.701 .232 1 r
.21089 .4341 m
.21007 .44281 L
s
.21009 .44277 m
.21089 .4341 L
s
.21089 .4341 m
.20933 .45145 L
s
.754 .219 1 r
.76473 .39529 m
.768 .43864 L
s
.4 .312 1 r
.47549 .39528 m
.47513 .43321 L
s
.648 .244 1 r
.18626 .39528 m
.18232 .43683 L
s
.569 .264 1 r
.39102 .43229 m
.39067 .44071 L
s
.39069 .44067 m
.39102 .43229 L
s
.39102 .43229 m
.39039 .44897 L
s
.559 .267 1 r
.54324 .4562 m
.54319 .45653 L
s
.712 .229 1 r
.92124 .39506 m
.92635 .43697 L
s
.531 .274 1 r
.63197 .39506 m
.63343 .43515 L
s
.559 .267 1 r
.34269 .39506 m
.34072 .43552 L
s
.711 .229 1 r
.2066 .45888 m
.20651 .45921 L
s
.765 .217 1 r
.36733 .43399 m
.3669 .44288 L
s
.36691 .44284 m
.36733 .43399 L
s
.36733 .43399 m
.36655 .45158 L
s
.822 .204 1 r
.50013 .43467 m
.50004 .44368 L
s
.50006 .44364 m
.50013 .43467 L
s
.50013 .43467 m
.50002 .45253 L
s
.512 .279 1 r
.41469 .43142 m
.4144 .43969 L
s
.41441 .43965 m
.41469 .43142 L
s
.41469 .43142 m
.41418 .44781 L
s
.845 .199 1 r
.9459 .43406 m
.94699 .44317 L
s
.94702 .44313 m
.9459 .43406 L
s
.9459 .43406 m
.94813 .45195 L
s
.658 .242 1 r
.73269 .446 m
.73321 .45463 L
s
.73326 .45448 m
.73269 .446 L
s
.477 .289 1 r
.59061 .45388 m
.59057 .45432 L
s
.777 .214 1 r
.68031 .43286 m
.68069 .44186 L
s
.68071 .44182 m
.68031 .43286 L
s
.68031 .43286 m
.68113 .45042 L
s
.658 .242 1 r
.73321 .45463 m
.73272 .44597 L
s
.73272 .44597 m
.73326 .45448 L
s
.425 .304 1 r
.75136 .42896 m
.75187 .43707 L
s
.75189 .43703 m
.75136 .42896 L
s
.75136 .42896 m
.75242 .44475 L
s
.496 .284 1 r
.74711 .4533 m
.7471 .45392 L
s
.777 .214 1 r
.65662 .43427 m
.65693 .44317 L
s
.65696 .44313 m
.65662 .43427 L
s
.65662 .43427 m
.65732 .45195 L
s
.744 .221 1 r
.28691 .4468 m
.28628 .45565 L
s
.28636 .45542 m
.28691 .4468 L
s
.4 .312 1 r
.6143 .45272 m
.61425 .45304 L
s
.601 .256 1 r
.78848 .39483 m
.79175 .4342 L
s
.799 .209 1 r
.49917 .39483 m
.49905 .43855 L
s
.55 .269 1 r
.57118 .43105 m
.57127 .43946 L
s
.57129 .43943 m
.57118 .43105 L
s
.57118 .43105 m
.57143 .44759 L
s
.799 .209 1 r
.20986 .39483 m
.20601 .43855 L
s
.744 .221 1 r
.28628 .45565 m
.28692 .44676 L
s
.28692 .44676 m
.28636 .45542 L
s
.562 .266 1 r
.80378 .44238 m
.80447 .45093 L
s
.80447 .45027 m
.80378 .44238 L
s
.80447 .45093 m
.8038 .44234 L
s
.8038 .44234 m
.80447 .45027 L
s
.788 .211 1 r
.73783 .46228 m
.73776 .46211 L
s
.425 .305 1 r
.46205 .42928 m
.46188 .43736 L
s
.46189 .43732 m
.46205 .42928 L
s
.46205 .42928 m
.46178 .44511 L
s
.531 .274 1 r
.64728 .44317 m
.64757 .45154 L
s
.64761 .45121 m
.64728 .44317 L
s
.45 .297 1 r
.4578 .45366 m
.45774 .45399 L
s
.589 .259 1 r
.43837 .43069 m
.43812 .43924 L
s
.43814 .4392 m
.43837 .43069 L
s
.43837 .43069 m
.43797 .44736 L
s
.531 .274 1 r
.64757 .45154 m
.6473 .44314 L
s
.6473 .44314 m
.64761 .45121 L
s
.467 .292 1 r
.28184 .43138 m
.28124 .43946 L
s
.28126 .43943 m
.28184 .43138 L
s
.28184 .43138 m
.28071 .44759 L
s
.823 .204 1 r
.65239 .45902 m
.65236 .45961 L
s
.744 .221 1 r
.94173 .45902 m
.94171 .45935 L
s
.659 .242 1 r
.36304 .45902 m
.36298 .45906 L
s
.712 .229 1 r
.75642 .44527 m
.75702 .45412 L
s
.75704 .45368 m
.75642 .44527 L
s
.588 .259 1 r
.20142 .44397 m
.20061 .45248 L
s
.2007 .45215 m
.20142 .44397 L
s
.777 .214 1 r
.94503 .3946 m
.95057 .4376 L
s
.45 .297 1 r
.65569 .3946 m
.65738 .43362 L
s
.733 .224 1 r
.36634 .3946 m
.36454 .4376 L
s
.712 .229 1 r
.75702 .45412 m
.75645 .44523 L
s
.75645 .44523 m
.75704 .45368 L
s
.588 .259 1 r
.20061 .45248 m
.20144 .44393 L
s
.20144 .44393 m
.2007 .45215 L
s
.531 .274 1 r
.51445 .44295 m
.51442 .45132 L
s
.51448 .45099 m
.51445 .44295 L
s
.477 .289 1 r
.61858 .42916 m
.61878 .43742 L
s
.6188 .43739 m
.61858 .42916 L
s
.61858 .42916 m
.61904 .44525 L
s
.388 .587 1 r
.6329 .43643 m
.63313 .44369 L
s
.63317 .44337 m
.6329 .43643 L
s
.531 .274 1 r
.51442 .45132 m
.51447 .44291 L
s
.51447 .44291 m
.51448 .45099 L
s
.388 .587 1 r
.63313 .44369 m
.63292 .43639 L
s
.63292 .43639 m
.63317 .44337 L
s
.522 .277 1 r
.96037 .44244 m
.96143 .45081 L
s
.96144 .45041 m
.96037 .44244 L
s
.368 .497 1 r
.81224 .39437 m
.81545 .43014 L
s
.811 .206 1 r
.52286 .39437 m
.52305 .43738 L
s
.659 .242 1 r
.23348 .39437 m
.22995 .43774 L
s
.522 .277 1 r
.96143 .45081 m
.9604 .4424 L
s
.9604 .4424 m
.96144 .45041 L
s
.569 .264 1 r
.3579 .44403 m
.35748 .45244 L
s
.35755 .45229 m
.3579 .44403 L
s
.35748 .45244 m
.35792 .444 L
s
.35792 .444 m
.35755 .45229 L
s
.811 .206 1 r
.46707 .44614 m
.46691 .4552 L
s
.46698 .45476 m
.46707 .44614 L
s
.424 .305 1 r
.67942 .39415 m
.68137 .4328 L
s
.811 .206 1 r
.39 .39415 m
.38849 .43752 L
s
.46691 .4552 m
.46709 .4461 L
s
.46709 .4461 m
.46698 .45476 L
s
.81 .206 1 r
.78529 .46069 m
.78524 .4608 L
s
.648 .244 1 r
.56695 .45684 m
.5669 .45717 L
s
.559 .267 1 r
.88433 .43122 m
.88518 .43959 L
s
.88521 .43956 m
.88433 .43122 L
s
.88433 .43122 m
.8861 .44787 L
s
1 .126 .786 r
.81829 .45114 m
.81913 .46095 L
s
.81917 .46064 m
.81829 .45114 L
s
.88 .191 1 r
.31049 .44722 m
.30991 .4564 L
s
.30999 .45607 m
.31049 .44722 L
s
.881 .191 1 r
.88939 .44722 m
.89036 .4564 L
s
.89039 .45607 m
.88939 .44722 L
s
.638 .247 1 r
.2538 .45836 m
.25374 .45833 L
s
.433 .302 1 r
.19627 .42944 m
.19547 .43749 L
s
.19549 .43745 m
.19627 .42944 L
s
.19627 .42944 m
.19476 .44539 L
s
1 .126 .786 r
.81913 .46095 m
.81833 .45109 L
s
.81833 .45109 m
.81917 .46064 L
s
.88 .191 1 r
.30991 .4564 m
.31051 .44718 L
s
.31051 .44718 m
.30999 .45607 L
s
.881 .191 1 r
.89036 .4564 m
.88942 .44718 L
s
.88942 .44718 m
.89039 .45607 L
s
.711 .229 1 r
.83601 .39392 m
.8401 .4362 L
s
.61 .254 1 r
.54656 .39392 m
.54702 .43439 L
s
.638 .247 1 r
.2571 .39392 m
.254 .43584 L
s
.27749 .4572 m
.27742 .45739 L
s
.893 .189 1 r
.80904 .45988 m
.80902 .46037 L
s
.513 .279 1 r
.63806 .45336 m
.63802 .45383 L
s
.384 .317 1 r
.84204 .4501 m
.84205 .45067 L
s
.701 .232 1 r
.70316 .39369 m
.70564 .43707 L
s
.953 .176 1 r
.41367 .39369 m
.41242 .43852 L
s
.56 .267 1 r
.93183 .42936 m
.9328 .43784 L
s
.93283 .4378 m
.93183 .42936 L
s
.93183 .42936 m
.93382 .44589 L
s
.57 .264 1 r
.79893 .42878 m
.79959 .43733 L
s
.79962 .43729 m
.79893 .42878 L
s
.79893 .42878 m
.80028 .44531 L
s
.468 .292 1 r
.95129 .45256 m
.95129 .45296 L
s
.416 .307 1 r
.8598 .39346 m
.86381 .43213 L
s
.531 .274 1 r
.57027 .39346 m
.571 .43322 L
s
.701 .232 1 r
.43406 .45734 m
.43399 .45764 L
s
.857 .196 1 r
.28074 .39346 m
.27775 .43793 L
s
.344 .33 1 r
.68974 .42711 m
.69009 .43494 L
s
.69011 .4349 m
.68974 .42711 L
s
.68974 .42711 m
.6905 .44248 L
s
.416 .307 1 r
.3765 .42852 m
.37613 .43653 L
s
.37614 .43649 m
.3765 .42852 L
s
.3765 .42852 m
.37583 .44436 L
s
.916 .184 1 r
.91322 .44707 m
.91427 .45632 L
s
.91429 .45599 m
.91322 .44707 L
s
.868 .194 1 r
.33413 .44706 m
.33361 .45618 L
s
.33368 .45599 m
.33413 .44706 L
s
.916 .184 1 r
.91427 .45632 m
.91325 .44702 L
s
.91325 .44702 m
.91429 .45599 L
s
.868 .194 1 r
.33361 .45618 m
.33414 .44702 L
s
.33414 .44702 m
.33368 .45599 L
s
.485 .287 1 r
.50942 .42942 m
.50936 .43762 L
s
.50937 .43758 m
.50942 .42942 L
s
.50942 .42942 m
.50937 .44567 L
s
.589 .259 1 r
.92766 .45444 m
.92766 .45488 L
s
1 .161 .972 r
.72691 .39324 m
.72985 .4388 L
s
.476 .29 1 r
.43735 .39324 m
.43653 .43263 L
s
.7 .232 1 r
.38152 .44474 m
.38115 .45348 L
s
.38121 .4533 m
.38152 .44474 L
s
.38115 .45348 m
.38154 .4447 L
s
.38154 .4447 m
.38121 .4533 L
s
.638 .247 1 r
.90397 .45596 m
.90395 .45626 L
s
.628 .249 1 r
.77105 .45538 m
.77102 .45575 L
s
.45 .297 1 r
.68552 .45212 m
.68548 .45244 L
s
.54 .272 1 r
.34851 .4548 m
.34845 .45495 L
s
.344 .33 1 r
.26298 .45154 m
.26293 .4515 L
s
1 .163 .984 r
.6237 .44764 m
.62396 .45712 L
s
.62401 .45671 m
.6237 .44764 L
s
.917 .184 1 r
.937 .44634 m
.93812 .45563 L
s
.93812 .45518 m
.937 .44634 L
s
.811 .206 1 r
.67111 .44503 m
.67149 .4541 L
s
.67153 .45366 m
.67111 .44503 L
s
.669 .239 1 r
.69482 .44372 m
.69524 .45243 L
s
.69529 .45213 m
.69482 .44372 L
s
1 .163 .984 r
.62396 .45712 m
.62372 .4476 L
s
.62372 .4476 m
.62401 .45671 L
s
.448 .827 1 r
.58559 .44175 m
.58555 .44195 L
s
.917 .184 1 r
.93812 .45563 m
.93703 .44629 L
s
.93703 .44629 m
.93812 .45518 L
s
.836 .201 1 r
.8836 .39301 m
.88829 .4353 L
s
.467 .292 1 r
.59399 .39301 m
.59501 .43349 L
s
.846 .199 1 r
.30439 .39301 m
.30179 .43639 L
s
.811 .206 1 r
.67149 .4541 m
.67114 .44499 L
s
.67114 .44499 m
.67153 .45366 L
s
.669 .239 1 r
.69524 .45243 m
.69484 .44369 L
s
.69484 .44369 m
.69529 .45213 L
s
.788 .212 1 r
.22485 .44583 m
.22405 .45475 L
s
.22413 .4546 m
.22485 .44583 L
s
.376 .32 1 r
.92262 .4393 m
.92353 .44719 L
s
.92356 .44698 m
.92262 .4393 L
s
.788 .212 1 r
.22405 .45475 m
.22486 .44579 L
s
.22486 .44579 m
.22413 .4546 L
s
.46 .294 1 r
.71351 .4268 m
.71394 .43507 L
s
.71396 .43503 m
.71351 .4268 L
s
.71351 .4268 m
.71441 .44275 L
s
.376 .32 1 r
.92353 .44719 m
.92264 .43926 L
s
.92264 .43926 m
.92356 .44698 L
s
.362 .473 1 r
.85153 .44326 m
.85159 .44436 L
s
.846 .199 1 r
.77535 .43151 m
.77598 .44066 L
s
.77601 .44061 m
.77535 .43151 L
s
.77535 .43151 m
.77668 .44937 L
s
.441 .3 1 r
.47634 .44009 m
.47622 .44821 L
s
.47628 .44792 m
.47634 .44009 L
s
.352 .427 1 r
.81339 .43748 m
.81403 .44504 L
s
.81406 .44487 m
.81339 .43748 L
s
.441 .3 1 r
.47622 .44821 m
.47636 .44006 L
s
.47636 .44006 m
.47628 .44792 L
s
.352 .427 1 r
.81403 .44504 m
.81341 .43744 L
s
.81341 .43744 m
.81406 .44487 L
s
.68 .237 1 r
.56188 .4435 m
.56197 .45224 L
s
.56202 .45191 m
.56188 .4435 L
s
.559 .267 1 r
.53314 .42901 m
.53313 .43746 L
s
.53315 .43742 m
.53314 .42901 L
s
.53314 .42901 m
.5332 .44559 L
s
.649 .244 1 r
.75068 .39278 m
.75363 .43399 L
s
.345 .39 1 r
.46104 .39278 m
.46053 .42964 L
s
.68 .237 1 r
.56197 .45224 m
.5619 .44346 L
s
.5619 .44346 m
.56202 .45191 L
s
.811 .206 1 r
.88037 .45821 m
.88035 .45854 L
s
.37 .507 1 r
.82786 .44515 m
.82786 .44572 L
s
.929 .181 1 r
.90741 .39255 m
.91265 .43703 L
s
.342 .378 1 r
.61773 .39255 m
.61894 .43014 L
s
.658 .242 1 r
.32805 .39255 m
.3258 .43485 L
s
.392 .314 1 r
.60003 .44993 m
.59998 .45033 L
s
.869 .194 1 r
.64242 .43153 m
.6427 .44072 L
s
.64272 .44068 m
.64242 .43153 L
s
.64242 .43153 m
.64306 .44951 L
s
.892 .189 1 r
.32901 .43288 m
.32846 .44203 L
s
.32848 .44199 m
.32901 .43288 L
s
.32901 .43288 m
.328 .45104 L
s
.659 .242 1 r
.35272 .43157 m
.35226 .44014 L
s
.35228 .44011 m
.35272 .43157 L
s
.35272 .43157 m
.35187 .44879 L
s
.722 .226 1 r
.95582 .43027 m
.9569 .43912 L
s
.95693 .43908 m
.95582 .43027 L
s
.95582 .43027 m
.95802 .44762 L
s
.476 .29 1 r
.76603 .44096 m
.7666 .44911 L
s
.76664 .449 m
.76603 .44096 L
s
.94 .179 1 r
.4103 .46067 m
.41023 .46086 L
s
.766 .217 1 r
.32474 .45741 m
.32466 .4577 L
s
.476 .29 1 r
.7666 .44911 m
.76605 .44092 L
s
.76605 .44092 m
.76664 .449 L
s
.733 .224 1 r
.27218 .44436 m
.27152 .45318 L
s
.2716 .45299 m
.27218 .44436 L
s
.68 .237 1 r
.2959 .44306 m
.29531 .4518 L
s
.29539 .45147 m
.2959 .44306 L
s
.503 .282 1 r
.34334 .44044 m
.34289 .44874 L
s
.34296 .44842 m
.34334 .44044 L
s
.648 .244 1 r
.77446 .39232 m
.77773 .4339 L
s
.36 .325 1 r
.48475 .39232 m
.48449 .42992 L
s
.658 .242 1 r
.19503 .39232 m
.19112 .43463 L
s
.733 .224 1 r
.27152 .45318 m
.2722 .44432 L
s
.2722 .44432 m
.2716 .45299 L
s
.68 .237 1 r
.29531 .4518 m
.29592 .44302 L
s
.29592 .44302 m
.29539 .45147 L
s
.503 .282 1 r
.34289 .44874 m
.34335 .44041 L
s
.34335 .44041 m
.34296 .44842 L
s
.68 .237 1 r
.50516 .45566 m
.5051 .45599 L
s
.337 .353 1 r
.54749 .43732 m
.54753 .44507 L
s
.54758 .44479 m
.54749 .43732 L
s
.723 .226 1 r
.66189 .45508 m
.66186 .45567 L
s
.337 .353 1 r
.54753 .44507 m
.54751 .43729 L
s
.54751 .43729 m
.54758 .44479 L
s
.701 .232 1 r
.87535 .44335 m
.87625 .45213 L
s
.87627 .45183 m
.87535 .44335 L
s
.87625 .45213 m
.87538 .44331 L
s
.87538 .44331 m
.87627 .45183 L
s
.477 .289 1 r
.73731 .42692 m
.7378 .43519 L
s
.73782 .43516 m
.73731 .42692 L
s
.73731 .42692 m
.73834 .44303 L
s
.588 .259 1 r
.39587 .45392 m
.3958 .45425 L
s
.822 .204 1 r
.40517 .44545 m
.40484 .45445 L
s
.40491 .4543 m
.40517 .44545 L
s
.871 .193 1 r
.71864 .44414 m
.71916 .4534 L
s
.71918 .45277 m
.71864 .44414 L
s
.733 .224 1 r
.42889 .44414 m
.42863 .45296 L
s
.4287 .45277 m
.42889 .44414 L
s
.822 .204 1 r
.40484 .45445 m
.40518 .44541 L
s
.40518 .44541 m
.40491 .4543 L
s
.391 .315 1 r
.93123 .39209 m
.93601 .43041 L
s
.416 .307 1 r
.64148 .39209 m
.643 .43077 L
s
.579 .262 1 r
.35173 .39209 m
.34984 .43295 L
s
.733 .224 1 r
.42863 .45296 m
.4289 .4441 L
s
.4289 .4441 m
.4287 .45277 L
s
.871 .193 1 r
.71916 .4534 m
.71866 .4441 L
s
.71866 .4441 m
.71918 .45277 L
s
.355 .437 1 r
.86096 .4363 m
.86171 .44387 L
s
.86173 .44362 m
.86096 .4363 L
s
.639 .247 1 r
.21541 .45602 m
.21534 .4561 L
s
.355 .437 1 r
.86171 .44387 m
.86099 .43627 L
s
.86099 .43627 m
.86173 .44362 L
s
.648 .244 1 r
.31959 .44233 m
.31906 .451 L
s
.31914 .45066 m
.31959 .44233 L
s
.31906 .451 m
.3196 .44229 L
s
.3196 .44229 m
.31914 .45066 L
s
.467 .292 1 r
.44331 .4516 m
.44324 .45189 L
s
.362 .474 1 r
.59494 .43528 m
.59509 .44281 L
s
.59513 .44246 m
.59494 .43528 L
s
.788 .212 1 r
.66618 .43134 m
.66651 .44027 L
s
.66654 .44023 m
.66618 .43134 L
s
.66618 .43134 m
.66693 .44906 L
s
.904 .186 1 r
.30096 .45965 m
.30089 .45984 L
s
.54 .272 1 r
.42384 .42873 m
.42357 .43708 L
s
.42358 .43704 m
.42384 .42873 L
s
.42384 .42873 m
.42337 .44528 L
s
.362 .474 1 r
.59509 .44281 m
.59496 .43525 L
s
.59496 .43525 m
.59513 .44246 L
s
.94 .179 1 r
.79825 .39187 m
.80209 .43672 L
s
.618 .252 1 r
.50846 .39187 m
.50847 .43308 L
s
.833 .201 1 r
.21868 .39187 m
.21484 .43672 L
s
.357 .451 1 r
.5382 .44659 m
.53815 .44691 L
s
.522 .277 1 r
.57633 .45254 m
.57628 .45283 L
s
.418 .713 1 r
.21957 .43216 m
.21894 .43914 L
s
.21901 .43882 m
.21957 .43216 L
s
.21894 .43914 m
.21958 .43213 L
s
.21958 .43213 m
.21901 .43882 L
s
.69 .234 1 r
.40011 .43025 m
.39977 .43896 L
s
.39978 .43893 m
.40011 .43025 L
s
.40011 .43025 m
.3995 .44753 L
s
.965 .174 1 r
.24838 .44682 m
.24762 .45612 L
s
.24769 .45597 m
.24838 .44682 L
s
.756 .219 1 r
.60937 .4429 m
.60958 .45187 L
s
.60963 .45139 m
.60937 .4429 L
s
.965 .174 1 r
.24762 .45612 m
.24839 .44678 L
s
.24839 .44678 m
.24769 .45597 L
s
.756 .219 1 r
.60958 .45187 m
.60939 .44286 L
s
.60939 .44286 m
.60963 .45139 L
s
.7 .232 1 r
.37211 .45616 m
.37205 .45635 L
s
1 .118 .742 r
.70009 .46211 m
.70005 .46275 L
s
.733 .224 1 r
.26706 .42988 m
.26636 .43874 L
s
.26638 .4387 m
.26706 .42988 L
s
.26706 .42988 m
.26577 .44731 L
s
.4 .312 1 r
.78057 .44963 m
.78054 .44996 L
s
1 .164 .985 r
.66524 .39164 m
.66735 .43722 L
s
.711 .229 1 r
.37542 .39164 m
.37376 .43395 L
s
.342 .377 1 r
.51873 .42408 m
.5187 .43184 L
s
.51871 .4318 m
.51873 .42408 L
s
.51873 .42408 m
.51873 .43916 L
s
.648 .244 1 r
.55262 .45442 m
.55256 .45475 L
s
.766 .217 1 r
.84672 .4301 m
.84753 .43903 L
s
.84756 .43899 m
.84672 .4301 L
s
.84672 .4301 m
.8484 .44767 L
s
.618 .252 1 r
.41956 .45384 m
.41949 .45417 L
s
.551 .269 1 r
.7094 .45384 m
.70935 .45392 L
s
.522 .277 1 r
.23393 .44007 m
.23321 .44841 L
s
.23329 .44811 m
.23393 .44007 L
s
.541 .272 1 r
.76113 .42687 m
.76169 .43532 L
s
.76171 .43528 m
.76113 .42687 L
s
.76113 .42687 m
.76229 .4433 L
s
.522 .277 1 r
.23321 .44841 m
.23394 .44003 L
s
.23394 .44003 m
.23329 .44811 L
s
.701 .232 1 r
.23903 .45594 m
.23896 .45613 L
s
.822 .204 1 r
.82206 .39141 m
.82608 .43481 L
s
.845 .199 1 r
.53219 .39141 m
.5325 .43517 L
s
.659 .242 1 r
.24233 .39141 m
.23892 .43481 L
s
1 .126 .786 r
.4857 .43433 m
.48556 .44411 L
s
.48558 .44407 m
.4857 .43433 L
s
.4857 .43433 m
.48551 .45371 L
s
.845 .199 1 r
.74245 .44428 m
.74303 .45339 L
s
.74306 .45305 m
.74245 .44428 L
s
.559 .267 1 r
.52378 .44035 m
.52377 .4488 L
s
.52382 .44847 m
.52378 .44035 L
s
.733 .224 1 r
.79503 .45747 m
.79497 .45744 L
s
.352 .327 1 r
.3051 .43643 m
.30458 .44433 L
s
.30466 .4439 m
.3051 .43643 L
s
.845 .199 1 r
.74303 .45339 m
.74248 .44423 L
s
.74248 .44423 m
.74306 .45305 L
s
.711 .229 1 r
.58062 .42918 m
.58074 .43801 L
s
.58076 .43797 m
.58062 .42918 L
s
.58062 .42918 m
.58093 .4465 L
s
.559 .267 1 r
.52377 .4488 m
.5238 .44031 L
s
.5238 .44031 m
.52382 .44847 L
s
.352 .327 1 r
.30458 .44433 m
.30511 .4364 L
s
.30511 .4364 m
.30466 .4439 L
s
.477 .289 1 r
.49075 .45035 m
.49069 .45079 L
s
.649 .244 1 r
.60435 .42799 m
.60453 .4367 L
s
.60455 .43666 m
.60435 .42799 L
s
.60435 .42799 m
.60477 .44497 L
s
.375 .532 1 r
.83235 .42346 m
.83299 .43081 L
s
.83301 .43078 m
.83235 .42346 L
s
.83235 .42346 m
.83368 .43799 L
s
.459 .295 1 r
.25761 .43933 m
.25697 .44745 L
s
.25703 .44731 m
.25761 .43933 L
s
.4 .312 1 r
.68901 .39118 m
.69104 .42915 L
s
.701 .232 1 r
.39911 .39118 m
.39775 .4335 L
s
.88 .191 1 r
.82306 .43212 m
.82382 .4412 L
s
.82384 .44116 m
.82306 .43212 L
s
.82306 .43212 m
.82466 .45029 L
s
.459 .295 1 r
.25697 .44745 m
.25763 .4393 L
s
.25763 .4393 m
.25703 .44731 L
s
.591 .259 1 r
.78492 .42624 m
.78555 .43487 L
s
.78557 .43484 m
.78492 .42624 L
s
.78492 .42624 m
.78621 .44286 L
s
.8 .209 1 r
.29073 .42954 m
.29008 .43858 L
s
.2901 .43854 m
.29073 .42954 L
s
.29073 .42954 m
.28954 .44723 L
s
.521 .277 1 r
.47127 .42759 m
.47111 .4359 L
s
.47113 .43586 m
.47127 .42759 L
s
.47127 .42759 m
.47103 .44403 L
s
.552 .269 1 r
.70434 .43882 m
.70478 .44734 L
s
.7048 .44672 m
.70434 .43882 L
s
.541 .272 1 r
.86626 .45398 m
.8662 .45391 L
s
.953 .176 1 r
.24325 .43222 m
.24246 .44149 L
s
.24248 .44145 m
.24325 .43222 L
s
.24325 .43222 m
.24176 .45065 L
s
.552 .269 1 r
.70478 .44734 m
.70436 .43879 L
s
.70436 .43879 m
.7048 .44672 L
s
.868 .194 1 r
.45257 .44485 m
.45237 .45397 L
s
.45244 .45378 m
.45257 .44485 L
s
.766 .217 1 r
.52889 .45666 m
.52883 .45685 L
s
.648 .244 1 r
.78996 .44224 m
.79062 .45084 L
s
.79067 .45072 m
.78996 .44224 L
s
.868 .194 1 r
.45237 .45397 m
.45259 .44481 L
s
.45259 .44481 m
.45244 .45378 L
s
.648 .244 1 r
.79062 .45084 m
.78998 .4422 L
s
.78998 .4422 m
.79067 .45072 L
s
.569 .264 1 r
.91803 .42718 m
.91898 .43567 L
s
.919 .43564 m
.91803 .42718 L
s
.91803 .42718 m
.91996 .44381 L
s
.559 .267 1 r
.33817 .42722 m
.33768 .43567 L
s
.3377 .43564 m
.33817 .42722 L
s
.33817 .42722 m
.33729 .4438 L
s
.613 .253 1 r
.7281 .43781 m
.72862 .44662 L
s
.72861 .44556 m
.7281 .43781 L
s
.495 .284 1 r
.84587 .39095 m
.8498 .43037 L
s
.777 .214 1 r
.55594 .39095 m
.55654 .434 L
s
.476 .29 1 r
.266 .39095 m
.26313 .43109 L
s
.613 .253 1 r
.72862 .44662 m
.72812 .43777 L
s
.72812 .43777 m
.72861 .44556 L
s
.629 .249 1 r
.83746 .43991 m
.83826 .44861 L
s
.83826 .44803 m
.83746 .43991 L
s
.83826 .44861 m
.83749 .43987 L
s
.83749 .43987 m
.83826 .44803 L
s
.881 .191 1 r
.89937 .44463 m
.90036 .45378 L
s
.9004 .45355 m
.89937 .44463 L
s
.425 .305 1 r
.22879 .42547 m
.22806 .43356 L
s
.22807 .43353 m
.22879 .42547 L
s
.22879 .42547 m
.22743 .44133 L
s
.569 .264 1 r
.39067 .44071 m
.39033 .44912 L
s
.39039 .44897 m
.39067 .44071 L
s
.881 .191 1 r
.90036 .45378 m
.89939 .44459 L
s
.89939 .44459 m
.9004 .45355 L
s
.569 .264 1 r
.39033 .44912 m
.39069 .44067 L
s
.39069 .44067 m
.39039 .44897 L
s
.388 .587 1 r
.63317 .44337 m
.63313 .44369 L
s
.755 .219 1 r
.89434 .42892 m
.89528 .43785 L
s
.89531 .43781 m
.89434 .42892 L
s
.89434 .42892 m
.89626 .44642 L
s
1 .161 .972 r
.55691 .43156 m
.55697 .44105 L
s
.55699 .441 m
.55691 .43156 L
s
.55691 .43156 m
.55711 .45021 L
s
.701 .232 1 r
.21007 .44281 m
.20926 .45153 L
s
.20933 .45145 m
.21007 .44281 L
s
.522 .277 1 r
.7128 .39072 m
.71522 .43087 L
s
.701 .232 1 r
.20926 .45153 m
.21009 .44277 L
s
.21009 .44277 m
.20933 .45145 L
s
.618 .252 1 r
.42282 .39072 m
.42179 .43195 L
s
.359 .46 1 r
.45684 .42115 m
.45667 .42883 L
s
.45668 .4288 m
.45684 .42115 L
s
.45684 .42115 m
.45657 .4358 L
s
1 .154 .933 r
.48142 .46007 m
.48135 .46041 L
s
.512 .279 1 r
.4144 .43969 m
.41412 .44795 L
s
.41418 .44781 m
.4144 .43969 L
s
.425 .304 1 r
.75187 .43707 m
.7524 .44519 L
s
.75242 .44475 m
.75187 .43707 L
s
.512 .279 1 r
.41412 .44795 m
.41441 .43965 L
s
.41441 .43965 m
.41418 .44781 L
s
.562 .266 1 r
.80447 .45027 m
.80447 .45093 L
s
.425 .304 1 r
.7524 .44519 m
.75189 .43703 L
s
.75189 .43703 m
.75242 .44475 L
s
.733 .224 1 r
.31439 .42931 m
.31382 .43814 L
s
.31384 .4381 m
.31439 .42931 L
s
.31439 .42931 m
.31334 .44678 L
s
.425 .305 1 r
.46188 .43736 m
.46172 .44544 L
s
.46178 .44511 m
.46188 .43736 L
s
.765 .217 1 r
.8697 .3905 m
.87433 .43391 L
s
.418 .713 1 r
.57969 .39049 m
.58039 .4234 L
s
.712 .229 1 r
.28968 .39049 m
.28698 .43246 L
s
.658 .242 1 r
.73326 .45448 m
.73321 .45463 L
s
.531 .274 1 r
.64761 .45121 m
.64757 .45154 L
s
.425 .305 1 r
.46172 .44544 m
.46189 .43732 L
s
.46189 .43732 m
.46178 .44511 L
s
.55 .269 1 r
.57127 .43946 m
.57138 .44788 L
s
.57143 .44759 m
.57127 .43946 L
s
.467 .292 1 r
.28124 .43946 m
.28066 .44755 L
s
.28071 .44759 m
.28124 .43946 L
s
.55 .269 1 r
.57138 .44788 m
.57129 .43943 L
s
.57129 .43943 m
.57143 .44759 L
s
.467 .292 1 r
.28066 .44755 m
.28126 .43943 L
s
.28126 .43943 m
.28071 .44759 L
s
.904 .186 1 r
.44752 .43028 m
.44728 .43951 L
s
.4473 .43947 m
.44752 .43028 L
s
.44752 .43028 m
.44713 .44845 L
s
.588 .259 1 r
.36186 .42698 m
.36143 .43551 L
s
.36144 .43548 m
.36186 .42698 L
s
.36186 .42698 m
.36108 .44372 L
s
.352 .327 1 r
.25245 .42503 m
.25181 .43283 L
s
.25182 .43279 m
.25245 .42503 L
s
.25245 .42503 m
.25124 .44052 L
s
.765 .217 1 r
.3669 .44288 m
.36648 .45177 L
s
.36655 .45158 m
.3669 .44288 L
s
.744 .221 1 r
.28636 .45542 m
.28628 .45565 L
s
.765 .217 1 r
.36648 .45177 m
.36691 .44284 L
s
.36691 .44284 m
.36655 .45158 L
s
.588 .259 1 r
.2007 .45215 m
.20061 .45248 L
s
.822 .204 1 r
.50004 .44368 m
.49996 .45268 L
s
.50002 .45253 m
.50004 .44368 L
s
.744 .222 1 r
.62815 .4285 m
.62839 .4374 L
s
.62841 .43736 m
.62815 .4285 L
s
.62815 .4285 m
.6287 .44597 L
s
.68 .237 1 r
.495 .42785 m
.4949 .4366 L
s
.49492 .43656 m
.495 .42785 L
s
.495 .42785 m
.49487 .44503 L
s
.822 .204 1 r
.49996 .45268 m
.50006 .44364 L
s
.50006 .44364 m
.50002 .45253 L
s
.559 .267 1 r
.73659 .39027 m
.73933 .43078 L
s
.383 .317 1 r
.44655 .39027 m
.44586 .42824 L
s
.531 .274 1 r
.51448 .45099 m
.51442 .45132 L
s
.777 .214 1 r
.65693 .44317 m
.65727 .45206 L
s
.65732 .45195 m
.65693 .44317 L
s
.845 .199 1 r
.94699 .44317 m
.94811 .45228 L
s
.94813 .45195 m
.94699 .44317 L
s
.777 .214 1 r
.68069 .44186 m
.68109 .45086 L
s
.68113 .45042 m
.68069 .44186 L
s
.712 .229 1 r
.75704 .45368 m
.75702 .45412 L
s
.589 .259 1 r
.43812 .43924 m
.4379 .4478 L
s
.43797 .44736 m
.43812 .43924 L
s
.522 .277 1 r
.96144 .45041 m
.96143 .45081 L
s
.777 .214 1 r
.65727 .45206 m
.65696 .44313 L
s
.65696 .44313 m
.65732 .45195 L
s
.845 .199 1 r
.94811 .45228 m
.94702 .44313 L
s
.94702 .44313 m
.94813 .45195 L
s
.777 .214 1 r
.68109 .45086 m
.68071 .44182 L
s
.68071 .44182 m
.68113 .45042 L
s
.589 .259 1 r
.4379 .4478 m
.43814 .4392 L
s
.43814 .4392 m
.43797 .44736 L
s
.477 .289 1 r
.61878 .43742 m
.619 .44569 L
s
.61904 .44525 m
.61878 .43742 L
s
.619 .44569 m
.6188 .43739 L
s
.6188 .43739 m
.61904 .44525 L
s
1 .146 .894 r
.87075 .43154 m
.87169 .44118 L
s
.87172 .44114 m
.87075 .43154 L
s
.87075 .43154 m
.87269 .45049 L
s
.969 .173 1 r
.89354 .39004 m
.89849 .43346 L
s
.339 .362 1 r
.60346 .39004 m
.60446 .42548 L
s
.503 .282 1 r
.31337 .39004 m
.31108 .42982 L
s
.569 .264 1 r
.35755 .45229 m
.35748 .45244 L
s
.34 .366 1 r
.69941 .42531 m
.69977 .43289 L
s
.69979 .43286 m
.69941 .42531 L
s
.69941 .42531 m
.70021 .44066 L
s
.722 .227 1 r
.20488 .42867 m
.20404 .43747 L
s
.20405 .43743 m
.20488 .42867 L
s
.20488 .42867 m
.20327 .44611 L
s
.56 .267 1 r
.7604 .38981 m
.7634 .42996 L
s
.669 .239 1 r
.47028 .38981 m
.46981 .43178 L
s
.408 .31 1 r
.18016 .38981 m
.17638 .42887 L
s
.618 .252 1 r
.5425 .4262 m
.54252 .43484 L
s
.54254 .43481 m
.5425 .4262 L
s
.5425 .4262 m
.54261 .44305 L
s
.433 .302 1 r
.19547 .43749 m
.19469 .44554 L
s
.19476 .44539 m
.19547 .43749 L
s
.19469 .44554 m
.19549 .43745 L
s
.19549 .43745 m
.19476 .44539 L
s
.375 .32 1 r
.29986 .4237 m
.29932 .43164 L
s
.29933 .43161 m
.29986 .4237 L
s
.29986 .4237 m
.29886 .43927 L
s
.559 .267 1 r
.88518 .43959 m
.88606 .44798 L
s
.8861 .44787 m
.88518 .43959 L
s
.811 .206 1 r
.46698 .45476 m
.46691 .4552 L
s
.559 .267 1 r
.88606 .44798 m
.88521 .43956 L
s
.88521 .43956 m
.8861 .44787 L
s
.766 .217 1 r
.91739 .38958 m
.92259 .43264 L
s
1 .159 .96 r
.62723 .38958 m
.62886 .43591 L
s
.56 .267 1 r
.33708 .38958 m
.33505 .42974 L
s
.744 .222 1 r
.38554 .42761 m
.38515 .43651 L
s
.38516 .43647 m
.38554 .42761 L
s
.38554 .42761 m
.38485 .44508 L
s
.344 .33 1 r
.69009 .43494 m
.69046 .44276 L
s
.6905 .44248 m
.69009 .43494 L
s
1 .161 .972 r
.78422 .38935 m
.78794 .43496 L
s
.375 .32 1 r
.49403 .38935 m
.49387 .42733 L
s
.367 .322 1 r
.20384 .38935 m
.20039 .42769 L
s
.88 .191 1 r
.30999 .45607 m
.30991 .4564 L
s
.881 .191 1 r
.89039 .45607 m
.89036 .4564 L
s
.344 .33 1 r
.69046 .44276 m
.69011 .4349 L
s
.69011 .4349 m
.6905 .44248 L
s
.579 .262 1 r
.85648 .4259 m
.85727 .4344 L
s
.8573 .43436 m
.85648 .4259 L
s
.85648 .4259 m
.85812 .44261 L
s
.467 .292 1 r
.88023 .42459 m
.88106 .4328 L
s
.88108 .43276 m
.88023 .42459 L
s
.88023 .42459 m
.88193 .44071 L
s
.56 .267 1 r
.9328 .43784 m
.93382 .44633 L
s
.93382 .44589 m
.9328 .43784 L
s
.416 .307 1 r
.37613 .43653 m
.37577 .44454 L
s
.37583 .44436 m
.37613 .43653 L
s
.56 .267 1 r
.93382 .44633 m
.93283 .4378 L
s
.93283 .4378 m
.93382 .44589 L
s
.416 .307 1 r
.37577 .44454 m
.37614 .43649 L
s
.37614 .43649 m
.37583 .44436 L
s
.522 .277 1 r
.59003 .4247 m
.59016 .43308 L
s
.59018 .43305 m
.59003 .4247 L
s
.59003 .4247 m
.59036 .44107 L
s
.57 .264 1 r
.79959 .43733 m
.80028 .44589 L
s
.80028 .44531 m
.79959 .43733 L
s
.869 .194 1 r
.80898 .42873 m
.80971 .43789 L
s
.80974 .43785 m
.80898 .42873 L
s
.80898 .42873 m
.8105 .44676 L
s
.367 .495 1 r
.94125 .38912 m
.9457 .42385 L
s
.79 .211 1 r
.65102 .38912 m
.65283 .43182 L
s
.904 .186 1 r
.36079 .38912 m
.35885 .43364 L
s
.57 .264 1 r
.80028 .44589 m
.79962 .43729 L
s
.79962 .43729 m
.80028 .44531 L
s
1 .126 .786 r
.81917 .46064 m
.81913 .46095 L
s
.485 .287 1 r
.50936 .43762 m
.50931 .44582 L
s
.50937 .44567 m
.50936 .43762 L
s
.352 .427 1 r
.81406 .44487 m
.81403 .44504 L
s
.485 .287 1 r
.50931 .44582 m
.50937 .43758 L
s
.50937 .43758 m
.50937 .44567 L
s
.68 .237 1 r
.56628 .42651 m
.56636 .43526 L
s
.56638 .43522 m
.56628 .42651 L
s
.56628 .42651 m
.56651 .44369 L
s
.376 .32 1 r
.92356 .44698 m
.92353 .44719 L
s
.434 .302 1 r
.80806 .38889 m
.81146 .42724 L
s
.477 .289 1 r
.51779 .38889 m
.5179 .42833 L
s
.57 .264 1 r
.22752 .38889 m
.2242 .42905 L
s
.977 .171 1 r
.94228 .42992 m
.94339 .43926 L
s
.94342 .43922 m
.94228 .42992 L
s
.94228 .42992 m
.94457 .44843 L
s
1 .156 .946 r
.65202 .43002 m
.65234 .43955 L
s
.65236 .43951 m
.65202 .43002 L
s
.65202 .43002 m
.65274 .44879 L
s
.441 .3 1 r
.47628 .44792 m
.47622 .44821 L
s
.7 .232 1 r
.38121 .4533 m
.38115 .45348 L
s
.811 .206 1 r
.40926 .42759 m
.40892 .43664 L
s
.40894 .4366 m
.40926 .42759 L
s
.40926 .42759 m
.40868 .44536 L
s
.916 .184 1 r
.91429 .45599 m
.91427 .45632 L
s
.868 .194 1 r
.33368 .45599 m
.33361 .45618 L
s
.712 .229 1 r
.67483 .38866 m
.67689 .43064 L
s
.811 .206 1 r
.38452 .38866 m
.38293 .4321 L
s
.669 .239 1 r
.69529 .45213 m
.69524 .45243 L
s
.46 .294 1 r
.71394 .43507 m
.71439 .44333 L
s
.71441 .44275 m
.71394 .43507 L
s
.71439 .44333 m
.71396 .43503 L
s
.71396 .43503 m
.71441 .44275 L
s
.811 .206 1 r
.67153 .45366 m
.67149 .4541 L
s
.928 .181 1 r
.6758 .42929 m
.67618 .43853 L
s
.67621 .43849 m
.6758 .42929 L
s
.6758 .42929 m
.67664 .44762 L
s
.734 .224 1 r
.8319 .38843 m
.83595 .43078 L
s
.559 .267 1 r
.54156 .38843 m
.54196 .42896 L
s
.569 .264 1 r
.25122 .38843 m
.24808 .42969 L
s
.917 .184 1 r
.93812 .45518 m
.93812 .45563 L
s
.68 .237 1 r
.56202 .45191 m
.56197 .45224 L
s
.559 .267 1 r
.53313 .43746 m
.53314 .44591 L
s
.5332 .44559 m
.53313 .43746 L
s
.754 .219 1 r
.27594 .42754 m
.27527 .43641 L
s
.27529 .43637 m
.27594 .42754 L
s
.27594 .42754 m
.27468 .44514 L
s
.788 .212 1 r
.22413 .4546 m
.22405 .45475 L
s
.559 .267 1 r
.53314 .44591 m
.53315 .43742 L
s
.53315 .43742 m
.5332 .44559 L
s
.418 .713 1 r
.21901 .43882 m
.21894 .43914 L
s
.337 .353 1 r
.54758 .44479 m
.54753 .44507 L
s
1 .163 .984 r
.62401 .45671 m
.62396 .45712 L
s
.355 .437 1 r
.86173 .44362 m
.86171 .44387 L
s
.68 .237 1 r
.69864 .3882 m
.70098 .42983 L
s
.424 .305 1 r
.40826 .3882 m
.40712 .42692 L
s
.476 .29 1 r
.76664 .449 m
.7666 .44911 L
s
.362 .474 1 r
.59513 .44246 m
.59509 .44281 L
s
.503 .282 1 r
.34296 .44842 m
.34289 .44874 L
s
.846 .199 1 r
.77598 .44066 m
.77665 .44981 L
s
.77668 .44937 m
.77598 .44066 L
s
.77665 .44981 m
.77601 .44061 L
s
.77601 .44061 m
.77668 .44937 L
s
.658 .242 1 r
.74717 .42623 m
.7477 .43488 L
s
.74773 .43484 m
.74717 .42623 L
s
.74717 .42623 m
.74831 .44338 L
s
.659 .242 1 r
.35226 .44014 m
.35182 .44872 L
s
.35187 .44879 m
.35226 .44014 L
s
.618 .252 1 r
.77095 .42495 m
.77154 .43356 L
s
.77156 .43353 m
.77095 .42495 L
s
.77095 .42495 m
.77219 .44185 L
s
.724 .226 1 r
.85576 .38798 m
.86008 .42996 L
s
.608 .254 1 r
.56534 .38798 m
.56604 .42924 L
s
.659 .242 1 r
.35182 .44872 m
.35228 .44011 L
s
.35228 .44011 m
.35187 .44879 L
s
.34 .366 1 r
.27493 .38798 m
.27233 .42561 L
s
.68 .237 1 r
.29539 .45147 m
.29531 .4518 L
s
.722 .226 1 r
.9569 .43912 m
.95802 .44799 L
s
.95802 .44762 m
.9569 .43912 L
s
.477 .289 1 r
.7378 .43519 m
.73831 .44346 L
s
.73834 .44303 m
.7378 .43519 L
s
.733 .224 1 r
.2716 .45299 m
.27152 .45318 L
s
.722 .226 1 r
.95802 .44799 m
.95693 .43908 L
s
.95693 .43908 m
.95802 .44762 L
s
.965 .174 1 r
.72343 .42796 m
.72394 .43735 L
s
.72397 .4373 m
.72343 .42796 L
s
.72343 .42796 m
.72452 .44637 L
s
.608 .254 1 r
.19009 .42531 m
.18923 .43385 L
s
.18924 .43381 m
.19009 .42531 L
s
.19009 .42531 m
.18846 .44221 L
s
.477 .289 1 r
.73831 .44346 m
.73782 .43516 L
s
.73782 .43516 m
.73834 .44303 L
s
.494 .285 1 r
.21386 .42401 m
.21309 .43225 L
s
.2131 .43221 m
.21386 .42401 L
s
.21386 .42401 m
.2124 .44031 L
s
.701 .232 1 r
.87627 .45183 m
.87625 .45213 L
s
.669 .239 1 r
.72247 .38775 m
.72512 .42974 L
s
.363 .474 1 r
.43201 .38775 m
.43119 .4243 L
s
.892 .189 1 r
.32846 .44203 m
.32792 .45119 L
s
.328 .45104 m
.32846 .44203 L
s
.869 .194 1 r
.6427 .44072 m
.64301 .44992 L
s
.64306 .44951 m
.6427 .44072 L
s
.4 .312 1 r
.55187 .42157 m
.5519 .42963 L
s
.55192 .42959 m
.55187 .42157 L
s
.55187 .42157 m
.55201 .43725 L
s
.892 .189 1 r
.32792 .45119 m
.32848 .44199 L
s
.32848 .44199 m
.328 .45104 L
s
.869 .194 1 r
.64301 .44992 m
.64272 .44068 L
s
.64272 .44068 m
.64306 .44951 L
s
.648 .244 1 r
.31914 .45066 m
.31906 .451 L
s
.335 .34 1 r
.41852 .42102 m
.41825 .42882 L
s
.41827 .42879 m
.41852 .42102 L
s
.41852 .42102 m
.41806 .4363 L
s
.744 .221 1 r
.32341 .42635 m
.32286 .43523 L
s
.32287 .43519 m
.32341 .42635 L
s
.32341 .42635 m
.3224 .44388 L
s
.871 .193 1 r
.71918 .45277 m
.71916 .4534 L
s
.733 .224 1 r
.4287 .45277 m
.42863 .45296 L
s
.669 .239 1 r
.48053 .42574 m
.48039 .43443 L
s
.48041 .43439 m
.48053 .42574 L
s
.48053 .42574 m
.48033 .44293 L
s
.722 .227 1 r
.90436 .42643 m
.9053 .43523 L
s
.90533 .43519 m
.90436 .42643 L
s
.90436 .42643 m
.90632 .44388 L
s
.54 .272 1 r
.42357 .43708 m
.42331 .44543 L
s
.42337 .44528 m
.42357 .43708 L
s
.88 .191 1 r
.87963 .38752 m
.88448 .43169 L
s
.4 .312 1 r
.58914 .38752 m
.59006 .42588 L
s
.68 .237 1 r
.29865 .38752 m
.29608 .42915 L
s
.342 .377 1 r
.5187 .43184 m
.51867 .43959 L
s
.51873 .43916 m
.5187 .43184 L
s
.54 .272 1 r
.42331 .44543 m
.42358 .43704 L
s
.42358 .43704 m
.42337 .44528 L
s
.881 .191 1 r
.61389 .42657 m
.6141 .43581 L
s
.61412 .43577 m
.61389 .42657 L
s
.61389 .42657 m
.61439 .44461 L
s
.822 .204 1 r
.40491 .4543 m
.40484 .45445 L
s
.342 .377 1 r
.51867 .43959 m
.51871 .4318 L
s
.51871 .4318 m
.51873 .43916 L
s
.352 .327 1 r
.30466 .4439 m
.30458 .44433 L
s
.375 .532 1 r
.83299 .43081 m
.83365 .43817 L
s
.83368 .43799 m
.83299 .43081 L
s
.83365 .43817 m
.83301 .43078 L
s
.83301 .43078 m
.83368 .43799 L
s
.503 .282 1 r
.68525 .42297 m
.68561 .43129 L
s
.68563 .43125 m
.68525 .42297 L
s
.68525 .42297 m
.68603 .43928 L
s
.733 .224 1 r
.34716 .42562 m
.34667 .43449 L
s
.34669 .43445 m
.34716 .42562 L
s
.34716 .42562 m
.34627 .44307 L
s
.66 .241 1 r
.7463 .38729 m
.74921 .42856 L
s
.494 .284 1 r
.45578 .38729 m
.45516 .42711 L
s
.756 .219 1 r
.60963 .45139 m
.60958 .45187 L
s
.522 .277 1 r
.23329 .44811 m
.23321 .44841 L
s
.811 .206 1 r
.63769 .42569 m
.63796 .43478 L
s
.63798 .43474 m
.63769 .42569 L
s
.63769 .42569 m
.6383 .44344 L
s
.788 .212 1 r
.66651 .44027 m
.66688 .44922 L
s
.66693 .44906 m
.66651 .44027 L
s
.69 .234 1 r
.39977 .43896 m
.39944 .44768 L
s
.3995 .44753 m
.39977 .43896 L
s
.788 .212 1 r
.66688 .44922 m
.66654 .44023 L
s
.66654 .44023 m
.66693 .44906 L
s
.69 .234 1 r
.39944 .44768 m
.39978 .43893 L
s
.39978 .43893 m
.3995 .44753 L
s
.711 .229 1 r
.50431 .42515 m
.50423 .43398 L
s
.50425 .43394 m
.50431 .42515 L
s
.50431 .42515 m
.50423 .44249 L
s
1 .151 .921 r
.43295 .42925 m
.43267 .43879 L
s
.43269 .43875 m
.43295 .42925 L
s
.43295 .42925 m
.43247 .44818 L
s
.559 .267 1 r
.52382 .44847 m
.52377 .4488 L
s
.541 .272 1 r
.76169 .43532 m
.76227 .44378 L
s
.76229 .4433 m
.76169 .43532 L
s
.712 .229 1 r
.90351 .38706 m
.90842 .42906 L
s
.648 .244 1 r
.61295 .38706 m
.61424 .42869 L
s
.68 .237 1 r
.32238 .38706 m
.32008 .42906 L
s
.541 .272 1 r
.76227 .44378 m
.76171 .43528 L
s
.76171 .43528 m
.76229 .4433 L
s
.733 .224 1 r
.26636 .43874 m
.26568 .44761 L
s
.26577 .44731 m
.26636 .43874 L
s
.459 .295 1 r
.25703 .44731 m
.25697 .44745 L
s
.733 .224 1 r
.26568 .44761 m
.26638 .4387 L
s
.26638 .4387 m
.26577 .44731 L
s
.965 .174 1 r
.24769 .45597 m
.24762 .45612 L
s
.552 .269 1 r
.7048 .44672 m
.70478 .44734 L
s
.613 .253 1 r
.72861 .44556 m
.72862 .44662 L
s
.766 .217 1 r
.84753 .43903 m
.84837 .44797 L
s
.8484 .44767 m
.84753 .43903 L
s
.579 .262 1 r
.52809 .42452 m
.52807 .43296 L
s
.52809 .43292 m
.52809 .42452 L
s
.52809 .42452 m
.52813 .44132 L
s
1 .116 .73 r
.77016 .38683 m
.77383 .43429 L
s
.522 .277 1 r
.47956 .38683 m
.47921 .42701 L
s
.608 .254 1 r
.18895 .38683 m
.18499 .42883 L
s
.766 .217 1 r
.84837 .44797 m
.84756 .43899 L
s
.84756 .43899 m
.8484 .44767 L
s
.36 .324 1 r
.46606 .41997 m
.4659 .42792 L
s
.46592 .42789 m
.46606 .41997 L
s
.46606 .41997 m
.46582 .43541 L
s
.521 .277 1 r
.47111 .4359 m
.47097 .44421 L
s
.47103 .44403 m
.47111 .4359 L
s
.26128 .42332 m
.26061 .43164 L
s
.26062 .4316 m
.26128 .42332 L
s
.26128 .42332 m
.26003 .43978 L
s
.845 .199 1 r
.74306 .45305 m
.74303 .45339 L
s
.777 .214 1 r
.3709 .42535 m
.37047 .43433 L
s
.37049 .43429 m
.3709 .42535 L
s
.3709 .42535 m
.37013 .44299 L
s
.521 .277 1 r
.47097 .44421 m
.47113 .43586 L
s
.47113 .43586 m
.47103 .44403 L
s
.711 .229 1 r
.58074 .43801 m
.58087 .44684 L
s
.58093 .4465 m
.58074 .43801 L
s
.649 .244 1 r
.60453 .4367 m
.60473 .44541 L
s
.60477 .44497 m
.60453 .4367 L
s
.711 .229 1 r
.58087 .44684 m
.58076 .43797 L
s
.58076 .43797 m
.58093 .4465 L
s
.359 .46 1 r
.45667 .42883 m
.4565 .43651 L
s
.45657 .4358 m
.45667 .42883 L
s
.649 .244 1 r
.60473 .44541 m
.60455 .43666 L
s
.60455 .43666 m
.60477 .44497 L
s
.359 .46 1 r
.4565 .43651 m
.45668 .4288 L
s
.45668 .4288 m
.45657 .4358 L
s
.629 .249 1 r
.83826 .44803 m
.83826 .44861 L
s
.591 .259 1 r
.78555 .43487 m
.7862 .44352 L
s
.78621 .44286 m
.78555 .43487 L
s
.425 .305 1 r
.22806 .43356 m
.22735 .44165 L
s
.22743 .44133 m
.22806 .43356 L
s
.425 .304 1 r
.75242 .44475 m
.7524 .44519 L
s
.744 .222 1 r
.9274 .3866 m
.9327 .42933 L
s
.648 .244 1 r
.79067 .45072 m
.79062 .45084 L
s
.857 .196 1 r
.63677 .3866 m
.63845 .43115 L
s
.711 .229 1 r
.34613 .3866 m
.3441 .42897 L
s
.591 .259 1 r
.7862 .44352 m
.78557 .43484 L
s
.78557 .43484 m
.78621 .44286 L
s
.425 .305 1 r
.22735 .44165 m
.22807 .43353 L
s
.22807 .43353 m
.22743 .44133 L
s
.56 .267 1 r
.86633 .4224 m
.86715 .43091 L
s
.86718 .43087 m
.86633 .4224 L
s
.86633 .4224 m
.86801 .43897 L
s
.569 .264 1 r
.91898 .43567 m
.91995 .44417 L
s
.91996 .44381 m
.91898 .43567 L
s
.559 .267 1 r
.33768 .43567 m
.33721 .44413 L
s
.33729 .4438 m
.33768 .43567 L
s
.569 .264 1 r
.91995 .44417 m
.919 .43564 L
s
.919 .43564 m
.91996 .44381 L
s
.559 .267 1 r
.33721 .44413 m
.3377 .43564 L
s
.3377 .43564 m
.33729 .4438 L
s
.569 .264 1 r
.39039 .44897 m
.39033 .44912 L
s
.799 .209 1 r
.66154 .42593 m
.66187 .43491 L
s
.66189 .43487 m
.66154 .42593 L
s
.66154 .42593 m
.66227 .44371 L
s
.88 .191 1 r
.82382 .4412 m
.82461 .4503 L
s
.82466 .45029 m
.82382 .4412 L
s
.425 .305 1 r
.46178 .44511 m
.46172 .44544 L
s
.953 .176 1 r
.79498 .42665 m
.79569 .436 L
s
.79571 .43596 m
.79498 .42665 L
s
.79498 .42665 m
.79646 .44502 L
s
.8 .209 1 r
.29008 .43858 m
.28945 .44763 L
s
.28954 .44723 m
.29008 .43858 L
s
.512 .279 1 r
.41418 .44781 m
.41412 .44795 L
s
.868 .194 1 r
.45244 .45378 m
.45237 .45397 L
s
.733 .224 1 r
.39467 .42473 m
.3943 .4336 L
s
.39432 .43356 m
.39467 .42473 L
s
.39467 .42473 m
.39403 .44218 L
s
.88 .191 1 r
.82461 .4503 m
.82384 .44116 L
s
.82384 .44116 m
.82466 .45029 L
s
.754 .219 1 r
.79402 .38637 m
.79768 .42983 L
s
.337 .353 1 r
.50334 .38637 m
.50329 .42402 L
s
.766 .216 1 r
.21267 .38637 m
.2089 .42947 L
s
.8 .209 1 r
.28945 .44763 m
.2901 .43854 L
s
.2901 .43854 m
.28954 .44723 L
s
.869 .194 1 r
.81879 .42548 m
.81955 .43469 L
s
.81958 .43464 m
.81879 .42548 L
s
.81879 .42548 m
.82037 .44349 L
s
.352 .327 1 r
.25181 .43283 m
.25117 .44063 L
s
.25124 .44052 m
.25181 .43283 L
s
1 .126 .786 r
.48556 .44411 m
.48544 .45391 L
s
.48551 .45371 m
.48556 .44411 L
s
.953 .176 1 r
.24246 .44149 m
.24168 .45077 L
s
.24176 .45065 m
.24246 .44149 L
s
.352 .327 1 r
.25117 .44063 m
.25182 .43279 L
s
.25182 .43279 m
.25124 .44052 L
s
1 .126 .786 r
.48544 .45391 m
.48558 .44407 L
s
.48558 .44407 m
.48551 .45371 L
s
.953 .176 1 r
.24168 .45077 m
.24248 .44145 L
s
.24248 .44145 m
.24176 .45065 L
s
.8 .209 1 r
.92845 .42767 m
.92946 .43651 L
s
.92949 .43647 m
.92845 .42767 L
s
.92845 .42767 m
.93059 .44561 L
s
.701 .232 1 r
.20933 .45145 m
.20926 .45153 L
s
.36 .462 1 r
.35639 .41916 m
.35599 .42667 L
s
.35601 .42664 m
.35639 .41916 L
s
.35639 .41916 m
.35567 .43401 L
s
.467 .292 1 r
.28071 .44759 m
.28066 .44755 L
s
.55 .269 1 r
.57143 .44759 m
.57138 .44788 L
s
.881 .191 1 r
.9004 .45355 m
.90036 .45378 L
s
.504 .282 1 r
.6606 .38614 m
.66238 .42561 L
s
.45 .297 1 r
.36989 .38614 m
.36829 .42524 L
s
.599 .257 1 r
.57571 .42322 m
.57581 .43177 L
s
.57583 .43173 m
.57571 .42322 L
s
.57571 .42322 m
.57598 .44005 L
s
.755 .219 1 r
.89528 .43785 m
.89624 .44679 L
s
.89626 .44642 m
.89528 .43785 L
s
.81 .206 1 r
.23738 .42599 m
.2366 .43498 L
s
.23662 .43494 m
.23738 .42599 L
s
.23738 .42599 m
.2359 .44385 L
s
.755 .219 1 r
.89624 .44679 m
.89531 .43781 L
s
.89531 .43781 m
.89626 .44642 L
s
.522 .277 1 r
.30878 .4221 m
.30822 .43046 L
s
.30824 .43042 m
.30878 .4221 L
s
.30878 .4221 m
.30776 .43853 L
s
.477 .289 1 r
.61904 .44525 m
.619 .44569 L
s
.733 .224 1 r
.31382 .43814 m
.31327 .44697 L
s
.31334 .44678 m
.31382 .43814 L
s
.354 .436 1 r
.59949 .42225 m
.59963 .42959 L
s
.59965 .42956 m
.59949 .42225 L
s
.59949 .42225 m
.59984 .43744 L
s
.588 .259 1 r
.36143 .43551 m
.36101 .44405 L
s
.36108 .44372 m
.36143 .43551 L
s
.589 .259 1 r
.43797 .44736 m
.4379 .4478 L
s
.34 .366 1 r
.69977 .43289 m
.70015 .44047 L
s
.70021 .44066 m
.69977 .43289 L
s
.777 .214 1 r
.81789 .38591 m
.82184 .42901 L
s
1 .146 .894 r
.52714 .38591 m
.5274 .43229 L
s
.823 .204 1 r
.2364 .38591 m
.2329 .42938 L
s
.733 .224 1 r
.31327 .44697 m
.31384 .4381 L
s
.31384 .4381 m
.31334 .44678 L
s
.588 .259 1 r
.36101 .44405 m
.36144 .43548 L
s
.36144 .43548 m
.36108 .44372 L
s
.34 .366 1 r
.70015 .44047 m
.69979 .43286 L
s
.69979 .43286 m
.70021 .44066 L
s
.845 .199 1 r
.84268 .42511 m
.8435 .43424 L
s
.84352 .4342 m
.84268 .42511 L
s
.84268 .42511 m
.84437 .44304 L
s
.777 .214 1 r
.7092 .42445 m
.70965 .43344 L
s
.70968 .4334 m
.7092 .42445 L
s
.7092 .42445 m
.71017 .44209 L
s
1 .161 .972 r
.55697 .44105 m
.55705 .45055 L
s
.55711 .45021 m
.55697 .44105 L
s
.765 .217 1 r
.36655 .45158 m
.36648 .45177 L
s
1 .161 .972 r
.55705 .45055 m
.55699 .441 L
s
.55699 .441 m
.55711 .45021 L
s
.777 .214 1 r
.68113 .45042 m
.68109 .45086 L
s
.68 .237 1 r
.4949 .4366 m
.49481 .44536 L
s
.49487 .44503 m
.4949 .4366 L
s
.337 .332 1 r
.82824 .41809 m
.82891 .426 L
s
.82894 .42596 m
.82824 .41809 L
s
.82824 .41809 m
.82961 .43334 L
s
.55 .269 1 r
.68444 .38568 m
.68655 .42624 L
s
.618 .252 1 r
.39366 .38568 m
.39226 .42697 L
s
.68 .237 1 r
.49481 .44536 m
.49492 .43656 L
s
.49492 .43656 m
.49487 .44503 L
s
.822 .204 1 r
.50002 .45253 m
.49996 .45268 L
s
.744 .222 1 r
.62839 .4374 m
.62865 .44631 L
s
.6287 .44597 m
.62839 .4374 L
s
.777 .214 1 r
.65732 .45195 m
.65727 .45206 L
s
.845 .199 1 r
.94813 .45195 m
.94811 .45228 L
s
.744 .222 1 r
.62865 .44631 m
.62841 .43736 L
s
.62841 .43736 m
.6287 .44597 L
s
.433 .302 1 r
.19476 .44539 m
.19469 .44554 L
s
.904 .186 1 r
.44728 .43951 m
.44706 .44875 L
s
.44713 .44845 m
.44728 .43951 L
s
.375 .32 1 r
.29932 .43164 m
.29878 .43959 L
s
.29886 .43927 m
.29932 .43164 L
s
.904 .186 1 r
.44706 .44875 m
.4473 .43947 L
s
.4473 .43947 m
.44713 .44845 L
s
.375 .32 1 r
.29878 .43959 m
.29933 .43161 L
s
.29933 .43161 m
.29886 .43927 L
s
.649 .244 1 r
.84178 .38545 m
.84589 .4271 L
s
.669 .239 1 r
.55096 .38545 m
.55149 .42783 L
s
.68 .237 1 r
.26014 .38545 m
.25705 .42747 L
s
.344 .33 1 r
.6905 .44248 m
.69046 .44276 L
s
.559 .267 1 r
.8861 .44787 m
.88606 .44798 L
s
.722 .227 1 r
.20404 .43747 m
.2032 .44627 L
s
.20327 .44611 m
.20404 .43747 L
s
.618 .252 1 r
.54252 .43484 m
.54256 .44349 L
s
.54261 .44305 m
.54252 .43484 L
s
.904 .186 1 r
.7083 .38522 m
.71093 .42979 L
s
.531 .274 1 r
.41744 .38522 m
.41636 .42542 L
s
.722 .227 1 r
.2032 .44627 m
.20405 .43743 L
s
.20405 .43743 m
.20327 .44611 L
s
.618 .252 1 r
.54256 .44349 m
.54254 .43481 L
s
.54254 .43481 m
.54261 .44305 L
s
.67 .239 1 r
.3325 .42239 m
.33198 .43116 L
s
.332 .43112 m
.3325 .42239 L
s
.3325 .42239 m
.33156 .43952 L
s
.416 .307 1 r
.37583 .44436 m
.37577 .44454 L
s
1 .123 .772 r
.95255 .42858 m
.95373 .43838 L
s
.95377 .43834 m
.95255 .42858 L
s
.95255 .42858 m
.95501 .44807 L
s
1 .146 .894 r
.87169 .44118 m
.87266 .45083 L
s
.87269 .45049 m
.87169 .44118 L
s
.87266 .45083 m
.87172 .44114 L
s
.87172 .44114 m
.87269 .45049 L
s
.504 .282 1 r
.86568 .38499 m
.86986 .42447 L
s
.477 .289 1 r
.57478 .38499 m
.57556 .4241 L
s
.845 .199 1 r
.28389 .38499 m
.28098 .42883 L
s
.56 .267 1 r
.93382 .44589 m
.93382 .44633 L
s
.57 .264 1 r
.80028 .44531 m
.80028 .44589 L
s
.467 .292 1 r
.88106 .4328 m
.88191 .441 L
s
.88193 .44071 m
.88106 .4328 L
s
.433 .302 1 r
.53746 .41959 m
.53747 .42773 L
s
.53749 .42769 m
.53746 .41959 L
s
.53746 .41959 m
.53754 .43551 L
s
.467 .292 1 r
.88191 .441 m
.88108 .43276 L
s
.88108 .43276 m
.88193 .44071 L
s
1 .166 .996 r
.73313 .42493 m
.73367 .43443 L
s
.7337 .43439 m
.73313 .42493 L
s
.73313 .42493 m
.73428 .44346 L
s
.579 .262 1 r
.93811 .42163 m
.93911 .43013 L
s
.93914 .4301 m
.93811 .42163 L
s
.93811 .42163 m
.94016 .43835 L
s
.671 .239 1 r
.51366 .42107 m
.5136 .42991 L
s
.51362 .42987 m
.51366 .42107 L
s
.51366 .42107 m
.51363 .43813 L
s
.777 .214 1 r
.8905 .42443 m
.89142 .43334 L
s
.89145 .4333 m
.8905 .42443 L
s
.8905 .42443 m
.89242 .44215 L
s
.579 .262 1 r
.85727 .4344 m
.85809 .4429 L
s
.85812 .44261 m
.85727 .4344 L
s
.522 .277 1 r
.59016 .43308 m
.59032 .44147 L
s
.59036 .44107 m
.59016 .43308 L
s
.822 .204 1 r
.73217 .38476 m
.73509 .42897 L
s
.408 .31 1 r
.44123 .38476 m
.44045 .42388 L
s
.579 .262 1 r
.85809 .4429 m
.8573 .43436 L
s
.8573 .43436 m
.85812 .44261 L
s
.485 .287 1 r
.50937 .44567 m
.50931 .44582 L
s
.522 .277 1 r
.59032 .44147 m
.59018 .43305 L
s
.59018 .43305 m
.59036 .44107 L
s
.36 .462 1 r
.5851 .41726 m
.5852 .42481 L
s
.58522 .42478 m
.5851 .41726 L
s
.5851 .41726 m
.58538 .43208 L
s
.744 .222 1 r
.38515 .43651 m
.38477 .44542 L
s
.38485 .44508 m
.38515 .43651 L
s
1 .154 .933 r
.28482 .42595 m
.28412 .43552 L
s
.28414 .43548 m
.28482 .42595 L
s
.28482 .42595 m
.28352 .44477 L
s
.744 .222 1 r
.38477 .44542 m
.38516 .43647 L
s
.38516 .43647 m
.38485 .44508 L
s
.777 .214 1 r
.6234 .42333 m
.62363 .43231 L
s
.62365 .43227 m
.6234 .42333 L
s
.6234 .42333 m
.62393 .44097 L
s
.589 .259 1 r
.67104 .42082 m
.67138 .4294 L
s
.6714 .42936 m
.67104 .42082 L
s
.67104 .42082 m
.67178 .43754 L
s
.578 .262 1 r
.19886 .42282 m
.19804 .43122 L
s
.19805 .43118 m
.19886 .42282 L
s
.19886 .42282 m
.19728 .43966 L
s
.618 .252 1 r
.80462 .42158 m
.8053 .4302 L
s
.80532 .43016 m
.80462 .42158 L
s
.80462 .42158 m
.80603 .43849 L
s
.46 .294 1 r
.71441 .44275 m
.71439 .44333 L
s
.649 .244 1 r
.88959 .38453 m
.89425 .42583 L
s
.531 .274 1 r
.59862 .38453 m
.5997 .42474 L
s
.352 .427 1 r
.30765 .38453 m
.30548 .42111 L
s
.588 .259 1 r
.38007 .42114 m
.37968 .42968 L
s
.3797 .42964 m
.38007 .42114 L
s
.38007 .42114 m
.37938 .4379 L
s
.991 .169 1 r
.75701 .42452 m
.75762 .43398 L
s
.75764 .43394 m
.75701 .42452 L
s
.75701 .42452 m
.75829 .44301 L
s
.494 .284 1 r
.24647 .42063 m
.24577 .42888 L
s
.24579 .42884 m
.24647 .42063 L
s
.24647 .42063 m
.24516 .43695 L
s
.869 .194 1 r
.80971 .43789 m
.81047 .44706 L
s
.8105 .44676 m
.80971 .43789 L
s
.68 .237 1 r
.56636 .43526 m
.56646 .44402 L
s
.56651 .44369 m
.56636 .43526 L
s
.869 .194 1 r
.81047 .44706 m
.80974 .43785 L
s
.80974 .43785 m
.8105 .44676 L
s
.648 .244 1 r
.75605 .3843 m
.7591 .42596 L
s
.522 .277 1 r
.46504 .3843 m
.46453 .42451 L
s
.512 .279 1 r
.17403 .3843 m
.17002 .42487 L
s
.68 .237 1 r
.56646 .44402 m
.56638 .43522 L
s
.56638 .43522 m
.56651 .44369 L
s
.425 .305 1 r
.4277 .41895 m
.42744 .42705 L
s
.42746 .42701 m
.4277 .41895 L
s
.4277 .41895 m
.42727 .43483 L
s
.589 .259 1 r
.69491 .42036 m
.69531 .42894 L
s
.69533 .42891 m
.69491 .42036 L
s
.69491 .42036 m
.69577 .43709 L
s
.857 .196 1 r
.91447 .42437 m
.91547 .43347 L
s
.9155 .43343 m
.91447 .42437 L
s
.91447 .42437 m
.91655 .44242 L
s
.777 .214 1 r
.48982 .42375 m
.4897 .43267 L
s
.48973 .43263 m
.48982 .42375 L
s
.48982 .42375 m
.48967 .44148 L
s
.559 .267 1 r
.5332 .44559 m
.53314 .44591 L
s
.629 .249 1 r
.91352 .38407 m
.91843 .42501 L
s
.513 .279 1 r
.62247 .38407 m
.62381 .42355 L
s
.88 .191 1 r
.33142 .38407 m
.32905 .42937 L
s
.823 .204 1 r
.22261 .4225 m
.22178 .43164 L
s
.22179 .4316 m
.22261 .4225 L
s
.22261 .4225 m
.22106 .4403 L
s
.977 .171 1 r
.94339 .43926 m
.94453 .44862 L
s
.94457 .44843 m
.94339 .43926 L
s
.811 .206 1 r
.40892 .43664 m
.40861 .4457 L
s
.40868 .44536 m
.40892 .43664 L
s
.977 .171 1 r
.94453 .44862 m
.94342 .43922 L
s
.94342 .43922 m
.94457 .44843 L
s
.811 .206 1 r
.40861 .4457 m
.40894 .4366 L
s
.40894 .4366 m
.40868 .44536 L
s
.629 .249 1 r
.77994 .38384 m
.78324 .42478 L
s
.4 .312 1 r
.48886 .38384 m
.48864 .42224 L
s
.367 .322 1 r
.19778 .38384 m
.19428 .42188 L
s
1 .156 .946 r
.65234 .43955 m
.65269 .44909 L
s
.65274 .44879 m
.65234 .43955 L
s
.618 .252 1 r
.56132 .42035 m
.56138 .42901 L
s
.5614 .42897 m
.56132 .42035 L
s
.56132 .42035 m
.56152 .43723 L
s
1 .156 .946 r
.65269 .44909 m
.65236 .43951 L
s
.65236 .43951 m
.65274 .44879 L
s
.44216 .42705 m
.4419 .43645 L
s
.44192 .43641 m
.44216 .42705 L
s
.44216 .42705 m
.44173 .446 L
s
.754 .219 1 r
.27527 .43641 m
.27461 .44529 L
s
.27468 .44514 m
.27527 .43641 L
s
.477 .289 1 r
.73834 .44303 m
.73831 .44346 L
s
.754 .219 1 r
.27461 .44529 m
.27529 .43637 L
s
.27529 .43637 m
.27468 .44514 L
s
.928 .181 1 r
.67618 .43853 m
.67658 .44777 L
s
.67664 .44762 m
.67618 .43853 L
s
.342 .377 1 r
.51873 .43916 m
.51867 .43959 L
s
.928 .181 1 r
.67658 .44777 m
.67621 .43849 L
s
.67621 .43849 m
.67664 .44762 L
s
.649 .244 1 r
.93745 .38361 m
.94274 .42528 L
s
.599 .257 1 r
.64633 .38361 m
.648 .42419 L
s
.916 .184 1 r
.35521 .38361 m
.35319 .42819 L
s
.514 .279 1 r
.74263 .41877 m
.74314 .42718 L
s
.74316 .42714 m
.74263 .41877 L
s
.74263 .41877 m
.7437 .4351 L
s
.375 .532 1 r
.83368 .43799 m
.83365 .43817 L
s
.4 .312 1 r
.47534 .41751 m
.4752 .42557 L
s
.47521 .42554 m
.47534 .41751 L
s
.47534 .41751 m
.47513 .43321 L
s
.335 .34 1 r
.41825 .42882 m
.418 .43663 L
s
.41806 .4363 m
.41825 .42882 L
s
.846 .199 1 r
.77668 .44937 m
.77665 .44981 L
s
.335 .34 1 r
.418 .43663 m
.41827 .42879 L
s
.41827 .42879 m
.41806 .4363 L
s
.658 .242 1 r
.7477 .43488 m
.74826 .44353 L
s
.74831 .44338 m
.7477 .43488 L
s
.618 .252 1 r
.77154 .43356 m
.77216 .44218 L
s
.77219 .44185 m
.77154 .43356 L
s
.659 .242 1 r
.35187 .44879 m
.35182 .44872 L
s
.494 .285 1 r
.21309 .43225 m
.21233 .4405 L
s
.2124 .44031 m
.21309 .43225 L
s
.4 .312 1 r
.5519 .42963 m
.55196 .43768 L
s
.55201 .43725 m
.5519 .42963 L
s
.658 .242 1 r
.74826 .44353 m
.74773 .43484 L
s
.74773 .43484 m
.74831 .44338 L
s
.618 .252 1 r
.77216 .44218 m
.77156 .43353 L
s
.77156 .43353 m
.77219 .44185 L
s
.494 .285 1 r
.21233 .4405 m
.2131 .43221 L
s
.2131 .43221 m
.2124 .44031 L
s
.4 .312 1 r
.55196 .43768 m
.55192 .42959 L
s
.55192 .42959 m
.55201 .43725 L
s
.722 .226 1 r
.95802 .44762 m
.95802 .44799 L
s
.618 .252 1 r
.80385 .38338 m
.80743 .42433 L
s
.733 .224 1 r
.51269 .38338 m
.51274 .42615 L
s
.822 .204 1 r
.22153 .38338 m
.21778 .4276 L
s
.608 .254 1 r
.18923 .43385 m
.18838 .44239 L
s
.18846 .44221 m
.18923 .43385 L
s
.18838 .44239 m
.18924 .43381 L
s
.18924 .43381 m
.18846 .44221 L
s
.649 .244 1 r
.71883 .42066 m
.7193 .42936 L
s
.71932 .42932 m
.71883 .42066 L
s
.71883 .42066 m
.71983 .43773 L
s
.399 .312 1 r
.90017 .4187 m
.90101 .42666 L
s
.90104 .42663 m
.90017 .4187 L
s
.90017 .4187 m
.90193 .43452 L
s
.368 .497 1 r
.81418 .41546 m
.81479 .42294 L
s
.81481 .42291 m
.81418 .41546 L
s
.81418 .41546 m
.81545 .43014 L
s
.54 .272 1 r
.42337 .44528 m
.42331 .44543 L
s
.658 .242 1 r
.27014 .4215 m
.26947 .43016 L
s
.26949 .43012 m
.27014 .4215 L
s
.27014 .4215 m
.26888 .43868 L
s
.767 .216 1 r
.67021 .38315 m
.67226 .42591 L
s
.953 .176 1 r
.37901 .38315 m
.37729 .4281 L
s
.869 .194 1 r
.64306 .44951 m
.64301 .44992 L
s
.669 .239 1 r
.48039 .43443 m
.48027 .44312 L
s
.48033 .44293 m
.48039 .43443 L
s
.48027 .44312 m
.48041 .43439 L
s
.48041 .43439 m
.48033 .44293 L
s
.359 .46 1 r
.45657 .4358 m
.4565 .43651 L
s
.892 .189 1 r
.328 .45104 m
.32792 .45119 L
s
.722 .227 1 r
.9053 .43523 m
.90628 .44403 L
s
.90632 .44388 m
.9053 .43523 L
s
.744 .221 1 r
.32286 .43523 m
.32232 .44411 L
s
.3224 .44388 m
.32286 .43523 L
s
.811 .206 1 r
.85257 .42196 m
.85341 .43103 L
s
.85343 .43099 m
.85257 .42196 L
s
.85257 .42196 m
.8543 .43976 L
s
.503 .282 1 r
.68561 .43129 m
.686 .43961 L
s
.68603 .43928 m
.68561 .43129 L
s
.777 .214 1 r
.82776 .38292 m
.83188 .42641 L
s
.588 .259 1 r
.53653 .38292 m
.53688 .42387 L
s
.868 .194 1 r
.2453 .38292 m
.24177 .42824 L
s
.722 .227 1 r
.90628 .44403 m
.90533 .43519 L
s
.90533 .43519 m
.90632 .44388 L
s
.744 .221 1 r
.32232 .44411 m
.32287 .43519 L
s
.32287 .43519 m
.3224 .44388 L
s
.503 .282 1 r
.686 .43961 m
.68563 .43125 L
s
.68563 .43125 m
.68603 .43928 L
s
.965 .174 1 r
.72394 .43735 m
.72448 .44674 L
s
.72452 .44637 m
.72394 .43735 L
s
.541 .272 1 r
.76229 .4433 m
.76227 .44378 L
s
.522 .277 1 r
.31778 .41949 m
.31725 .42782 L
s
.31727 .42778 m
.31778 .41949 L
s
.31778 .41949 m
.3168 .43596 L
s
.965 .174 1 r
.72448 .44674 m
.72397 .4373 L
s
.72397 .4373 m
.72452 .44637 L
s
.916 .184 1 r
.4038 .42283 m
.40345 .43212 L
s
.40346 .43208 m
.4038 .42283 L
s
.4038 .42283 m
.40318 .44108 L
s
.601 .256 1 r
.79042 .41755 m
.79107 .42628 L
s
.7911 .42624 m
.79042 .41755 L
s
.79042 .41755 m
.79175 .4342 L
s
.588 .259 1 r
.60903 .41956 m
.60921 .42811 L
s
.60923 .42807 m
.60903 .41956 L
s
.60903 .41956 m
.60946 .43633 L
s
.789 .211 1 r
.87644 .42094 m
.87735 .43 L
s
.87737 .42996 m
.87644 .42094 L
s
.87644 .42094 m
.87829 .43859 L
s
.69 .234 1 r
.3995 .44753 m
.39944 .44768 L
s
.69409 .38268 m
.6964 .42473 L
s
.559 .267 1 r
.40282 .38268 m
.40156 .42328 L
s
1 .133 .827 r
.78108 .42647 m
.78177 .43614 L
s
.7818 .43609 m
.78108 .42647 L
s
.78108 .42647 m
.78256 .44583 L
s
.881 .191 1 r
.6141 .43581 m
.61434 .44505 L
s
.61439 .44461 m
.6141 .43581 L
s
.733 .224 1 r
.34667 .43449 m
.3462 .44337 L
s
.34627 .44307 m
.34667 .43449 L
s
.788 .212 1 r
.66693 .44906 m
.66688 .44922 L
s
.36 .324 1 r
.4659 .42792 m
.46576 .43588 L
s
.46582 .43541 m
.4659 .42792 L
s
.881 .191 1 r
.61434 .44505 m
.61412 .43577 L
s
.61412 .43577 m
.61439 .44461 L
s
.733 .224 1 r
.3462 .44337 m
.34669 .43445 L
s
.34669 .43445 m
.34627 .44307 L
s
.531 .274 1 r
.63289 .41868 m
.63312 .42708 L
s
.63315 .42704 m
.63289 .41868 L
s
.63289 .41868 m
.63343 .43515 L
s
.36 .324 1 r
.46576 .43588 m
.46592 .42789 L
s
.46592 .42789 m
.46582 .43541 L
s
.711 .229 1 r
.50423 .43398 m
.50417 .44282 L
s
.50423 .44249 m
.50423 .43398 L
s
.50417 .44282 m
.50425 .43394 L
s
.50425 .43394 m
.50423 .44249 L
s
.425 .305 1 r
.22743 .44133 m
.22735 .44165 L
s
.733 .224 1 r
.26577 .44731 m
.26568 .44761 L
s
.811 .206 1 r
.63796 .43478 m
.63825 .44388 L
s
.6383 .44344 m
.63796 .43478 L
s
.521 .277 1 r
.47103 .44403 m
.47097 .44421 L
s
.559 .267 1 r
.34159 .41889 m
.34111 .42737 L
s
.34113 .42733 m
.34159 .41889 L
s
.34159 .41889 m
.34072 .43552 L
s
.45 .297 1 r
.65674 .41758 m
.65703 .42576 L
s
.65705 .42572 m
.65674 .41758 L
s
.65674 .41758 m
.65738 .43362 L
s
.733 .224 1 r
.85169 .38245 m
.85604 .42523 L
s
.56 .267 1 r
.56039 .38245 m
.56101 .42269 L
s
.68 .237 1 r
.26908 .38245 m
.26611 .4245 L
s
.811 .206 1 r
.63825 .44388 m
.63798 .43474 L
s
.63798 .43474 m
.6383 .44344 L
s
.579 .262 1 r
.52807 .43296 m
.52807 .4414 L
s
.52813 .44132 m
.52807 .43296 L
s
.521 .277 1 r
.26061 .43164 m
.25996 .43996 L
s
.26003 .43978 m
.26061 .43164 L
s
.591 .259 1 r
.78621 .44286 m
.7862 .44352 L
s
.579 .262 1 r
.52807 .4414 m
.52809 .43292 L
s
.52809 .43292 m
.52813 .44132 L
s
.648 .244 1 r
.184 .41976 m
.18311 .42846 L
s
.18312 .42842 m
.184 .41976 L
s
.184 .41976 m
.18232 .43683 L
s
.521 .277 1 r
.25996 .43996 m
.26062 .4316 L
s
.26062 .4316 m
.26003 .43978 L
s
.649 .244 1 r
.60477 .44497 m
.60473 .44541 L
s
.766 .217 1 r
.8484 .44767 m
.84837 .44797 L
s
.569 .264 1 r
.91996 .44381 m
.91995 .44417 L
s
.559 .267 1 r
.33729 .4438 m
.33721 .44413 L
s
.352 .327 1 r
.25124 .44052 m
.25117 .44063 L
s
.608 .254 1 r
.71799 .38222 m
.72055 .42355 L
s
.476 .29 1 r
.42665 .38222 m
.42569 .42173 L
s
.711 .229 1 r
.58093 .4465 m
.58087 .44684 L
s
.36 .462 1 r
.35599 .42667 m
.35561 .43419 L
s
.35567 .43401 m
.35599 .42667 L
s
1 .098 .63 r
.64741 .42671 m
.64774 .43678 L
s
.64777 .43674 m
.64741 .42671 L
s
.64741 .42671 m
.64816 .4467 L
s
.36 .462 1 r
.35561 .43419 m
.35601 .42664 L
s
.35601 .42664 m
.35567 .43401 L
s
1 .151 .921 r
.43267 .43879 m
.4324 .44834 L
s
.43247 .44818 m
.43267 .43879 L
s
.424 .305 1 r
.68062 .41691 m
.68096 .42502 L
s
.68099 .42498 m
.68062 .41691 L
s
.68062 .41691 m
.68137 .4328 L
s
.56 .267 1 r
.86715 .43091 m
.868 .43941 L
s
.86801 .43897 m
.86715 .43091 L
s
1 .151 .921 r
.4324 .44834 m
.43269 .43875 L
s
.43269 .43875 m
.43247 .44818 L
s
.354 .436 1 r
.59963 .42959 m
.59978 .43693 L
s
.59984 .43744 m
.59963 .42959 L
s
.712 .229 1 r
.92429 .41964 m
.9253 .42852 L
s
.92533 .42848 m
.92429 .41964 L
s
.92429 .41964 m
.92635 .43697 L
s
.56 .267 1 r
.868 .43941 m
.86718 .43087 L
s
.86718 .43087 m
.86801 .43897 L
s
.354 .436 1 r
.59978 .43693 m
.59965 .42956 L
s
.59965 .42956 m
.59984 .43744 L
s
.777 .214 1 r
.37047 .43433 m
.37005 .44332 L
s
.37013 .44299 m
.37047 .43433 L
s
.754 .219 1 r
.87563 .38199 m
.88036 .4255 L
s
.7 .232 1 r
.58425 .38199 m
.58522 .4255 L
s
.477 .289 1 r
.29287 .38199 m
.29036 .4215 L
s
.777 .214 1 r
.37005 .44332 m
.37049 .43429 L
s
.37049 .43429 m
.37013 .44299 L
s
.904 .186 1 r
.29384 .42252 m
.29319 .43173 L
s
.2932 .43169 m
.29384 .42252 L
s
.29384 .42252 m
.29263 .44077 L
s
.34 .366 1 r
.70021 .44066 m
.70015 .44047 L
s
.8 .209 1 r
.28954 .44723 m
.28945 .44763 L
s
.388 .587 1 r
.7419 .38176 m
.74429 .41619 L
s
.788 .212 1 r
.45048 .38176 m
.44973 .42564 L
s
.799 .209 1 r
.66187 .43491 m
.66222 .4439 L
s
.66227 .44371 m
.66187 .43491 L
s
.733 .224 1 r
.3943 .4336 m
.39395 .44248 L
s
.39403 .44218 m
.3943 .4336 L
s
.754 .219 1 r
.76673 .42102 m
.76733 .4299 L
s
.76736 .42986 m
.76673 .42102 L
s
.76673 .42102 m
.768 .43864 L
s
.799 .209 1 r
.66222 .4439 m
.66189 .43487 L
s
.66189 .43487 m
.66227 .44371 L
s
.733 .224 1 r
.39395 .44248 m
.39432 .43356 L
s
.39432 .43356 m
.39403 .44218 L
s
.599 .257 1 r
.57581 .43177 m
.57593 .44032 L
s
.57598 .44005 m
.57581 .43177 L
s
.522 .277 1 r
.30822 .43046 m
.30768 .43882 L
s
.30776 .43853 m
.30822 .43046 L
s
.88 .191 1 r
.82466 .45029 m
.82461 .4503 L
s
.588 .259 1 r
.36108 .44372 m
.36101 .44405 L
s
.599 .257 1 r
.57593 .44032 m
.57583 .43173 L
s
.57583 .43173 m
.57598 .44005 L
s
.522 .277 1 r
.30768 .43882 m
.30824 .43042 L
s
.30824 .43042 m
.30776 .43853 L
s
.8 .209 1 r
.92946 .43651 m
.9305 .44537 L
s
.93059 .44561 m
.92946 .43651 L
s
.755 .219 1 r
.89626 .44642 m
.89624 .44679 L
s
.8 .209 1 r
.9305 .44537 m
.92949 .43647 L
s
.92949 .43647 m
.93059 .44561 L
s
.69 .234 1 r
.89959 .38153 m
.90446 .42359 L
s
.64 .246 1 r
.60813 .38153 m
.60934 .42213 L
s
.337 .332 1 r
.82891 .426 m
.82962 .43391 L
s
.82961 .43334 m
.82891 .426 L
s
.811 .206 1 r
.31668 .38153 m
.31421 .42505 L
s
.953 .176 1 r
.79569 .436 m
.79642 .44536 L
s
.79646 .44502 m
.79569 .436 L
s
.375 .32 1 r
.29886 .43927 m
.29878 .43959 L
s
.869 .194 1 r
.81955 .43469 m
.82034 .4439 L
s
.82037 .44349 m
.81955 .43469 L
s
.337 .332 1 r
.82962 .43391 m
.82894 .42596 L
s
.82894 .42596 m
.82961 .43334 L
s
.953 .176 1 r
.79642 .44536 m
.79571 .43596 L
s
.79571 .43596 m
.79646 .44502 L
s
.869 .194 1 r
.82034 .4439 m
.81958 .43464 L
s
.81958 .43464 m
.82037 .44349 L
s
.953 .176 1 r
.24176 .45065 m
.24168 .45077 L
s
.61 .254 1 r
.54689 .41757 m
.54692 .42624 L
s
.54694 .4262 m
.54689 .41757 L
s
.54689 .41757 m
.54702 .43439 L
s
.416 .307 1 r
.86222 .41627 m
.86299 .42434 L
s
.86301 .42431 m
.86222 .41627 L
s
.86222 .41627 m
.86381 .43213 L
s
.733 .224 1 r
.31334 .44678 m
.31327 .44697 L
s
1 .146 .894 r
.45144 .42301 m
.45121 .43267 L
s
.45123 .43262 m
.45144 .42301 L
s
.45144 .42301 m
.45106 .442 L
s
.81 .206 1 r
.2366 .43498 m
.23583 .44397 L
s
.2359 .44385 m
.2366 .43498 L
s
.23583 .44397 m
.23662 .43494 L
s
.23662 .43494 m
.2359 .44385 L
s
.833 .201 1 r
.76582 .3813 m
.76924 .42628 L
s
.579 .262 1 r
.47433 .3813 m
.47392 .42227 L
s
.424 .305 1 r
.18284 .3813 m
.17903 .42082 L
s
.345 .39 1 r
.46079 .41452 m
.46062 .42222 L
s
.46064 .42219 m
.46079 .41452 L
s
.46079 .41452 m
.46053 .42964 L
s
.68 .237 1 r
.49487 .44503 m
.49481 .44536 L
s
1 .126 .786 r
.48551 .45371 m
.48544 .45391 L
s
.777 .214 1 r
.94835 .41994 m
.94944 .42894 L
s
.94947 .4289 m
.94835 .41994 L
s
.94835 .41994 m
.95057 .4376 L
s
.799 .209 1 r
.49916 .42074 m
.49906 .42974 L
s
.49909 .4297 m
.49916 .42074 L
s
.49916 .42074 m
.49905 .43855 L
s
.20764 .42074 m
.20678 .42974 L
s
.2068 .4297 m
.20764 .42074 L
s
.20764 .42074 m
.20601 .43855 L
s
.531 .274 1 r
.57076 .41677 m
.57084 .42521 L
s
.57086 .42517 m
.57076 .41677 L
s
.57076 .41677 m
.571 .43322 L
s
.733 .224 1 r
.36533 .42009 m
.36489 .42894 L
s
.36491 .4289 m
.36533 .42009 L
s
.36533 .42009 m
.36454 .4376 L
s
.744 .222 1 r
.6287 .44597 m
.62865 .44631 L
s
.777 .214 1 r
.70965 .43344 m
.71013 .44243 L
s
.71017 .44209 m
.70965 .43344 L
s
.893 .189 1 r
.92355 .38107 m
.92891 .42459 L
s
.916 .184 1 r
.63202 .38107 m
.63366 .42568 L
s
.503 .282 1 r
.3405 .38107 m
.33852 .42095 L
s
.777 .214 1 r
.71013 .44243 m
.70968 .4334 L
s
.70968 .4334 m
.71017 .44209 L
s
.811 .206 1 r
.52303 .41961 m
.523 .42871 L
s
.52302 .42867 m
.52303 .41961 L
s
.52303 .41961 m
.52305 .43738 L
s
.845 .199 1 r
.8435 .43424 m
.84434 .44338 L
s
.84437 .44304 m
.8435 .43424 L
s
.84434 .44338 m
.84352 .4342 L
s
.84352 .4342 m
.84437 .44304 L
s
1 .161 .972 r
.55711 .45021 m
.55705 .45055 L
s
.476 .29 1 r
.43692 .41644 m
.43668 .42469 L
s
.4367 .42466 m
.43692 .41644 L
s
.43692 .41644 m
.43653 .43263 L
s
.618 .252 1 r
.54261 .44305 m
.54256 .44349 L
s
.904 .186 1 r
.44713 .44845 m
.44706 .44875 L
s
.788 .212 1 r
.78976 .38084 m
.79341 .42473 L
s
.424 .305 1 r
.49819 .38084 m
.49808 .41963 L
s
.628 .249 1 r
.20663 .38084 m
.20287 .42291 L
s
.638 .247 1 r
.25532 .41876 m
.25462 .42739 L
s
.25463 .42735 m
.25532 .41876 L
s
.25532 .41876 m
.254 .43584 L
s
.36 .462 1 r
.5852 .42481 m
.58533 .43236 L
s
.58538 .43208 m
.5852 .42481 L
s
.711 .229 1 r
.83848 .41883 m
.83926 .42768 L
s
.83929 .42764 m
.83848 .41883 L
s
.83848 .41883 m
.8401 .4362 L
s
.467 .292 1 r
.88193 .44071 m
.88191 .441 L
s
.342 .378 1 r
.6185 .4149 m
.61869 .42257 L
s
.61871 .42254 m
.6185 .4149 L
s
.6185 .4149 m
.61894 .43014 L
s
.36 .462 1 r
.58533 .43236 m
.58522 .42478 L
s
.58522 .42478 m
.58538 .43208 L
s
.722 .227 1 r
.20327 .44611 m
.2032 .44627 L
s
.811 .206 1 r
.38917 .4197 m
.38878 .42877 L
s
.3888 .42873 m
.38917 .4197 L
s
.38917 .4197 m
.38849 .43752 L
s
.36 .325 1 r
.48465 .41442 m
.48453 .42235 L
s
.48455 .42231 m
.48465 .41442 L
s
.48465 .41442 m
.48449 .42992 L
s
.433 .302 1 r
.53747 .42773 m
.53749 .43587 L
s
.53754 .43551 m
.53747 .42773 L
s
.744 .221 1 r
.65593 .38061 m
.65779 .42304 L
s
.88 .191 1 r
.36432 .38061 m
.36239 .42595 L
s
.659 .242 1 r
.23142 .42044 m
.23066 .429 L
s
.23067 .42896 m
.23142 .42044 L
s
.23142 .42044 m
.22995 .43774 L
s
.433 .302 1 r
.53749 .43587 m
.53749 .42769 L
s
.53749 .42769 m
.53754 .43551 L
s
.67 .239 1 r
.33198 .43116 m
.33148 .43993 L
s
.33156 .43952 m
.33198 .43116 L
s
.522 .277 1 r
.59036 .44107 m
.59032 .44147 L
s
.67 .239 1 r
.33148 .43993 m
.332 .43112 L
s
.332 .43112 m
.33156 .43952 L
s
.579 .262 1 r
.85812 .44261 m
.85809 .4429 L
s
.93911 .43013 m
.94014 .43865 L
s
.94016 .43835 m
.93911 .43013 L
s
.917 .184 1 r
.81371 .38038 m
.81771 .42463 L
s
.649 .244 1 r
.52206 .38037 m
.52224 .42172 L
s
.459 .294 1 r
.23042 .38037 m
.2272 .41954 L
s
.579 .262 1 r
.94014 .43865 m
.93914 .4301 L
s
.93914 .4301 m
.94016 .43835 L
s
.418 .713 1 r
.58015 .40974 m
.58024 .41679 L
s
.58026 .41675 m
.58015 .40974 L
s
.58015 .40974 m
.58039 .4234 L
s
.467 .292 1 r
.59466 .41722 m
.5948 .42533 L
s
.59482 .4253 m
.59466 .41722 L
s
.59466 .41722 m
.59501 .43349 L
s
.744 .222 1 r
.38485 .44508 m
.38477 .44542 L
s
.578 .262 1 r
.19804 .43122 m
.19722 .43963 L
s
.19728 .43966 m
.19804 .43122 L
s
.671 .239 1 r
.5136 .42991 m
.51356 .43875 L
s
.51363 .43813 m
.5136 .42991 L
s
.857 .196 1 r
.67984 .38014 m
.68211 .42477 L
s
.648 .244 1 r
.38817 .38014 m
.38668 .42185 L
s
.578 .262 1 r
.19722 .43963 m
.19805 .43118 L
s
.19805 .43118 m
.19728 .43966 L
s
1 .146 .894 r
.87269 .45049 m
.87266 .45083 L
s
.391 .315 1 r
.9341 .4147 m
.93503 .4227 L
s
.93506 .42266 m
.9341 .4147 L
s
.9341 .4147 m
.93601 .43041 L
s
.671 .239 1 r
.51356 .43875 m
.51362 .42987 L
s
.51362 .42987 m
.51363 .43813 L
s
.777 .214 1 r
.89142 .43334 m
.89237 .44226 L
s
.89242 .44215 m
.89142 .43334 L
s
.589 .259 1 r
.67138 .4294 m
.67174 .43798 L
s
.67178 .43754 m
.67138 .4294 L
s
.777 .214 1 r
.89237 .44226 m
.89145 .4333 L
s
.89145 .4333 m
.89242 .44215 L
s
.589 .259 1 r
.67174 .43798 m
.6714 .42936 L
s
.6714 .42936 m
.67178 .43754 L
s
.836 .201 1 r
.88638 .41753 m
.88733 .42678 L
s
.88736 .42674 m
.88638 .41753 L
s
.88638 .41753 m
.88829 .4353 L
s
.416 .307 1 r
.64243 .41491 m
.64268 .42299 L
s
.6427 .42295 m
.64243 .41491 L
s
.64243 .41491 m
.643 .43077 L
s
.618 .252 1 r
.8053 .4302 m
.806 .43882 L
s
.80603 .43849 m
.8053 .4302 L
s
.494 .284 1 r
.24577 .42888 m
.24509 .43713 L
s
.24516 .43695 m
.24577 .42888 L
s
.649 .244 1 r
.75247 .41695 m
.75302 .42569 L
s
.75305 .42565 m
.75247 .41695 L
s
.75247 .41695 m
.75363 .43399 L
s
.701 .232 1 r
.7047 .41961 m
.70513 .42832 L
s
.70516 .42828 m
.7047 .41961 L
s
.7047 .41961 m
.70564 .43707 L
s
.618 .252 1 r
.806 .43882 m
.80532 .43016 L
s
.80532 .43016 m
.80603 .43849 L
s
.494 .284 1 r
.24509 .43713 m
.24579 .42884 L
s
.24579 .42884 m
.24516 .43695 L
s
.777 .214 1 r
.62363 .43231 m
.62388 .44131 L
s
.62393 .44097 m
.62363 .43231 L
s
.588 .259 1 r
.37968 .42968 m
.37931 .43823 L
s
.37938 .4379 m
.37968 .42968 L
s
.425 .305 1 r
.42744 .42705 m
.4272 .43516 L
s
.42727 .43483 m
.42744 .42705 L
s
.486 .287 1 r
.83767 .37991 m
.84146 .41872 L
s
.811 .206 1 r
.54595 .37991 m
.54644 .42345 L
s
.917 .184 1 r
.25423 .37991 m
.25091 .42418 L
s
.777 .214 1 r
.62388 .44131 m
.62365 .43227 L
s
.62365 .43227 m
.62393 .44097 L
s
1 .123 .772 r
.95373 .43838 m
.95496 .44819 L
s
.95501 .44807 m
.95373 .43838 L
s
.588 .259 1 r
.37931 .43823 m
.3797 .42964 L
s
.3797 .42964 m
.37938 .4379 L
s
.425 .305 1 r
.4272 .43516 m
.42746 .42701 L
s
.42746 .42701 m
.42727 .43483 L
s
1 .166 .996 r
.73367 .43443 m
.73425 .44394 L
s
.73428 .44346 m
.73367 .43443 L
s
.68 .237 1 r
.56651 .44369 m
.56646 .44402 L
s
1 .123 .772 r
.95496 .44819 m
.95377 .43834 L
s
.95377 .43834 m
.95501 .44807 L
s
1 .166 .996 r
.73425 .44394 m
.7337 .43439 L
s
.7337 .43439 m
.73428 .44346 L
s
.953 .176 1 r
.413 .42011 m
.41266 .42948 L
s
.41268 .42944 m
.413 .42011 L
s
.413 .42011 m
.41242 .43852 L
s
.522 .277 1 r
.70377 .37968 m
.7061 .41994 L
s
.559 .267 1 r
.41202 .37968 m
.41086 .42031 L
s
1 .154 .933 r
.28412 .43552 m
.28343 .44511 L
s
.28352 .44477 m
.28412 .43552 L
s
.869 .194 1 r
.8105 .44676 m
.81047 .44706 L
s
.589 .259 1 r
.69531 .42894 m
.69573 .43753 L
s
.69577 .43709 m
.69531 .42894 L
s
1 .154 .933 r
.28343 .44511 m
.28414 .43548 L
s
.28414 .43548 m
.28352 .44477 L
s
.589 .259 1 r
.69573 .43753 m
.69533 .42891 L
s
.69533 .42891 m
.69577 .43709 L
s
.335 .34 1 r
.41806 .4363 m
.418 .43663 L
s
.846 .199 1 r
.30293 .41846 m
.3023 .42765 L
s
.30232 .42761 m
.30293 .41846 L
s
.30293 .41846 m
.30179 .43639 L
s
.857 .196 1 r
.27903 .41985 m
.27835 .42897 L
s
.27836 .42892 m
.27903 .41985 L
s
.27903 .41985 m
.27775 .43793 L
s
.777 .214 1 r
.86164 .37945 m
.86616 .42262 L
s
.4 .312 1 r
.56985 .37945 m
.57055 .41789 L
s
.881 .191 1 r
.27806 .37945 m
.27504 .42372 L
s
.991 .169 1 r
.75762 .43398 m
.75826 .44346 L
s
.75829 .44301 m
.75762 .43398 L
s
.4 .312 1 r
.55201 .43725 m
.55196 .43768 L
s
.777 .214 1 r
.4897 .43267 m
.4896 .44159 L
s
.48967 .44148 m
.4897 .43267 L
s
.4 .312 1 r
.69026 .41343 m
.69062 .4215 L
s
.69064 .42147 m
.69026 .41343 L
s
.69026 .41343 m
.69104 .42915 L
s
.991 .169 1 r
.75826 .44346 m
.75764 .43394 L
s
.75764 .43394 m
.75829 .44301 L
s
.777 .214 1 r
.4896 .44159 m
.48973 .43263 L
s
.48973 .43263 m
.48967 .44148 L
s
.648 .244 1 r
.77644 .41682 m
.77705 .42552 L
s
.77708 .42548 m
.77644 .41682 L
s
.77644 .41682 m
.77773 .4339 L
s
.857 .196 1 r
.91547 .43347 m
.91651 .44258 L
s
.91655 .44242 m
.91547 .43347 L
s
.811 .206 1 r
.40868 .44536 m
.40861 .4457 L
s
.579 .262 1 r
.35068 .4162 m
.35021 .42472 L
s
.35023 .42468 m
.35068 .4162 L
s
.35068 .4162 m
.34984 .43295 L
s
.4 .312 1 r
.4752 .42557 m
.47507 .43364 L
s
.47513 .43321 m
.4752 .42557 L
s
.857 .196 1 r
.91651 .44258 m
.9155 .43343 L
s
.9155 .43343 m
.91655 .44242 L
s
.368 .497 1 r
.81479 .42294 m
.81542 .43042 L
s
.81545 .43014 m
.81479 .42294 L
s
.4 .312 1 r
.47507 .43364 m
.47521 .42554 L
s
.47521 .42554 m
.47513 .43321 L
s
.658 .242 1 r
.32678 .41766 m
.32625 .42633 L
s
.32626 .42629 m
.32678 .41766 L
s
.32678 .41766 m
.3258 .43485 L
s
.823 .204 1 r
.22178 .43164 m
.22096 .44078 L
s
.22106 .4403 m
.22178 .43164 L
s
.368 .497 1 r
.81542 .43042 m
.81481 .42291 L
s
.81481 .42291 m
.81545 .43014 L
s
.618 .252 1 r
.56138 .42901 m
.56147 .43767 L
s
.56152 .43723 m
.56138 .42901 L
s
.339 .362 1 r
.60409 .41042 m
.60425 .41835 L
s
.60427 .41831 m
.60409 .41042 L
s
.60409 .41042 m
.60446 .42548 L
s
.701 .232 1 r
.72771 .37922 m
.73047 .42167 L
s
.845 .199 1 r
.43589 .37922 m
.43495 .42313 L
s
.823 .204 1 r
.22096 .44078 m
.22179 .4316 L
s
.22179 .4316 m
.22106 .4403 L
s
.618 .252 1 r
.56147 .43767 m
.5614 .42897 L
s
.5614 .42897 m
.56152 .43723 L
s
.494 .285 1 r
.2124 .44031 m
.21233 .4405 L
s
.514 .279 1 r
.74314 .42718 m
.74368 .43558 L
s
.7437 .4351 m
.74314 .42718 L
s
.977 .171 1 r
.94457 .44843 m
.94453 .44862 L
s
.514 .279 1 r
.74368 .43558 m
.74316 .42714 L
s
.74316 .42714 m
.7437 .4351 L
s
.754 .219 1 r
.27468 .44514 m
.27461 .44529 L
s
.618 .252 1 r
.77219 .44185 m
.77216 .44218 L
s
.399 .312 1 r
.90101 .42666 m
.90189 .43463 L
s
.90193 .43452 m
.90101 .42666 L
s
.90189 .43463 m
.90104 .42663 L
s
.90104 .42663 m
.90193 .43452 L
s
.658 .242 1 r
.19277 .41743 m
.1919 .4261 L
s
.19192 .42606 m
.19277 .41743 L
s
.19277 .41743 m
.19112 .43463 L
s
1 .161 .972 r
.72871 .42009 m
.72925 .42961 L
s
.72927 .42956 m
.72871 .42009 L
s
.72871 .42009 m
.72985 .4388 L
s
.618 .252 1 r
.50853 .41615 m
.50846 .42478 L
s
.50848 .42474 m
.50853 .41615 L
s
.50853 .41615 m
.50847 .43308 L
s
.46 .294 1 r
.88562 .37899 m
.88997 .4178 L
s
.591 .259 1 r
.59376 .37899 m
.59478 .41889 L
s
.559 .267 1 r
.30189 .37899 m
.29941 .41962 L
s
.658 .242 1 r
.74831 .44338 m
.74826 .44353 L
s
1 .156 .946 r
.65274 .44879 m
.65269 .44909 L
s
.608 .254 1 r
.18846 .44221 m
.18838 .44239 L
s
.928 .181 1 r
.67664 .44762 m
.67658 .44777 L
s
1 .156 .946 r
.4419 .43645 m
.44166 .44586 L
s
.44173 .446 m
.4419 .43645 L
s
.44166 .44586 m
.44192 .43641 L
s
.44192 .43641 m
.44173 .446 L
s
.711 .229 1 r
.75167 .37875 m
.75473 .42121 L
s
.425 .305 1 r
.45976 .37875 m
.45921 .41757 L
s
.441 .3 1 r
.16786 .37875 m
.16387 .4183 L
s
.649 .244 1 r
.7193 .42936 m
.71979 .43806 L
s
.71983 .43773 m
.7193 .42936 L
s
.929 .181 1 r
.91055 .41873 m
.91157 .42806 L
s
.9116 .42802 m
.91055 .41873 L
s
.91055 .41873 m
.91265 .43703 L
s
.503 .282 1 r
.68603 .43928 m
.686 .43961 L
s
.495 .284 1 r
.84823 .41409 m
.849 .42243 L
s
.84902 .42239 m
.84823 .41409 L
s
.84823 .41409 m
.8498 .43037 L
s
.649 .244 1 r
.71979 .43806 m
.71932 .42932 L
s
.71932 .42932 m
.71983 .43773 L
s
.36 .324 1 r
.46582 .43541 m
.46576 .43588 L
s
.658 .242 1 r
.26947 .43016 m
.26881 .43883 L
s
.26888 .43868 m
.26947 .43016 L
s
.26881 .43883 m
.26949 .43012 L
s
.26949 .43012 m
.26888 .43868 L
s
.628 .249 1 r
.90962 .37852 m
.91462 .42062 L
s
1 .154 .933 r
.61768 .37852 m
.61917 .42463 L
s
.619 .252 1 r
.32574 .37852 m
.32348 .42025 L
s
.669 .239 1 r
.48033 .44293 m
.48027 .44312 L
s
.522 .277 1 r
.31725 .42782 m
.31673 .43615 L
s
.3168 .43596 m
.31725 .42782 L
s
.711 .229 1 r
.3745 .41657 m
.37408 .42542 L
s
.3741 .42538 m
.3745 .41657 L
s
.3745 .41657 m
.37376 .43395 L
s
.383 .317 1 r
.4462 .41259 m
.44599 .4206 L
s
.44601 .42056 m
.4462 .41259 L
s
.4462 .41259 m
.44586 .42824 L
s
.367 .495 1 r
.94389 .40926 m
.94479 .41686 L
s
.94482 .41683 m
.94389 .40926 L
s
.94389 .40926 m
.9457 .42385 L
s
.522 .277 1 r
.31673 .43615 m
.31727 .42778 L
s
.31727 .42778 m
.3168 .43596 L
s
.722 .227 1 r
.90632 .44388 m
.90628 .44403 L
s
.744 .221 1 r
.3224 .44388 m
.32232 .44411 L
s
.36 .462 1 r
.35567 .43401 m
.35561 .43419 L
s
.588 .259 1 r
.60921 .42811 m
.60942 .43666 L
s
.60946 .43633 m
.60921 .42811 L
s
.476 .29 1 r
.26435 .41481 m
.2637 .42301 L
s
.26371 .42297 m
.26435 .41481 L
s
.26435 .41481 m
.26313 .43109 L
s
.589 .259 1 r
.77563 .37829 m
.77885 .41893 L
s
.68 .237 1 r
.48365 .37829 m
.48335 .42039 L
s
.569 .264 1 r
.19168 .37829 m
.18779 .41966 L
s
.588 .259 1 r
.60942 .43666 m
.60923 .42807 L
s
.60923 .42807 m
.60946 .43633 L
s
.601 .256 1 r
.79107 .42628 m
.79175 .43501 L
s
.79175 .4342 m
.79107 .42628 L
s
.79175 .43501 m
.7911 .42624 L
s
.7911 .42624 m
.79175 .4342 L
s
.811 .206 1 r
.85341 .43103 m
.85428 .4401 L
s
.8543 .43976 m
.85341 .43103 L
s
.354 .436 1 r
.59984 .43744 m
.59978 .43693 L
s
.522 .277 1 r
.71428 .41441 m
.71472 .42278 L
s
.71474 .42274 m
.71428 .41441 L
s
.71428 .41441 m
.71522 .43087 L
s
.531 .274 1 r
.63312 .42708 m
.63339 .43548 L
s
.63343 .43515 m
.63312 .42708 L
s
.45 .297 1 r
.65703 .42576 m
.65734 .43394 L
s
.65738 .43362 m
.65703 .42576 L
s
.811 .206 1 r
.85428 .4401 m
.85343 .43099 L
s
.85343 .43099 m
.8543 .43976 L
s
.531 .274 1 r
.63339 .43548 m
.63315 .42704 L
s
.63315 .42704 m
.63343 .43515 L
s
.965 .174 1 r
.72452 .44637 m
.72448 .44674 L
s
.45 .297 1 r
.65734 .43394 m
.65705 .42572 L
s
.65705 .42572 m
.65738 .43362 L
s
.733 .224 1 r
.34627 .44307 m
.3462 .44337 L
s
.521 .277 1 r
.26003 .43978 m
.25996 .43996 L
s
.551 .269 1 r
.93363 .37806 m
.93883 .41943 L
s
1 .091 .585 r
.64161 .37806 m
.64357 .42783 L
s
.4 .312 1 r
.3496 .37806 m
.34779 .41652 L
s
.711 .229 1 r
.50423 .44249 m
.50417 .44282 L
s
.789 .211 1 r
.87735 .43 m
.87828 .43907 L
s
.87829 .43859 m
.87735 .43 L
s
.559 .267 1 r
.34111 .42737 m
.34064 .43585 L
s
.34072 .43552 m
.34111 .42737 L
s
.881 .191 1 r
.61439 .44461 m
.61434 .44505 L
s
.579 .262 1 r
.52813 .44132 m
.52807 .4414 L
s
.789 .211 1 r
.87828 .43907 m
.87737 .42996 L
s
.87737 .42996 m
.87829 .43859 L
s
.559 .267 1 r
.34064 .43585 m
.34113 .42733 L
s
.34113 .42733 m
.34072 .43552 L
s
.701 .232 1 r
.39837 .41615 m
.39802 .42497 L
s
.39804 .42493 m
.39837 .41615 L
s
.39837 .41615 m
.39775 .4335 L
s
.916 .184 1 r
.40345 .43212 m
.40311 .44142 L
s
.40318 .44108 m
.40345 .43212 L
s
.40311 .44142 m
.40346 .43208 L
s
.40346 .43208 m
.40318 .44108 L
s
.811 .206 1 r
.6383 .44344 m
.63825 .44388 L
s
.822 .204 1 r
.82448 .41695 m
.82525 .42606 L
s
.82528 .42602 m
.82448 .41695 L
s
.82448 .41695 m
.82608 .43481 L
s
.94 .179 1 r
.80058 .41834 m
.8013 .42767 L
s
.80133 .42763 m
.80058 .41834 L
s
.80058 .41834 m
.80209 .43672 L
s
.618 .252 1 r
.42227 .41501 m
.42199 .42365 L
s
.42201 .42361 m
.42227 .41501 L
s
.42227 .41501 m
.42179 .43195 L
s
.424 .305 1 r
.68096 .42502 m
.68133 .43313 L
s
.68137 .4328 m
.68096 .42502 L
s
.754 .219 1 r
.79961 .37783 m
.80337 .42139 L
s
.588 .259 1 r
.50756 .37783 m
.50755 .41884 L
s
.443 .299 1 r
.2155 .37783 m
.21214 .41665 L
s
.56 .267 1 r
.86801 .43897 m
.868 .43941 L
s
.424 .305 1 r
.68133 .43313 m
.68099 .42498 L
s
.68099 .42498 m
.68137 .4328 L
s
.648 .244 1 r
.18311 .42846 m
.18222 .43716 L
s
.18232 .43683 m
.18311 .42846 L
s
.845 .199 1 r
.53244 .4172 m
.53243 .42635 L
s
.53245 .42631 m
.53244 .4172 L
s
.53244 .4172 m
.5325 .43517 L
s
.648 .244 1 r
.18222 .43716 m
.18312 .42842 L
s
.18312 .42842 m
.18232 .43683 L
s
.833 .201 1 r
.21645 .41866 m
.2156 .42767 L
s
.21562 .42763 m
.21645 .41866 L
s
.21645 .41866 m
.21484 .43672 L
s
.337 .332 1 r
.82961 .43334 m
.82962 .43391 L
s
.559 .267 1 r
.73826 .41413 m
.73876 .42262 L
s
.73879 .42258 m
.73826 .41413 L
s
.73826 .41413 m
.73933 .43078 L
s
.503 .282 1 r
.31208 .41347 m
.31154 .42181 L
s
.31155 .42177 m
.31208 .41347 L
s
.31208 .41347 m
.31108 .42982 L
s
.589 .259 1 r
.66556 .3776 m
.66746 .41824 L
s
.722 .227 1 r
.37347 .37759 m
.37174 .42079 L
s
.659 .242 1 r
.24034 .41749 m
.2396 .42606 L
s
.23961 .42602 m
.24034 .41749 L
s
.24034 .41749 m
.23892 .43481 L
s
1 .133 .827 r
.78177 .43614 m
.78249 .44581 L
s
.78256 .44583 m
.78177 .43614 L
s
.78249 .44581 m
.7818 .43609 L
s
.7818 .43609 m
.78256 .44583 L
s
.777 .214 1 r
.55636 .41632 m
.55641 .42532 L
s
.55643 .42528 m
.55636 .41632 L
s
.55636 .41632 m
.55654 .434 L
s
.408 .31 1 r
.17797 .413 m
.17713 .42101 L
s
.17715 .42097 m
.17797 .413 L
s
.17797 .413 m
.17638 .42887 L
s
.375 .32 1 r
.49399 .41172 m
.4939 .41969 L
s
.49391 .41965 m
.49399 .41172 L
s
.49399 .41172 m
.49387 .42733 L
s
.712 .229 1 r
.28816 .41511 m
.28752 .424 L
s
.28753 .42396 m
.28816 .41511 L
s
.28816 .41511 m
.28698 .43246 L
s
.777 .214 1 r
.37013 .44299 m
.37005 .44332 L
s
.712 .229 1 r
.9253 .42852 m
.92634 .43741 L
s
.92635 .43697 m
.9253 .42852 L
s
1 .164 .985 r
.66655 .41854 m
.66691 .42803 L
s
.66694 .42798 m
.66655 .41854 L
s
.66655 .41854 m
.66735 .43722 L
s
.858 .196 1 r
.8236 .37736 m
.82774 .42165 L
s
.712 .229 1 r
.53147 .37736 m
.53177 .41947 L
s
.7 .232 1 r
.23934 .37736 m
.23593 .4202 L
s
.712 .229 1 r
.92634 .43741 m
.92533 .42848 L
s
.92533 .42848 m
.92635 .43697 L
s
.522 .277 1 r
.30776 .43853 m
.30768 .43882 L
s
.56 .267 1 r
.76221 .41335 m
.76278 .42187 L
s
.7628 .42184 m
.76221 .41335 L
s
.76221 .41335 m
.7634 .42996 L
s
.367 .322 1 r
.20185 .41207 m
.20108 .41997 L
s
.20109 .41994 m
.20185 .41207 L
s
.20185 .41207 m
.20039 .42769 L
s
.599 .257 1 r
.57598 .44005 m
.57593 .44032 L
s
.345 .39 1 r
.46062 .42222 m
.46047 .42993 L
s
.46053 .42964 m
.46062 .42222 L
s
.46047 .42993 m
.46064 .42219 L
s
.46064 .42219 m
.46053 .42964 L
s
.733 .224 1 r
.39403 .44218 m
.39395 .44248 L
s
1 .151 .921 r
.43247 .44818 m
.4324 .44834 L
s
.416 .307 1 r
.86299 .42434 m
.86379 .43242 L
s
.86381 .43213 m
.86299 .42434 L
s
.669 .239 1 r
.68952 .37713 m
.69178 .41924 L
s
.744 .222 1 r
.39735 .37713 m
.39595 .41997 L
s
.416 .307 1 r
.86379 .43242 m
.86301 .42431 L
s
.86301 .42431 m
.86381 .43213 L
s
.904 .186 1 r
.29319 .43173 m
.29255 .44096 L
s
.29263 .44077 m
.29319 .43173 L
s
.56 .267 1 r
.33595 .41312 m
.33545 .42165 L
s
.33547 .42161 m
.33595 .41312 L
s
.33595 .41312 m
.33505 .42974 L
s
.799 .209 1 r
.66227 .44371 m
.66222 .4439 L
s
.904 .186 1 r
.29255 .44096 m
.2932 .43169 L
s
.2932 .43169 m
.29263 .44077 L
s
.754 .219 1 r
.76733 .4299 m
.76796 .43879 L
s
.768 .43864 m
.76733 .4299 L
s
.434 .302 1 r
.8101 .41133 m
.81076 .41952 L
s
.81078 .41948 m
.8101 .41133 L
s
.8101 .41133 m
.81146 .42724 L
s
.754 .219 1 r
.76796 .43879 m
.76736 .42986 L
s
.76736 .42986 m
.768 .43864 L
s
1 .098 .63 r
.64774 .43678 m
.64809 .44686 L
s
.64816 .4467 m
.64774 .43678 L
s
.362 .324 1 r
.8476 .3769 m
.85126 .41319 L
s
.342 .378 1 r
.5554 .3769 m
.55592 .41392 L
s
.599 .257 1 r
.2632 .3769 m
.2601 .41938 L
s
.36 .462 1 r
.58538 .43208 m
.58533 .43236 L
s
.8 .209 1 r
.93059 .44561 m
.9305 .44537 L
s
.765 .217 1 r
.8725 .41622 m
.87338 .42516 L
s
.87341 .42512 m
.8725 .41622 L
s
.8725 .41622 m
.87433 .43391 L
s
1 .098 .63 r
.64809 .44686 m
.64777 .43674 L
s
.64777 .43674 m
.64816 .4467 L
s
.61 .254 1 r
.54692 .42624 m
.54697 .43491 L
s
.54702 .43439 m
.54692 .42624 L
s
.869 .194 1 r
.82037 .44349 m
.82034 .4439 L
s
.61 .254 1 r
.54697 .43491 m
.54694 .4262 L
s
.54694 .4262 m
.54702 .43439 L
s
.953 .176 1 r
.79646 .44502 m
.79642 .44536 L
s
.969 .173 1 r
.89647 .41515 m
.89747 .4247 L
s
.8975 .42466 m
.89647 .41515 L
s
.89647 .41515 m
.89849 .43346 L
s
.531 .274 1 r
.57084 .42521 m
.57095 .43365 L
s
.571 .43322 m
.57084 .42521 L
s
.669 .239 1 r
.47007 .41457 m
.4699 .42332 L
s
.46992 .42328 m
.47007 .41457 L
s
.47007 .41457 m
.46981 .43178 L
s
.342 .378 1 r
.61869 .42257 m
.61889 .43024 L
s
.61894 .43014 m
.61869 .42257 L
s
.638 .247 1 r
.71349 .37667 m
.71603 .41842 L
s
.953 .176 1 r
.42125 .37667 m
.42009 .4217 L
s
.531 .274 1 r
.57095 .43365 m
.57086 .42517 L
s
.57086 .42517 m
.571 .43322 L
s
.81 .206 1 r
.2359 .44385 m
.23583 .44397 L
s
.342 .378 1 r
.61889 .43024 m
.61871 .42254 L
s
.61871 .42254 m
.61894 .43014 L
s
.476 .29 1 r
.43668 .42469 m
.43646 .43295 L
s
.43653 .43263 m
.43668 .42469 L
s
.43646 .43295 m
.4367 .42466 L
s
.4367 .42466 m
.43653 .43263 L
s
.418 .713 1 r
.58024 .41679 m
.58035 .42383 L
s
.58039 .4234 m
.58024 .41679 L
s
.477 .289 1 r
.51791 .41212 m
.51787 .42039 L
s
.51789 .42035 m
.51791 .41212 L
s
.51791 .41212 m
.5179 .42833 L
s
.418 .713 1 r
.58035 .42383 m
.58026 .41675 L
s
.58026 .41675 m
.58039 .4234 L
s
.777 .214 1 r
.71017 .44209 m
.71013 .44243 L
s
.433 .302 1 r
.53754 .43551 m
.53749 .43587 L
s
.777 .214 1 r
.94944 .42894 m
.95056 .43794 L
s
.95057 .4376 m
.94944 .42894 L
s
.733 .224 1 r
.36489 .42894 m
.36447 .43779 L
s
.36454 .4376 m
.36489 .42894 L
s
.36 .325 1 r
.48453 .42235 m
.48443 .43028 L
s
.48449 .42992 m
.48453 .42235 L
s
.823 .204 1 r
.87161 .37643 m
.87627 .41964 L
s
.744 .221 1 r
.57934 .37643 m
.58024 .41928 L
s
.589 .259 1 r
.28706 .37643 m
.28437 .41746 L
s
.777 .214 1 r
.95056 .43794 m
.94947 .4289 L
s
.94947 .4289 m
.95057 .4376 L
s
.733 .224 1 r
.36447 .43779 m
.36491 .4289 L
s
.36491 .4289 m
.36454 .4376 L
s
.57 .264 1 r
.22564 .4124 m
.22486 .42096 L
s
.22487 .42092 m
.22564 .4124 L
s
.22564 .4124 m
.2242 .42905 L
s
.36 .325 1 r
.48443 .43028 m
.48455 .42231 L
s
.48455 .42231 m
.48449 .42992 L
s
.799 .209 1 r
.49906 .42974 m
.49899 .43874 L
s
.49905 .43855 m
.49906 .42974 L
s
.20678 .42974 m
.20593 .43874 L
s
.20601 .43855 m
.20678 .42974 L
s
.845 .199 1 r
.84437 .44304 m
.84434 .44338 L
s
.799 .209 1 r
.49899 .43874 m
.49909 .4297 L
s
.49909 .4297 m
.49905 .43855 L
s
.20593 .43874 m
.2068 .4297 L
s
.2068 .4297 m
.20601 .43855 L
s
1 .146 .894 r
.45121 .43267 m
.45099 .44234 L
s
.45106 .442 m
.45121 .43267 L
s
.811 .206 1 r
.523 .42871 m
.52299 .43782 L
s
.52305 .43738 m
.523 .42871 L
s
.638 .247 1 r
.25462 .42739 m
.25392 .43603 L
s
.254 .43584 m
.25462 .42739 L
s
.363 .474 1 r
.43158 .40944 m
.43135 .41694 L
s
.43136 .41691 m
.43158 .40944 L
s
.43158 .40944 m
.43119 .4243 L
s
1 .146 .894 r
.45099 .44234 m
.45123 .43262 L
s
.45123 .43262 m
.45106 .442 L
s
.599 .257 1 r
.73747 .3762 m
.74024 .41686 L
s
.765 .217 1 r
.44516 .3762 m
.44434 .41978 L
s
.811 .206 1 r
.52299 .43782 m
.52302 .42867 L
s
.52302 .42867 m
.52305 .43738 L
s
.638 .247 1 r
.25392 .43603 m
.25463 .42735 L
s
.25463 .42735 m
.254 .43584 L
s
.67 .239 1 r
.33156 .43952 m
.33148 .43993 L
s
.34 .366 1 r
.27344 .41032 m
.27285 .41803 L
s
.27286 .418 m
.27344 .41032 L
s
.27344 .41032 m
.27233 .42561 L
s
.766 .217 1 r
.92052 .41499 m
.92152 .42396 L
s
.92156 .42392 m
.92052 .41499 L
s
.92052 .41499 m
.92259 .43264 L
s
.424 .305 1 r
.40765 .41101 m
.40734 .41913 L
s
.40736 .41909 m
.40765 .41101 L
s
.40765 .41101 m
.40712 .42692 L
s
.659 .242 1 r
.23066 .429 m
.2299 .43756 L
s
.22995 .43774 m
.23066 .429 L
s
.711 .229 1 r
.83926 .42768 m
.84008 .43654 L
s
.8401 .4362 m
.83926 .42768 L
s
.659 .242 1 r
.2299 .43756 m
.23067 .42896 L
s
.23067 .42896 m
.22995 .43774 L
s
.711 .229 1 r
.84008 .43654 m
.83929 .42764 L
s
.83929 .42764 m
.8401 .4362 L
s
.579 .262 1 r
.94016 .43835 m
.94014 .43865 L
s
.834 .201 1 r
.89564 .37597 m
.90069 .41992 L
s
.45 .297 1 r
.60329 .37597 m
.60439 .41481 L
s
.833 .201 1 r
.31094 .37597 m
.30834 .42028 L
s
.467 .292 1 r
.5948 .42533 m
.59496 .43345 L
s
.59501 .43349 m
.5948 .42533 L
s
.391 .315 1 r
.93503 .4227 m
.936 .4307 L
s
.93601 .43041 m
.93503 .4227 L
s
.467 .292 1 r
.59496 .43345 m
.59482 .4253 L
s
.59482 .4253 m
.59501 .43349 L
s
.391 .315 1 r
.936 .4307 m
.93506 .42266 L
s
.93506 .42266 m
.93601 .43041 L
s
.811 .206 1 r
.38878 .42877 m
.38841 .43785 L
s
.38849 .43752 m
.38878 .42877 L
s
.79 .211 1 r
.65214 .41413 m
.65245 .42322 L
s
.65248 .42317 m
.65214 .41413 L
s
.65214 .41413 m
.65283 .43182 L
s
.811 .206 1 r
.38841 .43785 m
.3888 .42873 L
s
.3888 .42873 m
.38849 .43752 L
s
.671 .239 1 r
.51363 .43813 m
.51356 .43875 L
s
.425 .305 1 r
.42727 .43483 m
.4272 .43516 L
s
.589 .259 1 r
.67178 .43754 m
.67174 .43798 L
s
.559 .267 1 r
.54185 .41231 m
.54187 .4208 L
s
.54189 .42076 m
.54185 .41231 L
s
.54185 .41231 m
.54196 .42896 L
s
.416 .307 1 r
.64268 .42299 m
.64296 .43106 L
s
.643 .43077 m
.64268 .42299 L
s
.701 .232 1 r
.76146 .37574 m
.76465 .41823 L
s
.425 .743 1 r
.46908 .37574 m
.46869 .40877 L
s
1 .144 .881 r
.17669 .37574 m
.17204 .42297 L
s
.494 .284 1 r
.24516 .43695 m
.24509 .43713 L
s
.416 .307 1 r
.64296 .43106 m
.6427 .42295 L
s
.6427 .42295 m
.643 .43077 L
s
.578 .262 1 r
.19728 .43966 m
.19722 .43963 L
s
.618 .252 1 r
.80603 .43849 m
.806 .43882 L
s
.712 .229 1 r
.6761 .41329 m
.67646 .42219 L
s
.67649 .42215 m
.6761 .41329 L
s
.6761 .41329 m
.67689 .43064 L
s
.588 .259 1 r
.37938 .4379 m
.37931 .43823 L
s
.4 .312 1 r
.58974 .41011 m
.58986 .41816 L
s
.58988 .41812 m
.58974 .41011 L
s
.58974 .41011 m
.59006 .42588 L
s
.869 .194 1 r
.91968 .3755 m
.92508 .41982 L
s
.881 .191 1 r
.62725 .3755 m
.62881 .41946 L
s
.733 .224 1 r
.33483 .3755 m
.3326 .41872 L
s
.368 .497 1 r
.81545 .43014 m
.81542 .43042 L
s
.777 .214 1 r
.89242 .44215 m
.89237 .44226 L
s
.569 .264 1 r
.24942 .41292 m
.24871 .42138 L
s
.24872 .42134 m
.24942 .41292 L
s
.24942 .41292 m
.24808 .42969 L
s
.701 .232 1 r
.70513 .42832 m
.70559 .43704 L
s
.70564 .43707 m
.70513 .42832 L
s
.649 .244 1 r
.75302 .42569 m
.7536 .43443 L
s
.75363 .43399 m
.75302 .42569 L
s
.777 .214 1 r
.62393 .44097 m
.62388 .44131 L
s
.701 .232 1 r
.70559 .43704 m
.70516 .42828 L
s
.70516 .42828 m
.70564 .43707 L
s
.649 .244 1 r
.7536 .43443 m
.75305 .42565 L
s
.75305 .42565 m
.75363 .43399 L
s
.589 .259 1 r
.69577 .43709 m
.69573 .43753 L
s
.504 .282 1 r
.78547 .37527 m
.78873 .41485 L
s
.894 .188 1 r
.49301 .37527 m
.49281 .41995 L
s
.531 .274 1 r
.20054 .37527 m
.19687 .41558 L
s
.4 .312 1 r
.47513 .43321 m
.47507 .43364 L
s
.68 .237 1 r
.70007 .41262 m
.7005 .42144 L
s
.70052 .4214 m
.70007 .41262 L
s
.70007 .41262 m
.70098 .42983 L
s
.734 .224 1 r
.83434 .41331 m
.83512 .42225 L
s
.83515 .42221 m
.83434 .41331 L
s
.83434 .41331 m
.83595 .43078 L
s
.904 .186 1 r
.35971 .4154 m
.35924 .42467 L
s
.35925 .42462 m
.35971 .4154 L
s
.35971 .4154 m
.35885 .43364 L
s
.836 .201 1 r
.88733 .42678 m
.88831 .43604 L
s
.88829 .4353 m
.88733 .42678 L
s
.4 .312 1 r
.69062 .4215 m
.69101 .42958 L
s
.69104 .42915 m
.69062 .4215 L
s
.836 .201 1 r
.88831 .43604 m
.88736 .42674 L
s
.88736 .42674 m
.88829 .4353 L
s
1 .166 .996 r
.73428 .44346 m
.73425 .44394 L
s
.4 .312 1 r
.69101 .42958 m
.69064 .42147 L
s
.69064 .42147 m
.69104 .42915 L
s
1 .161 .972 r
.78648 .41623 m
.78718 .42576 L
s
.7872 .42572 m
.78648 .41623 L
s
.78648 .41623 m
.78794 .43496 L
s
.811 .206 1 r
.38365 .41426 m
.38325 .42334 L
s
.38326 .4233 m
.38365 .41426 L
s
.38365 .41426 m
.38293 .4321 L
s
.608 .254 1 r
.56581 .41232 m
.56589 .42092 L
s
.56591 .42089 m
.56581 .41232 L
s
.56581 .41232 m
.56604 .42924 L
s
.395 .619 1 r
.65123 .37504 m
.65268 .40917 L
s
.588 .259 1 r
.35873 .37504 m
.35691 .41608 L
s
.339 .362 1 r
.60425 .41835 m
.60443 .42628 L
s
.60446 .42548 m
.60425 .41835 L
s
.60443 .42628 m
.60427 .41831 L
s
.60427 .41831 m
.60446 .42548 L
s
1 .159 .96 r
.62826 .41707 m
.62852 .42657 L
s
.62854 .42652 m
.62826 .41707 L
s
.62826 .41707 m
.62886 .43591 L
s
.514 .279 1 r
.7437 .4351 m
.74368 .43558 L
s
.724 .226 1 r
.85835 .41256 m
.85919 .4215 L
s
.85922 .42146 m
.85835 .41256 L
s
.85835 .41256 m
.86008 .42996 L
s
.399 .312 1 r
.90193 .43452 m
.90189 .43463 L
s
.618 .252 1 r
.56152 .43723 m
.56147 .43767 L
s
.579 .262 1 r
.35021 .42472 m
.34977 .43324 L
s
.34984 .43295 m
.35021 .42472 L
s
.811 .206 1 r
.80949 .37481 m
.81339 .4184 L
s
.494 .285 1 r
.51695 .37481 m
.51706 .41512 L
s
.638 .247 1 r
.22441 .37481 m
.2209 .41658 L
s
.494 .284 1 r
.45547 .41078 m
.45528 .41909 L
s
.45529 .41905 m
.45547 .41078 L
s
.45547 .41078 m
.45516 .42711 L
s
.579 .262 1 r
.34977 .43324 m
.35023 .42468 L
s
.35023 .42468 m
.34984 .43295 L
s
.953 .176 1 r
.41266 .42948 m
.41234 .43886 L
s
.41242 .43852 m
.41266 .42948 L
s
1 .123 .772 r
.95501 .44807 m
.95496 .44819 L
s
.648 .244 1 r
.77705 .42552 m
.7777 .43423 L
s
.77773 .4339 m
.77705 .42552 L
s
1 .154 .933 r
.28352 .44477 m
.28343 .44511 L
s
.777 .214 1 r
.48967 .44148 m
.4896 .44159 L
s
.953 .176 1 r
.41234 .43886 m
.41268 .42944 L
s
.41268 .42944 m
.41242 .43852 L
s
.648 .244 1 r
.7777 .43423 m
.77708 .42548 L
s
.77708 .42548 m
.77773 .4339 L
s
.857 .196 1 r
.27835 .42897 m
.27768 .43809 L
s
.27775 .43793 m
.27835 .42897 L
s
.846 .199 1 r
.3023 .42765 m
.30169 .43684 L
s
.30179 .43639 m
.3023 .42765 L
s
.658 .242 1 r
.32625 .42633 m
.32573 .435 L
s
.3258 .43485 m
.32625 .42633 L
s
.857 .196 1 r
.27768 .43809 m
.27836 .42892 L
s
.27836 .42892 m
.27775 .43793 L
s
.823 .204 1 r
.22106 .4403 m
.22096 .44078 L
s
.846 .199 1 r
.30169 .43684 m
.30232 .42761 L
s
.30232 .42761 m
.30179 .43639 L
s
.658 .242 1 r
.32573 .435 m
.32626 .42629 L
s
.32626 .42629 m
.3258 .43485 L
s
.991 .169 1 r
.75829 .44301 m
.75826 .44346 L
s
.857 .196 1 r
.91655 .44242 m
.91651 .44258 L
s
.669 .239 1 r
.72409 .41252 m
.72457 .42128 L
s
.7246 .42124 m
.72409 .41252 L
s
.72409 .41252 m
.72512 .42974 L
s
.67522 .37457 m
.6773 .41671 L
s
.469 .292 1 r
.38264 .37457 m
.38119 .41379 L
s
.68 .237 1 r
.2972 .41194 m
.29659 .42076 L
s
.2966 .42072 m
.2972 .41194 L
s
.2972 .41194 m
.29608 .42915 L
s
.337 .353 1 r
.50336 .40868 m
.50329 .41644 L
s
.50331 .4164 m
.50336 .40868 L
s
.50336 .40868 m
.50329 .42402 L
s
.658 .242 1 r
.1919 .4261 m
.19104 .43478 L
s
.19112 .43463 m
.1919 .4261 L
s
.618 .252 1 r
.50846 .42478 m
.50841 .43342 L
s
.50847 .43308 m
.50846 .42478 L
s
.66 .241 1 r
.74807 .41145 m
.74861 .42024 L
s
.74864 .4202 m
.74807 .41145 L
s
.74807 .41145 m
.74921 .42856 L
s
.658 .242 1 r
.19104 .43478 m
.19192 .42606 L
s
.19192 .42606 m
.19112 .43463 L
s
.618 .252 1 r
.50841 .43342 m
.50848 .42474 L
s
.50848 .42474 m
.50847 .43308 L
s
.367 .495 1 r
.94479 .41686 m
.94573 .42446 L
s
.9457 .42385 m
.94479 .41686 L
s
.94573 .42446 m
.94482 .41683 L
s
.94482 .41683 m
.9457 .42385 L
s
.383 .566 1 r
.83352 .37434 m
.83696 .40993 L
s
.833 .201 1 r
.54091 .37434 m
.54134 .41867 L
s
.569 .264 1 r
.2483 .37434 m
.2451 .41575 L
s
.495 .284 1 r
.849 .42243 m
.84979 .43077 L
s
.8498 .43037 m
.849 .42243 L
s
.649 .244 1 r
.71983 .43773 m
.71979 .43806 L
s
.495 .284 1 r
.84979 .43077 m
.84902 .42239 L
s
.84902 .42239 m
.8498 .43037 L
s
.522 .277 1 r
.47941 .41054 m
.47927 .41892 L
s
.47929 .41888 m
.47941 .41054 L
s
.47941 .41054 m
.47921 .42701 L
s
.383 .317 1 r
.44599 .4206 m
.4458 .4286 L
s
.44586 .42824 m
.44599 .4206 L
s
.4458 .4286 m
.44601 .42056 L
s
.44601 .42056 m
.44586 .42824 L
s
.522 .277 1 r
.3168 .43596 m
.31673 .43615 L
s
.589 .259 1 r
.69922 .37411 m
.70156 .41552 L
s
.648 .244 1 r
.40657 .37411 m
.40531 .41589 L
s
.658 .242 1 r
.26888 .43868 m
.26881 .43883 L
s
.648 .244 1 r
.61377 .41159 m
.61396 .4203 L
s
.61399 .42026 m
.61377 .41159 L
s
.61377 .41159 m
.61424 .42869 L
s
.601 .256 1 r
.79175 .4342 m
.79175 .43501 L
s
1 .161 .972 r
.72925 .42961 m
.72981 .43914 L
s
.72985 .4388 m
.72925 .42961 L
s
.476 .29 1 r
.2637 .42301 m
.26306 .4312 L
s
.26313 .43109 m
.2637 .42301 L
s
.45 .297 1 r
.65738 .43362 m
.65734 .43394 L
s
1 .161 .972 r
.72981 .43914 m
.72927 .42956 L
s
.72927 .42956 m
.72985 .4388 L
s
.712 .229 1 r
.90645 .41169 m
.90741 .42059 L
s
.90744 .42055 m
.90645 .41169 L
s
.90645 .41169 m
.90842 .42906 L
s
.588 .259 1 r
.60946 .43633 m
.60942 .43666 L
s
.476 .29 1 r
.26306 .4312 m
.26371 .42297 L
s
.26371 .42297 m
.26313 .43109 L
s
.68 .237 1 r
.32109 .4118 m
.32054 .42059 L
s
.32055 .42055 m
.32109 .4118 L
s
.32109 .4118 m
.32008 .42906 L
s
.45 .297 1 r
.369 .40917 m
.3686 .41737 L
s
.36862 .41733 m
.369 .40917 L
s
.369 .40917 m
.36829 .42524 L
s
.337 .332 1 r
.85757 .37388 m
.86141 .41092 L
s
.422 .731 1 r
.56488 .37388 m
.56544 .40656 L
s
.638 .247 1 r
.27219 .37388 m
.26924 .41602 L
s
.531 .274 1 r
.63343 .43515 m
.63339 .43548 L
s
.504 .282 1 r
.6617 .40928 m
.66201 .41766 L
s
.66203 .41762 m
.6617 .40928 L
s
.6617 .40928 m
.66238 .42561 L
s
1 .156 .946 r
.44173 .446 m
.44166 .44586 L
s
.929 .181 1 r
.91157 .42806 m
.91263 .43741 L
s
.91265 .43703 m
.91157 .42806 L
s
.711 .229 1 r
.37408 .42542 m
.37368 .43428 L
s
.37376 .43395 m
.37408 .42542 L
s
.522 .277 1 r
.71472 .42278 m
.71518 .43116 L
s
.71522 .43087 m
.71472 .42278 L
s
.929 .181 1 r
.91263 .43741 m
.9116 .42802 L
s
.9116 .42802 m
.91265 .43703 L
s
.711 .229 1 r
.37368 .43428 m
.3741 .42538 L
s
.3741 .42538 m
.37376 .43395 L
s
.522 .277 1 r
.71518 .43116 m
.71474 .42274 L
s
.71474 .42274 m
.71522 .43087 L
s
.424 .305 1 r
.68137 .4328 m
.68133 .43313 L
s
.88 .191 1 r
.88255 .41355 m
.88348 .42279 L
s
.88351 .42274 m
.88255 .41355 L
s
.88255 .41355 m
.88448 .43169 L
s
.559 .267 1 r
.34072 .43552 m
.34064 .43585 L
s
.649 .244 1 r
.72323 .37364 m
.72588 .41506 L
s
.68 .237 1 r
.43051 .37364 m
.42953 .41579 L
s
.608 .254 1 r
.18665 .41183 m
.18578 .42037 L
s
.18579 .42033 m
.18665 .41183 L
s
.18665 .41183 m
.18499 .42883 L
s
.811 .206 1 r
.8543 .43976 m
.85428 .4401 L
s
.789 .211 1 r
.87829 .43859 m
.87828 .43907 L
s
.916 .184 1 r
.88163 .37341 m
.88665 .41885 L
s
.669 .239 1 r
.58886 .37341 m
.58987 .41556 L
s
.523 .277 1 r
.2961 .37341 m
.29359 .41337 L
s
.648 .244 1 r
.18232 .43683 m
.18222 .43716 L
s
.711 .229 1 r
.345 .41156 m
.3445 .42043 L
s
.34452 .42039 m
.345 .41156 L
s
.345 .41156 m
.3441 .42897 L
s
.701 .232 1 r
.39802 .42497 m
.39768 .43379 L
s
.39775 .4335 m
.39802 .42497 L
s
.618 .252 1 r
.42199 .42365 m
.42172 .43229 L
s
.42179 .43195 m
.42199 .42365 L
s
.408 .31 1 r
.17713 .42101 m
.1763 .42902 L
s
.17638 .42887 m
.17713 .42101 L
s
.375 .32 1 r
.4939 .41969 m
.49382 .42766 L
s
.49387 .42733 m
.4939 .41969 L
s
.345 .39 1 r
.46053 .42964 m
.46047 .42993 L
s
.701 .232 1 r
.39768 .43379 m
.39804 .42493 L
s
.39804 .42493 m
.39775 .4335 L
s
.618 .252 1 r
.42172 .43229 m
.42201 .42361 L
s
.42201 .42361 m
.42179 .43195 L
s
.408 .31 1 r
.1763 .42902 m
.17715 .42097 L
s
.17715 .42097 m
.17638 .42887 L
s
.375 .32 1 r
.49382 .42766 m
.49391 .41965 L
s
.49391 .41965 m
.49387 .42733 L
s
.744 .222 1 r
.93058 .41178 m
.93161 .42072 L
s
.93164 .42068 m
.93058 .41178 L
s
.93058 .41178 m
.9327 .42933 L
s
.503 .282 1 r
.31154 .42181 m
.31101 .43015 L
s
.31108 .42982 m
.31154 .42181 L
s
.916 .184 1 r
.40318 .44108 m
.40311 .44142 L
s
.441 .3 1 r
.74726 .37318 m
.75004 .41241 L
s
.352 .327 1 r
.45446 .37318 m
.45386 .41096 L
s
.54 .272 1 r
.16165 .37318 m
.15743 .41424 L
s
.503 .282 1 r
.31101 .43015 m
.31155 .42177 L
s
.31155 .42177 m
.31108 .42982 L
s
.559 .267 1 r
.73876 .42262 m
.73929 .43111 L
s
.73933 .43078 m
.73876 .42262 L
s
.367 .322 1 r
.20108 .41997 m
.20031 .42787 L
s
.20039 .42769 m
.20108 .41997 L
s
.559 .267 1 r
.73929 .43111 m
.73879 .42258 L
s
.73879 .42258 m
.73933 .43078 L
s
.367 .322 1 r
.20031 .42787 m
.20109 .41994 L
s
.20109 .41994 m
.20039 .42769 L
s
.822 .204 1 r
.82525 .42606 m
.82605 .43519 L
s
.82608 .43481 m
.82525 .42606 L
s
.659 .242 1 r
.2396 .42606 m
.23887 .43463 L
s
.23892 .43481 m
.2396 .42606 L
s
.352 .427 1 r
.30642 .4061 m
.30591 .41375 L
s
.30592 .41371 m
.30642 .4061 L
s
.30642 .4061 m
.30548 .42111 L
s
.418 .713 1 r
.58039 .4234 m
.58035 .42383 L
s
.822 .204 1 r
.82605 .43519 m
.82528 .42602 L
s
.82528 .42602 m
.82608 .43481 L
s
.659 .242 1 r
.23887 .43463 m
.23961 .42602 L
s
.23961 .42602 m
.23892 .43481 L
s
.416 .307 1 r
.86381 .43213 m
.86379 .43242 L
s
.669 .239 1 r
.9057 .37294 m
.91067 .4151 L
s
.869 .194 1 r
.61286 .37294 m
.61423 .41729 L
s
.55 .269 1 r
.68575 .40961 m
.68612 .41807 L
s
.68614 .41803 m
.68575 .40961 L
s
.68575 .40961 m
.68655 .42624 L
s
.811 .206 1 r
.32002 .37294 m
.31758 .41656 L
s
.94 .179 1 r
.8013 .42767 m
.80205 .43702 L
s
.80209 .43672 m
.8013 .42767 L
s
.833 .201 1 r
.2156 .42767 m
.21477 .43669 L
s
.21484 .43672 m
.2156 .42767 L
s
.845 .199 1 r
.53243 .42635 m
.53244 .43551 L
s
.5325 .43517 m
.53243 .42635 L
s
.712 .229 1 r
.92635 .43697 m
.92634 .43741 L
s
.94 .179 1 r
.80205 .43702 m
.80133 .42763 L
s
.80133 .42763 m
.80209 .43672 L
s
.833 .201 1 r
.21477 .43669 m
.21562 .42763 L
s
.21562 .42763 m
.21484 .43672 L
s
.845 .199 1 r
.53244 .43551 m
.53245 .42631 L
s
.53245 .42631 m
.5325 .43517 L
s
.766 .216 1 r
.21051 .4118 m
.20966 .42078 L
s
.20967 .42074 m
.21051 .4118 L
s
.21051 .4118 m
.2089 .42947 L
s
.56 .267 1 r
.76278 .42187 m
.76337 .4304 L
s
.7634 .42996 m
.76278 .42187 L
s
.477 .289 1 r
.57529 .40792 m
.57539 .41623 L
s
.57541 .41619 m
.57529 .40792 L
s
.57529 .40792 m
.57556 .4241 L
s
.56 .267 1 r
.76337 .4304 m
.7628 .42184 L
s
.7628 .42184 m
.7634 .42996 L
s
.777 .214 1 r
.55641 .42532 m
.55649 .43433 L
s
.55654 .434 m
.55641 .42532 L
s
.712 .229 1 r
.28752 .424 m
.28688 .4329 L
s
.28698 .43246 m
.28752 .424 L
s
.618 .252 1 r
.39289 .41 m
.39253 .41865 L
s
.39255 .41861 m
.39289 .41 L
s
.39289 .41 m
.39226 .42697 L
s
.777 .214 1 r
.7713 .37271 m
.77467 .41596 L
s
.375 .32 1 r
.47842 .37271 m
.47808 .41086 L
s
.669 .239 1 r
.18554 .37271 m
.18147 .41523 L
s
.777 .214 1 r
.55649 .43433 m
.55643 .42528 L
s
.55643 .42528 m
.55654 .434 L
s
.712 .229 1 r
.28688 .4329 m
.28753 .42396 L
s
.28753 .42396 m
.28698 .43246 L
s
.504 .282 1 r
.86818 .40813 m
.869 .41652 L
s
.86903 .41648 m
.86818 .40813 L
s
.86818 .40813 m
.86986 .42447 L
s
.754 .219 1 r
.79625 .41216 m
.79693 .42107 L
s
.79696 .42103 m
.79625 .41216 L
s
.79625 .41216 m
.79768 .42983 L
s
.434 .302 1 r
.81076 .41952 m
.81144 .42772 L
s
.81146 .42724 m
.81076 .41952 L
s
.342 .378 1 r
.61894 .43014 m
.61889 .43024 L
s
.531 .274 1 r
.41686 .4089 m
.41657 .41732 L
s
.41659 .41729 m
.41686 .4089 L
s
.41686 .4089 m
.41636 .42542 L
s
.434 .302 1 r
.81144 .42772 m
.81078 .41948 L
s
.81078 .41948 m
.81146 .42724 L
s
.56 .267 1 r
.33545 .42165 m
.33497 .43017 L
s
.33505 .42974 m
.33545 .42165 L
s
.857 .196 1 r
.63783 .41304 m
.6381 .42217 L
s
.63813 .42212 m
.63783 .41304 L
s
.63783 .41304 m
.63845 .43115 L
s
.56 .267 1 r
.33497 .43017 m
.33547 .42161 L
s
.33547 .42161 m
.33505 .42974 L
s
.61 .254 1 r
.54702 .43439 m
.54697 .43491 L
s
.619 .251 1 r
.92978 .37248 m
.93487 .41318 L
s
.916 .184 1 r
.63686 .37248 m
.63857 .41719 L
s
.833 .201 1 r
.34395 .37248 m
.34178 .41683 L
s
1 .133 .827 r
.78256 .44583 m
.78249 .44581 L
s
.531 .274 1 r
.571 .43322 m
.57095 .43365 L
s
.36 .325 1 r
.48449 .42992 m
.48443 .43028 L
s
.777 .214 1 r
.82028 .41131 m
.82103 .42032 L
s
.82106 .42028 m
.82028 .41131 L
s
.82028 .41131 m
.82184 .42901 L
s
.408 .31 1 r
.44083 .40798 m
.4406 .416 L
s
.44062 .41596 m
.44083 .40798 L
s
.44083 .40798 m
.44045 .42388 L
s
.649 .244 1 r
.84426 .40999 m
.84505 .41871 L
s
.84507 .41867 m
.84426 .40999 L
s
.84426 .40999 m
.84589 .4271 L
s
1 .164 .985 r
.66691 .42803 m
.6673 .43752 L
s
.66735 .43722 m
.66691 .42803 L
s
.476 .29 1 r
.43653 .43263 m
.43646 .43295 L
s
.754 .219 1 r
.768 .43864 m
.76796 .43879 L
s
1 .164 .985 r
.6673 .43752 m
.66694 .42798 L
s
.66694 .42798 m
.66735 .43722 L
s
.823 .204 1 r
.23441 .41149 m
.2336 .42061 L
s
.23362 .42057 m
.23441 .41149 L
s
.23441 .41149 m
.2329 .42938 L
s
.904 .186 1 r
.29263 .44077 m
.29255 .44096 L
s
.68 .237 1 r
.25838 .4102 m
.25767 .419 L
s
.25768 .41896 m
.25838 .4102 L
s
.25838 .4102 m
.25705 .42747 L
s
.503 .282 1 r
.79535 .37224 m
.79875 .41222 L
s
.477 .289 1 r
.50239 .37224 m
.50233 .41149 L
s
.722 .227 1 r
.20944 .37224 m
.2056 .4155 L
s
.363 .474 1 r
.43135 .41694 m
.43113 .42444 L
s
.43119 .4243 m
.43135 .41694 L
s
.43113 .42444 m
.43136 .41691 L
s
.43136 .41691 m
.43119 .4243 L
s
.477 .289 1 r
.51787 .42039 m
.51785 .42866 L
s
.5179 .42833 m
.51787 .42039 L
s
.51785 .42866 m
.51789 .42035 L
s
.51789 .42035 m
.5179 .42833 L
s
.765 .217 1 r
.87338 .42516 m
.87429 .4341 L
s
.87433 .43391 m
.87338 .42516 L
s
.87429 .4341 m
.87341 .42512 L
s
.87341 .42512 m
.87433 .43391 L
s
.669 .239 1 r
.55133 .41056 m
.55137 .41929 L
s
.55139 .41925 m
.55133 .41056 L
s
.55133 .41056 m
.55149 .42783 L
s
.4699 .42332 m
.46975 .43207 L
s
.46981 .43178 m
.4699 .42332 L
s
.34 .366 1 r
.27285 .41803 m
.27227 .42575 L
s
.27233 .42561 m
.27285 .41803 L
s
.68 .237 1 r
.66088 .37201 m
.66278 .41381 L
s
.744 .222 1 r
.36789 .37201 m
.3661 .4149 L
s
1 .116 .73 r
.77238 .4147 m
.77307 .42471 L
s
.7731 .42467 m
.77238 .4147 L
s
.77238 .4147 m
.77383 .43429 L
s
.669 .239 1 r
.46975 .43207 m
.46992 .42328 L
s
.46992 .42328 m
.46981 .43178 L
s
.34 .366 1 r
.27227 .42575 m
.27286 .418 L
s
.27286 .418 m
.27233 .42561 L
s
.531 .274 1 r
.59931 .40821 m
.59947 .41664 L
s
.59949 .4166 m
.59931 .40821 L
s
.59931 .40821 m
.5997 .42474 L
s
.367 .322 1 r
.19577 .40627 m
.19498 .41422 L
s
.19499 .41418 m
.19577 .40627 L
s
.19577 .40627 m
.19428 .42188 L
s
.57 .264 1 r
.22486 .42096 m
.2241 .42953 L
s
.2242 .42905 m
.22486 .42096 L
s
.777 .214 1 r
.95057 .4376 m
.95056 .43794 L
s
.733 .224 1 r
.36454 .4376 m
.36447 .43779 L
s
.57 .264 1 r
.2241 .42953 m
.22487 .42092 L
s
.22487 .42092 m
.2242 .42905 L
s
.424 .305 1 r
.40734 .41913 m
.40705 .42725 L
s
.40712 .42692 m
.40734 .41913 L
s
.391 .315 1 r
.93601 .43041 m
.936 .4307 L
s
.4 .312 1 r
.48879 .40645 m
.48868 .41451 L
s
.48869 .41447 m
.48879 .40645 L
s
.48879 .40645 m
.48864 .42224 L
s
.408 .31 1 r
.81941 .37178 m
.82303 .41103 L
s
.799 .209 1 r
.52638 .37178 m
.52662 .41577 L
s
.608 .254 1 r
.23335 .37178 m
.22994 .41358 L
s
.424 .305 1 r
.40705 .42725 m
.40736 .41909 L
s
.40736 .41909 m
.40712 .42692 L
s
.513 .279 1 r
.62331 .40718 m
.62353 .4156 L
s
.62355 .41556 m
.62331 .40718 L
s
.62331 .40718 m
.62381 .42355 L
s
.638 .247 1 r
.254 .43584 m
.25392 .43603 L
s
.799 .209 1 r
.49905 .43855 m
.49899 .43874 L
s
.20601 .43855 m
.20593 .43874 L
s
.969 .173 1 r
.89747 .4247 m
.89852 .43427 L
s
.89849 .43346 m
.89747 .4247 L
s
.522 .277 1 r
.46479 .40802 m
.46462 .41641 L
s
.46464 .41637 m
.46479 .40802 L
s
.46479 .40802 m
.46453 .42451 L
s
1 .098 .63 r
.64816 .4467 m
.64809 .44686 L
s
.811 .206 1 r
.52305 .43738 m
.52299 .43782 L
s
.649 .244 1 r
.89238 .40875 m
.8933 .41751 L
s
.89333 .41747 m
.89238 .40875 L
s
.89238 .40875 m
.89425 .42583 L
s
.969 .173 1 r
.89852 .43427 m
.8975 .42466 L
s
.8975 .42466 m
.89849 .43346 L
s
.416 .307 1 r
.643 .43077 m
.64296 .43106 L
s
.467 .292 1 r
.59501 .43349 m
.59496 .43345 L
s
.375 .32 1 r
.68491 .37154 m
.68692 .4097 L
s
.476 .29 1 r
.39185 .37154 m
.39048 .41116 L
s
.711 .229 1 r
.8401 .4362 m
.84008 .43654 L
s
.659 .242 1 r
.22995 .43774 m
.2299 .43756 L
s
.512 .279 1 r
.17171 .40838 m
.17082 .4167 L
s
.17083 .41666 m
.17171 .40838 L
s
.17171 .40838 m
.17002 .42487 L
s
1 .146 .894 r
.52736 .41325 m
.52734 .42293 L
s
.52736 .42289 m
.52736 .41325 L
s
.52736 .41325 m
.5274 .43229 L
s
.766 .217 1 r
.92152 .42396 m
.92257 .43294 L
s
.92259 .43264 m
.92152 .42396 L
s
.916 .184 1 r
.84348 .37131 m
.84794 .41604 L
s
.977 .171 1 r
.55038 .37131 m
.55095 .41714 L
s
.733 .224 1 r
.25728 .37131 m
.25405 .41458 L
s
.766 .217 1 r
.92257 .43294 m
.92156 .42392 L
s
.92156 .42392 m
.92259 .43264 L
s
1 .146 .894 r
.45106 .442 m
.45099 .44234 L
s
.629 .249 1 r
.91645 .40804 m
.91742 .41676 L
s
.91745 .41672 m
.91645 .40804 L
s
.91645 .40804 m
.91843 .42501 L
s
.559 .267 1 r
.54187 .4208 m
.5419 .42929 L
s
.54196 .42896 m
.54187 .4208 L
s
.4 .312 1 r
.58986 .41816 m
.59001 .42621 L
s
.59006 .42588 m
.58986 .41816 L
s
.845 .199 1 r
.28224 .41082 m
.28156 .41999 L
s
.28157 .41995 m
.28224 .41082 L
s
.28224 .41082 m
.28098 .42883 L
s
.339 .362 1 r
.60446 .42548 m
.60443 .42628 L
s
.648 .244 1 r
.75791 .40885 m
.75847 .41757 L
s
.7585 .41753 m
.75791 .40885 L
s
.75791 .40885 m
.7591 .42596 L
s
.559 .267 1 r
.5419 .42929 m
.54189 .42076 L
s
.54189 .42076 m
.54196 .42896 L
s
.904 .186 1 r
.70992 .41152 m
.71039 .4208 L
s
.71041 .42076 m
.70992 .41152 L
s
.70992 .41152 m
.71093 .42979 L
s
.4 .312 1 r
.59001 .42621 m
.58988 .41812 L
s
.58988 .41812 m
.59006 .42588 L
s
.811 .206 1 r
.38849 .43752 m
.38841 .43785 L
s
.744 .221 1 r
.70896 .37108 m
.71153 .41435 L
s
.531 .274 1 r
.41581 .37108 m
.41472 .41106 L
s
.629 .249 1 r
.78193 .40781 m
.78256 .41653 L
s
.78258 .41649 m
.78193 .40781 L
s
.78193 .40781 m
.78324 .42478 L
s
.4 .312 1 r
.69104 .42915 m
.69101 .42958 L
s
.79 .211 1 r
.65245 .42322 m
.65279 .43231 L
s
.65283 .43182 m
.65245 .42322 L
s
.388 .587 1 r
.74335 .40191 m
.7438 .40927 L
s
.74382 .40923 m
.74335 .40191 L
s
.74335 .40191 m
.74429 .41619 L
s
.79 .211 1 r
.65279 .43231 m
.65248 .42317 L
s
.65248 .42317 m
.65283 .43182 L
s
.649 .244 1 r
.75363 .43399 m
.7536 .43443 L
s
.569 .264 1 r
.24871 .42138 m
.24801 .42984 L
s
.24808 .42969 m
.24871 .42138 L
s
.599 .257 1 r
.64736 .40736 m
.64765 .41601 L
s
.64767 .41597 m
.64736 .40736 L
s
.64736 .40736 m
.648 .42419 L
s
.569 .264 1 r
.24801 .42984 m
.24872 .42134 L
s
.24872 .42134 m
.24808 .42969 L
s
.712 .229 1 r
.67646 .42219 m
.67686 .43109 L
s
.67689 .43064 m
.67646 .42219 L
s
.425 .305 1 r
.86757 .37084 m
.87172 .40974 L
s
.522 .277 1 r
.57439 .37084 m
.57518 .41083 L
s
.441 .3 1 r
.28121 .37084 m
.27854 .41047 L
s
.712 .229 1 r
.67686 .43109 m
.67649 .42215 L
s
.67649 .42215 m
.67689 .43064 L
s
.822 .204 1 r
.73396 .41099 m
.73449 .42005 L
s
.73451 .42001 m
.73396 .41099 L
s
.73396 .41099 m
.73509 .42897 L
s
.701 .232 1 r
.70564 .43707 m
.70559 .43704 L
s
.367 .495 1 r
.9457 .42385 m
.94573 .42446 L
s
.836 .201 1 r
.88829 .4353 m
.88831 .43604 L
s
.503 .282 1 r
.73301 .37061 m
.73572 .41133 L
s
.744 .221 1 r
.43979 .37061 m
.43893 .41315 L
s
.618 .252 1 r
.80601 .40739 m
.80669 .41608 L
s
.80672 .41604 m
.80601 .40739 L
s
.80601 .40739 m
.80743 .42433 L
s
.68 .237 1 r
.7005 .42144 m
.70095 .43027 L
s
.70098 .42983 m
.7005 .42144 L
s
.70095 .43027 m
.70052 .4214 L
s
.70052 .4214 m
.70098 .42983 L
s
.649 .244 1 r
.94063 .40816 m
.94166 .41688 L
s
.94169 .41684 m
.94063 .40816 L
s
.94063 .40816 m
.94274 .42528 L
s
.734 .224 1 r
.83512 .42225 m
.83593 .43119 L
s
.83595 .43078 m
.83512 .42225 L
s
.608 .254 1 r
.56589 .42092 m
.56599 .42953 L
s
.56604 .42924 m
.56589 .42092 L
s
.734 .224 1 r
.83593 .43119 m
.83515 .42221 L
s
.83515 .42221 m
.83595 .43078 L
s
.579 .262 1 r
.34984 .43295 m
.34977 .43324 L
s
.608 .254 1 r
.56599 .42953 m
.56591 .42089 L
s
.56591 .42089 m
.56604 .42924 L
s
.494 .284 1 r
.45528 .41909 m
.4551 .4274 L
s
.45516 .42711 m
.45528 .41909 L
s
.337 .353 1 r
.50329 .41644 m
.50323 .4242 L
s
.50329 .42402 m
.50329 .41644 L
s
.916 .184 1 r
.89167 .37037 m
.89684 .41585 L
s
.45 .297 1 r
.59842 .37037 m
.59947 .40964 L
s
.733 .224 1 r
.30516 .37037 m
.30257 .41329 L
s
.494 .284 1 r
.4551 .4274 m
.45529 .41905 L
s
.45529 .41905 m
.45516 .42711 L
s
.337 .353 1 r
.50323 .4242 m
.50331 .4164 L
s
.50331 .4164 m
.50329 .42402 L
s
.648 .244 1 r
.77773 .4339 m
.7777 .43423 L
s
.904 .186 1 r
.35924 .42467 m
.35878 .43394 L
s
.35885 .43364 m
.35924 .42467 L
s
.811 .206 1 r
.38325 .42334 m
.38286 .43243 L
s
.38293 .4321 m
.38325 .42334 L
s
.904 .186 1 r
.35878 .43394 m
.35925 .42462 L
s
.35925 .42462 m
.35885 .43364 L
s
.811 .206 1 r
.38286 .43243 m
.38326 .4233 L
s
.38326 .4233 m
.38293 .4321 L
s
.724 .226 1 r
.85919 .4215 m
.86007 .43045 L
s
.86008 .42996 m
.85919 .4215 L
s
.588 .259 1 r
.75708 .37014 m
.76012 .41123 L
s
.701 .232 1 r
.46379 .37014 m
.46323 .41269 L
s
.345 .391 1 r
.1705 .37014 m
.16666 .40831 L
s
.658 .242 1 r
.3258 .43485 m
.32573 .435 L
s
.724 .226 1 r
.86007 .43045 m
.85922 .42146 L
s
.85922 .42146 m
.86008 .42996 L
s
.383 .317 1 r
.44586 .42824 m
.4458 .4286 L
s
.588 .259 1 r
.53679 .40704 m
.5368 .41562 L
s
.53682 .41558 m
.53679 .40704 L
s
.53679 .40704 m
.53688 .42387 L
s
1 .161 .972 r
.78718 .42576 m
.7879 .4353 L
s
.78794 .43496 m
.78718 .42576 L
s
.495 .284 1 r
.8498 .43037 m
.84979 .43077 L
s
.846 .199 1 r
.30179 .43639 m
.30169 .43684 L
s
.618 .252 1 r
.50847 .43308 m
.50841 .43342 L
s
1 .161 .972 r
.7879 .4353 m
.7872 .42572 L
s
.7872 .42572 m
.78794 .43496 L
s
1 .159 .96 r
.62852 .42657 m
.6288 .43607 L
s
.62886 .43591 m
.62852 .42657 L
s
.953 .176 1 r
.41242 .43852 m
.41234 .43886 L
s
.669 .239 1 r
.72457 .42128 m
.72508 .43003 L
s
.72512 .42974 m
.72457 .42128 L
s
.559 .267 1 r
.40214 .4066 m
.40181 .4151 L
s
.40182 .41506 m
.40214 .4066 L
s
.40214 .4066 m
.40156 .42328 L
s
1 .159 .96 r
.6288 .43607 m
.62854 .42652 L
s
.62854 .42652 m
.62886 .43591 L
s
.857 .196 1 r
.27775 .43793 m
.27768 .43809 L
s
.733 .224 1 r
.51278 .40861 m
.51272 .41753 L
s
.51274 .41748 m
.51278 .40861 L
s
.51278 .40861 m
.51274 .42615 L
s
.376 .32 1 r
.91578 .36991 m
.92045 .40845 L
s
.754 .219 1 r
.62245 .36991 m
.62393 .41356 L
s
.881 .191 1 r
.32912 .36991 m
.32676 .41429 L
s
.658 .242 1 r
.19112 .43463 m
.19104 .43478 L
s
.669 .239 1 r
.72508 .43003 m
.7246 .42124 L
s
.7246 .42124 m
.72512 .42974 L
s
.56 .267 1 r
.56081 .40604 m
.56087 .41458 L
s
.5609 .41454 m
.56081 .40604 L
s
.56081 .40604 m
.56101 .42269 L
s
.68 .237 1 r
.29659 .42076 m
.29598 .42959 L
s
.29608 .42915 m
.29659 .42076 L
s
.29598 .42959 m
.2966 .42072 L
s
.2966 .42072 m
.29608 .42915 L
s
.476 .29 1 r
.42614 .40549 m
.42588 .41377 L
s
.4259 .41374 m
.42614 .40549 L
s
.42614 .40549 m
.42569 .42173 L
s
.66 .241 1 r
.74861 .42024 m
.74919 .42904 L
s
.74921 .42856 m
.74861 .42024 L
s
.522 .277 1 r
.47927 .41892 m
.47915 .42731 L
s
.47921 .42701 m
.47927 .41892 L
s
.767 .216 1 r
.67147 .40827 m
.67183 .41729 L
s
.67186 .41725 m
.67147 .40827 L
s
.67147 .40827 m
.67226 .42591 L
s
.66 .241 1 r
.74919 .42904 m
.74864 .4202 L
s
.74864 .4202 m
.74921 .42856 L
s
.522 .277 1 r
.47915 .42731 m
.47929 .41888 L
s
.47929 .41888 m
.47921 .42701 L
s
.777 .214 1 r
.78116 .36967 m
.78467 .41296 L
s
.476 .29 1 r
.48779 .36967 m
.48755 .40931 L
s
.669 .239 1 r
.19443 .36967 m
.19049 .41186 L
s
.88 .191 1 r
.33007 .4111 m
.32952 .42024 L
s
.32954 .4202 m
.33007 .4111 L
s
.33007 .4111 m
.32905 .42937 L
s
.476 .29 1 r
.26313 .43109 m
.26306 .4312 L
s
.916 .184 1 r
.35409 .40988 m
.35359 .4192 L
s
.35361 .41916 m
.35409 .40988 L
s
.35409 .40988 m
.35319 .42819 L
s
.477 .289 1 r
.29145 .40526 m
.29086 .41354 L
s
.29087 .41351 m
.29145 .40526 L
s
.29145 .40526 m
.29036 .4215 L
s
.45 .297 1 r
.3686 .41737 m
.36822 .42557 L
s
.36829 .42524 m
.3686 .41737 L
s
.36822 .42557 m
.36862 .41733 L
s
.36862 .41733 m
.36829 .42524 L
s
.69 .234 1 r
.69551 .40742 m
.69593 .41626 L
s
.69595 .41622 m
.69551 .40742 L
s
.69551 .40742 m
.6964 .42473 L
s
.335 .34 1 r
.6465 .36944 m
.64804 .40689 L
s
.559 .267 1 r
.3531 .36944 m
.35122 .41017 L
s
.522 .277 1 r
.71522 .43087 m
.71518 .43116 L
s
.648 .244 1 r
.61396 .4203 m
.61419 .42903 L
s
.61424 .42869 m
.61396 .4203 L
s
.822 .204 1 r
.21937 .40962 m
.21853 .41868 L
s
.21854 .41864 m
.21937 .40962 L
s
.21937 .40962 m
.21778 .4276 L
s
.504 .282 1 r
.66201 .41766 m
.66234 .42604 L
s
.66238 .42561 m
.66201 .41766 L
s
.648 .244 1 r
.61419 .42903 m
.61399 .42026 L
s
.61399 .42026 m
.61424 .42869 L
s
.504 .282 1 r
.66234 .42604 m
.66203 .41762 L
s
.66203 .41762 m
.66238 .42561 L
s
.712 .229 1 r
.90741 .42059 m
.90841 .4295 L
s
.90842 .42906 m
.90741 .42059 L
s
.68 .237 1 r
.32054 .42059 m
.32 .42939 L
s
.32008 .42906 m
.32054 .42059 L
s
.26739 .40723 m
.2667 .41603 L
s
.26671 .41599 m
.26739 .40723 L
s
.26739 .40723 m
.26611 .4245 L
s
.608 .254 1 r
.71956 .40661 m
.72002 .41522 L
s
.72005 .41518 m
.71956 .40661 L
s
.71956 .40661 m
.72055 .42355 L
s
.834 .201 1 r
.80525 .3692 m
.80911 .41286 L
s
.66 .241 1 r
.51181 .3692 m
.51186 .41031 L
s
.569 .264 1 r
.21837 .3692 m
.21479 .41067 L
s
.711 .229 1 r
.37376 .43395 m
.37368 .43428 L
s
.712 .229 1 r
.90841 .4295 m
.90744 .42055 L
s
.90744 .42055 m
.90842 .42906 L
s
.68 .237 1 r
.32 .42939 m
.32055 .42055 L
s
.32055 .42055 m
.32008 .42906 L
s
.777 .214 1 r
.83026 .40865 m
.83103 .41765 L
s
.83106 .4176 m
.83026 .40865 L
s
.83026 .40865 m
.83188 .42641 L
s
.375 .32 1 r
.49387 .42733 m
.49382 .42766 L
s
1 .161 .972 r
.72985 .4388 m
.72981 .43914 L
s
.408 .31 1 r
.17638 .42887 m
.1763 .42902 L
s
.953 .176 1 r
.37807 .40964 m
.37763 .41904 L
s
.37765 .41899 m
.37807 .40964 L
s
.37807 .40964 m
.37729 .4281 L
s
.608 .254 1 r
.18578 .42037 m
.18492 .42891 L
s
.18499 .42883 m
.18578 .42037 L
s
.929 .181 1 r
.91265 .43703 m
.91263 .43741 L
s
.733 .224 1 r
.85432 .4077 m
.85515 .41661 L
s
.85518 .41657 m
.85432 .4077 L
s
.85432 .4077 m
.85604 .42523 L
s
.367 .322 1 r
.20039 .42769 m
.20031 .42787 L
s
.68 .237 1 r
.67056 .36897 m
.6726 .41117 L
s
.892 .189 1 r
.37708 .36897 m
.37532 .41409 L
s
.352 .427 1 r
.30591 .41375 m
.30541 .4214 L
s
.30548 .42111 m
.30591 .41375 L
s
.608 .254 1 r
.18492 .42891 m
.18579 .42033 L
s
.18579 .42033 m
.18499 .42883 L
s
.352 .427 1 r
.30541 .4214 m
.30592 .41371 L
s
.30592 .41371 m
.30548 .42111 L
s
.503 .282 1 r
.31108 .42982 m
.31101 .43015 L
s
.64 .246 1 r
.6089 .40516 m
.60909 .41396 L
s
.60911 .41392 m
.6089 .40516 L
s
.6089 .40516 m
.60934 .42213 L
s
.618 .252 1 r
.42179 .43195 m
.42172 .43229 L
s
.88 .191 1 r
.88348 .42279 m
.88445 .43203 L
s
.88448 .43169 m
.88348 .42279 L
s
.559 .267 1 r
.73933 .43078 m
.73929 .43111 L
s
.424 .305 1 r
.18063 .40479 m
.17979 .41286 L
s
.1798 .41282 m
.18063 .40479 L
s
.18063 .40479 m
.17903 .42082 L
s
.88 .191 1 r
.88445 .43203 m
.88351 .42274 L
s
.88351 .42274 m
.88448 .43169 L
s
.477 .289 1 r
.82936 .36874 m
.83311 .40802 L
s
.648 .244 1 r
.53584 .36874 m
.53618 .41057 L
s
.701 .232 1 r
.39775 .4335 m
.39768 .43379 L
s
.669 .239 1 r
.24232 .36874 m
.23892 .41167 L
s
.424 .305 1 r
.49818 .40368 m
.49809 .41182 L
s
.49811 .41178 m
.49818 .40368 L
s
.49818 .40368 m
.49808 .41963 L
s
.711 .229 1 r
.3445 .42043 m
.34402 .4293 L
s
.3441 .42897 m
.3445 .42043 L
s
.34402 .4293 m
.34452 .42039 L
s
.34452 .42039 m
.3441 .42897 L
s
.503 .282 1 r
.33939 .40456 m
.33891 .41292 L
s
.33892 .41288 m
.33939 .40456 L
s
.33939 .40456 m
.33852 .42095 L
s
.434 .302 1 r
.81146 .42724 m
.81144 .42772 L
s
.433 .302 1 r
.69464 .3685 m
.69683 .40815 L
s
.711 .229 1 r
.40108 .3685 m
.39973 .41107 L
s
.56 .267 1 r
.7634 .42996 m
.76337 .4304 L
s
.659 .242 1 r
.23892 .43481 m
.23887 .43463 L
s
.868 .194 1 r
.24325 .40999 m
.24247 .4191 L
s
.24249 .41905 m
.24325 .40999 L
s
.24325 .40999 m
.24177 .42824 L
s
.744 .222 1 r
.93161 .42072 m
.93268 .42966 L
s
.9327 .42933 m
.93161 .42072 L
s
.55 .269 1 r
.68612 .41807 m
.68651 .42653 L
s
.68655 .42624 m
.68612 .41807 L
s
.744 .222 1 r
.93268 .42966 m
.93164 .42068 L
s
.93164 .42068 m
.9327 .42933 L
s
.55 .269 1 r
.68651 .42653 m
.68614 .41803 L
s
.68614 .41803 m
.68655 .42624 L
s
.822 .204 1 r
.82608 .43481 m
.82605 .43519 L
s
.579 .262 1 r
.47415 .40547 m
.47399 .41402 L
s
.47401 .41398 m
.47415 .40547 L
s
.47415 .40547 m
.47392 .42227 L
s
.477 .289 1 r
.57539 .41623 m
.57551 .42454 L
s
.57556 .4241 m
.57539 .41623 L
s
.57551 .42454 m
.57541 .41619 L
s
.57541 .41619 m
.57556 .4241 L
s
.69 .234 1 r
.90251 .40628 m
.90346 .41512 L
s
.90349 .41508 m
.90251 .40628 L
s
.90251 .40628 m
.90446 .42359 L
s
.363 .474 1 r
.43119 .4243 m
.43113 .42444 L
s
.467 .292 1 r
.85348 .36827 m
.85754 .40792 L
s
.367 .322 1 r
.55988 .36827 m
.56047 .40682 L
s
.669 .239 1 r
.26629 .36827 m
.26323 .41084 L
s
.56 .267 1 r
.33505 .42974 m
.33497 .43017 L
s
.712 .229 1 r
.28698 .43246 m
.28688 .4329 L
s
.504 .282 1 r
.869 .41652 m
.86985 .42491 L
s
.86986 .42447 m
.869 .41652 L
s
.754 .219 1 r
.8785 .40782 m
.87939 .41673 L
s
.87942 .41669 m
.8785 .40782 L
s
.8785 .40782 m
.88036 .4255 L
s
.845 .199 1 r
.5325 .43517 m
.53244 .43551 L
s
.504 .282 1 r
.86985 .42491 m
.86903 .41648 L
s
.86903 .41648 m
.86986 .42447 L
s
.618 .252 1 r
.39253 .41865 m
.39219 .4273 L
s
.39226 .42697 m
.39253 .41865 L
s
.531 .274 1 r
.41657 .41732 m
.41629 .42575 L
s
.41636 .42542 m
.41657 .41732 L
s
.408 .31 1 r
.4406 .416 m
.4404 .42402 L
s
.44045 .42388 m
.4406 .416 L
s
.777 .214 1 r
.55654 .434 m
.55649 .43433 L
s
.7 .232 1 r
.58489 .408 m
.58502 .41673 L
s
.58504 .41669 m
.58489 .408 L
s
.58489 .408 m
.58522 .4255 L
s
.618 .252 1 r
.39219 .4273 m
.39255 .41861 L
s
.39255 .41861 m
.39226 .42697 L
s
.531 .274 1 r
.41629 .42575 m
.41659 .41729 L
s
.41659 .41729 m
.41636 .42542 L
s
.94 .179 1 r
.80209 .43672 m
.80205 .43702 L
s
.833 .201 1 r
.21484 .43672 m
.21477 .43669 L
s
.408 .31 1 r
.4404 .42402 m
.44062 .41596 L
s
.44062 .41596 m
.44045 .42388 L
s
.766 .216 1 r
.20966 .42078 m
.20881 .42977 L
s
.2089 .42947 m
.20966 .42078 L
s
.459 .294 1 r
.22859 .4034 m
.22785 .41165 L
s
.22786 .41161 m
.22859 .4034 L
s
.22859 .4034 m
.2272 .41954 L
s
1 .161 .972 r
.71872 .36803 m
.72157 .41353 L
s
1 .156 .946 r
.42509 .36803 m
.42395 .41427 L
s
.766 .216 1 r
.20881 .42977 m
.20967 .42074 L
s
.20967 .42074 m
.2089 .42947 L
s
.34 .366 1 r
.27233 .42561 m
.27227 .42575 L
s
.477 .289 1 r
.5179 .42833 m
.51785 .42866 L
s
.754 .219 1 r
.79693 .42107 m
.79764 .42998 L
s
.79768 .42983 m
.79693 .42107 L
s
.79764 .42998 m
.79696 .42103 L
s
.79696 .42103 m
.79768 .42983 L
s
.788 .212 1 r
.4501 .4078 m
.44987 .41679 L
s
.44989 .41675 m
.4501 .4078 L
s
.4501 .4078 m
.44973 .42564 L
s
.811 .206 1 r
.31529 .40717 m
.3147 .41627 L
s
.31472 .41623 m
.31529 .40717 L
s
.31529 .40717 m
.31421 .42505 L
s
.486 .287 1 r
.83993 .40251 m
.84068 .4109 L
s
.8407 .41087 m
.83993 .40251 L
s
.83993 .40251 m
.84146 .41872 L
s
.777 .214 1 r
.87761 .3678 m
.88236 .41111 L
s
.669 .239 1 r
.58394 .3678 m
.58489 .41001 L
s
.441 .3 1 r
.29027 .3678 m
.28772 .40709 L
s
.649 .244 1 r
.84505 .41871 m
.84586 .42743 L
s
.84589 .4271 m
.84505 .41871 L
s
.84586 .42743 m
.84507 .41867 L
s
.84507 .41867 m
.84589 .4271 L
s
.857 .196 1 r
.6381 .42217 m
.6384 .4313 L
s
.63845 .43115 m
.6381 .42217 L
s
.367 .322 1 r
.19498 .41422 m
.1942 .42217 L
s
.19428 .42188 m
.19498 .41422 L
s
.857 .196 1 r
.6384 .4313 m
.63813 .42212 L
s
.63813 .42212 m
.63845 .43115 L
s
.424 .305 1 r
.40712 .42692 m
.40705 .42725 L
s
.367 .322 1 r
.1942 .42217 m
.19499 .41418 L
s
.19499 .41418 m
.19428 .42188 L
s
.777 .214 1 r
.82103 .42032 m
.82181 .42935 L
s
.82184 .42901 m
.82103 .42032 L
s
.68 .237 1 r
.25767 .419 m
.25697 .4278 L
s
.25705 .42747 m
.25767 .419 L
s
.669 .239 1 r
.74282 .36756 m
.74577 .40978 L
s
.476 .29 1 r
.44912 .36756 m
.44842 .40722 L
s
.618 .252 1 r
.15541 .36756 m
.15106 .40905 L
s
.777 .214 1 r
.82181 .42935 m
.82106 .42028 L
s
.82106 .42028 m
.82184 .42901 L
s
.68 .237 1 r
.25697 .4278 m
.25768 .41896 L
s
.25768 .41896 m
.25705 .42747 L
s
.57 .264 1 r
.2242 .42905 m
.2241 .42953 L
s
.669 .239 1 r
.46981 .43178 m
.46975 .43207 L
s
.893 .189 1 r
.92674 .40646 m
.92781 .41582 L
s
.92784 .41578 m
.92674 .40646 L
s
.92674 .40646 m
.92891 .42459 L
s
.4 .312 1 r
.48868 .41451 m
.48858 .42256 L
s
.48864 .42224 m
.48868 .41451 L
s
.628 .249 1 r
.20446 .4058 m
.20362 .41443 L
s
.20363 .41439 m
.20446 .4058 L
s
.20446 .4058 m
.20287 .42291 L
s
1 .164 .985 r
.66735 .43722 m
.6673 .43752 L
s
.4 .312 1 r
.48858 .42256 m
.48869 .41447 L
s
.48869 .41447 m
.48864 .42224 L
s
.765 .217 1 r
.87433 .43391 m
.87429 .4341 L
s
.823 .204 1 r
.2336 .42061 m
.23281 .42975 L
s
.2329 .42938 m
.2336 .42061 L
s
.669 .239 1 r
.55137 .41929 m
.55143 .42802 L
s
.55149 .42783 m
.55137 .41929 L
s
.531 .274 1 r
.59947 .41664 m
.59965 .42507 L
s
.5997 .42474 m
.59947 .41664 L
s
.649 .244 1 r
.52223 .40462 m
.52219 .41339 L
s
.52221 .41335 m
.52223 .40462 L
s
.52223 .40462 m
.52224 .42172 L
s
.823 .204 1 r
.23281 .42975 m
.23362 .42057 L
s
.23362 .42057 m
.2329 .42938 L
s
.669 .239 1 r
.55143 .42802 m
.55139 .41925 L
s
.55139 .41925 m
.55149 .42783 L
s
.531 .274 1 r
.59965 .42507 m
.59949 .4166 L
s
.59949 .4166 m
.5997 .42474 L
s
.4 .312 1 r
.57032 .40209 m
.5704 .41015 L
s
.57042 .41012 m
.57032 .40209 L
s
.57032 .40209 m
.57055 .41789 L
s
.991 .169 1 r
.90175 .36733 m
.90703 .41247 L
s
.68 .237 1 r
.608 .36733 m
.60926 .40955 L
s
.588 .259 1 r
.31426 .36733 m
.31189 .40845 L
s
.744 .221 1 r
.65708 .4055 m
.6574 .41449 L
s
.65742 .41445 m
.65708 .4055 L
s
.65708 .4055 m
.65779 .42304 L
s
.513 .279 1 r
.62353 .4156 m
.62377 .42403 L
s
.62381 .42355 m
.62353 .4156 L
s
.62377 .42403 m
.62355 .41556 L
s
.62355 .41556 m
.62381 .42355 L
s
.522 .277 1 r
.46462 .41641 m
.46446 .4248 L
s
.46453 .42451 m
.46462 .41641 L
s
.46446 .4248 m
.46464 .41637 L
s
.46464 .41637 m
.46453 .42451 L
s
.4 .312 1 r
.59006 .42588 m
.59001 .42621 L
s
.916 .184 1 r
.76693 .36709 m
.77038 .41187 L
s
.833 .201 1 r
.47315 .36709 m
.47268 .41151 L
s
.608 .254 1 r
.17937 .36709 m
.17531 .40858 L
s
.388 .587 1 r
.7438 .40927 m
.74427 .41662 L
s
.74429 .41619 m
.7438 .40927 L
s
.74427 .41662 m
.74382 .40923 L
s
.74382 .40923 m
.74429 .41619 L
s
.512 .279 1 r
.17082 .4167 m
.16994 .42502 L
s
.17002 .42487 m
.17082 .4167 L
s
.916 .184 1 r
.63305 .40736 m
.63332 .41669 L
s
.63334 .41665 m
.63305 .40736 L
s
.63305 .40736 m
.63366 .42568 L
s
.648 .244 1 r
.38736 .40472 m
.38698 .41345 L
s
.38699 .41341 m
.38736 .40472 L
s
.38736 .40472 m
.38668 .42185 L
s
.512 .279 1 r
.16994 .42502 m
.17083 .41666 L
s
.17083 .41666 m
.17002 .42487 L
s
.969 .173 1 r
.89849 .43346 m
.89852 .43427 L
s
.522 .277 1 r
.7052 .40343 m
.70562 .41183 L
s
.70565 .41179 m
.7052 .40343 L
s
.7052 .40343 m
.7061 .41994 L
s
.649 .244 1 r
.8933 .41751 m
.89424 .42627 L
s
.89425 .42583 m
.8933 .41751 L
s
.833 .201 1 r
.76793 .40817 m
.76854 .41721 L
s
.76857 .41717 m
.76793 .40817 L
s
.76793 .40817 m
.76924 .42628 L
s
.649 .244 1 r
.89424 .42627 m
.89333 .41747 L
s
.89333 .41747 m
.89425 .42583 L
s
.788 .212 1 r
.79199 .40688 m
.79266 .41588 L
s
.79269 .41584 m
.79199 .40688 L
s
.79199 .40688 m
.79341 .42473 L
s
.559 .267 1 r
.54196 .42896 m
.5419 .42929 L
s
.4114 .40361 m
.41109 .41212 L
s
.41111 .41208 m
.4114 .40361 L
s
.4114 .40361 m
.41086 .42031 L
s
.66 .241 1 r
.9259 .36686 m
.93106 .40835 L
s
.41 .683 1 r
.63208 .36686 m
.63333 .4007 L
s
.881 .191 1 r
.33826 .36686 m
.33602 .41127 L
s
.46 .294 1 r
.88822 .40169 m
.88908 .40998 L
s
.8891 .40995 m
.88822 .40169 L
s
.88822 .40169 m
.88997 .4178 L
s
.766 .217 1 r
.92259 .43264 m
.92257 .43294 L
s
1 .116 .73 r
.77307 .42471 m
.7738 .43474 L
s
.77383 .43429 m
.77307 .42471 L
s
.629 .249 1 r
.91742 .41676 m
.91843 .42549 L
s
.91843 .42501 m
.91742 .41676 L
s
1 .116 .73 r
.7738 .43474 m
.7731 .42467 L
s
.7731 .42467 m
.77383 .43429 L
s
.391 .315 1 r
.79106 .36663 m
.79433 .40556 L
s
.559 .267 1 r
.4972 .36662 m
.49707 .40739 L
s
.88 .191 1 r
.20334 .36662 m
.19924 .41178 L
s
.629 .249 1 r
.91843 .42549 m
.91745 .41672 L
s
.91745 .41672 m
.91843 .42501 L
s
.591 .259 1 r
.59441 .40216 m
.59456 .41085 L
s
.59458 .41081 m
.59441 .40216 L
s
.59441 .40216 m
.59478 .41889 L
s
.648 .244 1 r
.75847 .41757 m
.75907 .4263 L
s
.7591 .42596 m
.75847 .41757 L
s
.75907 .4263 m
.7585 .41753 L
s
.7585 .41753 m
.7591 .42596 L
s
.425 .305 1 r
.45949 .40161 m
.45931 .40975 L
s
.45933 .40972 m
.45949 .40161 L
s
.45949 .40161 m
.45921 .41757 L
s
.569 .264 1 r
.24808 .42969 m
.24801 .42984 L
s
.917 .184 1 r
.81612 .40635 m
.81689 .41571 L
s
.81692 .41567 m
.81612 .40635 L
s
.81612 .40635 m
.81771 .42463 L
s
.79 .211 1 r
.65283 .43182 m
.65279 .43231 L
s
.629 .249 1 r
.78256 .41653 m
.78322 .42526 L
s
.78324 .42478 m
.78256 .41653 L
s
.495 .284 1 r
.65618 .36639 m
.65792 .40606 L
s
.711 .229 1 r
.36228 .36639 m
.36043 .40898 L
s
.629 .249 1 r
.78322 .42526 m
.78258 .41649 L
s
.78258 .41649 m
.78324 .42478 L
s
.845 .199 1 r
.28156 .41999 m
.28089 .42917 L
s
.28098 .42883 m
.28156 .41999 L
s
.712 .229 1 r
.67689 .43064 m
.67686 .43109 L
s
.599 .257 1 r
.64765 .41601 m
.64795 .42467 L
s
.648 .42419 m
.64765 .41601 L
s
.337 .353 1 r
.50329 .42402 m
.50323 .4242 L
s
.845 .199 1 r
.28089 .42917 m
.28157 .41995 L
s
.28157 .41995 m
.28098 .42883 L
s
.599 .257 1 r
.64795 .42467 m
.64767 .41597 L
s
.64767 .41597 m
.648 .42419 L
s
.904 .186 1 r
.71039 .4208 m
.71089 .43009 L
s
.71093 .42979 m
.71039 .4208 L
s
.71089 .43009 m
.71041 .42076 L
s
.71041 .42076 m
.71093 .42979 L
s
1 .146 .894 r
.52734 .42293 m
.52734 .43263 L
s
.5274 .43229 m
.52734 .42293 L
s
.441 .3 1 r
.16556 .40219 m
.16467 .41033 L
s
.16468 .4103 m
.16556 .40219 L
s
.16556 .40219 m
.16387 .4183 L
s
.811 .206 1 r
.5463 .40556 m
.54633 .41467 L
s
.54635 .41463 m
.5463 .40556 L
s
.5463 .40556 m
.54644 .42345 L
s
.559 .267 1 r
.30049 .40292 m
.2999 .41143 L
s
.29992 .41139 m
.30049 .40292 L
s
.30049 .40292 m
.29941 .41962 L
s
1 .146 .894 r
.52734 .43263 m
.52736 .42289 L
s
.52736 .42289 m
.5274 .43229 L
s
.469 .291 1 r
.81519 .36616 m
.81869 .40437 L
s
.916 .184 1 r
.52126 .36616 m
.52143 .41204 L
s
.628 .249 1 r
.22732 .36615 m
.22379 .40838 L
s
.88 .191 1 r
.36323 .40766 m
.36277 .41681 L
s
.36279 .41677 m
.36323 .40766 L
s
.36323 .40766 m
.36239 .42595 L
s
.494 .284 1 r
.45516 .42711 m
.4551 .4274 L
s
.68 .237 1 r
.70098 .42983 m
.70095 .43027 L
s
.608 .254 1 r
.56604 .42924 m
.56599 .42953 L
s
.917 .184 1 r
.25235 .40589 m
.25157 .41525 L
s
.25159 .41521 m
.25235 .40589 L
s
.25235 .40589 m
.25091 .42418 L
s
.857 .196 1 r
.68125 .40663 m
.68164 .41577 L
s
.68166 .41573 m
.68125 .40663 L
s
.68125 .40663 m
.68211 .42477 L
s
.822 .204 1 r
.73449 .42005 m
.73504 .42912 L
s
.73509 .42897 m
.73449 .42005 L
s
.618 .252 1 r
.80669 .41608 m
.80741 .42477 L
s
.80743 .42433 m
.80669 .41608 L
s
.4 .312 1 r
.34859 .4007 m
.34815 .40877 L
s
.34816 .40874 m
.34859 .4007 L
s
.34859 .4007 m
.34779 .41652 L
s
.822 .204 1 r
.73504 .42912 m
.73451 .42001 L
s
.73451 .42001 m
.73509 .42897 L
s
.416 .307 1 r
.68028 .36592 m
.68227 .40487 L
s
.822 .204 1 r
.38631 .36592 m
.38469 .41035 L
s
.734 .224 1 r
.83595 .43078 m
.83593 .43119 L
s
.618 .252 1 r
.80741 .42477 m
.80672 .41604 L
s
.80672 .41604 m
.80743 .42433 L
s
.649 .244 1 r
.94166 .41688 m
.94273 .42561 L
s
.94274 .42528 m
.94166 .41688 L
s
.777 .214 1 r
.86436 .40489 m
.86523 .41392 L
s
.86526 .41388 m
.86436 .40489 L
s
.86436 .40489 m
.86616 .42262 L
s
.649 .244 1 r
.94273 .42561 m
.94169 .41684 L
s
.94169 .41684 m
.94274 .42528 L
s
.701 .232 1 r
.7294 .40427 m
.7299 .41311 L
s
.72993 .41307 m
.7294 .40427 L
s
.7294 .40427 m
.73047 .42167 L
s
.362 .324 1 r
.84976 .39778 m
.85051 .40589 L
s
.85054 .40585 m
.84976 .39778 L
s
.84976 .39778 m
.85126 .41319 L
s
.589 .259 1 r
.83934 .36569 m
.84336 .40646 L
s
.79 .211 1 r
.54533 .36569 m
.54581 .40865 L
s
.45 .297 1 r
.25132 .36568 m
.24832 .405 L
s
.724 .226 1 r
.86008 .42996 m
.86007 .43045 L
s
.443 .299 1 r
.21359 .40061 m
.21282 .40883 L
s
.21283 .40879 m
.21359 .40061 L
s
.21359 .40061 m
.21214 .41665 L
s
.811 .206 1 r
.38293 .4321 m
.38286 .43243 L
s
.589 .259 1 r
.77758 .40212 m
.77819 .41074 L
s
.77822 .4107 m
.77758 .40212 L
s
.77758 .40212 m
.77885 .41893 L
s
.881 .191 1 r
.27635 .40554 m
.27564 .41479 L
s
.27566 .41475 m
.27635 .40554 L
s
.27635 .40554 m
.27504 .42372 L
s
.588 .259 1 r
.5368 .41562 m
.53682 .4242 L
s
.53688 .42387 m
.5368 .41562 L
s
.904 .186 1 r
.35885 .43364 m
.35878 .43394 L
s
.691 .234 1 r
.7044 .36545 m
.70682 .40696 L
s
.355 .439 1 r
.41035 .36545 m
.40926 .40258 L
s
.588 .259 1 r
.53682 .4242 m
.53682 .41558 L
s
.53682 .41558 m
.53688 .42387 L
s
.522 .277 1 r
.47921 .42701 m
.47915 .42731 L
s
.669 .239 1 r
.72512 .42974 m
.72508 .43003 L
s
.559 .267 1 r
.40181 .4151 m
.40149 .42361 L
s
.40156 .42328 m
.40181 .4151 L
s
.476 .29 1 r
.42588 .41377 m
.42563 .42206 L
s
.42569 .42173 m
.42588 .41377 L
s
.845 .199 1 r
.4354 .40509 m
.43513 .41427 L
s
.43515 .41423 m
.4354 .40509 L
s
.4354 .40509 m
.43495 .42313 L
s
.68 .237 1 r
.29608 .42915 m
.29598 .42959 L
s
.711 .229 1 r
.75353 .40377 m
.7541 .41265 L
s
.75412 .41261 m
.75353 .40377 L
s
.75353 .40377 m
.75473 .42121 L
s
.559 .267 1 r
.40149 .42361 m
.40182 .41506 L
s
.40182 .41506 m
.40156 .42328 L
s
.476 .29 1 r
.42563 .42206 m
.4259 .41374 L
s
.4259 .41374 m
.42569 .42173 L
s
.66 .241 1 r
.74921 .42856 m
.74919 .42904 L
s
.56 .267 1 r
.56087 .41458 m
.56096 .42313 L
s
.56101 .42269 m
.56087 .41458 L
s
.45 .297 1 r
.36829 .42524 m
.36822 .42557 L
s
.425 .743 1 r
.4689 .39517 m
.46876 .40213 L
s
.46878 .4021 m
.4689 .39517 L
s
.4689 .39517 m
.46869 .40877 L
s
.619 .252 1 r
.32446 .40322 m
.32393 .41185 L
s
.32394 .41181 m
.32446 .40322 L
s
.32446 .40322 m
.32348 .42025 L
s
.56 .267 1 r
.56096 .42313 m
.5609 .41454 L
s
.5609 .41454 m
.56101 .42269 L
s
1 .065 .43 r
.8635 .36522 m
.86871 .41442 L
s
.476 .29 1 r
.56942 .36521 m
.57014 .4049 L
s
.904 .186 1 r
.27533 .36521 m
.2722 .41038 L
s
.342 .378 1 r
.55576 .39869 m
.5558 .40646 L
s
.55582 .40643 m
.55576 .39869 L
s
.55576 .39869 m
.55592 .41392 L
s
.733 .224 1 r
.51272 .41753 m
.51268 .42644 L
s
.51274 .42615 m
.51272 .41753 L
s
.477 .289 1 r
.29086 .41354 m
.29028 .42183 L
s
.29036 .4215 m
.29086 .41354 L
s
.628 .249 1 r
.91264 .40351 m
.91359 .41213 L
s
.91362 .41209 m
.91264 .40351 L
s
.91264 .40351 m
.91462 .42062 L
s
.569 .264 1 r
.18943 .40284 m
.18857 .41132 L
s
.18858 .41128 m
.18943 .40284 L
s
.18943 .40284 m
.18779 .41966 L
s
.733 .224 1 r
.51268 .42644 m
.51274 .41748 L
s
.51274 .41748 m
.51274 .42615 L
s
1 .161 .972 r
.78794 .43496 m
.7879 .4353 L
s
.504 .282 1 r
.66238 .42561 m
.66234 .42604 L
s
.477 .289 1 r
.29028 .42183 m
.29087 .41351 L
s
.29087 .41351 m
.29036 .4215 L
s
.352 .427 1 r
.30548 .42111 m
.30541 .4214 L
s
.68 .237 1 r
.48354 .40309 m
.4834 .4119 L
s
.48342 .41186 m
.48354 .40309 L
s
.48354 .40309 m
.48335 .42039 L
s
.811 .206 1 r
.72853 .36498 m
.73139 .40868 L
s
.835 .201 1 r
.4344 .36498 m
.43345 .40868 L
s
1 .159 .96 r
.62886 .43591 m
.6288 .43607 L
s
.767 .216 1 r
.67183 .41729 m
.67222 .42633 L
s
.67226 .42591 m
.67183 .41729 L
s
.67222 .42633 m
.67186 .41725 L
s
.67186 .41725 m
.67226 .42591 L
s
.648 .244 1 r
.61424 .42869 m
.61419 .42903 L
s
.588 .259 1 r
.50761 .40198 m
.50754 .41057 L
s
.50756 .41053 m
.50761 .40198 L
s
.50761 .40198 m
.50755 .41884 L
s
.551 .269 1 r
.93678 .40268 m
.93777 .4111 L
s
.9378 .41106 m
.93678 .40268 L
s
.93678 .40268 m
.93883 .41943 L
s
.589 .259 1 r
.66673 .40143 m
.66706 .41005 L
s
.66708 .41001 m
.66673 .40143 L
s
.66673 .40143 m
.66746 .41824 L
s
.88 .191 1 r
.32952 .42024 m
.32898 .42938 L
s
.32905 .42937 m
.32952 .42024 L
s
.69 .234 1 r
.69593 .41626 m
.69637 .4251 L
s
.6964 .42473 m
.69593 .41626 L
s
.88 .191 1 r
.32898 .42938 m
.32954 .4202 L
s
.32954 .4202 m
.32905 .42937 L
s
.869 .194 1 r
.88768 .36474 m
.89269 .40919 L
s
.881 .191 1 r
.59351 .36474 m
.59463 .40882 L
s
.744 .222 1 r
.29935 .36474 m
.29663 .40845 L
s
.69 .234 1 r
.69637 .4251 m
.69595 .41622 L
s
.69595 .41622 m
.6964 .42473 L
s
.712 .229 1 r
.90842 .42906 m
.90841 .4295 L
s
.68 .237 1 r
.32008 .42906 m
.32 .42939 L
s
.916 .184 1 r
.35359 .4192 m
.35311 .42853 L
s
.35319 .42819 m
.35359 .4192 L
s
.608 .254 1 r
.72002 .41522 m
.72051 .42384 L
s
.72055 .42355 m
.72002 .41522 L
s
.916 .184 1 r
.35311 .42853 m
.35361 .41916 L
s
.35361 .41916 m
.35319 .42819 L
s
.608 .254 1 r
.72051 .42384 m
.72005 .41518 L
s
.72005 .41518 m
.72055 .42355 L
s
.822 .204 1 r
.21853 .41868 m
.2177 .42775 L
s
.21778 .4276 m
.21853 .41868 L
s
.68 .237 1 r
.2667 .41603 m
.26602 .42484 L
s
.26611 .4245 m
.2667 .41603 L
s
.822 .204 1 r
.2177 .42775 m
.21854 .41864 L
s
.21854 .41864 m
.21778 .4276 L
s
.569 .264 1 r
.75267 .36451 m
.75568 .40603 L
s
.88 .191 1 r
.45847 .36451 m
.45781 .40895 L
s
.495 .284 1 r
.16427 .36451 m
.16009 .4053 L
s
.68 .237 1 r
.26602 .42484 m
.26671 .41599 L
s
.26671 .41599 m
.26611 .4245 L
s
.608 .254 1 r
.18499 .42883 m
.18492 .42891 L
s
.424 .305 1 r
.17979 .41286 m
.17896 .42093 L
s
.17903 .42082 m
.17979 .41286 L
s
.17896 .42093 m
.1798 .41282 L
s
.1798 .41282 m
.17903 .42082 L
s
.777 .214 1 r
.83103 .41765 m
.83184 .42664 L
s
.83188 .42641 m
.83103 .41765 L
s
.83184 .42664 m
.83106 .4176 L
s
.83106 .4176 m
.83188 .42641 L
s
.395 .619 1 r
.65213 .39501 m
.65238 .4023 L
s
.6524 .40227 m
.65213 .39501 L
s
.65213 .39501 m
.65268 .40917 L
s
.424 .305 1 r
.49809 .41182 m
.49802 .41996 L
s
.49808 .41963 m
.49809 .41182 L
s
.8 .209 1 r
.91186 .36427 m
.9172 .40871 L
s
.669 .239 1 r
.61762 .36427 m
.61901 .40689 L
s
.777 .214 1 r
.32339 .36427 m
.32098 .40799 L
s
.424 .305 1 r
.49802 .41996 m
.49811 .41178 L
s
.49811 .41178 m
.49808 .41963 L
s
.733 .224 1 r
.85515 .41661 m
.85601 .42553 L
s
.85604 .42523 m
.85515 .41661 L
s
.64 .246 1 r
.60909 .41396 m
.6093 .42276 L
s
.60934 .42213 m
.60909 .41396 L
s
.733 .224 1 r
.85601 .42553 m
.85518 .41657 L
s
.85518 .41657 m
.85604 .42523 L
s
.64 .246 1 r
.6093 .42276 m
.60911 .41392 L
s
.60911 .41392 m
.60934 .42213 L
s
.477 .289 1 r
.57556 .4241 m
.57551 .42454 L
s
.712 .229 1 r
.53171 .40206 m
.5317 .41098 L
s
.53172 .41094 m
.53171 .40206 L
s
.53171 .40206 m
.53177 .41947 L
s
.55 .269 1 r
.68655 .42624 m
.68651 .42653 L
s
.503 .282 1 r
.33891 .41292 m
.33844 .42128 L
s
.33852 .42095 m
.33891 .41292 L
s
.68 .237 1 r
.77682 .36404 m
.7802 .40629 L
s
.559 .267 1 r
.48254 .36404 m
.48223 .40483 L
s
.777 .214 1 r
.18827 .36404 m
.18407 .40812 L
s
.711 .229 1 r
.3441 .42897 m
.34402 .4293 L
s
.503 .282 1 r
.33844 .42128 m
.33892 .41288 L
s
.33892 .41288 m
.33852 .42095 L
s
.88 .191 1 r
.88448 .43169 m
.88445 .43203 L
s
.953 .176 1 r
.37763 .41904 m
.37721 .42844 L
s
.37729 .4281 m
.37763 .41904 L
s
.754 .219 1 r
.8019 .40368 m
.80259 .41261 L
s
.80262 .41256 m
.8019 .40368 L
s
.8019 .40368 m
.80337 .42139 L
s
1 .154 .933 r
.61862 .4057 m
.61886 .41533 L
s
.61888 .41528 m
.61862 .4057 L
s
.61862 .4057 m
.61917 .42463 L
s
.953 .176 1 r
.37721 .42844 m
.37765 .41899 L
s
.37765 .41899 m
.37729 .4281 L
s
.504 .282 1 r
.86986 .42447 m
.86985 .42491 L
s
.408 .31 1 r
.44045 .42388 m
.4404 .42402 L
s
.722 .227 1 r
.3725 .40323 m
.37208 .41209 L
s
.3721 .41204 m
.3725 .40323 L
s
.3725 .40323 m
.37174 .42079 L
s
.744 .222 1 r
.9327 .42933 m
.93268 .42966 L
s
.579 .262 1 r
.47399 .41402 m
.47386 .42257 L
s
.47392 .42227 m
.47399 .41402 L
s
.669 .239 1 r
.69091 .40198 m
.69131 .41076 L
s
.69133 .41072 m
.69091 .40198 L
s
.69091 .40198 m
.69178 .41924 L
s
.503 .282 1 r
.64175 .3638 m
.64334 .40386 L
s
.7 .232 1 r
.34743 .3638 m
.34537 .40679 L
s
.579 .262 1 r
.47386 .42257 m
.47401 .41398 L
s
.47401 .41398 m
.47392 .42227 L
s
.531 .274 1 r
.41636 .42542 m
.41629 .42575 L
s
.7 .232 1 r
.23738 .40275 m
.23661 .41156 L
s
.23663 .41152 m
.23738 .40275 L
s
.23738 .40275 m
.23593 .4202 L
s
.45 .297 1 r
.60399 .39874 m
.60416 .40699 L
s
.60418 .40696 m
.60399 .39874 L
s
.60399 .39874 m
.60439 .41481 L
s
.618 .252 1 r
.39226 .42697 m
.39219 .4273 L
s
.459 .294 1 r
.22785 .41165 m
.22711 .4199 L
s
.2272 .41954 m
.22785 .41165 L
s
.22711 .4199 m
.22786 .41161 L
s
.22786 .41161 m
.2272 .41954 L
s
.868 .194 1 r
.24247 .4191 m
.2417 .42821 L
s
.24177 .42824 m
.24247 .4191 L
s
.422 .731 1 r
.56525 .39295 m
.56532 .39999 L
s
.56533 .39996 m
.56525 .39295 L
s
.56525 .39295 m
.56544 .40656 L
s
.69 .234 1 r
.90346 .41512 m
.90445 .42396 L
s
.90446 .42359 m
.90346 .41512 L
s
.744 .222 1 r
.39659 .40237 m
.39622 .41133 L
s
.39624 .41129 m
.39659 .40237 L
s
.39659 .40237 m
.39595 .41997 L
s
.868 .194 1 r
.2417 .42821 m
.24249 .41905 L
s
.24249 .41905 m
.24177 .42824 L
s
.352 .327 1 r
.80099 .36357 m
.80429 .40144 L
s
.589 .259 1 r
.50664 .36357 m
.50662 .40436 L
s
.459 .295 1 r
.21228 .36357 m
.20875 .40363 L
s
.69 .234 1 r
.90445 .42396 m
.90349 .41508 L
s
.90349 .41508 m
.90446 .42359 L
s
.367 .322 1 r
.19428 .42188 m
.1942 .42217 L
s
.589 .259 1 r
.28554 .4006 m
.28491 .40919 L
s
.28492 .40915 m
.28554 .4006 L
s
.28554 .4006 m
.28437 .41746 L
s
.638 .247 1 r
.71504 .4013 m
.7155 .41 L
s
.71553 .40997 m
.71504 .4013 L
s
.71504 .4013 m
.71603 .41842 L
s
.754 .219 1 r
.87939 .41673 m
.88032 .42566 L
s
.88036 .4255 m
.87939 .41673 L
s
.7 .232 1 r
.58502 .41673 m
.58516 .42547 L
s
.58522 .4255 m
.58502 .41673 L
s
.599 .257 1 r
.73915 .40001 m
.73967 .40867 L
s
.73969 .40863 m
.73915 .40001 L
s
.73915 .40001 m
.74024 .41686 L
s
.766 .216 1 r
.2089 .42947 m
.20881 .42977 L
s
.754 .219 1 r
.88032 .42566 m
.87942 .41669 L
s
.87942 .41669 m
.88036 .4255 L
s
.7 .232 1 r
.58516 .42547 m
.58504 .41669 L
s
.58504 .41669 m
.58522 .4255 L
s
.388 .587 1 r
.74429 .41619 m
.74427 .41662 L
s
.486 .287 1 r
.84068 .4109 m
.84146 .4193 L
s
.84146 .41872 m
.84068 .4109 L
s
.4 .312 1 r
.48864 .42224 m
.48858 .42256 L
s
.777 .214 1 r
.66588 .36333 m
.66792 .40669 L
s
.569 .264 1 r
.37149 .36333 m
.36983 .40413 L
s
.858 .196 1 r
.82611 .40353 m
.82689 .41272 L
s
.82692 .41268 m
.82611 .40353 L
s
.82611 .40353 m
.82774 .42165 L
s
.486 .287 1 r
.84146 .4193 m
.8407 .41087 L
s
.8407 .41087 m
.84146 .41872 L
s
.599 .257 1 r
.2614 .40232 m
.26072 .41081 L
s
.26074 .41078 m
.2614 .40232 L
s
.2614 .40232 m
.2601 .41938 L
s
.649 .244 1 r
.84589 .4271 m
.84586 .42743 L
s
.754 .219 1 r
.79768 .42983 m
.79764 .42998 L
s
.521 .277 1 r
.82517 .3631 m
.82901 .4039 L
s
.744 .222 1 r
.53074 .3631 m
.53103 .40609 L
s
.375 .32 1 r
.23631 .3631 m
.23315 .40207 L
s
.531 .274 1 r
.5997 .42474 m
.59965 .42507 L
s
.788 .212 1 r
.44987 .41679 m
.44966 .42579 L
s
.44973 .42564 m
.44987 .41679 L
s
.68 .237 1 r
.25705 .42747 m
.25697 .4278 L
s
.4 .312 1 r
.5704 .41015 m
.5705 .41822 L
s
.57055 .41789 m
.5704 .41015 L
s
.788 .212 1 r
.44966 .42579 m
.44989 .41675 L
s
.44989 .41675 m
.44973 .42564 L
s
.383 .566 1 r
.83561 .39543 m
.83625 .40277 L
s
.83628 .40273 m
.83561 .39543 L
s
.83561 .39543 m
.83696 .40993 L
s
.513 .279 1 r
.62381 .42355 m
.62377 .42403 L
s
.4 .312 1 r
.5705 .41822 m
.57042 .41012 L
s
.57042 .41012 m
.57055 .41789 L
s
.811 .206 1 r
.3147 .41627 m
.31413 .42538 L
s
.31421 .42505 m
.3147 .41627 L
s
.777 .214 1 r
.82184 .42901 m
.82181 .42935 L
s
.811 .206 1 r
.31413 .42538 m
.31472 .41623 L
s
.31472 .41623 m
.31421 .42505 L
s
.628 .249 1 r
.20362 .41443 m
.20279 .42306 L
s
.20287 .42291 m
.20362 .41443 L
s
.744 .221 1 r
.57993 .40168 m
.58005 .41064 L
s
.58007 .4106 m
.57993 .40168 L
s
.57993 .40168 m
.58024 .41928 L
s
.857 .196 1 r
.63845 .43115 m
.6384 .4313 L
s
.477 .289 1 r
.69003 .36286 m
.69218 .40257 L
s
.628 .249 1 r
.39556 .36286 m
.39414 .40513 L
s
.669 .239 1 r
.55149 .42783 m
.55143 .42802 L
s
.823 .204 1 r
.87441 .40175 m
.87532 .41093 L
s
.87535 .41089 m
.87441 .40175 L
s
.87441 .40175 m
.87627 .41964 L
s
.628 .249 1 r
.20279 .42306 m
.20363 .41439 L
s
.20363 .41439 m
.20287 .42291 L
s
.522 .277 1 r
.46453 .42451 m
.46446 .4248 L
s
.504 .282 1 r
.78744 .39847 m
.78806 .40688 L
s
.78808 .40684 m
.78744 .39847 L
s
.78744 .39847 m
.78873 .41485 L
s
.823 .204 1 r
.2329 .42938 m
.23281 .42975 L
s
.649 .244 1 r
.52219 .41339 m
.52218 .42216 L
s
.52224 .42172 m
.52219 .41339 L
s
.52218 .42216 m
.52221 .41335 L
s
.52221 .41335 m
.52224 .42172 L
s
.512 .279 1 r
.17002 .42487 m
.16994 .42502 L
s
.4 .312 1 r
.84936 .36262 m
.85328 .40124 L
s
.367 .497 1 r
.55485 .36262 m
.55535 .39869 L
s
.765 .217 1 r
.26035 .36262 m
.25706 .40709 L
s
.531 .274 1 r
.19844 .39901 m
.1976 .40746 L
s
.19762 .40742 m
.19844 .39901 L
s
.19844 .39901 m
.19687 .41558 L
s
.893 .189 1 r
.92781 .41582 m
.92892 .42519 L
s
.92891 .42459 m
.92781 .41582 L
s
.744 .221 1 r
.6574 .41449 m
.65775 .42349 L
s
.65779 .42304 m
.6574 .41449 L
s
.649 .244 1 r
.89425 .42583 m
.89424 .42627 L
s
.522 .277 1 r
.70562 .41183 m
.70606 .42024 L
s
.7061 .41994 m
.70562 .41183 L
s
.893 .189 1 r
.92892 .42519 m
.92784 .41578 L
s
.92784 .41578 m
.92891 .42459 L
s
.744 .221 1 r
.65775 .42349 m
.65742 .41445 L
s
.65742 .41445 m
.65779 .42304 L
s
.522 .277 1 r
.70606 .42024 m
.70565 .41179 L
s
.70565 .41179 m
.7061 .41994 L
s
.953 .176 1 r
.42063 .40321 m
.42031 .41262 L
s
.42033 .41257 m
.42063 .40321 L
s
.42063 .40321 m
.42009 .4217 L
s
.46 .294 1 r
.88908 .40998 m
.88996 .41828 L
s
.88997 .4178 m
.88908 .40998 L
s
.777 .214 1 r
.71419 .36239 m
.71687 .40612 L
s
.618 .252 1 r
.41965 .36239 m
.41855 .40393 L
s
.46 .294 1 r
.88996 .41828 m
.8891 .40995 L
s
.8891 .40995 m
.88997 .4178 L
s
.765 .217 1 r
.44473 .40203 m
.44449 .41099 L
s
.44451 .41095 m
.44473 .40203 L
s
.44473 .40203 m
.44434 .41978 L
s
.648 .244 1 r
.38698 .41345 m
.38661 .42219 L
s
.38668 .42185 m
.38698 .41345 L
s
.559 .267 1 r
.41109 .41212 m
.41079 .42064 L
s
.41086 .42031 m
.41109 .41212 L
s
.648 .244 1 r
.38661 .42219 m
.38699 .41341 L
s
.38699 .41341 m
.38668 .42185 L
s
.559 .267 1 r
.41079 .42064 m
.41111 .41208 L
s
.41111 .41208 m
.41086 .42031 L
s
.701 .232 1 r
.76341 .40081 m
.764 .40966 L
s
.76402 .40962 m
.76341 .40081 L
s
.76341 .40081 m
.76465 .41823 L
s
1 .091 .585 r
.64284 .40758 m
.64316 .41778 L
s
.64319 .41773 m
.64284 .40758 L
s
.64284 .40758 m
.64357 .42783 L
s
.337 .332 1 r
.85987 .39554 m
.86063 .40346 L
s
.86065 .40343 m
.85987 .39554 L
s
.85987 .39554 m
.86141 .41092 L
s
.629 .249 1 r
.91843 .42501 m
.91843 .42549 L
s
.469 .292 1 r
.38185 .39759 m
.38147 .4059 L
s
.38149 .40586 m
.38185 .39759 L
s
.38185 .39759 m
.38119 .41379 L
s
.425 .305 1 r
.45931 .40975 m
.45915 .4179 L
s
.45921 .41757 m
.45931 .40975 L
s
.756 .219 1 r
.87356 .36215 m
.87821 .40479 L
s
.588 .259 1 r
.57898 .36215 m
.57985 .40333 L
s
.618 .252 1 r
.2844 .36215 m
.28163 .40369 L
s
.425 .305 1 r
.45915 .4179 m
.45933 .40972 L
s
.45933 .40972 m
.45921 .41757 L
s
.833 .201 1 r
.76854 .41721 m
.76918 .42625 L
s
.76924 .42628 m
.76854 .41721 L
s
.788 .212 1 r
.79266 .41588 m
.79337 .42488 L
s
.79341 .42473 m
.79266 .41588 L
s
.833 .201 1 r
.76918 .42625 m
.76857 .41717 L
s
.76857 .41717 m
.76924 .42628 L
s
.788 .212 1 r
.79337 .42488 m
.79269 .41584 L
s
.79269 .41584 m
.79341 .42473 L
s
.648 .244 1 r
.7591 .42596 m
.75907 .4263 L
s
.588 .259 1 r
.35772 .39921 m
.35727 .40781 L
s
.35729 .40777 m
.35772 .39921 L
s
.35772 .39921 m
.35691 .41608 L
s
.834 .201 1 r
.89868 .4019 m
.89965 .41106 L
s
.89968 .41101 m
.89868 .4019 L
s
.89868 .4019 m
.90069 .41992 L
s
.916 .184 1 r
.63332 .41669 m
.63361 .42602 L
s
.63366 .42568 m
.63332 .41669 L
s
.63361 .42602 m
.63334 .41665 L
s
.63334 .41665 m
.63366 .42568 L
s
.629 .249 1 r
.78324 .42478 m
.78322 .42526 L
s
.494 .285 1 r
.51707 .3987 m
.51703 .407 L
s
.51704 .40696 m
.51707 .3987 L
s
.51707 .3987 m
.51706 .41512 L
s
.599 .257 1 r
.648 .42419 m
.64795 .42467 L
s
.591 .259 1 r
.59456 .41085 m
.59473 .41955 L
s
.59478 .41889 m
.59456 .41085 L
s
.648 .244 1 r
.73836 .36192 m
.74123 .40383 L
s
.845 .199 1 r
.44374 .36192 m
.4429 .40602 L
s
.425 .305 1 r
.14912 .36192 m
.14496 .4009 L
s
.591 .259 1 r
.59473 .41955 m
.59458 .41081 L
s
.59458 .41081 m
.59478 .41889 L
s
.833 .201 1 r
.30947 .40223 m
.30886 .41135 L
s
.30888 .4113 m
.30947 .40223 L
s
.30947 .40223 m
.30834 .42028 L
s
.441 .3 1 r
.16467 .41033 m
.16379 .41848 L
s
.16387 .4183 m
.16467 .41033 L
s
.16379 .41848 m
.16468 .4103 L
s
.16468 .4103 m
.16387 .4183 L
s
.733 .224 1 r
.33357 .40112 m
.33304 .41001 L
s
.33306 .40997 m
.33357 .40112 L
s
.33357 .40112 m
.3326 .41872 L
s
.88 .191 1 r
.89778 .36168 m
.90294 .40616 L
s
.811 .206 1 r
.60312 .36168 m
.60436 .40542 L
s
.392 .315 1 r
.30847 .36168 m
.30612 .40104 L
s
.881 .191 1 r
.62823 .40129 m
.62848 .41059 L
s
.62851 .41055 m
.62823 .40129 L
s
.62823 .40129 m
.62881 .41946 L
s
.559 .267 1 r
.2999 .41143 m
.29933 .41995 L
s
.29941 .41962 m
.2999 .41143 L
s
.4 .312 1 r
.34815 .40877 m
.34772 .41684 L
s
.34779 .41652 m
.34815 .40877 L
s
.845 .199 1 r
.28098 .42883 m
.28089 .42917 L
s
.559 .267 1 r
.29933 .41995 m
.29992 .41139 L
s
.29992 .41139 m
.29941 .41962 L
s
.425 .743 1 r
.46876 .40213 m
.46864 .40909 L
s
.46869 .40877 m
.46876 .40213 L
s
.4 .312 1 r
.34772 .41684 m
.34816 .40874 L
s
.34816 .40874 m
.34779 .41652 L
s
.638 .247 1 r
.2224 .39945 m
.2216 .40816 L
s
.22162 .40812 m
.2224 .39945 L
s
.2224 .39945 m
.2209 .41658 L
s
1 .116 .73 r
.77383 .43429 m
.7738 .43474 L
s
.425 .743 1 r
.46864 .40909 m
.46878 .4021 L
s
.46878 .4021 m
.46869 .40877 L
s
.618 .252 1 r
.80743 .42433 m
.80741 .42477 L
s
.917 .184 1 r
.81689 .41571 m
.81769 .42508 L
s
.81771 .42463 m
.81689 .41571 L
s
.869 .194 1 r
.92293 .40166 m
.92398 .41089 L
s
.92401 .41085 m
.92293 .40166 L
s
.92293 .40166 m
.92508 .41982 L
s
.904 .186 1 r
.71093 .42979 m
.71089 .43009 L
s
.917 .184 1 r
.81769 .42508 m
.81692 .41567 L
s
.81692 .41567 m
.81771 .42463 L
s
.788 .212 1 r
.76254 .36144 m
.76588 .40556 L
s
.579 .262 1 r
.46785 .36144 m
.46736 .40226 L
s
.669 .239 1 r
.17316 .36144 m
.16894 .40373 L
s
.362 .324 1 r
.85051 .40589 m
.85129 .41399 L
s
.85126 .41319 m
.85051 .40589 L
s
.649 .244 1 r
.94274 .42528 m
.94273 .42561 L
s
.811 .206 1 r
.54633 .41467 m
.54638 .42378 L
s
.54644 .42345 m
.54633 .41467 L
s
.362 .324 1 r
.85129 .41399 m
.85054 .40585 L
s
.85054 .40585 m
.85126 .41319 L
s
.811 .206 1 r
.54638 .42378 m
.54635 .41463 L
s
.54635 .41463 m
.54644 .42345 L
s
.88 .191 1 r
.36277 .41681 m
.36232 .42596 L
s
.36239 .42595 m
.36277 .41681 L
s
.443 .299 1 r
.21282 .40883 m
.21205 .41706 L
s
.21214 .41665 m
.21282 .40883 L
s
.88 .191 1 r
.36232 .42596 m
.36279 .41677 L
s
.36279 .41677 m
.36239 .42595 L
s
.669 .239 1 r
.67651 .39944 m
.67687 .40822 L
s
.6769 .40818 m
.67651 .39944 L
s
.67651 .39944 m
.6773 .41671 L
s
.352 .327 1 r
.45416 .39542 m
.45397 .40335 L
s
.45398 .40331 m
.45416 .39542 L
s
.45416 .39542 m
.45386 .41096 L
s
.513 .279 1 r
.92201 .36121 m
.92691 .40093 L
s
.618 .252 1 r
.62728 .36121 m
.62875 .40276 L
s
.477 .289 1 r
.33254 .36121 m
.33044 .4013 L
s
1 .146 .894 r
.5274 .43229 m
.52734 .43263 L
s
.822 .204 1 r
.73509 .42897 m
.73504 .42912 L
s
.443 .299 1 r
.21205 .41706 m
.21283 .40879 L
s
.21283 .40879 m
.21214 .41665 L
s
.569 .264 1 r
.24646 .39892 m
.24574 .40741 L
s
.24575 .40737 m
.24646 .39892 L
s
.24646 .39892 m
.2451 .41575 L
s
.476 .29 1 r
.42569 .42173 m
.42563 .42206 L
s
.857 .196 1 r
.68164 .41577 m
.68205 .42493 L
s
.68211 .42477 m
.68164 .41577 L
s
.894 .188 1 r
.49295 .40167 m
.49284 .41094 L
s
.49286 .4109 m
.49295 .40167 L
s
.49295 .40167 m
.49281 .41995 L
s
.701 .232 1 r
.7299 .41311 m
.73043 .42197 L
s
.73047 .42167 m
.7299 .41311 L
s
.857 .196 1 r
.68205 .42493 m
.68166 .41573 L
s
.68166 .41573 m
.68211 .42477 L
s
.342 .378 1 r
.5558 .40646 m
.55587 .41424 L
s
.55592 .41392 m
.5558 .40646 L
s
.701 .232 1 r
.73043 .42197 m
.72993 .41307 L
s
.72993 .41307 m
.73047 .42167 L
s
.588 .259 1 r
.53688 .42387 m
.53682 .4242 L
s
.917 .184 1 r
.25157 .41525 m
.25081 .42463 L
s
.25091 .42418 m
.25157 .41525 L
s
.342 .378 1 r
.55587 .41424 m
.55582 .40643 L
s
.55582 .40643 m
.55592 .41392 L
s
.777 .214 1 r
.86523 .41392 m
.86613 .42296 L
s
.86616 .42262 m
.86523 .41392 L
s
.811 .206 1 r
.81185 .4005 m
.81259 .40961 L
s
.81261 .40957 m
.81185 .4005 L
s
.81185 .4005 m
.81339 .4184 L
s
.559 .267 1 r
.40156 .42328 m
.40149 .42361 L
s
.917 .184 1 r
.25081 .42463 m
.25159 .41521 L
s
.25159 .41521 m
.25091 .42418 L
s
.811 .206 1 r
.78674 .36097 m
.79034 .40436 L
s
.385 .575 1 r
.49197 .36097 m
.49181 .39523 L
s
.66 .241 1 r
.1972 .36097 m
.19321 .40399 L
s
.777 .214 1 r
.86613 .42296 m
.86526 .41388 L
s
.86526 .41388 m
.86616 .42262 L
s
.56 .267 1 r
.56101 .42269 m
.56096 .42313 L
s
.589 .259 1 r
.70066 .39861 m
.70108 .40718 L
s
.7011 .40714 m
.70066 .39861 L
s
.70066 .39861 m
.70156 .41552 L
s
.77819 .41074 m
.77883 .41937 L
s
.77885 .41893 m
.77819 .41074 L
s
.648 .244 1 r
.40589 .39872 m
.40555 .40747 L
s
.40557 .40743 m
.40589 .39872 L
s
.40589 .39872 m
.40531 .41589 L
s
.589 .259 1 r
.77883 .41937 m
.77822 .4107 L
s
.77822 .4107 m
.77885 .41893 L
s
.477 .289 1 r
.29036 .4215 m
.29028 .42183 L
s
.523 .277 1 r
.29468 .39687 m
.29409 .40532 L
s
.2941 .40528 m
.29468 .39687 L
s
.29468 .39687 m
.29359 .41337 L
s
.68 .237 1 r
.65144 .36074 m
.65323 .40266 L
s
.766 .217 1 r
.35663 .36074 m
.35465 .40449 L
s
.441 .3 1 r
.74895 .39632 m
.74947 .40451 L
s
.74949 .40448 m
.74895 .39632 L
s
.74895 .39632 m
.75004 .41241 L
s
1 .144 .881 r
.174 .40376 m
.17297 .41344 L
s
.17299 .4134 m
.174 .40376 L
s
.174 .40376 m
.17204 .42297 L
s
.619 .252 1 r
.32393 .41185 m
.32341 .42048 L
s
.32348 .42025 m
.32393 .41185 L
s
.32341 .42048 m
.32394 .41181 L
s
.32394 .41181 m
.32348 .42025 L
s
.375 .32 1 r
.47828 .39517 m
.47814 .40318 L
s
.47816 .40314 m
.47828 .39517 L
s
.47828 .39517 m
.47808 .41086 L
s
.711 .229 1 r
.7541 .41265 m
.75469 .42154 L
s
.75473 .42121 m
.7541 .41265 L
s
.569 .264 1 r
.18857 .41132 m
.18772 .41981 L
s
.18779 .41966 m
.18857 .41132 L
s
.649 .244 1 r
.72484 .39793 m
.72533 .40672 L
s
.72536 .40668 m
.72484 .39793 L
s
.72484 .39793 m
.72588 .41506 L
s
.711 .229 1 r
.75469 .42154 m
.75412 .41261 L
s
.75412 .41261 m
.75473 .42121 L
s
.569 .264 1 r
.18772 .41981 m
.18858 .41128 L
s
.18858 .41128 m
.18779 .41966 L
s
.881 .191 1 r
.27564 .41479 m
.27495 .42406 L
s
.27504 .42372 m
.27564 .41479 L
s
.733 .224 1 r
.51274 .42615 m
.51268 .42644 L
s
.628 .249 1 r
.91359 .41213 m
.91458 .42077 L
s
.91462 .42062 m
.91359 .41213 L
s
.881 .191 1 r
.27495 .42406 m
.27566 .41475 L
s
.27566 .41475 m
.27504 .42372 L
s
.845 .199 1 r
.81095 .3605 m
.81502 .40572 L
s
.765 .217 1 r
.5161 .3605 m
.5162 .40425 L
s
.777 .214 1 r
.22126 .3605 m
.21752 .40425 L
s
.628 .249 1 r
.91458 .42077 m
.91362 .41209 L
s
.91362 .41209 m
.91462 .42062 L
s
.845 .199 1 r
.43513 .41427 m
.43487 .42346 L
s
.43495 .42313 m
.43513 .41427 L
s
.638 .247 1 r
.2705 .39885 m
.26983 .40753 L
s
.26984 .40749 m
.2705 .39885 L
s
.2705 .39885 m
.26924 .41602 L
s
.845 .199 1 r
.43487 .42346 m
.43515 .41423 L
s
.43515 .41423 m
.43495 .42313 L
s
.395 .619 1 r
.65238 .4023 m
.65265 .4096 L
s
.65268 .40917 m
.65238 .4023 L
s
.551 .269 1 r
.93777 .4111 m
.93879 .41951 L
s
.93883 .41943 m
.93777 .4111 L
s
.395 .619 1 r
.65265 .4096 m
.6524 .40227 L
s
.6524 .40227 m
.65268 .40917 L
s
.551 .269 1 r
.93879 .41951 m
.9378 .41106 L
s
.9378 .41106 m
.93883 .41943 L
s
.767 .216 1 r
.67226 .42591 m
.67222 .42633 L
s
.68 .237 1 r
.4834 .4119 m
.48328 .42072 L
s
.48335 .42039 m
.4834 .4119 L
s
.588 .259 1 r
.50754 .41057 m
.50749 .41917 L
s
.50755 .41884 m
.50754 .41057 L
s
.68 .237 1 r
.43 .39847 m
.42972 .4073 L
s
.42974 .40726 m
.43 .39847 L
s
.43 .39847 m
.42953 .41579 L
s
.416 .307 1 r
.67562 .36026 m
.67758 .39963 L
s
.744 .221 1 r
.38073 .36026 m
.3791 .40329 L
s
.68 .237 1 r
.48328 .42072 m
.48342 .41186 L
s
.48342 .41186 m
.48335 .42039 L
s
.588 .259 1 r
.50749 .41917 m
.50756 .41053 L
s
.50756 .41053 m
.50755 .41884 L
s
.833 .201 1 r
.54123 .40061 m
.54124 .40973 L
s
.54126 .40969 m
.54123 .40061 L
s
.54123 .40061 m
.54134 .41867 L
s
.69 .234 1 r
.6964 .42473 m
.69637 .4251 L
s
.589 .259 1 r
.66706 .41005 m
.66742 .41868 L
s
.66746 .41824 m
.66706 .41005 L
s
.66742 .41868 m
.66708 .41001 L
s
.66708 .41001 m
.66746 .41824 L
s
.424 .305 1 r
.17903 .42082 m
.17896 .42093 L
s
.608 .254 1 r
.72055 .42355 m
.72051 .42384 L
s
.424 .305 1 r
.49808 .41963 m
.49802 .41996 L
s
.54 .272 1 r
.15921 .39755 m
.15828 .40596 L
s
.15829 .40592 m
.15921 .39755 L
s
.15921 .39755 m
.15743 .41424 L
s
.669 .239 1 r
.58952 .39828 m
.58965 .40707 L
s
.58968 .40703 m
.58952 .39828 L
s
.58952 .39828 m
.58987 .41556 L
s
.638 .247 1 r
.83517 .36003 m
.83926 .40196 L
s
.68 .237 1 r
.54025 .36003 m
.54065 .40232 L
s
.598 .257 1 r
.24533 .36003 m
.24204 .40196 L
s
.68 .237 1 r
.26611 .4245 m
.26602 .42484 L
s
.88 .191 1 r
.32905 .42937 m
.32898 .42938 L
s
.477 .289 1 r
.50241 .39525 m
.50233 .40359 L
s
.50235 .40355 m
.50241 .39525 L
s
.50241 .39525 m
.50233 .41149 L
s
.422 .731 1 r
.56532 .39999 m
.56539 .40703 L
s
.56544 .40656 m
.56532 .39999 L
s
.64 .246 1 r
.60934 .42213 m
.6093 .42276 L
s
.422 .731 1 r
.56539 .40703 m
.56533 .39996 L
s
.56533 .39996 m
.56544 .40656 L
s
.916 .184 1 r
.35319 .42819 m
.35311 .42853 L
s
.68 .237 1 r
.69981 .35979 m
.70222 .40209 L
s
.4 .312 1 r
.40485 .35979 m
.40366 .39843 L
s
.822 .204 1 r
.21778 .4276 m
.2177 .42775 L
s
.503 .282 1 r
.33852 .42095 m
.33844 .42128 L
s
.619 .251 1 r
.93281 .39624 m
.93383 .40498 L
s
.93386 .40494 m
.93281 .39624 L
s
.93281 .39624 m
.93487 .41318 L
s
.777 .214 1 r
.83188 .42641 m
.83184 .42664 L
s
.733 .224 1 r
.85604 .42523 m
.85601 .42553 L
s
.503 .282 1 r
.79741 .39579 m
.79805 .40417 L
s
.79808 .40413 m
.79741 .39579 L
s
.79741 .39579 m
.79875 .41222 L
s
.669 .239 1 r
.90868 .39782 m
.90965 .40661 L
s
.90968 .40656 m
.90868 .39782 L
s
.90868 .39782 m
.91067 .4151 L
s
.6 .256 1 r
.85941 .35955 m
.86369 .40039 L
s
.799 .209 1 r
.56441 .35955 m
.56515 .40368 L
s
.7 .232 1 r
.26941 .35955 m
.26629 .40332 L
s
.375 .32 1 r
.68615 .39401 m
.6865 .40202 L
s
.68652 .40198 m
.68615 .39401 L
s
.68615 .39401 m
.68692 .4097 L
s
.459 .294 1 r
.2272 .41954 m
.22711 .4199 L
s
.579 .262 1 r
.47392 .42227 m
.47386 .42257 L
s
.712 .229 1 r
.5317 .41098 m
.53171 .41991 L
s
.53177 .41947 m
.5317 .41098 L
s
.45 .297 1 r
.60416 .40699 m
.60434 .41525 L
s
.60439 .41481 m
.60416 .40699 L
s
.618 .252 1 r
.72401 .35932 m
.72669 .40089 L
s
.638 .247 1 r
.42897 .35932 m
.42798 .40125 L
s
.712 .229 1 r
.53171 .41991 m
.53172 .41094 L
s
.53172 .41094 m
.53177 .41947 L
s
.45 .297 1 r
.60434 .41525 m
.60418 .40696 L
s
.60418 .40696 m
.60439 .41481 L
s
.408 .31 1 r
.82161 .39508 m
.82229 .40312 L
s
.82231 .40309 m
.82161 .39508 L
s
.82161 .39508 m
.82303 .41103 L
s
.754 .219 1 r
.80259 .41261 m
.80332 .42154 L
s
.80337 .42139 m
.80259 .41261 L
s
.80332 .42154 m
.80262 .41256 L
s
.80262 .41256 m
.80337 .42139 L
s
.669 .239 1 r
.18319 .39791 m
.18228 .40666 L
s
.1823 .40662 m
.18319 .39791 L
s
.18319 .39791 m
.18147 .41523 L
s
.953 .176 1 r
.37729 .4281 m
.37721 .42844 L
s
.486 .287 1 r
.84146 .41872 m
.84146 .4193 L
s
.722 .227 1 r
.37208 .41209 m
.37167 .42094 L
s
.37174 .42079 m
.37208 .41209 L
s
.669 .239 1 r
.69131 .41076 m
.69173 .41954 L
s
.69178 .41924 m
.69131 .41076 L
s
.811 .206 1 r
.31865 .39864 m
.31807 .40776 L
s
.31808 .40772 m
.31865 .39864 L
s
.31865 .39864 m
.31758 .41656 L
s
.361 .324 1 r
.88366 .35908 m
.88786 .39663 L
s
.679 .237 1 r
.58858 .35908 m
.5896 .40212 L
s
.628 .249 1 r
.2935 .35908 m
.29079 .40139 L
s
.722 .227 1 r
.37167 .42094 m
.3721 .41204 L
s
.3721 .41204 m
.37174 .42079 L
s
.669 .239 1 r
.69173 .41954 m
.69133 .41072 L
s
.69133 .41072 m
.69178 .41924 L
s
.383 .566 1 r
.83625 .40277 m
.83692 .4101 L
s
.83696 .40993 m
.83625 .40277 L
s
.69 .234 1 r
.90446 .42359 m
.90445 .42396 L
s
.7 .232 1 r
.23661 .41156 m
.23585 .42039 L
s
.23593 .4202 m
.23661 .41156 L
s
.383 .566 1 r
.83692 .4101 m
.83628 .40273 L
s
.83628 .40273 m
.83696 .40993 L
s
.7 .232 1 r
.23585 .42039 m
.23663 .41152 L
s
.23663 .41152 m
.23593 .4202 L
s
.777 .214 1 r
.77335 .39819 m
.77398 .40724 L
s
.774 .4072 m
.77335 .39819 L
s
.77335 .39819 m
.77467 .41596 L
s
.476 .29 1 r
.3911 .39488 m
.39075 .40318 L
s
.39076 .40314 m
.3911 .39488 L
s
.3911 .39488 m
.39048 .41116 L
s
.916 .184 1 r
.88467 .40041 m
.88562 .40968 L
s
.88565 .40964 m
.88467 .40041 L
s
.88467 .40041 m
.88665 .41885 L
s
.589 .259 1 r
.28491 .40919 m
.28429 .41779 L
s
.28437 .41746 m
.28491 .40919 L
s
.869 .194 1 r
.61373 .39911 m
.61394 .40835 L
s
.61397 .40831 m
.61373 .39911 L
s
.61373 .39911 m
.61423 .41729 L
s
.4 .312 1 r
.57055 .41789 m
.5705 .41822 L
s
.589 .259 1 r
.74823 .35884 m
.75118 .40005 L
s
.503 .282 1 r
.45311 .35884 m
.45246 .39896 L
s
.822 .204 1 r
.158 .35884 m
.15335 .40335 L
s
.589 .259 1 r
.28429 .41779 m
.28492 .40915 L
s
.28492 .40915 m
.28437 .41746 L
s
1 .154 .933 r
.61886 .41533 m
.61912 .42497 L
s
.61917 .42463 m
.61886 .41533 L
s
.68 .237 1 r
.66205 .39653 m
.66238 .40539 L
s
.66241 .40535 m
.66205 .39653 L
s
.66205 .39653 m
.66278 .41381 L
s
.744 .222 1 r
.39622 .41133 m
.39587 .4203 L
s
.39595 .41997 m
.39622 .41133 L
s
.638 .247 1 r
.7155 .41 m
.71599 .41871 L
s
.71603 .41842 m
.7155 .41 L
s
.599 .257 1 r
.73967 .40867 m
.74021 .41734 L
s
.74024 .41686 m
.73967 .40867 L
s
1 .154 .933 r
.61912 .42497 m
.61888 .41528 L
s
.61888 .41528 m
.61917 .42463 L
s
.744 .222 1 r
.39587 .4203 m
.39624 .41129 L
s
.39624 .41129 m
.39595 .41997 L
s
.638 .247 1 r
.71599 .41871 m
.71553 .40997 L
s
.71553 .40997 m
.71603 .41842 L
s
.599 .257 1 r
.74021 .41734 m
.73969 .40863 L
s
.73969 .40863 m
.74024 .41686 L
s
.754 .219 1 r
.88036 .4255 m
.88032 .42566 L
s
.7 .232 1 r
.58522 .4255 m
.58516 .42547 L
s
.599 .257 1 r
.26072 .41081 m
.26005 .41931 L
s
.2601 .41938 m
.26072 .41081 L
s
.868 .194 1 r
.24177 .42824 m
.2417 .42821 L
s
.599 .257 1 r
.26005 .41931 m
.26074 .41078 L
s
.26074 .41078 m
.2601 .41938 L
s
.711 .229 1 r
.90792 .35861 m
.913 .40128 L
s
.476 .29 1 r
.61276 .35861 m
.614 .39836 L
s
.42 .721 1 r
.31761 .35861 m
.31575 .39142 L
s
.425 .305 1 r
.87007 .39375 m
.87087 .40191 L
s
.8709 .40187 m
.87007 .39375 L
s
.87007 .39375 m
.87172 .40974 L
s
.531 .274 1 r
.41523 .39452 m
.41493 .40301 L
s
.41495 .40297 m
.41523 .39452 L
s
.41523 .39452 m
.41472 .41106 L
s
.608 .254 1 r
.23139 .39655 m
.23062 .40516 L
s
.23064 .40512 m
.23139 .39655 L
s
.23139 .39655 m
.22994 .41358 L
s
.722 .227 1 r
.20723 .39791 m
.20637 .40678 L
s
.20638 .40674 m
.20723 .39791 L
s
.20723 .39791 m
.2056 .4155 L
s
.858 .196 1 r
.82689 .41272 m
.8277 .42192 L
s
.82774 .42165 m
.82689 .41272 L
s
.744 .222 1 r
.3669 .39728 m
.36646 .40626 L
s
.36647 .40622 m
.3669 .39728 L
s
.3669 .39728 m
.3661 .4149 L
s
.858 .196 1 r
.8277 .42192 m
.82692 .41268 L
s
.82692 .41268 m
.82774 .42165 L
s
.766 .217 1 r
.77245 .35837 m
.77587 .40178 L
s
.991 .169 1 r
.47726 .35837 m
.47685 .40361 L
s
.711 .229 1 r
.18207 .35837 m
.17793 .40105 L
s
.833 .201 1 r
.34273 .39876 m
.34221 .40788 L
s
.34223 .40784 m
.34273 .39876 L
s
.34273 .39876 m
.34178 .41683 L
s
.628 .249 1 r
.20287 .42291 m
.20279 .42306 L
s
.504 .282 1 r
.78806 .40688 m
.78871 .41529 L
s
.78873 .41485 m
.78806 .40688 L
s
.788 .212 1 r
.44973 .42564 m
.44966 .42579 L
s
.916 .184 1 r
.63793 .39883 m
.63821 .40818 L
s
.63824 .40813 m
.63793 .39883 L
s
.63793 .39883 m
.63857 .41719 L
s
.504 .282 1 r
.78871 .41529 m
.78808 .40684 L
s
.78808 .40684 m
.78873 .41485 L
s
.811 .206 1 r
.31421 .42505 m
.31413 .42538 L
s
.649 .244 1 r
.52224 .42172 m
.52218 .42216 L
s
.522 .277 1 r
.57491 .39432 m
.57501 .40278 L
s
.57503 .40274 m
.57491 .39432 L
s
.57491 .39432 m
.57518 .41083 L
s
.441 .3 1 r
.27969 .39432 m
.27907 .40249 L
s
.27909 .40245 m
.27969 .39432 L
s
.27969 .39432 m
.27854 .41047 L
s
.46 .294 1 r
.88997 .4178 m
.88996 .41828 L
s
.68 .237 1 r
.63696 .35813 m
.63858 .40045 L
s
.34173 .35813 m
.33963 .40045 L
s
.522 .277 1 r
.7061 .41994 m
.70606 .42024 L
s
.744 .221 1 r
.58005 .41064 m
.58019 .41962 L
s
.58024 .41928 m
.58005 .41064 L
s
.58019 .41962 m
.58007 .4106 L
s
.58007 .4106 m
.58024 .41928 L
s
.531 .274 1 r
.1976 .40746 m
.19678 .41591 L
s
.19687 .41558 m
.1976 .40746 L
s
.425 .743 1 r
.46869 .40877 m
.46864 .40909 L
s
.337 .332 1 r
.86063 .40346 m
.86141 .41139 L
s
.86141 .41092 m
.86063 .40346 L
s
.531 .274 1 r
.19678 .41591 m
.19762 .40742 L
s
.19762 .40742 m
.19687 .41558 L
s
.425 .305 1 r
.45921 .41757 m
.45915 .4179 L
s
.337 .332 1 r
.86141 .41139 m
.86065 .40343 L
s
.86065 .40343 m
.86141 .41092 L
s
.823 .204 1 r
.87532 .41093 m
.87627 .42013 L
s
.87627 .41964 m
.87532 .41093 L
s
.559 .267 1 r
.41086 .42031 m
.41079 .42064 L
s
.45 .297 1 r
.59909 .3935 m
.59925 .40173 L
s
.59927 .40169 m
.59909 .3935 L
s
.59909 .3935 m
.59947 .40964 L
s
.845 .199 1 r
.7967 .35789 m
.80049 .40205 L
s
.375 .32 1 r
.50143 .35789 m
.50135 .39619 L
s
.744 .221 1 r
.65779 .42304 m
.65775 .42349 L
s
.733 .224 1 r
.20616 .35789 m
.20225 .40131 L
s
.823 .204 1 r
.87627 .42013 m
.87535 .41089 L
s
.87535 .41089 m
.87627 .41964 L
s
.345 .391 1 r
.16826 .39298 m
.16743 .40063 L
s
.16744 .40059 m
.16826 .39298 L
s
.16826 .39298 m
.16666 .40831 L
s
.648 .244 1 r
.38668 .42185 m
.38661 .42219 L
s
.893 .189 1 r
.92891 .42459 m
.92892 .42519 L
s
.469 .292 1 r
.38147 .4059 m
.38111 .4142 L
s
.38119 .41379 m
.38147 .4059 L
s
.799 .209 1 r
.52658 .39785 m
.52656 .4069 L
s
.52658 .40686 m
.52658 .39785 L
s
.52658 .39785 m
.52662 .41577 L
s
.469 .292 1 r
.38111 .4142 m
.38149 .40586 L
s
.38149 .40586 m
.38119 .41379 L
s
.4 .312 1 r
.66117 .35766 m
.66293 .39632 L
s
1 .149 .907 r
.36586 .35766 m
.36386 .40475 L
s
.376 .32 1 r
.9186 .39271 m
.91949 .40069 L
s
.91952 .40065 m
.9186 .39271 L
s
.9186 .39271 m
.92045 .40845 L
s
.591 .259 1 r
.59478 .41889 m
.59473 .41955 L
s
.503 .282 1 r
.73468 .39481 m
.73516 .40313 L
s
.73519 .40309 m
.73468 .39481 L
s
.73468 .39481 m
.73572 .41133 L
s
.441 .3 1 r
.16387 .4183 m
.16379 .41848 L
s
.765 .217 1 r
.44449 .41099 m
.44427 .41997 L
s
.44434 .41978 m
.44449 .41099 L
s
.335 .34 1 r
.64746 .39149 m
.64772 .39935 L
s
.64774 .39932 m
.64746 .39149 L
s
.64746 .39149 m
.64804 .40689 L
s
.701 .232 1 r
.764 .40966 m
.76462 .41853 L
s
.76465 .41823 m
.764 .40966 L
s
.494 .285 1 r
.51703 .407 m
.517 .4153 L
s
.51706 .41512 m
.51703 .407 L
s
.765 .217 1 r
.44427 .41997 m
.44451 .41095 L
s
.44451 .41095 m
.44434 .41978 L
s
.701 .232 1 r
.76462 .41853 m
.76402 .40962 L
s
.76402 .40962 m
.76465 .41823 L
s
.733 .224 1 r
.25543 .39695 m
.2547 .40585 L
s
.25471 .40581 m
.25543 .39695 L
s
.25543 .39695 m
.25405 .41458 L
s
.494 .285 1 r
.517 .4153 m
.51704 .40696 L
s
.51704 .40696 m
.51706 .41512 L
s
.588 .259 1 r
.35727 .40781 m
.35683 .41641 L
s
.35691 .41608 m
.35727 .40781 L
s
.4 .312 1 r
.34779 .41652 m
.34772 .41684 L
s
.679 .237 1 r
.82095 .35742 m
.82499 .40084 L
s
.503 .282 1 r
.52561 .35742 m
.52581 .39755 L
s
.54 .272 1 r
.23026 .35742 m
.22684 .39865 L
s
.362 .324 1 r
.85126 .41319 m
.85129 .41399 L
s
.588 .259 1 r
.35683 .41641 m
.35729 .40777 L
s
.35729 .40777 m
.35691 .41608 L
s
.953 .176 1 r
.42031 .41262 m
.42001 .42204 L
s
.42009 .4217 m
.42031 .41262 L
s
.788 .212 1 r
.79341 .42473 m
.79337 .42488 L
s
.953 .176 1 r
.42001 .42204 m
.42033 .41257 L
s
.42033 .41257 m
.42009 .4217 L
s
.744 .221 1 r
.71054 .39668 m
.711 .40563 L
s
.71102 .40559 m
.71054 .39668 L
s
.71054 .39668 m
.71153 .41435 L
s
.833 .201 1 r
.76924 .42628 m
.76918 .42625 L
s
.559 .267 1 r
.29941 .41962 m
.29933 .41995 L
s
.916 .184 1 r
.63366 .42568 m
.63361 .42602 L
s
.629 .249 1 r
.68539 .35718 m
.68755 .39805 L
s
.68 .237 1 r
.39001 .35718 m
.38852 .39951 L
s
.744 .221 1 r
.43935 .39557 m
.4391 .40458 L
s
.43912 .40454 m
.43935 .39557 L
s
.43935 .39557 m
.43893 .41315 L
s
.834 .201 1 r
.89965 .41106 m
.90066 .42022 L
s
.90069 .41992 m
.89965 .41106 L
s
.90066 .42022 m
.89968 .41101 L
s
.89968 .41101 m
.90069 .41992 L
s
.916 .184 1 r
.84617 .39767 m
.84702 .40702 L
s
.84705 .40698 m
.84617 .39767 L
s
.84617 .39767 m
.84794 .41604 L
s
.588 .259 1 r
.75893 .39435 m
.75949 .40295 L
s
.75952 .40291 m
.75893 .39435 L
s
.75893 .39435 m
.76012 .41123 L
s
.476 .29 1 r
.48771 .39302 m
.48759 .40133 L
s
.48761 .40129 m
.48771 .39302 L
s
.48771 .39302 m
.48755 .40931 L
s
.342 .378 1 r
.55592 .41392 m
.55587 .41424 L
s
.443 .299 1 r
.21214 .41665 m
.21205 .41706 L
s
.833 .201 1 r
.30886 .41135 m
.30827 .42047 L
s
.30834 .42028 m
.30886 .41135 L
s
.733 .224 1 r
.33304 .41001 m
.33253 .41891 L
s
.3326 .41872 m
.33304 .41001 L
s
.352 .327 1 r
.45397 .40335 m
.45379 .41128 L
s
.45386 .41096 m
.45397 .40335 L
s
.833 .201 1 r
.30827 .42047 m
.30888 .4113 L
s
.30888 .4113 m
.30834 .42028 L
s
.45 .297 1 r
.84521 .35695 m
.84917 .39635 L
s
.523 .276 1 r
.54979 .35695 m
.55029 .39635 L
s
.521 .277 1 r
.25437 .35695 m
.25122 .39854 L
s
.733 .224 1 r
.33253 .41891 m
.33306 .40997 L
s
.33306 .40997 m
.3326 .41872 L
s
.352 .327 1 r
.45379 .41128 m
.45398 .40331 L
s
.45398 .40331 m
.45386 .41096 L
s
.638 .247 1 r
.2216 .40816 m
.22081 .41687 L
s
.2209 .41658 m
.2216 .40816 L
s
.22081 .41687 m
.22162 .40812 L
s
.22162 .40812 m
.2209 .41658 L
s
1 .091 .585 r
.64316 .41778 m
.64351 .42799 L
s
.64357 .42783 m
.64316 .41778 L
s
.64351 .42799 m
.64319 .41773 L
s
.64319 .41773 m
.64357 .42783 L
s
.733 .224 1 r
.3037 .3957 m
.30309 .40464 L
s
.30311 .4046 m
.3037 .3957 L
s
.3037 .3957 m
.30257 .41329 L
s
.834 .201 1 r
.70962 .35671 m
.71227 .40087 L
s
.916 .184 1 r
.41416 .35671 m
.41291 .40161 L
s
.395 .619 1 r
.65268 .40917 m
.65265 .4096 L
s
.917 .184 1 r
.81771 .42463 m
.81769 .42508 L
s
.977 .171 1 r
.55078 .39846 m
.55082 .40789 L
s
.55085 .40785 m
.55078 .39846 L
s
.55078 .39846 m
.55095 .41714 L
s
.881 .191 1 r
.62848 .41059 m
.62876 .4199 L
s
.62881 .41946 m
.62848 .41059 L
s
.62876 .4199 m
.62851 .41055 L
s
.62851 .41055 m
.62881 .41946 L
s
.701 .232 1 r
.46352 .39525 m
.46333 .40412 L
s
.46335 .40408 m
.46352 .39525 L
s
.46352 .39525 m
.46323 .41269 L
s
.811 .206 1 r
.54644 .42345 m
.54638 .42378 L
s
.569 .264 1 r
.24574 .40741 m
.24503 .4159 L
s
.2451 .41575 m
.24574 .40741 L
s
.24503 .4159 m
.24575 .40737 L
s
.24575 .40737 m
.2451 .41575 L
s
.869 .194 1 r
.92398 .41089 m
.92506 .42012 L
s
.92508 .41982 m
.92398 .41089 L
s
.669 .239 1 r
.67687 .40822 m
.67726 .41701 L
s
.6773 .41671 m
.67687 .40822 L
s
.589 .259 1 r
.77885 .41893 m
.77883 .41937 L
s
.559 .267 1 r
.35205 .39343 m
.35159 .40197 L
s
.35161 .40193 m
.35205 .39343 L
s
.35205 .39343 m
.35122 .41017 L
s
.869 .194 1 r
.92506 .42012 m
.92401 .41085 L
s
.92401 .41085 m
.92508 .41982 L
s
.354 .435 1 r
.86949 .35647 m
.87328 .39149 L
s
.701 .232 1 r
.73047 .42167 m
.73043 .42197 L
s
.354 .326 1 r
.574 .35647 m
.57477 .39661 L
s
.638 .247 1 r
.2785 .35647 m
.2756 .3988 L
s
.669 .239 1 r
.67726 .41701 m
.6769 .40818 L
s
.6769 .40818 m
.6773 .41671 L
s
.589 .259 1 r
.70108 .40718 m
.70152 .41575 L
s
.70156 .41552 m
.70108 .40718 L
s
.88 .191 1 r
.36239 .42595 m
.36232 .42596 L
s
.441 .3 1 r
.74947 .40451 m
.75001 .41271 L
s
.75004 .41241 m
.74947 .40451 L
s
.375 .32 1 r
.47814 .40318 m
.47802 .41119 L
s
.47808 .41086 m
.47814 .40318 L
s
.777 .214 1 r
.86616 .42262 m
.86613 .42296 L
s
.589 .259 1 r
.70152 .41575 m
.7011 .40714 L
s
.7011 .40714 m
.70156 .41552 L
s
.477 .289 1 r
.83161 .39176 m
.83234 .40011 L
s
.83237 .40007 m
.83161 .39176 L
s
.83161 .39176 m
.83311 .40802 L
s
.441 .3 1 r
.75001 .41271 m
.74949 .40448 L
s
.74949 .40448 m
.75004 .41241 L
s
.375 .32 1 r
.47802 .41119 m
.47816 .40314 L
s
.47816 .40314 m
.47808 .41086 L
s
.422 .731 1 r
.56544 .40656 m
.56539 .40703 L
s
.66 .241 1 r
.5119 .39316 m
.51184 .40203 L
s
.51186 .40199 m
.5119 .39316 L
s
.5119 .39316 m
.51186 .41031 L
s
.523 .277 1 r
.29409 .40532 m
.2935 .41378 L
s
.29359 .41337 m
.29409 .40532 L
s
.857 .196 1 r
.68211 .42477 m
.68205 .42493 L
s
.669 .239 1 r
.19217 .39457 m
.19128 .40336 L
s
.19129 .40332 m
.19217 .39457 L
s
.19217 .39457 m
.19049 .41186 L
s
.777 .214 1 r
.73387 .35623 m
.73679 .39967 L
s
.359 .325 1 r
.43833 .35623 m
.43752 .39491 L
s
.744 .222 1 r
.1428 .35623 m
.13802 .40004 L
s
.523 .277 1 r
.2935 .41378 m
.2941 .40528 L
s
.2941 .40528 m
.29359 .41337 L
s
.917 .184 1 r
.25091 .42418 m
.25081 .42463 L
s
.648 .244 1 r
.40555 .40747 m
.40524 .41622 L
s
.40531 .41589 m
.40555 .40747 L
s
.619 .252 1 r
.32348 .42025 m
.32341 .42048 L
s
.648 .244 1 r
.40524 .41622 m
.40557 .40743 L
s
.40557 .40743 m
.40531 .41589 L
s
.894 .188 1 r
.49284 .41094 m
.49274 .42022 L
s
.49281 .41995 m
.49284 .41094 L
s
.811 .206 1 r
.81259 .40961 m
.81336 .41874 L
s
.81339 .4184 m
.81259 .40961 L
s
.569 .264 1 r
.18779 .41966 m
.18772 .41981 L
s
.41 .683 1 r
.63287 .38676 m
.63307 .39389 L
s
.63309 .39386 m
.63287 .38676 L
s
.63287 .38676 m
.63333 .4007 L
s
.894 .188 1 r
.49274 .42022 m
.49286 .4109 L
s
.49286 .4109 m
.49281 .41995 L
s
.811 .206 1 r
.81336 .41874 m
.81261 .40957 L
s
.81261 .40957 m
.81339 .4184 L
s
.618 .252 1 r
.89378 .356 m
.89857 .3976 L
s
.383 .565 1 r
.59821 .356 m
.59916 .39139 L
s
.375 .32 1 r
.30264 .356 m
.30024 .39504 L
s
.711 .229 1 r
.75473 .42121 m
.75469 .42154 L
s
.628 .249 1 r
.91462 .42062 m
.91458 .42077 L
s
.754 .219 1 r
.62339 .39581 m
.62362 .40476 L
s
.62364 .40472 m
.62339 .39581 L
s
.62339 .39581 m
.62393 .41356 L
s
.367 .322 1 r
.56029 .39112 m
.56034 .39906 L
s
.56036 .39902 m
.56029 .39112 L
s
.56029 .39112 m
.56047 .40682 L
s
.569 .264 1 r
.21631 .39381 m
.21551 .40232 L
s
.21552 .40228 m
.21631 .39381 L
s
.21631 .39381 m
.21479 .41067 L
s
.777 .214 1 r
.78329 .39518 m
.78395 .40423 L
s
.78397 .40419 m
.78329 .39518 L
s
.78329 .39518 m
.78467 .41296 L
s
.551 .269 1 r
.93883 .41943 m
.93879 .41951 L
s
.649 .244 1 r
.72533 .40672 m
.72585 .4155 L
s
.72588 .41506 m
.72533 .40672 L
s
.72585 .4155 m
.72536 .40668 L
s
.72536 .40668 m
.72588 .41506 L
s
.588 .259 1 r
.50755 .41884 m
.50749 .41917 L
s
.916 .184 1 r
.8948 .39739 m
.89578 .40668 L
s
.89581 .40663 m
.8948 .39739 L
s
.8948 .39739 m
.89684 .41585 L
s
.881 .191 1 r
.3278 .39606 m
.32723 .40534 L
s
.32725 .4053 m
.3278 .39606 L
s
.3278 .39606 m
.32676 .41429 L
s
.433 .302 1 r
.69599 .39204 m
.69638 .40017 L
s
.6964 .40013 m
.69599 .39204 L
s
.69599 .39204 m
.69683 .40815 L
s
.638 .247 1 r
.26983 .40753 m
.26916 .41621 L
s
.26924 .41602 m
.26983 .40753 L
s
.589 .259 1 r
.66746 .41824 m
.66742 .41868 L
s
.953 .176 1 r
.75813 .35576 m
.7615 .40103 L
s
1 .164 .985 r
.46252 .35576 m
.46188 .40214 L
s
.468 .292 1 r
.1669 .35576 m
.16277 .39627 L
s
.638 .247 1 r
.26916 .41621 m
.26984 .40749 L
s
.26984 .40749 m
.26924 .41602 L
s
.881 .191 1 r
.27504 .42372 m
.27495 .42406 L
s
.68 .237 1 r
.48335 .42039 m
.48328 .42072 L
s
.845 .199 1 r
.43495 .42313 m
.43487 .42346 L
s
.467 .292 1 r
.85593 .39166 m
.85671 .39993 L
s
.85674 .3999 m
.85593 .39166 L
s
.85593 .39166 m
.85754 .40792 L
s
.68 .237 1 r
.42972 .4073 m
.42946 .41612 L
s
.42953 .41579 m
.42972 .4073 L
s
.67182 .39383 m
.67218 .40266 L
s
.6722 .40262 m
.67182 .39383 L
s
.67182 .39383 m
.6726 .41117 L
s
.54 .272 1 r
.15828 .40596 m
.15735 .41438 L
s
.15743 .41424 m
.15828 .40596 L
s
.68 .237 1 r
.91809 .35552 m
.92326 .39787 L
s
.357 .451 1 r
.62244 .35552 m
.62368 .39201 L
s
.692 .234 1 r
.32679 .35552 m
.32452 .3975 L
s
.68 .237 1 r
.42946 .41612 m
.42974 .40726 L
s
.42974 .40726 m
.42953 .41579 L
s
.54 .272 1 r
.15735 .41438 m
.15829 .40592 L
s
.15829 .40592 m
.15743 .41424 L
s
1 .144 .881 r
.17297 .41344 m
.17195 .42313 L
s
.17204 .42297 m
.17297 .41344 L
s
.17195 .42313 m
.17299 .4134 L
s
.17299 .4134 m
.17204 .42297 L
s
.648 .244 1 r
.5361 .39338 m
.5361 .40214 L
s
.53613 .4021 m
.5361 .39338 L
s
.5361 .39338 m
.53618 .41057 L
s
.477 .289 1 r
.50233 .40359 m
.50227 .41193 L
s
.50233 .41149 m
.50233 .40359 L
s
.834 .201 1 r
.80758 .39485 m
.80832 .40406 L
s
.80834 .40402 m
.80758 .39485 L
s
.80758 .39485 m
.80911 .41286 L
s
.477 .289 1 r
.50227 .41193 m
.50235 .40355 L
s
.50235 .40355 m
.50233 .41149 L
s
.833 .201 1 r
.54124 .40973 m
.54128 .41886 L
s
.54134 .41867 m
.54124 .40973 L
s
.669 .239 1 r
.58965 .40707 m
.58982 .41586 L
s
.58987 .41556 m
.58965 .40707 L
s
.833 .201 1 r
.54128 .41886 m
.54126 .40969 L
s
.54126 .40969 m
.54134 .41867 L
s
1 .153 .933 r
.7824 .35528 m
.78617 .4013 L
s
.559 .267 1 r
.48671 .35528 m
.48645 .39616 L
s
.442 .3 1 r
.19102 .35528 m
.18729 .3947 L
s
.669 .239 1 r
.58982 .41586 m
.58968 .40703 L
s
.58968 .40703 m
.58987 .41556 L
s
.441 .3 1 r
.28882 .39098 m
.28823 .39918 L
s
.28824 .39914 m
.28882 .39098 L
s
.28882 .39098 m
.28772 .40709 L
s
.383 .566 1 r
.83696 .40993 m
.83692 .4101 L
s
.375 .32 1 r
.6865 .40202 m
.68688 .41003 L
s
.68692 .4097 m
.6865 .40202 L
s
.45 .297 1 r
.60439 .41481 m
.60434 .41525 L
s
.375 .32 1 r
.68688 .41003 m
.68652 .40198 L
s
.68652 .40198 m
.68692 .4097 L
s
.503 .282 1 r
.79805 .40417 m
.79873 .41255 L
s
.79875 .41222 m
.79805 .40417 L
s
.46 .294 1 r
.64668 .35505 m
.6483 .3941 L
s
.799 .209 1 r
.35095 .35505 m
.34889 .39886 L
s
.503 .282 1 r
.79873 .41255 m
.79808 .40413 L
s
.79808 .40413 m
.79875 .41222 L
s
.619 .251 1 r
.93383 .40498 m
.93489 .41373 L
s
.93487 .41318 m
.93383 .40498 L
s
.711 .229 1 r
.40035 .39358 m
.39999 .40249 L
s
.40001 .40245 m
.40035 .39358 L
s
.40035 .39358 m
.39973 .41107 L
s
.619 .251 1 r
.93489 .41373 m
.93386 .40494 L
s
.93386 .40494 m
.93487 .41318 L
s
.669 .239 1 r
.24036 .39429 m
.2396 .40302 L
s
.23962 .40298 m
.24036 .39429 L
s
.24036 .39429 m
.23892 .41167 L
s
.476 .29 1 r
.44876 .39092 m
.44855 .39923 L
s
.44857 .3992 m
.44876 .39092 L
s
.44876 .39092 m
.44842 .40722 L
s
.408 .31 1 r
.82229 .40312 m
.82299 .41117 L
s
.82303 .41103 m
.82229 .40312 L
s
.82299 .41117 m
.82231 .40309 L
s
.82231 .40309 m
.82303 .41103 L
s
.669 .239 1 r
.90965 .40661 m
.91064 .4154 L
s
.91067 .4151 m
.90965 .40661 L
s
.811 .206 1 r
.80668 .35481 m
.81059 .39863 L
s
.744 .221 1 r
.51092 .35481 m
.51095 .39789 L
s
.485 .287 1 r
.21515 .35481 m
.2115 .39643 L
s
.669 .239 1 r
.91064 .4154 m
.90968 .40656 L
s
.90968 .40656 m
.91067 .4151 L
s
.712 .229 1 r
.53177 .41947 m
.53171 .41991 L
s
.669 .239 1 r
.26454 .39349 m
.26384 .40226 L
s
.26385 .40222 m
.26454 .39349 L
s
.26454 .39349 m
.26323 .41084 L
s
.45 .297 1 r
.67093 .35457 m
.67283 .39363 L
s
.569 .264 1 r
.37512 .35457 m
.37347 .39619 L
s
.669 .239 1 r
.69178 .41924 m
.69173 .41954 L
s
.892 .189 1 r
.3761 .39575 m
.37567 .40499 L
s
.37569 .40495 m
.3761 .39575 L
s
.3761 .39575 m
.37532 .41409 L
s
.476 .29 1 r
.39075 .40318 m
.39041 .41149 L
s
.39048 .41116 m
.39075 .40318 L
s
.39041 .41149 m
.39076 .40314 L
s
.39076 .40314 m
.39048 .41116 L
s
.754 .219 1 r
.80337 .42139 m
.80332 .42154 L
s
.669 .239 1 r
.18228 .40666 m
.18139 .41542 L
s
.18147 .41523 m
.18228 .40666 L
s
.722 .227 1 r
.37174 .42079 m
.37167 .42094 L
s
.669 .239 1 r
.18139 .41542 m
.1823 .40662 L
s
.1823 .40662 m
.18147 .41523 L
s
.589 .259 1 r
.28437 .41746 m
.28429 .41779 L
s
.7 .232 1 r
.23593 .4202 m
.23585 .42039 L
s
.599 .257 1 r
.74024 .41686 m
.74021 .41734 L
s
.618 .252 1 r
.15291 .392 m
.15193 .40069 L
s
.15194 .40065 m
.15291 .392 L
s
.15291 .392 m
.15106 .40905 L
s
.669 .239 1 r
.58456 .3927 m
.58468 .4015 L
s
.58471 .40146 m
.58456 .3927 L
s
.58456 .3927 m
.58489 .41001 L
s
.615 1 .735 r
.83098 .35433 m
.83311 .37628 L
s
.468 .292 1 r
.53514 .35433 m
.53546 .39413 L
s
.834 .201 1 r
.2393 .35433 m
.23575 .39852 L
s
.638 .247 1 r
.71603 .41842 m
.71599 .41871 L
s
.588 .259 1 r
.31292 .39155 m
.31236 .40017 L
s
.31238 .40013 m
.31292 .39155 L
s
.31292 .39155 m
.31189 .40845 L
s
.811 .206 1 r
.31807 .40776 m
.3175 .41689 L
s
.31758 .41656 m
.31807 .40776 L
s
.469 .291 1 r
.81727 .38826 m
.81797 .39668 L
s
.818 .39664 m
.81727 .38826 L
s
.81727 .38826 m
.81869 .40437 L
s
.811 .206 1 r
.3175 .41689 m
.31808 .40772 L
s
.31808 .40772 m
.31758 .41656 L
s
.391 .315 1 r
.79305 .3897 m
.79366 .39772 L
s
.79368 .39768 m
.79305 .3897 L
s
.79305 .3897 m
.79433 .40556 L
s
.744 .222 1 r
.39595 .41997 m
.39587 .4203 L
s
.777 .214 1 r
.77398 .40724 m
.77464 .4163 L
s
.77467 .41596 m
.77398 .40724 L
s
.599 .257 1 r
.2601 .41938 m
.26005 .41931 L
s
.425 .305 1 r
.87087 .40191 m
.8717 .41007 L
s
.87172 .40974 m
.87087 .40191 L
s
.669 .239 1 r
.74462 .39247 m
.74516 .40127 L
s
.74518 .40123 m
.74462 .39247 L
s
.74462 .39247 m
.74577 .40978 L
s
.391 .315 1 r
.69519 .35409 m
.69737 .39316 L
s
.777 .214 1 r
.39931 .35409 m
.3979 .39755 L
s
.77464 .4163 m
.774 .4072 L
s
.774 .4072 m
.77467 .41596 L
s
.425 .305 1 r
.8717 .41007 m
.8709 .40187 L
s
.8709 .40187 m
.87172 .40974 L
s
.68 .237 1 r
.66238 .40539 m
.66274 .41425 L
s
.66278 .41381 m
.66238 .40539 L
s
.777 .214 1 r
.88047 .39332 m
.88139 .40238 L
s
.88142 .40233 m
.88047 .39332 L
s
.88047 .39332 m
.88236 .41111 L
s
.68 .237 1 r
.66274 .41425 m
.66241 .40535 L
s
.66241 .40535 m
.66278 .41381 L
s
.504 .282 1 r
.78873 .41485 m
.78871 .41529 L
s
.337 .332 1 r
.86141 .41092 m
.86141 .41139 L
s
.916 .184 1 r
.88562 .40968 m
.88661 .41897 L
s
.88665 .41885 m
.88562 .40968 L
s
.869 .194 1 r
.61394 .40835 m
.61418 .41759 L
s
.61423 .41729 m
.61394 .40835 L
s
.68 .237 1 r
.6088 .3922 m
.60899 .40104 L
s
.60902 .401 m
.6088 .3922 L
s
.6088 .3922 m
.60926 .40955 L
s
.531 .274 1 r
.41493 .40301 m
.41465 .4115 L
s
.41472 .41106 m
.41493 .40301 L
s
.916 .184 1 r
.88661 .41897 m
.88565 .40964 L
s
.88565 .40964 m
.88665 .41885 L
s
.869 .194 1 r
.61418 .41759 m
.61397 .40831 L
s
.61397 .40831 m
.61423 .41729 L
s
.608 .254 1 r
.17704 .39157 m
.17612 .40022 L
s
.17614 .40018 m
.17704 .39157 L
s
.17704 .39157 m
.17531 .40858 L
s
.471 .907 1 r
.85529 .35386 m
.8585 .38489 L
s
.359 .325 1 r
.55937 .35386 m
.55996 .39256 L
s
.459 .295 1 r
.26345 .35386 m
.26051 .39402 L
s
.531 .274 1 r
.41465 .4115 m
.41495 .40297 L
s
.41495 .40297 m
.41472 .41106 L
s
.608 .254 1 r
.23062 .40516 m
.22986 .41376 L
s
.22994 .41358 m
.23062 .40516 L
s
1 .154 .933 r
.61917 .42463 m
.61912 .42497 L
s
.441 .3 1 r
.27907 .40249 m
.27847 .41065 L
s
.27854 .41047 m
.27907 .40249 L
s
.495 .284 1 r
.65726 .38968 m
.65756 .39807 L
s
.65758 .39803 m
.65726 .38968 L
s
.65726 .38968 m
.65792 .40606 L
s
.608 .254 1 r
.22986 .41376 m
.23064 .40512 L
s
.23064 .40512 m
.22994 .41358 L
s
.441 .3 1 r
.27847 .41065 m
.27909 .40245 L
s
.27909 .40245 m
.27854 .41047 L
s
.66 .241 1 r
.92898 .39115 m
.93001 .39999 L
s
.93003 .39995 m
.92898 .39115 L
s
.92898 .39115 m
.93106 .40835 L
s
.345 .391 1 r
.16743 .40063 m
.16661 .40827 L
s
.16666 .40831 m
.16743 .40063 L
s
.16661 .40827 m
.16744 .40059 L
s
.16744 .40059 m
.16666 .40831 L
s
.722 .227 1 r
.20637 .40678 m
.20552 .41565 L
s
.2056 .4155 m
.20637 .40678 L
s
.522 .277 1 r
.57501 .40278 m
.57513 .41124 L
s
.57518 .41083 m
.57501 .40278 L
s
.559 .267 1 r
.49718 .39064 m
.49708 .39918 L
s
.4971 .39914 m
.49718 .39064 L
s
.49718 .39064 m
.49707 .40739 L
s
.638 .247 1 r
.71947 .35362 m
.72214 .39598 L
s
.45 .297 1 r
.42351 .35362 m
.42252 .39305 L
s
.722 .227 1 r
.20552 .41565 m
.20638 .40674 L
s
.20638 .40674 m
.2056 .4155 L
s
1 .161 .972 r
.72046 .39474 m
.72098 .40436 L
s
.72101 .40431 m
.72046 .39474 L
s
.72046 .39474 m
.72157 .41353 L
s
.531 .274 1 r
.19687 .41558 m
.19678 .41591 L
s
.522 .277 1 r
.57513 .41124 m
.57503 .40274 L
s
.57503 .40274 m
.57518 .41083 L
s
.858 .196 1 r
.82774 .42165 m
.8277 .42192 L
s
.744 .222 1 r
.36646 .40626 m
.36603 .41524 L
s
.3661 .4149 m
.36646 .40626 L
s
.36603 .41524 m
.36647 .40622 L
s
.36647 .40622 m
.3661 .4149 L
s
.355 .439 1 r
.40976 .38749 m
.40947 .3951 L
s
.40949 .39507 m
.40976 .38749 L
s
.40976 .38749 m
.40926 .40258 L
s
.416 .307 1 r
.68151 .38889 m
.68186 .39702 L
s
.68188 .39699 m
.68151 .38889 L
s
.68151 .38889 m
.68227 .40487 L
s
.45 .297 1 r
.59925 .40173 m
.59942 .40997 L
s
.59947 .40964 m
.59925 .40173 L
s
.469 .292 1 r
.38119 .41379 m
.38111 .4142 L
s
.45 .297 1 r
.59942 .40997 m
.59927 .40169 L
s
.59927 .40169 m
.59947 .40964 L
s
.833 .201 1 r
.34221 .40788 m
.34171 .41702 L
s
.34178 .41683 m
.34221 .40788 L
s
.744 .221 1 r
.58024 .41928 m
.58019 .41962 L
s
.833 .201 1 r
.34171 .41702 m
.34223 .40784 L
s
.34223 .40784 m
.34178 .41683 L
s
.462 .294 1 r
.87961 .35338 m
.88383 .39135 L
s
.609 .254 1 r
.58362 .35338 m
.58458 .39685 L
s
.701 .232 1 r
.28762 .35338 m
.28473 .39721 L
s
.376 .32 1 r
.91949 .40069 m
.92042 .40867 L
s
.92045 .40845 m
.91949 .40069 L
s
.335 .34 1 r
.64772 .39935 m
.648 .40722 L
s
.64804 .40689 m
.64772 .39935 L
s
1 .156 .946 r
.42448 .39532 m
.42417 .40494 L
s
.42419 .4049 m
.42448 .39532 L
s
.42448 .39532 m
.42395 .41427 L
s
.376 .32 1 r
.92042 .40867 m
.91952 .40065 L
s
.91952 .40065 m
.92045 .40845 L
s
.916 .184 1 r
.63821 .40818 m
.63852 .41753 L
s
.63857 .41719 m
.63821 .40818 L
s
.335 .34 1 r
.648 .40722 m
.64774 .39932 L
s
.64774 .39932 m
.64804 .40689 L
s
.916 .184 1 r
.63852 .41753 m
.63824 .40813 L
s
.63824 .40813 m
.63857 .41719 L
s
.823 .204 1 r
.87627 .41964 m
.87627 .42013 L
s
.45 .297 1 r
.24961 .38884 m
.24892 .39708 L
s
.24893 .39704 m
.24961 .38884 L
s
.24961 .38884 m
.24832 .405 L
s
.744 .222 1 r
.74376 .35314 m
.74679 .39624 L
s
.495 .284 1 r
.44773 .35314 m
.44698 .39405 L
s
.619 .252 1 r
.15169 .35314 m
.14722 .39514 L
s
.494 .285 1 r
.51706 .41512 m
.517 .4153 L
s
.503 .282 1 r
.73516 .40313 m
.73568 .41144 L
s
.73572 .41133 m
.73516 .40313 L
s
.73568 .41144 m
.73519 .40309 L
s
.73519 .40309 m
.73572 .41133 L
s
.991 .169 1 r
.90491 .39382 m
.90595 .40337 L
s
.90598 .40332 m
.90491 .39382 L
s
.90491 .39382 m
.90703 .41247 L
s
.588 .259 1 r
.35691 .41608 m
.35683 .41641 L
s
.756 .219 1 r
.90394 .3529 m
.90896 .39528 L
s
.701 .232 1 r
.76465 .41823 m
.76462 .41853 L
s
.60787 .3529 m
.60914 .39564 L
s
.608 .254 1 r
.3118 .3529 m
.30934 .39491 L
s
.799 .209 1 r
.52656 .4069 m
.52655 .41596 L
s
.52662 .41577 m
.52656 .4069 L
s
.833 .201 1 r
.47294 .39341 m
.47277 .40255 L
s
.47279 .40251 m
.47294 .39341 L
s
.47294 .39341 m
.47268 .41151 L
s
.352 .327 1 r
.45386 .41096 m
.45379 .41128 L
s
.916 .184 1 r
.76903 .39348 m
.76967 .40284 L
s
.7697 .4028 m
.76903 .39348 L
s
.76903 .39348 m
.77038 .41187 L
s
.799 .209 1 r
.52655 .41596 m
.52658 .40686 L
s
.52658 .40686 m
.52662 .41577 L
s
.711 .229 1 r
.36125 .39148 m
.3608 .4004 L
s
.36081 .40036 m
.36125 .39148 L
s
.36125 .39148 m
.36043 .40898 L
s
.765 .217 1 r
.44434 .41978 m
.44427 .41997 L
s
.589 .259 1 r
.84175 .38959 m
.84253 .39825 L
s
.84256 .39821 m
.84175 .38959 L
s
.84175 .38959 m
.84336 .40646 L
s
.733 .224 1 r
.2547 .40585 m
.25397 .41477 L
s
.25405 .41458 m
.2547 .40585 L
s
.881 .191 1 r
.33701 .39303 m
.33646 .40232 L
s
.33648 .40228 m
.33701 .39303 L
s
.33701 .39303 m
.33602 .41127 L
s
.743 .222 1 r
.76806 .35266 m
.77148 .39687 L
s
.777 .214 1 r
.47195 .35266 m
.47148 .39614 L
s
.754 .219 1 r
.17584 .35266 m
.17149 .39651 L
s
.733 .224 1 r
.25397 .41477 m
.25471 .40581 L
s
.25471 .40581 m
.25405 .41458 L
s
.476 .29 1 r
.48759 .40133 m
.48749 .40964 L
s
.48755 .40931 m
.48759 .40133 L
s
.628 .249 1 r
.22529 .39122 m
.2245 .39987 L
s
.22451 .39983 m
.22529 .39122 L
s
.22529 .39122 m
.22379 .40838 L
s
.476 .29 1 r
.48749 .40964 m
.48761 .40129 L
s
.48761 .40129 m
.48755 .40931 L
s
.5699 .38859 m
.56998 .39691 L
s
.57 .39687 m
.5699 .38859 L
s
.5699 .38859 m
.57014 .4049 L
s
.953 .176 1 r
.42009 .4217 m
.42001 .42204 L
s
.744 .221 1 r
.711 .40563 m
.71148 .41458 L
s
.71153 .41435 m
.711 .40563 L
s
.588 .259 1 r
.75949 .40295 m
.76008 .41156 L
s
.76012 .41123 m
.75949 .40295 L
s
.744 .221 1 r
.71148 .41458 m
.71102 .40559 L
s
.71102 .40559 m
.71153 .41435 L
s
1 .148 .907 r
.63214 .35243 m
.63387 .39921 L
s
.589 .259 1 r
.33599 .35243 m
.33387 .3937 L
s
.588 .259 1 r
.76008 .41156 m
.75952 .40291 L
s
.75952 .40291 m
.76012 .41123 L
s
.834 .201 1 r
.90069 .41992 m
.90066 .42022 L
s
.691 .234 1 r
.70587 .38965 m
.70632 .39859 L
s
.70635 .39855 m
.70587 .38965 L
s
.70587 .38965 m
.70682 .40696 L
s
.638 .247 1 r
.2209 .41658 m
.22081 .41687 L
s
.744 .221 1 r
.4391 .40458 m
.43886 .4136 L
s
.43893 .41315 m
.4391 .40458 L
s
.733 .224 1 r
.3326 .41872 m
.33253 .41891 L
s
.744 .221 1 r
.43886 .4136 m
.43912 .40454 L
s
.43912 .40454 m
.43893 .41315 L
s
.41 .683 1 r
.63307 .39389 m
.63329 .40102 L
s
.63333 .4007 m
.63307 .39389 L
s
.63329 .40102 m
.63309 .39386 L
s
.63309 .39386 m
.63333 .4007 L
s
.489 .286 1 r
.79238 .35219 m
.79567 .3909 L
s
.441 .3 1 r
.49619 .35219 m
.49605 .39164 L
s
.711 .229 1 r
.2 .35219 m
.19607 .39493 L
s
.833 .201 1 r
.30834 .42028 m
.30827 .42047 L
s
.375 .32 1 r
.47808 .41086 m
.47802 .41119 L
s
.88 .191 1 r
.20097 .39345 m
.20006 .40267 L
s
.20008 .40263 m
.20097 .39345 L
s
.20097 .39345 m
.19924 .41178 L
s
.916 .184 1 r
.84702 .40702 m
.84791 .41638 L
s
.84794 .41604 m
.84702 .40702 L
s
.569 .264 1 r
.2451 .41575 m
.24503 .4159 L
s
.79 .211 1 r
.54568 .39085 m
.5457 .39999 L
s
.54572 .39995 m
.54568 .39085 L
s
.54568 .39085 m
.54581 .40865 L
s
.441 .3 1 r
.75004 .41241 m
.75001 .41271 L
s
.916 .184 1 r
.84791 .41638 m
.84705 .40698 L
s
.84705 .40698 m
.84794 .41604 L
s
.467 .292 1 r
.65643 .35195 m
.6582 .39213 L
s
.754 .219 1 r
.3602 .35195 m
.35826 .3958 L
s
.733 .224 1 r
.30309 .40464 m
.30249 .41359 L
s
.30257 .41329 m
.30309 .40464 L
s
.669 .239 1 r
.6773 .41671 m
.67726 .41701 L
s
.559 .267 1 r
.35159 .40197 m
.35115 .4105 L
s
.35122 .41017 m
.35159 .40197 L
s
.523 .277 1 r
.29359 .41337 m
.2935 .41378 L
s
.881 .191 1 r
.62881 .41946 m
.62876 .4199 L
s
.733 .224 1 r
.30249 .41359 m
.30311 .4046 L
s
.30311 .4046 m
.30257 .41329 L
s
.559 .267 1 r
.35115 .4105 m
.35161 .40193 L
s
.35161 .40193 m
.35122 .41017 L
s
.701 .232 1 r
.46333 .40412 m
.46316 .41299 L
s
.46323 .41269 m
.46333 .40412 L
s
.589 .259 1 r
.70156 .41552 m
.70152 .41575 L
s
.477 .289 1 r
.83234 .40011 m
.8331 .40846 L
s
.83311 .40802 m
.83234 .40011 L
s
.701 .232 1 r
.46316 .41299 m
.46335 .40408 L
s
.46335 .40408 m
.46323 .41269 L
s
.477 .289 1 r
.8331 .40846 m
.83237 .40007 L
s
.83237 .40007 m
.83311 .40802 L
s
.904 .186 1 r
.8167 .35171 m
.82094 .39777 L
s
.531 .274 1 r
.52044 .35171 m
.52059 .39226 L
s
.578 .262 1 r
.22418 .35171 m
.22057 .3941 L
s
.869 .194 1 r
.92508 .41982 m
.92506 .42012 L
s
.822 .204 1 r
.38541 .39228 m
.38501 .40139 L
s
.38503 .40135 m
.38541 .39228 L
s
.38541 .39228 m
.38469 .41035 L
s
.367 .322 1 r
.56034 .39906 m
.56042 .407 L
s
.56047 .40682 m
.56034 .39906 L
s
.648 .244 1 r
.40531 .41589 m
.40524 .41622 L
s
.977 .171 1 r
.55082 .40789 m
.55089 .41733 L
s
.55095 .41714 m
.55082 .40789 L
s
.367 .322 1 r
.56042 .407 m
.56036 .39902 L
s
.56036 .39902 m
.56047 .40682 L
s
.977 .171 1 r
.55089 .41733 m
.55085 .40785 L
s
.55085 .40785 m
.55095 .41714 L
s
.669 .239 1 r
.19128 .40336 m
.1904 .41216 L
s
.19049 .41186 m
.19128 .40336 L
s
.66 .241 1 r
.51184 .40203 m
.5118 .4109 L
s
.51186 .41031 m
.51184 .40203 L
s
.352 .327 1 r
.80298 .38587 m
.80361 .39382 L
s
.80363 .39378 m
.80298 .38587 L
s
.80298 .38587 m
.80429 .40144 L
s
.66 .241 1 r
.68072 .35147 m
.68287 .39312 L
s
.892 .189 1 r
.38442 .35147 m
.38274 .3968 L
s
.669 .239 1 r
.1904 .41216 m
.19129 .40332 L
s
.19129 .40332 m
.19049 .41186 L
s
.66 .241 1 r
.5118 .4109 m
.51186 .40199 L
s
.51186 .40199 m
.51186 .41031 L
s
.433 .302 1 r
.69638 .40017 m
.69678 .4083 L
s
.69683 .40815 m
.69638 .40017 L
s
.69678 .4083 m
.6964 .40013 L
s
.6964 .40013 m
.69683 .40815 L
s
1 .091 .585 r
.64357 .42783 m
.64351 .42799 L
s
.811 .206 1 r
.81339 .4184 m
.81336 .41874 L
s
.495 .284 1 r
.16184 .38879 m
.16092 .39708 L
s
.16094 .39704 m
.16184 .38879 L
s
.16184 .38879 m
.16009 .4053 L
s
.649 .244 1 r
.72588 .41506 m
.72585 .4155 L
s
.569 .264 1 r
.21551 .40232 m
.21472 .41082 L
s
.21479 .41067 m
.21551 .40232 L
s
.916 .184 1 r
.52142 .39353 m
.52138 .40279 L
s
.52141 .40274 m
.52142 .39353 L
s
.52142 .39353 m
.52143 .41204 L
s
.569 .264 1 r
.21472 .41082 m
.21552 .40228 L
s
.21552 .40228 m
.21479 .41067 L
s
.894 .188 1 r
.49281 .41995 m
.49274 .42022 L
s
.442 .299 1 r
.84104 .35123 m
.84503 .39143 L
s
.68 .237 1 r
.5447 .35123 m
.54517 .39362 L
s
.754 .219 1 r
.24836 .35123 m
.24495 .39509 L
s
.638 .247 1 r
.26924 .41602 m
.26916 .41621 L
s
.467 .292 1 r
.85671 .39993 m
.85752 .40821 L
s
.85754 .40792 m
.85671 .39993 L
s
.569 .264 1 r
.75451 .38915 m
.75506 .39766 L
s
.75509 .39762 m
.75451 .38915 L
s
.75451 .38915 m
.75568 .40603 L
s
.467 .292 1 r
.85752 .40821 m
.85674 .3999 L
s
.85674 .3999 m
.85754 .40792 L
s
.754 .219 1 r
.62362 .40476 m
.62387 .41371 L
s
.62393 .41356 m
.62362 .40476 L
s
.477 .289 1 r
.50233 .41149 m
.50227 .41193 L
s
.367 .497 1 r
.5552 .38389 m
.55524 .39143 L
s
.55526 .3914 m
.5552 .38389 L
s
.5552 .38389 m
.55535 .39869 L
s
.754 .219 1 r
.62387 .41371 m
.62364 .40472 L
s
.62364 .40472 m
.62393 .41356 L
s
.835 .201 1 r
.43391 .39065 m
.43363 .39987 L
s
.43365 .39983 m
.43391 .39065 L
s
.43391 .39065 m
.43345 .40868 L
s
.54 .272 1 r
.15743 .41424 m
.15735 .41438 L
s
.777 .214 1 r
.78395 .40423 m
.78464 .4133 L
s
.78467 .41296 m
.78395 .40423 L
s
.811 .206 1 r
.73027 .39073 m
.7308 .39987 L
s
.73082 .39983 m
.73027 .39073 L
s
.73027 .39073 m
.73139 .40868 L
s
.559 .267 1 r
.48242 .38807 m
.48229 .39661 L
s
.48231 .39657 m
.48242 .38807 L
s
.48242 .38807 m
.48223 .40483 L
s
.503 .282 1 r
.64274 .3874 m
.64301 .39579 L
s
.64303 .39576 m
.64274 .3874 L
s
.64274 .3874 m
.64334 .40386 L
s
.531 .274 1 r
.70503 .35099 m
.70741 .39155 L
s
.559 .267 1 r
.40865 .35099 m
.40743 .39192 L
s
.777 .214 1 r
.78464 .4133 m
.78397 .40419 L
s
.78397 .40419 m
.78467 .41296 L
s
.375 .32 1 r
.68692 .4097 m
.68688 .41003 L
s
.68 .237 1 r
.42953 .41579 m
.42946 .41612 L
s
.441 .3 1 r
.28823 .39918 m
.28764 .40738 L
s
.28772 .40709 m
.28823 .39918 L
s
.28764 .40738 m
.28824 .39914 L
s
.28824 .39914 m
.28772 .40709 L
s
.916 .184 1 r
.89578 .40668 m
.8968 .41597 L
s
.89684 .41585 m
.89578 .40668 L
s
.881 .191 1 r
.32723 .40534 m
.32668 .41463 L
s
.32676 .41429 m
.32723 .40534 L
s
.68 .237 1 r
.67218 .40266 m
.67256 .4115 L
s
.6726 .41117 m
.67218 .40266 L
s
.916 .184 1 r
.8968 .41597 m
.89581 .40663 L
s
.89581 .40663 m
.89684 .41585 L
s
.881 .191 1 r
.32668 .41463 m
.32725 .4053 L
s
.32725 .4053 m
.32676 .41429 L
s
.335 .34 1 r
.8654 .35075 m
.86941 .38839 L
s
.37 .509 1 r
.56898 .35075 m
.56964 .38729 L
s
.892 .189 1 r
.27256 .35075 m
.26936 .39609 L
s
.68 .237 1 r
.67256 .4115 m
.6722 .40262 L
s
.6722 .40262 m
.6726 .41117 L
s
.881 .191 1 r
.59424 .39061 m
.5944 .39993 L
s
.59442 .39989 m
.59424 .39061 L
s
.59424 .39061 m
.59463 .40882 L
s
.904 .186 1 r
.27354 .39198 m
.27282 .40127 L
s
.27284 .40123 m
.27354 .39198 L
s
.27354 .39198 m
.2722 .41038 L
s
.669 .239 1 r
.58987 .41556 m
.58982 .41586 L
s
.648 .244 1 r
.5361 .40214 m
.53613 .41091 L
s
.53618 .41057 m
.5361 .40214 L
s
.503 .282 1 r
.79875 .41222 m
.79873 .41255 L
s
.744 .222 1 r
.2978 .39072 m
.29717 .39964 L
s
.29719 .3996 m
.2978 .39072 L
s
.2978 .39072 m
.29663 .40845 L
s
.459 .295 1 r
.21025 .38735 m
.20946 .39556 L
s
.20947 .39552 m
.21025 .38735 L
s
.21025 .38735 m
.20875 .40363 L
s
.648 .244 1 r
.53613 .41091 m
.53613 .4021 L
s
.53613 .4021 m
.53618 .41057 L
s
.408 .31 1 r
.82303 .41103 m
.82299 .41117 L
s
.589 .259 1 r
.50669 .38749 m
.50661 .39614 L
s
.50663 .3961 m
.50669 .38749 L
s
.50669 .38749 m
.50662 .40436 L
s
.669 .239 1 r
.6185 .38953 m
.61872 .3983 L
s
.61874 .39826 m
.6185 .38953 L
s
.6185 .38953 m
.61901 .40689 L
s
.619 .251 1 r
.93487 .41318 m
.93489 .41373 L
s
.68 .237 1 r
.77887 .38893 m
.7795 .39778 L
s
.77953 .39773 m
.77887 .38893 L
s
.77887 .38893 m
.7802 .40629 L
s
.869 .194 1 r
.89069 .39097 m
.89166 .40023 L
s
.89169 .40018 m
.89069 .39097 L
s
.89069 .39097 m
.89269 .40919 L
s
.375 .32 1 r
.23449 .38627 m
.23378 .39422 L
s
.2338 .39418 m
.23449 .38627 L
s
.23449 .38627 m
.23315 .40207 L
s
.649 .244 1 r
.72935 .35052 m
.73211 .39218 L
s
.337 .354 1 r
.43289 .35052 m
.43204 .38852 L
s
.679 .237 1 r
.13644 .35052 m
.1316 .39401 L
s
.833 .201 1 r
.54134 .41867 m
.54128 .41886 L
s
.476 .29 1 r
.44855 .39923 m
.44836 .40755 L
s
.44842 .40722 m
.44855 .39923 L
s
.44836 .40755 m
.44857 .3992 L
s
.44857 .3992 m
.44842 .40722 L
s
.834 .201 1 r
.80832 .40406 m
.80908 .41327 L
s
.80911 .41286 m
.80832 .40406 L
s
.80908 .41327 m
.80834 .40402 L
s
.80834 .40402 m
.80911 .41286 L
s
1 .144 .881 r
.17204 .42297 m
.17195 .42313 L
s
.569 .264 1 r
.37058 .38733 m
.37016 .39591 L
s
.37018 .39587 m
.37058 .38733 L
s
.37058 .38733 m
.36983 .40413 L
s
.88 .191 1 r
.45814 .3907 m
.45793 .39999 L
s
.45795 .39995 m
.45814 .3907 L
s
.45814 .3907 m
.45781 .40895 L
s
.4 .312 1 r
.85172 .38536 m
.85248 .39346 L
s
.8525 .39343 m
.85172 .38536 L
s
.85172 .38536 m
.85328 .40124 L
s
.845 .199 1 r
.88976 .35028 m
.89481 .39451 L
s
.559 .267 1 r
.59327 .35028 m
.59431 .39121 L
s
.69 .234 1 r
.29677 .35028 m
.29404 .39341 L
s
.777 .214 1 r
.32203 .39014 m
.32146 .39918 L
s
.32147 .39913 m
.32203 .39014 L
s
.32203 .39014 m
.32098 .40799 L
s
.669 .239 1 r
.2396 .40302 m
.23886 .41175 L
s
.23892 .41167 m
.2396 .40302 L
s
.91067 .4151 m
.91064 .4154 L
s
.23886 .41175 m
.23962 .40298 L
s
.23962 .40298 m
.23892 .41167 L
s
.476 .29 1 r
.39048 .41116 m
.39041 .41149 L
s
.477 .289 1 r
.69135 .38624 m
.69173 .39457 L
s
.69175 .39453 m
.69135 .38624 L
s
.69135 .38624 m
.69218 .40257 L
s
.385 .575 1 r
.49193 .38087 m
.49184 .38834 L
s
.49185 .3883 m
.49193 .38087 L
s
.49193 .38087 m
.49181 .39523 L
s
.711 .229 1 r
.39999 .40249 m
.39965 .41141 L
s
.39973 .41107 m
.39999 .40249 L
s
.39965 .41141 m
.40001 .40245 L
s
.40001 .40245 m
.39973 .41107 L
s
1 .123 .772 r
.75368 .35004 m
.7572 .39796 L
s
.579 .262 1 r
.45715 .35004 m
.45652 .39134 L
s
.799 .209 1 r
.16061 .35004 m
.15602 .39428 L
s
.7 .232 1 r
.34627 .38928 m
.34578 .39812 L
s
.3458 .39808 m
.34627 .38928 L
s
.34627 .38928 m
.34537 .40679 L
s
.521 .277 1 r
.8275 .38727 m
.82822 .39568 L
s
.82825 .39564 m
.8275 .38727 L
s
.8275 .38727 m
.82901 .4039 L
s
.8 .209 1 r
.91509 .39071 m
.9161 .39975 L
s
.91613 .39971 m
.91509 .39071 L
s
.91509 .39071 m
.9172 .40871 L
s
.669 .239 1 r
.26384 .40226 m
.26315 .41103 L
s
.26323 .41084 m
.26384 .40226 L
s
.26315 .41103 m
.26385 .40222 L
s
.26385 .40222 m
.26323 .41084 L
s
.425 .305 1 r
.87172 .40974 m
.8717 .41007 L
s
.777 .214 1 r
.18584 .39023 m
.18491 .39923 L
s
.18492 .39919 m
.18584 .39023 L
s
.18584 .39023 m
.18407 .40812 L
s
.391 .315 1 r
.79366 .39772 m
.79429 .40574 L
s
.79433 .40556 m
.79366 .39772 L
s
.36 .462 1 r
.91414 .3498 m
.91857 .38634 L
s
.733 .224 1 r
.61757 .3498 m
.61898 .39294 L
s
.722 .227 1 r
.321 .3498 m
.31856 .39331 L
s
.669 .239 1 r
.18147 .41523 m
.18139 .41542 L
s
.391 .315 1 r
.79429 .40574 m
.79368 .39768 L
s
.79368 .39768 m
.79433 .40556 L
s
1 .065 .43 r
.8666 .39382 m
.86764 .40449 L
s
.86767 .40444 m
.8666 .39382 L
s
.8666 .39382 m
.86871 .41442 L
s
.618 .252 1 r
.15193 .40069 m
.15096 .40938 L
s
.15106 .40905 m
.15193 .40069 L
s
.469 .291 1 r
.81797 .39668 m
.8187 .4051 L
s
.81869 .40437 m
.81797 .39668 L
s
.618 .252 1 r
.15096 .40938 m
.15194 .40065 L
s
.15194 .40065 m
.15106 .40905 L
s
.469 .291 1 r
.8187 .4051 m
.818 .39664 L
s
.818 .39664 m
.81869 .40437 L
s
.669 .239 1 r
.58468 .4015 m
.58483 .41031 L
s
.58489 .41001 m
.58468 .4015 L
s
.588 .259 1 r
.31236 .40017 m
.31181 .40878 L
s
.31189 .40845 m
.31236 .40017 L
s
.788 .212 1 r
.77803 .34956 m
.78159 .3938 L
s
.45 .297 1 r
.48142 .34956 m
.4811 .38903 L
s
.733 .224 1 r
.18481 .34956 m
.1806 .39307 L
s
.669 .239 1 r
.58483 .41031 m
.58471 .40146 L
s
.58471 .40146 m
.58489 .41001 L
s
.588 .259 1 r
.31181 .40878 m
.31238 .40013 L
s
.31238 .40013 m
.31189 .40845 L
s
.345 .391 1 r
.16666 .40831 m
.16661 .40827 L
s
.892 .189 1 r
.37567 .40499 m
.37525 .41425 L
s
.37532 .41409 m
.37567 .40499 L
s
.531 .274 1 r
.41472 .41106 m
.41465 .4115 L
s
.892 .189 1 r
.37525 .41425 m
.37569 .40495 L
s
.37569 .40495 m
.37532 .41409 L
s
.68 .237 1 r
.66278 .41381 m
.66274 .41425 L
s
.777 .214 1 r
.66714 .38888 m
.66749 .39795 L
s
.66752 .39791 m
.66714 .38888 L
s
.66714 .38888 m
.66792 .40669 L
s
.441 .3 1 r
.27854 .41047 m
.27847 .41065 L
s
.425 .305 1 r
.14673 .38487 m
.14579 .39305 L
s
.1458 .39301 m
.14673 .38487 L
s
.14673 .38487 m
.14496 .4009 L
s
.811 .206 1 r
.31758 .41656 m
.3175 .41689 L
s
.777 .214 1 r
.77467 .41596 m
.77464 .4163 L
s
.355 .439 1 r
.40947 .3951 m
.40921 .40272 L
s
.40926 .40258 m
.40947 .3951 L
s
.40921 .40272 m
.40949 .39507 L
s
.40949 .39507 m
.40926 .40258 L
s
.669 .239 1 r
.74516 .40127 m
.74573 .41008 L
s
.74577 .40978 m
.74516 .40127 L
s
.744 .222 1 r
.53097 .38843 m
.53096 .39742 L
s
.53098 .39738 m
.53097 .38843 L
s
.53097 .38843 m
.53103 .40609 L
s
.618 .252 1 r
.64188 .34932 m
.64357 .39173 L
s
.711 .229 1 r
.34523 .34932 m
.34315 .3921 L
s
.669 .239 1 r
.74573 .41008 m
.74518 .40123 L
s
.74518 .40123 m
.74577 .40978 L
s
.522 .277 1 r
.57518 .41083 m
.57513 .41124 L
s
.495 .284 1 r
.65756 .39807 m
.65788 .40646 L
s
.65792 .40606 m
.65756 .39807 L
s
.628 .249 1 r
.39478 .38794 m
.39442 .39661 L
s
.39444 .39657 m
.39478 .38794 L
s
.39478 .38794 m
.39414 .40513 L
s
.608 .254 1 r
.22994 .41358 m
.22986 .41376 L
s
.495 .284 1 r
.65788 .40646 m
.65758 .39803 L
s
.65758 .39803 m
.65792 .40606 L
s
.335 .34 1 r
.64804 .40689 m
.648 .40722 L
s
.608 .254 1 r
.17612 .40022 m
.17522 .40888 L
s
.17531 .40858 m
.17612 .40022 L
s
.45 .297 1 r
.59947 .40964 m
.59942 .40997 L
s
.608 .254 1 r
.17522 .40888 m
.17614 .40018 L
s
.17614 .40018 m
.17531 .40858 L
s
.777 .214 1 r
.88139 .40238 m
.88234 .41144 L
s
.88236 .41111 m
.88139 .40238 L
s
.68 .237 1 r
.60899 .40104 m
.60921 .40988 L
s
.60926 .40955 m
.60899 .40104 L
s
.618 .252 1 r
.41906 .38686 m
.41876 .39556 L
s
.41878 .39552 m
.41906 .38686 L
s
.41906 .38686 m
.41855 .40393 L
s
.416 .307 1 r
.68186 .39702 m
.68223 .40516 L
s
.68227 .40487 m
.68186 .39702 L
s
.376 .32 1 r
.92045 .40845 m
.92042 .40867 L
s
.68 .237 1 r
.80239 .34908 m
.80614 .39186 L
s
.495 .284 1 r
.5057 .34908 m
.50567 .38892 L
s
.754 .219 1 r
.20901 .34908 m
.20508 .39296 L
s
.777 .214 1 r
.88234 .41144 m
.88142 .40233 L
s
.88142 .40233 m
.88236 .41111 L
s
.68 .237 1 r
.60921 .40988 m
.60902 .401 L
s
.60902 .401 m
.60926 .40955 L
s
.416 .307 1 r
.68223 .40516 m
.68188 .39699 L
s
.68188 .39699 m
.68227 .40487 L
s
.869 .194 1 r
.61423 .41729 m
.61418 .41759 L
s
.559 .267 1 r
.49708 .39918 m
.497 .40772 L
s
.49707 .40739 m
.49708 .39918 L
s
.497 .40772 m
.4971 .39914 L
s
.4971 .39914 m
.49707 .40739 L
s
.588 .259 1 r
.57955 .38641 m
.57966 .39503 L
s
.57969 .39499 m
.57955 .38641 L
s
.57955 .38641 m
.57985 .40333 L
s
.392 .315 1 r
.30713 .38511 m
.30658 .39311 L
s
.3066 .39307 m
.30713 .38511 L
s
.30713 .38511 m
.30612 .40104 L
s
.66 .241 1 r
.93001 .39999 m
.93106 .40883 L
s
.93106 .40835 m
.93001 .39999 L
s
.916 .184 1 r
.88665 .41885 m
.88661 .41897 L
s
.722 .227 1 r
.2056 .4155 m
.20552 .41565 L
s
.66 .241 1 r
.93106 .40883 m
.93003 .39995 L
s
.93003 .39995 m
.93106 .40835 L
s
.744 .222 1 r
.3661 .4149 m
.36603 .41524 L
s
.618 .252 1 r
.28283 .38662 m
.28219 .39532 L
s
.2822 .39528 m
.28283 .38662 L
s
.28283 .38662 m
.28163 .40369 L
s
.648 .244 1 r
.66621 .34884 m
.66819 .39089 L
s
.701 .231 1 r
.36948 .34884 m
.36773 .39126 L
s
.45 .297 1 r
.24892 .39708 m
.24823 .40533 L
s
.24832 .405 m
.24892 .39708 L
s
.24823 .40533 m
.24893 .39704 L
s
.24893 .39704 m
.24832 .405 L
s
.503 .282 1 r
.73572 .41133 m
.73568 .41144 L
s
.777 .214 1 r
.82676 .3486 m
.8309 .39212 L
s
.337 .354 1 r
.52999 .3486 m
.53024 .38662 L
s
.34 .366 1 r
.23323 .3486 m
.2301 .38662 L
s
.756 .219 1 r
.87634 .38712 m
.87725 .3962 L
s
.87728 .39615 m
.87634 .38712 L
s
.87634 .38712 m
.87821 .40479 L
s
.513 .279 1 r
.92493 .38445 m
.9259 .39293 L
s
.92593 .39289 m
.92493 .38445 L
s
.92493 .38445 m
.92691 .40093 L
s
.833 .201 1 r
.34178 .41683 m
.34171 .41702 L
s
.41 .683 1 r
.63333 .4007 m
.63329 .40102 L
s
.648 .244 1 r
.74011 .38661 m
.74064 .39538 L
s
.74066 .39534 m
.74011 .38661 L
s
.74011 .38661 m
.74123 .40383 L
s
.579 .262 1 r
.46762 .38541 m
.46745 .39404 L
s
.46747 .394 m
.46762 .38541 L
s
.46762 .38541 m
.46736 .40226 L
s
1 .161 .972 r
.72098 .40436 m
.72154 .41399 L
s
.72157 .41353 m
.72098 .40436 L
s
.916 .184 1 r
.63857 .41719 m
.63852 .41753 L
s
1 .161 .972 r
.72154 .41399 m
.72101 .40431 L
s
.72101 .40431 m
.72157 .41353 L
s
.477 .289 1 r
.69055 .34836 m
.6927 .38785 L
s
.733 .224 1 r
.39374 .34836 m
.39225 .39188 L
s
.777 .214 1 r
.71583 .38826 m
.71631 .3973 L
s
.71634 .39726 m
.71583 .38826 L
s
.71583 .38826 m
.71687 .40612 L
s
.477 .289 1 r
.33136 .38493 m
.33086 .39322 L
s
.33088 .39319 m
.33136 .38493 L
s
.33136 .38493 m
.33044 .4013 L
s
.476 .29 1 r
.48755 .40931 m
.48749 .40964 L
s
.765 .217 1 r
.25845 .38919 m
.25772 .39812 L
s
.25773 .39808 m
.25845 .38919 L
s
.25845 .38919 m
.25706 .40709 L
s
.42 .721 1 r
.31658 .37771 m
.31612 .38482 L
s
.31613 .38479 m
.31658 .37771 L
s
.31658 .37771 m
.31575 .39142 L
s
.354 .434 1 r
.85114 .34812 m
.85475 .38322 L
s
.45 .297 1 r
.5543 .34812 m
.55485 .38761 L
s
.54 .272 1 r
.25746 .34812 m
.25436 .38945 L
s
1 .156 .946 r
.42417 .40494 m
.42387 .41457 L
s
.42395 .41427 m
.42417 .40494 L
s
.589 .259 1 r
.84253 .39825 m
.84334 .4069 L
s
.84336 .40646 m
.84253 .39825 L
s
.476 .29 1 r
.56998 .39691 m
.57009 .40523 L
s
.57014 .4049 m
.56998 .39691 L
s
1 .156 .946 r
.42387 .41457 m
.42419 .4049 L
s
.42419 .4049 m
.42395 .41427 L
s
.799 .209 1 r
.52662 .41577 m
.52655 .41596 L
s
.589 .259 1 r
.84334 .4069 m
.84256 .39821 L
s
.84256 .39821 m
.84336 .40646 L
s
.476 .29 1 r
.57009 .40523 m
.57 .39687 L
s
.57 .39687 m
.57014 .4049 L
s
.711 .229 1 r
.3608 .4004 m
.36035 .40932 L
s
.36043 .40898 m
.3608 .4004 L
s
.733 .224 1 r
.25405 .41458 m
.25397 .41477 L
s
.711 .229 1 r
.36035 .40932 m
.36081 .40036 L
s
.36081 .40036 m
.36043 .40898 L
s
.588 .259 1 r
.76012 .41123 m
.76008 .41156 L
s
.833 .201 1 r
.47277 .40255 m
.47262 .4117 L
s
.47268 .41151 m
.47277 .40255 L
s
.628 .249 1 r
.2245 .39987 m
.22372 .40854 L
s
.22379 .40838 m
.2245 .39987 L
s
.618 .252 1 r
.6282 .38569 m
.62844 .39439 L
s
.62846 .39435 m
.6282 .38569 L
s
.6282 .38569 m
.62875 .40276 L
s
.669 .239 1 r
.17073 .38639 m
.16978 .3952 L
s
.1698 .39516 m
.17073 .38639 L
s
.17073 .38639 m
.16894 .40373 L
s
.833 .201 1 r
.47262 .4117 m
.47279 .40251 L
s
.47279 .40251 m
.47268 .41151 L
s
.618 .252 1 r
.7149 .34788 m
.71746 .38921 L
s
.917 .184 1 r
.41802 .34788 m
.41682 .39251 L
s
.628 .249 1 r
.22372 .40854 m
.22451 .39983 L
s
.22451 .39983 m
.22379 .40838 L
s
.991 .169 1 r
.90595 .40337 m
.90702 .41292 L
s
.90703 .41247 m
.90595 .40337 L
s
.90702 .41292 m
.90598 .40332 L
s
.90598 .40332 m
.90703 .41247 L
s
.845 .199 1 r
.44331 .38791 m
.44306 .39713 L
s
.44308 .39709 m
.44331 .38791 L
s
.44331 .38791 m
.4429 .40602 L
s
.916 .184 1 r
.76967 .40284 m
.77034 .41221 L
s
.77038 .41187 m
.76967 .40284 L
s
.744 .221 1 r
.71153 .41435 m
.71148 .41458 L
s
.916 .184 1 r
.77034 .41221 m
.7697 .4028 L
s
.7697 .4028 m
.77038 .41187 L
s
.881 .191 1 r
.33646 .40232 m
.33594 .41161 L
s
.33602 .41127 m
.33646 .40232 L
s
.811 .206 1 r
.60391 .38746 m
.6041 .3966 L
s
.60412 .39656 m
.60391 .38746 L
s
.60391 .38746 m
.60436 .40542 L
s
.615 1 .735 r
.83221 .36655 m
.83268 .37188 L
s
.83269 .37186 m
.83221 .36655 L
s
.83221 .36655 m
.83311 .37628 L
s
.881 .191 1 r
.33594 .41161 m
.33648 .40228 L
s
.33648 .40228 m
.33602 .41127 L
s
.342 .378 1 r
.87554 .34764 m
.87964 .38494 L
s
.608 .254 1 r
.57862 .34764 m
.5795 .38934 L
s
.811 .206 1 r
.2817 .34764 m
.27873 .39154 L
s
.744 .221 1 r
.43893 .41315 m
.43886 .4136 L
s
.416 .307 1 r
.67684 .38359 m
.67717 .3917 L
s
.67719 .39166 m
.67684 .38359 L
s
.67684 .38359 m
.67758 .39963 L
s
.691 .234 1 r
.70632 .39859 m
.7068 .40755 L
s
.70682 .40696 m
.70632 .39859 L
s
.477 .289 1 r
.83311 .40802 m
.8331 .40846 L
s
.691 .234 1 r
.7068 .40755 m
.70635 .39855 L
s
.70635 .39855 m
.70682 .40696 L
s
.88 .191 1 r
.90088 .38789 m
.90188 .39719 L
s
.90191 .39714 m
.90088 .38789 L
s
.90088 .38789 m
.90294 .40616 L
s
.559 .267 1 r
.35122 .41017 m
.35115 .4105 L
s
.367 .322 1 r
.56047 .40682 m
.56042 .407 L
s
.4 .312 1 r
.4042 .38254 m
.40389 .39065 L
s
.40391 .39061 m
.4042 .38254 L
s
.4042 .38254 m
.40366 .39843 L
s
.504 .282 1 r
.73926 .3474 m
.74206 .388 L
s
1 .146 .894 r
.4423 .3474 m
.44139 .39388 L
s
.383 .317 1 r
.14535 .3474 m
.1411 .38653 L
s
.68 .237 1 r
.65255 .38532 m
.65286 .39421 L
s
.65288 .39417 m
.65255 .38532 L
s
.65255 .38532 m
.65323 .40266 L
s
.788 .212 1 r
.76458 .38762 m
.76519 .39666 L
s
.76522 .39662 m
.76458 .38762 L
s
.76458 .38762 m
.76588 .40556 L
s
.733 .224 1 r
.30257 .41329 m
.30249 .41359 L
s
.916 .184 1 r
.84794 .41604 m
.84791 .41638 L
s
.352 .327 1 r
.80361 .39382 m
.80426 .40177 L
s
.80429 .40144 m
.80361 .39382 L
s
.425 .305 1 r
.89995 .34716 m
.90449 .38593 L
s
1 .161 .972 r
.60295 .34716 m
.60426 .39327 L
s
.701 .232 1 r
.46323 .41269 m
.46316 .41299 L
s
.494 .284 1 r
.30595 .34716 m
.30345 .3885 L
s
.811 .206 1 r
.78892 .38643 m
.7896 .39561 L
s
.78963 .39557 m
.78892 .38643 L
s
.78892 .38643 m
.79034 .40436 L
s
.88 .191 1 r
.20006 .40267 m
.19916 .41189 L
s
.19924 .41178 m
.20006 .40267 L
s
.352 .327 1 r
.80426 .40177 m
.80363 .39378 L
s
.80363 .39378 m
.80429 .40144 L
s
.361 .324 1 r
.88617 .38104 m
.887 .38907 L
s
.88703 .38903 m
.88617 .38104 L
s
.88617 .38104 m
.88786 .39663 L
s
.79 .211 1 r
.5457 .39999 m
.54575 .40914 L
s
.54581 .40865 m
.5457 .39999 L
s
.88 .191 1 r
.19916 .41189 m
.20008 .40263 L
s
.20008 .40263 m
.19924 .41178 L
s
.79 .211 1 r
.54575 .40914 m
.54572 .39995 L
s
.54572 .39995 m
.54581 .40865 L
s
.433 .302 1 r
.69683 .40815 m
.69678 .4083 L
s
.66 .241 1 r
.19488 .38661 m
.19401 .39532 L
s
.19402 .39528 m
.19488 .38661 L
s
.19488 .38661 m
.19321 .40399 L
s
.367 .497 1 r
.55524 .39143 m
.55531 .39897 L
s
.55535 .39869 m
.55524 .39143 L
s
.66 .241 1 r
.51186 .41031 m
.5118 .4109 L
s
.367 .497 1 r
.55531 .39897 m
.55526 .3914 L
s
.55526 .3914 m
.55535 .39869 L
s
.845 .199 1 r
.76364 .34692 m
.76702 .3912 L
s
.799 .209 1 r
.4666 .34692 m
.46605 .3912 L
s
.357 .451 1 r
.16957 .34692 m
.16587 .38349 L
s
.669 .239 1 r
.19049 .41186 m
.1904 .41216 L
s
.495 .284 1 r
.16092 .39708 m
.16002 .40537 L
s
.16009 .4053 m
.16092 .39708 L
s
.16002 .40537 m
.16094 .39704 L
s
.16094 .39704 m
.16009 .4053 L
s
.467 .292 1 r
.85754 .40792 m
.85752 .40821 L
s
.569 .264 1 r
.21479 .41067 m
.21472 .41082 L
s
.822 .204 1 r
.38501 .40139 m
.38462 .4105 L
s
.38469 .41035 m
.38501 .40139 L
s
.38462 .4105 m
.38503 .40135 L
s
.38503 .40135 m
.38469 .41035 L
s
.669 .239 1 r
.6273 .34668 m
.62881 .38912 L
s
.57 .264 1 r
.33022 .34668 m
.32807 .38728 L
s
.766 .217 1 r
.35552 .38666 m
.35505 .39567 L
s
.35506 .39562 m
.35552 .38666 L
s
.35552 .38666 m
.35465 .40449 L
s
.977 .171 1 r
.55095 .41714 m
.55089 .41733 L
s
.638 .247 1 r
.83764 .38477 m
.83842 .39351 L
s
.83845 .39347 m
.83764 .38477 L
s
.83764 .38477 m
.83926 .40196 L
s
.569 .264 1 r
.75506 .39766 m
.75564 .40618 L
s
.75568 .40603 m
.75506 .39766 L
s
.6 .256 1 r
.86197 .38346 m
.86281 .39216 L
s
.86284 .39212 m
.86197 .38346 L
s
.86197 .38346 m
.86369 .40039 L
s
.441 .3 1 r
.28772 .40709 m
.28764 .40738 L
s
.569 .264 1 r
.75564 .40618 m
.75509 .39762 L
s
.75509 .39762 m
.75568 .40603 L
s
.598 .257 1 r
.24344 .38491 m
.2427 .39351 L
s
.24271 .39347 m
.24344 .38491 L
s
.24344 .38491 m
.24204 .40196 L
s
.744 .221 1 r
.37984 .38561 m
.37942 .39461 L
s
.37944 .39457 m
.37984 .38561 L
s
.37984 .38561 m
.3791 .40329 L
s
.68 .237 1 r
.54055 .38494 m
.54056 .3938 L
s
.54058 .39376 m
.54055 .38494 L
s
.54055 .38494 m
.54065 .40232 L
s
.503 .282 1 r
.64301 .39579 m
.64329 .4042 L
s
.64334 .40386 m
.64301 .39579 L
s
.723 .226 1 r
.78803 .34644 m
.79156 .38852 L
s
.68 .237 1 r
.49092 .34644 m
.4907 .38889 L
s
.367 .322 1 r
.1938 .34644 m
.19015 .38521 L
s
.503 .282 1 r
.64329 .4042 m
.64303 .39576 L
s
.64303 .39576 m
.64334 .40386 L
s
.777 .214 1 r
.21911 .38639 m
.21827 .39543 L
s
.21828 .39539 m
.21911 .38639 L
s
.21911 .38639 m
.21752 .40425 L
s
.765 .217 1 r
.51623 .38643 m
.51617 .39543 L
s
.51619 .39539 m
.51623 .38643 L
s
.51623 .38643 m
.5162 .40425 L
s
.559 .267 1 r
.48229 .39661 m
.48217 .40516 L
s
.48223 .40483 m
.48229 .39661 L
s
.48217 .40516 m
.48231 .39657 L
s
.48231 .39657 m
.48223 .40483 L
s
.916 .184 1 r
.52138 .40279 m
.52137 .41205 L
s
.52143 .41204 m
.52138 .40279 L
s
.754 .219 1 r
.62393 .41356 m
.62387 .41371 L
s
.916 .184 1 r
.52137 .41205 m
.52141 .40274 L
s
.52141 .40274 m
.52143 .41204 L
s
.777 .214 1 r
.78467 .41296 m
.78464 .4133 L
s
.68 .237 1 r
.70129 .38471 m
.70172 .39356 L
s
.70175 .39352 m
.70129 .38471 L
s
.70129 .38471 m
.70222 .40209 L
s
.459 .295 1 r
.20946 .39556 m
.20868 .40378 L
s
.20875 .40363 m
.20946 .39556 L
s
.375 .32 1 r
.23378 .39422 m
.23309 .40218 L
s
.23315 .40207 m
.23378 .39422 L
s
.777 .214 1 r
.65165 .3462 m
.65352 .38975 L
s
.68 .237 1 r
.3545 .3462 m
.35255 .38865 L
s
.459 .295 1 r
.20868 .40378 m
.20947 .39552 L
s
.20947 .39552 m
.20875 .40363 L
s
.375 .32 1 r
.23309 .40218 m
.2338 .39418 L
s
.2338 .39418 m
.23315 .40207 L
s
.68 .237 1 r
.6726 .41117 m
.67256 .4115 L
s
.648 .244 1 r
.53618 .41057 m
.53613 .41091 L
s
.385 .575 1 r
.49184 .38834 m
.49176 .3958 L
s
.49181 .39523 m
.49184 .38834 L
s
.476 .29 1 r
.44842 .40722 m
.44836 .40755 L
s
.811 .206 1 r
.7308 .39987 m
.73135 .40902 L
s
.73139 .40868 m
.7308 .39987 L
s
.835 .201 1 r
.43363 .39987 m
.43337 .4091 L
s
.43345 .40868 m
.43363 .39987 L
s
.385 .575 1 r
.49176 .3958 m
.49185 .3883 L
s
.49185 .3883 m
.49181 .39523 L
s
.811 .206 1 r
.73135 .40902 m
.73082 .39983 L
s
.73082 .39983 m
.73139 .40868 L
s
.835 .201 1 r
.43337 .4091 m
.43365 .39983 L
s
.43365 .39983 m
.43345 .40868 L
s
.618 .252 1 r
.72565 .38381 m
.72613 .39251 L
s
.72616 .39247 m
.72565 .38381 L
s
.72565 .38381 m
.72669 .40089 L
s
.503 .282 1 r
.45278 .38247 m
.45258 .39088 L
s
.4526 .39084 m
.45278 .38247 L
s
.45278 .38247 m
.45246 .39896 L
s
.869 .194 1 r
.81243 .34596 m
.8165 .39062 L
s
.503 .282 1 r
.51524 .34596 m
.51533 .38621 L
s
.733 .224 1 r
.21805 .34596 m
.21427 .38951 L
s
.881 .191 1 r
.32676 .41429 m
.32668 .41463 L
s
.589 .259 1 r
.50661 .39614 m
.50656 .40481 L
s
.50662 .40436 m
.50661 .39614 L
s
.4 .312 1 r
.85248 .39346 m
.85326 .40157 L
s
.85328 .40124 m
.85248 .39346 L
s
.589 .259 1 r
.50656 .40481 m
.50663 .3961 L
s
.50663 .3961 m
.50662 .40436 L
s
.4 .312 1 r
.85326 .40157 m
.8525 .39343 L
s
.8525 .39343 m
.85328 .40124 L
s
.476 .29 1 r
.61355 .38202 m
.61374 .39035 L
s
.61376 .39031 m
.61355 .38202 L
s
.61355 .38202 m
.614 .39836 L
s
.638 .247 1 r
.42845 .38406 m
.42817 .3928 L
s
.42819 .39276 m
.42845 .38406 L
s
.42845 .38406 m
.42798 .40125 L
s
.744 .222 1 r
.29717 .39964 m
.29656 .40857 L
s
.29663 .40845 m
.29717 .39964 L
s
.669 .239 1 r
.61872 .3983 m
.61895 .40708 L
s
.61901 .40689 m
.61872 .3983 L
s
.845 .199 1 r
.81344 .38748 m
.81418 .3966 L
s
.81421 .39656 m
.81344 .38748 L
s
.81344 .38748 m
.81502 .40572 L
s
.916 .184 1 r
.89684 .41585 m
.8968 .41597 L
s
.744 .222 1 r
.29656 .40857 m
.29719 .3996 L
s
.29719 .3996 m
.29663 .40845 L
s
.669 .239 1 r
.61895 .40708 m
.61874 .39826 L
s
.61874 .39826 m
.61901 .40689 L
s
.68 .237 1 r
.7795 .39778 m
.78017 .40663 L
s
.7802 .40629 m
.7795 .39778 L
s
.823 .204 1 r
.67602 .34572 m
.6782 .38891 L
s
.8 .209 1 r
.37879 .34572 m
.37709 .38965 L
s
.68 .237 1 r
.78017 .40663 m
.77953 .39773 L
s
.77953 .39773 m
.7802 .40629 L
s
.904 .186 1 r
.27282 .40127 m
.27212 .41057 L
s
.2722 .41038 m
.27282 .40127 L
s
.881 .191 1 r
.5944 .39993 m
.59458 .40927 L
s
.59463 .40882 m
.5944 .39993 L
s
.569 .264 1 r
.37016 .39591 m
.36976 .4045 L
s
.36983 .40413 m
.37016 .39591 L
s
.477 .289 1 r
.69173 .39457 m
.69214 .4029 L
s
.69218 .40257 m
.69173 .39457 L
s
.904 .186 1 r
.27212 .41057 m
.27284 .40123 L
s
.27284 .40123 m
.2722 .41038 L
s
.881 .191 1 r
.59458 .40927 m
.59442 .39989 L
s
.59442 .39989 m
.59463 .40882 L
s
.569 .264 1 r
.36976 .4045 m
.37018 .39587 L
s
.37018 .39587 m
.36983 .40413 L
s
.589 .259 1 r
.75002 .38312 m
.75057 .39175 L
s
.75059 .39171 m
.75002 .38312 L
s
.75002 .38312 m
.75118 .40005 L
s
.477 .289 1 r
.69214 .4029 m
.69175 .39453 L
s
.69175 .39453 m
.69218 .40257 L
s
.834 .201 1 r
.80911 .41286 m
.80908 .41327 L
s
.375 .32 1 r
.50144 .38044 m
.50136 .38848 L
s
.50138 .38844 m
.50144 .38044 L
s
.50144 .38044 m
.50135 .39619 L
s
.391 .315 1 r
.79433 .40556 m
.79429 .40574 L
s
.869 .194 1 r
.89166 .40023 m
.89266 .40949 L
s
.89269 .40919 m
.89166 .40023 L
s
.669 .239 1 r
.23892 .41167 m
.23886 .41175 L
s
.869 .194 1 r
.89266 .40949 m
.89169 .40018 L
s
.89169 .40018 m
.89269 .40919 L
s
.354 .435 1 r
.87172 .3766 m
.8725 .38445 L
s
.87253 .38441 m
.87172 .3766 L
s
.87172 .3766 m
.87328 .39149 L
s
.618 .252 1 r
.83685 .34548 m
.84095 .3872 L
s
.441 .3 1 r
.53958 .34548 m
.53995 .38536 L
s
.833 .201 1 r
.24231 .34548 m
.23876 .39014 L
s
.711 .229 1 r
.39973 .41107 m
.39965 .41141 L
s
.469 .291 1 r
.81869 .40437 m
.8187 .4051 L
s
.521 .277 1 r
.82822 .39568 m
.82897 .40408 L
s
.82901 .4039 m
.82822 .39568 L
s
.628 .249 1 r
.29196 .38419 m
.29133 .39286 L
s
.29135 .39282 m
.29196 .38419 L
s
.29196 .38419 m
.29079 .40139 L
s
.521 .277 1 r
.82897 .40408 m
.82825 .39564 L
s
.82825 .39564 m
.82901 .4039 L
s
.777 .214 1 r
.32146 .39918 m
.3209 .40822 L
s
.32098 .40799 m
.32146 .39918 L
s
.3209 .40822 m
.32147 .39913 L
s
.32147 .39913 m
.32098 .40799 L
s
.355 .439 1 r
.40926 .40258 m
.40921 .40272 L
s
.799 .209 1 r
.56491 .3857 m
.56499 .39479 L
s
.56501 .39474 m
.56491 .3857 L
s
.56491 .3857 m
.56515 .40368 L
s
.7 .232 1 r
.26761 .38571 m
.26691 .39449 L
s
.26693 .39445 m
.26761 .38571 L
s
.26761 .38571 m
.26629 .40332 L
s
.88 .191 1 r
.45793 .39999 m
.45774 .40929 L
s
.45781 .40895 m
.45793 .39999 L
s
.4 .312 1 r
.66226 .38042 m
.66256 .38854 L
s
.66259 .3885 m
.66226 .38042 L
s
.66226 .38042 m
.66293 .39632 L
s
.88 .191 1 r
.45774 .40929 m
.45795 .39995 L
s
.45795 .39995 m
.45781 .40895 L
s
.503 .282 1 r
.70041 .34524 m
.70272 .38549 L
s
.777 .214 1 r
.4031 .34524 m
.40173 .3888 L
s
.669 .239 1 r
.26323 .41084 m
.26315 .41103 L
s
.7 .232 1 r
.34578 .39812 m
.3453 .40698 L
s
.34537 .40679 m
.34578 .39812 L
s
.3453 .40698 m
.3458 .39808 L
s
.3458 .39808 m
.34537 .40679 L
s
.679 .237 1 r
.58925 .38466 m
.58939 .39344 L
s
.58941 .3934 m
.58925 .38466 L
s
.58925 .38466 m
.5896 .40212 L
s
.618 .252 1 r
.15106 .40905 m
.15096 .40938 L
s
.588 .259 1 r
.31189 .40845 m
.31181 .40878 L
s
.8 .209 1 r
.9161 .39975 m
.91715 .4088 L
s
.9172 .40871 m
.9161 .39975 L
s
.425 .305 1 r
.14579 .39305 m
.14486 .40123 L
s
.14496 .4009 m
.14579 .39305 L
s
.8 .209 1 r
.91715 .4088 m
.91613 .39971 L
s
.91613 .39971 m
.9172 .40871 L
s
1 .151 .92 r
.86128 .345 m
.86637 .39335 L
s
.811 .206 1 r
.56393 .345 m
.56466 .38893 L
s
.495 .284 1 r
.26658 .345 m
.2637 .38489 L
s
.425 .305 1 r
.14486 .40123 m
.1458 .39301 L
s
.1458 .39301 m
.14496 .4009 L
s
.777 .214 1 r
.18491 .39923 m
.18399 .40824 L
s
.18407 .40812 m
.18491 .39923 L
s
.669 .239 1 r
.58489 .41001 m
.58483 .41031 L
s
.777 .214 1 r
.18399 .40824 m
.18492 .39919 L
s
.18492 .39919 m
.18407 .40812 L
s
.711 .229 1 r
.91097 .38375 m
.91196 .39268 L
s
.91199 .39264 m
.91097 .38375 L
s
.91097 .38375 m
.913 .40128 L
s
.495 .284 1 r
.65792 .40606 m
.65788 .40646 L
s
.416 .307 1 r
.68227 .40487 m
.68223 .40516 L
s
.881 .191 1 r
.7248 .34476 m
.7277 .38943 L
s
.375 .32 1 r
.42742 .34476 m
.42649 .38318 L
s
1 .161 .972 r
.13003 .34476 m
.12468 .392 L
s
.615 1 .735 r
.83268 .37188 m
.83316 .3772 L
s
.83311 .37628 m
.83268 .37188 L
s
.83316 .3772 m
.83269 .37186 L
s
.83269 .37186 m
.83311 .37628 L
s
.669 .239 1 r
.74577 .40978 m
.74573 .41008 L
s
.711 .229 1 r
.1797 .38351 m
.17876 .39245 L
s
.17877 .39241 m
.1797 .38351 L
s
.1797 .38351 m
.17793 .40105 L
s
.608 .254 1 r
.17531 .40858 m
.17522 .40888 L
s
.392 .315 1 r
.30658 .39311 m
.30606 .40111 L
s
.30612 .40104 m
.30658 .39311 L
s
.383 .565 1 r
.59882 .37686 m
.59896 .38427 L
s
.59898 .38423 m
.59882 .37686 L
s
.59882 .37686 m
.59916 .39139 L
s
.392 .315 1 r
.30606 .40111 m
.3066 .39307 L
s
.3066 .39307 m
.30612 .40104 L
s
.892 .189 1 r
.37532 .41409 m
.37525 .41425 L
s
.777 .214 1 r
.66749 .39795 m
.66787 .40703 L
s
.66792 .40669 m
.66749 .39795 L
s
.628 .249 1 r
.39442 .39661 m
.39407 .40528 L
s
.39414 .40513 m
.39442 .39661 L
s
.68 .237 1 r
.63798 .38306 m
.63824 .39192 L
s
.63827 .39188 m
.63798 .38306 L
s
.63798 .38306 m
.63858 .40045 L
s
.34056 .38306 m
.34005 .39192 L
s
.34006 .39188 m
.34056 .38306 L
s
.34056 .38306 m
.33963 .40045 L
s
.559 .267 1 r
.49707 .40739 m
.497 .40772 L
s
.503 .282 1 r
.52579 .38105 m
.52576 .38947 L
s
.52578 .38943 m
.52579 .38105 L
s
.52579 .38105 m
.52581 .39755 L
s
.711 .229 1 r
.88572 .34452 m
.89056 .38735 L
s
.531 .274 1 r
.58829 .34452 m
.58927 .38515 L
s
.7 .232 1 r
.29087 .34452 m
.28806 .38772 L
s
.777 .214 1 r
.66787 .40703 m
.66752 .39791 L
s
.66752 .39791 m
.66792 .40669 L
s
.628 .249 1 r
.39407 .40528 m
.39444 .39657 L
s
.39444 .39657 m
.39414 .40513 L
s
.744 .222 1 r
.53096 .39742 m
.53097 .40643 L
s
.53103 .40609 m
.53096 .39742 L
s
.68 .237 1 r
.60926 .40955 m
.60921 .40988 L
s
.822 .204 1 r
.15531 .38525 m
.15428 .39438 L
s
.1543 .39433 m
.15531 .38525 L
s
.15531 .38525 m
.15335 .40335 L
s
.523 .276 1 r
.55014 .37985 m
.55018 .38841 L
s
.5502 .38837 m
.55014 .37985 L
s
.55014 .37985 m
.55029 .39635 L
s
.744 .222 1 r
.53097 .40643 m
.53098 .39738 L
s
.53098 .39738 m
.53103 .40609 L
s
.766 .217 1 r
.77453 .38399 m
.77517 .39303 L
s
.7752 .39299 m
.77453 .38399 L
s
.77453 .38399 m
.77587 .40178 L
s
.618 .252 1 r
.41876 .39556 m
.41848 .40426 L
s
.41855 .40393 m
.41876 .39556 L
s
.66 .241 1 r
.93106 .40835 m
.93106 .40883 L
s
.45 .297 1 r
.24832 .405 m
.24823 .40533 L
s
.777 .214 1 r
.88236 .41111 m
.88234 .41144 L
s
.618 .252 1 r
.41848 .40426 m
.41878 .39552 L
s
.41878 .39552 m
.41855 .40393 L
s
.42 .721 1 r
.31612 .38482 m
.31567 .39193 L
s
.31575 .39142 m
.31612 .38482 L
s
.588 .259 1 r
.57966 .39503 m
.5798 .40366 L
s
.57985 .40333 m
.57966 .39503 L
s
.42 .721 1 r
.31567 .39193 m
.31613 .38479 L
s
.31613 .38479 m
.31575 .39142 L
s
.45 .297 1 r
.8476 .38015 m
.84836 .38841 L
s
.84839 .38837 m
.8476 .38015 L
s
.8476 .38015 m
.84917 .39635 L
s
.777 .214 1 r
.74921 .34428 m
.75235 .38785 L
s
.522 .277 1 r
.45175 .34428 m
.45106 .38491 L
s
.608 .254 1 r
.15429 .34428 m
.14986 .38601 L
s
.588 .259 1 r
.5798 .40366 m
.57969 .39499 L
s
.57969 .39499 m
.57985 .40333 L
s
.629 .249 1 r
.68671 .381 m
.6871 .38981 L
s
.68713 .38977 m
.68671 .381 L
s
.68671 .381 m
.68755 .39805 L
s
.618 .252 1 r
.28219 .39532 m
.28155 .40403 L
s
.28163 .40369 m
.28219 .39532 L
s
.28155 .40403 m
.2822 .39528 L
s
.2822 .39528 m
.28163 .40369 L
s
.54 .272 1 r
.22829 .38189 m
.22753 .39034 L
s
.22754 .3903 m
.22829 .38189 L
s
.22829 .38189 m
.22684 .39865 L
s
.941 .179 1 r
.91017 .34404 m
.91563 .38945 L
s
.589 .259 1 r
.61267 .34404 m
.61396 .3854 L
s
.648 .244 1 r
.31517 .34404 m
.31274 .38614 L
s
.513 .279 1 r
.9259 .39293 m
.92691 .40141 L
s
.92691 .40093 m
.9259 .39293 L
s
1 .065 .43 r
.86764 .40449 m
.86872 .41517 L
s
.86871 .41442 m
.86764 .40449 L
s
.513 .279 1 r
.92691 .40141 m
.92593 .39289 L
s
.92593 .39289 m
.92691 .40093 L
s
1 .065 .43 r
.86872 .41517 m
.86767 .40444 L
s
.86767 .40444 m
.86871 .41442 L
s
.991 .169 1 r
.47709 .38492 m
.47692 .39449 L
s
.47694 .39445 m
.47709 .38492 L
s
.47709 .38492 m
.47685 .40361 L
s
.471 .907 1 r
.85722 .3721 m
.85785 .37865 L
s
.85787 .37862 m
.85722 .3721 L
s
.85722 .3721 m
.8585 .38489 L
s
.733 .224 1 r
.20391 .38362 m
.20303 .39256 L
s
.20305 .39252 m
.20391 .38362 L
s
.20391 .38362 m
.20225 .40131 L
s
.477 .289 1 r
.33086 .39322 m
.33037 .40152 L
s
.33044 .4013 m
.33086 .39322 L
s
.589 .259 1 r
.77363 .3438 m
.77692 .38517 L
s
.477 .289 1 r
.47609 .3438 m
.47571 .3837 L
s
.467 .292 1 r
.17855 .3438 m
.1745 .3848 L
s
.357 .451 1 r
.62322 .377 m
.62342 .38467 L
s
.62344 .38463 m
.62322 .377 L
s
.62322 .377 m
.62368 .39201 L
s
.477 .289 1 r
.33037 .40152 m
.33088 .39319 L
s
.33088 .39319 m
.33044 .4013 L
s
.648 .244 1 r
.74064 .39538 m
.7412 .40416 L
s
.74123 .40383 m
.74064 .39538 L
s
.579 .262 1 r
.46745 .39404 m
.4673 .40267 L
s
.46736 .40226 m
.46745 .39404 L
s
.845 .199 1 r
.79899 .38391 m
.79971 .39314 L
s
.79974 .3931 m
.79899 .38391 L
s
.79899 .38391 m
.80049 .40205 L
s
.648 .244 1 r
.7412 .40416 m
.74066 .39534 L
s
.74066 .39534 m
.74123 .40383 L
s
.359 .325 1 r
.43791 .37919 m
.43768 .38712 L
s
.4377 .38709 m
.43791 .37919 L
s
.43791 .37919 m
.43752 .39491 L
s
.579 .262 1 r
.4673 .40267 m
.46747 .394 L
s
.46747 .394 m
.46736 .40226 L
s
.476 .29 1 r
.57014 .4049 m
.57009 .40523 L
s
.756 .219 1 r
.87725 .3962 m
.8782 .40528 L
s
.87821 .40479 m
.87725 .3962 L
s
.8782 .40528 m
.87728 .39615 L
s
.87728 .39615 m
.87821 .40479 L
s
.589 .259 1 r
.84336 .40646 m
.84334 .4069 L
s
.68 .237 1 r
.38919 .38212 m
.38881 .39098 L
s
.38883 .39094 m
.38919 .38212 L
s
.38919 .38212 m
.38852 .39951 L
s
.648 .244 1 r
.63706 .34356 m
.63868 .38566 L
s
.799 .209 1 r
.33948 .34356 m
.33724 .38787 L
s
.777 .214 1 r
.71631 .3973 m
.71682 .40635 L
s
.71687 .40612 m
.71631 .3973 L
s
1 .161 .972 r
.72157 .41353 m
.72154 .41399 L
s
.777 .214 1 r
.71682 .40635 m
.71634 .39726 L
s
.71634 .39726 m
.71687 .40612 L
s
.521 .277 1 r
.25255 .38182 m
.25185 .39016 L
s
.25186 .39012 m
.25255 .38182 L
s
.25255 .38182 m
.25122 .39854 L
s
.765 .217 1 r
.25772 .39812 m
.257 .40706 L
s
.25706 .40709 m
.25772 .39812 L
s
.375 .32 1 r
.30127 .37921 m
.30071 .38718 L
s
.30073 .38714 m
.30127 .37921 L
s
.30127 .37921 m
.30024 .39504 L
s
.765 .217 1 r
.257 .40706 m
.25773 .39808 L
s
.25773 .39808 m
.25706 .40709 L
s
.552 .269 1 r
.79807 .34332 m
.8016 .38395 L
s
.711 .229 1 r
.50045 .34332 m
.50035 .38616 L
s
.58 .262 1 r
.20283 .34332 m
.19897 .38543 L
s
.711 .229 1 r
.36043 .40898 m
.36035 .40932 L
s
.679 .237 1 r
.82342 .38333 m
.82416 .39209 L
s
.82419 .39205 m
.82342 .38333 L
s
.82342 .38333 m
.82499 .40084 L
s
.628 .249 1 r
.22379 .40838 m
.22372 .40854 L
s
.354 .326 1 r
.57451 .38076 m
.5746 .38853 L
s
.57462 .38849 m
.57451 .38076 L
s
.57451 .38076 m
.57477 .39661 L
s
.618 .252 1 r
.62844 .39439 m
.6287 .40309 L
s
.62875 .40276 m
.62844 .39439 L
s
.416 .307 1 r
.67717 .3917 m
.67753 .39981 L
s
.67758 .39963 m
.67717 .3917 L
s
.618 .252 1 r
.6287 .40309 m
.62846 .39435 L
s
.62846 .39435 m
.62875 .40276 L
s
.416 .307 1 r
.67753 .39981 m
.67719 .39166 L
s
.67719 .39166 m
.67758 .39963 L
s
.669 .239 1 r
.16978 .3952 m
.16884 .40402 L
s
.16894 .40373 m
.16978 .3952 L
s
.68 .237 1 r
.66146 .34308 m
.66341 .38555 L
s
.476 .29 1 r
.3638 .34308 m
.36208 .38298 L
s
.669 .239 1 r
.16884 .40402 m
.1698 .39516 L
s
.1698 .39516 m
.16894 .40373 L
s
.833 .201 1 r
.47268 .41151 m
.47262 .4117 L
s
.367 .497 1 r
.55535 .39869 m
.55531 .39897 L
s
1 .156 .946 r
.42395 .41427 m
.42387 .41457 L
s
.4 .312 1 r
.40389 .39065 m
.40359 .39876 L
s
.40366 .39843 m
.40389 .39065 L
s
.352 .327 1 r
.80429 .40144 m
.80426 .40177 L
s
.4 .312 1 r
.40359 .39876 m
.40391 .39061 L
s
.40391 .39061 m
.40366 .39843 L
s
.691 .234 1 r
.70682 .40696 m
.7068 .40755 L
s
.991 .169 1 r
.90703 .41247 m
.90702 .41292 L
s
.916 .184 1 r
.77038 .41187 m
.77034 .41221 L
s
.56 .267 1 r
.82251 .34284 m
.82634 .38348 L
s
.752 1 .697 r
.52482 .34284 m
.52492 .36267 L
s
.512 .279 1 r
.22712 .34284 m
.22367 .38385 L
s
.881 .191 1 r
.33602 .41127 m
.33594 .41161 L
s
.845 .199 1 r
.44306 .39713 m
.44282 .40636 L
s
.4429 .40602 m
.44306 .39713 L
s
.638 .247 1 r
.27684 .38156 m
.27618 .39027 L
s
.27619 .39023 m
.27684 .38156 L
s
.27684 .38156 m
.2756 .3988 L
s
.361 .324 1 r
.887 .38907 m
.88786 .39711 L
s
.88786 .39663 m
.887 .38907 L
s
.845 .199 1 r
.44282 .40636 m
.44308 .39709 L
s
.44308 .39709 m
.4429 .40602 L
s
.361 .324 1 r
.88786 .39711 m
.88703 .38903 L
s
.88703 .38903 m
.88786 .39663 L
s
.811 .206 1 r
.6041 .3966 m
.60431 .40576 L
s
.60436 .40542 m
.6041 .3966 L
s
.60431 .40576 m
.60412 .39656 L
s
.60412 .39656 m
.60436 .40542 L
s
.618 .252 1 r
.89666 .38051 m
.89759 .38922 L
s
.89762 .38918 m
.89666 .38051 L
s
.89666 .38051 m
.89857 .3976 L
s
.468 .292 1 r
.16451 .37987 m
.1636 .38811 L
s
.16362 .38807 m
.16451 .37987 L
s
.16451 .37987 m
.16277 .39627 L
s
.916 .184 1 r
.68587 .34259 m
.68832 .38876 L
s
.788 .212 1 r
.38814 .34259 m
.38654 .38692 L
s
.442 .3 1 r
.18888 .37853 m
.18804 .38676 L
s
.18805 .38673 m
.18888 .37853 L
s
.18888 .37853 m
.18729 .3947 L
s
.46 .294 1 r
.64768 .37789 m
.64796 .38623 L
s
.64798 .38619 m
.64768 .37789 L
s
.64768 .37789 m
.6483 .3941 L
s
.68 .237 1 r
.65286 .39421 m
.65319 .4031 L
s
.65323 .40266 m
.65286 .39421 L
s
.65319 .4031 m
.65288 .39417 L
s
.65288 .39417 m
.65323 .40266 L
s
.834 .201 1 r
.71125 .38277 m
.71172 .39197 L
s
.71175 .39193 m
.71125 .38277 L
s
.71125 .38277 m
.71227 .40087 L
s
1 .149 .907 r
.36475 .38556 m
.36426 .39525 L
s
.36428 .3952 m
.36475 .38556 L
s
.36475 .38556 m
.36386 .40475 L
s
.88 .191 1 r
.90188 .39719 m
.90292 .40649 L
s
.90294 .40616 m
.90188 .39719 L
s
.79 .211 1 r
.54581 .40865 m
.54575 .40914 L
s
.495 .284 1 r
.16009 .4053 m
.16002 .40537 L
s
.88 .191 1 r
.90292 .40649 m
.90191 .39714 L
s
.90191 .39714 m
.90294 .40616 L
s
.559 .267 1 r
.84697 .34235 m
.85113 .38337 L
s
.711 .229 1 r
.5492 .34235 m
.54973 .38521 L
s
.833 .201 1 r
.25142 .34235 m
.24799 .38705 L
s
.385 .575 1 r
.49181 .39523 m
.49176 .3958 L
s
.788 .212 1 r
.76519 .39666 m
.76583 .40571 L
s
.76588 .40556 m
.76519 .39666 L
s
.615 1 .735 r
.83311 .37628 m
.83316 .3772 L
s
.66 .241 1 r
.19401 .39532 m
.19314 .40404 L
s
.19321 .40399 m
.19401 .39532 L
s
.788 .212 1 r
.76583 .40571 m
.76522 .39662 L
s
.76522 .39662 m
.76588 .40556 L
s
.916 .184 1 r
.41349 .38317 m
.41315 .39255 L
s
.41317 .39251 m
.41349 .38317 L
s
.41349 .38317 m
.41291 .40161 L
s
.66 .241 1 r
.19314 .40404 m
.19402 .39528 L
s
.19402 .39528 m
.19321 .40399 L
s
.777 .214 1 r
.73565 .38183 m
.73619 .39091 L
s
.73621 .39087 m
.73565 .38183 L
s
.73565 .38183 m
.73679 .39967 L
s
.88 .191 1 r
.19924 .41178 m
.19916 .41189 L
s
.811 .206 1 r
.7896 .39561 m
.79032 .4048 L
s
.79034 .40436 m
.7896 .39561 L
s
.559 .267 1 r
.48662 .37936 m
.48649 .38793 L
s
.48651 .38789 m
.48662 .37936 L
s
.48662 .37936 m
.48645 .39616 L
s
.531 .274 1 r
.7103 .34211 m
.71276 .38276 L
s
.845 .199 1 r
.41249 .34211 m
.41122 .38644 L
s
.811 .206 1 r
.79032 .4048 m
.78963 .39557 L
s
.78963 .39557 m
.79034 .40436 L
s
.692 .234 1 r
.32552 .3801 m
.32497 .38904 L
s
.32499 .389 m
.32552 .3801 L
s
.32552 .3801 m
.32452 .3975 L
s
.45 .297 1 r
.6721 .37746 m
.67243 .38576 L
s
.67246 .38573 m
.6721 .37746 L
s
.6721 .37746 m
.67283 .39363 L
s
.503 .282 1 r
.64334 .40386 m
.64329 .4042 L
s
.744 .222 1 r
.14002 .38226 m
.13898 .39121 L
s
.13899 .39116 m
.14002 .38226 L
s
.14002 .38226 m
.13802 .40004 L
s
.569 .264 1 r
.75568 .40603 m
.75564 .40618 L
s
.375 .32 1 r
.23315 .40207 m
.23309 .40218 L
s
.68 .237 1 r
.92119 .38047 m
.9222 .38933 L
s
.92223 .38929 m
.92119 .38047 L
s
.92119 .38047 m
.92326 .39787 L
s
.559 .267 1 r
.48223 .40483 m
.48217 .40516 L
s
.478 .289 1 r
.87144 .34187 m
.87568 .38069 L
s
.45 .297 1 r
.57359 .34187 m
.57437 .38142 L
s
.711 .229 1 r
.27574 .34187 m
.27276 .38473 L
s
.822 .204 1 r
.38469 .41035 m
.38462 .4105 L
s
.638 .247 1 r
.83842 .39351 m
.83923 .40225 L
s
.83926 .40196 m
.83842 .39351 L
s
.598 .257 1 r
.2427 .39351 m
.24197 .40211 L
s
.24204 .40196 m
.2427 .39351 L
s
.6 .256 1 r
.86281 .39216 m
.86368 .40087 L
s
.86369 .40039 m
.86281 .39216 L
s
.459 .295 1 r
.20875 .40363 m
.20868 .40378 L
s
.638 .247 1 r
.83923 .40225 m
.83845 .39347 L
s
.83845 .39347 m
.83926 .40196 L
s
.598 .257 1 r
.24197 .40211 m
.24271 .39347 L
s
.24271 .39347 m
.24204 .40196 L
s
.6 .256 1 r
.86368 .40087 m
.86284 .39212 L
s
.86284 .39212 m
.86369 .40039 L
s
.766 .217 1 r
.35505 .39567 m
.35458 .40468 L
s
.35465 .40449 m
.35505 .39567 L
s
.35458 .40468 m
.35506 .39562 L
s
.35506 .39562 m
.35465 .40449 L
s
.68 .237 1 r
.54056 .3938 m
.5406 .40266 L
s
.54065 .40232 m
.54056 .3938 L
s
.4 .312 1 r
.85328 .40124 m
.85326 .40157 L
s
.744 .222 1 r
.73474 .34163 m
.73767 .38486 L
s
.68 .237 1 r
.43685 .34163 m
.43594 .38412 L
s
.777 .214 1 r
.13896 .34163 m
.13405 .38596 L
s
.68 .237 1 r
.5406 .40266 m
.54058 .39376 L
s
.54058 .39376 m
.54065 .40232 L
s
.744 .221 1 r
.37942 .39461 m
.37902 .40362 L
s
.3791 .40329 m
.37942 .39461 L
s
.37902 .40362 m
.37944 .39457 L
s
.37944 .39457 m
.3791 .40329 L
s
.765 .217 1 r
.51617 .39543 m
.51614 .40444 L
s
.5162 .40425 m
.51617 .39543 L
s
.777 .214 1 r
.21827 .39543 m
.21743 .40448 L
s
.21752 .40425 m
.21827 .39543 L
s
.468 .292 1 r
.53538 .3778 m
.53538 .38611 L
s
.5354 .38607 m
.53538 .3778 L
s
.53538 .3778 m
.53546 .39413 L
s
.765 .217 1 r
.51614 .40444 m
.51619 .39539 L
s
.51619 .39539 m
.5162 .40425 L
s
.777 .214 1 r
.21743 .40448 m
.21828 .39539 L
s
.21828 .39539 m
.21752 .40425 L
s
.391 .315 1 r
.69654 .37724 m
.69692 .38529 L
s
.69694 .38525 m
.69654 .37724 L
s
.69654 .37724 m
.69737 .39316 L
s
.68 .237 1 r
.70172 .39356 m
.70218 .40242 L
s
.70222 .40209 m
.70172 .39356 L
s
.589 .259 1 r
.50662 .40436 m
.50656 .40481 L
s
.462 .294 1 r
.8821 .37526 m
.88297 .38371 L
s
.88299 .38367 m
.8821 .37526 L
s
.8821 .37526 m
.88383 .39135 L
s
.503 .282 1 r
.45258 .39088 m
.45239 .39929 L
s
.45246 .39896 m
.45258 .39088 L
s
.777 .214 1 r
.89593 .34139 m
.90107 .38573 L
s
.598 .34139 m
.59917 .38462 L
s
.618 .252 1 r
.30007 .34139 m
.29742 .38388 L
s
.68 .237 1 r
.70218 .40242 m
.70175 .39352 L
s
.70175 .39352 m
.70222 .40209 L
s
.503 .282 1 r
.45239 .39929 m
.4526 .39084 L
s
.4526 .39084 m
.45246 .39896 L
s
.476 .29 1 r
.61374 .39035 m
.61396 .39869 L
s
.614 .39836 m
.61374 .39035 L
s
.359 .325 1 r
.55977 .37683 m
.55983 .38476 L
s
.55985 .38473 m
.55977 .37683 L
s
.55977 .37683 m
.55996 .39256 L
s
.916 .184 1 r
.52143 .41204 m
.52137 .41205 L
s
.476 .29 1 r
.61396 .39869 m
.61376 .39031 L
s
.61376 .39031 m
.614 .39836 L
s
.477 .289 1 r
.69218 .40257 m
.69214 .4029 L
s
.811 .206 1 r
.73139 .40868 m
.73135 .40902 L
s
.835 .201 1 r
.43345 .40868 m
.43337 .4091 L
s
.618 .252 1 r
.72613 .39251 m
.72665 .40122 L
s
.72669 .40089 m
.72613 .39251 L
s
.375 .32 1 r
.50136 .38848 m
.5013 .39652 L
s
.50135 .39619 m
.50136 .38848 L
s
.354 .435 1 r
.8725 .38445 m
.87331 .3923 L
s
.87328 .39149 m
.8725 .38445 L
s
.618 .252 1 r
.72665 .40122 m
.72616 .39247 L
s
.72616 .39247 m
.72669 .40089 L
s
.375 .32 1 r
.5013 .39652 m
.50138 .38844 L
s
.50138 .38844 m
.50135 .39619 L
s
.953 .176 1 r
.76018 .38244 m
.76081 .3919 L
s
.76083 .39186 m
.76018 .38244 L
s
.76018 .38244 m
.7615 .40103 L
s
.354 .435 1 r
.87331 .3923 m
.87253 .38441 L
s
.87253 .38441 m
.87328 .39149 L
s
.569 .264 1 r
.36983 .40413 m
.36976 .4045 L
s
.953 .176 1 r
.75919 .34115 m
.76261 .38659 L
s
.777 .214 1 r
.46122 .34115 m
.46061 .38475 L
s
.743 .222 1 r
.16326 .34115 m
.15867 .38548 L
s
.669 .239 1 r
.61901 .40689 m
.61895 .40708 L
s
.485 .287 1 r
.21302 .37984 m
.21223 .38804 L
s
.21225 .388 m
.21302 .37984 L
s
.21302 .37984 m
.2115 .39643 L
s
.68 .237 1 r
.7802 .40629 m
.78017 .40663 L
s
.638 .247 1 r
.42817 .3928 m
.42791 .40155 L
s
.42798 .40125 m
.42817 .3928 L
s
.569 .264 1 r
.3742 .37927 m
.37379 .3878 L
s
.37381 .38776 m
.3742 .37927 L
s
.3742 .37927 m
.37347 .39619 L
s
.638 .247 1 r
.42791 .40155 m
.42819 .39276 L
s
.42819 .39276 m
.42798 .40125 L
s
.744 .222 1 r
.29663 .40845 m
.29656 .40857 L
s
.744 .221 1 r
.511 .38019 m
.51094 .38921 L
s
.51096 .38917 m
.511 .38019 L
s
.511 .38019 m
.51095 .39789 L
s
.589 .259 1 r
.75057 .39175 m
.75114 .40039 L
s
.75118 .40005 m
.75057 .39175 L
s
.521 .277 1 r
.82901 .4039 m
.82897 .40408 L
s
.799 .209 1 r
.3498 .3809 m
.3493 .39003 L
s
.34932 .38999 m
.3498 .3809 L
s
.3498 .3809 m
.34889 .39886 L
s
.45 .297 1 r
.42299 .37684 m
.42271 .38511 L
s
.42273 .38507 m
.42299 .37684 L
s
.42299 .37684 m
.42252 .39305 L
s
.744 .221 1 r
.62242 .34091 m
.6239 .38414 L
s
.628 .249 1 r
.32441 .34091 m
.32207 .38341 L
s
.589 .259 1 r
.75114 .40039 m
.75059 .39171 L
s
.75059 .39171 m
.75118 .40005 L
s
.845 .199 1 r
.81418 .3966 m
.81496 .40573 L
s
.81502 .40572 m
.81418 .3966 L
s
.4 .312 1 r
.66256 .38854 m
.66289 .39665 L
s
.66293 .39632 m
.66256 .38854 L
s
.881 .191 1 r
.59463 .40882 m
.59458 .40927 L
s
.845 .199 1 r
.81496 .40573 m
.81421 .39656 L
s
.81421 .39656 m
.81502 .40572 L
s
.459 .295 1 r
.26177 .37769 m
.2611 .38593 L
s
.26111 .38589 m
.26177 .37769 L
s
.26177 .37769 m
.26051 .39402 L
s
.4 .312 1 r
.66289 .39665 m
.66259 .3885 L
s
.66259 .3885 m
.66293 .39632 L
s
1 .164 .985 r
.46221 .38324 m
.462 .39278 L
s
.46202 .39274 m
.46221 .38324 L
s
.46221 .38324 m
.46188 .40214 L
s
.904 .186 1 r
.2722 .41038 m
.27212 .41057 L
s
.425 .305 1 r
.14496 .4009 m
.14486 .40123 L
s
.42 .721 1 r
.31575 .39142 m
.31567 .39193 L
s
.811 .206 1 r
.80904 .38063 m
.80978 .38979 L
s
.80981 .38975 m
.80904 .38063 L
s
.80904 .38063 m
.81059 .39863 L
s
.628 .249 1 r
.29133 .39286 m
.29072 .40154 L
s
.29079 .40139 m
.29133 .39286 L
s
.811 .206 1 r
.78366 .34066 m
.78729 .38464 L
s
.744 .222 1 r
.48561 .34066 m
.48532 .3839 L
s
.608 .254 1 r
.18757 .34066 m
.18344 .38353 L
s
.628 .249 1 r
.29072 .40154 m
.29135 .39282 L
s
.29135 .39282 m
.29079 .40139 L
s
.869 .194 1 r
.89269 .40919 m
.89266 .40949 L
s
.383 .565 1 r
.59896 .38427 m
.59912 .39167 L
s
.59916 .39139 m
.59896 .38427 L
s
.777 .214 1 r
.32098 .40799 m
.3209 .40822 L
s
.7 .232 1 r
.26691 .39449 m
.26623 .40329 L
s
.26629 .40332 m
.26691 .39449 L
s
.383 .565 1 r
.59912 .39167 m
.59898 .38423 L
s
.59898 .38423 m
.59916 .39139 L
s
1 .153 .933 r
.78468 .38229 m
.78539 .39202 L
s
.78542 .39197 m
.78468 .38229 L
s
.78468 .38229 m
.78617 .4013 L
s
.7 .232 1 r
.26623 .40329 m
.26693 .39445 L
s
.26693 .39445 m
.26629 .40332 L
s
.34537 .40679 m
.3453 .40698 L
s
.69 .234 1 r
.64685 .34042 m
.64864 .38367 L
s
.916 .184 1 r
.34877 .34042 m
.34661 .38551 L
s
.88 .191 1 r
.45781 .40895 m
.45774 .40929 L
s
.799 .209 1 r
.56499 .39479 m
.56509 .40388 L
s
.56515 .40368 m
.56499 .39479 L
s
.679 .237 1 r
.58939 .39344 m
.58955 .40223 L
s
.5896 .40212 m
.58939 .39344 L
s
.799 .209 1 r
.56509 .40388 m
.56501 .39474 L
s
.56501 .39474 m
.56515 .40368 L
s
.679 .237 1 r
.58955 .40223 m
.58941 .3934 L
s
.58941 .3934 m
.5896 .40212 L
s
.471 .907 1 r
.85785 .37865 m
.85849 .3852 L
s
.8585 .38489 m
.85785 .37865 L
s
.392 .315 1 r
.30612 .40104 m
.30606 .40111 L
s
.471 .907 1 r
.85849 .3852 m
.85787 .37862 L
s
.85787 .37862 m
.8585 .38489 L
s
.811 .206 1 r
.80814 .34018 m
.81212 .38453 L
s
.711 .229 1 r
.51001 .34018 m
.51004 .38306 L
s
.754 .219 1 r
.21189 .34018 m
.20798 .38416 L
s
.8 .209 1 r
.9172 .40871 m
.91715 .4088 L
s
.777 .214 1 r
.18407 .40812 m
.18399 .40824 L
s
.39855 .3797 m
.39818 .38879 L
s
.3982 .38875 m
.39855 .3797 L
s
.39855 .3797 m
.3979 .39755 L
s
.834 .201 1 r
.23727 .38041 m
.23646 .38961 L
s
.23647 .38957 m
.23727 .38041 L
s
.23727 .38041 m
.23575 .39852 L
s
.711 .229 1 r
.91196 .39268 m
.91298 .40162 L
s
.913 .40128 m
.91196 .39268 L
s
.91298 .40162 m
.91199 .39264 L
s
.91199 .39264 m
.913 .40128 L
s
.503 .282 1 r
.52576 .38947 m
.52576 .39788 L
s
.52581 .39755 m
.52576 .38947 L
s
.46 .294 1 r
.6713 .33994 m
.67322 .37914 L
s
.503 .282 1 r
.37313 .33994 m
.3715 .38024 L
s
.52576 .39788 m
.52578 .38943 L
s
.52578 .38943 m
.52581 .39755 L
s
.489 .286 1 r
.79435 .37461 m
.795 .38311 L
s
.79502 .38307 m
.79435 .37461 L
s
.79435 .37461 m
.79567 .3909 L
s
.628 .249 1 r
.39414 .40513 m
.39407 .40528 L
s
.638 .247 1 r
.72111 .37872 m
.72159 .38744 L
s
.72161 .3874 m
.72111 .37872 L
s
.72111 .37872 m
.72214 .39598 L
s
.495 .284 1 r
.44734 .37749 m
.44712 .38581 L
s
.44714 .38577 m
.44734 .37749 L
s
.44734 .37749 m
.44698 .39405 L
s
.711 .229 1 r
.17876 .39245 m
.17783 .40138 L
s
.17793 .40105 m
.17876 .39245 L
s
.618 .252 1 r
.41855 .40393 m
.41848 .40426 L
s
.523 .276 1 r
.55018 .38841 m
.55024 .39697 L
s
.55029 .39635 m
.55018 .38841 L
s
.45 .297 1 r
.84836 .38841 m
.84915 .39668 L
s
.84917 .39635 m
.84836 .38841 L
s
.777 .214 1 r
.66792 .40669 m
.66787 .40703 L
s
.711 .229 1 r
.17783 .40138 m
.17877 .39241 L
s
.17877 .39241 m
.17793 .40105 L
s
.588 .259 1 r
.57985 .40333 m
.5798 .40366 L
s
.45 .297 1 r
.84915 .39668 m
.84839 .38837 L
s
.84839 .38837 m
.84917 .39635 L
s
.523 .276 1 r
.55024 .39697 m
.5502 .38837 L
s
.5502 .38837 m
.55029 .39635 L
s
.744 .222 1 r
.53103 .40609 m
.53097 .40643 L
s
.68 .237 1 r
.63824 .39192 m
.63854 .40078 L
s
.63858 .40045 m
.63824 .39192 L
s
.34005 .39192 m
.33955 .40078 L
s
.33963 .40045 m
.34005 .39192 L
s
.756 .219 1 r
.83263 .3397 m
.8368 .38258 L
s
.476 .29 1 r
.53442 .3397 m
.53474 .37964 L
s
.559 .267 1 r
.23622 .3397 m
.23288 .38074 L
s
.68 .237 1 r
.63854 .40078 m
.63827 .39188 L
s
.63827 .39188 m
.63858 .40045 L
s
.33955 .40078 m
.34006 .39188 L
s
.34006 .39188 m
.33963 .40045 L
s
.357 .451 1 r
.62342 .38467 m
.62364 .39234 L
s
.62368 .39201 m
.62342 .38467 L
s
.513 .279 1 r
.92691 .40093 m
.92691 .40141 L
s
.357 .451 1 r
.62364 .39234 m
.62344 .38463 L
s
.62344 .38463 m
.62368 .39201 L
s
.618 .252 1 r
.28163 .40369 m
.28155 .40403 L
s
.619 .252 1 r
.14911 .37799 m
.14812 .38668 L
s
.14813 .38664 m
.14911 .37799 L
s
.14911 .37799 m
.14722 .39514 L
s
.822 .204 1 r
.15428 .39438 m
.15327 .4035 L
s
.15335 .40335 m
.15428 .39438 L
s
.766 .217 1 r
.77517 .39303 m
.77584 .40208 L
s
.77587 .40178 m
.77517 .39303 L
s
.54 .272 1 r
.22753 .39034 m
.22677 .39879 L
s
.22684 .39865 m
.22753 .39034 L
s
.822 .204 1 r
.15327 .4035 m
.1543 .39433 L
s
.1543 .39433 m
.15335 .40335 L
s
.811 .206 1 r
.69576 .33946 m
.69821 .38308 L
s
.494 .285 1 r
.39752 .33946 m
.39616 .38013 L
s
.766 .217 1 r
.77584 .40208 m
.7752 .39299 L
s
.7752 .39299 m
.77587 .40178 L
s
.441 .3 1 r
.49616 .37546 m
.49607 .38369 L
s
.49609 .38365 m
.49616 .37546 L
s
.49616 .37546 m
.49605 .39164 L
s
.54 .272 1 r
.22677 .39879 m
.22754 .3903 L
s
.22754 .3903 m
.22684 .39865 L
s
.629 .249 1 r
.6871 .38981 m
.68752 .39864 L
s
.68755 .39805 m
.6871 .38981 L
s
.477 .289 1 r
.33044 .4013 m
.33037 .40152 L
s
.359 .325 1 r
.43768 .38712 m
.43747 .39505 L
s
.43752 .39491 m
.43768 .38712 L
s
.756 .219 1 r
.90693 .37761 m
.90793 .38674 L
s
.90796 .3867 m
.90693 .37761 L
s
.90693 .37761 m
.90896 .39528 L
s
.629 .249 1 r
.68752 .39864 m
.68713 .38977 L
s
.68713 .38977 m
.68755 .39805 L
s
.359 .325 1 r
.43747 .39505 m
.4377 .38709 L
s
.4377 .38709 m
.43752 .39491 L
s
.608 .254 1 r
.3104 .37779 m
.30983 .38644 L
s
.30984 .3864 m
.3104 .37779 L
s
.3104 .37779 m
.30934 .39491 L
s
.744 .222 1 r
.74561 .37854 m
.74616 .38756 L
s
.74619 .38751 m
.74561 .37854 L
s
.74561 .37854 m
.74679 .39624 L
s
.579 .262 1 r
.46736 .40226 m
.4673 .40267 L
s
.341 .371 1 r
.85713 .33921 m
.86083 .37439 L
s
.88 .191 1 r
.55885 .33921 m
.55953 .38394 L
s
.638 .247 1 r
.26057 .33921 m
.25744 .38137 L
s
.648 .244 1 r
.74123 .40383 m
.7412 .40416 L
s
.589 .259 1 r
.33481 .37674 m
.33429 .38539 L
s
.33431 .38535 m
.33481 .37674 L
s
.33481 .37674 m
.33387 .3937 L
s
.701 .232 1 r
.60868 .37812 m
.60887 .38703 L
s
.6089 .38699 m
.60868 .37812 L
s
.60868 .37812 m
.60914 .39564 L
s
.28595 .37957 m
.2853 .38838 L
s
.28532 .38834 m
.28595 .37957 L
s
.28595 .37957 m
.28473 .39721 L
s
.609 .254 1 r
.58425 .37958 m
.58437 .38808 L
s
.5844 .38804 m
.58425 .37958 L
s
.58425 .37958 m
.58458 .39685 L
s
.733 .224 1 r
.20303 .39256 m
.20217 .4015 L
s
.20225 .40131 m
.20303 .39256 L
s
.354 .326 1 r
.5746 .38853 m
.57471 .39629 L
s
.57477 .39661 m
.5746 .38853 L
s
.375 .32 1 r
.30071 .38718 m
.30017 .39515 L
s
.30024 .39504 m
.30071 .38718 L
s
.777 .214 1 r
.72023 .33897 m
.72298 .38223 L
s
.56 .267 1 r
.42191 .33897 m
.42086 .37965 L
s
.512 .279 1 r
.12359 .33897 m
.11881 .38039 L
s
.756 .219 1 r
.87821 .40479 m
.8782 .40528 L
s
.733 .224 1 r
.20217 .4015 m
.20305 .39252 L
s
.20305 .39252 m
.20225 .40131 L
s
.354 .326 1 r
.57471 .39629 m
.57462 .38849 L
s
.57462 .38849 m
.57477 .39661 L
s
.375 .32 1 r
.30017 .39515 m
.30073 .38714 L
s
.30073 .38714 m
.30024 .39504 L
s
.467 .292 1 r
.65754 .37576 m
.65783 .38404 L
s
.65785 .384 m
.65754 .37576 L
s
.65754 .37576 m
.6582 .39213 L
s
.37 .509 1 r
.56942 .37244 m
.5695 .37994 L
s
.56951 .3799 m
.56942 .37244 L
s
.56942 .37244 m
.56964 .38729 L
s
.521 .277 1 r
.25185 .39016 m
.25116 .39851 L
s
.25122 .39854 m
.25185 .39016 L
s
.416 .307 1 r
.67758 .39963 m
.67753 .39981 L
s
.521 .277 1 r
.25116 .39851 m
.25186 .39012 L
s
.25186 .39012 m
.25122 .39854 L
s
.68 .237 1 r
.38881 .39098 m
.38844 .39985 L
s
.38852 .39951 m
.38881 .39098 L
s
.4 .312 1 r
.40366 .39843 m
.40359 .39876 L
s
.559 .267 1 r
.88165 .33873 m
.88624 .37978 L
s
.953 .176 1 r
.58329 .33873 m
.58431 .3842 L
s
.522 .277 1 r
.28493 .33873 m
.28221 .37941 L
s
.68 .237 1 r
.38844 .39985 m
.38883 .39094 L
s
.38883 .39094 m
.38852 .39951 L
s
.991 .169 1 r
.47692 .39449 m
.47678 .40407 L
s
.47685 .40361 m
.47692 .39449 L
s
.845 .199 1 r
.79971 .39314 m
.80046 .40239 L
s
.80049 .40205 m
.79971 .39314 L
s
.991 .169 1 r
.47678 .40407 m
.47694 .39445 L
s
.47694 .39445 m
.47685 .40361 L
s
.845 .199 1 r
.80046 .40239 m
.79974 .3931 L
s
.79974 .3931 m
.80049 .40205 L
s
.777 .214 1 r
.47174 .37828 m
.47157 .38738 L
s
.47159 .38733 m
.47174 .37828 L
s
.47174 .37828 m
.47148 .39614 L
s
.531 .274 1 r
.52059 .37559 m
.52055 .38409 L
s
.52057 .38405 m
.52059 .37559 L
s
.52059 .37559 m
.52059 .39226 L
s
.777 .214 1 r
.71687 .40612 m
.71682 .40635 L
s
.335 .34 1 r
.86781 .37291 m
.86859 .38081 L
s
.86862 .38077 m
.86781 .37291 L
s
.86781 .37291 m
.86941 .38839 L
s
.361 .324 1 r
.88786 .39663 m
.88786 .39711 L
s
.618 .252 1 r
.62875 .40276 m
.6287 .40309 L
s
1 .065 .43 r
.86871 .41442 m
.86872 .41517 L
s
.679 .237 1 r
.82416 .39209 m
.82493 .40085 L
s
.82499 .40084 m
.82416 .39209 L
s
.811 .206 1 r
.74471 .33849 m
.74783 .38249 L
s
.744 .221 1 r
.44631 .33849 m
.44552 .38138 L
s
.54 .272 1 r
.14792 .33849 m
.14344 .37991 L
s
.679 .237 1 r
.82493 .40085 m
.82419 .39205 L
s
.82419 .39205 m
.82499 .40084 L
s
.765 .217 1 r
.25706 .40709 m
.257 .40706 L
s
.669 .239 1 r
.16894 .40373 m
.16884 .40402 L
s
.754 .219 1 r
.17332 .37868 m
.17236 .38767 L
s
.17237 .38763 m
.17332 .37868 L
s
.17332 .37868 m
.17149 .39651 L
s
.711 .229 1 r
.19775 .37737 m
.19686 .38632 L
s
.19687 .38628 m
.19775 .37737 L
s
.19775 .37737 m
.19607 .39493 L
s
.777 .214 1 r
.90618 .33825 m
.91142 .38225 L
s
.56 .267 1 r
.60774 .33825 m
.60896 .37893 L
s
.416 .307 1 r
.3093 .33825 m
.30694 .37783 L
s
.743 .222 1 r
.77016 .37904 m
.77078 .38796 L
s
.77081 .38792 m
.77016 .37904 L
s
.77016 .37904 m
.77148 .39687 L
s
.337 .354 1 r
.43244 .37303 m
.4322 .38086 L
s
.43222 .38083 m
.43244 .37303 L
s
.43244 .37303 m
.43204 .38852 L
s
.442 .299 1 r
.84347 .37516 m
.84421 .38333 L
s
.84424 .38329 m
.84347 .37516 L
s
.84347 .37516 m
.84503 .39143 L
s
.468 .292 1 r
.1636 .38811 m
.16271 .39635 L
s
.16277 .39627 m
.1636 .38811 L
s
.66 .241 1 r
.68204 .37586 m
.68243 .38473 L
s
.68245 .38469 m
.68204 .37586 L
s
.68204 .37586 m
.68287 .39312 L
s
.442 .3 1 r
.18804 .38676 m
.1872 .395 L
s
.18729 .3947 m
.18804 .38676 L
s
.468 .292 1 r
.16271 .39635 m
.16362 .38807 L
s
.16362 .38807 m
.16277 .39627 L
s
.442 .3 1 r
.1872 .395 m
.18805 .38673 L
s
.18805 .38673 m
.18729 .3947 L
s
.638 .247 1 r
.27618 .39027 m
.27552 .39899 L
s
.2756 .3988 m
.27618 .39027 L
s
.46 .294 1 r
.64796 .38623 m
.64826 .39458 L
s
.6483 .3941 m
.64796 .38623 L
s
.352 .327 1 r
.76921 .338 m
.77219 .37612 L
s
.833 .201 1 r
.47073 .338 m
.47023 .38274 L
s
.669 .239 1 r
.17226 .338 m
.16793 .3809 L
s
.638 .247 1 r
.27552 .39899 m
.27619 .39023 L
s
.27619 .39023 m
.2756 .3988 L
s
.36 .462 1 r
.9168 .37135 m
.91766 .37899 L
s
.91769 .37895 m
.9168 .37135 L
s
.9168 .37135 m
.91857 .38634 L
s
.46 .294 1 r
.64826 .39458 m
.64798 .38619 L
s
.64798 .38619 m
.6483 .3941 L
s
.845 .199 1 r
.4429 .40602 m
.44282 .40636 L
s
.68 .237 1 r
.65323 .40266 m
.65319 .4031 L
s
.531 .274 1 r
.70649 .37488 m
.70692 .38338 L
s
.70694 .38334 m
.70649 .37488 L
s
.70649 .37488 m
.70741 .39155 L
s
.811 .206 1 r
.60436 .40542 m
.60431 .40576 L
s
.618 .252 1 r
.89759 .38922 m
.89855 .39794 L
s
.89857 .3976 m
.89759 .38922 L
s
.89855 .39794 m
.89762 .38918 L
s
.89762 .38918 m
.89857 .3976 L
s
.578 .262 1 r
.22208 .37705 m
.22129 .38555 L
s
.22131 .38551 m
.22208 .37705 L
s
.22208 .37705 m
.22057 .3941 L
s
.559 .267 1 r
.40799 .3751 m
.40767 .38367 L
s
.40769 .38363 m
.40799 .3751 L
s
.40799 .3751 m
.40743 .39192 L
s
.441 .3 1 r
.6322 .33776 m
.63367 .37735 L
s
.777 .214 1 r
.33369 .33776 m
.33136 .38214 L
s
.754 .219 1 r
.35911 .37797 m
.35864 .38696 L
s
.35866 .38692 m
.35911 .37797 L
s
.35911 .37797 m
.35826 .3958 L
s
.66 .241 1 r
.19321 .40399 m
.19314 .40404 L
s
.68 .237 1 r
.54504 .3762 m
.54506 .38508 L
s
.54508 .38504 m
.54504 .3762 L
s
.54504 .3762 m
.54517 .39362 L
s
.45 .297 1 r
.67243 .38576 m
.67279 .39407 L
s
.67283 .39363 m
.67243 .38576 L
s
.846 .199 1 r
.79372 .33752 m
.79749 .38153 L
s
.744 .222 1 r
.49516 .33752 m
.49499 .38079 L
s
.833 .201 1 r
.19661 .33752 m
.19243 .38226 L
s
.45 .297 1 r
.67279 .39407 m
.67246 .38573 L
s
.67246 .38573 m
.67283 .39363 L
s
.88 .191 1 r
.90294 .40616 m
.90292 .40649 L
s
.834 .201 1 r
.71172 .39197 m
.71223 .40118 L
s
.71227 .40087 m
.71172 .39197 L
s
.559 .267 1 r
.48649 .38793 m
.48639 .3965 L
s
.48645 .39616 m
.48649 .38793 L
s
.788 .212 1 r
.76588 .40556 m
.76583 .40571 L
s
.834 .201 1 r
.71223 .40118 m
.71175 .39193 L
s
.71175 .39193 m
.71227 .40087 L
s
.559 .267 1 r
.48639 .3965 m
.48651 .38789 L
s
.48651 .38789 m
.48645 .39616 L
s
.811 .206 1 r
.79034 .40436 m
.79032 .4048 L
s
.354 .435 1 r
.87328 .39149 m
.87331 .3923 L
s
.777 .214 1 r
.73619 .39091 m
.73675 .40001 L
s
.73679 .39967 m
.73619 .39091 L
s
1 .148 .907 r
.63323 .38004 m
.63351 .38977 L
s
.63354 .38973 m
.63323 .38004 L
s
.63323 .38004 m
.63387 .39921 L
s
.6 .256 1 r
.86369 .40039 m
.86368 .40087 L
s
.916 .184 1 r
.65668 .33728 m
.65869 .38239 L
s
.754 .219 1 r
.35809 .33728 m
.3561 .38129 L
s
.777 .214 1 r
.73675 .40001 m
.73621 .39087 L
s
.73621 .39087 m
.73679 .39967 L
s
.692 .234 1 r
.32497 .38904 m
.32443 .39798 L
s
.32452 .3975 m
.32497 .38904 L
s
.638 .247 1 r
.83926 .40196 m
.83923 .40225 L
s
.598 .257 1 r
.24204 .40196 m
.24197 .40211 L
s
.692 .234 1 r
.32443 .39798 m
.32499 .389 L
s
.32499 .389 m
.32452 .3975 L
s
1 .149 .907 r
.36426 .39525 m
.36378 .40494 L
s
.36386 .40475 m
.36426 .39525 L
s
.916 .184 1 r
.41315 .39255 m
.41283 .40195 L
s
.41291 .40161 m
.41315 .39255 L
s
.744 .222 1 r
.13898 .39121 m
.13794 .40015 L
s
.13802 .40004 m
.13898 .39121 L
s
1 .149 .907 r
.36378 .40494 m
.36428 .3952 L
s
.36428 .3952 m
.36386 .40475 L
s
.916 .184 1 r
.41283 .40195 m
.41317 .39251 L
s
.41317 .39251 m
.41291 .40161 L
s
.649 .244 1 r
.73103 .37495 m
.73154 .38379 L
s
.73156 .38374 m
.73103 .37495 L
s
.73103 .37495 m
.73211 .39218 L
s
.744 .222 1 r
.13794 .40015 m
.13899 .39116 L
s
.13899 .39116 m
.13802 .40004 L
s
.68 .237 1 r
.9222 .38933 m
.92325 .3982 L
s
.92326 .39787 m
.9222 .38933 L
s
.559 .267 1 r
.59394 .37439 m
.59409 .38296 L
s
.59411 .38292 m
.59394 .37439 L
s
.59394 .37439 m
.59431 .39121 L
s
.391 .315 1 r
.69692 .38529 m
.69733 .39334 L
s
.69737 .39316 m
.69692 .38529 L
s
.354 .434 1 r
.85327 .36829 m
.85401 .37616 L
s
.85404 .37612 m
.85327 .36829 L
s
.85327 .36829 m
.85475 .38322 L
s
.869 .194 1 r
.81824 .33703 m
.8224 .38179 L
s
.599 .257 1 r
.51961 .33703 m
.51975 .37774 L
s
.658 .242 1 r
.22098 .33703 m
.21728 .37994 L
s
.68 .237 1 r
.92325 .3982 m
.92223 .38929 L
s
.92223 .38929 m
.92326 .39787 L
s
.391 .315 1 r
.69733 .39334 m
.69694 .38525 L
s
.69694 .38525 m
.69737 .39316 L
s
.375 .32 1 r
.50135 .39619 m
.5013 .39652 L
s
.68 .237 1 r
.54065 .40232 m
.5406 .40266 L
s
.503 .282 1 r
.45246 .39896 m
.45239 .39929 L
s
.468 .292 1 r
.53538 .38611 m
.5354 .39442 L
s
.53546 .39413 m
.53538 .38611 L
s
.754 .219 1 r
.2464 .37726 m
.24563 .38625 L
s
.24565 .38621 m
.2464 .37726 L
s
.2464 .37726 m
.24495 .39509 L
s
.359 .325 1 r
.55983 .38476 m
.5599 .3927 L
s
.55996 .39256 m
.55983 .38476 L
s
.468 .292 1 r
.5354 .39442 m
.5354 .38607 L
s
.5354 .38607 m
.53546 .39413 L
s
.476 .29 1 r
.614 .39836 m
.61396 .39869 L
s
.359 .325 1 r
.5599 .3927 m
.55985 .38473 L
s
.55985 .38473 m
.55996 .39256 L
s
.766 .217 1 r
.35465 .40449 m
.35458 .40468 L
s
.471 .907 1 r
.8585 .38489 m
.85849 .3852 L
s
.744 .221 1 r
.3791 .40329 m
.37902 .40362 L
s
.45 .297 1 r
.48129 .37281 m
.48116 .38108 L
s
.48118 .38105 m
.48129 .37281 L
s
.48129 .37281 m
.4811 .38903 L
s
.462 .294 1 r
.88297 .38371 m
.88387 .39216 L
s
.88383 .39135 m
.88297 .38371 L
s
.789 .211 1 r
.68117 .33679 m
.68342 .38007 L
s
.68 .237 1 r
.3825 .33679 m
.3809 .37933 L
s
.462 .294 1 r
.88387 .39216 m
.88299 .38367 L
s
.88299 .38367 m
.88383 .39135 L
s
.68 .237 1 r
.70222 .40209 m
.70218 .40242 L
s
.892 .189 1 r
.38349 .37837 m
.38307 .38766 L
s
.38309 .38761 m
.38349 .37837 L
s
.38349 .37837 m
.38274 .3968 L
s
.765 .217 1 r
.5162 .40425 m
.51614 .40444 L
s
.777 .214 1 r
.21752 .40425 m
.21743 .40448 L
s
.579 .262 1 r
.45684 .3744 m
.45664 .38302 L
s
.45666 .38298 m
.45684 .3744 L
s
.45684 .3744 m
.45652 .39134 L
s
.618 .252 1 r
.72669 .40089 m
.72665 .40122 L
s
.485 .287 1 r
.21223 .38804 m
.21146 .39624 L
s
.2115 .39643 m
.21223 .38804 L
s
.383 .565 1 r
.59916 .39139 m
.59912 .39167 L
s
.904 .186 1 r
.81929 .37922 m
.82007 .38848 L
s
.8201 .38843 m
.81929 .37922 L
s
.81929 .37922 m
.82094 .39777 L
s
.485 .287 1 r
.21146 .39624 m
.21225 .388 L
s
.21225 .388 m
.2115 .39643 L
s
.4 .312 1 r
.66293 .39632 m
.66289 .39665 L
s
.789 .211 1 r
.84277 .33655 m
.84709 .37946 L
s
.822 .204 1 r
.54406 .33655 m
.54454 .38057 L
s
.579 .262 1 r
.24535 .33655 m
.24209 .37799 L
s
.752 1 .697 r
.52491 .35431 m
.5249 .3587 L
s
.52491 .35868 m
.52491 .35431 L
s
.52491 .35431 m
.52492 .36267 L
s
.638 .247 1 r
.42798 .40125 m
.42791 .40155 L
s
.569 .264 1 r
.37379 .3878 m
.3734 .39634 L
s
.37347 .39619 m
.37379 .3878 L
s
.45 .297 1 r
.42271 .38511 m
.42245 .39338 L
s
.42252 .39305 m
.42271 .38511 L
s
.569 .264 1 r
.3734 .39634 m
.37381 .38776 L
s
.37381 .38776 m
.37347 .39619 L
s
.589 .259 1 r
.75118 .40005 m
.75114 .40039 L
s
.45 .297 1 r
.42245 .39338 m
.42273 .38507 L
s
.42273 .38507 m
.42252 .39305 L
s
.459 .295 1 r
.2611 .38593 m
.26044 .39417 L
s
.26051 .39402 m
.2611 .38593 L
s
.648 .244 1 r
.70567 .33631 m
.70817 .37849 L
s
.375 .529 1 r
.40692 .33631 m
.40587 .37114 L
s
.459 .295 1 r
.26044 .39417 m
.26111 .38589 L
s
.26111 .38589 m
.26051 .39402 L
s
.679 .237 1 r
.13361 .37647 m
.13257 .38524 L
s
.13258 .3852 m
.13361 .37647 L
s
.13361 .37647 m
.1316 .39401 L
s
.69 .234 1 r
.29522 .37587 m
.29459 .38472 L
s
.2946 .38468 m
.29522 .37587 L
s
.29522 .37587 m
.29404 .39341 L
s
.495 .284 1 r
.50574 .37247 m
.50567 .3809 L
s
.50569 .38086 m
.50574 .37247 L
s
.50574 .37247 m
.50567 .38892 L
s
.337 .354 1 r
.53019 .37113 m
.53018 .37897 L
s
.5302 .37893 m
.53019 .37113 L
s
.53019 .37113 m
.53024 .38662 L
s
.34 .366 1 r
.23143 .37117 m
.23072 .37897 L
s
.23074 .37893 m
.23143 .37117 L
s
.23143 .37117 m
.2301 .38662 L
s
.711 .229 1 r
.86732 .33606 m
.87195 .37898 L
s
1 .151 .921 r
.56853 .33606 m
.56939 .38341 L
s
.608 .254 1 r
.26975 .33606 m
.26667 .37898 L
s
.953 .176 1 r
.76081 .3919 m
.76146 .40138 L
s
.7615 .40103 m
.76081 .3919 L
s
.744 .221 1 r
.51094 .38921 m
.51089 .39823 L
s
.51095 .39789 m
.51094 .38921 L
s
.628 .249 1 r
.29079 .40139 m
.29072 .40154 L
s
.892 .189 1 r
.27073 .37765 m
.27 .38695 L
s
.27002 .3869 m
.27073 .37765 L
s
.27073 .37765 m
.26936 .39609 L
s
.953 .176 1 r
.76146 .40138 m
.76083 .39186 L
s
.76083 .39186 m
.7615 .40103 L
s
.845 .199 1 r
.8928 .37634 m
.89377 .38559 L
s
.8938 .38555 m
.8928 .37634 L
s
.8928 .37634 m
.89481 .39451 L
s
.744 .221 1 r
.51089 .39823 m
.51096 .38917 L
s
.51096 .38917 m
.51095 .39789 L
s
.799 .209 1 r
.3493 .39003 m
.34881 .39916 L
s
.34889 .39886 m
.3493 .39003 L
s
.34881 .39916 m
.34932 .38999 L
s
.34932 .38999 m
.34889 .39886 L
s
.845 .199 1 r
.81502 .40572 m
.81496 .40573 L
s
.733 .224 1 r
.61846 .37525 m
.61868 .38424 L
s
.6187 .3842 m
.61846 .37525 L
s
.61846 .37525 m
.61898 .39294 L
s
.345 .39 1 r
.73019 .33582 m
.73268 .37323 L
s
.991 .169 1 r
.43136 .33582 m
.43031 .38132 L
s
.54 .272 1 r
.13253 .33582 m
.12786 .37727 L
s
.7 .232 1 r
.26629 .40332 m
.26623 .40329 L
s
.811 .206 1 r
.80978 .38979 m
.81055 .39897 L
s
.81059 .39863 m
.80978 .38979 L
s
.81055 .39897 m
.80981 .38975 L
s
.80981 .38975 m
.81059 .39863 L
s
.799 .209 1 r
.15796 .37625 m
.15694 .38536 L
s
.15695 .38531 m
.15796 .37625 L
s
.15796 .37625 m
.15602 .39428 L
s
.477 .289 1 r
.69187 .37151 m
.69226 .3799 L
s
.69228 .37986 m
.69187 .37151 L
s
.69187 .37151 m
.6927 .38785 L
s
.722 .227 1 r
.31961 .37562 m
.31904 .38454 L
s
.31906 .38449 m
.31961 .37562 L
s
.31961 .37562 m
.31856 .39331 L
s
.679 .237 1 r
.5896 .40212 m
.58955 .40223 L
s
.569 .264 1 r
.89188 .33558 m
.89669 .3774 L
s
.433 .302 1 r
.59302 .33558 m
.59402 .37482 L
s
.679 .237 1 r
.29415 .33558 m
.29136 .37887 L
s
.342 .378 1 r
.878 .3696 m
.8788 .37743 L
s
.87882 .37739 m
.878 .3696 L
s
.878 .3696 m
.87964 .38494 L
s
.357 .451 1 r
.62368 .39201 m
.62364 .39234 L
s
1 .164 .985 r
.462 .39278 m
.46181 .40233 L
s
.46188 .40214 m
.462 .39278 L
s
.503 .282 1 r
.52581 .39755 m
.52576 .39788 L
s
1 .164 .985 r
.46181 .40233 m
.46202 .39274 L
s
.46202 .39274 m
.46188 .40214 L
s
.799 .209 1 r
.56515 .40368 m
.56509 .40388 L
s
.618 .252 1 r
.64294 .37453 m
.64322 .38318 L
s
.64324 .38314 m
.64294 .37453 L
s
.64294 .37453 m
.64357 .39173 L
s
.711 .229 1 r
.34407 .37452 m
.34356 .38348 L
s
.34358 .38343 m
.34407 .37452 L
s
.34407 .37452 m
.34315 .3921 L
s
.45 .297 1 r
.84917 .39635 m
.84915 .39668 L
s
.523 .276 1 r
.55029 .39635 m
.55024 .39697 L
s
.733 .224 1 r
.18238 .37534 m
.18144 .3843 L
s
.18146 .38426 m
.18238 .37534 L
s
.18238 .37534 m
.1806 .39307 L
s
.45 .297 1 r
.55468 .37138 m
.55473 .37966 L
s
.55475 .37962 m
.55468 .37138 L
s
.55468 .37138 m
.55485 .38761 L
s
.917 .184 1 r
.75472 .33533 m
.75803 .38011 L
s
.618 .252 1 r
.45581 .33533 m
.45515 .37716 L
s
.1569 .33533 m
.1525 .37716 L
s
.711 .229 1 r
.913 .40128 m
.91298 .40162 L
s
.495 .284 1 r
.44712 .38581 m
.44692 .39412 L
s
.44698 .39405 m
.44712 .38581 L
s
.489 .286 1 r
.795 .38311 m
.79567 .39161 L
s
.79567 .3909 m
.795 .38311 L
s
.495 .284 1 r
.44692 .39412 m
.44714 .38577 L
s
.44714 .38577 m
.44698 .39405 L
s
.648 .244 1 r
.66744 .37361 m
.66778 .38242 L
s
.66781 .38238 m
.66744 .37361 L
s
.66744 .37361 m
.66819 .39089 L
s
1 .153 .933 r
.78539 .39202 m
.78614 .40175 L
s
.78617 .4013 m
.78539 .39202 L
s
.489 .286 1 r
.79567 .39161 m
.79502 .38307 L
s
.79502 .38307 m
.79567 .3909 L
s
.68 .237 1 r
.80467 .3744 m
.80537 .38324 L
s
.8054 .3832 m
.80467 .3744 L
s
.80467 .3744 m
.80614 .39186 L
s
1 .153 .933 r
.78614 .40175 m
.78542 .39197 L
s
.78542 .39197 m
.78617 .4013 L
s
.701 .231 1 r
.36851 .37375 m
.36807 .38271 L
s
.36809 .38267 m
.36851 .37375 L
s
.36851 .37375 m
.36773 .39126 L
s
.788 .212 1 r
.7802 .37581 m
.78086 .38488 L
s
.78089 .38484 m
.7802 .37581 L
s
.7802 .37581 m
.78159 .3938 L
s
.777 .214 1 r
.39818 .38879 m
.39783 .39789 L
s
.3979 .39755 m
.39818 .38879 L
s
.638 .247 1 r
.72159 .38744 m
.72209 .39617 L
s
.72214 .39598 m
.72159 .38744 L
s
.359 .325 1 r
.43752 .39491 m
.43747 .39505 L
s
.569 .264 1 r
.61751 .33509 m
.61888 .37692 L
s
.588 .259 1 r
.31857 .33509 m
.31616 .37729 L
s
.711 .229 1 r
.17793 .40105 m
.17783 .40138 L
s
.777 .214 1 r
.39783 .39789 m
.3982 .38875 L
s
.3982 .38875 m
.3979 .39755 L
s
.357 .451 1 r
.16745 .36845 m
.16661 .37613 L
s
.16662 .3761 m
.16745 .36845 L
s
.16745 .36845 m
.16587 .38349 L
s
.638 .247 1 r
.72209 .39617 m
.72161 .3874 L
s
.72161 .3874 m
.72214 .39598 L
s
.834 .201 1 r
.23646 .38961 m
.23566 .39883 L
s
.23575 .39852 m
.23646 .38961 L
s
.68 .237 1 r
.63858 .40045 m
.63854 .40078 L
s
.33963 .40045 m
.33955 .40078 L
s
.834 .201 1 r
.23566 .39883 m
.23647 .38957 L
s
.23647 .38957 m
.23575 .39852 L
s
.441 .3 1 r
.49607 .38369 m
.49599 .39193 L
s
.49605 .39164 m
.49607 .38369 L
s
.54 .272 1 r
.22684 .39865 m
.22677 .39879 L
s
.441 .3 1 r
.49599 .39193 m
.49609 .38365 L
s
.49609 .38365 m
.49605 .39164 L
s
.629 .249 1 r
.68755 .39805 m
.68752 .39864 L
s
.68 .237 1 r
.77926 .33485 m
.78272 .37741 L
s
.403 .652 1 r
.48027 .33485 m
.47999 .36933 L
s
.658 .242 1 r
.18129 .33485 m
.17707 .37778 L
s
.619 .252 1 r
.14812 .38668 m
.14713 .39537 L
s
.14722 .39514 m
.14812 .38668 L
s
.754 .219 1 r
.20675 .37512 m
.20587 .38412 L
s
.20588 .38407 m
.20675 .37512 L
s
.20675 .37512 m
.20508 .39296 L
s
.37 .509 1 r
.5695 .37994 m
.56959 .38743 L
s
.56964 .38729 m
.5695 .37994 L
s
.619 .252 1 r
.14713 .39537 m
.14813 .38664 L
s
.14813 .38664 m
.14722 .39514 L
s
.37 .509 1 r
.56959 .38743 m
.56951 .3799 L
s
.56951 .3799 m
.56964 .38729 L
s
.354 .326 1 r
.57477 .39661 m
.57471 .39629 L
s
.766 .217 1 r
.77587 .40178 m
.77584 .40208 L
s
.425 .305 1 r
.90267 .36988 m
.90356 .37812 L
s
.90359 .37809 m
.90267 .36988 L
s
.90267 .36988 m
.90449 .38593 L
s
.375 .32 1 r
.30024 .39504 m
.30017 .39515 L
s
.54 .272 1 r
.25568 .37265 m
.25497 .38112 L
s
.25499 .38108 m
.25568 .37265 L
s
.25568 .37265 m
.25436 .38945 L
s
.383 .317 1 r
.14288 .37063 m
.14195 .37865 L
s
.14196 .37862 m
.14288 .37063 L
s
.14288 .37063 m
.1411 .38653 L
s
.648 .244 1 r
.64202 .33461 m
.64372 .3768 L
s
.343 .33461 m
.34091 .3768 L
s
.822 .204 1 r
.15335 .40335 m
.15327 .4035 L
s
.618 .252 1 r
.71646 .37212 m
.71693 .38088 L
s
.71695 .38084 m
.71646 .37212 L
s
.71646 .37212 m
.71746 .38921 L
s
.608 .254 1 r
.30983 .38644 m
.30926 .39509 L
s
.30934 .39491 m
.30983 .38644 L
s
1 .123 .772 r
.75582 .37828 m
.75647 .38829 L
s
.7565 .38824 m
.75582 .37828 L
s
.75582 .37828 m
.7572 .39796 L
s
.777 .214 1 r
.82926 .37424 m
.83005 .38335 L
s
.83008 .38331 m
.82926 .37424 L
s
.82926 .37424 m
.8309 .39212 L
s
.608 .254 1 r
.30926 .39509 m
.30984 .3864 L
s
.30984 .3864 m
.30934 .39491 L
s
.609 .254 1 r
.58437 .38808 m
.58452 .39659 L
s
.58458 .39685 m
.58437 .38808 L
s
.756 .219 1 r
.90793 .38674 m
.90897 .39587 L
s
.90896 .39528 m
.90793 .38674 L
s
.589 .259 1 r
.33429 .38539 m
.33379 .39404 L
s
.33387 .3937 m
.33429 .38539 L
s
.467 .292 1 r
.65783 .38404 m
.65815 .39232 L
s
.6582 .39213 m
.65783 .38404 L
s
.777 .214 1 r
.80381 .33436 m
.80766 .37767 L
s
.701 .232 1 r
.50475 .33436 m
.5047 .37767 L
s
.658 .242 1 r
.20569 .33436 m
.20178 .3773 L
s
.609 .254 1 r
.58452 .39659 m
.5844 .38804 L
s
.5844 .38804 m
.58458 .39685 L
s
.756 .219 1 r
.90897 .39587 m
.90796 .3867 L
s
.90796 .3867 m
.90896 .39528 L
s
.589 .259 1 r
.33379 .39404 m
.33431 .38535 L
s
.33431 .38535 m
.33387 .3937 L
s
.467 .292 1 r
.65815 .39232 m
.65785 .384 L
s
.65785 .384 m
.6582 .39213 L
s
.744 .222 1 r
.74616 .38756 m
.74675 .39658 L
s
.74679 .39624 m
.74616 .38756 L
s
.335 .34 1 r
.86859 .38081 m
.8694 .38871 L
s
.86941 .38839 m
.86859 .38081 L
s
.744 .222 1 r
.74675 .39658 m
.74619 .38751 L
s
.74619 .38751 m
.74679 .39624 L
s
.335 .34 1 r
.8694 .38871 m
.86862 .38077 L
s
.86862 .38077 m
.86941 .38839 L
s
.701 .232 1 r
.2853 .38838 m
.28466 .39718 L
s
.28473 .39721 m
.2853 .38838 L
s
.60887 .38703 m
.60909 .39594 L
s
.60914 .39564 m
.60887 .38703 L
s
.521 .277 1 r
.25122 .39854 m
.25116 .39851 L
s
.504 .282 1 r
.74098 .37142 m
.74148 .37982 L
s
.74151 .37979 m
.74098 .37142 L
s
.74098 .37142 m
.74206 .388 L
s
.733 .224 1 r
.20225 .40131 m
.20217 .4015 L
s
.701 .232 1 r
.28466 .39718 m
.28532 .38834 L
s
.28532 .38834 m
.28473 .39721 L
s
.60909 .39594 m
.6089 .38699 L
s
.6089 .38699 m
.60914 .39564 L
s
.733 .224 1 r
.39292 .37415 m
.39254 .38311 L
s
.39256 .38307 m
.39292 .37415 L
s
.39292 .37415 m
.39225 .39188 L
s
.608 .254 1 r
.5792 .37224 m
.57931 .38094 L
s
.57933 .3809 m
.5792 .37224 L
s
.5792 .37224 m
.5795 .38934 L
s
.61 .254 1 r
.66654 .33412 m
.66849 .37485 L
s
.416 .307 1 r
.36744 .33412 m
.36576 .37374 L
s
.752 1 .697 r
.5249 .3587 m
.52489 .36307 L
s
.52492 .36267 m
.5249 .3587 L
s
.68 .237 1 r
.38852 .39951 m
.38844 .39985 L
s
.752 1 .697 r
.52489 .36307 m
.52491 .35868 L
s
.52491 .35868 m
.52492 .36267 L
s
.531 .274 1 r
.52055 .38409 m
.52053 .39259 L
s
.52059 .39226 m
.52055 .38409 L
s
.52053 .39259 m
.52057 .38405 L
s
.52057 .38405 m
.52059 .39226 L
s
.337 .354 1 r
.4322 .38086 m
.43198 .38869 L
s
.43204 .38852 m
.4322 .38086 L
s
.67 .239 1 r
.82838 .33388 m
.83244 .37608 L
s
.423 .732 1 r
.52924 .33388 m
.52945 .36653 L
s
.788 .212 1 r
.2301 .33388 m
.22638 .37829 L
s
.337 .354 1 r
.43198 .38869 m
.43222 .38083 L
s
.43222 .38083 m
.43204 .38852 L
s
.845 .199 1 r
.80049 .40205 m
.80046 .40239 L
s
.367 .322 1 r
.1917 .36942 m
.19089 .37741 L
s
.1909 .37737 m
.1917 .36942 L
s
.1917 .36942 m
.19015 .38521 L
s
.36 .462 1 r
.91766 .37899 m
.91856 .38663 L
s
.91857 .38634 m
.91766 .37899 L
s
.91856 .38663 m
.91769 .37895 L
s
.91769 .37895 m
.91857 .38634 L
s
.442 .3 1 r
.18729 .3947 m
.1872 .395 L
s
.679 .237 1 r
.82499 .40084 m
.82493 .40085 L
s
.991 .169 1 r
.47685 .40361 m
.47678 .40407 L
s
.46 .294 1 r
.6483 .3941 m
.64826 .39458 L
s
.777 .214 1 r
.47157 .38738 m
.47141 .39648 L
s
.47148 .39614 m
.47157 .38738 L
s
.442 .299 1 r
.84421 .38333 m
.84499 .3915 L
s
.84503 .39143 m
.84421 .38333 L
s
.744 .221 1 r
.69108 .33363 m
.69344 .37658 L
s
.68 .237 1 r
.3919 .33363 m
.39043 .37584 L
s
.777 .214 1 r
.47141 .39648 m
.47159 .38733 L
s
.47159 .38733 m
.47148 .39614 L
s
.468 .292 1 r
.16277 .39627 m
.16271 .39635 L
s
.442 .299 1 r
.84499 .3915 m
.84424 .38329 L
s
.84424 .38329 m
.84503 .39143 L
s
.57 .264 1 r
.32902 .37045 m
.32849 .37911 L
s
.32851 .37907 m
.32902 .37045 L
s
.32902 .37045 m
.32807 .38728 L
s
.494 .284 1 r
.30451 .37188 m
.30394 .38017 L
s
.30396 .38013 m
.30451 .37188 L
s
.30451 .37188 m
.30345 .3885 L
s
.754 .219 1 r
.17236 .38767 m
.17141 .39666 L
s
.17149 .39651 m
.17236 .38767 L
s
.711 .229 1 r
.19686 .38632 m
.19597 .39527 L
s
.19607 .39493 m
.19686 .38632 L
s
.917 .184 1 r
.41738 .37407 m
.41705 .38352 L
s
.41707 .38347 m
.41738 .37407 L
s
.41738 .37407 m
.41682 .39251 L
s
.754 .219 1 r
.17141 .39666 m
.17237 .38763 L
s
.17237 .38763 m
.17149 .39651 L
s
.711 .229 1 r
.19597 .39527 m
.19687 .38628 L
s
.19687 .38628 m
.19607 .39493 L
s
.811 .206 1 r
.28001 .37351 m
.27932 .38269 L
s
.27934 .38265 m
.28001 .37351 L
s
.28001 .37351 m
.27873 .39154 L
s
.699 .232 1 r
.85296 .33339 m
.85719 .37412 L
s
.433 .302 1 r
.55374 .33339 m
.55428 .37266 L
s
.68 .237 1 r
.25452 .33339 m
.25128 .37597 L
s
.743 .222 1 r
.77078 .38796 m
.77143 .39688 L
s
.77148 .39687 m
.77078 .38796 L
s
.638 .247 1 r
.2756 .3988 m
.27552 .39899 L
s
.743 .222 1 r
.77143 .39688 m
.77081 .38792 L
s
.77081 .38792 m
.77148 .39687 L
s
.618 .252 1 r
.89857 .3976 m
.89855 .39794 L
s
.66 .241 1 r
.68243 .38473 m
.68284 .39361 L
s
.68287 .39312 m
.68243 .38473 L
s
.531 .274 1 r
.70692 .38338 m
.70738 .39189 L
s
.70741 .39155 m
.70692 .38338 L
s
.66 .241 1 r
.68284 .39361 m
.68245 .38469 L
s
.68245 .38469 m
.68287 .39312 L
s
.531 .274 1 r
.70738 .39189 m
.70694 .38334 L
s
.70694 .38334 m
.70741 .39155 L
s
.45 .297 1 r
.67283 .39363 m
.67279 .39407 L
s
.578 .262 1 r
.22129 .38555 m
.22051 .39406 L
s
.22057 .3941 m
.22129 .38555 L
s
.953 .176 1 r
.71562 .33315 m
.71846 .37868 L
s
.588 .259 1 r
.41636 .33315 m
.41522 .37462 L
s
.589 .259 1 r
.1171 .33314 m
.11224 .37462 L
s
.578 .262 1 r
.22051 .39406 m
.22131 .38551 L
s
.22131 .38551 m
.22057 .3941 L
s
.559 .267 1 r
.40767 .38367 m
.40736 .39225 L
s
.40743 .39192 m
.40767 .38367 L
s
.40736 .39225 m
.40769 .38363 L
s
.40769 .38363 m
.40743 .39192 L
s
.723 .226 1 r
.79015 .37097 m
.79083 .38004 L
s
.79086 .38 m
.79015 .37097 L
s
.79015 .37097 m
.79156 .38852 L
s
.559 .267 1 r
.48645 .39616 m
.48639 .3965 L
s
.503 .282 1 r
.51535 .36966 m
.5153 .3781 L
s
.51532 .37806 m
.51535 .36966 L
s
.51535 .36966 m
.51533 .38621 L
s
.669 .239 1 r
.62825 .37172 m
.62849 .38057 L
s
.62851 .38053 m
.62825 .37172 L
s
.62825 .37172 m
.62881 .38912 L
s
.833 .201 1 r
.87755 .3329 m
.88259 .37844 L
s
.799 .209 1 r
.57825 .3329 m
.57918 .37733 L
s
.27895 .3329 m
.27584 .37807 L
s
.754 .219 1 r
.35864 .38696 m
.35819 .39595 L
s
.35826 .3958 m
.35864 .38696 L
s
.35819 .39595 m
.35866 .38692 L
s
.35866 .38692 m
.35826 .3958 L
s
.354 .434 1 r
.85401 .37616 m
.85478 .38402 L
s
.85475 .38322 m
.85401 .37616 L
s
.391 .315 1 r
.69737 .39316 m
.69733 .39334 L
s
.68 .237 1 r
.54506 .38508 m
.54511 .39396 L
s
.54517 .39362 m
.54506 .38508 L
s
.354 .434 1 r
.85478 .38402 m
.85404 .37612 L
s
.85404 .37612 m
.85475 .38322 L
s
.68 .237 1 r
.49085 .37145 m
.49073 .38033 L
s
.49075 .38029 m
.49085 .37145 L
s
.49085 .37145 m
.4907 .38889 L
s
.359 .325 1 r
.55996 .39256 m
.5599 .3927 L
s
.799 .209 1 r
.74018 .33266 m
.74325 .37672 L
s
.638 .247 1 r
.44084 .33266 m
.43999 .37488 L
s
.628 .249 1 r
.14151 .33266 m
.13681 .37525 L
s
.68 .237 1 r
.54511 .39396 m
.54508 .38504 L
s
.54508 .38504 m
.54517 .39362 L
s
.834 .201 1 r
.71227 .40087 m
.71223 .40118 L
s
.462 .294 1 r
.88383 .39135 m
.88387 .39216 L
s
.845 .199 1 r
.7657 .37301 m
.76633 .38227 L
s
.76635 .38223 m
.7657 .37301 L
s
.7657 .37301 m
.76702 .3912 L
s
.692 .234 1 r
.32452 .3975 m
.32443 .39798 L
s
.468 .292 1 r
.53546 .39413 m
.5354 .39442 L
s
.777 .214 1 r
.73679 .39967 m
.73675 .40001 L
s
.799 .209 1 r
.46634 .37316 m
.46615 .38227 L
s
.46617 .38223 m
.46634 .37316 L
s
.46634 .37316 m
.46605 .3912 L
s
.441 .3 1 r
.53986 .36912 m
.53987 .37733 L
s
.53989 .37729 m
.53986 .36912 L
s
.53986 .36912 m
.53995 .38536 L
s
.68 .237 1 r
.35342 .37121 m
.35294 .38009 L
s
.35295 .38005 m
.35342 .37121 L
s
.35342 .37121 m
.35255 .38865 L
s
.701 .232 1 r
.90216 .33241 m
.90728 .37574 L
s
.711 .229 1 r
.60278 .33241 m
.604 .37537 L
s
.476 .29 1 r
.3034 .33241 m
.30089 .37316 L
s
1 .146 .894 r
.44184 .37469 m
.44157 .3845 L
s
.44159 .38446 m
.44184 .37469 L
s
.44184 .37469 m
.44139 .39388 L
s
.68 .237 1 r
.92326 .39787 m
.92325 .3982 L
s
.559 .267 1 r
.59409 .38296 m
.59426 .39154 L
s
.59431 .39121 m
.59409 .38296 L
s
.59426 .39154 m
.59411 .38292 L
s
.59411 .38292 m
.59431 .39121 L
s
.744 .222 1 r
.13802 .40004 m
.13794 .40015 L
s
.375 .32 1 r
.42693 .36738 m
.42667 .37545 L
s
.42669 .37541 m
.42693 .36738 L
s
.42693 .36738 m
.42649 .38318 L
s
.649 .244 1 r
.73154 .38379 m
.73207 .39263 L
s
.73211 .39218 m
.73154 .38379 L
s
.45 .297 1 r
.48116 .38108 m
.48104 .38936 L
s
.4811 .38903 m
.48116 .38108 L
s
.649 .244 1 r
.73207 .39263 m
.73156 .38374 L
s
.73156 .38374 m
.73211 .39218 L
s
.45 .297 1 r
.48104 .38936 m
.48118 .38105 L
s
.48118 .38105 m
.4811 .38903 L
s
1 .161 .972 r
.60379 .37434 m
.60398 .38397 L
s
.60401 .38393 m
.60379 .37434 L
s
.60379 .37434 m
.60426 .39327 L
s
.916 .184 1 r
.41291 .40161 m
.41283 .40195 L
s
.503 .282 1 r
.70183 .36895 m
.70224 .37739 L
s
.70227 .37735 m
.70183 .36895 L
s
.70183 .36895 m
.70272 .38549 L
s
.531 .274 1 r
.76475 .33217 m
.7679 .37292 L
s
.46534 .33217 m
.46482 .37292 L
s
.766 .217 1 r
.16592 .33217 m
.16143 .37587 L
s
.485 .287 1 r
.2115 .39643 m
.21146 .39624 L
s
.495 .284 1 r
.26495 .36842 m
.26428 .37685 L
s
.26429 .37681 m
.26495 .36842 L
s
.26495 .36842 m
.2637 .38489 L
s
.777 .214 1 r
.65282 .37186 m
.65313 .38097 L
s
.65316 .38093 m
.65282 .37186 L
s
.65282 .37186 m
.65352 .38975 L
s
.754 .219 1 r
.24563 .38625 m
.24488 .39525 L
s
.24495 .39509 m
.24563 .38625 L
s
.45 .297 1 r
.42252 .39305 m
.42245 .39338 L
s
.754 .219 1 r
.24488 .39525 m
.24565 .38621 L
s
.24565 .38621 m
.24495 .39509 L
s
1 .148 .907 r
.63351 .38977 m
.63382 .39952 L
s
.63387 .39921 m
.63351 .38977 L
s
1 .149 .907 r
.36386 .40475 m
.36378 .40494 L
s
.579 .262 1 r
.45664 .38302 m
.45645 .39164 L
s
.45652 .39134 m
.45664 .38302 L
s
.618 .252 1 r
.83932 .37006 m
.84011 .37879 L
s
.84014 .37875 m
.83932 .37006 L
s
.83932 .37006 m
.84095 .3872 L
s
1 .148 .907 r
.63382 .39952 m
.63354 .38973 L
s
.63354 .38973 m
.63387 .39921 L
s
.34 .366 1 r
.23072 .37897 m
.23003 .38676 L
s
.2301 .38662 m
.23072 .37897 L
s
.337 .354 1 r
.53018 .37897 m
.53019 .3868 L
s
.53024 .38662 m
.53018 .37897 L
s
.352 .327 1 r
.62732 .33193 m
.62869 .3701 L
s
.7 .232 1 r
.32786 .33193 m
.32551 .37526 L
s
.579 .262 1 r
.45645 .39164 m
.45666 .38298 L
s
.45666 .38298 m
.45652 .39134 L
s
.34 .366 1 r
.23003 .38676 m
.23074 .37893 L
s
.23074 .37893 m
.2301 .38662 L
s
.337 .354 1 r
.53019 .3868 m
.5302 .37893 L
s
.5302 .37893 m
.53024 .38662 L
s
.752 1 .697 r
.52492 .36267 m
.52489 .36307 L
s
.459 .295 1 r
.26051 .39402 m
.26044 .39417 L
s
.823 .204 1 r
.67736 .37091 m
.67775 .3802 L
s
.67777 .38016 m
.67736 .37091 L
s
.67736 .37091 m
.6782 .38891 L
s
.569 .264 1 r
.37347 .39619 m
.3734 .39634 L
s
.733 .224 1 r
.21587 .37177 m
.21503 .38073 L
s
.21504 .38069 m
.21587 .37177 L
s
.21587 .37177 m
.21427 .38951 L
s
.669 .239 1 r
.78934 .33168 m
.79294 .37428 L
s
.45 .297 1 r
.48985 .33168 m
.48963 .37133 L
s
.722 .227 1 r
.19035 .33168 m
.18617 .37539 L
s
.892 .189 1 r
.38307 .38766 m
.38267 .39695 L
s
.38274 .3968 m
.38307 .38766 L
s
.495 .284 1 r
.50567 .3809 m
.50561 .38933 L
s
.50567 .38892 m
.50567 .3809 L
s
.892 .189 1 r
.38267 .39695 m
.38309 .38761 L
s
.38309 .38761 m
.38274 .3968 L
s
.904 .186 1 r
.82007 .38848 m
.82087 .39774 L
s
.82094 .39777 m
.82007 .38848 L
s
.495 .284 1 r
.50561 .38933 m
.50569 .38086 L
s
.50569 .38086 m
.50567 .38892 L
s
.904 .186 1 r
.82087 .39774 m
.8201 .38843 L
s
.8201 .38843 m
.82094 .39777 L
s
.679 .237 1 r
.13257 .38524 m
.13153 .39402 L
s
.1316 .39401 m
.13257 .38524 L
s
.869 .194 1 r
.81489 .37231 m
.81566 .38161 L
s
.81569 .38157 m
.81489 .37231 L
s
.81489 .37231 m
.8165 .39062 L
s
.8 .209 1 r
.37786 .37164 m
.37743 .38079 L
s
.37745 .38075 m
.37786 .37164 L
s
.37786 .37164 m
.37709 .38965 L
s
.55 .269 1 r
.65187 .33144 m
.65365 .37257 L
s
.35234 .33144 m
.35035 .37367 L
s
.679 .237 1 r
.13153 .39402 m
.13258 .3852 L
s
.13258 .3852 m
.1316 .39401 L
s
.69 .234 1 r
.29459 .38472 m
.29397 .39356 L
s
.29404 .39341 m
.29459 .38472 L
s
.29397 .39356 m
.2946 .38468 L
s
.2946 .38468 m
.29404 .39341 L
s
.531 .274 1 r
.58893 .36845 m
.58906 .37696 L
s
.58908 .37692 m
.58893 .36845 L
s
.58893 .36845 m
.58927 .38515 L
s
.342 .378 1 r
.8788 .37743 m
.87962 .38526 L
s
.87964 .38494 m
.8788 .37743 L
s
.87962 .38526 m
.87882 .37739 L
s
.87882 .37739 m
.87964 .38494 L
s
.744 .221 1 r
.51095 .39789 m
.51089 .39823 L
s
.845 .199 1 r
.81394 .3312 m
.81802 .37564 L
s
.467 .292 1 r
.51437 .3312 m
.51444 .37122 L
s
.754 .219 1 r
.21479 .33119 m
.2109 .37527 L
s
.777 .214 1 r
.40236 .37091 m
.402 .38002 L
s
.40202 .37998 m
.40236 .37091 L
s
.40236 .37091 m
.40173 .3888 L
s
.799 .209 1 r
.34889 .39886 m
.34881 .39916 L
s
.522 .277 1 r
.4514 .36825 m
.45119 .37673 L
s
.45121 .37669 m
.4514 .36825 L
s
.4514 .36825 m
.45106 .38491 L
s
.477 .289 1 r
.69226 .3799 m
.69267 .38829 L
s
.6927 .38785 m
.69226 .3799 L
s
.953 .176 1 r
.7615 .40103 m
.76146 .40138 L
s
.477 .289 1 r
.69267 .38829 m
.69228 .37986 L
s
.69228 .37986 m
.6927 .38785 L
s
.489 .286 1 r
.79567 .3909 m
.79567 .39161 L
s
.671 .239 1 r
.67644 .33095 m
.67854 .37245 L
s
.618 .252 1 r
.37682 .33095 m
.37517 .37282 L
s
.892 .189 1 r
.27 .38695 m
.26929 .39625 L
s
.26936 .39609 m
.27 .38695 L
s
.845 .199 1 r
.89377 .38559 m
.89478 .39485 L
s
.89481 .39451 m
.89377 .38559 L
s
.733 .224 1 r
.61868 .38424 m
.61892 .39324 L
s
.61898 .39294 m
.61868 .38424 L
s
.833 .201 1 r
.24027 .37194 m
.23947 .38114 L
s
.23948 .38109 m
.24027 .37194 L
s
.24027 .37194 m
.23876 .39014 L
s
.892 .189 1 r
.26929 .39625 m
.27002 .3869 L
s
.27002 .3869 m
.26936 .39609 L
s
.845 .199 1 r
.89478 .39485 m
.8938 .38555 L
s
.8938 .38555 m
.89481 .39451 L
s
.733 .224 1 r
.61892 .39324 m
.6187 .3842 L
s
.6187 .3842 m
.61898 .39294 L
s
.357 .451 1 r
.16661 .37613 m
.16578 .38382 L
s
.16587 .38349 m
.16661 .37613 L
s
.477 .289 1 r
.47593 .36729 m
.47578 .37566 L
s
.4758 .37562 m
.47593 .36729 L
s
.47593 .36729 m
.47571 .3837 L
s
.811 .206 1 r
.81059 .39863 m
.81055 .39897 L
s
.357 .451 1 r
.16578 .38382 m
.16662 .3761 L
s
.16662 .3761 m
.16587 .38349 L
s
.45 .297 1 r
.55473 .37966 m
.55479 .38794 L
s
.55485 .38761 m
.55473 .37966 L
s
.55479 .38794 m
.55475 .37962 L
s
.55475 .37962 m
.55485 .38761 L
s
.722 .227 1 r
.31904 .38454 m
.31849 .39346 L
s
.31856 .39331 m
.31904 .38454 L
s
.811 .206 1 r
.56443 .37089 m
.5645 .38007 L
s
.56453 .38003 m
.56443 .37089 L
s
.56443 .37089 m
.56466 .38893 L
s
.618 .252 1 r
.64322 .38318 m
.64352 .39185 L
s
.64357 .39173 m
.64322 .38318 L
s
.495 .284 1 r
.44698 .39405 m
.44692 .39412 L
s
.608 .254 1 r
.15174 .3689 m
.15075 .3776 L
s
.15076 .37756 m
.15174 .3689 L
s
.15174 .3689 m
.14986 .38601 L
s
.779 .214 1 r
.83855 .33071 m
.84302 .3759 L
s
.977 .171 1 r
.5389 .33071 m
.53932 .37664 L
s
.69 .234 1 r
.23925 .33071 m
.23574 .37405 L
s
.722 .227 1 r
.31849 .39346 m
.31906 .38449 L
s
.31906 .38449 m
.31856 .39331 L
s
.37 .509 1 r
.56964 .38729 m
.56959 .38743 L
s
.618 .252 1 r
.64352 .39185 m
.64324 .38314 L
s
.64324 .38314 m
.64357 .39173 L
s
.799 .209 1 r
.15694 .38536 m
.15593 .39447 L
s
.15602 .39428 m
.15694 .38536 L
s
.15593 .39447 m
.15695 .38531 L
s
.15695 .38531 m
.15602 .39428 L
s
.711 .229 1 r
.88863 .36975 m
.88956 .37872 L
s
.88959 .37868 m
.88863 .36975 L
s
.88863 .36975 m
.89056 .38735 L
s
.589 .259 1 r
.61349 .3684 m
.61369 .37707 L
s
.61371 .37703 m
.61349 .3684 L
s
.61349 .3684 m
.61396 .3854 L
s
.711 .229 1 r
.34356 .38348 m
.34307 .39243 L
s
.34315 .3921 m
.34356 .38348 L
s
.441 .3 1 r
.49605 .39164 m
.49599 .39193 L
s
.711 .229 1 r
.34307 .39243 m
.34358 .38343 L
s
.34358 .38343 m
.34315 .3921 L
s
.733 .224 1 r
.18144 .3843 m
.18052 .39326 L
s
.1806 .39307 m
.18144 .3843 L
s
.433 .302 1 r
.70102 .33046 m
.70333 .37049 L
s
.345 .389 1 r
.40132 .33046 m
.40005 .36976 L
s
.733 .224 1 r
.18052 .39326 m
.18146 .38426 L
s
.18146 .38426 m
.1806 .39307 L
s
.638 .247 1 r
.72214 .39598 m
.72209 .39617 L
s
.648 .244 1 r
.66778 .38242 m
.66815 .39123 L
s
.66819 .39089 m
.66778 .38242 L
s
.7 .232 1 r
.28927 .37012 m
.28862 .37901 L
s
.28863 .37897 m
.28927 .37012 L
s
.28927 .37012 m
.28806 .38772 L
s
1 .164 .985 r
.46188 .40214 m
.46181 .40233 L
s
.648 .244 1 r
.66815 .39123 m
.66781 .38238 L
s
.66781 .38238 m
.66819 .39089 L
s
.3138 .36884 m
.31322 .37766 L
s
.31324 .37761 m
.3138 .36884 L
s
.3138 .36884 m
.31274 .38614 L
s
.589 .259 1 r
.77563 .36817 m
.77624 .37683 L
s
.77627 .37679 m
.77563 .36817 L
s
.77563 .36817 m
.77692 .38517 L
s
.68 .237 1 r
.80537 .38324 m
.80611 .39209 L
s
.80614 .39186 m
.80537 .38324 L
s
.777 .214 1 r
.3979 .39755 m
.39783 .39789 L
s
.68 .237 1 r
.80611 .39209 m
.8054 .3832 L
s
.8054 .3832 m
.80614 .39186 L
s
.467 .292 1 r
.17619 .36832 m
.17531 .37654 L
s
.17532 .3765 m
.17619 .36832 L
s
.17619 .36832 m
.1745 .3848 L
s
.881 .191 1 r
.72657 .37108 m
.7271 .38042 L
s
.72713 .38038 m
.72657 .37108 L
s
.72657 .37108 m
.7277 .38943 L
s
.701 .231 1 r
.36807 .38271 m
.36764 .39167 L
s
.36773 .39126 m
.36807 .38271 L
s
.383 .317 1 r
.14195 .37865 m
.14102 .38668 L
s
.1411 .38653 m
.14195 .37865 L
s
.522 .277 1 r
.86317 .33022 m
.86749 .37062 L
s
.629 .249 1 r
.56344 .33022 m
.56414 .37172 L
s
.777 .214 1 r
.26371 .33022 m
.2605 .37394 L
s
.701 .231 1 r
.36764 .39167 m
.36809 .38267 L
s
.36809 .38267 m
.36773 .39126 L
s
.383 .317 1 r
.14102 .38668 m
.14196 .37862 L
s
.14196 .37862 m
.1411 .38653 L
s
.788 .212 1 r
.78086 .38488 m
.78154 .39396 L
s
.78159 .3938 m
.78086 .38488 L
s
.552 .269 1 r
.8002 .36717 m
.80087 .37577 L
s
.8009 .37573 m
.8002 .36717 L
s
.8002 .36717 m
.8016 .38395 L
s
.425 .305 1 r
.90356 .37812 m
.90449 .38637 L
s
.90449 .38593 m
.90356 .37812 L
s
.834 .201 1 r
.23575 .39852 m
.23566 .39883 L
s
.788 .212 1 r
.78154 .39396 m
.78089 .38484 L
s
.78089 .38484 m
.78159 .3938 L
s
.777 .214 1 r
.75112 .36995 m
.75171 .37907 L
s
.75173 .37902 m
.75112 .36995 L
s
.75112 .36995 m
.75235 .38785 L
s
.619 .252 1 r
.14722 .39514 m
.14713 .39537 L
s
1 .153 .933 r
.78617 .4013 m
.78614 .40175 L
s
.425 .305 1 r
.90449 .38637 m
.90359 .37809 L
s
.90359 .37809 m
.90449 .38593 L
s
.476 .29 1 r
.36285 .36658 m
.36242 .37494 L
s
.36243 .37491 m
.36285 .36658 L
s
.36285 .36658 m
.36208 .38298 L
s
.335 .34 1 r
.86941 .38839 m
.8694 .38871 L
s
.54 .272 1 r
.25497 .38112 m
.25428 .38959 L
s
.25436 .38945 m
.25497 .38112 L
s
.531 .274 1 r
.72561 .32997 m
.72827 .37075 L
s
.503 .282 1 r
.42584 .32997 m
.42484 .37038 L
s
.521 .277 1 r
.12607 .32997 m
.12134 .37111 L
s
.54 .272 1 r
.25428 .38959 m
.25499 .38108 L
s
.25499 .38108 m
.25436 .38945 L
s
.467 .292 1 r
.6582 .39213 m
.65815 .39232 L
s
.608 .254 1 r
.30934 .39491 m
.30926 .39509 L
s
.648 .244 1 r
.63808 .36836 m
.63834 .37718 L
s
.63837 .37714 m
.63808 .36836 L
s
.63808 .36836 m
.63868 .38566 L
s
.754 .219 1 r
.20587 .38412 m
.205 .39312 L
s
.20508 .39296 m
.20587 .38412 L
s
.205 .39312 m
.20588 .38407 L
s
.20588 .38407 m
.20508 .39296 L
s
.589 .259 1 r
.33387 .3937 m
.33379 .39404 L
s
.618 .252 1 r
.71693 .38088 m
.71742 .38965 L
s
.71746 .38921 m
.71693 .38088 L
s
.416 .307 1 r
.88781 .32973 m
.8923 .36903 L
s
.904 .186 1 r
.588 .32973 m
.58909 .37493 L
s
.638 .247 1 r
.28819 .32973 m
.28537 .37235 L
s
.36 .462 1 r
.91857 .38634 m
.91856 .38663 L
s
.618 .252 1 r
.71742 .38965 m
.71695 .38084 L
s
.71695 .38084 m
.71746 .38921 L
s
.609 .254 1 r
.58458 .39685 m
.58452 .39659 L
s
.756 .219 1 r
.90896 .39528 m
.90897 .39587 L
s
.56 .267 1 r
.82481 .36666 m
.82555 .37529 L
s
.82558 .37525 m
.82481 .36666 L
s
.82481 .36666 m
.82634 .38348 L
s
.337 .354 1 r
.43204 .38852 m
.43198 .38869 L
s
.504 .282 1 r
.74148 .37982 m
.74202 .38823 L
s
.74206 .388 m
.74148 .37982 L
s
.74202 .38823 m
.74151 .37979 L
s
.74151 .37979 m
.74206 .388 L
s
.744 .222 1 r
.74679 .39624 m
.74675 .39658 L
s
.777 .214 1 r
.83005 .38335 m
.83087 .39246 L
s
.8309 .39212 m
.83005 .38335 L
s
.58 .262 1 r
.2006 .36838 m
.19974 .37694 L
s
.19976 .3769 m
.2006 .36838 L
s
.2006 .36838 m
.19897 .38543 L
s
.711 .229 1 r
.75021 .32949 m
.75339 .37321 L
s
.701 .232 1 r
.60914 .39564 m
.60909 .39594 L
s
.744 .221 1 r
.45036 .32949 m
.44961 .37284 L
s
.521 .277 1 r
.15051 .32948 m
.146 .37137 L
s
.777 .214 1 r
.83087 .39246 m
.83008 .38331 L
s
.83008 .38331 m
.8309 .39212 L
s
.531 .274 1 r
.52059 .39226 m
.52053 .39259 L
s
.478 .289 1 r
.87396 .36439 m
.87481 .37287 L
s
.87484 .37283 m
.87396 .36439 L
s
.87396 .36439 m
.87568 .38069 L
s
.367 .322 1 r
.19089 .37741 m
.19008 .3854 L
s
.19015 .38521 m
.19089 .37741 L
s
.512 .279 1 r
.22513 .36717 m
.22436 .37558 L
s
.22437 .37554 m
.22513 .36717 L
s
.22513 .36717 m
.22367 .38385 L
s
.711 .229 1 r
.50045 .36856 m
.50036 .37753 L
s
.50038 .37748 m
.50045 .36856 L
s
.50045 .36856 m
.50035 .38616 L
s
.367 .322 1 r
.19008 .3854 m
.1909 .37737 L
s
.1909 .37737 m
.19015 .38521 L
s
.701 .232 1 r
.28473 .39721 m
.28466 .39718 L
s
.608 .254 1 r
.57931 .38094 m
.57944 .38964 L
s
.5795 .38934 m
.57931 .38094 L
s
.57944 .38964 m
.57933 .3809 L
s
.57933 .3809 m
.5795 .38934 L
s
.733 .224 1 r
.39254 .38311 m
.39218 .39207 L
s
.39225 .39188 m
.39254 .38311 L
s
.68 .237 1 r
.66267 .3681 m
.663 .37699 L
s
.66303 .37695 m
.66267 .3681 L
s
.66267 .3681 m
.66341 .38555 L
s
.941 .179 1 r
.91345 .37084 m
.91451 .38029 L
s
.91454 .38025 m
.91345 .37084 L
s
.91345 .37084 m
.91563 .38945 L
s
.744 .221 1 r
.61257 .32924 m
.61394 .3726 L
s
.608 .254 1 r
.31269 .32924 m
.3102 .37149 L
s
.733 .224 1 r
.39218 .39207 m
.39256 .38307 L
s
.39256 .38307 m
.39225 .39188 L
s
1 .161 .972 r
.12691 .37294 m
.12576 .38247 L
s
.12577 .38243 m
.12691 .37294 L
s
.12691 .37294 m
.12468 .392 L
s
.442 .299 1 r
.84503 .39143 m
.84499 .3915 L
s
.799 .209 1 r
.33822 .36981 m
.33768 .37893 L
s
.3377 .37889 m
.33822 .36981 L
s
.33822 .36981 m
.33724 .38787 L
s
1 .123 .772 r
.75647 .38829 m
.75716 .3983 L
s
.7572 .39796 m
.75647 .38829 L
s
.494 .284 1 r
.30394 .38017 m
.30339 .38846 L
s
.30345 .3885 m
.30394 .38017 L
s
1 .151 .92 r
.8644 .37401 m
.86532 .38359 L
s
.86536 .38355 m
.8644 .37401 L
s
.8644 .37401 m
.86637 .39335 L
s
1 .123 .772 r
.75716 .3983 m
.7565 .38824 L
s
.7565 .38824 m
.7572 .39796 L
s
.559 .267 1 r
.84948 .36651 m
.85028 .3751 L
s
.85031 .37506 m
.84948 .36651 L
s
.84948 .36651 m
.85113 .38337 L
s
.45 .297 1 r
.57411 .36516 m
.5742 .37346 L
s
.57422 .37342 m
.57411 .36516 L
s
.57411 .36516 m
.57437 .38142 L
s
.68 .237 1 r
.77483 .329 m
.77825 .37162 L
s
.342 .378 1 r
.4749 .329 m
.47453 .36646 L
s
.659 .242 1 r
.17497 .329 m
.1705 .37346 L
s
.494 .284 1 r
.30339 .38846 m
.30396 .38013 L
s
.30396 .38013 m
.30345 .3885 L
s
.531 .274 1 r
.71181 .36605 m
.71225 .37457 L
s
.71228 .37453 m
.71181 .36605 L
s
.71181 .36605 m
.71276 .38276 L
s
.57 .264 1 r
.32849 .37911 m
.32798 .38777 L
s
.32807 .38728 m
.32849 .37911 L
s
.777 .214 1 r
.47148 .39614 m
.47141 .39648 L
s
.354 .434 1 r
.85475 .38322 m
.85478 .38402 L
s
.57 .264 1 r
.32798 .38777 m
.32851 .37907 L
s
.32851 .37907 m
.32807 .38728 L
s
.68 .237 1 r
.63716 .32875 m
.6388 .37101 L
s
.669 .239 1 r
.33719 .32875 m
.33498 .37175 L
s
.711 .229 1 r
.19607 .39493 m
.19597 .39527 L
s
.531 .274 1 r
.70741 .39155 m
.70738 .39189 L
s
.754 .219 1 r
.17149 .39651 m
.17141 .39666 L
s
.66 .241 1 r
.68287 .39312 m
.68284 .39361 L
s
.559 .267 1 r
.40743 .39192 m
.40736 .39225 L
s
.777 .214 1 r
.79946 .32851 m
.80329 .37224 L
s
.811 .206 1 r
.49945 .32851 m
.49934 .37261 L
s
.68 .237 1 r
.19944 .32851 m
.19549 .37114 L
s
.578 .262 1 r
.22057 .3941 m
.22051 .39406 L
s
.743 .222 1 r
.77148 .39687 m
.77143 .39688 L
s
.711 .229 1 r
.54957 .3676 m
.54961 .37657 L
s
.54963 .37653 m
.54957 .3676 L
s
.54957 .3676 m
.54973 .38521 L
s
.811 .206 1 r
.27932 .38269 m
.27864 .39188 L
s
.27873 .39154 m
.27932 .38269 L
s
.27864 .39188 m
.27934 .38265 L
s
.27934 .38265 m
.27873 .39154 L
s
.917 .184 1 r
.41705 .38352 m
.41674 .39297 L
s
.41682 .39251 m
.41705 .38352 L
s
.503 .282 1 r
.5153 .3781 m
.51527 .38654 L
s
.51533 .38621 m
.5153 .3781 L
s
.917 .184 1 r
.41674 .39297 m
.41707 .38347 L
s
.41707 .38347 m
.41682 .39251 L
s
.516 1 .953 r
.66176 .32826 m
.6631 .3573 L
s
.467 .292 1 r
.36171 .32826 m
.35989 .36942 L
s
.503 .282 1 r
.51527 .38654 m
.51532 .37806 L
s
.51532 .37806 m
.51533 .38621 L
s
.341 .371 1 r
.85929 .35925 m
.86007 .36731 L
s
.86009 .36727 m
.85929 .35925 L
s
.85929 .35925 m
.86083 .37439 L
s
.788 .212 1 r
.38725 .3689 m
.38685 .37798 L
s
.38687 .37794 m
.38725 .3689 L
s
.38725 .3689 m
.38654 .38692 L
s
.669 .239 1 r
.62849 .38057 m
.62876 .38942 L
s
.62881 .38912 m
.62849 .38057 L
s
.335 .34 1 r
.8241 .32802 m
.82767 .36549 L
s
.416 .307 1 r
.52402 .32802 m
.5242 .36734 L
s
.638 .247 1 r
.22393 .32802 m
.22021 .37139 L
s
.669 .239 1 r
.62876 .38942 m
.62851 .38053 L
s
.62851 .38053 m
.62881 .38912 L
s
.68 .237 1 r
.54517 .39362 m
.54511 .39396 L
s
.723 .226 1 r
.79083 .38004 m
.79155 .38911 L
s
.79156 .38852 m
.79083 .38004 L
s
.441 .3 1 r
.53987 .37733 m
.5399 .38555 L
s
.53995 .38536 m
.53987 .37733 L
s
.723 .226 1 r
.79155 .38911 m
.79086 .38 L
s
.79086 .38 m
.79156 .38852 L
s
.711 .229 1 r
.27405 .36712 m
.27335 .37609 L
s
.27337 .37605 m
.27405 .36712 L
s
.27405 .36712 m
.27276 .38473 L
s
.441 .3 1 r
.5399 .38555 m
.53989 .37729 L
s
.53989 .37729 m
.53995 .38536 L
s
.754 .219 1 r
.35826 .3958 m
.35819 .39595 L
s
.45 .297 1 r
.4811 .38903 m
.48104 .38936 L
s
.375 .32 1 r
.42667 .37545 m
.42642 .38351 L
s
.42649 .38318 m
.42667 .37545 L
s
.42642 .38351 m
.42669 .37541 L
s
.42669 .37541 m
.42649 .38318 L
s
.68 .237 1 r
.49073 .38033 m
.49063 .38922 L
s
.4907 .38889 m
.49073 .38033 L
s
.43638 .36666 m
.43612 .37556 L
s
.43613 .37552 m
.43638 .36666 L
s
.43638 .36666 m
.43594 .38412 L
s
.559 .267 1 r
.59431 .39121 m
.59426 .39154 L
s
.744 .221 1 r
.68637 .32777 m
.68867 .37078 L
s
.578 .262 1 r
.38624 .32777 m
.3847 .36967 L
s
.68 .237 1 r
.49063 .38922 m
.49075 .38029 L
s
.49075 .38029 m
.4907 .38889 L
s
.833 .201 1 r
.24945 .36884 m
.24867 .37803 L
s
.24869 .37799 m
.24945 .36884 L
s
.24945 .36884 m
.24799 .38705 L
s
.34 .366 1 r
.2301 .38662 m
.23003 .38676 L
s
.337 .354 1 r
.53024 .38662 m
.53019 .3868 L
s
.845 .199 1 r
.41181 .36823 m
.41146 .3775 L
s
.41148 .37746 m
.41181 .36823 L
s
.41181 .36823 m
.41122 .38644 L
s
.649 .244 1 r
.73211 .39218 m
.73207 .39263 L
s
.68 .237 1 r
.35294 .38009 m
.35247 .38898 L
s
.35255 .38865 m
.35294 .38009 L
s
.744 .222 1 r
.73653 .3671 m
.73707 .37615 L
s
.73709 .3761 m
.73653 .3671 L
s
.73653 .3671 m
.73767 .38486 L
s
.503 .282 1 r
.70224 .37739 m
.70268 .38583 L
s
.70272 .38549 m
.70224 .37739 L
s
1 .136 .839 r
.84876 .32753 m
.85358 .3746 L
s
.559 .267 1 r
.54859 .32753 m
.54909 .36869 L
s
.87 .194 1 r
.24843 .32753 m
.24476 .37423 L
s
.68 .237 1 r
.35247 .38898 m
.35295 .38005 L
s
.35295 .38005 m
.35255 .38865 L
s
.503 .282 1 r
.70268 .38583 m
.70227 .37735 L
s
.70227 .37735 m
.70272 .38549 L
s
.845 .199 1 r
.76633 .38227 m
.76699 .39154 L
s
.76702 .3912 m
.76633 .38227 L
s
.799 .209 1 r
.46615 .38227 m
.46598 .39139 L
s
.46605 .3912 m
.46615 .38227 L
s
.495 .284 1 r
.26428 .37685 m
.26361 .38529 L
s
.2637 .38489 m
.26428 .37685 L
s
.845 .199 1 r
.76699 .39154 m
.76635 .38223 L
s
.76635 .38223 m
.76702 .3912 L
s
.799 .209 1 r
.46598 .39139 m
.46617 .38223 L
s
.46617 .38223 m
.46605 .3912 L
s
.618 .252 1 r
.29856 .36664 m
.29794 .37532 L
s
.29796 .37528 m
.29856 .36664 L
s
.29856 .36664 m
.29742 .38388 L
s
.495 .284 1 r
.26361 .38529 m
.26429 .37681 L
s
.26429 .37681 m
.2637 .38489 L
s
.916 .184 1 r
.6874 .37013 m
.68781 .37944 L
s
.68784 .3794 m
.6874 .37013 L
s
.6874 .37013 m
.68832 .38876 L
s
.777 .214 1 r
.59875 .36675 m
.59892 .37591 L
s
.59894 .37586 m
.59875 .36675 L
s
.59875 .36675 m
.59917 .38462 L
s
.579 .262 1 r
.45652 .39134 m
.45645 .39164 L
s
.494 .284 1 r
.71099 .32728 m
.71353 .36918 L
s
.438 .79 1 r
.41078 .32728 m
.40984 .35962 L
s
.777 .214 1 r
.11058 .32728 m
.10535 .37103 L
s
.46 .294 1 r
.67248 .36287 m
.67282 .37125 L
s
.67284 .37121 m
.67248 .36287 L
s
.67248 .36287 m
.67322 .37914 L
s
.495 .284 1 r
.50567 .38892 m
.50561 .38933 L
s
.754 .219 1 r
.24495 .39509 m
.24488 .39525 L
s
.618 .252 1 r
.84011 .37879 m
.84093 .38754 L
s
.84095 .3872 m
.84011 .37879 L
s
.342 .378 1 r
.87964 .38494 m
.87962 .38526 L
s
.618 .252 1 r
.84093 .38754 m
.84014 .37875 L
s
.84014 .37875 m
.84095 .3872 L
s
.777 .214 1 r
.65313 .38097 m
.65348 .39009 L
s
.65352 .38975 m
.65313 .38097 L
s
.13611 .36797 m
.13504 .37702 L
s
.13505 .37698 m
.13611 .36797 L
s
.13611 .36797 m
.13405 .38596 L
s
.618 .252 1 r
.87343 .32704 m
.87811 .36968 L
s
.589 .259 1 r
.57318 .32704 m
.57399 .36821 L
s
.55 .269 1 r
.27294 .32704 m
.26997 .36895 L
s
.777 .214 1 r
.65348 .39009 m
.65316 .38093 L
s
.65316 .38093 m
.65352 .38975 L
s
1 .146 .894 r
.44157 .3845 m
.44131 .39434 L
s
.44139 .39388 m
.44157 .3845 L
s
.44131 .39434 m
.44159 .38446 L
s
.44159 .38446 m
.44139 .39388 L
s
.628 .249 1 r
.32308 .36613 m
.32253 .37484 L
s
.32255 .3748 m
.32308 .36613 L
s
.32308 .36613 m
.32207 .38341 L
s
.777 .214 1 r
.46093 .36684 m
.46073 .37596 L
s
.46074 .37592 m
.46093 .36684 L
s
.46093 .36684 m
.46061 .38475 L
s
1 .161 .972 r
.60398 .38397 m
.6042 .39362 L
s
.60426 .39327 m
.60398 .38397 L
s
.6042 .39362 m
.60401 .38393 L
s
.60401 .38393 m
.60426 .39327 L
s
.733 .224 1 r
.21503 .38073 m
.21419 .3897 L
s
.21427 .38951 m
.21503 .38073 L
s
.777 .214 1 r
.89904 .36773 m
.90002 .37679 L
s
.90005 .37674 m
.89904 .36773 L
s
.89904 .36773 m
.90107 .38573 L
s
.744 .221 1 r
.62335 .36638 m
.62359 .37543 L
s
.62361 .37538 m
.62335 .36638 L
s
.62335 .36638 m
.6239 .38414 L
s
.503 .282 1 r
.37224 .36368 m
.37183 .37212 L
s
.37184 .37208 m
.37224 .36368 L
s
.37224 .36368 m
.3715 .38024 L
s
.953 .176 1 r
.73562 .32679 m
.73875 .3724 L
s
.701 .232 1 r
.43534 .32679 m
.4344 .36981 L
s
.522 .277 1 r
.13506 .32679 m
.13048 .3676 L
s
.733 .224 1 r
.21419 .3897 m
.21504 .38069 L
s
.21504 .38069 m
.21427 .38951 L
s
.357 .451 1 r
.16587 .38349 m
.16578 .38382 L
s
1 .148 .907 r
.63387 .39921 m
.63382 .39952 L
s
.823 .204 1 r
.67775 .3802 m
.67816 .38951 L
s
.6782 .38891 m
.67775 .3802 L
s
.67816 .38951 m
.67777 .38016 L
s
.67777 .38016 m
.6782 .38891 L
s
.476 .29 1 r
.53467 .36322 m
.53467 .37159 L
s
.53469 .37155 m
.53467 .36322 L
s
.53467 .36322 m
.53474 .37964 L
s
.531 .274 1 r
.58906 .37696 m
.58922 .38548 L
s
.58927 .38515 m
.58906 .37696 L
s
.477 .289 1 r
.6927 .38785 m
.69267 .38829 L
s
.679 .237 1 r
.1316 .39401 m
.13153 .39402 L
s
.531 .274 1 r
.58922 .38548 m
.58908 .37692 L
s
.58908 .37692 m
.58927 .38515 L
s
.892 .189 1 r
.38274 .3968 m
.38267 .39695 L
s
.69 .234 1 r
.29404 .39341 m
.29397 .39356 L
s
.744 .222 1 r
.4855 .36614 m
.48537 .37519 L
s
.48539 .37514 m
.4855 .36614 L
s
.4855 .36614 m
.48532 .3839 L
s
.679 .237 1 r
.89811 .32655 m
.90319 .36994 L
s
1 .156 .946 r
.59779 .32655 m
.59904 .37289 L
s
.733 .224 1 r
.29746 .32655 m
.29469 .3703 L
s
.743 .222 1 r
.16058 .3676 m
.15959 .37654 L
s
.1596 .3765 m
.16058 .3676 L
s
.16058 .3676 m
.15867 .38548 L
s
.608 .254 1 r
.18516 .36629 m
.18427 .37489 L
s
.18428 .37485 m
.18516 .36629 L
s
.18516 .36629 m
.18344 .38353 L
s
.904 .186 1 r
.82094 .39777 m
.82087 .39774 L
s
.8 .209 1 r
.37743 .38079 m
.37702 .38995 L
s
.37709 .38965 m
.37743 .38079 L
s
.522 .277 1 r
.45119 .37673 m
.451 .38521 L
s
.45106 .38491 m
.45119 .37673 L
s
.45 .297 1 r
.55485 .38761 m
.55479 .38794 L
s
.8 .209 1 r
.37702 .38995 m
.37745 .38075 L
s
.37745 .38075 m
.37709 .38965 L
s
.522 .277 1 r
.451 .38521 m
.45121 .37669 L
s
.45121 .37669 m
.45106 .38491 L
s
.869 .194 1 r
.81566 .38161 m
.81646 .39092 L
s
.8165 .39062 m
.81566 .38161 L
s
.953 .176 1 r
.76127 .36793 m
.76191 .37742 L
s
.76193 .37738 m
.76127 .36793 L
s
.76127 .36793 m
.76261 .38659 L
s
.811 .206 1 r
.78586 .36658 m
.78654 .37577 L
s
.78657 .37573 m
.78586 .36658 L
s
.78586 .36658 m
.78729 .38464 L
s
.559 .267 1 r
.23432 .36387 m
.23355 .37247 L
s
.23356 .37243 m
.23432 .36387 L
s
.23432 .36387 m
.23288 .38074 L
s
.869 .194 1 r
.81646 .39092 m
.81569 .38157 L
s
.81569 .38157 m
.8165 .39062 L
s
.559 .267 1 r
.76027 .3263 m
.7634 .36748 L
s
.68 .237 1 r
.45991 .3263 m
.45929 .36895 L
s
.754 .219 1 r
.15955 .3263 m
.15491 .37043 L
s
.477 .289 1 r
.47578 .37566 m
.47565 .38403 L
s
.47571 .3837 m
.47578 .37566 L
s
.69 .234 1 r
.64798 .36608 m
.64827 .37495 L
s
.64829 .37491 m
.64798 .36608 L
s
.64798 .36608 m
.64864 .38367 L
s
.711 .229 1 r
.51009 .36544 m
.51002 .37441 L
s
.51004 .37437 m
.51009 .36544 L
s
.51009 .36544 m
.51004 .38306 L
s
.477 .289 1 r
.47565 .38403 m
.4758 .37562 L
s
.4758 .37562 m
.47571 .3837 L
s
.494 .285 1 r
.39677 .36356 m
.39643 .37194 L
s
.39644 .3719 m
.39677 .36356 L
s
.39677 .36356 m
.39616 .38013 L
s
.733 .224 1 r
.61898 .39294 m
.61892 .39324 L
s
.777 .214 1 r
.402 .38002 m
.40165 .38914 L
s
.40173 .3888 m
.402 .38002 L
s
.788 .212 1 r
.6224 .32606 m
.62393 .37056 L
s
.766 .216 1 r
.322 .32606 m
.31955 .36982 L
s
.777 .214 1 r
.40165 .38914 m
.40202 .37998 L
s
.40202 .37998 m
.40173 .3888 L
s
.618 .252 1 r
.64357 .39173 m
.64352 .39185 L
s
.845 .199 1 r
.89481 .39451 m
.89478 .39485 L
s
.608 .254 1 r
.15075 .3776 m
.14977 .38631 L
s
.14986 .38601 m
.15075 .3776 L
s
.722 .227 1 r
.31856 .39331 m
.31849 .39346 L
s
.608 .254 1 r
.14977 .38631 m
.15076 .37756 L
s
.15076 .37756 m
.14986 .38601 L
s
.892 .189 1 r
.26936 .39609 m
.26929 .39625 L
s
.383 .317 1 r
.1411 .38653 m
.14102 .38668 L
s
.833 .201 1 r
.23947 .38114 m
.23867 .39033 L
s
.23876 .39014 m
.23947 .38114 L
s
.589 .259 1 r
.61369 .37707 m
.61391 .38574 L
s
.61396 .3854 m
.61369 .37707 L
s
.425 .305 1 r
.90449 .38593 m
.90449 .38637 L
s
.833 .201 1 r
.23867 .39033 m
.23948 .38109 L
s
.23948 .38109 m
.23876 .39014 L
s
.559 .267 1 r
.78494 .32581 m
.78837 .36699 L
s
.335 .341 1 r
.48449 .32581 m
.48423 .36367 L
s
.754 .219 1 r
.18405 .32581 m
.17974 .36995 L
s
.711 .229 1 r
.34315 .3921 m
.34307 .39243 L
s
.756 .219 1 r
.83513 .36481 m
.83594 .37393 L
s
.83597 .37389 m
.83513 .36481 L
s
.83513 .36481 m
.8368 .38258 L
s
.589 .259 1 r
.61391 .38574 m
.61371 .37703 L
s
.61371 .37703 m
.61396 .3854 L
s
.56 .267 1 r
.42136 .36282 m
.42106 .37146 L
s
.42108 .37142 m
.42136 .36282 L
s
.42136 .36282 m
.42086 .37965 L
s
.467 .292 1 r
.17531 .37654 m
.17444 .38476 L
s
.1745 .3848 m
.17531 .37654 L
s
.754 .219 1 r
.20963 .36628 m
.20876 .37529 L
s
.20878 .37525 m
.20963 .36628 L
s
.20963 .36628 m
.20798 .38416 L
s
.799 .209 1 r
.15602 .39428 m
.15593 .39447 L
s
.916 .184 1 r
.34757 .36699 m
.34704 .37641 L
s
.34706 .37637 m
.34757 .36699 L
s
.34757 .36699 m
.34661 .38551 L
s
.648 .244 1 r
.66819 .39089 m
.66815 .39123 L
s
.467 .292 1 r
.17444 .38476 m
.17532 .3765 L
s
.17532 .3765 m
.1745 .3848 L
s
.811 .206 1 r
.5645 .38007 m
.5646 .38927 L
s
.56466 .38893 m
.5645 .38007 L
s
.711 .229 1 r
.88956 .37872 m
.89054 .38769 L
s
.89056 .38735 m
.88956 .37872 L
s
.811 .206 1 r
.81055 .36642 m
.8113 .37559 L
s
.81133 .37555 m
.81055 .36642 L
s
.81055 .36642 m
.81212 .38453 L
s
.733 .224 1 r
.1806 .39307 m
.18052 .39326 L
s
.811 .206 1 r
.5646 .38927 m
.56453 .38003 L
s
.56453 .38003 m
.56466 .38893 L
s
.711 .229 1 r
.89054 .38769 m
.88959 .37868 L
s
.88959 .37868 m
.89056 .38735 L
s
.589 .259 1 r
.77624 .37683 m
.77689 .3855 L
s
.77692 .38517 m
.77624 .37683 L
s
.68 .237 1 r
.80614 .39186 m
.80611 .39209 L
s
.352 .327 1 r
.77102 .36045 m
.77158 .36845 L
s
.7716 .36841 m
.77102 .36045 L
s
.77102 .36045 m
.77219 .37612 L
s
.368 .322 1 r
.64703 .32557 m
.64863 .3638 L
s
.788 .212 1 r
.34655 .32556 m
.34438 .37007 L
s
.589 .259 1 r
.77689 .3855 m
.77627 .37679 L
s
.77627 .37679 m
.77692 .38517 L
s
.7 .232 1 r
.28862 .37901 m
.28798 .38791 L
s
.28806 .38772 m
.28862 .37901 L
s
.701 .231 1 r
.36773 .39126 m
.36764 .39167 L
s
.648 .244 1 r
.31322 .37766 m
.31265 .38648 L
s
.31274 .38614 m
.31322 .37766 L
s
.476 .29 1 r
.36242 .37494 m
.362 .38331 L
s
.36208 .38298 m
.36242 .37494 L
s
.7 .232 1 r
.28798 .38791 m
.28863 .37897 L
s
.28863 .37897 m
.28806 .38772 L
s
.648 .244 1 r
.31265 .38648 m
.31324 .37761 L
s
.31324 .37761 m
.31274 .38614 L
s
.476 .29 1 r
.362 .38331 m
.36243 .37491 L
s
.36243 .37491 m
.36208 .38298 L
s
.638 .247 1 r
.25879 .36408 m
.25807 .37287 L
s
.25808 .37283 m
.25879 .36408 L
s
.25879 .36408 m
.25744 .38137 L
s
.522 .277 1 r
.28339 .36273 m
.28275 .37122 L
s
.28276 .37118 m
.28339 .36273 L
s
.28339 .36273 m
.28221 .37941 L
s
.552 .269 1 r
.80087 .37577 m
.80157 .38437 L
s
.8016 .38395 m
.80087 .37577 L
s
.54 .272 1 r
.25436 .38945 m
.25428 .38959 L
s
.552 .269 1 r
.80157 .38437 m
.8009 .37573 L
s
.8009 .37573 m
.8016 .38395 L
s
.559 .267 1 r
.88441 .36291 m
.8853 .37151 L
s
.88533 .37147 m
.88441 .36291 L
s
.88441 .36291 m
.88624 .37978 L
s
.712 .229 1 r
.80961 .32532 m
.81349 .36798 L
s
.335 .34 1 r
.50909 .32532 m
.5091 .36319 L
s
.766 .216 1 r
.20857 .32532 m
.20455 .36983 L
s
.512 .279 1 r
.1208 .36366 m
.11977 .37204 L
s
.11978 .372 m
.1208 .36366 L
s
.1208 .36366 m
.11881 .38039 L
s
.811 .206 1 r
.69726 .36505 m
.6977 .37428 L
s
.69773 .37424 m
.69726 .36505 L
s
.69726 .36505 m
.69821 .38308 L
s
.788 .212 1 r
.78159 .3938 m
.78154 .39396 L
s
.416 .307 1 r
.30796 .3617 m
.30741 .36986 L
s
.30742 .36982 m
.30796 .3617 L
s
.30796 .3617 m
.30694 .37783 L
s
.618 .252 1 r
.71746 .38921 m
.71742 .38965 L
s
.881 .191 1 r
.7271 .38042 m
.72766 .38977 L
s
.7277 .38943 m
.7271 .38042 L
s
.777 .214 1 r
.75171 .37907 m
.75232 .38819 L
s
.75235 .38785 m
.75171 .37907 L
s
.375 .529 1 r
.40637 .3565 m
.40608 .36413 L
s
.40609 .36409 m
.40637 .3565 L
s
.40637 .3565 m
.40587 .37114 L
s
.367 .322 1 r
.19015 .38521 m
.19008 .3854 L
s
.881 .191 1 r
.72766 .38977 m
.72713 .38038 L
s
.72713 .38038 m
.7277 .38943 L
s
.531 .274 1 r
.67167 .32507 m
.67368 .36589 L
s
.679 .237 1 r
.37111 .32507 m
.3693 .36885 L
s
.777 .214 1 r
.75232 .38819 m
.75173 .37902 L
s
.75173 .37902 m
.75235 .38785 L
s
.504 .282 1 r
.74206 .388 m
.74202 .38823 L
s
.56 .267 1 r
.60851 .3621 m
.6087 .37074 L
s
.60872 .3707 m
.60851 .3621 L
s
.60851 .3621 m
.60896 .37893 L
s
.648 .244 1 r
.63834 .37718 m
.63863 .386 L
s
.63868 .38566 m
.63834 .37718 L
s
.63863 .386 m
.63837 .37714 L
s
.63837 .37714 m
.63868 .38566 L
s
.754 .219 1 r
.20508 .39296 m
.205 .39312 L
s
.56 .267 1 r
.82555 .37529 m
.82632 .38392 L
s
.82634 .38348 m
.82555 .37529 L
s
.777 .214 1 r
.7219 .36435 m
.72241 .37351 L
s
.72244 .37347 m
.7219 .36435 L
s
.7219 .36435 m
.72298 .38223 L
s
.56 .267 1 r
.82632 .38392 m
.82558 .37525 L
s
.82558 .37525 m
.82634 .38348 L
s
.54 .272 1 r
.14532 .36307 m
.14434 .37156 L
s
.14435 .37152 m
.14532 .36307 L
s
.14532 .36307 m
.14344 .37991 L
s
.953 .176 1 r
.8343 .32483 m
.83884 .3712 L
s
.659 .242 1 r
.5337 .32483 m
.53402 .36713 L
s
.638 .247 1 r
.2331 .32483 m
.2295 .36823 L
s
.441 .3 1 r
.63313 .36111 m
.63337 .36938 L
s
.63339 .36934 m
.63313 .36111 L
s
.63313 .36111 m
.63367 .37735 L
s
.58 .262 1 r
.19974 .37694 m
.1989 .38551 L
s
.19897 .38543 m
.19974 .37694 L
s
.512 .279 1 r
.22436 .37558 m
.22359 .38399 L
s
.22367 .38385 m
.22436 .37558 L
s
.478 .289 1 r
.87481 .37287 m
.87569 .38135 L
s
.87568 .38069 m
.87481 .37287 L
s
.58 .262 1 r
.1989 .38551 m
.19976 .3769 L
s
.19976 .3769 m
.19897 .38543 L
s
.512 .279 1 r
.22359 .38399 m
.22437 .37554 L
s
.22437 .37554 m
.22367 .38385 L
s
.478 .289 1 r
.87569 .38135 m
.87484 .37283 L
s
.87484 .37283 m
.87568 .38069 L
s
.608 .254 1 r
.5795 .38934 m
.57944 .38964 L
s
.777 .214 1 r
.8309 .39212 m
.83087 .39246 L
s
.88 .191 1 r
.55932 .36557 m
.55938 .37492 L
s
.5594 .37488 m
.55932 .36557 L
s
.55932 .36557 m
.55953 .38394 L
s
.711 .229 1 r
.69633 .32458 m
.69877 .36762 L
s
.589 .259 1 r
.39569 .32458 m
.3943 .36578 L
s
.744 .221 1 r
.44591 .36365 m
.44567 .37274 L
s
.44569 .37269 m
.44591 .36365 L
s
.44591 .36365 m
.44552 .38138 L
s
.711 .229 1 r
.50036 .37753 m
.50029 .3865 L
s
.50035 .38616 m
.50036 .37753 L
s
.45 .297 1 r
.5742 .37346 m
.57432 .38175 L
s
.57437 .38142 m
.5742 .37346 L
s
.733 .224 1 r
.39225 .39188 m
.39218 .39207 L
s
.711 .229 1 r
.50029 .3865 m
.50038 .37748 L
s
.50038 .37748 m
.50035 .38616 L
s
.494 .284 1 r
.30345 .3885 m
.30339 .38846 L
s
.45 .297 1 r
.57432 .38175 m
.57422 .37342 L
s
.57422 .37342 m
.57437 .38142 L
s
.68 .237 1 r
.663 .37699 m
.66336 .38589 L
s
.66341 .38555 m
.663 .37699 L
s
.569 .264 1 r
.859 .32434 m
.86353 .36738 L
s
.916 .184 1 r
.55832 .32434 m
.559 .3696 L
s
.649 .244 1 r
.25764 .32434 m
.25445 .36664 L
s
.68 .237 1 r
.66336 .38589 m
.66303 .37695 L
s
.66303 .37695 m
.66341 .38555 L
s
.57 .264 1 r
.32807 .38728 m
.32798 .38777 L
s
.559 .267 1 r
.85028 .3751 m
.85111 .3837 L
s
.85113 .38337 m
.85028 .3751 L
s
.85111 .3837 m
.85031 .37506 L
s
.85031 .37506 m
.85113 .38337 L
s
.531 .274 1 r
.71225 .37457 m
.71272 .3831 L
s
.71276 .38276 m
.71225 .37457 L
s
.71272 .3831 m
.71228 .37453 L
s
.71228 .37453 m
.71276 .38276 L
s
.811 .206 1 r
.74661 .36441 m
.74719 .37362 L
s
.74721 .37357 m
.74661 .36441 L
s
.74661 .36441 m
.74783 .38249 L
s
.4 .312 1 r
.721 .32409 m
.7235 .36308 L
s
.423 .732 1 r
.42028 .32409 m
.41941 .35719 L
s
.441 .3 1 r
.11956 .32409 m
.11486 .36418 L
s
.941 .179 1 r
.91451 .38029 m
.91561 .38976 L
s
.91563 .38945 m
.91451 .38029 L
s
.799 .209 1 r
.33768 .37893 m
.33716 .38806 L
s
.33724 .38787 m
.33768 .37893 L
s
.941 .179 1 r
.91561 .38976 m
.91454 .38025 L
s
.91454 .38025 m
.91563 .38945 L
s
.799 .209 1 r
.33716 .38806 m
.3377 .37889 L
s
.3377 .37889 m
.33724 .38787 L
s
1 .161 .972 r
.12576 .38247 m
.12461 .39202 L
s
.12468 .392 m
.12576 .38247 L
s
.12461 .39202 m
.12577 .38243 L
s
.12577 .38243 m
.12468 .392 L
s
.669 .239 1 r
.16976 .36342 m
.1688 .37225 L
s
.16881 .37221 m
.16976 .36342 L
s
.16976 .36342 m
.16793 .3809 L
s
.953 .176 1 r
.58396 .36553 m
.58409 .37503 L
s
.58412 .37498 m
.58396 .36553 L
s
.58396 .36553 m
.58431 .3842 L
s
.599 .257 1 r
.51975 .36075 m
.51971 .36954 L
s
.51973 .3695 m
.51975 .36075 L
s
.51975 .36075 m
.51975 .37774 L
s
.94 .179 1 r
.88371 .32384 m
.88891 .36985 L
s
.35 .414 1 r
.58296 .32384 m
.58379 .36062 L
s
.451 .837 1 r
.2822 .32384 m
.28 .35621 L
s
.777 .214 1 r
.90934 .36428 m
.91034 .37338 L
s
.91038 .37334 m
.90934 .36428 L
s
.90934 .36428 m
.91142 .38225 L
s
.503 .282 1 r
.51533 .38621 m
.51527 .38654 L
s
1 .151 .92 r
.86532 .38359 m
.86629 .39318 L
s
.86637 .39335 m
.86532 .38359 L
s
1 .123 .772 r
.7572 .39796 m
.75716 .3983 L
s
1 .151 .92 r
.86629 .39318 m
.86536 .38355 L
s
.86536 .38355 m
.86637 .39335 L
s
.341 .371 1 r
.86007 .36731 m
.86087 .37538 L
s
.86083 .37439 m
.86007 .36731 L
s
.86087 .37538 m
.86009 .36727 L
s
.86009 .36727 m
.86083 .37439 L
s
.45 .297 1 r
.74568 .3236 m
.74852 .36333 L
s
.845 .199 1 r
.44488 .3236 m
.44403 .36813 L
s
.578 .262 1 r
.14408 .3236 m
.13948 .36554 L
s
.403 .652 1 r
.48016 .35513 m
.48004 .36239 L
s
.48005 .36236 m
.48016 .35513 L
s
.48016 .35513 m
.47999 .36933 L
s
.345 .39 1 r
.73171 .35788 m
.73216 .3657 L
s
.73219 .36566 m
.73171 .35788 L
s
.73171 .35788 m
.73268 .37323 L
s
.375 .32 1 r
.42649 .38318 m
.42642 .38351 L
s
.441 .3 1 r
.53995 .38536 m
.5399 .38555 L
s
.811 .206 1 r
.27873 .39154 m
.27864 .39188 L
s
.711 .229 1 r
.54961 .37657 m
.54967 .38554 L
s
.54973 .38521 m
.54961 .37657 L
s
.54967 .38554 m
.54963 .37653 L
s
.54963 .37653 m
.54973 .38521 L
s
.744 .222 1 r
.49513 .36301 m
.49502 .37207 L
s
.49504 .37203 m
.49513 .36301 L
s
.49513 .36301 m
.49499 .38079 L
s
.916 .184 1 r
.6076 .32335 m
.60896 .36862 L
s
.618 .252 1 r
.30677 .32335 m
.30422 .3653 L
s
.423 .732 1 r
.52941 .35282 m
.5294 .35996 L
s
.52942 .35993 m
.52941 .35282 L
s
.52941 .35282 m
.52945 .36653 L
s
.917 .184 1 r
.41682 .39251 m
.41674 .39297 L
s
.833 .201 1 r
.4705 .36451 m
.47032 .37372 L
s
.47034 .37368 m
.4705 .36451 L
s
.4705 .36451 m
.47023 .38274 L
s
.669 .239 1 r
.62881 .38912 m
.62876 .38942 L
s
.723 .226 1 r
.79156 .38852 m
.79155 .38911 L
s
.846 .199 1 r
.79599 .36334 m
.79671 .37266 L
s
.79674 .37261 m
.79599 .36334 L
s
.79599 .36334 m
.79749 .38153 L
s
.777 .214 1 r
.33237 .36413 m
.33182 .37319 L
s
.33184 .37315 m
.33237 .36413 L
s
.33237 .36413 m
.33136 .38214 L
s
.691 .234 1 r
.77037 .32311 m
.77377 .36616 L
s
.834 .201 1 r
.46949 .32311 m
.46897 .36764 L
s
.598 .257 1 r
.16862 .32311 m
.16428 .36542 L
s
.788 .212 1 r
.38685 .37798 m
.38647 .38707 L
s
.38654 .38692 m
.38685 .37798 L
s
.68 .237 1 r
.4907 .38889 m
.49063 .38922 L
s
.503 .282 1 r
.70272 .38549 m
.70268 .38583 L
s
.788 .212 1 r
.38647 .38707 m
.38687 .37794 L
s
.38687 .37794 m
.38654 .38692 L
s
.495 .284 1 r
.2637 .38489 m
.26361 .38529 L
s
.579 .262 1 r
.24349 .361 m
.24274 .36964 L
s
.24275 .3696 m
.24349 .361 L
s
.24349 .361 m
.24209 .37799 L
s
.711 .229 1 r
.27335 .37609 m
.27267 .38507 L
s
.27276 .38473 m
.27335 .37609 L
s
.27267 .38507 m
.27337 .37605 L
s
.27337 .37605 m
.27276 .38473 L
s
.658 .242 1 r
.21884 .3625 m
.21802 .37129 L
s
.21803 .37125 m
.21884 .3625 L
s
.21884 .3625 m
.21728 .37994 L
s
.68 .237 1 r
.43612 .37556 m
.43587 .38446 L
s
.43594 .38412 m
.43612 .37556 L
s
.38162 .36185 m
.38121 .37076 L
s
.38123 .37072 m
.38162 .36185 L
s
.38162 .36185 m
.3809 .37933 L
s
.588 .259 1 r
.63226 .32286 m
.63382 .36444 L
s
.845 .199 1 r
.33135 .32286 m
.32898 .3674 L
s
.68 .237 1 r
.43587 .38446 m
.43613 .37552 L
s
.43613 .37552 m
.43594 .38412 L
s
.833 .201 1 r
.1942 .36403 m
.19326 .37324 L
s
.19328 .3732 m
.1942 .36403 L
s
.1942 .36403 m
.19243 .38226 L
s
.68 .237 1 r
.35255 .38865 m
.35247 .38898 L
s
.754 .219 1 r
.35697 .36339 m
.35649 .37242 L
s
.35651 .37237 m
.35697 .36339 L
s
.35697 .36339 m
.3561 .38129 L
s
.433 .302 1 r
.59366 .35865 m
.5938 .36692 L
s
.59383 .36688 m
.59366 .35865 L
s
.59366 .35865 m
.59402 .37482 L
s
.789 .211 1 r
.68255 .36214 m
.68295 .37135 L
s
.68298 .3713 m
.68255 .36214 L
s
.68255 .36214 m
.68342 .38007 L
s
.84535 .36158 m
.8462 .37082 L
s
.84623 .37077 m
.84535 .36158 L
s
.84535 .36158 m
.84709 .37946 L
s
.833 .201 1 r
.24867 .37803 m
.2479 .38724 L
s
.24799 .38705 m
.24867 .37803 L
s
.618 .252 1 r
.29794 .37532 m
.29735 .384 L
s
.29742 .38388 m
.29794 .37532 L
s
.46 .294 1 r
.67282 .37125 m
.67318 .37962 L
s
.67322 .37914 m
.67282 .37125 L
s
.833 .201 1 r
.2479 .38724 m
.24869 .37799 L
s
.24869 .37799 m
.24799 .38705 L
s
.357 .451 1 r
.79508 .32261 m
.79826 .3594 L
s
.4 .312 1 r
.49412 .32261 m
.49396 .36161 L
s
.833 .201 1 r
.19316 .32261 m
.1889 .36752 L
s
.618 .252 1 r
.29735 .384 m
.29796 .37528 L
s
.29796 .37528 m
.29742 .38388 L
s
.46 .294 1 r
.67318 .37962 m
.67284 .37121 L
s
.67284 .37121 m
.67322 .37914 L
s
.845 .199 1 r
.41146 .3775 m
.41114 .38678 L
s
.41122 .38644 m
.41146 .3775 L
s
.744 .222 1 r
.73707 .37615 m
.73763 .3852 L
s
.73767 .38486 m
.73707 .37615 L
s
.845 .199 1 r
.76702 .3912 m
.76699 .39154 L
s
.799 .209 1 r
.46605 .3912 m
.46598 .39139 L
s
.845 .199 1 r
.41114 .38678 m
.41148 .37746 L
s
.41148 .37746 m
.41122 .38644 L
s
.916 .184 1 r
.65793 .36386 m
.65827 .37329 L
s
.6583 .37325 m
.65793 .36386 L
s
.65793 .36386 m
.65869 .38239 L
s
.744 .222 1 r
.73763 .3852 m
.73709 .3761 L
s
.73709 .3761 m
.73767 .38486 L
s
.648 .244 1 r
.7072 .36115 m
.70765 .36999 L
s
.70768 .36994 m
.7072 .36115 L
s
.7072 .36115 m
.70817 .37849 L
s
.618 .252 1 r
.84095 .3872 m
.84093 .38754 L
s
.869 .194 1 r
.82076 .36344 m
.82154 .37276 L
s
.82157 .37272 m
.82076 .36344 L
s
.82076 .36344 m
.8224 .38179 L
s
.357 .45 1 r
.65694 .32237 m
.6586 .35953 L
s
.658 .242 1 r
.35594 .32237 m
.35396 .36543 L
s
.777 .214 1 r
.59892 .37591 m
.59911 .38507 L
s
.59917 .38462 m
.59892 .37591 L
s
.59911 .38507 m
.59894 .37586 L
s
.59894 .37586 m
.59917 .38462 L
s
.916 .184 1 r
.68781 .37944 m
.68826 .38877 L
s
.68832 .38876 m
.68781 .37944 L
s
.68826 .38877 m
.68784 .3794 L
s
.68784 .3794 m
.68832 .38876 L
s
.777 .214 1 r
.65352 .38975 m
.65348 .39009 L
s
.822 .204 1 r
.54441 .36245 m
.54443 .37169 L
s
.54445 .37165 m
.54441 .36245 L
s
.54441 .36245 m
.54454 .38057 L
s
.54 .272 1 r
.12982 .36042 m
.1288 .36892 L
s
.12881 .36888 m
.12982 .36042 L
s
.12982 .36042 m
.12786 .37727 L
s
.628 .249 1 r
.32253 .37484 m
.322 .38356 L
s
.32207 .38341 m
.32253 .37484 L
s
.503 .282 1 r
.37183 .37212 m
.37143 .38058 L
s
.3715 .38024 m
.37183 .37212 L
s
.859 .196 1 r
.8198 .32212 m
.82395 .36629 L
s
.544 .271 1 r
.51876 .32212 m
.5189 .36113 L
s
.799 .209 1 r
.21773 .32212 m
.21382 .36667 L
s
.628 .249 1 r
.322 .38356 m
.32255 .3748 L
s
.32255 .3748 m
.32207 .38341 L
s
.531 .274 1 r
.58927 .38515 m
.58922 .38548 L
s
.503 .282 1 r
.37143 .38058 m
.37184 .37208 L
s
.37184 .37208 m
.3715 .38024 L
s
.777 .214 1 r
.13504 .37702 m
.13397 .38608 L
s
.13405 .38596 m
.13504 .37702 L
s
.476 .29 1 r
.53467 .37159 m
.53468 .37997 L
s
.53474 .37964 m
.53467 .37159 L
s
.777 .214 1 r
.13397 .38608 m
.13505 .37698 L
s
.13505 .37698 m
.13405 .38596 L
s
.711 .229 1 r
.87011 .36135 m
.871 .37033 L
s
.87103 .37029 m
.87011 .36135 L
s
.87011 .36135 m
.87195 .37898 L
s
.476 .29 1 r
.53468 .37997 m
.53469 .37155 L
s
.53469 .37155 m
.53474 .37964 L
s
.733 .224 1 r
.21427 .38951 m
.21419 .3897 L
s
.823 .204 1 r
.6782 .38891 m
.67816 .38951 L
s
.777 .214 1 r
.46073 .37596 m
.46054 .38509 L
s
.46061 .38475 m
.46073 .37596 L
s
.68163 .32187 m
.68397 .36679 L
s
.628 .249 1 r
.38055 .32187 m
.3789 .36457 L
s
.777 .214 1 r
.46054 .38509 m
.46074 .37592 L
s
.46074 .37592 m
.46061 .38475 L
s
.522 .277 1 r
.45106 .38491 m
.451 .38521 L
s
.777 .214 1 r
.90002 .37679 m
.90103 .38584 L
s
.90107 .38573 m
.90002 .37679 L
s
.744 .221 1 r
.62359 .37543 m
.62385 .38448 L
s
.6239 .38414 m
.62359 .37543 L
s
.608 .254 1 r
.26797 .36172 m
.26728 .37033 L
s
.2673 .37029 m
.26797 .36172 L
s
.26797 .36172 m
.26667 .37898 L
s
1 .146 .894 r
.44139 .39388 m
.44131 .39434 L
s
.569 .264 1 r
.89479 .3604 m
.89571 .36897 L
s
.89574 .36893 m
.89479 .3604 L
s
.89479 .3604 m
.89669 .3774 L
s
.777 .214 1 r
.90103 .38584 m
.90005 .37674 L
s
.90005 .37674 m
.90107 .38573 L
s
.744 .221 1 r
.62385 .38448 m
.62361 .37538 L
s
.62361 .37538 m
.6239 .38414 L
s
1 .161 .972 r
.60426 .39327 m
.6042 .39362 L
s
.477 .289 1 r
.47571 .3837 m
.47565 .38403 L
s
.608 .254 1 r
.18427 .37489 m
.18338 .3835 L
s
.18344 .38353 m
.18427 .37489 L
s
.18338 .3835 m
.18428 .37485 L
s
.18428 .37485 m
.18344 .38353 L
s
.618 .252 1 r
.45549 .35997 m
.45528 .36873 L
s
.4553 .36869 m
.45549 .35997 L
s
.45549 .35997 m
.45515 .37716 L
s
.15437 .35997 m
.15338 .36873 L
s
.15339 .36869 m
.15437 .35997 L
s
.15437 .35997 m
.1525 .37716 L
s
.659 .242 1 r
.84453 .32163 m
.849 .36581 L
s
1 .151 .919 r
.54342 .32163 m
.54391 .36803 L
s
.892 .189 1 r
.2423 .32163 m
.23864 .36729 L
s
.743 .222 1 r
.15959 .37654 m
.1586 .38549 L
s
.15867 .38548 m
.15959 .37654 L
s
.744 .222 1 r
.48537 .37519 m
.48525 .38424 L
s
.48532 .3839 m
.48537 .37519 L
s
.559 .267 1 r
.23355 .37247 m
.23279 .38107 L
s
.23288 .38074 m
.23355 .37247 L
s
.743 .222 1 r
.1586 .38549 m
.1596 .3765 L
s
.1596 .3765 m
.15867 .38548 L
s
.744 .222 1 r
.48525 .38424 m
.48539 .37514 L
s
.48539 .37514 m
.48532 .3839 L
s
.559 .267 1 r
.23279 .38107 m
.23356 .37243 L
s
.23356 .37243 m
.23288 .38074 L
s
.8 .209 1 r
.37709 .38965 m
.37702 .38995 L
s
.494 .285 1 r
.39643 .37194 m
.3961 .38032 L
s
.39616 .38013 m
.39643 .37194 L
s
.3961 .38032 m
.39644 .3719 L
s
.39644 .3719 m
.39616 .38013 L
s
.424 .305 1 r
.70633 .32138 m
.70868 .36076 L
s
1 .138 .854 r
.40517 .32138 m
.40367 .36964 L
s
.589 .259 1 r
.10401 .32138 m
.0989 .36334 L
s
.869 .194 1 r
.8165 .39062 m
.81646 .39092 L
s
.69 .234 1 r
.64827 .37495 m
.64859 .38382 L
s
.64864 .38367 m
.64827 .37495 L
s
.569 .264 1 r
.61838 .35991 m
.61859 .36849 L
s
.61862 .36845 m
.61838 .35991 L
s
.61838 .35991 m
.61888 .37692 L
s
.69 .234 1 r
.64859 .38382 m
.64829 .37491 L
s
.64829 .37491 m
.64864 .38367 L
s
.679 .237 1 r
.29256 .36131 m
.29192 .37014 L
s
.29194 .3701 m
.29256 .36131 L
s
.29256 .36131 m
.29136 .37887 L
s
.811 .206 1 r
.78654 .37577 m
.78725 .38498 L
s
.78729 .38464 m
.78654 .37577 L
s
.711 .229 1 r
.51002 .37441 m
.50997 .38339 L
s
.51004 .38306 m
.51002 .37441 L
s
.608 .254 1 r
.14986 .38601 m
.14977 .38631 L
s
.777 .214 1 r
.40173 .3888 m
.40165 .38914 L
s
.811 .206 1 r
.78725 .38498 m
.78657 .37573 L
s
.78657 .37573 m
.78729 .38464 L
s
.711 .229 1 r
.50997 .38339 m
.51004 .37437 L
s
.51004 .37437 m
.51004 .38306 L
s
.589 .259 1 r
.61396 .3854 m
.61391 .38574 L
s
.467 .292 1 r
.1745 .3848 m
.17444 .38476 L
s
.588 .259 1 r
.3172 .36017 m
.31664 .36878 L
s
.31666 .36874 m
.3172 .36017 L
s
.3172 .36017 m
.31616 .37729 L
s
.352 .327 1 r
.77158 .36845 m
.77216 .37645 L
s
.77219 .37612 m
.77158 .36845 L
s
.648 .244 1 r
.86928 .32114 m
.87389 .36347 L
s
.618 .252 1 r
.56808 .32113 m
.56884 .3631 L
s
.766 .217 1 r
.26689 .32113 m
.26361 .36606 L
s
.953 .176 1 r
.76191 .37742 m
.76257 .38693 L
s
.76261 .38659 m
.76191 .37742 L
s
.352 .327 1 r
.77216 .37645 m
.7716 .36841 L
s
.7716 .36841 m
.77219 .37612 L
s
.416 .307 1 r
.3665 .3576 m
.36609 .36576 L
s
.36611 .36572 m
.3665 .3576 L
s
.3665 .3576 m
.36576 .37374 L
s
.953 .176 1 r
.76257 .38693 m
.76193 .37738 L
s
.76193 .37738 m
.76261 .38659 L
s
.476 .29 1 r
.36208 .38298 m
.362 .38331 L
s
.991 .169 1 r
.43082 .36252 m
.43052 .37215 L
s
.43054 .3721 m
.43082 .36252 L
s
.43082 .36252 m
.43031 .38132 L
s
.56 .267 1 r
.42106 .37146 m
.42079 .3801 L
s
.42086 .37965 m
.42106 .37146 L
s
.589 .259 1 r
.77692 .38517 m
.77689 .3855 L
s
.56 .267 1 r
.42079 .3801 m
.42108 .37142 L
s
.42108 .37142 m
.42086 .37965 L
s
.61 .254 1 r
.66773 .35781 m
.66808 .36664 L
s
.6681 .3666 m
.66773 .35781 L
s
.66773 .35781 m
.66849 .37485 L
s
.68 .237 1 r
.78136 .35992 m
.78201 .36883 L
s
.78203 .36879 m
.78136 .35992 L
s
.78136 .35992 m
.78272 .37741 L
s
.733 .224 1 r
.73104 .32089 m
.73395 .36434 L
s
.476 .29 1 r
.4298 .32089 m
.42886 .36101 L
s
.618 .252 1 r
.12857 .32089 m
.12381 .36249 L
s
.711 .229 1 r
.89056 .38735 m
.89054 .38769 L
s
.375 .529 1 r
.40608 .36413 m
.4058 .37176 L
s
.40587 .37114 m
.40608 .36413 L
s
.552 .269 1 r
.8016 .38395 m
.80157 .38437 L
s
.833 .201 1 r
.23876 .39014 m
.23867 .39033 L
s
.375 .529 1 r
.4058 .37176 m
.40609 .36409 L
s
.40609 .36409 m
.40587 .37114 L
s
.648 .244 1 r
.31274 .38614 m
.31265 .38648 L
s
.64308 .35946 m
.64336 .3683 L
s
.64339 .36826 m
.64308 .35946 L
s
.64308 .35946 m
.64372 .3768 L
s
.34183 .35946 m
.34132 .3683 L
s
.34134 .36826 m
.34183 .35946 L
s
.34183 .35946 m
.34091 .3768 L
s
.811 .206 1 r
.56466 .38893 m
.5646 .38927 L
s
.754 .219 1 r
.20876 .37529 m
.2079 .38432 L
s
.20798 .38416 m
.20876 .37529 L
s
.756 .219 1 r
.83594 .37393 m
.83679 .38307 L
s
.8368 .38258 m
.83594 .37393 L
s
.522 .277 1 r
.28275 .37122 m
.28213 .37971 L
s
.28221 .37941 m
.28275 .37122 L
s
.917 .184 1 r
.75672 .36161 m
.75735 .37108 L
s
.75737 .37103 m
.75672 .36161 L
s
.75672 .36161 m
.75803 .38011 L
s
.416 .307 1 r
.30741 .36986 m
.30687 .37801 L
s
.30694 .37783 m
.30741 .36986 L
s
.754 .219 1 r
.2079 .38432 m
.20878 .37525 L
s
.20878 .37525 m
.20798 .38416 L
s
.756 .219 1 r
.83679 .38307 m
.83597 .37389 L
s
.83597 .37389 m
.8368 .38258 L
s
.522 .277 1 r
.28213 .37971 m
.28276 .37118 L
s
.28276 .37118 m
.28221 .37941 L
s
.416 .307 1 r
.30687 .37801 m
.30742 .36982 L
s
.30742 .36982 m
.30694 .37783 L
s
.658 .242 1 r
.17885 .36033 m
.17792 .36913 L
s
.17793 .36909 m
.17885 .36033 L
s
.17885 .36033 m
.17707 .37778 L
s
.7 .232 1 r
.28806 .38772 m
.28798 .38791 L
s
.512 .279 1 r
.11977 .37204 m
.11874 .38043 L
s
.11881 .38039 m
.11977 .37204 L
s
.978 .171 1 r
.89404 .32064 m
.89939 .36669 L
s
.494 .284 1 r
.59276 .32064 m
.59379 .36114 L
s
.638 .247 1 r
.29149 .32064 m
.28872 .36298 L
s
.512 .279 1 r
.11874 .38043 m
.11978 .372 L
s
.11978 .372 m
.11881 .38039 L
s
.811 .206 1 r
.8113 .37559 m
.81208 .38476 L
s
.81212 .38453 m
.8113 .37559 L
s
.638 .247 1 r
.25807 .37287 m
.25735 .38166 L
s
.25744 .38137 m
.25807 .37287 L
s
.559 .267 1 r
.8853 .37151 m
.88622 .38012 L
s
.88624 .37978 m
.8853 .37151 L
s
.811 .206 1 r
.81208 .38476 m
.81133 .37555 L
s
.81133 .37555 m
.81212 .38453 L
s
.638 .247 1 r
.25735 .38166 m
.25808 .37283 L
s
.25808 .37283 m
.25744 .38137 L
s
.433 .302 1 r
.55411 .35647 m
.55416 .36475 L
s
.55418 .36471 m
.55411 .35647 L
s
.55411 .35647 m
.55428 .37266 L
s
.559 .267 1 r
.88622 .38012 m
.88533 .37147 L
s
.88533 .37147 m
.88624 .37978 L
s
.916 .184 1 r
.34704 .37641 m
.34653 .38585 L
s
.34661 .38551 m
.34704 .37641 L
s
.34653 .38585 m
.34706 .37637 L
s
.34706 .37637 m
.34661 .38551 L
s
1 .151 .921 r
.56911 .36415 m
.5692 .37386 L
s
.56923 .37381 m
.56911 .36415 L
s
.56911 .36415 m
.56939 .38341 L
s
.478 .289 1 r
.87568 .38069 m
.87569 .38135 L
s
.531 .274 1 r
.75576 .32039 m
.75882 .36126 L
s
.578 .262 1 r
.45445 .32039 m
.45377 .36237 L
s
1 .154 .934 r
.15313 .32039 m
.14804 .36792 L
s
.56 .267 1 r
.82634 .38348 m
.82632 .38392 L
s
.699 .232 1 r
.85545 .35677 m
.85632 .36592 L
s
.85635 .36587 m
.85545 .35677 L
s
.85545 .35677 m
.85719 .37412 L
s
.648 .244 1 r
.63868 .38566 m
.63863 .386 L
s
.56 .267 1 r
.6087 .37074 m
.60891 .37938 L
s
.60896 .37893 m
.6087 .37074 L
s
.441 .3 1 r
.63337 .36938 m
.63363 .37765 L
s
.63367 .37735 m
.63337 .36938 L
s
.777 .214 1 r
.80613 .35977 m
.80687 .36894 L
s
.80689 .3689 m
.80613 .35977 L
s
.80613 .35977 m
.80766 .37767 L
s
.75235 .38785 m
.75232 .38819 L
s
.56 .267 1 r
.60891 .37938 m
.60872 .3707 L
s
.60872 .3707 m
.60896 .37893 L
s
.441 .3 1 r
.63363 .37765 m
.63339 .36934 L
s
.63339 .36934 m
.63367 .37735 L
s
.658 .242 1 r
.20343 .35984 m
.20256 .36865 L
s
.20258 .3686 m
.20343 .35984 L
s
.20343 .35984 m
.20178 .3773 L
s
.811 .206 1 r
.6977 .37428 m
.69817 .38353 L
s
.69821 .38308 m
.6977 .37428 L
s
.54 .272 1 r
.14434 .37156 m
.14336 .38006 L
s
.14344 .37991 m
.14434 .37156 L
s
.512 .279 1 r
.22367 .38385 m
.22359 .38399 L
s
1 .156 .946 r
.61746 .32015 m
.61899 .36694 L
s
.904 .186 1 r
.3161 .32015 m
.31345 .36582 L
s
.811 .206 1 r
.69817 .38353 m
.69773 .37424 L
s
.69773 .37424 m
.69821 .38308 L
s
.54 .272 1 r
.14336 .38006 m
.14435 .37152 L
s
.14435 .37152 m
.14344 .37991 L
s
.881 .191 1 r
.7277 .38943 m
.72766 .38977 L
s
.701 .232 1 r
.50478 .36002 m
.5047 .36894 L
s
.50472 .36889 m
.50478 .36002 L
s
.50478 .36002 m
.5047 .37767 L
s
.67 .239 1 r
.83082 .35866 m
.8316 .36758 L
s
.83163 .36753 m
.83082 .35866 L
s
.83082 .35866 m
.83244 .37608 L
s
.58 .262 1 r
.19897 .38543 m
.1989 .38551 L
s
.45 .297 1 r
.57437 .38142 m
.57432 .38175 L
s
.928 .181 1 r
.7805 .3199 m
.78428 .36595 L
s
.531 .274 1 r
.47911 .3199 m
.47875 .36077 L
s
.799 .209 1 r
.17771 .3199 m
.17327 .36447 L
s
.68 .237 1 r
.3911 .35839 m
.39071 .36733 L
s
.39073 .36729 m
.3911 .35839 L
s
.3911 .35839 m
.39043 .37584 L
s
.777 .214 1 r
.72241 .37351 m
.72294 .38268 L
s
.72298 .38223 m
.72241 .37351 L
s
.72294 .38268 m
.72244 .37347 L
s
.72244 .37347 m
.72298 .38223 L
s
.341 .371 1 r
.86083 .37439 m
.86087 .37538 L
s
.559 .267 1 r
.85113 .38337 m
.85111 .3837 L
s
.4 .312 1 r
.64216 .31965 m
.64374 .35868 L
s
.588 .259 1 r
.34073 .31965 m
.33863 .36127 L
s
.711 .229 1 r
.50035 .38616 m
.50029 .3865 L
s
.531 .274 1 r
.71276 .38276 m
.71272 .3831 L
s
.744 .221 1 r
.69252 .35882 m
.69295 .36792 L
s
.69297 .36788 m
.69252 .35882 L
s
.69252 .35882 m
.69344 .37658 L
s
.68 .237 1 r
.66341 .38555 m
.66336 .38589 L
s
.403 .652 1 r
.48004 .36239 m
.47993 .36965 L
s
.47999 .36933 m
.48004 .36239 L
s
.588 .259 1 r
.41575 .35758 m
.41544 .36626 L
s
.41546 .36622 m
.41575 .35758 L
s
.41575 .35758 m
.41522 .37462 L
s
.589 .259 1 r
.1143 .35757 m
.11321 .36626 L
s
.11322 .36622 m
.1143 .35757 L
s
.1143 .35757 m
.11224 .37462 L
s
.744 .221 1 r
.44567 .37274 m
.44545 .38183 L
s
.44552 .38138 m
.44567 .37274 L
s
.403 .652 1 r
.47993 .36965 m
.48005 .36236 L
s
.48005 .36236 m
.47999 .36933 L
s
.744 .221 1 r
.44545 .38183 m
.44569 .37269 L
s
.44569 .37269 m
.44552 .38138 L
s
.88 .191 1 r
.55938 .37492 m
.55947 .38428 L
s
.55953 .38394 m
.55938 .37492 L
s
.68 .237 1 r
.25267 .35847 m
.25192 .36739 L
s
.25194 .36734 m
.25267 .35847 L
s
.25267 .35847 m
.25128 .37597 L
s
.88 .191 1 r
.55947 .38428 m
.5594 .37488 L
s
.5594 .37488 m
.55953 .38394 L
s
.352 .327 1 r
.62818 .3544 m
.6284 .36242 L
s
.62842 .36238 m
.62818 .3544 L
s
.62818 .3544 m
.62869 .3701 L
s
.68 .237 1 r
.80526 .31941 m
.80908 .36213 L
s
.50378 .31941 m
.50373 .36213 L
s
.569 .264 1 r
.20231 .31941 m
.19843 .36139 L
s
.423 .732 1 r
.5294 .35996 m
.5294 .36711 L
s
.52945 .36653 m
.5294 .35996 L
s
.5294 .36711 m
.52942 .35993 L
s
.52942 .35993 m
.52945 .36653 L
s
.345 .39 1 r
.73216 .3657 m
.73264 .37352 L
s
.73268 .37323 m
.73216 .3657 L
s
.788 .212 1 r
.22796 .36023 m
.22713 .36934 L
s
.22714 .36929 m
.22796 .36023 L
s
.22796 .36023 m
.22638 .37829 L
s
.345 .39 1 r
.73264 .37352 m
.73219 .36566 L
s
.73219 .36566 m
.73268 .37323 L
s
.609 .254 1 r
.66688 .31916 m
.66888 .36077 L
s
.559 .267 1 r
.36537 .31916 m
.36359 .36041 L
s
.799 .209 1 r
.33724 .38787 m
.33716 .38806 L
s
.811 .206 1 r
.74719 .37362 m
.74779 .38283 L
s
.74783 .38249 m
.74719 .37362 L
s
.669 .239 1 r
.1688 .37225 m
.16785 .38109 L
s
.16793 .3809 m
.1688 .37225 L
s
.599 .257 1 r
.51971 .36954 m
.51969 .37833 L
s
.51975 .37774 m
.51971 .36954 L
s
.811 .206 1 r
.74779 .38283 m
.74721 .37357 L
s
.74721 .37357 m
.74783 .38249 L
s
.669 .239 1 r
.16785 .38109 m
.16881 .37221 L
s
.16881 .37221 m
.16793 .3809 L
s
.599 .257 1 r
.51969 .37833 m
.51973 .3695 L
s
.51973 .3695 m
.51975 .37774 L
s
.941 .179 1 r
.91563 .38945 m
.91561 .38976 L
s
.476 .29 1 r
.30197 .35663 m
.30139 .36495 L
s
.30141 .36491 m
.30197 .35663 L
s
.30197 .35663 m
.30089 .37316 L
s
.433 .302 1 r
.83002 .31891 m
.83391 .35906 L
s
.765 .217 1 r
.52847 .31891 m
.52873 .36312 L
s
.94 .179 1 r
.22691 .31891 m
.223 .36497 L
s
.531 .274 1 r
.46509 .35617 m
.46491 .36471 L
s
.46493 .36467 m
.46509 .35617 L
s
.46509 .35617 m
.46482 .37292 L
s
.76666 .35617 m
.76725 .36471 L
s
.76727 .36467 m
.76666 .35617 L
s
.76666 .35617 m
.7679 .37292 L
s
.638 .247 1 r
.4404 .35757 m
.44015 .36637 L
s
.44017 .36633 m
.4404 .35757 L
s
.4404 .35757 m
.43999 .37488 L
s
.777 .214 1 r
.91034 .37338 m
.91139 .38248 L
s
.91142 .38225 m
.91034 .37338 L
s
.91139 .38248 m
.91038 .37334 L
s
.91038 .37334 m
.91142 .38225 L
s
.516 1 .953 r
.66259 .34531 m
.66282 .35146 L
s
.66284 .35143 m
.66259 .34531 L
s
.66259 .34531 m
.6631 .3573 L
s
1 .161 .972 r
.12468 .392 m
.12461 .39202 L
s
.45 .297 1 r
.48978 .35503 m
.48966 .36335 L
s
.48968 .36331 m
.48978 .35503 L
s
.48978 .35503 m
.48963 .37133 L
s
.8 .209 1 r
.69161 .31866 m
.69406 .36288 L
s
.799 .209 1 r
.39002 .31866 m
.38843 .36325 L
s
.711 .229 1 r
.54973 .38521 m
.54967 .38554 L
s
.953 .176 1 r
.58409 .37503 m
.58425 .38454 L
s
.58431 .3842 m
.58409 .37503 L
s
.58425 .38454 m
.58412 .37498 L
s
.58412 .37498 m
.58431 .3842 L
s
.628 .249 1 r
.13879 .35793 m
.13776 .36666 L
s
.13777 .36662 m
.13879 .35793 L
s
.13879 .35793 m
.13681 .37525 L
s
.337 .332 1 r
.8548 .31842 m
.85873 .35598 L
s
.42 .722 1 r
.55317 .31842 m
.55363 .35193 L
s
.608 .254 1 r
.25153 .31842 m
.24825 .36078 L
s
1 .151 .92 r
.86637 .39335 m
.86629 .39318 L
s
.744 .222 1 r
.49502 .37207 m
.49493 .38113 L
s
.49499 .38079 m
.49502 .37207 L
s
.49493 .38113 m
.49504 .37203 L
s
.49504 .37203 m
.49499 .38079 L
s
.711 .229 1 r
.60356 .35772 m
.60374 .36671 L
s
.60376 .36667 m
.60356 .35772 L
s
.60356 .35772 m
.604 .37537 L
s
.799 .209 1 r
.57887 .35923 m
.57898 .36837 L
s
.57901 .36833 m
.57887 .35923 L
s
.57887 .35923 m
.57918 .37733 L
s
.46 .294 1 r
.67322 .37914 m
.67318 .37962 L
s
.833 .201 1 r
.47032 .37372 m
.47016 .38294 L
s
.47023 .38274 m
.47032 .37372 L
s
.953 .176 1 r
.71736 .35998 m
.71787 .3695 L
s
.7179 .36945 m
.71736 .35998 L
s
.71736 .35998 m
.71846 .37868 L
s
.579 .262 1 r
.24274 .36964 m
.242 .37829 L
s
.24209 .37799 m
.24274 .36964 L
s
.799 .209 1 r
.74205 .35866 m
.74262 .36784 L
s
.74264 .36779 m
.74205 .35866 L
s
.74205 .35866 m
.74325 .37672 L
s
.433 .302 1 r
.5938 .36692 m
.59397 .37519 L
s
.59402 .37482 m
.5938 .36692 L
s
.833 .201 1 r
.47016 .38294 m
.47034 .37368 L
s
.47034 .37368 m
.47023 .38274 L
s
.733 .224 1 r
.71636 .31817 m
.71911 .36202 L
s
.845 .199 1 r
.41468 .31817 m
.4134 .3635 L
s
.378 .543 1 r
.11301 .31817 m
.10866 .35463 L
s
.711 .229 1 r
.27276 .38473 m
.27267 .38507 L
s
.579 .262 1 r
.242 .37829 m
.24275 .3696 L
s
.24275 .3696 m
.24209 .37799 L
s
.433 .302 1 r
.59397 .37519 m
.59383 .36688 L
s
.59383 .36688 m
.59402 .37482 L
s
.777 .214 1 r
.33182 .37319 m
.33129 .38225 L
s
.33136 .38214 m
.33182 .37319 L
s
.68 .237 1 r
.43594 .38412 m
.43587 .38446 L
s
.701 .232 1 r
.90525 .35809 m
.90623 .36701 L
s
.90626 .36696 m
.90525 .35809 L
s
.90525 .35809 m
.90728 .37574 L
s
.788 .212 1 r
.38654 .38692 m
.38647 .38707 L
s
.777 .214 1 r
.33129 .38225 m
.33184 .37315 L
s
.33184 .37315 m
.33136 .38214 L
s
.846 .199 1 r
.79671 .37266 m
.79746 .38198 L
s
.79749 .38153 m
.79671 .37266 L
s
.658 .242 1 r
.21802 .37129 m
.2172 .3801 L
s
.21728 .37994 m
.21802 .37129 L
s
.467 .292 1 r
.51447 .3548 m
.51441 .36316 L
s
.51443 .36312 m
.51447 .3548 L
s
.51447 .3548 m
.51444 .37122 L
s
.846 .199 1 r
.79746 .38198 m
.79674 .37261 L
s
.79674 .37261 m
.79749 .38153 L
s
.658 .242 1 r
.2172 .3801 m
.21803 .37125 L
s
.21803 .37125 m
.21728 .37994 L
s
.68 .237 1 r
.38121 .37076 m
.38082 .37967 L
s
.3809 .37933 m
.38121 .37076 L
s
.408 .31 1 r
.87959 .31792 m
.88404 .35771 L
s
.701 .231 1 r
.57788 .31792 m
.57878 .36066 L
s
.55 .269 1 r
.65298 .3557 m
.65327 .36428 L
s
.6533 .36424 m
.65298 .3557 L
s
.65298 .3557 m
.65365 .37257 L
s
.712 .229 1 r
.27616 .31792 m
.27318 .36066 L
s
.68 .237 1 r
.38082 .37967 m
.38123 .37072 L
s
.38123 .37072 m
.3809 .37933 L
s
.799 .209 1 r
.27716 .35989 m
.27646 .36896 L
s
.27647 .36892 m
.27716 .35989 L
s
.27716 .35989 m
.27584 .37807 L
s
.618 .252 1 r
.29742 .38388 m
.29735 .384 L
s
.766 .217 1 r
.16334 .35795 m
.16233 .36706 L
s
.16234 .36702 m
.16334 .35795 L
s
.16334 .35795 m
.16143 .37587 L
s
.754 .219 1 r
.35649 .37242 m
.35603 .38144 L
s
.3561 .38129 m
.35649 .37242 L
s
.833 .201 1 r
.88062 .3601 m
.88156 .36925 L
s
.88159 .36921 m
.88062 .3601 L
s
.88062 .3601 m
.88259 .37844 L
s
.754 .219 1 r
.35603 .38144 m
.35651 .37237 L
s
.35651 .37237 m
.3561 .38129 L
s
.833 .201 1 r
.19326 .37324 m
.19234 .38246 L
s
.19243 .38226 m
.19326 .37324 L
s
.744 .222 1 r
.73767 .38486 m
.73763 .3852 L
s
.669 .239 1 r
.79152 .35682 m
.7922 .3657 L
s
.79222 .36565 m
.79152 .35682 L
s
.79152 .35682 m
.79294 .37428 L
s
.833 .201 1 r
.19234 .38246 m
.19328 .3732 L
s
.19328 .3732 m
.19243 .38226 L
s
.669 .239 1 r
.74112 .31767 m
.74412 .36042 L
s
.722 .227 1 r
.43936 .31767 m
.43847 .36079 L
s
1 .149 .907 r
.13761 .31767 m
.13229 .36523 L
s
.833 .201 1 r
.24799 .38705 m
.2479 .38724 L
s
.789 .211 1 r
.68295 .37135 m
.68338 .38056 L
s
.68342 .38007 m
.68295 .37135 L
s
.648 .244 1 r
.70765 .36999 m
.70813 .37882 L
s
.70817 .37849 m
.70765 .36999 L
s
.7 .232 1 r
.32653 .3576 m
.32598 .36652 L
s
.326 .36648 m
.32653 .3576 L
s
.32653 .3576 m
.32551 .37526 L
s
.503 .282 1 r
.3715 .38024 m
.37143 .38058 L
s
.845 .199 1 r
.41122 .38644 m
.41114 .38678 L
s
.789 .211 1 r
.68338 .38056 m
.68298 .3713 L
s
.68298 .3713 m
.68342 .38007 L
s
.648 .244 1 r
.70813 .37882 m
.70768 .36994 L
s
.70768 .36994 m
.70817 .37849 L
s
.476 .29 1 r
.53474 .37964 m
.53468 .37997 L
s
.789 .211 1 r
.8462 .37082 m
.84708 .38006 L
s
.84709 .37946 m
.8462 .37082 L
s
.84708 .38006 m
.84623 .37077 L
s
.84623 .37077 m
.84709 .37946 L
s
.671 .239 1 r
.67773 .3551 m
.67811 .36409 L
s
.67813 .36405 m
.67773 .3551 L
s
.67773 .3551 m
.67854 .37245 L
s
.777 .214 1 r
.59917 .38462 m
.59911 .38507 L
s
.54 .272 1 r
.1288 .36892 m
.12778 .37742 L
s
.12786 .37727 m
.1288 .36892 L
s
.391 .315 1 r
.6026 .31743 m
.60371 .35648 L
s
.352 .327 1 r
.30081 .31743 m
.29841 .35574 L
s
.54 .272 1 r
.12778 .37742 m
.12881 .36888 L
s
.12881 .36888 m
.12786 .37727 L
s
.628 .249 1 r
.32207 .38341 m
.322 .38356 L
s
.55 .269 1 r
.35121 .35668 m
.35074 .36516 L
s
.35076 .36512 m
.35121 .35668 L
s
.35121 .35668 m
.35035 .37367 L
s
.916 .184 1 r
.65827 .37329 m
.65864 .38274 L
s
.65869 .38239 m
.65827 .37329 L
s
.65864 .38274 m
.6583 .37325 L
s
.6583 .37325 m
.65869 .38239 L
s
.722 .227 1 r
.18794 .35762 m
.18701 .36658 L
s
.18703 .36653 m
.18794 .35762 L
s
.18794 .35762 m
.18617 .37539 L
s
.345 .389 1 r
.40061 .35419 m
.4003 .36184 L
s
.40031 .36181 m
.40061 .35419 L
s
.40061 .35419 m
.40005 .36976 L
s
.869 .194 1 r
.82154 .37276 m
.82236 .38209 L
s
.8224 .38179 m
.82154 .37276 L
s
.433 .302 1 r
.70244 .35422 m
.70285 .36243 L
s
.70287 .36239 m
.70244 .35422 L
s
.70244 .35422 m
.70333 .37049 L
s
.618 .252 1 r
.37591 .35561 m
.3755 .36438 L
s
.37551 .36434 m
.37591 .35561 L
s
.37591 .35561 m
.37517 .37282 L
s
.869 .194 1 r
.82236 .38209 m
.82157 .37272 L
s
.82157 .37272 m
.8224 .38179 L
s
.754 .219 1 r
.76589 .31718 m
.76932 .36141 L
s
.424 .305 1 r
.46405 .31718 m
.46353 .3566 L
s
.88 .191 1 r
.16222 .31718 m
.15744 .36289 L
s
.777 .214 1 r
.13405 .38596 m
.13397 .38608 L
s
.916 .184 1 r
.68832 .38876 m
.68826 .38877 L
s
.822 .204 1 r
.54443 .37169 m
.54448 .38095 L
s
.54454 .38057 m
.54443 .37169 L
s
.711 .229 1 r
.871 .37033 m
.87192 .37932 L
s
.87195 .37898 m
.871 .37033 L
s
.608 .254 1 r
.26728 .37033 m
.26661 .37895 L
s
.26667 .37898 m
.26728 .37033 L
s
.569 .264 1 r
.89571 .36897 m
.89665 .37755 L
s
.89669 .3774 m
.89571 .36897 L
s
.777 .214 1 r
.46061 .38475 m
.46054 .38509 L
s
.822 .204 1 r
.54448 .38095 m
.54445 .37165 L
s
.54445 .37165 m
.54454 .38057 L
s
.608 .254 1 r
.26661 .37895 m
.2673 .37029 L
s
.2673 .37029 m
.26667 .37898 L
s
.711 .229 1 r
.87192 .37932 m
.87103 .37029 L
s
.87103 .37029 m
.87195 .37898 L
s
.569 .264 1 r
.89665 .37755 m
.89574 .36893 L
s
.89574 .36893 m
.89669 .3774 L
s
.522 .277 1 r
.86576 .35393 m
.8666 .36248 L
s
.86663 .36244 m
.86576 .35393 L
s
.86576 .35393 m
.86749 .37062 L
s
.744 .221 1 r
.6239 .38414 m
.62385 .38448 L
s
.559 .267 1 r
.23288 .38074 m
.23279 .38107 L
s
.375 .529 1 r
.40587 .37114 m
.4058 .37176 L
s
.811 .206 1 r
.62734 .31693 m
.62892 .36079 L
s
.618 .252 1 r
.32547 .31693 m
.32315 .35894 L
s
.608 .254 1 r
.18344 .38353 m
.18338 .3835 L
s
.494 .285 1 r
.39616 .38013 m
.3961 .38032 L
s
.777 .214 1 r
.90107 .38573 m
.90103 .38584 L
s
.352 .327 1 r
.77219 .37612 m
.77216 .37645 L
s
.416 .307 1 r
.89051 .35291 m
.89138 .36112 L
s
.8914 .36108 m
.89051 .35291 L
s
.89051 .35291 m
.8923 .36903 L
s
.618 .252 1 r
.45528 .36873 m
.45509 .37749 L
s
.45515 .37716 m
.45528 .36873 L
s
.15338 .36873 m
.1524 .37749 L
s
.1525 .37716 m
.15338 .36873 L
s
.45509 .37749 m
.4553 .36869 L
s
.4553 .36869 m
.45515 .37716 L
s
.1524 .37749 m
.15339 .36869 L
s
.15339 .36869 m
.1525 .37716 L
s
.438 .79 1 r
.41029 .34614 m
.41003 .35312 L
s
.41004 .35308 m
.41029 .34614 L
s
.41029 .34614 m
.40984 .35962 L
s
.744 .222 1 r
.48532 .3839 m
.48525 .38424 L
s
.503 .282 1 r
.42531 .35377 m
.42503 .36224 L
s
.42505 .3622 m
.42531 .35377 L
s
.42531 .35377 m
.42484 .37038 L
s
.411 .309 1 r
.79067 .31668 m
.79389 .35426 L
s
.504 .282 1 r
.48876 .31668 m
.48853 .35685 L
s
.733 .224 1 r
.18684 .31668 m
.18259 .36055 L
s
.342 .378 1 r
.47474 .35105 m
.47459 .35892 L
s
.47461 .35888 m
.47474 .35105 L
s
.47474 .35105 m
.47453 .36646 L
s
.629 .249 1 r
.56391 .35452 m
.56399 .36336 L
s
.56401 .36332 m
.56391 .35452 L
s
.56391 .35452 m
.56414 .37172 L
s
.754 .219 1 r
.21255 .35735 m
.21168 .36639 L
s
.2117 .36634 m
.21255 .35735 L
s
.21255 .35735 m
.2109 .37527 L
s
.743 .222 1 r
.15867 .38548 m
.1586 .38549 L
s
.845 .199 1 r
.81641 .35738 m
.81718 .36668 L
s
.81721 .36664 m
.81641 .35738 L
s
.81641 .35738 m
.81802 .37564 L
s
.531 .274 1 r
.72723 .35399 m
.72772 .36253 L
s
.72775 .36249 m
.72723 .35399 L
s
.72723 .35399 m
.72827 .37075 L
s
.569 .264 1 r
.61859 .36849 m
.61883 .37707 L
s
.61888 .37692 m
.61859 .36849 L
s
.416 .307 1 r
.36609 .36576 m
.3657 .37393 L
s
.36576 .37374 m
.36609 .36576 L
s
.569 .264 1 r
.61883 .37707 m
.61862 .36845 L
s
.61862 .36845 m
.61888 .37692 L
s
.416 .307 1 r
.3657 .37393 m
.36611 .36572 L
s
.36611 .36572 m
.36576 .37374 L
s
.69 .234 1 r
.64864 .38367 m
.64859 .38382 L
s
1 .108 .687 r
.65209 .31644 m
.65422 .36549 L
s
.424 .305 1 r
.35014 .31644 m
.34826 .35586 L
s
.711 .229 1 r
.51004 .38306 m
.50997 .38339 L
s
.56 .267 1 r
.42086 .37965 m
.42079 .3801 L
s
.679 .237 1 r
.29192 .37014 m
.29129 .37899 L
s
.29136 .37887 m
.29192 .37014 L
s
.588 .259 1 r
.31664 .36878 m
.31609 .3774 L
s
.31616 .37729 m
.31664 .36878 L
s
.521 .277 1 r
.12333 .35435 m
.12229 .36282 L
s
.1223 .36278 m
.12333 .35435 L
s
.12333 .35435 m
.12134 .37111 L
s
.69 .234 1 r
.23723 .35643 m
.23644 .36531 L
s
.23646 .36527 m
.23723 .35643 L
s
.23723 .35643 m
.23574 .37405 L
s
.679 .237 1 r
.29129 .37899 m
.29194 .3701 L
s
.29194 .3701 m
.29136 .37887 L
s
.588 .259 1 r
.31609 .3774 m
.31666 .36874 L
s
.31666 .36874 m
.31616 .37729 L
s
.811 .206 1 r
.78729 .38464 m
.78725 .38498 L
s
.416 .307 1 r
.30694 .37783 m
.30687 .37801 L
s
.744 .222 1 r
.81547 .31619 m
.8195 .35969 L
s
.57 .264 1 r
.51348 .31619 m
.51355 .35709 L
s
.638 .247 1 r
.21148 .31619 m
.20765 .35894 L
s
.522 .277 1 r
.28221 .37941 m
.28213 .37971 L
s
.61 .254 1 r
.66808 .36664 m
.66845 .37548 L
s
.66849 .37485 m
.66808 .36664 L
s
.512 .279 1 r
.11881 .38039 m
.11874 .38043 L
s
.61 .254 1 r
.66845 .37548 m
.6681 .3666 L
s
.6681 .3666 m
.66849 .37485 L
s
.953 .176 1 r
.76261 .38659 m
.76257 .38693 L
s
.68 .237 1 r
.78201 .36883 m
.78269 .37775 L
s
.78272 .37741 m
.78201 .36883 L
s
.559 .267 1 r
.88624 .37978 m
.88622 .38012 L
s
.433 .302 1 r
.55416 .36475 m
.55422 .37302 L
s
.55428 .37266 m
.55416 .36475 L
s
.777 .214 1 r
.67686 .31594 m
.67907 .35944 L
s
.578 .262 1 r
.37482 .31594 m
.37313 .35796 L
s
.756 .219 1 r
.8368 .38258 m
.83679 .38307 L
s
.68 .237 1 r
.78269 .37775 m
.78203 .36879 L
s
.78203 .36879 m
.78272 .37741 L
s
.433 .302 1 r
.55422 .37302 m
.55418 .36471 L
s
.55418 .36471 m
.55428 .37266 L
s
.648 .244 1 r
.64336 .3683 m
.64367 .37714 L
s
.64372 .3768 m
.64336 .3683 L
s
.34132 .3683 m
.34082 .37714 L
s
.34091 .3768 m
.34132 .3683 L
s
.638 .247 1 r
.25744 .38137 m
.25735 .38166 L
s
.777 .214 1 r
.26189 .35598 m
.26114 .36512 L
s
.26116 .36508 m
.26189 .35598 L
s
.26189 .35598 m
.2605 .37394 L
s
.648 .244 1 r
.64367 .37714 m
.64339 .36826 L
s
.64339 .36826 m
.64372 .3768 L
s
.34082 .37714 m
.34134 .36826 L
s
.34134 .36826 m
.34091 .3768 L
s
.754 .219 1 r
.20798 .38416 m
.2079 .38432 L
s
.658 .242 1 r
.17792 .36913 m
.17699 .37793 L
s
.17707 .37778 m
.17792 .36913 L
s
.441 .3 1 r
.63367 .37735 m
.63363 .37765 L
s
.658 .242 1 r
.17699 .37793 m
.17793 .36909 L
s
.17793 .36909 m
.17707 .37778 L
s
.335 .34 1 r
.82624 .34997 m
.82693 .35795 L
s
.82696 .35791 m
.82624 .34997 L
s
.82624 .34997 m
.82767 .36549 L
s
.423 .732 1 r
.52945 .36653 m
.5294 .36711 L
s
.579 .262 1 r
.84028 .31569 m
.84445 .35735 L
s
.559 .267 1 r
.53821 .31569 m
.53858 .35697 L
s
.711 .229 1 r
.23613 .31569 m
.23259 .35882 L
s
.56 .267 1 r
.60896 .37893 m
.60891 .37938 L
s
.403 .652 1 r
.47999 .36933 m
.47993 .36965 L
s
.991 .169 1 r
.43052 .37215 m
.43023 .38178 L
s
.43031 .38132 m
.43052 .37215 L
s
.638 .247 1 r
.28658 .35498 m
.28593 .36376 L
s
.28595 .36371 m
.28658 .35498 L
s
.28658 .35498 m
.28537 .37235 L
s
.811 .206 1 r
.81212 .38453 m
.81208 .38476 L
s
.779 .214 1 r
.84129 .35778 m
.8421 .36679 L
s
.84213 .36674 m
.84129 .35778 L
s
.84129 .35778 m
.84302 .3759 L
s
.991 .169 1 r
.43023 .38178 m
.43054 .3721 L
s
.43054 .3721 m
.43031 .38132 L
s
.977 .171 1 r
.53921 .35781 m
.53922 .36737 L
s
.53925 .36733 m
.53921 .35781 L
s
.53921 .35781 m
.53932 .37664 L
s
.54 .272 1 r
.14344 .37991 m
.14336 .38006 L
s
.521 .277 1 r
.14788 .35452 m
.14691 .36293 L
s
.14692 .36289 m
.14788 .35452 L
s
.14788 .35452 m
.146 .37137 L
s
.917 .184 1 r
.75735 .37108 m
.758 .38056 L
s
.75803 .38011 m
.75735 .37108 L
s
.916 .184 1 r
.34661 .38551 m
.34653 .38585 L
s
.917 .184 1 r
.758 .38056 m
.75737 .37103 L
s
.75737 .37103 m
.75803 .38011 L
s
.559 .267 1 r
.70163 .31544 m
.70404 .35673 L
s
.904 .186 1 r
.39952 .31544 m
.39802 .36117 L
s
.638 .247 1 r
.09741 .31544 m
.0921 .35821 L
s
.658 .242 1 r
.20256 .36865 m
.2017 .37745 L
s
.20178 .3773 m
.20256 .36865 L
s
.516 1 .953 r
.66282 .35146 m
.66307 .35761 L
s
.6631 .3573 m
.66282 .35146 L
s
.699 .232 1 r
.85632 .36592 m
.85723 .37507 L
s
.85719 .37412 m
.85632 .36592 L
s
.811 .206 1 r
.69821 .38308 m
.69817 .38353 L
s
.516 1 .953 r
.66307 .35761 m
.66284 .35143 L
s
.66284 .35143 m
.6631 .3573 L
s
.658 .242 1 r
.2017 .37745 m
.20258 .3686 L
s
.20258 .3686 m
.20178 .3773 L
s
.608 .254 1 r
.31127 .35428 m
.31069 .36298 L
s
.31071 .36294 m
.31127 .35428 L
s
.31127 .35428 m
.3102 .37149 L
s
.699 .232 1 r
.85723 .37507 m
.85635 .36587 L
s
.85635 .36587 m
.85719 .37412 L
s
.744 .221 1 r
.44998 .35503 m
.44975 .3641 L
s
.44977 .36406 m
.44998 .35503 L
s
.44998 .35503 m
.44961 .37284 L
s
1 .141 .868 r
.8651 .3152 m
.87027 .36315 L
s
.639 .247 1 r
.56295 .3152 m
.56366 .35833 L
s
.638 .247 1 r
.2608 .3152 m
.25763 .35759 L
s
.777 .214 1 r
.80687 .36894 m
.80763 .37812 L
s
.80766 .37767 m
.80687 .36894 L
s
.701 .232 1 r
.5047 .36894 m
.50464 .37786 L
s
.5047 .37767 m
.5047 .36894 L
s
.67 .239 1 r
.8316 .36758 m
.83242 .37649 L
s
.83244 .37608 m
.8316 .36758 L
s
.777 .214 1 r
.80763 .37812 m
.80689 .3689 L
s
.80689 .3689 m
.80766 .37767 L
s
.701 .232 1 r
.50464 .37786 m
.50472 .36889 L
s
.50472 .36889 m
.5047 .37767 L
s
.67 .239 1 r
.83242 .37649 m
.83163 .36753 L
s
.83163 .36753 m
.83244 .37608 L
s
1 .151 .921 r
.5692 .37386 m
.56932 .38357 L
s
.56939 .38341 m
.5692 .37386 L
s
.416 .307 1 r
.52418 .35121 m
.52415 .35942 L
s
.52417 .35938 m
.52418 .35121 L
s
.52418 .35121 m
.5242 .36734 L
s
1 .151 .921 r
.56932 .38357 m
.56923 .37381 L
s
.56923 .37381 m
.56939 .38341 L
s
.345 .39 1 r
.73268 .37323 m
.73264 .37352 L
s
.777 .214 1 r
.72298 .38223 m
.72294 .38268 L
s
.711 .229 1 r
.75216 .35547 m
.75273 .3644 L
s
.75276 .36436 m
.75216 .35547 L
s
.75216 .35547 m
.75339 .37321 L
s
.744 .221 1 r
.61344 .35479 m
.61365 .36386 L
s
.61367 .36382 m
.61344 .35479 L
s
.61344 .35479 m
.61394 .3726 L
s
.68 .237 1 r
.7769 .35411 m
.77754 .36303 L
s
.77757 .36299 m
.7769 .35411 L
s
.7769 .35411 m
.77825 .37162 L
s
.352 .327 1 r
.6284 .36242 m
.62864 .37043 L
s
.62869 .3701 m
.6284 .36242 L
s
.66 .241 1 r
.72642 .31495 m
.7292 .35698 L
s
.733 .224 1 r
.42423 .31495 m
.42313 .35846 L
s
.395 .62 1 r
.12204 .31495 m
.11786 .3507 L
s
.352 .327 1 r
.62864 .37043 m
.62842 .36238 L
s
.62842 .36238 m
.62869 .3701 L
s
.68 .237 1 r
.63818 .35353 m
.63846 .36249 L
s
.63848 .36245 m
.63818 .35353 L
s
.63818 .35353 m
.6388 .37101 L
s
.39071 .36733 m
.39034 .37629 L
s
.39043 .37584 m
.39071 .36733 L
s
.39034 .37629 m
.39073 .36729 L
s
.39073 .36729 m
.39043 .37584 L
s
.904 .186 1 r
.58871 .3564 m
.58885 .36582 L
s
.58888 .36577 m
.58871 .3564 L
s
.58871 .3564 m
.58909 .37493 L
s
.588 .259 1 r
.41544 .36626 m
.41515 .37496 L
s
.41522 .37462 m
.41544 .36626 L
s
.589 .259 1 r
.11321 .36626 m
.11213 .37496 L
s
.11224 .37462 m
.11321 .36626 L
s
.754 .219 1 r
.88994 .3147 m
.89504 .35895 L
s
.649 .244 1 r
.58771 .3147 m
.58873 .3571 L
s
.744 .222 1 r
.28547 .3147 m
.28249 .35895 L
s
.744 .221 1 r
.44552 .38138 m
.44545 .38183 L
s
.588 .259 1 r
.41515 .37496 m
.41546 .36622 L
s
.41546 .36622 m
.41522 .37462 L
s
.589 .259 1 r
.11213 .37496 m
.11322 .36622 L
s
.11322 .36622 m
.11224 .37462 L
s
.744 .221 1 r
.69295 .36792 m
.6934 .37703 L
s
.69344 .37658 m
.69295 .36792 L
s
.6934 .37703 m
.69297 .36788 L
s
.69297 .36788 m
.69344 .37658 L
s
.669 .239 1 r
.33594 .35423 m
.33542 .36308 L
s
.33543 .36304 m
.33594 .35423 L
s
.33594 .35423 m
.33498 .37175 L
s
.467 .292 1 r
.36068 .35287 m
.36025 .36113 L
s
.36026 .36109 m
.36068 .35287 L
s
.36068 .35287 m
.35989 .36942 L
s
.68 .237 1 r
.25192 .36739 m
.25118 .37631 L
s
.25128 .37597 m
.25192 .36739 L
s
.19718 .35362 m
.19628 .36254 L
s
.19629 .3625 m
.19718 .35362 L
s
.19718 .35362 m
.19549 .37114 L
s
.75123 .31445 m
.75434 .35686 L
s
.598 .257 1 r
.44895 .31445 m
.44819 .35686 L
s
.744 .221 1 r
.14668 .31445 m
.14193 .35796 L
s
.68 .237 1 r
.25118 .37631 m
.25194 .36734 L
s
.25194 .36734 m
.25128 .37597 L
s
.599 .257 1 r
.51975 .37774 m
.51969 .37833 L
s
.88 .191 1 r
.55953 .38394 m
.55947 .38428 L
s
.476 .29 1 r
.30139 .36495 m
.30082 .37327 L
s
.30089 .37316 m
.30139 .36495 L
s
.30082 .37327 m
.30141 .36491 L
s
.30141 .36491 m
.30089 .37316 L
s
.68 .237 1 r
.61248 .3142 m
.61382 .35698 L
s
.744 .222 1 r
.31016 .3142 m
.30756 .35772 L
s
.669 .239 1 r
.16793 .3809 m
.16785 .38109 L
s
.788 .212 1 r
.22713 .36934 m
.2263 .37845 L
s
.22638 .37829 m
.22713 .36934 L
s
.2263 .37845 m
.22714 .36929 L
s
.22714 .36929 m
.22638 .37829 L
s
.777 .214 1 r
.80178 .35427 m
.8025 .36343 L
s
.80253 .36338 m
.80178 .35427 L
s
.80178 .35427 m
.80329 .37224 L
s
.811 .206 1 r
.74783 .38249 m
.74779 .38283 L
s
.531 .274 1 r
.46491 .36471 m
.46475 .37325 L
s
.46482 .37292 m
.46491 .36471 L
s
.76725 .36471 m
.76786 .37325 L
s
.7679 .37292 m
.76725 .36471 L
s
.45 .297 1 r
.48966 .36335 m
.48957 .37166 L
s
.48963 .37133 m
.48966 .36335 L
s
.531 .274 1 r
.46475 .37325 m
.46493 .36467 L
s
.46493 .36467 m
.46482 .37292 L
s
.76786 .37325 m
.76727 .36467 L
s
.76727 .36467 m
.7679 .37292 L
s
.659 .242 1 r
.17234 .35582 m
.1714 .3645 L
s
.17141 .36445 m
.17234 .35582 L
s
.17234 .35582 m
.1705 .37346 L
s
.45 .297 1 r
.48957 .37166 m
.48968 .36331 L
s
.48968 .36331 m
.48963 .37133 L
s
.811 .206 1 r
.49945 .35449 m
.49935 .36372 L
s
.49937 .36368 m
.49945 .35449 L
s
.49945 .35449 m
.49934 .37261 L
s
.559 .267 1 r
.54895 .35177 m
.54898 .3604 L
s
.549 .36036 m
.54895 .35177 L
s
.54895 .35177 m
.54909 .36869 L
s
.628 .249 1 r
.77604 .31395 m
.77944 .35599 L
s
.723 .226 1 r
.47369 .31395 m
.47325 .35636 L
s
.503 .282 1 r
.17134 .31395 m
.16713 .35525 L
s
.638 .247 1 r
.44015 .36637 m
.43992 .37518 L
s
.43999 .37488 m
.44015 .36637 L
s
.578 .262 1 r
.38539 .3526 m
.385 .36123 L
s
.38502 .36119 m
.38539 .3526 L
s
.38539 .3526 m
.3847 .36967 L
s
.638 .247 1 r
.43992 .37518 m
.44017 .36633 L
s
.44017 .36633 m
.43999 .37488 L
s
.777 .214 1 r
.91142 .38225 m
.91139 .38248 L
s
.433 .302 1 r
.59402 .37482 m
.59397 .37519 L
s
.628 .249 1 r
.13776 .36666 m
.13673 .3754 L
s
.13681 .37525 m
.13776 .36666 L
s
.869 .194 1 r
.63726 .3137 m
.639 .35834 L
s
.734 .224 1 r
.33487 .3137 m
.33261 .35686 L
s
.628 .249 1 r
.13673 .3754 m
.13777 .36662 L
s
.13777 .36662 m
.13681 .37525 L
s
.744 .221 1 r
.68778 .353 m
.68819 .36211 L
s
.68822 .36207 m
.68778 .353 L
s
.68778 .353 m
.68867 .37078 L
s
.589 .259 1 r
.57372 .35117 m
.57382 .35991 L
s
.57384 .35987 m
.57372 .35117 L
s
.57372 .35117 m
.57399 .36821 L
s
.638 .247 1 r
.22177 .35394 m
.22096 .36265 L
s
.22097 .3626 m
.22177 .35394 L
s
.22177 .35394 m
.22021 .37139 L
s
.579 .262 1 r
.24209 .37799 m
.242 .37829 L
s
.953 .176 1 r
.58431 .3842 m
.58425 .38454 L
s
.744 .222 1 r
.49499 .38079 m
.49493 .38113 L
s
.649 .244 1 r
.80087 .31346 m
.80462 .35587 L
s
.811 .206 1 r
.49844 .31346 m
.49831 .35772 L
s
.723 .226 1 r
.196 .31346 m
.19197 .35624 L
s
.467 .292 1 r
.51441 .36316 m
.51438 .37151 L
s
.51444 .37122 m
.51441 .36316 L
s
.51438 .37151 m
.51443 .36312 L
s
.51443 .36312 m
.51444 .37122 L
s
.335 .341 1 r
.48439 .3481 m
.48427 .35605 L
s
.48429 .35601 m
.48439 .3481 L
s
.48439 .3481 m
.48423 .36367 L
s
.522 .277 1 r
.13242 .35086 m
.1314 .35938 L
s
.13141 .35933 m
.13242 .35086 L
s
.13242 .35086 m
.13048 .3676 L
s
.711 .229 1 r
.60374 .36671 m
.60395 .37571 L
s
.604 .37537 m
.60374 .36671 L
s
.60395 .37571 m
.60376 .36667 L
s
.60376 .36667 m
.604 .37537 L
s
.423 .732 1 r
.41982 .3434 m
.41958 .35053 L
s
.41959 .3505 m
.41982 .3434 L
s
.41982 .3434 m
.41941 .35719 L
s
.494 .284 1 r
.71257 .35244 m
.71301 .36074 L
s
.71303 .3607 m
.71257 .35244 L
s
.71257 .35244 m
.71353 .36918 L
s
.559 .267 1 r
.66206 .31321 m
.66398 .35451 L
s
.628 .249 1 r
.35958 .31321 m
.35766 .356 L
s
.658 .242 1 r
.21728 .37994 m
.2172 .3801 L
s
.833 .201 1 r
.47023 .38274 m
.47016 .38294 L
s
.799 .209 1 r
.57898 .36837 m
.57912 .37752 L
s
.57918 .37733 m
.57898 .36837 L
s
.701 .232 1 r
.90623 .36701 m
.90724 .37593 L
s
.90728 .37574 m
.90623 .36701 L
s
.68 .237 1 r
.3809 .37933 m
.38082 .37967 L
s
.451 .837 1 r
.28095 .34291 m
.28043 .3497 L
s
.28045 .34967 m
.28095 .34291 L
s
.28095 .34291 m
.28 .35621 L
s
.55 .269 1 r
.65327 .36428 m
.6536 .37286 L
s
.65365 .37257 m
.65327 .36428 L
s
.777 .214 1 r
.33136 .38214 m
.33129 .38225 L
s
.799 .209 1 r
.57912 .37752 m
.57901 .36833 L
s
.57901 .36833 m
.57918 .37733 L
s
.701 .232 1 r
.90724 .37593 m
.90626 .36696 L
s
.90626 .36696 m
.90728 .37574 L
s
.55 .269 1 r
.6536 .37286 m
.6533 .36424 L
s
.6533 .36424 m
.65365 .37257 L
s
.846 .199 1 r
.79749 .38153 m
.79746 .38198 L
s
.55 .269 1 r
.27123 .35198 m
.27056 .3605 L
s
.27058 .36046 m
.27123 .35198 L
s
.27123 .35198 m
.26997 .36895 L
s
.799 .209 1 r
.74262 .36784 m
.74321 .37702 L
s
.74325 .37672 m
.74262 .36784 L
s
.74321 .37702 m
.74264 .36779 L
s
.74264 .36779 m
.74325 .37672 L
s
.368 .322 1 r
.64803 .348 m
.6483 .3561 L
s
.64832 .35606 m
.64803 .348 L
s
.64803 .348 m
.64863 .3638 L
s
.345 .389 1 r
.4003 .36184 m
.4 .3695 L
s
.40005 .36976 m
.4003 .36184 L
s
.494 .284 1 r
.82572 .31296 m
.82964 .3539 L
s
.649 .244 1 r
.5232 .31296 m
.5234 .35501 L
s
.733 .224 1 r
.22069 .31296 m
.21687 .35686 L
s
.345 .389 1 r
.4 .3695 m
.40031 .36181 L
s
.40031 .36181 m
.40005 .36976 L
s
.953 .176 1 r
.71787 .3695 m
.71841 .37902 L
s
.71846 .37868 m
.71787 .3695 L
s
.71841 .37902 m
.7179 .36945 L
s
.7179 .36945 m
.71846 .37868 L
s
.648 .244 1 r
.70817 .37849 m
.70813 .37882 L
s
.777 .214 1 r
.10757 .35306 m
.1064 .36221 L
s
.10641 .36217 m
.10757 .35306 L
s
.10757 .35306 m
.10535 .37103 L
s
.618 .252 1 r
.87627 .35238 m
.87715 .36109 L
s
.87718 .36105 m
.87627 .35238 L
s
.87627 .35238 m
.87811 .36968 L
s
.799 .209 1 r
.27646 .36896 m
.27577 .37804 L
s
.27584 .37807 m
.27646 .36896 L
s
.438 .79 1 r
.41003 .35312 m
.40978 .36009 L
s
.40984 .35962 m
.41003 .35312 L
s
.754 .219 1 r
.3561 .38129 m
.35603 .38144 L
s
.335 .34 1 r
.50915 .34761 m
.50909 .35556 L
s
.50911 .35553 m
.50915 .34761 L
s
.50915 .34761 m
.5091 .36319 L
s
.438 .79 1 r
.40978 .36009 m
.41004 .35308 L
s
.41004 .35308 m
.40984 .35962 L
s
.799 .209 1 r
.27577 .37804 m
.27647 .36892 L
s
.27647 .36892 m
.27584 .37807 L
s
.54 .272 1 r
.12786 .37727 m
.12778 .37742 L
s
.766 .217 1 r
.16233 .36706 m
.16133 .37617 L
s
.16143 .37587 m
.16233 .36706 L
s
.789 .211 1 r
.68342 .38007 m
.68338 .38056 L
s
.669 .239 1 r
.7922 .3657 m
.7929 .37458 L
s
.79294 .37428 m
.7922 .3657 L
s
.559 .267 1 r
.76217 .35055 m
.76275 .35918 L
s
.76278 .35914 m
.76217 .35055 L
s
.76217 .35055 m
.7634 .36748 L
s
.789 .211 1 r
.84709 .37946 m
.84708 .38006 L
s
.405 .662 1 r
.68687 .31271 m
.68874 .34737 L
s
.55 .269 1 r
.38431 .31271 m
.38276 .35402 L
s
.766 .217 1 r
.16133 .37617 m
.16234 .36702 L
s
.16234 .36702 m
.16143 .37587 L
s
.669 .239 1 r
.7929 .37458 m
.79222 .36565 L
s
.79222 .36565 m
.79294 .37428 L
s
.833 .201 1 r
.88156 .36925 m
.88253 .37841 L
s
.88259 .37844 m
.88156 .36925 L
s
.19243 .38226 m
.19234 .38246 L
s
.7 .232 1 r
.32598 .36652 m
.32544 .37545 L
s
.32551 .37526 m
.32598 .36652 L
s
.55 .269 1 r
.35074 .36516 m
.35029 .37363 L
s
.35035 .37367 m
.35074 .36516 L
s
.433 .302 1 r
.70285 .36243 m
.70328 .37064 L
s
.70333 .37049 m
.70285 .36243 L
s
.833 .201 1 r
.88253 .37841 m
.88159 .36921 L
s
.88159 .36921 m
.88259 .37844 L
s
.7 .232 1 r
.32544 .37545 m
.326 .36648 L
s
.326 .36648 m
.32551 .37526 L
s
.55 .269 1 r
.35029 .37363 m
.35076 .36512 L
s
.35076 .36512 m
.35035 .37367 L
s
.433 .302 1 r
.70328 .37064 m
.70287 .36239 L
s
.70287 .36239 m
.70333 .37049 L
s
.701 .232 1 r
.43485 .35217 m
.43458 .36114 L
s
.4346 .3611 m
.43485 .35217 L
s
.43485 .35217 m
.4344 .36981 L
s
.671 .239 1 r
.67811 .36409 m
.67851 .37308 L
s
.67854 .37245 m
.67811 .36409 L
s
.669 .239 1 r
.85057 .31246 m
.855 .35526 L
s
.977 .171 1 r
.54798 .31246 m
.54853 .35896 L
s
.822 .204 1 r
.24538 .31246 m
.2418 .35748 L
s
.671 .239 1 r
.67851 .37308 m
.67813 .36405 L
s
.67813 .36405 m
.67854 .37245 L
s
.569 .264 1 r
.89669 .3774 m
.89665 .37755 L
s
.618 .252 1 r
.3755 .36438 m
.3751 .37315 L
s
.37517 .37282 m
.3755 .36438 L
s
.342 .378 1 r
.47459 .35892 m
.47447 .36679 L
s
.47453 .36646 m
.47459 .35892 L
s
.618 .252 1 r
.3751 .37315 m
.37551 .36434 L
s
.37551 .36434 m
.37517 .37282 L
s
.342 .378 1 r
.47447 .36679 m
.47461 .35888 L
s
.47461 .35888 m
.47453 .36646 L
s
.722 .227 1 r
.18701 .36658 m
.18609 .37554 L
s
.18617 .37539 m
.18701 .36658 L
s
.68 .237 1 r
.45961 .35143 m
.45941 .36036 L
s
.45943 .36032 m
.45961 .35143 L
s
.45961 .35143 m
.45929 .36895 L
s
.522 .277 1 r
.8666 .36248 m
.86747 .37103 L
s
.86749 .37062 m
.8666 .36248 L
s
.559 .267 1 r
.78701 .35007 m
.78766 .3587 L
s
.78769 .35865 m
.78701 .35007 L
s
.78701 .35007 m
.78837 .36699 L
s
.416 .307 1 r
.89138 .36112 m
.89227 .36933 L
s
.8923 .36903 m
.89138 .36112 L
s
.916 .184 1 r
.65869 .38239 m
.65864 .38274 L
s
.608 .254 1 r
.26667 .37898 m
.26661 .37895 L
s
.669 .239 1 r
.71169 .31221 m
.71434 .35538 L
s
1 .133 .827 r
.40905 .31221 m
.4076 .36058 L
s
.337 .332 1 r
.10642 .31221 m
.10186 .34983 L
s
.711 .229 1 r
.87195 .37898 m
.87192 .37932 L
s
.722 .227 1 r
.18609 .37554 m
.18703 .36653 L
s
.18703 .36653 m
.18617 .37539 L
s
.522 .277 1 r
.86747 .37103 m
.86663 .36244 L
s
.86663 .36244 m
.86749 .37062 L
s
.416 .307 1 r
.89227 .36933 m
.8914 .36108 L
s
.8914 .36108 m
.8923 .36903 L
s
.869 .194 1 r
.8224 .38179 m
.82236 .38209 L
s
.679 .237 1 r
.90119 .35233 m
.90215 .36119 L
s
.90218 .36115 m
.90119 .35233 L
s
.90119 .35233 m
.90319 .36994 L
s
1 .136 .839 r
.85165 .35512 m
.85259 .3651 L
s
.85262 .36506 m
.85165 .35512 L
s
.85165 .35512 m
.85358 .3746 L
s
.822 .204 1 r
.54454 .38057 m
.54448 .38095 L
s
.618 .252 1 r
.45515 .37716 m
.45509 .37749 L
s
.1525 .37716 m
.1524 .37749 L
s
.416 .307 1 r
.36576 .37374 m
.3657 .37393 L
s
.733 .224 1 r
.29588 .35247 m
.29524 .36148 L
s
.29526 .36144 m
.29588 .35247 L
s
.29588 .35247 m
.29469 .3703 L
s
.516 1 .953 r
.6631 .3573 m
.66307 .35761 L
s
.503 .282 1 r
.42503 .36224 m
.42477 .37071 L
s
.42484 .37038 m
.42503 .36224 L
s
.953 .176 1 r
.87544 .31196 m
.88052 .35773 L
s
.467 .292 1 r
.57277 .31196 m
.57356 .35254 L
s
.754 .219 1 r
.27009 .31196 m
.2669 .35625 L
s
.503 .282 1 r
.42477 .37071 m
.42505 .3622 L
s
.42505 .3622 m
.42484 .37038 L
s
.569 .264 1 r
.61888 .37692 m
.61883 .37707 L
s
.531 .274 1 r
.72772 .36253 m
.72823 .37108 L
s
.72827 .37075 m
.72772 .36253 L
s
.87 .194 1 r
.24629 .35564 m
.2455 .36481 L
s
.24551 .36477 m
.24629 .35564 L
s
.24629 .35564 m
.24476 .37423 L
s
.531 .274 1 r
.72823 .37108 m
.72775 .36249 L
s
.72775 .36249 m
.72827 .37075 L
s
.35 .414 1 r
.5835 .34538 m
.58361 .35322 L
s
.58363 .35318 m
.5835 .34538 L
s
.5835 .34538 m
.58379 .36062 L
s
.953 .176 1 r
.73753 .35367 m
.7381 .3632 L
s
.73813 .36315 m
.73753 .35367 L
s
.73753 .35367 m
.73875 .3724 L
s
.629 .249 1 r
.56399 .36336 m
.56408 .37221 L
s
.56414 .37172 m
.56399 .36336 L
s
.608 .254 1 r
.73652 .31171 m
.73945 .35415 L
s
.811 .206 1 r
.43381 .31171 m
.43281 .356 L
s
.628 .249 1 r
.13109 .31171 m
.12621 .35452 L
s
.629 .249 1 r
.56408 .37221 m
.56401 .36332 L
s
.56401 .36332 m
.56414 .37172 L
s
.521 .277 1 r
.12229 .36282 m
.12125 .3713 L
s
.12134 .37111 m
.12229 .36282 L
s
.754 .219 1 r
.15687 .35249 m
.15584 .36153 L
s
.15586 .36149 m
.15687 .35249 L
s
.15687 .35249 m
.15491 .37043 L
s
.588 .259 1 r
.31616 .37729 m
.31609 .3774 L
s
.521 .277 1 r
.12125 .3713 m
.1223 .36278 L
s
.1223 .36278 m
.12134 .37111 L
s
.531 .274 1 r
.67292 .34912 m
.67327 .35767 L
s
.67329 .35763 m
.67292 .34912 L
s
.67292 .34912 m
.67368 .36589 L
s
.766 .216 1 r
.32062 .35188 m
.32003 .361 L
s
.32005 .36096 m
.32062 .35188 L
s
.32062 .35188 m
.31955 .36982 L
s
.754 .219 1 r
.21168 .36639 m
.21082 .37543 L
s
.2109 .37527 m
.21168 .36639 L
s
.21082 .37543 m
.2117 .36634 L
s
.2117 .36634 m
.2109 .37527 L
s
.433 .302 1 r
.55428 .37266 m
.55422 .37302 L
s
.679 .237 1 r
.29136 .37887 m
.29129 .37899 L
s
.811 .206 1 r
.59757 .31146 m
.59877 .35575 L
s
.352 .426 1 r
.29481 .31146 m
.29236 .34946 L
s
.61 .254 1 r
.66849 .37485 m
.66845 .37548 L
s
.845 .199 1 r
.81718 .36668 m
.81799 .37598 L
s
.81802 .37564 m
.81718 .36668 L
s
.69 .234 1 r
.23644 .36531 m
.23566 .37421 L
s
.23574 .37405 m
.23644 .36531 L
s
.845 .199 1 r
.81799 .37598 m
.81721 .36664 L
s
.81721 .36664 m
.81802 .37564 L
s
.69 .234 1 r
.23566 .37421 m
.23646 .36527 L
s
.23646 .36527 m
.23574 .37405 L
s
1 .156 .946 r
.59859 .35378 m
.59877 .36354 L
s
.5988 .3635 m
.59859 .35378 L
s
.59859 .35378 m
.59904 .37289 L
s
.712 .229 1 r
.81194 .35034 m
.81269 .35938 L
s
.81272 .35934 m
.81194 .35034 L
s
.81194 .35034 m
.81349 .36798 L
s
.335 .34 1 r
.82693 .35795 m
.82765 .36593 L
s
.82767 .36549 m
.82693 .35795 L
s
.788 .212 1 r
.62337 .35246 m
.62361 .36159 L
s
.62363 .36154 m
.62337 .35246 L
s
.62337 .35246 m
.62393 .37056 L
s
.335 .34 1 r
.82765 .36593 m
.82696 .35791 L
s
.82696 .35791 m
.82767 .36549 L
s
.4 .312 1 r
.72252 .34705 m
.72298 .35523 L
s
.723 .35519 m
.72252 .34705 L
s
.72252 .34705 m
.7235 .36308 L
s
.648 .244 1 r
.76137 .31121 m
.76462 .35365 L
s
1 .156 .946 r
.45858 .31121 m
.45788 .35773 L
s
.467 .292 1 r
.15578 .31121 m
.15137 .35254 L
s
.68 .237 1 r
.78272 .37741 m
.78269 .37775 L
s
.754 .219 1 r
.18156 .352 m
.18061 .36105 L
s
.18062 .361 m
.18156 .352 L
s
.18156 .352 m
.17974 .36995 L
s
.648 .244 1 r
.64372 .3768 m
.64367 .37714 L
s
.34091 .3768 m
.34082 .37714 L
s
.589 .259 1 r
.39494 .34874 m
.39457 .35748 L
s
.39459 .35744 m
.39494 .34874 L
s
.39494 .34874 m
.3943 .36578 L
s
.712 .229 1 r
.62238 .31097 m
.62387 .35378 L
s
.628 .249 1 r
.31955 .31097 m
.3171 .35378 L
s
.658 .242 1 r
.17707 .37778 m
.17699 .37793 L
s
.659 .242 1 r
.53395 .34971 m
.53395 .3586 L
s
.53397 .35856 m
.53395 .34971 L
s
.53395 .34971 m
.53402 .36713 L
s
.521 .277 1 r
.14691 .36293 m
.14594 .37133 L
s
.146 .37137 m
.14691 .36293 L
s
.14594 .37133 m
.14692 .36289 L
s
.14692 .36289 m
.146 .37137 L
s
.788 .212 1 r
.34533 .35197 m
.34481 .3611 L
s
.34483 .36106 m
.34533 .35197 L
s
.34533 .35197 m
.34438 .37007 L
s
.441 .3 1 r
.11684 .34785 m
.11581 .35611 L
s
.11582 .35607 m
.11684 .34785 L
s
.11684 .34785 m
.11486 .36418 L
s
.777 .214 1 r
.26114 .36512 m
.26041 .37428 L
s
.2605 .37394 m
.26114 .36512 L
s
.638 .247 1 r
.28593 .36376 m
.2853 .37254 L
s
.28537 .37235 m
.28593 .36376 L
s
1 .149 .908 r
.78624 .31072 m
.79029 .3591 L
s
.711 .229 1 r
.48336 .31072 m
.48304 .3539 L
s
1 0 0 r
.18048 .31072 m
.1749 .36692 L
s
.777 .214 1 r
.26041 .37428 m
.26116 .36508 L
s
.26116 .36508 m
.2605 .37394 L
s
.638 .247 1 r
.2853 .37254 m
.28595 .36371 L
s
.28595 .36371 m
.28537 .37235 L
s
.699 .232 1 r
.85719 .37412 m
.85723 .37507 L
s
.352 .327 1 r
.62869 .3701 m
.62864 .37043 L
s
.779 .214 1 r
.8421 .36679 m
.84295 .3758 L
s
.84302 .3759 m
.8421 .36679 L
s
.84295 .3758 m
.84213 .36674 L
s
.84213 .36674 m
.84302 .3759 L
s
.991 .169 1 r
.43031 .38132 m
.43023 .38178 L
s
.766 .216 1 r
.20624 .3518 m
.20535 .36086 L
s
.20537 .36081 m
.20624 .3518 L
s
.20624 .3518 m
.20455 .36983 L
s
.416 .307 1 r
.52415 .35942 m
.52415 .36763 L
s
.5242 .36734 m
.52415 .35942 L
s
.45 .297 1 r
.74741 .34699 m
.74793 .35533 L
s
.74796 .35529 m
.74741 .34699 L
s
.74741 .34699 m
.74852 .36333 L
s
.869 .194 1 r
.64721 .31047 m
.6491 .35551 L
s
.559 .267 1 r
.3443 .31047 m
.34225 .3518 L
s
.658 .242 1 r
.20178 .3773 m
.2017 .37745 L
s
.357 .451 1 r
.797 .34427 m
.79761 .352 L
s
.79763 .35196 m
.797 .34427 L
s
.797 .34427 m
.79826 .3594 L
s
.416 .307 1 r
.52415 .36763 m
.52417 .35938 L
s
.52417 .35938 m
.5242 .36734 L
s
.917 .184 1 r
.75803 .38011 m
.758 .38056 L
s
.679 .237 1 r
.37009 .35119 m
.36966 .36002 L
s
.36967 .35998 m
.37009 .35119 L
s
.37009 .35119 m
.3693 .36885 L
s
.608 .254 1 r
.31069 .36298 m
.31012 .37168 L
s
.3102 .37149 m
.31069 .36298 L
s
.67 .239 1 r
.83244 .37608 m
.83242 .37649 L
s
.608 .254 1 r
.31012 .37168 m
.31071 .36294 L
s
.31071 .36294 m
.3102 .37149 L
s
.711 .229 1 r
.69783 .34994 m
.69826 .35895 L
s
.69829 .3589 m
.69783 .34994 L
s
.69783 .34994 m
.69877 .36762 L
s
.649 .244 1 r
.25583 .34925 m
.25509 .35811 L
s
.2551 .35807 m
.25583 .34925 L
s
.25583 .34925 m
.25445 .36664 L
s
.638 .247 1 r
.23101 .35077 m
.23022 .35948 L
s
.23023 .35944 m
.23101 .35077 L
s
.23101 .35077 m
.2295 .36823 L
s
.977 .171 1 r
.53922 .36737 m
.53926 .37694 L
s
.53932 .37664 m
.53922 .36737 L
s
.777 .214 1 r
.80766 .37767 m
.80763 .37812 L
s
.701 .232 1 r
.5047 .37767 m
.50464 .37786 L
s
.977 .171 1 r
.53926 .37694 m
.53925 .36733 L
s
.53925 .36733 m
.53932 .37664 L
s
.375 .32 1 r
.81111 .31022 m
.81472 .3497 L
s
.512 .279 1 r
.50815 .31022 m
.50815 .35155 L
s
.619 .252 1 r
.2052 .31022 m
.20131 .35266 L
s
.744 .221 1 r
.44975 .3641 m
.44954 .37318 L
s
.44961 .37284 m
.44975 .3641 L
s
.44954 .37318 m
.44977 .36406 L
s
.44977 .36406 m
.44961 .37284 L
s
.68 .237 1 r
.39043 .37584 m
.39034 .37629 L
s
.588 .259 1 r
.41522 .37462 m
.41515 .37496 L
s
.589 .259 1 r
.11224 .37462 m
.11213 .37496 L
s
.357 .45 1 r
.65797 .34435 m
.65825 .35205 L
s
.65828 .35201 m
.65797 .34435 L
s
.65797 .34435 m
.6586 .35953 L
s
.711 .229 1 r
.75273 .3644 m
.75333 .37333 L
s
.75339 .37321 m
.75273 .3644 L
s
.68 .237 1 r
.77754 .36303 m
.77821 .37196 L
s
.77825 .37162 m
.77754 .36303 L
s
.845 .199 1 r
.67206 .30997 m
.67427 .35464 L
s
.777 .214 1 r
.36906 .30997 m
.36721 .3539 L
s
.711 .229 1 r
.75333 .37333 m
.75276 .36436 L
s
.75276 .36436 m
.75339 .37321 L
s
.68 .237 1 r
.77821 .37196 m
.77757 .36299 L
s
.77757 .36299 m
.77825 .37162 L
s
.744 .221 1 r
.61365 .36386 m
.61388 .37294 L
s
.61394 .3726 m
.61365 .36386 L
s
.68 .237 1 r
.63846 .36249 m
.63875 .37146 L
s
.6388 .37101 m
.63846 .36249 L
s
.467 .292 1 r
.36025 .36113 m
.35983 .36938 L
s
.35989 .36942 m
.36025 .36113 L
s
.744 .221 1 r
.61388 .37294 m
.61367 .36382 L
s
.61367 .36382 m
.61394 .3726 L
s
.68 .237 1 r
.63875 .37146 m
.63848 .36245 L
s
.63848 .36245 m
.6388 .37101 L
s
.467 .292 1 r
.35983 .36938 m
.36026 .36109 L
s
.36026 .36109 m
.35989 .36942 L
s
.569 .264 1 r
.86178 .35021 m
.8626 .3587 L
s
.86263 .35866 m
.86178 .35021 L
s
.86178 .35021 m
.86353 .36738 L
s
1 .151 .921 r
.56939 .38341 m
.56932 .38357 L
s
.4 .312 1 r
.49408 .34558 m
.49398 .35376 L
s
.494 .35372 m
.49408 .34558 L
s
.49408 .34558 m
.49396 .36161 L
s
1 .062 .414 r
.836 .30972 m
.84099 .35997 L
s
.365 .485 1 r
.53296 .30972 m
.53324 .34588 L
s
.54 .272 1 r
.22993 .30972 m
.22641 .35143 L
s
.744 .221 1 r
.69344 .37658 m
.6934 .37703 L
s
.476 .29 1 r
.30089 .37316 m
.30082 .37327 L
s
.68 .237 1 r
.25128 .37597 m
.25118 .37631 L
s
.578 .262 1 r
.14142 .34845 m
.1404 .35709 L
s
.14041 .35705 m
.14142 .34845 L
s
.14142 .34845 m
.13948 .36554 L
s
.904 .186 1 r
.58885 .36582 m
.58903 .37524 L
s
.58909 .37493 m
.58885 .36582 L
s
.669 .239 1 r
.33542 .36308 m
.3349 .37194 L
s
.33498 .37175 m
.33542 .36308 L
s
.45 .297 1 r
.48963 .37133 m
.48957 .37166 L
s
.544 .271 1 r
.51891 .3445 m
.51886 .35327 L
s
.51888 .35323 m
.51891 .3445 L
s
.51891 .3445 m
.5189 .36113 L
s
.904 .186 1 r
.58903 .37524 m
.58888 .36577 L
s
.58888 .36577 m
.58909 .37493 L
s
.669 .239 1 r
.3349 .37194 m
.33543 .36304 L
s
.33543 .36304 m
.33498 .37175 L
s
.68 .237 1 r
.19628 .36254 m
.19539 .37147 L
s
.19549 .37114 m
.19628 .36254 L
s
.618 .252 1 r
.30533 .34806 m
.30473 .35684 L
s
.30474 .3568 m
.30533 .34806 L
s
.30533 .34806 m
.30422 .3653 L
s
.846 .199 1 r
.69691 .30947 m
.69944 .35378 L
s
.424 .305 1 r
.39383 .30947 m
.39244 .3497 L
s
.55 .269 1 r
.09075 .30947 m
.08544 .35155 L
s
.68 .237 1 r
.19539 .37147 m
.19629 .3625 L
s
.19629 .3625 m
.19549 .37114 L
s
.531 .274 1 r
.46482 .37292 m
.46475 .37325 L
s
.7679 .37292 m
.76786 .37325 L
s
.953 .176 1 r
.83706 .35237 m
.83791 .36184 L
s
.83794 .3618 m
.83706 .35237 L
s
.83706 .35237 m
.83884 .3712 L
s
.916 .184 1 r
.55879 .35101 m
.55886 .36047 L
s
.55888 .36042 m
.55879 .35101 L
s
.55879 .35101 m
.559 .3696 L
s
.451 .837 1 r
.28043 .3497 m
.27993 .35649 L
s
.28 .35621 m
.28043 .3497 L
s
.27993 .35649 m
.28045 .34967 L
s
.28045 .34967 m
.28 .35621 L
s
.423 .732 1 r
.41958 .35053 m
.41934 .35766 L
s
.41941 .35719 m
.41958 .35053 L
s
.41934 .35766 m
.41959 .3505 L
s
.41959 .3505 m
.41941 .35719 L
s
.418 .307 1 r
.8609 .30922 m
.86501 .3476 L
s
.744 .221 1 r
.55778 .30922 m
.55844 .35279 L
s
.892 .189 1 r
.25467 .30922 m
.25115 .35502 L
s
.659 .242 1 r
.1714 .3645 m
.17047 .37317 L
s
.1705 .37346 m
.1714 .3645 L
s
.438 .79 1 r
.40984 .35962 m
.40978 .36009 L
s
.559 .267 1 r
.54898 .3604 m
.54904 .36903 L
s
.54909 .36869 m
.54898 .3604 L
s
.788 .212 1 r
.22638 .37829 m
.2263 .37845 L
s
.659 .242 1 r
.17047 .37317 m
.17141 .36445 L
s
.17141 .36445 m
.1705 .37346 L
s
.638 .247 1 r
.43999 .37488 m
.43992 .37518 L
s
.559 .267 1 r
.54904 .36903 m
.549 .36036 L
s
.549 .36036 m
.54909 .36869 L
s
.588 .259 1 r
.63324 .34735 m
.63349 .35606 L
s
.63352 .35602 m
.63324 .34735 L
s
.63324 .34735 m
.63382 .36444 L
s
.578 .262 1 r
.385 .36123 m
.38463 .36986 L
s
.3847 .36967 m
.385 .36123 L
s
.38463 .36986 m
.38502 .36119 L
s
.38502 .36119 m
.3847 .36967 L
s
.598 .257 1 r
.16611 .34822 m
.16515 .35689 L
s
.16517 .35685 m
.16611 .34822 L
s
.16611 .34822 m
.16428 .36542 L
s
.777 .214 1 r
.8025 .36343 m
.80326 .37258 L
s
.80329 .37224 m
.8025 .36343 L
s
.588 .259 1 r
.72178 .30897 m
.72452 .35143 L
s
.467 .292 1 r
.41862 .30897 m
.41752 .34957 L
s
.578 .262 1 r
.11546 .30897 m
.11046 .35106 L
s
.777 .214 1 r
.80326 .37258 m
.80253 .36338 L
s
.80253 .36338 m
.80329 .37224 L
s
.628 .249 1 r
.13681 .37525 m
.13673 .3754 L
s
.335 .341 1 r
.48427 .35605 m
.48417 .364 L
s
.48423 .36367 m
.48427 .35605 L
s
.845 .199 1 r
.44445 .34984 m
.44419 .35915 L
s
.44421 .3591 m
.44445 .34984 L
s
.44445 .34984 m
.44403 .36813 L
s
.467 .292 1 r
.51444 .37122 m
.51438 .37151 L
s
.335 .341 1 r
.48417 .364 m
.48429 .35601 L
s
.48429 .35601 m
.48423 .36367 L
s
.811 .206 1 r
.49935 .36372 m
.49927 .37295 L
s
.49934 .37261 m
.49935 .36372 L
s
.691 .234 1 r
.77244 .34854 m
.77307 .35748 L
s
.7731 .35744 m
.77244 .34854 L
s
.77244 .34854 m
.77377 .36616 L
s
.811 .206 1 r
.49927 .37295 m
.49937 .36368 L
s
.49937 .36368 m
.49934 .37261 L
s
.711 .229 1 r
.88582 .30872 m
.89075 .35192 L
s
.531 .274 1 r
.58262 .30872 m
.58354 .34933 L
s
.892 .189 1 r
.27942 .30872 m
.27625 .35452 L
s
.638 .247 1 r
.22096 .36265 m
.22015 .37136 L
s
.22021 .37139 m
.22096 .36265 L
s
.589 .259 1 r
.57382 .35991 m
.57394 .36865 L
s
.57399 .36821 m
.57382 .35991 L
s
.345 .389 1 r
.40005 .36976 m
.4 .3695 L
s
.638 .247 1 r
.22015 .37136 m
.22097 .3626 L
s
.22097 .3626 m
.22021 .37139 L
s
.589 .259 1 r
.57394 .36865 m
.57384 .35987 L
s
.57384 .35987 m
.57399 .36821 L
s
.744 .221 1 r
.68819 .36211 m
.68863 .37123 L
s
.68867 .37078 m
.68819 .36211 L
s
.494 .284 1 r
.71301 .36074 m
.71347 .36904 L
s
.71353 .36918 m
.71301 .36074 L
s
.522 .277 1 r
.1314 .35938 m
.13038 .36789 L
s
.13048 .3676 m
.1314 .35938 L
s
.94 .179 1 r
.88686 .3511 m
.88785 .36057 L
s
.88788 .36053 m
.88686 .3511 L
s
.88686 .3511 m
.88891 .36985 L
s
.744 .221 1 r
.68863 .37123 m
.68822 .36207 L
s
.68822 .36207 m
.68867 .37078 L
s
.494 .284 1 r
.71347 .36904 m
.71303 .3607 L
s
.71303 .3607 m
.71353 .36918 L
s
.522 .277 1 r
.13038 .36789 m
.13141 .35933 L
s
.13141 .35933 m
.13048 .3676 L
s
.55 .269 1 r
.65365 .37257 m
.6536 .37286 L
s
.368 .322 1 r
.6483 .3561 m
.64859 .3642 L
s
.64863 .3638 m
.6483 .3561 L
s
.503 .282 1 r
.74666 .30847 m
.74959 .34908 L
s
.94 .179 1 r
.44342 .30847 m
.44252 .35427 L
s
.598 .257 1 r
.14018 .30847 m
.13545 .35093 L
s
.711 .229 1 r
.604 .37537 m
.60395 .37571 L
s
.368 .322 1 r
.64859 .3642 m
.64832 .35606 L
s
.64832 .35606 m
.64863 .3638 L
s
.335 .34 1 r
.50909 .35556 m
.50905 .36352 L
s
.5091 .36319 m
.50909 .35556 L
s
.916 .184 1 r
.60847 .35003 m
.60867 .35949 L
s
.6087 .35945 m
.60847 .35003 L
s
.60847 .35003 m
.60896 .36862 L
s
.834 .201 1 r
.46925 .34938 m
.46907 .35866 L
s
.46909 .35862 m
.46925 .34938 L
s
.46925 .34938 m
.46897 .36764 L
s
.424 .305 1 r
.70777 .34457 m
.70819 .35283 L
s
.70821 .35279 m
.70777 .34457 L
s
.70777 .34457 m
.70868 .36076 L
s
.335 .34 1 r
.50905 .36352 m
.50911 .35553 L
s
.50911 .35553 m
.5091 .36319 L
s
.55 .269 1 r
.27056 .3605 m
.2699 .36902 L
s
.26997 .36895 m
.27056 .3605 L
s
.2699 .36902 m
.27058 .36046 L
s
.27058 .36046 m
.26997 .36895 L
s
.701 .232 1 r
.90728 .37574 m
.90724 .37593 L
s
.365 .486 1 r
.60747 .30822 m
.60857 .34476 L
s
.744 .222 1 r
.30419 .30822 m
.3015 .3518 L
s
.799 .209 1 r
.57918 .37733 m
.57912 .37752 L
s
.845 .199 1 r
.33002 .3491 m
.32945 .35842 L
s
.32946 .35837 m
.33002 .3491 L
s
.33002 .3491 m
.32898 .3674 L
s
.433 .302 1 r
.70333 .37049 m
.70328 .37064 L
s
.799 .209 1 r
.74325 .37672 m
.74321 .37702 L
s
.342 .378 1 r
.47453 .36646 m
.47447 .36679 L
s
.658 .242 1 r
.35483 .34792 m
.35435 .35675 L
s
.35437 .35671 m
.35483 .34792 L
s
.35483 .34792 m
.35396 .36543 L
s
.618 .252 1 r
.87715 .36109 m
.87806 .3698 L
s
.87811 .36968 m
.87715 .36109 L
s
.711 .229 1 r
.77155 .30797 m
.775 .35118 L
s
.638 .247 1 r
.46824 .30797 m
.46772 .35044 L
s
.578 .262 1 r
.16492 .30797 m
.16046 .35081 L
s
.618 .252 1 r
.87806 .3698 m
.87718 .36105 L
s
.87718 .36105 m
.87811 .36968 L
s
.669 .239 1 r
.79294 .37428 m
.7929 .37458 L
s
.559 .267 1 r
.76275 .35918 m
.76336 .36781 L
s
.7634 .36748 m
.76275 .35918 L
s
.55 .269 1 r
.35035 .37367 m
.35029 .37363 L
s
.559 .267 1 r
.76336 .36781 m
.76278 .35914 L
s
.76278 .35914 m
.7634 .36748 L
s
.766 .217 1 r
.16143 .37587 m
.16133 .37617 L
s
.671 .239 1 r
.67854 .37245 m
.67851 .37308 L
s
.953 .176 1 r
.71846 .37868 m
.71841 .37902 L
s
.416 .307 1 r
.8923 .36903 m
.89227 .36933 L
s
.7 .232 1 r
.32551 .37526 m
.32544 .37545 L
s
.777 .214 1 r
.1064 .36221 m
.10524 .37137 L
s
.10535 .37103 m
.1064 .36221 L
s
.799 .209 1 r
.27584 .37807 m
.27577 .37804 L
s
.722 .227 1 r
.63233 .30772 m
.63395 .35093 L
s
.711 .229 1 r
.32897 .30772 m
.32658 .35168 L
s
.777 .214 1 r
.10524 .37137 m
.10641 .36217 L
s
.10641 .36217 m
.10535 .37103 L
s
.833 .201 1 r
.1907 .34922 m
.18975 .35847 L
s
.18977 .35842 m
.1907 .34922 L
s
.1907 .34922 m
.1889 .36752 L
s
.522 .277 1 r
.86749 .37062 m
.86747 .37103 L
s
.628 .249 1 r
.37963 .34721 m
.37923 .35597 L
s
.37924 .35593 m
.37963 .34721 L
s
.37963 .34721 m
.3789 .36457 L
s
.476 .29 1 r
.42931 .34452 m
.42904 .35293 L
s
.42906 .35289 m
.42931 .34452 L
s
.42931 .34452 m
.42886 .36101 L
s
.701 .232 1 r
.43458 .36114 m
.43433 .37011 L
s
.4344 .36981 m
.43458 .36114 L
s
.859 .196 1 r
.8223 .348 m
.8231 .35739 L
s
.82313 .35734 m
.8223 .348 L
s
.8223 .348 m
.82395 .36629 L
s
.618 .252 1 r
.37517 .37282 m
.3751 .37315 L
s
.701 .232 1 r
.43433 .37011 m
.4346 .3611 L
s
.4346 .3611 m
.4344 .36981 L
s
.833 .201 1 r
.88259 .37844 m
.88253 .37841 L
s
.965 .174 1 r
.79646 .30747 m
.80046 .35329 L
s
.335 .34 1 r
.49306 .30747 m
.49289 .3455 L
s
.569 .264 1 r
.18966 .30747 m
.1856 .34957 L
s
.589 .259 1 r
.10105 .34621 m
.09993 .35489 L
s
.09994 .35484 m
.10105 .34621 L
s
.10105 .34621 m
.0989 .36334 L
s
.559 .267 1 r
.78766 .3587 m
.78834 .36733 L
s
.78837 .36699 m
.78766 .3587 L
s
.503 .282 1 r
.42484 .37038 m
.42477 .37071 L
s
.35 .414 1 r
.58361 .35322 m
.58374 .36106 L
s
.58379 .36062 m
.58361 .35322 L
s
.559 .267 1 r
.78834 .36733 m
.78769 .35865 L
s
.78769 .35865 m
.78837 .36699 L
s
.42 .722 1 r
.55349 .33805 m
.55352 .34519 L
s
.55354 .34515 m
.55349 .33805 L
s
.55349 .33805 m
.55363 .35193 L
s
.35 .414 1 r
.58374 .36106 m
.58363 .35318 L
s
.58363 .35318 m
.58379 .36062 L
s
.722 .227 1 r
.18617 .37539 m
.18609 .37554 L
s
.799 .209 1 r
.21548 .34851 m
.21461 .35768 L
s
.21462 .35764 m
.21548 .34851 L
s
.21548 .34851 m
.21382 .36667 L
s
.68 .237 1 r
.45941 .36036 m
.45922 .36929 L
s
.45929 .36895 m
.45941 .36036 L
s
.618 .252 1 r
.56859 .34585 m
.56868 .35464 L
s
.5687 .3546 m
.56859 .34585 L
s
.56859 .34585 m
.56884 .3631 L
s
.744 .221 1 r
.6572 .30722 m
.65917 .35081 L
s
.845 .199 1 r
.35376 .30722 m
.35167 .35192 L
s
.494 .284 1 r
.59343 .34453 m
.59357 .35298 L
s
.5936 .35294 m
.59343 .34453 L
s
.59343 .34453 m
.59379 .36114 L
s
.68 .237 1 r
.45922 .36929 m
.45943 .36032 L
s
.45943 .36032 m
.45929 .36895 L
s
.531 .274 1 r
.72827 .37075 m
.72823 .37108 L
s
.618 .252 1 r
.12584 .34528 m
.12477 .35411 L
s
.12478 .35406 m
.12584 .34528 L
s
.12584 .34528 m
.12381 .36249 L
s
.679 .237 1 r
.90215 .36119 m
.90315 .37005 L
s
.90319 .36994 m
.90215 .36119 L
s
.90315 .37005 m
.90218 .36115 L
s
.90218 .36115 m
.90319 .36994 L
s
.648 .244 1 r
.87205 .34607 m
.87294 .35494 L
s
.87297 .3549 m
.87205 .34607 L
s
.87205 .34607 m
.87389 .36347 L
s
.335 .34 1 r
.82767 .36549 m
.82765 .36593 L
s
.629 .249 1 r
.56414 .37172 m
.56408 .37221 L
s
.733 .224 1 r
.29524 .36148 m
.29461 .3705 L
s
.29469 .3703 m
.29524 .36148 L
s
.521 .277 1 r
.12134 .37111 m
.12125 .3713 L
s
.952 .176 1 r
.82138 .30697 m
.82583 .3539 L
s
.561 .266 1 r
.5179 .30697 m
.51803 .34722 L
s
.618 .252 1 r
.21442 .30697 m
.21061 .34982 L
s
.733 .224 1 r
.29461 .3705 m
.29526 .36144 L
s
.29526 .36144 m
.29469 .3703 L
s
.531 .274 1 r
.75762 .34446 m
.75819 .35303 L
s
.75821 .35299 m
.75762 .34446 L
s
.75762 .34446 m
.75882 .36126 L
s
.67327 .35767 m
.67364 .36623 L
s
.67368 .36589 m
.67327 .35767 L
s
.777 .214 1 r
.68308 .34867 m
.68348 .35773 L
s
.68351 .35769 m
.68308 .34867 L
s
.68308 .34867 m
.68397 .36679 L
s
.531 .274 1 r
.67364 .36623 m
.67329 .35763 L
s
.67329 .35763 m
.67368 .36589 L
s
.4 .312 1 r
.64315 .34263 m
.64341 .35082 L
s
.64343 .35078 m
.64315 .34263 L
s
.64315 .34263 m
.64374 .35868 L
s
.69 .234 1 r
.68209 .30672 m
.68438 .35031 L
s
.608 .254 1 r
.37857 .30672 m
.37691 .34883 L
s
.659 .242 1 r
.84727 .34818 m
.84808 .3569 L
s
.84811 .35686 m
.84727 .34818 L
s
.84727 .34818 m
.849 .36581 L
s
.87 .194 1 r
.2455 .36481 m
.24472 .37399 L
s
.24476 .37423 m
.2455 .36481 L
s
.24472 .37399 m
.24551 .36477 L
s
.24551 .36477 m
.24476 .37423 L
s
.4 .312 1 r
.72298 .35523 m
.72346 .36341 L
s
.7235 .36308 m
.72298 .35523 L
s
.72346 .36341 m
.723 .35519 L
s
.723 .35519 m
.7235 .36308 L
s
.754 .219 1 r
.2109 .37527 m
.21082 .37543 L
s
.638 .247 1 r
.28992 .34562 m
.28927 .35445 L
s
.28929 .35441 m
.28992 .34562 L
s
.28992 .34562 m
.28872 .36298 L
s
.754 .219 1 r
.15584 .36153 m
.15483 .37059 L
s
.15491 .37043 m
.15584 .36153 L
s
.15483 .37059 m
.15586 .36149 L
s
.15586 .36149 m
.15491 .37043 L
s
1 .136 .839 r
.85259 .3651 m
.85357 .3751 L
s
.85358 .3746 m
.85259 .3651 L
s
.766 .216 1 r
.32003 .361 m
.31946 .37013 L
s
.31955 .36982 m
.32003 .361 L
s
.69 .234 1 r
.23574 .37405 m
.23566 .37421 L
s
1 .136 .839 r
.85357 .3751 m
.85262 .36506 L
s
.85262 .36506 m
.85358 .3746 L
s
.733 .224 1 r
.73282 .34652 m
.73335 .35558 L
s
.73338 .35554 m
.73282 .34652 L
s
.73282 .34652 m
.73395 .36434 L
s
.702 .231 1 r
.84632 .30647 m
.85064 .34858 L
s
.649 .244 1 r
.54276 .30647 m
.5432 .34895 L
s
.55 .269 1 r
.23919 .30647 m
.23576 .34858 L
s
.766 .216 1 r
.31946 .37013 m
.32005 .36096 L
s
.32005 .36096 m
.31955 .36982 L
s
.953 .176 1 r
.7381 .3632 m
.7387 .37274 L
s
.73875 .3724 m
.7381 .3632 L
s
.892 .189 1 r
.24019 .34872 m
.23937 .35808 L
s
.23939 .35803 m
.24019 .34872 L
s
.24019 .34872 m
.23864 .36729 L
s
.578 .262 1 r
.45411 .34527 m
.4539 .35391 L
s
.45391 .35387 m
.45411 .34527 L
s
.45411 .34527 m
.45377 .36237 L
s
.845 .199 1 r
.81802 .37564 m
.81799 .37598 L
s
.953 .176 1 r
.7387 .37274 m
.73813 .36315 L
s
.73813 .36315 m
.73875 .3724 L
s
.531 .274 1 r
.47896 .34397 m
.47881 .35254 L
s
.47883 .3525 m
.47896 .34397 L
s
.47896 .34397 m
.47875 .36077 L
s
1 .151 .919 r
.54378 .34882 m
.5438 .35867 L
s
.54382 .35862 m
.54378 .34882 L
s
.54378 .34882 m
.54391 .36803 L
s
.712 .229 1 r
.81269 .35938 m
.81346 .36843 L
s
.81349 .36798 m
.81269 .35938 L
s
.352 .327 1 r
.70699 .30622 m
.70928 .34426 L
s
.467 .292 1 r
.40339 .30621 m
.4021 .34685 L
s
.375 .32 1 r
.09979 .30621 m
.09489 .34574 L
s
.712 .229 1 r
.81346 .36843 m
.81272 .35934 L
s
.81272 .35934 m
.81349 .36798 L
s
.788 .212 1 r
.62361 .36159 m
.62387 .37071 L
s
.62393 .37056 m
.62361 .36159 L
s
.589 .259 1 r
.39457 .35748 m
.39422 .36622 L
s
.3943 .36578 m
.39457 .35748 L
s
.441 .3 1 r
.11581 .35611 m
.11478 .36437 L
s
.11486 .36418 m
.11581 .35611 L
s
.788 .212 1 r
.62387 .37071 m
.62363 .36154 L
s
.62363 .36154 m
.62393 .37056 L
s
.357 .451 1 r
.79761 .352 m
.79823 .35973 L
s
.79826 .3594 m
.79761 .352 L
s
.589 .259 1 r
.39422 .36622 m
.39459 .35744 L
s
.39459 .35744 m
.3943 .36578 L
s
.441 .3 1 r
.11478 .36437 m
.11582 .35607 L
s
.11582 .35607 m
.11486 .36418 L
s
.754 .219 1 r
.18061 .36105 m
.17966 .3701 L
s
.17974 .36995 m
.18061 .36105 L
s
.357 .451 1 r
.79823 .35973 m
.79763 .35196 L
s
.79763 .35196 m
.79826 .3594 L
s
.521 .277 1 r
.146 .37137 m
.14594 .37133 L
s
.766 .217 1 r
.26499 .34798 m
.26426 .357 L
s
.26428 .35696 m
.26499 .34798 L
s
.26499 .34798 m
.26361 .36606 L
s
.754 .219 1 r
.17966 .3701 m
.18062 .361 L
s
.18062 .361 m
.17974 .36995 L
s
.337 .332 1 r
.85715 .34038 m
.85793 .34842 L
s
.85795 .34838 m
.85715 .34038 L
s
.85715 .34038 m
.85873 .35598 L
s
.416 .307 1 r
.5242 .36734 m
.52415 .36763 L
s
.378 .543 1 r
.11048 .33981 m
.10953 .34729 L
s
.10954 .34726 m
.11048 .33981 L
s
.11048 .33981 m
.10866 .35463 L
s
.477 .289 1 r
.87127 .30596 m
.87569 .34623 L
s
.648 .244 1 r
.56762 .30596 m
.56839 .34845 L
s
.382 .563 1 r
.26398 .30596 m
.26142 .34068 L
s
.638 .247 1 r
.28537 .37235 m
.2853 .37254 L
s
.659 .242 1 r
.53395 .3586 m
.53396 .3675 L
s
.53402 .36713 m
.53395 .3586 L
s
.53396 .3675 m
.53397 .35856 L
s
.53397 .35856 m
.53402 .36713 L
s
.588 .259 1 r
.33955 .34416 m
.33904 .35288 L
s
.33906 .35284 m
.33955 .34416 L
s
.33955 .34416 m
.33863 .36127 L
s
1 .156 .946 r
.59877 .36354 m
.59898 .37331 L
s
.59904 .37289 m
.59877 .36354 L
s
.45 .297 1 r
.74793 .35533 m
.74849 .36366 L
s
.74852 .36333 m
.74793 .35533 L
s
1 .156 .946 r
.59898 .37331 m
.5988 .3635 L
s
.5988 .3635 m
.59904 .37289 L
s
.777 .214 1 r
.2605 .37394 m
.26041 .37428 L
s
.45 .297 1 r
.74849 .36366 m
.74796 .35529 L
s
.74796 .35529 m
.74852 .36333 L
s
.357 .45 1 r
.65825 .35205 m
.65856 .35975 L
s
.6586 .35953 m
.65825 .35205 L
s
.608 .254 1 r
.7319 .30571 m
.73478 .34821 L
s
.733 .224 1 r
.42822 .30571 m
.42716 .34932 L
s
.649 .244 1 r
.12454 .30571 m
.1196 .3482 L
s
.788 .212 1 r
.34481 .3611 m
.34431 .37023 L
s
.34438 .37007 m
.34481 .3611 L
s
.357 .45 1 r
.65856 .35975 m
.65828 .35201 L
s
.65828 .35201 m
.6586 .35953 L
s
.451 .837 1 r
.28 .35621 m
.27993 .35649 L
s
.788 .212 1 r
.34431 .37023 m
.34483 .36106 L
s
.34483 .36106 m
.34438 .37007 L
s
.608 .254 1 r
.3102 .37149 m
.31012 .37168 L
s
.779 .214 1 r
.84302 .3759 m
.84295 .3758 L
s
.423 .732 1 r
.41941 .35719 m
.41934 .35766 L
s
.679 .237 1 r
.36966 .36002 m
.36924 .36885 L
s
.3693 .36885 m
.36966 .36002 L
s
.433 .302 1 r
.83239 .34274 m
.83311 .35097 L
s
.83314 .35093 m
.83239 .34274 L
s
.83239 .34274 m
.83391 .35906 L
s
.559 .267 1 r
.36438 .34345 m
.36394 .3521 L
s
.36396 .35205 m
.36438 .34345 L
s
.36438 .34345 m
.36359 .36041 L
s
.578 .262 1 r
.5925 .30546 m
.59358 .34759 L
s
.367 .322 1 r
.28878 .30546 m
.28612 .34536 L
s
.679 .237 1 r
.36924 .36885 m
.36967 .35998 L
s
.36967 .35998 m
.3693 .36885 L
s
.766 .216 1 r
.20535 .36086 m
.20447 .36991 L
s
.20455 .36983 m
.20535 .36086 L
s
.638 .247 1 r
.23022 .35948 m
.22944 .3682 L
s
.2295 .36823 m
.23022 .35948 L
s
.649 .244 1 r
.25509 .35811 m
.25436 .36698 L
s
.25445 .36664 m
.25509 .35811 L
s
.609 .254 1 r
.66811 .34359 m
.66846 .35239 L
s
.66848 .35235 m
.66811 .34359 L
s
.66811 .34359 m
.66888 .36077 L
s
.766 .216 1 r
.20447 .36991 m
.20537 .36081 L
s
.20537 .36081 m
.20455 .36983 L
s
.569 .264 1 r
.20007 .34432 m
.19921 .35293 L
s
.19922 .35289 m
.20007 .34432 L
s
.20007 .34432 m
.19843 .36139 L
s
.638 .247 1 r
.22944 .3682 m
.23023 .35944 L
s
.23023 .35944 m
.2295 .36823 L
s
.978 .171 1 r
.89726 .34781 m
.89829 .3574 L
s
.89832 .35735 m
.89726 .34781 L
s
.89726 .34781 m
.89939 .36669 L
s
.649 .244 1 r
.25436 .36698 m
.2551 .35807 L
s
.2551 .35807 m
.25445 .36664 L
s
.711 .229 1 r
.69826 .35895 m
.69872 .36796 L
s
.69877 .36762 m
.69826 .35895 L
s
.69872 .36796 m
.69829 .3589 L
s
.69829 .3589 m
.69877 .36762 L
s
1 .138 .854 r
.40435 .35005 m
.40396 .3599 L
s
.40398 .35985 m
.40435 .35005 L
s
.40435 .35005 m
.40367 .36964 L
s
.744 .221 1 r
.44961 .37284 m
.44954 .37318 L
s
.467 .292 1 r
.35989 .36942 m
.35983 .36938 L
s
.68 .237 1 r
.80757 .34458 m
.8083 .35352 L
s
.80832 .35348 m
.80757 .34458 L
s
.80757 .34458 m
.80908 .36213 L
s
.50381 .34457 m
.50373 .35352 L
s
.50375 .35348 m
.50381 .34457 L
s
.50381 .34457 m
.50373 .36213 L
s
.669 .239 1 r
.75683 .30521 m
.76006 .34808 L
s
.744 .222 1 r
.45307 .30521 m
.45234 .34882 L
s
.788 .212 1 r
.1493 .30521 m
.14444 .34994 L
s
.68 .237 1 r
.77825 .37162 m
.77821 .37196 L
s
.4 .312 1 r
.49398 .35376 m
.4939 .36194 L
s
.49396 .36161 m
.49398 .35376 L
s
.68 .237 1 r
.6388 .37101 m
.63875 .37146 L
s
.4 .312 1 r
.4939 .36194 m
.494 .35372 L
s
.494 .35372 m
.49396 .36161 L
s
.569 .264 1 r
.8626 .3587 m
.86346 .3672 L
s
.86353 .36738 m
.8626 .3587 L
s
.977 .171 1 r
.53932 .37664 m
.53926 .37694 L
s
.711 .229 1 r
.75339 .37321 m
.75333 .37333 L
s
.799 .209 1 r
.17515 .34631 m
.17416 .35548 L
s
.17418 .35544 m
.17515 .34631 L
s
.17515 .34631 m
.17327 .36447 L
s
.569 .264 1 r
.86346 .3672 m
.86263 .35866 L
s
.86263 .35866 m
.86353 .36738 L
s
.744 .221 1 r
.61394 .3726 m
.61388 .37294 L
s
.777 .214 1 r
.6174 .30496 m
.61885 .34895 L
s
.55 .269 1 r
.31359 .30496 m
.31113 .34672 L
s
.904 .186 1 r
.3146 .34721 m
.31398 .35661 L
s
.314 .35657 m
.3146 .34721 L
s
.3146 .34721 m
.31345 .36582 L
s
.578 .262 1 r
.1404 .35709 m
.13939 .36573 L
s
.13948 .36554 m
.1404 .35709 L
s
.13939 .36573 m
.14041 .35705 L
s
.14041 .35705 m
.13948 .36554 L
s
.352 .327 1 r
.29946 .33998 m
.29889 .34802 L
s
.2989 .34798 m
.29946 .33998 L
s
.29946 .33998 m
.29841 .35574 L
s
.834 .201 1 r
.78177 .30471 m
.78548 .34944 L
s
.56 .267 1 r
.47793 .30471 m
.47754 .34647 L
s
.658 .242 1 r
.17408 .30471 m
.1697 .34796 L
s
.669 .239 1 r
.33498 .37175 m
.3349 .37194 L
s
.68 .237 1 r
.19549 .37114 m
.19539 .37147 L
s
.544 .271 1 r
.51886 .35327 m
.51884 .36205 L
s
.5189 .36113 m
.51886 .35327 L
s
1 .156 .946 r
.61843 .34776 m
.61867 .3575 L
s
.6187 .35745 m
.61843 .34776 L
s
.61843 .34776 m
.61899 .36694 L
s
.408 .31 1 r
.88229 .34153 m
.88313 .34969 L
s
.88316 .34965 m
.88229 .34153 L
s
.88229 .34153 m
.88404 .35771 L
s
.544 .271 1 r
.51884 .36205 m
.51888 .35323 L
s
.51888 .35323 m
.5189 .36113 L
s
.335 .341 1 r
.48423 .36367 m
.48417 .364 L
s
.618 .252 1 r
.30473 .35684 m
.30414 .36563 L
s
.30422 .3653 m
.30473 .35684 L
s
.928 .181 1 r
.78281 .34722 m
.7835 .35666 L
s
.78353 .35662 m
.78281 .34722 L
s
.78281 .34722 m
.78428 .36595 L
s
.618 .252 1 r
.30414 .36563 m
.30474 .3568 L
s
.30474 .3568 m
.30422 .3653 L
s
1 .154 .934 r
.15018 .34863 m
.14906 .35833 L
s
.14908 .35829 m
.15018 .34863 L
s
.15018 .34863 m
.14804 .36792 L
s
.559 .267 1 r
.54909 .36869 m
.54904 .36903 L
s
.411 .309 1 r
.79258 .33832 m
.79323 .3467 L
s
.79325 .34666 m
.79258 .33832 L
s
.79258 .33832 m
.79389 .35426 L
s
.904 .186 1 r
.58909 .37493 m
.58903 .37524 L
s
.723 .226 1 r
.6423 .30446 m
.64405 .34733 L
s
.649 .244 1 r
.33842 .30446 m
.33626 .34659 L
s
.391 .315 1 r
.60331 .34046 m
.60348 .34861 L
s
.6035 .34857 m
.60331 .34046 L
s
.60331 .34046 m
.60371 .35648 L
s
.578 .262 1 r
.3847 .36967 m
.38463 .36986 L
s
.659 .242 1 r
.1705 .37346 m
.17047 .37317 L
s
.608 .254 1 r
.24965 .34352 m
.24891 .35224 L
s
.24892 .3522 m
.24965 .34352 L
s
.24965 .34352 m
.24825 .36078 L
s
.588 .259 1 r
.63349 .35606 m
.63377 .36478 L
s
.63382 .36444 m
.63349 .35606 L
s
1 .161 .972 r
.80673 .30421 m
.81094 .3508 L
s
.835 .201 1 r
.5028 .30421 m
.50273 .34857 L
s
.34 .366 1 r
.19887 .30421 m
.19527 .34264 L
s
.588 .259 1 r
.63377 .36478 m
.63352 .35602 L
s
.63352 .35602 m
.63382 .36444 L
s
.765 .217 1 r
.52869 .34511 m
.52867 .35421 L
s
.52869 .35416 m
.52869 .34511 L
s
.52869 .34511 m
.52873 .36312 L
s
.598 .257 1 r
.16515 .35689 m
.1642 .36557 L
s
.16428 .36542 m
.16515 .35689 L
s
.368 .322 1 r
.64863 .3638 m
.64859 .3642 L
s
.598 .257 1 r
.1642 .36557 m
.16517 .35685 L
s
.16517 .35685 m
.16428 .36542 L
s
.953 .176 1 r
.83791 .36184 m
.83879 .37132 L
s
.83884 .3712 m
.83791 .36184 L
s
.916 .184 1 r
.55886 .36047 m
.55894 .36994 L
s
.559 .3696 m
.55886 .36047 L
s
.424 .305 1 r
.4638 .34039 m
.46363 .34866 L
s
.46364 .34862 m
.4638 .34039 L
s
.4638 .34039 m
.46353 .3566 L
s
.335 .34 1 r
.5091 .36319 m
.50905 .36352 L
s
.953 .176 1 r
.83879 .37132 m
.83794 .3618 L
s
.83794 .3618 m
.83884 .3712 L
s
.916 .184 1 r
.55894 .36994 m
.55888 .36042 L
s
.55888 .36042 m
.559 .3696 L
s
.777 .214 1 r
.80329 .37224 m
.80326 .37258 L
s
.589 .259 1 r
.57399 .36821 m
.57394 .36865 L
s
.8 .209 1 r
.69312 .34475 m
.69355 .35396 L
s
.69358 .35392 m
.69312 .34475 L
s
.69312 .34475 m
.69406 .36288 L
s
.648 .244 1 r
.66722 .30396 m
.66927 .34647 L
s
.701 .232 1 r
.36326 .30396 m
.36134 .34758 L
s
.522 .277 1 r
.13048 .3676 m
.13038 .36789 L
s
.494 .284 1 r
.71353 .36918 m
.71347 .36904 L
s
.811 .206 1 r
.49934 .37261 m
.49927 .37295 L
s
.691 .234 1 r
.77307 .35748 m
.77373 .36643 L
s
.77377 .36616 m
.77307 .35748 L
s
.712 .229 1 r
.27448 .34299 m
.27377 .35205 L
s
.27379 .352 m
.27448 .34299 L
s
.27448 .34299 m
.27318 .36066 L
s
.799 .209 1 r
.38914 .34508 m
.38874 .35426 L
s
.38876 .35421 m
.38914 .34508 L
s
.38914 .34508 m
.38843 .36325 L
s
.691 .234 1 r
.77373 .36643 m
.7731 .35744 L
s
.7731 .35744 m
.77377 .36616 L
s
.701 .231 1 r
.57847 .34302 m
.57859 .35205 L
s
.57861 .352 m
.57847 .34302 L
s
.57847 .34302 m
.57878 .36066 L
s
.638 .247 1 r
.22021 .37139 m
.22015 .37136 L
s
.424 .305 1 r
.70819 .35283 m
.70864 .36109 L
s
.70868 .36076 m
.70819 .35283 L
s
.467 .895 1 r
.83169 .30371 m
.83461 .33328 L
s
.523 .277 1 r
.52769 .30371 m
.52793 .34436 L
s
.744 .221 1 r
.68867 .37078 m
.68863 .37123 L
s
.598 .257 1 r
.22368 .3037 m
.22001 .34622 L
s
.424 .305 1 r
.70864 .36109 m
.70821 .35279 L
s
.70821 .35279 m
.70868 .36076 L
s
.845 .199 1 r
.44419 .35915 m
.44396 .36847 L
s
.44403 .36813 m
.44419 .35915 L
s
.44396 .36847 m
.44421 .3591 L
s
.44421 .3591 m
.44403 .36813 L
s
.55 .269 1 r
.26997 .36895 m
.2699 .36902 L
s
.94 .179 1 r
.22467 .3462 m
.22379 .35568 L
s
.2238 .35564 m
.22467 .3462 L
s
.22467 .3462 m
.223 .36497 L
s
.733 .224 1 r
.71805 .34415 m
.71854 .35318 L
s
.71856 .35313 m
.71805 .34415 L
s
.71805 .34415 m
.71911 .36202 L
s
.669 .239 1 r
.74295 .34289 m
.7435 .3518 L
s
.74352 .35176 m
.74295 .34289 L
s
.74295 .34289 m
.74412 .36042 L
s
.701 .232 1 r
.69216 .30345 m
.69457 .34671 L
s
.344 .33 1 r
.38811 .30345 m
.38671 .34189 L
s
.608 .254 1 r
.08406 .30345 m
.07849 .34671 L
s
.504 .282 1 r
.48868 .34023 m
.48856 .34876 L
s
.48858 .34872 m
.48868 .34023 L
s
.48868 .34023 m
.48853 .35685 L
s
.722 .227 1 r
.4389 .34304 m
.43864 .3521 L
s
.43866 .35205 m
.4389 .34304 L
s
.4389 .34304 m
.43847 .36079 L
s
.42 .722 1 r
.55352 .34519 m
.55358 .35232 L
s
.55363 .35193 m
.55352 .34519 L
s
.424 .305 1 r
.34909 .33965 m
.34863 .34792 L
s
.34865 .34788 m
.34909 .33965 L
s
.34909 .33965 m
.34826 .35586 L
s
.42 .722 1 r
.55358 .35232 m
.55354 .34515 L
s
.55354 .34515 m
.55363 .35193 L
s
.94 .179 1 r
.88785 .36057 m
.88887 .37005 L
s
.88891 .36985 m
.88785 .36057 L
s
.559 .267 1 r
.7634 .36748 m
.76336 .36781 L
s
.94 .179 1 r
.88887 .37005 m
.88788 .36053 L
s
.88788 .36053 m
.88891 .36985 L
s
.494 .284 1 r
.85667 .3032 m
.86097 .34387 L
s
.68 .237 1 r
.55259 .3032 m
.55316 .34609 L
s
.69 .234 1 r
.2485 .3032 m
.24512 .34609 L
s
.35 .414 1 r
.58379 .36062 m
.58374 .36106 L
s
.834 .201 1 r
.46907 .35866 m
.4689 .36795 L
s
.46897 .36764 m
.46907 .35866 L
s
.618 .252 1 r
.87811 .36968 m
.87806 .3698 L
s
.834 .201 1 r
.4689 .36795 m
.46909 .35862 L
s
.46909 .35862 m
.46897 .36764 L
s
.916 .184 1 r
.60867 .35949 m
.6089 .36897 L
s
.60896 .36862 m
.60867 .35949 L
s
.658 .242 1 r
.35435 .35675 m
.35389 .36558 L
s
.35396 .36543 m
.35435 .35675 L
s
.916 .184 1 r
.6089 .36897 m
.6087 .35945 L
s
.6087 .35945 m
.60896 .36862 L
s
.658 .242 1 r
.35389 .36558 m
.35437 .35671 L
s
.35437 .35671 m
.35396 .36543 L
s
.845 .199 1 r
.41399 .3451 m
.41365 .35436 L
s
.41367 .35431 m
.41399 .3451 L
s
.41399 .3451 m
.4134 .3635 L
s
.618 .252 1 r
.32417 .34168 m
.32361 .35048 L
s
.32363 .35043 m
.32417 .34168 L
s
.32417 .34168 m
.32315 .35894 L
s
.904 .186 1 r
.7171 .30295 m
.72 .34882 L
s
1 .154 .933 r
.41298 .30295 m
.41162 .34993 L
s
.531 .274 1 r
.10885 .30295 m
.10388 .34399 L
s
.395 .62 1 r
.11961 .3362 m
.1187 .3435 L
s
.11871 .34347 m
.11961 .3362 L
s
.11961 .3362 m
.11786 .3507 L
s
.845 .199 1 r
.32945 .35842 m
.32889 .36774 L
s
.32898 .3674 m
.32945 .35842 L
s
.476 .29 1 r
.42904 .35293 m
.42879 .36134 L
s
.42886 .36101 m
.42904 .35293 L
s
.845 .199 1 r
.32889 .36774 m
.32946 .35837 L
s
.32946 .35837 m
.32898 .3674 L
s
.476 .29 1 r
.42879 .36134 m
.42906 .35289 L
s
.42906 .35289 m
.42886 .36101 L
s
.777 .214 1 r
.10535 .37103 m
.10524 .37137 L
s
.628 .249 1 r
.37923 .35597 m
.37883 .36473 L
s
.3789 .36457 m
.37923 .35597 L
s
.559 .267 1 r
.78837 .36699 m
.78834 .36733 L
s
.845 .199 1 r
.88167 .3027 m
.88673 .34745 L
s
.476 .29 1 r
.5775 .3027 m
.57834 .343 L
s
.701 .232 1 r
.4344 .36981 m
.43433 .37011 L
s
.649 .244 1 r
.27333 .3027 m
.27036 .34448 L
s
.628 .249 1 r
.37883 .36473 m
.37924 .35593 L
s
.37924 .35593 m
.3789 .36457 L
s
.57 .264 1 r
.51358 .34013 m
.51352 .34885 L
s
.51354 .34881 m
.51358 .34013 L
s
.51358 .34013 m
.51355 .35709 L
s
.589 .259 1 r
.09993 .35489 m
.09881 .36357 L
s
.0989 .36334 m
.09993 .35489 L
s
.09881 .36357 m
.09994 .35484 L
s
.09994 .35484 m
.0989 .36334 L
s
.833 .201 1 r
.18975 .35847 m
.18881 .36772 L
s
.1889 .36752 m
.18975 .35847 L
s
.494 .284 1 r
.59357 .35298 m
.59374 .36143 L
s
.59379 .36114 m
.59357 .35298 L
s
.833 .201 1 r
.18881 .36772 m
.18977 .35842 L
s
.18977 .35842 m
.1889 .36752 L
s
.45 .297 1 r
.74206 .30245 m
.7449 .34237 L
s
.88 .191 1 r
.43785 .30245 m
.43689 .34757 L
s
.845 .199 1 r
.13364 .30245 m
.12856 .3472 L
s
.494 .284 1 r
.59374 .36143 m
.5936 .35294 L
s
.5936 .35294 m
.59379 .36114 L
s
.811 .206 1 r
.62833 .34266 m
.62859 .35195 L
s
.62861 .35191 m
.62833 .34266 L
s
.62833 .34266 m
.62892 .36079 L
s
.68 .237 1 r
.45929 .36895 m
.45922 .36929 L
s
.754 .219 1 r
.76799 .34342 m
.76861 .35249 L
s
.76864 .35245 m
.76799 .34342 L
s
.76799 .34342 m
.76932 .36141 L
s
.859 .196 1 r
.8231 .35739 m
.82393 .36679 L
s
.82395 .36629 m
.8231 .35739 L
s
.618 .252 1 r
.56868 .35464 m
.56879 .36344 L
s
.56884 .3631 m
.56868 .35464 L
s
.859 .196 1 r
.82393 .36679 m
.82313 .35734 L
s
.82313 .35734 m
.82395 .36629 L
s
.618 .252 1 r
.56879 .36344 m
.5687 .3546 L
s
.5687 .3546 m
.56884 .3631 L
s
.679 .237 1 r
.90319 .36994 m
.90315 .37005 L
s
.618 .252 1 r
.12477 .35411 m
.12369 .36294 L
s
.12381 .36249 m
.12477 .35411 L
s
.4 .312 1 r
.7235 .36308 m
.72346 .36341 L
s
.845 .199 1 r
.60242 .3022 m
.6037 .34695 L
s
.494 .284 1 r
.29817 .3022 m
.29558 .34287 L
s
.618 .252 1 r
.12369 .36294 m
.12478 .35406 L
s
.12478 .35406 m
.12381 .36249 L
s
.531 .274 1 r
.67368 .36589 m
.67364 .36623 L
s
.799 .209 1 r
.21461 .35768 m
.21374 .36686 L
s
.21382 .36667 m
.21461 .35768 L
s
.648 .244 1 r
.87294 .35494 m
.87386 .36381 L
s
.87389 .36347 m
.87294 .35494 L
s
.4 .312 1 r
.64341 .35082 m
.64369 .35901 L
s
.64374 .35868 m
.64341 .35082 L
s
.799 .209 1 r
.21374 .36686 m
.21462 .35764 L
s
.21462 .35764 m
.21382 .36667 L
s
.648 .244 1 r
.87386 .36381 m
.87297 .3549 L
s
.87297 .3549 m
.87389 .36347 L
s
.4 .312 1 r
.64369 .35901 m
.64343 .35078 L
s
.64343 .35078 m
.64374 .35868 L
s
.531 .274 1 r
.75819 .35303 m
.75878 .3616 L
s
.75882 .36126 m
.75819 .35303 L
s
.733 .224 1 r
.29469 .3703 m
.29461 .3705 L
s
.18439 .34267 m
.18344 .3517 L
s
.18345 .35166 m
.18439 .34267 L
s
.18439 .34267 m
.18259 .36055 L
s
.531 .274 1 r
.75878 .3616 m
.75821 .35299 L
s
.75821 .35299 m
.75882 .36126 L
s
.559 .267 1 r
.53849 .34001 m
.53849 .34866 L
s
.53852 .34861 m
.53849 .34001 L
s
.53849 .34001 m
.53858 .35697 L
s
.822 .204 1 r
.76704 .30194 m
.77057 .34708 L
s
.559 .267 1 r
.46275 .30194 m
.46218 .34336 L
s
.712 .229 1 r
.15845 .30194 m
.15382 .34559 L
s
.357 .451 1 r
.79826 .3594 m
.79823 .35973 L
s
.638 .247 1 r
.20928 .34152 m
.20842 .35033 L
s
.20843 .35028 m
.20928 .34152 L
s
.20928 .34152 m
.20765 .35894 L
s
.578 .262 1 r
.37388 .34084 m
.37346 .34949 L
s
.37348 .34945 m
.37388 .34084 L
s
.37388 .34084 m
.37313 .35796 L
s
.88 .191 1 r
.15945 .34434 m
.1584 .35367 L
s
.15841 .35363 m
.15945 .34434 L
s
.15945 .34434 m
.15744 .36289 L
s
.659 .242 1 r
.84808 .3569 m
.84892 .36563 L
s
.849 .36581 m
.84808 .3569 L
s
.579 .262 1 r
.8428 .34026 m
.8436 .34895 L
s
.84362 .34891 m
.8428 .34026 L
s
.8428 .34026 m
.84445 .35735 L
s
1 .149 .907 r
.13453 .34585 m
.13336 .35564 L
s
.13337 .35559 m
.13453 .34585 L
s
.13453 .34585 m
.13229 .36523 L
s
.659 .242 1 r
.84892 .36563 m
.84811 .35686 L
s
.84811 .35686 m
.849 .36581 L
s
.378 .543 1 r
.10953 .34729 m
.10859 .35477 L
s
.10866 .35463 m
.10953 .34729 L
s
.777 .214 1 r
.68348 .35773 m
.6839 .3668 L
s
.68397 .36679 m
.68348 .35773 L
s
.378 .543 1 r
.10859 .35477 m
.10954 .34726 L
s
.10954 .34726 m
.10866 .35463 L
s
.744 .222 1 r
.81791 .34181 m
.81867 .35092 L
s
.8187 .35087 m
.81791 .34181 L
s
.81791 .34181 m
.8195 .35969 L
s
.559 .267 1 r
.70311 .33976 m
.70355 .34841 L
s
.70357 .34837 m
.70311 .33976 L
s
.70311 .33976 m
.70404 .35673 L
s
.777 .214 1 r
.6839 .3668 m
.68351 .35769 L
s
.68351 .35769 m
.68397 .36679 L
s
.649 .244 1 r
.62736 .30169 m
.62889 .34385 L
s
.55 .269 1 r
.32303 .30169 m
.32068 .34348 L
s
.638 .247 1 r
.28927 .35445 m
.28864 .36328 L
s
.28872 .36298 m
.28927 .35445 L
s
.28864 .36328 m
.28929 .35441 L
s
.28929 .35441 m
.28872 .36298 L
s
.441 .3 1 r
.11486 .36418 m
.11478 .36437 L
s
.754 .219 1 r
.15491 .37043 m
.15483 .37059 L
s
.578 .262 1 r
.4539 .35391 m
.4537 .36256 L
s
.45377 .36237 m
.4539 .35391 L
s
.531 .274 1 r
.47881 .35254 m
.47869 .36111 L
s
.47875 .36077 m
.47881 .35254 L
s
.777 .214 1 r
.67822 .34146 m
.67861 .35067 L
s
.67864 .35063 m
.67822 .34146 L
s
.67822 .34146 m
.67907 .35944 L
s
.766 .216 1 r
.31955 .36982 m
.31946 .37013 L
s
.337 .332 1 r
.85793 .34842 m
.85873 .35646 L
s
.85873 .35598 m
.85793 .34842 L
s
.578 .262 1 r
.4537 .36256 m
.45391 .35387 L
s
.45391 .35387 m
.45377 .36237 L
s
.87 .194 1 r
.24476 .37423 m
.24472 .37399 L
s
.531 .274 1 r
.47869 .36111 m
.47883 .3525 L
s
.47883 .3525 m
.47875 .36077 L
s
.337 .332 1 r
.85873 .35646 m
.85795 .34838 L
s
.85795 .34838 m
.85873 .35598 L
s
.357 .45 1 r
.6586 .35953 m
.65856 .35975 L
s
.589 .259 1 r
.3943 .36578 m
.39422 .36622 L
s
.68 .237 1 r
.79202 .30144 m
.79572 .34435 L
s
.485 .287 1 r
.48765 .30144 m
.48739 .34249 L
s
.522 .277 1 r
.18328 .30144 m
.17916 .34324 L
s
.733 .224 1 r
.73335 .35558 m
.73391 .36464 L
s
.73395 .36434 m
.73335 .35558 L
s
.712 .229 1 r
.81349 .36798 m
.81346 .36843 L
s
.733 .224 1 r
.73391 .36464 m
.73338 .35554 L
s
.73338 .35554 m
.73395 .36434 L
s
.711 .229 1 r
.23411 .3411 m
.2333 .35013 L
s
.23331 .35009 m
.23411 .3411 L
s
.23411 .3411 m
.23259 .35882 L
s
.45 .297 1 r
.74852 .36333 m
.74849 .36366 L
s
.953 .176 1 r
.73875 .3724 m
.7387 .37274 L
s
.777 .214 1 r
.65232 .30119 m
.65423 .34484 L
s
.579 .262 1 r
.3479 .30119 m
.34587 .34299 L
s
1 .136 .839 r
.85358 .3746 m
.85357 .3751 L
s
.892 .189 1 r
.23937 .35808 m
.23856 .36745 L
s
.23864 .36729 m
.23937 .35808 L
s
.405 .662 1 r
.68802 .33314 m
.68835 .3404 L
s
.68837 .34036 m
.68802 .33314 L
s
.68802 .33314 m
.68874 .34737 L
s
.638 .247 1 r
.09433 .34078 m
.09317 .34959 L
s
.09318 .34955 m
.09433 .34078 L
s
.09433 .34078 m
.0921 .35821 L
s
.788 .212 1 r
.62393 .37056 m
.62387 .37071 L
s
.892 .189 1 r
.23856 .36745 m
.23939 .35803 L
s
.23939 .35803 m
.23864 .36729 L
s
.659 .242 1 r
.53402 .36713 m
.53396 .3675 L
s
.754 .219 1 r
.17974 .36995 m
.17966 .3701 L
s
.638 .247 1 r
.25899 .34021 m
.25826 .34905 L
s
.25828 .34901 m
.25899 .34021 L
s
.25899 .34021 m
.25763 .35759 L
s
.66 .241 1 r
.72811 .33955 m
.72863 .34851 L
s
.72865 .34846 m
.72811 .33955 L
s
.72811 .33955 m
.7292 .35698 L
s
.766 .217 1 r
.26426 .357 m
.26355 .36603 L
s
.26361 .36606 m
.26426 .357 L
s
.588 .259 1 r
.33904 .35288 m
.33855 .3616 L
s
.33863 .36127 m
.33904 .35288 L
s
.766 .217 1 r
.26355 .36603 m
.26428 .35696 L
s
.26428 .35696 m
.26361 .36606 L
s
.711 .229 1 r
.81702 .30094 m
.82108 .34422 L
s
.559 .267 1 r
.51257 .30094 m
.51263 .34236 L
s
.598 .257 1 r
.20812 .30094 m
.20424 .34348 L
s
.588 .259 1 r
.33855 .3616 m
.33906 .35284 L
s
.33906 .35284 m
.33863 .36127 L
s
.433 .302 1 r
.83311 .35097 m
.83387 .3592 L
s
.83391 .35906 m
.83311 .35097 L
s
.83387 .3592 m
.83314 .35093 L
s
.83314 .35093 m
.83391 .35906 L
s
1 .151 .919 r
.5438 .35867 m
.54385 .36853 L
s
.54391 .36803 m
.5438 .35867 L
s
.54385 .36853 m
.54382 .35862 L
s
.54382 .35862 m
.54391 .36803 L
s
.4 .312 1 r
.49396 .36161 m
.4939 .36194 L
s
.639 .247 1 r
.56343 .34086 m
.56351 .34963 L
s
.56353 .34959 m
.56343 .34086 L
s
.56343 .34086 m
.56366 .35833 L
s
.711 .229 1 r
.67728 .30068 m
.6795 .34397 L
s
.441 .3 1 r
.37279 .30068 m
.37115 .34063 L
s
.559 .267 1 r
.36394 .3521 m
.36351 .36074 L
s
.36359 .36041 m
.36394 .3521 L
s
.788 .212 1 r
.34438 .37007 m
.34431 .37023 L
s
.649 .244 1 r
.25445 .36664 m
.25436 .36698 L
s
.58837 .33967 m
.58851 .34855 L
s
.58853 .34851 m
.58837 .33967 L
s
.58837 .33967 m
.58873 .3571 L
s
.559 .267 1 r
.36351 .36074 m
.36396 .35205 L
s
.36396 .35205 m
.36359 .36041 L
s
1 .156 .946 r
.59904 .37289 m
.59898 .37331 L
s
.569 .264 1 r
.19921 .35293 m
.19835 .36154 L
s
.19843 .36139 m
.19921 .35293 L
s
.679 .237 1 r
.3693 .36885 m
.36924 .36885 L
s
.569 .264 1 r
.19835 .36154 m
.19922 .35289 L
s
.19922 .35289 m
.19843 .36139 L
s
.638 .247 1 r
.2295 .36823 m
.22944 .3682 L
s
.609 .254 1 r
.66846 .35239 m
.66883 .36119 L
s
.66888 .36077 m
.66846 .35239 L
s
.733 .224 1 r
.42364 .34062 m
.42334 .34969 L
s
.42336 .34964 m
.42364 .34062 L
s
.42364 .34062 m
.42313 .35846 L
s
.756 .219 1 r
.84204 .30043 m
.8465 .34446 L
s
.669 .239 1 r
.5375 .30043 m
.53788 .34372 L
s
.68 .237 1 r
.23297 .30043 m
.22939 .34335 L
s
.711 .229 1 r
.69877 .36762 m
.69872 .36796 L
s
.609 .254 1 r
.66883 .36119 m
.66848 .35235 L
s
.66848 .35235 m
.66888 .36077 L
s
.68 .237 1 r
.75312 .33932 m
.7537 .34831 L
s
.75373 .34827 m
.75312 .33932 L
s
.75312 .33932 m
.75434 .35686 L
s
.766 .216 1 r
.20455 .36983 m
.20447 .36991 L
s
.569 .264 1 r
.86353 .36738 m
.86346 .3672 L
s
.598 .257 1 r
.44856 .33961 m
.44833 .34831 L
s
.44835 .34827 m
.44856 .33961 L
s
.44856 .33961 m
.44819 .35686 L
s
.68 .237 1 r
.8083 .35352 m
.80905 .36247 L
s
.80908 .36213 m
.8083 .35352 L
s
.50373 .35352 m
.50366 .36247 L
s
.50373 .36213 m
.50373 .35352 L
s
.544 .271 1 r
.5189 .36113 m
.51884 .36205 L
s
.352 .327 1 r
.29889 .34802 m
.29833 .35607 L
s
.29841 .35574 m
.29889 .34802 L
s
.754 .219 1 r
.70226 .30018 m
.70487 .34459 L
s
.777 .214 1 r
.39769 .30018 m
.39621 .34421 L
s
.494 .284 1 r
.09311 .30018 m
.08784 .34198 L
s
.68 .237 1 r
.80905 .36247 m
.80832 .35348 L
s
.80832 .35348 m
.80908 .36213 L
s
.50366 .36247 m
.50375 .35348 L
s
.50375 .35348 m
.50373 .36213 L
s
.352 .327 1 r
.29833 .35607 m
.2989 .34798 L
s
.2989 .34798 m
.29841 .35574 L
s
.904 .186 1 r
.3987 .34254 m
.39831 .35195 L
s
.39833 .3519 m
.3987 .34254 L
s
.3987 .34254 m
.39802 .36117 L
s
1 .108 .687 r
.65342 .34535 m
.65378 .35559 L
s
.6538 .35554 m
.65342 .34535 L
s
.65342 .34535 m
.65422 .36549 L
s
.503 .282 1 r
.1689 .3385 m
.16797 .34693 L
s
.16798 .34689 m
.1689 .3385 L
s
.1689 .3385 m
.16713 .35525 L
s
.578 .262 1 r
.13948 .36554 m
.13939 .36573 L
s
.408 .31 1 r
.88313 .34969 m
.88401 .35785 L
s
.88404 .35771 m
.88313 .34969 L
s
.88401 .35785 m
.88316 .34965 L
s
.88316 .34965 m
.88404 .35771 L
s
.978 .171 1 r
.89829 .3574 m
.89936 .36699 L
s
.89939 .36669 m
.89829 .3574 L
s
.723 .226 1 r
.4735 .33868 m
.47333 .34782 L
s
.47335 .34777 m
.4735 .33868 L
s
.4735 .33868 m
.47325 .35636 L
s
.628 .249 1 r
.7781 .33868 m
.77874 .34752 L
s
.77877 .34748 m
.7781 .33868 L
s
.7781 .33868 m
.77944 .35599 L
s
.744 .221 1 r
.14395 .34008 m
.14288 .34919 L
s
.14289 .34915 m
.14395 .34008 L
s
.14395 .34008 m
.14193 .35796 L
s
.68 .237 1 r
.61333 .3394 m
.61354 .34836 L
s
.61356 .34831 m
.61333 .3394 L
s
.61333 .3394 m
.61382 .35698 L
s
.978 .171 1 r
.89936 .36699 m
.89832 .35735 L
s
.89832 .35735 m
.89939 .36669 L
s
1 .146 .894 r
.86706 .29993 m
.87222 .34732 L
s
.495 .284 1 r
.56245 .29993 m
.56311 .34025 L
s
.531 .274 1 r
.25783 .29993 m
.25471 .34099 L
s
.799 .209 1 r
.17416 .35548 m
.17318 .36466 L
s
.17327 .36447 m
.17416 .35548 L
s
.754 .219 1 r
.89302 .34096 m
.89399 .35003 L
s
.89402 .34999 m
.89302 .34096 L
s
.89302 .34096 m
.89504 .35895 L
s
.391 .315 1 r
.60348 .34861 m
.60367 .35677 L
s
.60371 .35648 m
.60348 .34861 L
s
.799 .209 1 r
.17318 .36466 m
.17418 .35544 L
s
.17418 .35544 m
.17327 .36447 L
s
.744 .222 1 r
.28377 .34099 m
.28309 .35003 L
s
.2831 .34999 m
.28377 .34099 L
s
.28377 .34099 m
.28249 .35895 L
s
.391 .315 1 r
.60367 .35677 m
.6035 .34857 L
s
.6035 .34857 m
.60371 .35648 L
s
.618 .252 1 r
.30422 .3653 m
.30414 .36563 L
s
.411 .309 1 r
.79323 .3467 m
.7939 .35508 L
s
.79389 .35426 m
.79323 .3467 L
s
.337 .332 1 r
.10381 .3342 m
.10277 .34226 L
s
.10278 .34222 m
.10381 .3342 L
s
.10381 .3342 m
.10186 .34983 L
s
1 .138 .854 r
.40396 .3599 m
.40359 .36977 L
s
.40367 .36964 m
.40396 .3599 L
s
.411 .309 1 r
.7939 .35508 m
.79325 .34666 L
s
.79325 .34666 m
.79389 .35426 L
s
.744 .222 1 r
.3087 .33984 m
.30808 .34895 L
s
.30809 .3489 m
.3087 .33984 L
s
.3087 .33984 m
.30756 .35772 L
s
1 .138 .854 r
.40359 .36977 m
.40398 .35985 L
s
.40398 .35985 m
.40367 .36964 L
s
1 .156 .946 r
.72725 .29968 m
.73038 .34669 L
s
.56 .267 1 r
.4226 .29968 m
.42153 .34074 L
s
.658 .242 1 r
.11794 .29967 m
.11281 .34297 L
s
.904 .186 1 r
.31398 .35661 m
.31337 .36602 L
s
.31345 .36582 m
.31398 .35661 L
s
.31337 .36602 m
.314 .35657 L
s
.314 .35657 m
.31345 .36582 L
s
.42 .722 1 r
.55363 .35193 m
.55358 .35232 L
s
.588 .259 1 r
.63382 .36444 m
.63377 .36478 L
s
.559 .267 1 r
.66325 .33754 m
.66358 .34619 L
s
.6636 .34615 m
.66325 .33754 L
s
.66325 .33754 m
.66398 .35451 L
s
.424 .305 1 r
.46363 .34866 m
.46347 .35693 L
s
.46353 .3566 m
.46363 .34866 L
s
.588 .259 1 r
.58741 .29942 m
.58841 .34124 L
s
.336 .332 1 r
.28271 .29942 m
.28005 .33827 L
s
.424 .305 1 r
.46347 .35693 m
.46364 .34862 L
s
.46364 .34862 m
.46353 .3566 L
s
.608 .254 1 r
.24891 .35224 m
.24817 .36097 L
s
.24825 .36078 m
.24891 .35224 L
s
.734 .224 1 r
.33361 .33905 m
.33306 .34816 L
s
.33307 .34811 m
.33361 .33905 L
s
.33361 .33905 m
.33261 .35686 L
s
.598 .257 1 r
.16428 .36542 m
.1642 .36557 L
s
.608 .254 1 r
.24817 .36097 m
.24892 .3522 L
s
.24892 .3522 m
.24825 .36078 L
s
.649 .244 1 r
.80314 .33844 m
.80385 .34732 L
s
.80388 .34728 m
.80314 .33844 L
s
.80314 .33844 m
.80462 .35587 L
s
.723 .226 1 r
.19371 .33851 m
.19278 .34762 L
s
.1928 .34757 m
.19371 .33851 L
s
.19371 .33851 m
.19197 .35624 L
s
.494 .284 1 r
.8281 .33722 m
.82884 .34565 L
s
.82886 .34561 m
.8281 .33722 L
s
.8281 .33722 m
.82964 .3539 L
s
.928 .181 1 r
.7835 .35666 m
.78423 .36611 L
s
.78428 .36595 m
.7835 .35666 L
s
.424 .305 1 r
.70868 .36076 m
.70864 .36109 L
s
.928 .181 1 r
.78423 .36611 m
.78353 .35662 L
s
.78353 .35662 m
.78428 .36595 L
s
.744 .221 1 r
.75226 .29917 m
.75552 .34322 L
s
.476 .29 1 r
.44752 .29917 m
.44678 .3395 L
s
.649 .244 1 r
.14278 .29917 m
.13802 .3421 L
s
1 .156 .946 r
.61867 .3575 m
.61894 .36725 L
s
.61899 .36694 m
.61867 .3575 L
s
1 .141 .868 r
.86823 .34361 m
.86921 .35348 L
s
.86924 .35343 m
.86823 .34361 L
s
.86823 .34361 m
.87027 .36315 L
s
1 .156 .946 r
.61894 .36725 m
.6187 .35745 L
s
.6187 .35745 m
.61899 .36694 L
s
1 .154 .934 r
.14906 .35833 m
.14796 .36805 L
s
.14804 .36792 m
.14906 .35833 L
s
.765 .217 1 r
.52867 .35421 m
.52867 .36331 L
s
.52873 .36312 m
.52867 .35421 L
s
1 .154 .934 r
.14796 .36805 m
.14908 .35829 L
s
.14908 .35829 m
.14804 .36792 L
s
.649 .244 1 r
.52338 .33762 m
.52335 .34653 L
s
.52337 .34649 m
.52338 .33762 L
s
.52338 .33762 m
.5234 .35501 L
s
.765 .217 1 r
.52867 .36331 m
.52869 .35416 L
s
.52869 .35416 m
.52873 .36312 L
s
.916 .184 1 r
.559 .3696 m
.55894 .36994 L
s
.55 .269 1 r
.38346 .33708 m
.38307 .3457 L
s
.38309 .34566 m
.38346 .33708 L
s
.38346 .33708 m
.38276 .35402 L
s
.711 .229 1 r
.61238 .29892 m
.61375 .34222 L
s
.392 .315 1 r
.3076 .29892 m
.30521 .33814 L
s
.691 .234 1 r
.77377 .36616 m
.77373 .36643 L
s
.869 .194 1 r
.63835 .33993 m
.63864 .34934 L
s
.63866 .34929 m
.63835 .33993 L
s
.63835 .33993 m
.639 .35834 L
s
.628 .249 1 r
.3585 .3386 m
.35804 .34737 L
s
.35805 .34733 m
.3585 .3386 L
s
.3585 .3386 m
.35766 .356 L
s
.395 .62 1 r
.1187 .3435 m
.1178 .3508 L
s
.11786 .3507 m
.1187 .3435 L
s
.953 .176 1 r
.83884 .3712 m
.83879 .37132 L
s
.8 .209 1 r
.69355 .35396 m
.69401 .36318 L
s
.69406 .36288 m
.69355 .35396 L
s
.395 .62 1 r
.1178 .3508 m
.11871 .34347 L
s
.11871 .34347 m
.11786 .3507 L
s
.8 .209 1 r
.69401 .36318 m
.69358 .35392 L
s
.69358 .35392 m
.69406 .36288 L
s
.811 .206 1 r
.49843 .33954 m
.49833 .3488 L
s
.49835 .34875 m
.49843 .33954 L
s
.49843 .33954 m
.49831 .35772 L
s
.712 .229 1 r
.27377 .35205 m
.27308 .36111 L
s
.27318 .36066 m
.27377 .35205 L
s
.701 .231 1 r
.57859 .35205 m
.57872 .36108 L
s
.57878 .36066 m
.57859 .35205 L
s
.424 .305 1 r
.34863 .34792 m
.34818 .35619 L
s
.34826 .35586 m
.34863 .34792 L
s
.69 .234 1 r
.77728 .29867 m
.78084 .34234 L
s
.375 .32 1 r
.47246 .29867 m
.47204 .33751 L
s
.512 .279 1 r
.16764 .29866 m
.16335 .34011 L
s
.712 .229 1 r
.27308 .36111 m
.27379 .352 L
s
.27379 .352 m
.27318 .36066 L
s
.701 .231 1 r
.57872 .36108 m
.57861 .352 L
s
.57861 .352 m
.57878 .36066 L
s
.352 .426 1 r
.29341 .33409 m
.29284 .34181 L
s
.29286 .34177 m
.29341 .33409 L
s
.29341 .33409 m
.29236 .34946 L
s
.424 .305 1 r
.34818 .35619 m
.34865 .34788 L
s
.34865 .34788 m
.34826 .35586 L
s
.799 .209 1 r
.38874 .35426 m
.38835 .36344 L
s
.38843 .36325 m
.38874 .35426 L
s
.504 .282 1 r
.48856 .34876 m
.48846 .35729 L
s
.48853 .35685 m
.48856 .34876 L
s
.845 .199 1 r
.44403 .36813 m
.44396 .36847 L
s
.799 .209 1 r
.38835 .36344 m
.38876 .35421 L
s
.38876 .35421 m
.38843 .36325 L
s
.504 .282 1 r
.48846 .35729 m
.48858 .34872 L
s
.48858 .34872 m
.48853 .35685 L
s
.733 .224 1 r
.71854 .35318 m
.71906 .36221 L
s
.71911 .36202 m
.71854 .35318 L
s
.669 .239 1 r
.7435 .3518 m
.74408 .36072 L
s
.74412 .36042 m
.7435 .3518 L
s
.504 .282 1 r
.63736 .29841 m
.63895 .33875 L
s
.88 .191 1 r
.3325 .29841 m
.33005 .34433 L
s
.733 .224 1 r
.71906 .36221 m
.71856 .35313 L
s
.71856 .35313 m
.71911 .36202 L
s
.669 .239 1 r
.74408 .36072 m
.74352 .35176 L
s
.74352 .35176 m
.74412 .36042 L
s
.467 .292 1 r
.57329 .33601 m
.57339 .34437 L
s
.57341 .34433 m
.57329 .33601 L
s
.57329 .33601 m
.57356 .35254 L
s
.476 .29 1 r
.42886 .36101 m
.42879 .36134 L
s
.722 .227 1 r
.43864 .3521 m
.43839 .36116 L
s
.43847 .36079 m
.43864 .3521 L
s
.43839 .36116 m
.43866 .35205 L
s
.43866 .35205 m
.43847 .36079 L
s
.733 .224 1 r
.21849 .33897 m
.21764 .34801 L
s
.21765 .34796 m
.21849 .33897 L
s
.21849 .33897 m
.21687 .35686 L
s
.94 .179 1 r
.22379 .35568 m
.22292 .36517 L
s
.223 .36497 m
.22379 .35568 L
s
.22292 .36517 m
.2238 .35564 L
s
.2238 .35564 m
.223 .36497 L
s
.669 .239 1 r
.85324 .33771 m
.85409 .34663 L
s
.85412 .34659 m
.85324 .33771 L
s
.85324 .33771 m
.855 .35526 L
s
1 .161 .972 r
.80231 .29816 m
.80645 .34445 L
s
.868 .194 1 r
.49741 .29816 m
.49726 .3437 L
s
.722 .227 1 r
.19251 .29816 m
.18828 .34222 L
s
.658 .242 1 r
.35396 .36543 m
.35389 .36558 L
s
.834 .201 1 r
.46897 .36764 m
.4689 .36795 L
s
.618 .252 1 r
.32361 .35048 m
.32307 .35928 L
s
.32315 .35894 m
.32361 .35048 L
s
.94 .179 1 r
.88891 .36985 m
.88887 .37005 L
s
.618 .252 1 r
.32307 .35928 m
.32363 .35043 L
s
.32363 .35043 m
.32315 .35894 L
s
.916 .184 1 r
.60896 .36862 m
.6089 .36897 L
s
.599 .257 1 r
.66236 .29791 m
.66431 .33936 L
s
.618 .252 1 r
.35742 .29791 m
.35549 .34011 L
s
.628 .249 1 r
.3789 .36457 m
.37883 .36473 L
s
.494 .284 1 r
.59379 .36114 m
.59374 .36143 L
s
.845 .199 1 r
.32898 .3674 m
.32889 .36774 L
s
.41365 .35436 m
.41333 .36362 L
s
.4134 .3635 m
.41365 .35436 L
s
.589 .259 1 r
.0989 .36334 m
.09881 .36357 L
s
.57 .264 1 r
.51352 .34885 m
.51348 .35758 L
s
.51355 .35709 m
.51352 .34885 L
s
.845 .199 1 r
.41333 .36362 m
.41367 .35431 L
s
.41367 .35431 m
.4134 .3635 L
s
.669 .239 1 r
.71332 .33779 m
.71379 .34668 L
s
.71382 .34663 m
.71332 .33779 L
s
.71332 .33779 m
.71434 .35538 L
s
.57 .264 1 r
.51348 .35758 m
.51354 .34881 L
s
.51354 .34881 m
.51355 .35709 L
s
.365 .485 1 r
.53318 .33089 m
.53317 .3386 L
s
.53319 .33857 m
.53318 .33089 L
s
.53318 .33089 m
.53324 .34588 L
s
.4 .312 1 r
.64374 .35868 m
.64369 .35901 L
s
.66 .241 1 r
.82736 .29765 m
.83145 .33985 L
s
.68 .237 1 r
.52237 .29765 m
.52256 .3406 L
s
.55 .269 1 r
.21739 .29765 m
.21363 .34023 L
s
.378 .543 1 r
.10866 .35463 m
.10859 .35477 L
s
.618 .252 1 r
.56884 .3631 m
.56879 .36344 L
s
.12381 .36249 m
.12369 .36294 L
s
.608 .254 1 r
.73832 .33686 m
.73885 .34559 L
s
.73887 .34555 m
.73832 .33686 L
s
.73832 .33686 m
.73945 .35415 L
s
.733 .224 1 r
.68737 .2974 m
.68977 .34146 L
s
.609 .254 1 r
.38235 .2974 m
.38076 .33923 L
s
.754 .219 1 r
.07733 .2974 m
.07151 .34184 L
s
.531 .274 1 r
.75882 .36126 m
.75878 .3616 L
s
.833 .201 1 r
.1889 .36752 m
.18881 .36772 L
s
.822 .204 1 r
.24333 .33917 m
.24252 .3484 L
s
.24254 .34836 m
.24333 .33917 L
s
.24333 .33917 m
.2418 .35748 L
s
.628 .249 1 r
.12826 .33711 m
.12719 .34589 L
s
.1272 .34585 m
.12826 .33711 L
s
.12826 .33711 m
.12621 .35452 L
s
.648 .244 1 r
.87389 .36347 m
.87386 .36381 L
s
.859 .196 1 r
.82395 .36629 m
.82393 .36679 L
s
.754 .219 1 r
.76861 .35249 m
.76927 .36156 L
s
.76932 .36141 m
.76861 .35249 L
s
.76927 .36156 m
.76864 .35245 L
s
.76864 .35245 m
.76932 .36141 L
s
.337 .332 1 r
.85873 .35598 m
.85873 .35646 L
s
.467 .292 1 r
.15321 .33592 m
.15226 .34421 L
s
.15227 .34417 m
.15321 .33592 L
s
.15321 .33592 m
.15137 .35254 L
s
.811 .206 1 r
.62859 .35195 m
.62887 .36125 L
s
.62892 .36079 m
.62859 .35195 L
s
.744 .222 1 r
.85242 .29715 m
.85698 .34084 L
s
.68 .237 1 r
.54735 .29715 m
.54786 .3401 L
s
.733 .224 1 r
.24229 .29715 m
.23876 .34084 L
s
.811 .206 1 r
.62887 .36125 m
.62861 .35191 L
s
.62861 .35191 m
.62892 .36079 L
s
.559 .267 1 r
.53849 .34866 m
.53852 .35731 L
s
.53858 .35697 m
.53849 .34866 L
s
.754 .219 1 r
.26826 .33824 m
.26754 .34732 L
s
.26755 .34727 m
.26826 .33824 L
s
.26826 .33824 m
.2669 .35625 L
s
.799 .209 1 r
.21382 .36667 m
.21374 .36686 L
s
.648 .244 1 r
.76335 .33621 m
.76395 .3451 L
s
.76398 .34506 m
.76335 .33621 L
s
.76335 .33621 m
.76462 .35365 L
s
.559 .267 1 r
.53852 .35731 m
.53852 .34861 L
s
.53852 .34861 m
.53858 .35697 L
s
.405 .662 1 r
.68835 .3404 m
.6887 .34766 L
s
.68874 .34737 m
.68835 .3404 L
s
.6887 .34766 m
.68837 .34036 L
s
.68837 .34036 m
.68874 .34737 L
s
.578 .262 1 r
.37346 .34949 m
.37306 .35815 L
s
.37313 .35796 m
.37346 .34949 L
s
.37306 .35815 m
.37348 .34945 L
s
.37348 .34945 m
.37313 .35796 L
s
.733 .224 1 r
.18344 .3517 m
.1825 .36074 L
s
.18259 .36055 m
.18344 .3517 L
s
.811 .206 1 r
.43329 .33781 m
.43301 .34707 L
s
.43302 .34702 m
.43329 .33781 L
s
.43329 .33781 m
.43281 .356 L
s
.638 .247 1 r
.20842 .35033 m
.20757 .35913 L
s
.20765 .35894 m
.20842 .35033 L
s
.579 .262 1 r
.8436 .34895 m
.84443 .35764 L
s
.84445 .35735 m
.8436 .34895 L
s
.375 .32 1 r
.81331 .33369 m
.81398 .34175 L
s
.81401 .34171 m
.81331 .33369 L
s
.81331 .33369 m
.81472 .3497 L
s
.56 .267 1 r
.7124 .29689 m
.71495 .33799 L
s
.357 .45 1 r
.40729 .29689 m
.40616 .33391 L
s
.45 .297 1 r
.10219 .29689 m
.09726 .33687 L
s
.733 .224 1 r
.1825 .36074 m
.18345 .35166 L
s
.18345 .35166 m
.18259 .36055 L
s
.638 .247 1 r
.20757 .35913 m
.20843 .35028 L
s
.20843 .35028 m
.20765 .35894 L
s
.579 .262 1 r
.84443 .35764 m
.84362 .34891 L
s
.84362 .34891 m
.84445 .35735 L
s
.531 .274 1 r
.47875 .36077 m
.47869 .36111 L
s
.977 .171 1 r
.54837 .34001 m
.54841 .34958 L
s
.54843 .34954 m
.54837 .34001 L
s
.54837 .34001 m
.54853 .35896 L
s
.659 .242 1 r
.849 .36581 m
.84892 .36563 L
s
.559 .267 1 r
.70355 .34841 m
.704 .35706 L
s
.70404 .35673 m
.70355 .34841 L
s
.638 .247 1 r
.28872 .36298 m
.28864 .36328 L
s
.559 .267 1 r
.704 .35706 m
.70357 .34837 L
s
.70357 .34837 m
.70404 .35673 L
s
.578 .262 1 r
.45377 .36237 m
.4537 .36256 L
s
.712 .229 1 r
.62332 .33607 m
.62355 .34515 L
s
.62358 .3451 m
.62332 .33607 L
s
.62332 .33607 m
.62387 .35378 L
s
.953 .176 1 r
.8785 .33893 m
.87948 .3485 L
s
.87951 .34845 m
.8785 .33893 L
s
.8785 .33893 m
.88052 .35773 L
s
.811 .206 1 r
.59834 .33756 m
.59851 .34682 L
s
.59854 .34678 m
.59834 .33756 L
s
.59834 .33756 m
.59877 .35575 L
s
.559 .267 1 r
.34315 .33481 m
.34265 .34347 L
s
.34267 .34343 m
.34315 .33481 L
s
.34315 .33481 m
.34225 .3518 L
s
.691 .234 1 r
.87749 .29664 m
.88227 .33922 L
s
.629 .249 1 r
.57234 .29664 m
.57316 .33848 L
s
.352 .327 1 r
.2672 .29664 m
.26438 .33514 L
s
.88 .191 1 r
.1584 .35367 m
.15736 .36301 L
s
.15744 .36289 m
.1584 .35367 L
s
.777 .214 1 r
.68397 .36679 m
.6839 .3668 L
s
.744 .222 1 r
.81867 .35092 m
.81947 .36003 L
s
.8195 .35969 m
.81867 .35092 L
s
.88 .191 1 r
.15736 .36301 m
.15841 .35363 L
s
.15841 .35363 m
.15744 .36289 L
s
.628 .249 1 r
.31816 .33637 m
.31759 .34515 L
s
.31761 .3451 m
.31816 .33637 L
s
.31816 .33637 m
.3171 .35378 L
s
.418 .307 1 r
.86334 .33152 m
.86416 .33987 L
s
.86419 .33983 m
.86334 .33152 L
s
.86334 .33152 m
.86501 .3476 L
s
.744 .222 1 r
.81947 .36003 m
.8187 .35087 L
s
.8187 .35087 m
.8195 .35969 L
s
.733 .224 1 r
.73395 .36434 m
.73391 .36464 L
s
.7 .232 1 r
.73744 .29639 m
.74048 .34009 L
s
.752 1 .697 r
.43225 .29639 m
.43179 .31644 L
s
.337 .353 1 r
.12706 .29639 m
.12261 .33489 L
s
.777 .214 1 r
.67861 .35067 m
.67903 .35989 L
s
.67907 .35944 m
.67861 .35067 L
s
.512 .279 1 r
.50821 .33475 m
.50814 .34322 L
s
.50816 .34318 m
.50821 .33475 L
s
.50821 .33475 m
.50815 .35155 L
s
.777 .214 1 r
.67903 .35989 m
.67864 .35063 L
s
.67864 .35063 m
.67907 .35944 L
s
.711 .229 1 r
.48323 .33616 m
.48309 .34519 L
s
.48311 .34515 m
.48323 .33616 L
s
.48323 .33616 m
.48304 .3539 L
s
1 .149 .907 r
.13336 .35564 m
.13219 .36543 L
s
.13229 .36523 m
.13336 .35564 L
s
.433 .302 1 r
.83391 .35906 m
.83387 .3592 L
s
.711 .229 1 r
.2333 .35013 m
.2325 .35916 L
s
.23259 .35882 m
.2333 .35013 L
s
1 .149 .907 r
.13219 .36543 m
.13337 .35559 L
s
.13337 .35559 m
.13229 .36523 L
s
.711 .229 1 r
.2325 .35916 m
.23331 .35009 L
s
.23331 .35009 m
.23259 .35882 L
s
.588 .259 1 r
.33863 .36127 m
.33855 .3616 L
s
.638 .247 1 r
.09317 .34959 m
.09201 .3584 L
s
.0921 .35821 m
.09317 .34959 L
s
.68 .237 1 r
.59735 .29614 m
.59851 .33909 L
s
.744 .222 1 r
.29212 .29613 m
.2892 .34058 L
s
.638 .247 1 r
.09201 .3584 m
.09318 .34955 L
s
.09318 .34955 m
.0921 .35821 L
s
.25826 .34905 m
.25754 .35789 L
s
.25763 .35759 m
.25826 .34905 L
s
.25754 .35789 m
.25828 .34901 L
s
.25828 .34901 m
.25763 .35759 L
s
.365 .486 1 r
.60817 .32972 m
.60833 .33741 L
s
.60835 .33737 m
.60817 .32972 L
s
.60817 .32972 m
.60857 .34476 L
s
.66 .241 1 r
.72863 .34851 m
.72917 .35746 L
s
.7292 .35698 m
.72863 .34851 L
s
1 .133 .827 r
.40826 .34086 m
.40788 .35081 L
s
.4079 .35077 m
.40826 .34086 L
s
.40826 .34086 m
.4076 .36058 L
s
.619 .252 1 r
.20296 .33533 m
.20209 .34411 L
s
.2021 .34406 m
.20296 .33533 L
s
.20296 .33533 m
.20131 .35266 L
s
.66 .241 1 r
.72917 .35746 m
.72865 .34846 L
s
.72865 .34846 m
.7292 .35698 L
s
.892 .189 1 r
.23864 .36729 m
.23856 .36745 L
s
.559 .267 1 r
.36359 .36041 m
.36351 .36074 L
s
.424 .305 1 r
.39306 .33338 m
.39271 .3416 L
s
.39273 .34156 m
.39306 .33338 L
s
.39306 .33338 m
.39244 .3497 L
s
.395 .62 1 r
.76249 .29588 m
.76521 .33105 L
s
.424 .305 1 r
.45722 .29588 m
.45661 .3355 L
s
.648 .244 1 r
.15195 .29588 m
.14726 .33922 L
s
.766 .217 1 r
.26361 .36606 m
.26355 .36603 L
s
.352 .327 1 r
.29841 .35574 m
.29833 .35607 L
s
.639 .247 1 r
.56351 .34963 m
.5636 .35841 L
s
.56366 .35833 m
.56351 .34963 L
s
.569 .264 1 r
.19843 .36139 m
.19835 .36154 L
s
1 .156 .946 r
.45824 .33855 m
.45801 .34835 L
s
.45803 .3483 m
.45824 .33855 L
s
.45824 .33855 m
.45788 .35773 L
s
.639 .247 1 r
.5636 .35841 m
.56353 .34959 L
s
.56353 .34959 m
.56366 .35833 L
s
.609 .254 1 r
.66888 .36077 m
.66883 .36119 L
s
.54 .272 1 r
.2279 .33447 m
.22711 .34302 L
s
.22713 .34298 m
.2279 .33447 L
s
.2279 .33447 m
.22641 .35143 L
s
.649 .244 1 r
.62237 .29563 m
.62383 .33785 L
s
.521 .277 1 r
.31706 .29563 m
.31465 .3371 L
s
.649 .244 1 r
.58851 .34855 m
.58867 .35744 L
s
.58873 .3571 m
.58851 .34855 L
s
.58867 .35744 m
.58853 .34851 L
s
.58853 .34851 m
.58873 .3571 L
s
1 .151 .919 r
.54391 .36803 m
.54385 .36853 L
s
.408 .31 1 r
.88404 .35771 m
.88401 .35785 L
s
.411 .309 1 r
.79389 .35426 m
.7939 .35508 L
s
.869 .194 1 r
.64839 .33704 m
.64871 .34643 L
s
.64874 .34638 m
.64839 .33704 L
s
.64839 .33704 m
.6491 .35551 L
s
.391 .315 1 r
.60371 .35648 m
.60367 .35677 L
s
.822 .204 1 r
.78756 .29537 m
.79139 .34058 L
s
.35 .414 1 r
.48221 .29537 m
.48191 .33277 L
s
.54 .272 1 r
.17685 .29537 m
.17264 .33723 L
s
.733 .224 1 r
.42334 .34969 m
.42305 .35876 L
s
.42313 .35846 m
.42334 .34969 L
s
.68 .237 1 r
.80908 .36213 m
.80905 .36247 L
s
.50373 .36213 m
.50366 .36247 L
s
.7537 .34831 m
.75431 .35731 L
s
.75434 .35686 m
.7537 .34831 L
s
.598 .257 1 r
.44833 .34831 m
.44813 .35701 L
s
.44819 .35686 m
.44833 .34831 L
s
.503 .282 1 r
.16797 .34693 m
.16705 .35537 L
s
.16713 .35525 m
.16797 .34693 L
s
.467 .292 1 r
.41803 .33303 m
.41773 .34139 L
s
.41775 .34135 m
.41803 .33303 L
s
.41803 .33303 m
.41752 .34957 L
s
.733 .224 1 r
.42305 .35876 m
.42336 .34964 L
s
.42336 .34964 m
.42313 .35846 L
s
.777 .214 1 r
.36804 .33585 m
.36757 .34504 L
s
.36759 .345 m
.36804 .33585 L
s
.36804 .33585 m
.36721 .3539 L
s
.598 .257 1 r
.44813 .35701 m
.44835 .34827 L
s
.44835 .34827 m
.44819 .35686 L
s
.68 .237 1 r
.75431 .35731 m
.75373 .34827 L
s
.75373 .34827 m
.75434 .35686 L
s
.503 .282 1 r
.16705 .35537 m
.16798 .34689 L
s
.16798 .34689 m
.16713 .35525 L
s
.55 .269 1 r
.08765 .33451 m
.0865 .34307 L
s
.08652 .34303 m
.08765 .33451 L
s
.08765 .33451 m
.08544 .35155 L
s
.337 .332 1 r
.10277 .34226 m
.10174 .35031 L
s
.10186 .34983 m
.10277 .34226 L
s
.531 .274 1 r
.58322 .33252 m
.58334 .34115 L
s
.58336 .34111 m
.58322 .33252 L
s
.58322 .33252 m
.58354 .34933 L
s
.337 .332 1 r
.10174 .35031 m
.10278 .34222 L
s
.10278 .34222 m
.10186 .34983 L
s
1 .153 .933 r
.6474 .29512 m
.64938 .34182 L
s
.345 .391 1 r
.34201 .29512 m
.34008 .33326 L
s
.845 .199 1 r
.67342 .33629 m
.67381 .34563 L
s
.67383 .34559 m
.67342 .33629 L
s
.67342 .33629 m
.67427 .35464 L
s
.628 .249 1 r
.77874 .34752 m
.77942 .35637 L
s
.77944 .35599 m
.77874 .34752 L
s
.77942 .35637 m
.77877 .34748 L
s
.77877 .34748 m
.77944 .35599 L
s
.424 .305 1 r
.46353 .3566 m
.46347 .35693 L
s
.68 .237 1 r
.61354 .34836 m
.61377 .35732 L
s
.61382 .35698 m
.61354 .34836 L
s
.503 .282 1 r
.74844 .33239 m
.74899 .3409 L
s
.74901 .34086 m
.74844 .33239 L
s
.74844 .33239 m
.74959 .34908 L
s
.36 .325 1 r
.81264 .29487 m
.8162 .33338 L
s
.701 .232 1 r
.5072 .29487 m
.50719 .33858 L
s
.628 .249 1 r
.20177 .29487 m
.19777 .33784 L
s
.68 .237 1 r
.61377 .35732 m
.61356 .34831 L
s
.61356 .34831 m
.61382 .35698 L
s
.904 .186 1 r
.39831 .35195 m
.39794 .36137 L
s
.39802 .36117 m
.39831 .35195 L
s
.744 .221 1 r
.14288 .34919 m
.14182 .35831 L
s
.14193 .35796 m
.14288 .34919 L
s
.723 .226 1 r
.47333 .34782 m
.47318 .35696 L
s
.47325 .35636 m
.47333 .34782 L
s
.578 .262 1 r
.11256 .33391 m
.11146 .34257 L
s
.11148 .34253 m
.11256 .33391 L
s
.11256 .33391 m
.11046 .35106 L
s
.799 .209 1 r
.17327 .36447 m
.17318 .36466 L
s
.904 .186 1 r
.39794 .36137 m
.39833 .3519 L
s
.39833 .3519 m
.39802 .36117 L
s
.744 .221 1 r
.14182 .35831 m
.14289 .34915 L
s
.14289 .34915 m
.14193 .35796 L
s
.723 .226 1 r
.47318 .35696 m
.47335 .34777 L
s
.47335 .34777 m
.47325 .35636 L
s
.754 .219 1 r
.89399 .35003 m
.89499 .35911 L
s
.89504 .35895 m
.89399 .35003 L
s
.744 .222 1 r
.28309 .35003 m
.28242 .35907 L
s
.28249 .35895 m
.28309 .35003 L
s
.335 .34 1 r
.49302 .32985 m
.49292 .33784 L
s
.49293 .3378 m
.49302 .32985 L
s
.49302 .32985 m
.49289 .3455 L
s
.395 .62 1 r
.11786 .3507 m
.1178 .3508 L
s
.978 .171 1 r
.89939 .36669 m
.89936 .36699 L
s
.846 .199 1 r
.69846 .33546 m
.69892 .34484 L
s
.69894 .3448 m
.69846 .33546 L
s
.69846 .33546 m
.69944 .35378 L
s
.754 .219 1 r
.89499 .35911 m
.89402 .34999 L
s
.89402 .34999 m
.89504 .35895 L
s
.744 .222 1 r
.28242 .35907 m
.2831 .34999 L
s
.2831 .34999 m
.28249 .35895 L
s
.744 .221 1 r
.55823 .33488 m
.5583 .344 L
s
.55832 .34396 m
.55823 .33488 L
s
.55823 .33488 m
.55844 .35279 L
s
.588 .259 1 r
.72346 .3342 m
.72395 .34287 L
s
.72398 .34283 m
.72346 .3342 L
s
.72346 .3342 m
.72452 .35143 L
s
.352 .327 1 r
.67244 .29461 m
.67435 .33276 L
s
.618 .252 1 r
.36697 .29461 m
.36516 .33684 L
s
.744 .222 1 r
.30808 .34895 m
.30747 .35806 L
s
.30756 .35772 m
.30808 .34895 L
s
.559 .267 1 r
.66358 .34619 m
.66393 .35485 L
s
.66398 .35451 m
.66358 .34619 L
s
.744 .222 1 r
.30747 .35806 m
.30809 .3489 L
s
.30809 .3489 m
.30756 .35772 L
s
.608 .254 1 r
.24825 .36078 m
.24817 .36097 L
s
.559 .267 1 r
.66393 .35485 m
.6636 .34615 L
s
.6636 .34615 m
.66398 .35451 L
s
.382 .563 1 r
.26256 .32609 m
.26193 .3337 L
s
.26195 .33366 m
.26256 .32609 L
s
.26256 .32609 m
.26142 .34068 L
s
.494 .284 1 r
.82884 .34565 m
.8296 .35408 L
s
.82964 .3539 m
.82884 .34565 L
s
.8296 .35408 m
.82886 .34561 L
s
.82886 .34561 m
.82964 .3539 L
s
.904 .186 1 r
.31345 .36582 m
.31337 .36602 L
s
.57 .264 1 r
.83773 .29436 m
.84192 .33622 L
s
.589 .259 1 r
.53221 .29436 m
.53252 .33622 L
s
.638 .247 1 r
.2267 .29436 m
.22302 .33734 L
s
1 .108 .687 r
.65378 .35559 m
.65417 .36585 L
s
.65422 .36549 m
.65378 .35559 L
s
1 .149 .908 r
.78872 .3396 m
.78946 .34933 L
s
.78949 .34928 m
.78872 .3396 L
s
.78872 .3396 m
.79029 .3591 L
s
.649 .244 1 r
.80385 .34732 m
.80459 .35621 L
s
.80462 .35587 m
.80385 .34732 L
s
1 .108 .687 r
.65417 .36585 m
.6538 .35554 L
s
.6538 .35554 m
.65422 .36549 L
s
.352 .426 1 r
.29284 .34181 m
.2923 .34953 L
s
.29236 .34946 m
.29284 .34181 L
s
.711 .229 1 r
.88878 .33417 m
.88974 .34321 L
s
.88977 .34317 m
.88878 .33417 L
s
.88878 .33417 m
.89075 .35192 L
s
.649 .244 1 r
.80459 .35621 m
.80388 .34728 L
s
.80388 .34728 m
.80462 .35587 L
s
.352 .426 1 r
.2923 .34953 m
.29286 .34177 L
s
.29286 .34177 m
.29236 .34946 L
s
1 .138 .854 r
.40367 .36964 m
.40359 .36977 L
s
.734 .224 1 r
.33306 .34816 m
.33252 .35727 L
s
.33261 .35686 m
.33306 .34816 L
s
.33252 .35727 m
.33307 .34811 L
s
.33307 .34811 m
.33261 .35686 L
s
.424 .305 1 r
.34826 .35586 m
.34818 .35619 L
s
.598 .257 1 r
.13744 .33367 m
.1364 .34237 L
s
.13641 .34233 m
.13744 .33367 L
s
.13744 .33367 m
.13545 .35093 L
s
.467 .895 1 r
.83339 .32049 m
.83401 .32734 L
s
.83403 .32731 m
.83339 .32049 L
s
.83339 .32049 m
.83461 .33328 L
s
.723 .226 1 r
.19278 .34762 m
.19186 .35673 L
s
.19197 .35624 m
.19278 .34762 L
s
.608 .254 1 r
.6975 .29411 m
.69993 .33634 L
s
.485 .287 1 r
.39195 .29411 m
.39044 .33634 L
s
.701 .232 1 r
.08639 .29411 m
.08068 .33858 L
s
.723 .226 1 r
.19186 .35673 m
.1928 .34757 L
s
.1928 .34757 m
.19197 .35624 L
s
.55 .269 1 r
.38307 .3457 m
.38269 .35432 L
s
.38276 .35402 m
.38307 .3457 L
s
.38269 .35432 m
.38309 .34566 L
s
.38309 .34566 m
.38276 .35402 L
s
.504 .282 1 r
.48853 .35685 m
.48846 .35729 L
s
.765 .217 1 r
.52873 .36312 m
.52867 .36331 L
s
.649 .244 1 r
.52335 .34653 m
.52333 .35546 L
s
.5234 .35501 m
.52335 .34653 L
s
.928 .181 1 r
.78428 .36595 m
.78423 .36611 L
s
.649 .244 1 r
.52333 .35546 m
.52337 .34649 L
s
.52337 .34649 m
.5234 .35501 L
s
.628 .249 1 r
.35804 .34737 m
.35759 .35615 L
s
.35766 .356 m
.35804 .34737 L
s
.7 .232 1 r
.86283 .29385 m
.86754 .33758 L
s
.916 .184 1 r
.55724 .29385 m
.55792 .33944 L
s
1 .141 .867 r
.25164 .29385 m
.24785 .34243 L
s
.628 .249 1 r
.35759 .35615 m
.35805 .34733 L
s
.35805 .34733 m
.35766 .356 L
s
.712 .229 1 r
.27318 .36066 m
.27308 .36111 L
s
.701 .231 1 r
.57878 .36066 m
.57872 .36108 L
s
1 .156 .946 r
.61899 .36694 m
.61894 .36725 L
s
.892 .189 1 r
.25265 .33639 m
.25185 .34578 L
s
.25187 .34573 m
.25265 .33639 L
s
.25265 .33639 m
.25115 .35502 L
s
.8 .209 1 r
.69406 .36288 m
.69401 .36318 L
s
.638 .247 1 r
.46799 .33302 m
.46781 .34188 L
s
.46784 .34184 m
.46799 .33302 L
s
.46799 .33302 m
.46772 .35044 L
s
.561 .266 1 r
.51804 .33034 m
.518 .33911 L
s
.51801 .33907 m
.51804 .33034 L
s
.51804 .33034 m
.51803 .34722 L
s
1 .154 .934 r
.14804 .36792 m
.14796 .36805 L
s
.744 .222 1 r
.30267 .33389 m
.30203 .34301 L
s
.30205 .34297 m
.30267 .33389 L
s
.30267 .33389 m
.3015 .3518 L
s
.467 .292 1 r
.57339 .34437 m
.5735 .35273 L
s
.57356 .35254 m
.57339 .34437 L
s
.744 .222 1 r
.72257 .2936 m
.72542 .33733 L
s
.559 .267 1 r
.41694 .2936 m
.41579 .33509 L
s
.531 .274 1 r
.1113 .2936 m
.10629 .33509 L
s
1 .141 .868 r
.86921 .35348 m
.87022 .36335 L
s
.87027 .36315 m
.86921 .35348 L
s
.467 .292 1 r
.5735 .35273 m
.57341 .34433 L
s
.57341 .34433 m
.57356 .35254 L
s
.869 .194 1 r
.63864 .34934 m
.63895 .35876 L
s
.639 .35834 m
.63864 .34934 L
s
.669 .239 1 r
.74412 .36042 m
.74408 .36072 L
s
.352 .327 1 r
.70839 .3285 m
.70881 .3366 L
s
.70883 .33656 m
.70839 .3285 L
s
.70839 .3285 m
.70928 .34426 L
s
1 .141 .868 r
.87022 .36335 m
.86924 .35343 L
s
.86924 .35343 m
.87027 .36315 L
s
.799 .209 1 r
.38843 .36325 m
.38835 .36344 L
s
.869 .194 1 r
.63895 .35876 m
.63866 .34929 L
s
.63866 .34929 m
.639 .35834 L
s
.711 .229 1 r
.77365 .33342 m
.77429 .34247 L
s
.77432 .34243 m
.77365 .33342 L
s
.77365 .33342 m
.775 .35118 L
s
.811 .206 1 r
.49833 .3488 m
.49824 .35807 L
s
.49831 .35772 m
.49833 .3488 L
s
.733 .224 1 r
.71911 .36202 m
.71906 .36221 L
s
.811 .206 1 r
.49824 .35807 m
.49835 .34875 L
s
.49835 .34875 m
.49831 .35772 L
s
.578 .262 1 r
.16231 .33357 m
.16135 .34217 L
s
.16136 .34213 m
.16231 .33357 L
s
.16231 .33357 m
.16046 .35081 L
s
.722 .227 1 r
.43847 .36079 m
.43839 .36116 L
s
.756 .219 1 r
.58228 .29334 m
.58326 .3367 L
s
.4 .312 1 r
.2766 .29334 m
.27383 .33261 L
s
.365 .485 1 r
.53317 .3386 m
.53319 .34632 L
s
.53324 .34588 m
.53317 .3386 L
s
.53319 .34632 m
.53319 .33857 L
s
.53319 .33857 m
.53324 .34588 L
s
.892 .189 1 r
.2776 .33589 m
.27688 .34528 L
s
.2769 .34524 m
.2776 .33589 L
s
.2776 .33589 m
.27625 .35452 L
s
.722 .227 1 r
.63335 .33314 m
.63361 .34222 L
s
.63364 .34218 m
.63335 .33314 L
s
.63335 .33314 m
.63395 .35093 L
s
.569 .264 1 r
.18731 .33245 m
.18641 .34109 L
s
.18643 .34104 m
.18731 .33245 L
s
.18731 .33245 m
.1856 .34957 L
s
.618 .252 1 r
.32315 .35894 m
.32307 .35928 L
s
.733 .224 1 r
.21764 .34801 m
.21679 .35705 L
s
.21687 .35686 m
.21764 .34801 L
s
.669 .239 1 r
.85409 .34663 m
.85497 .35556 L
s
.855 .35526 m
.85409 .34663 L
s
.94 .179 1 r
.44296 .3355 m
.44269 .34504 L
s
.44271 .34499 m
.44296 .3355 L
s
.44296 .3355 m
.44252 .35427 L
s
1 .062 .414 r
.83898 .339 m
.83996 .34982 L
s
.84 .34977 m
.83898 .339 L
s
.83898 .339 m
.84099 .35997 L
s
.503 .282 1 r
.74766 .29309 m
.75063 .33385 L
s
.589 .259 1 r
.44194 .29309 m
.44111 .33459 L
s
.344 .33 1 r
.13622 .29309 m
.13182 .33199 L
s
.733 .224 1 r
.21679 .35705 m
.21765 .34796 L
s
.21765 .34796 m
.21687 .35686 L
s
.669 .239 1 r
.85497 .35556 m
.85412 .34659 L
s
.85412 .34659 m
.855 .35526 L
s
.57 .264 1 r
.51355 .35709 m
.51348 .35758 L
s
.405 .662 1 r
.68874 .34737 m
.6887 .34766 L
s
.94 .179 1 r
.223 .36497 m
.22292 .36517 L
s
.711 .229 1 r
.32761 .33384 m
.32705 .34281 L
s
.32707 .34277 m
.32761 .33384 L
s
.32761 .33384 m
.32658 .35168 L
s
.375 .32 1 r
.09694 .32971 m
.09588 .33778 L
s
.09589 .33774 m
.09694 .32971 L
s
.09694 .32971 m
.09489 .34574 L
s
.4 .312 1 r
.60733 .29284 m
.60851 .33211 L
s
.618 .252 1 r
.30157 .29284 m
.29891 .33508 L
s
.669 .239 1 r
.71379 .34668 m
.71429 .35557 L
s
.71434 .35538 m
.71379 .34668 L
s
.71429 .35557 m
.71382 .34663 L
s
.71382 .34663 m
.71434 .35538 L
s
.744 .221 1 r
.65842 .3329 m
.65876 .34202 L
s
.65878 .34197 m
.65842 .3329 L
s
.65842 .3329 m
.65917 .35081 L
s
.845 .199 1 r
.4134 .3635 m
.41333 .36362 L
s
.608 .254 1 r
.37766 .33156 m
.37724 .34034 L
s
.37726 .3403 m
.37766 .33156 L
s
.37766 .33156 m
.37691 .34883 L
s
.744 .222 1 r
.77276 .29258 m
.77628 .33632 L
s
.539 1 .893 r
.46696 .29258 m
.46661 .32075 L
s
.68 .237 1 r
.16115 .29258 m
.15658 .33595 L
s
.608 .254 1 r
.73885 .34559 m
.7394 .35433 L
s
.73945 .35415 m
.73885 .34559 L
s
.467 .292 1 r
.15226 .34421 m
.15131 .3525 L
s
.15137 .35254 m
.15226 .34421 L
s
.702 .231 1 r
.84889 .33097 m
.84975 .34009 L
s
.84978 .34005 m
.84889 .33097 L
s
.84889 .33097 m
.85064 .34858 L
s
.467 .292 1 r
.40268 .33029 m
.40235 .33866 L
s
.40237 .33862 m
.40268 .33029 L
s
.40268 .33029 m
.4021 .34685 L
s
.608 .254 1 r
.7394 .35433 m
.73887 .34555 L
s
.73887 .34555 m
.73945 .35415 L
s
.618 .252 1 r
.21222 .33243 m
.21137 .34118 L
s
.21138 .34114 m
.21222 .33243 L
s
.21222 .33243 m
.21061 .34982 L
s
.467 .292 1 r
.15131 .3525 m
.15227 .34417 L
s
.15227 .34417 m
.15137 .35254 L
s
.477 .289 1 r
.87393 .32967 m
.87479 .33812 L
s
.87481 .33808 m
.87393 .32967 L
s
.87393 .32967 m
.87569 .34623 L
s
.628 .249 1 r
.12719 .34589 m
.12613 .35467 L
s
.12621 .35452 m
.12719 .34589 L
s
.559 .267 1 r
.53858 .35697 m
.53852 .35731 L
s
.375 .32 1 r
.81398 .34175 m
.81468 .34981 L
s
.81472 .3497 m
.81398 .34175 L
s
.589 .259 1 r
.63239 .29233 m
.63396 .33384 L
s
.833 .201 1 r
.32655 .29233 m
.32405 .33756 L
s
.628 .249 1 r
.12613 .35467 m
.1272 .34585 L
s
.1272 .34585 m
.12621 .35452 L
s
.375 .32 1 r
.81468 .34981 m
.81401 .34171 L
s
.81401 .34171 m
.81472 .3497 L
s
.845 .199 1 r
.3526 .33356 m
.35209 .34291 L
s
.3521 .34286 m
.3526 .33356 L
s
.3526 .33356 m
.35167 .35192 L
s
.649 .244 1 r
.54308 .33149 m
.5431 .34039 L
s
.54312 .34034 m
.54308 .33149 L
s
.54308 .33149 m
.5432 .34895 L
s
.754 .219 1 r
.76932 .36141 m
.76927 .36156 L
s
.55 .269 1 r
.23721 .33153 m
.23645 .34009 L
s
.23646 .34005 m
.23721 .33153 L
s
.23721 .33153 m
.23576 .34858 L
s
.578 .262 1 r
.37313 .35796 m
.37306 .35815 L
s
.811 .206 1 r
.62892 .36079 m
.62887 .36125 L
s
.579 .262 1 r
.84445 .35735 m
.84443 .35764 L
s
.965 .174 1 r
.79888 .33443 m
.79964 .34404 L
s
.79967 .344 m
.79888 .33443 L
s
.79888 .33443 m
.80046 .35329 L
s
.822 .204 1 r
.24252 .3484 m
.24172 .35764 L
s
.2418 .35748 m
.24252 .3484 L
s
.559 .267 1 r
.70404 .35673 m
.704 .35706 L
s
.822 .204 1 r
.24172 .35764 m
.24254 .34836 L
s
.24254 .34836 m
.2418 .35748 L
s
.99 .169 1 r
.79787 .29207 m
.80195 .33843 L
s
.417 .307 1 r
.49199 .29207 m
.4918 .33135 L
s
.427 .751 1 r
.1861 .29207 m
.18292 .32468 L
s
.638 .247 1 r
.20765 .35894 m
.20757 .35913 L
s
.648 .244 1 r
.76395 .3451 m
.76459 .35399 L
s
.76462 .35365 m
.76395 .3451 L
s
.69 .234 1 r
.68351 .33259 m
.6839 .34152 L
s
.68393 .34148 m
.68351 .33259 L
s
.68351 .33259 m
.68438 .35031 L
s
.648 .244 1 r
.76459 .35399 m
.76398 .34506 L
s
.76398 .34506 m
.76462 .35365 L
s
.754 .219 1 r
.26754 .34732 m
.26682 .3564 L
s
.2669 .35625 m
.26754 .34732 L
s
.733 .224 1 r
.18259 .36055 m
.1825 .36074 L
s
.754 .219 1 r
.26682 .3564 m
.26755 .34727 L
s
.26755 .34727 m
.2669 .35625 L
s
.367 .322 1 r
.28725 .32933 m
.28665 .33732 L
s
.28667 .33729 m
.28725 .32933 L
s
.28725 .32933 m
.28612 .34536 L
s
.418 .307 1 r
.86416 .33987 m
.86502 .34823 L
s
.86501 .3476 m
.86416 .33987 L
s
.618 .252 1 r
.65747 .29182 m
.65937 .3337 L
s
.588 .259 1 r
.35154 .29182 m
.34951 .33445 L
s
.418 .307 1 r
.86502 .34823 m
.86419 .33983 L
s
.86419 .33983 m
.86501 .3476 L
s
.559 .267 1 r
.34265 .34347 m
.34217 .35214 L
s
.34225 .3518 m
.34265 .34347 L
s
.648 .244 1 r
.56814 .33099 m
.56822 .33989 L
s
.56825 .33985 m
.56814 .33099 L
s
.56814 .33099 m
.56839 .34845 L
s
.559 .267 1 r
.34217 .35214 m
.34267 .34343 L
s
.34267 .34343 m
.34225 .3518 L
s
.811 .206 1 r
.43301 .34707 m
.43274 .35634 L
s
.43281 .356 m
.43301 .34707 L
s
.43274 .35634 m
.43302 .34702 L
s
.43302 .34702 m
.43281 .356 L
s
.365 .486 1 r
.60833 .33741 m
.60852 .34509 L
s
.60857 .34476 m
.60833 .33741 L
s
1 0 0 r
.17722 .34437 m
.17602 .35556 L
s
.17604 .3555 m
.17722 .34437 L
s
.17722 .34437 m
.1749 .36692 L
s
.744 .222 1 r
.8195 .35969 m
.81947 .36003 L
s
.365 .486 1 r
.60852 .34509 m
.60835 .33737 L
s
.60835 .33737 m
.60857 .34476 L
s
.712 .229 1 r
.62355 .34515 m
.62382 .35423 L
s
.62387 .35378 m
.62355 .34515 L
s
.628 .249 1 r
.31759 .34515 m
.31703 .35393 L
s
.3171 .35378 m
.31759 .34515 L
s
.777 .214 1 r
.823 .29156 m
.82722 .33569 L
s
.766 .217 1 r
.51703 .29156 m
.51715 .33606 L
s
.669 .239 1 r
.21106 .29156 m
.20703 .33606 L
s
.628 .249 1 r
.31703 .35393 m
.31761 .3451 L
s
.31761 .3451 m
.3171 .35378 L
s
.712 .229 1 r
.62382 .35423 m
.62358 .3451 L
s
.62358 .3451 m
.62387 .35378 L
s
.512 .279 1 r
.50814 .34322 m
.50809 .3517 L
s
.50815 .35155 m
.50814 .34322 L
s
.50809 .3517 m
.50816 .34318 L
s
.50816 .34318 m
.50815 .35155 L
s
.649 .244 1 r
.1217 .33074 m
.12059 .33964 L
s
.1206 .3396 m
.1217 .33074 L
s
.1217 .33074 m
.1196 .3482 L
s
.977 .171 1 r
.54841 .34958 m
.54847 .35916 L
s
.54853 .35896 m
.54841 .34958 L
s
.811 .206 1 r
.59851 .34682 m
.59871 .35609 L
s
.59877 .35575 m
.59851 .34682 L
s
.977 .171 1 r
.54847 .35916 m
.54843 .34954 L
s
.54843 .34954 m
.54853 .35896 L
s
.811 .206 1 r
.59871 .35609 m
.59854 .34678 L
s
.59854 .34678 m
.59877 .35575 L
s
.608 .254 1 r
.73367 .33089 m
.73419 .33964 L
s
.73421 .3396 m
.73367 .33089 L
s
.73367 .33089 m
.73478 .34821 L
s
.88 .191 1 r
.15744 .36289 m
.15736 .36301 L
s
.777 .214 1 r
.67907 .35944 m
.67903 .35989 L
s
.618 .252 1 r
.68256 .29131 m
.68478 .3332 L
s
.638 .247 1 r
.37655 .29131 m
.37485 .33395 L
s
.367 .322 1 r
.07055 .29131 m
.06537 .33023 L
s
.711 .229 1 r
.23259 .35882 m
.2325 .35916 L
s
.953 .176 1 r
.87948 .3485 m
.8805 .35807 L
s
.88052 .35773 m
.87948 .3485 L
s
.638 .247 1 r
.0921 .35821 m
.09201 .3584 L
s
.578 .262 1 r
.5932 .33042 m
.59335 .3391 L
s
.59337 .33905 m
.5932 .33042 L
s
.5932 .33042 m
.59358 .34759 L
s
.424 .305 1 r
.39271 .3416 m
.39237 .34981 L
s
.39244 .3497 m
.39271 .3416 L
s
.953 .176 1 r
.8805 .35807 m
.87951 .34845 L
s
.87951 .34845 m
.88052 .35773 L
s
.638 .247 1 r
.25763 .35759 m
.25754 .35789 L
s
.34 .366 1 r
.19679 .32702 m
.19599 .3349 L
s
.196 .33486 m
.19679 .32702 L
s
.19679 .32702 m
.19527 .34264 L
s
.424 .305 1 r
.39237 .34981 m
.39273 .34156 L
s
.39273 .34156 m
.39244 .3497 L
s
.711 .229 1 r
.48309 .34519 m
.48297 .35424 L
s
.48304 .3539 m
.48309 .34519 L
s
.66 .241 1 r
.7292 .35698 m
.72917 .35746 L
s
.711 .229 1 r
.48297 .35424 m
.48311 .34515 L
s
.48311 .34515 m
.48304 .3539 L
s
.733 .224 1 r
.42766 .33144 m
.42737 .34053 L
s
.42739 .34049 m
.42766 .33144 L
s
.42766 .33144 m
.42716 .34932 L
s
.811 .206 1 r
.84813 .29105 m
.8527 .33518 L
s
.54209 .29105 m
.54255 .33555 L
s
.598 .257 1 r
.23604 .29105 m
.23251 .33369 L
s
.952 .176 1 r
.8241 .33496 m
.82491 .34443 L
s
.82494 .34439 m
.8241 .33496 L
s
.8241 .33496 m
.82583 .3539 L
s
.619 .252 1 r
.20209 .34411 m
.20122 .35289 L
s
.20131 .35266 m
.20209 .34411 L
s
.20122 .35289 m
.2021 .34406 L
s
.2021 .34406 m
.20131 .35266 L
s
.337 .332 1 r
.10186 .34983 m
.10174 .35031 L
s
.55 .269 1 r
.3122 .3297 m
.31162 .3383 L
s
.31163 .33826 m
.3122 .3297 L
s
.3122 .3297 m
.31113 .34672 L
s
1 .149 .907 r
.13229 .36523 m
.13219 .36543 L
s
.54 .272 1 r
.22711 .34302 m
.22634 .35158 L
s
.22641 .35143 m
.22711 .34302 L
s
.669 .239 1 r
.75879 .3305 m
.75939 .33944 L
s
.75942 .3394 m
.75879 .3305 L
s
.75879 .3305 m
.76006 .34808 L
s
.744 .222 1 r
.70766 .2908 m
.71032 .33456 L
s
.36 .463 1 r
.40158 .2908 m
.40036 .32823 L
s
.45 .297 1 r
.09549 .2908 m
.09036 .33158 L
s
.639 .247 1 r
.56366 .35833 m
.5636 .35841 L
s
.54 .272 1 r
.22634 .35158 m
.22713 .34298 L
s
.22713 .34298 m
.22641 .35143 L
s
.649 .244 1 r
.58873 .3571 m
.58867 .35744 L
s
.56 .267 1 r
.47776 .32942 m
.47761 .33806 L
s
.47763 .33802 m
.47776 .32942 L
s
.47776 .32942 m
.47754 .34647 L
s
.744 .222 1 r
.4527 .3309 m
.45248 .34003 L
s
.4525 .33999 m
.4527 .3309 L
s
.4527 .3309 m
.45234 .34882 L
s
.503 .282 1 r
.16713 .35525 m
.16705 .35537 L
s
.467 .292 1 r
.41773 .34139 m
.41745 .34976 L
s
.41752 .34957 m
.41773 .34139 L
s
.811 .206 1 r
.87329 .29055 m
.87819 .33468 L
s
.916 .184 1 r
.56716 .29054 m
.56798 .33617 L
s
.367 .322 1 r
.26103 .29054 m
.25807 .32984 L
s
.344 .33 1 r
.38734 .32612 m
.38698 .33415 L
s
.387 .33411 m
.38734 .32612 L
s
.38734 .32612 m
.38671 .34189 L
s
.467 .292 1 r
.41745 .34976 m
.41775 .34135 L
s
.41775 .34135 m
.41752 .34957 L
s
.598 .257 1 r
.44819 .35686 m
.44813 .35701 L
s
.68 .237 1 r
.75434 .35686 m
.75431 .35731 L
s
.55 .269 1 r
.0865 .34307 m
.08536 .35163 L
s
.08544 .35155 m
.0865 .34307 L
s
.649 .244 1 r
.33722 .32916 m
.33668 .3381 L
s
.3367 .33806 m
.33722 .32916 L
s
.33722 .32916 m
.33626 .34659 L
s
.55 .269 1 r
.08536 .35163 m
.08652 .34303 L
s
.08652 .34303 m
.08544 .35155 L
s
1 .133 .827 r
.40788 .35081 m
.40752 .36078 L
s
.4076 .36058 m
.40788 .35081 L
s
.733 .224 1 r
.42313 .35846 m
.42305 .35876 L
s
1 .133 .827 r
.40752 .36078 m
.4079 .35077 L
s
.4079 .35077 m
.4076 .36058 L
s
.531 .274 1 r
.58334 .34115 m
.58348 .34978 L
s
.58354 .34933 m
.58334 .34115 L
s
.342 .378 1 r
.73278 .29029 m
.73537 .3281 L
s
.385 .575 1 r
.42661 .29029 m
.42576 .32513 L
s
.638 .247 1 r
.12044 .29029 m
.11536 .33331 L
s
.531 .274 1 r
.58348 .34978 m
.58336 .34111 L
s
.58336 .34111 m
.58354 .34933 L
s
.467 .895 1 r
.83401 .32734 m
.83465 .33419 L
s
.83461 .33328 m
.83401 .32734 L
s
.335 .34 1 r
.49292 .33784 m
.49283 .34583 L
s
.49289 .3455 m
.49292 .33784 L
s
.467 .895 1 r
.83465 .33419 m
.83403 .32731 L
s
.83403 .32731 m
.83461 .33328 L
s
.777 .214 1 r
.61832 .33087 m
.61855 .34008 L
s
.61857 .34003 m
.61832 .33087 L
s
.61832 .33087 m
.61885 .34895 L
s
.382 .563 1 r
.26193 .3337 m
.26132 .3413 L
s
.26142 .34068 m
.26193 .3337 L
s
1 .156 .946 r
.45801 .34835 m
.45781 .35815 L
s
.45788 .35773 m
.45801 .34835 L
s
.335 .34 1 r
.49283 .34583 m
.49293 .3378 L
s
.49293 .3378 m
.49289 .3455 L
s
.628 .249 1 r
.77944 .35599 m
.77942 .35637 L
s
.382 .563 1 r
.26132 .3413 m
.26195 .33366 L
s
.26195 .33366 m
.26142 .34068 L
s
.723 .226 1 r
.64339 .32956 m
.64369 .33869 L
s
.64371 .33865 m
.64339 .32956 L
s
.64339 .32956 m
.64405 .34733 L
s
1 .156 .946 r
.45781 .35815 m
.45803 .3483 L
s
.45803 .3483 m
.45788 .35773 L
s
.788 .212 1 r
.14648 .33175 m
.14541 .34092 L
s
.14543 .34087 m
.14648 .33175 L
s
.14648 .33175 m
.14444 .34994 L
s
.523 .277 1 r
.52789 .32757 m
.52787 .33617 L
s
.52789 .33613 m
.52789 .32757 L
s
.52789 .32757 m
.52793 .34436 L
s
.658 .242 1 r
.17155 .33037 m
.17058 .33924 L
s
.17059 .33919 m
.17155 .33037 L
s
.17155 .33037 m
.1697 .34796 L
s
.869 .194 1 r
.64871 .34643 m
.64905 .35582 L
s
.6491 .35551 m
.64871 .34643 L
s
.777 .214 1 r
.36757 .34504 m
.36713 .35424 L
s
.36721 .3539 m
.36757 .34504 L
s
.503 .282 1 r
.74899 .3409 m
.74956 .34942 L
s
.74959 .34908 m
.74899 .3409 L
s
.869 .194 1 r
.64905 .35582 m
.64874 .34638 L
s
.64874 .34638 m
.6491 .35551 L
s
.953 .176 1 r
.59224 .29004 m
.59342 .33604 L
s
.766 .216 1 r
.28603 .29003 m
.28304 .33418 L
s
.777 .214 1 r
.36713 .35424 m
.36759 .345 L
s
.36759 .345 m
.36721 .3539 L
s
.503 .282 1 r
.74956 .34942 m
.74901 .34086 L
s
.74901 .34086 m
.74959 .34908 L
s
.68 .237 1 r
.61382 .35698 m
.61377 .35732 L
s
.723 .226 1 r
.47325 .35636 m
.47318 .35696 L
s
.352 .426 1 r
.29236 .34946 m
.2923 .34953 L
s
.578 .262 1 r
.11146 .34257 m
.11037 .35124 L
s
.11046 .35106 m
.11146 .34257 L
s
.11037 .35124 m
.11148 .34253 L
s
.11148 .34253 m
.11046 .35106 L
s
.744 .221 1 r
.14193 .35796 m
.14182 .35831 L
s
.559 .267 1 r
.66398 .35451 m
.66393 .35485 L
s
.81 .206 1 r
.75791 .28978 m
.76135 .33504 L
s
.41 .682 1 r
.45166 .28978 m
.45108 .32389 L
s
.494 .285 1 r
.14541 .28978 m
.14077 .33168 L
s
.494 .284 1 r
.82964 .3539 m
.8296 .35408 L
s
.845 .199 1 r
.67381 .34563 m
.67422 .35499 L
s
.67427 .35464 m
.67381 .34563 L
s
.752 1 .697 r
.43202 .30799 m
.43188 .31242 L
s
.43189 .3124 m
.43202 .30799 L
s
.43202 .30799 m
.43179 .31644 L
s
.588 .259 1 r
.72395 .34287 m
.72446 .35154 L
s
.72452 .35143 m
.72395 .34287 L
s
.845 .199 1 r
.67422 .35499 m
.67383 .34559 L
s
.67383 .34559 m
.67427 .35464 L
s
.588 .259 1 r
.72446 .35154 m
.72398 .34283 L
s
.72398 .34283 m
.72452 .35143 L
s
.648 .244 1 r
.66849 .329 m
.66885 .3379 L
s
.66887 .33786 m
.66849 .329 L
s
.66849 .329 m
.66927 .34647 L
s
.834 .201 1 r
.78402 .3311 m
.78471 .34042 L
s
.78474 .34038 m
.78402 .3311 L
s
.78402 .3311 m
.78548 .34944 L
s
.754 .219 1 r
.89504 .35895 m
.89499 .35911 L
s
.744 .222 1 r
.28249 .35895 m
.28242 .35907 L
s
.904 .186 1 r
.39802 .36117 m
.39794 .36137 L
s
.744 .222 1 r
.30756 .35772 m
.30747 .35806 L
s
.953 .176 1 r
.61734 .28953 m
.61887 .33553 L
s
.669 .239 1 r
.31104 .28952 m
.30839 .33367 L
s
.494 .284 1 r
.85926 .32719 m
.86008 .33567 L
s
.86011 .33563 m
.85926 .32719 L
s
.85926 .32719 m
.86097 .34387 L
s
.744 .221 1 r
.5583 .344 m
.55838 .35313 L
s
.55844 .35279 m
.5583 .344 L
s
.55838 .35313 m
.55832 .34396 L
s
.55832 .34396 m
.55844 .35279 L
s
.649 .244 1 r
.80462 .35587 m
.80459 .35621 L
s
.846 .199 1 r
.69892 .34484 m
.6994 .35423 L
s
.69944 .35378 m
.69892 .34484 L
s
.6994 .35423 m
.69894 .3448 L
s
.69894 .3448 m
.69944 .35378 L
s
.835 .201 1 r
.50283 .33026 m
.50273 .33962 L
s
.50275 .33958 m
.50283 .33026 L
s
.50283 .33026 m
.50273 .34857 L
s
.598 .257 1 r
.22157 .32893 m
.22074 .33765 L
s
.22076 .33761 m
.22157 .32893 L
s
.22157 .32893 m
.22001 .34622 L
s
.55 .269 1 r
.38276 .35402 m
.38269 .35432 L
s
.559 .267 1 r
.78306 .28927 m
.78653 .33081 L
s
.378 .543 1 r
.47672 .28927 m
.47638 .32524 L
s
.881 .191 1 r
.17039 .28927 m
.1657 .3349 L
s
.734 .224 1 r
.33261 .35686 m
.33252 .35727 L
s
.723 .226 1 r
.19197 .35624 m
.19186 .35673 L
s
.598 .257 1 r
.1364 .34237 m
.13537 .35108 L
s
.13545 .35093 m
.1364 .34237 L
s
.701 .232 1 r
.36219 .3298 m
.36172 .33878 L
s
.36174 .33874 m
.36219 .3298 L
s
.36219 .3298 m
.36134 .34758 L
s
.598 .257 1 r
.13537 .35108 m
.13641 .34233 L
s
.13641 .34233 m
.13545 .35093 L
s
.365 .485 1 r
.53324 .34588 m
.53319 .34632 L
s
.531 .274 1 r
.10599 .32712 m
.10488 .33572 L
s
.10489 .33568 m
.10599 .32712 L
s
.10599 .32712 m
.10388 .34399 L
s
.476 .29 1 r
.57806 .32643 m
.57816 .33488 L
s
.57818 .33484 m
.57806 .32643 L
s
.57806 .32643 m
.57834 .343 L
s
.711 .229 1 r
.88974 .34321 m
.89073 .35226 L
s
.89075 .35192 m
.88974 .34321 L
s
.649 .244 1 r
.5234 .35501 m
.52333 .35546 L
s
.711 .229 1 r
.89073 .35226 m
.88977 .34317 L
s
.88977 .34317 m
.89075 .35192 L
s
.45 .297 1 r
.74379 .32596 m
.74431 .33433 L
s
.74434 .33429 m
.74379 .32596 L
s
.74379 .32596 m
.7449 .34237 L
s
.64245 .28901 m
.64407 .32869 L
s
.765 .217 1 r
.33607 .28901 m
.33374 .33354 L
s
.628 .249 1 r
.35766 .356 m
.35759 .35615 L
s
.467 .292 1 r
.57356 .35254 m
.5735 .35273 L
s
.352 .327 1 r
.70881 .3366 m
.70925 .3447 L
s
.70928 .34426 m
.70881 .3366 L
s
.701 .232 1 r
.69364 .32897 m
.69407 .33799 L
s
.69409 .33795 m
.69364 .32897 L
s
.69364 .32897 m
.69457 .34671 L
s
.352 .327 1 r
.70925 .3447 m
.70883 .33656 L
s
.70883 .33656 m
.70928 .34426 L
s
1 .149 .908 r
.78946 .34933 m
.79023 .35907 L
s
.79029 .3591 m
.78946 .34933 L
s
.69 .234 1 r
.24658 .32843 m
.2458 .33745 L
s
.24581 .3374 m
.24658 .32843 L
s
.24658 .32843 m
.24512 .34609 L
s
.68 .237 1 r
.55299 .32847 m
.55304 .33745 L
s
.55306 .3374 m
.55299 .32847 L
s
.55299 .32847 m
.55316 .34609 L
s
.649 .244 1 r
.27166 .32709 m
.27095 .33606 L
s
.27097 .33602 m
.27166 .32709 L
s
.27166 .32709 m
.27036 .34448 L
s
1 .149 .908 r
.79023 .35907 m
.78949 .34928 L
s
.78949 .34928 m
.79029 .3591 L
s
.881 .191 1 r
.80822 .28876 m
.81238 .33441 L
s
.487 .287 1 r
.5018 .28876 m
.50173 .32881 L
s
.702 .231 1 r
.19538 .28876 m
.19137 .33105 L
s
1 .108 .687 r
.65422 .36549 m
.65417 .36585 L
s
.638 .247 1 r
.46781 .34188 m
.46765 .35074 L
s
.46772 .35044 m
.46781 .34188 L
s
.608 .254 1 r
.0808 .32931 m
.07961 .33799 L
s
.07963 .33795 m
.0808 .32931 L
s
.0808 .32931 m
.07849 .34671 L
s
.561 .266 1 r
.518 .33911 m
.51797 .3479 L
s
.51803 .34722 m
.518 .33911 L
s
.638 .247 1 r
.46765 .35074 m
.46784 .34184 L
s
.46784 .34184 m
.46772 .35044 L
s
.561 .266 1 r
.51797 .3479 m
.51801 .33907 L
s
.51801 .33907 m
.51803 .34722 L
s
1 .161 .972 r
.80927 .33167 m
.81007 .3414 L
s
.8101 .34136 m
.80927 .33167 L
s
.80927 .33167 m
.81094 .3508 L
s
.578 .262 1 r
.16135 .34217 m
.1604 .35077 L
s
.16046 .35081 m
.16135 .34217 L
s
.917 .184 1 r
.66757 .2885 m
.66977 .33378 L
s
1 .166 .998 r
.36111 .2885 m
.359 .33564 L
s
.494 .284 1 r
.29671 .32619 m
.2961 .33468 L
s
.29611 .33463 m
.29671 .32619 L
s
.29671 .32619 m
.29558 .34287 L
s
.578 .262 1 r
.1604 .35077 m
.16136 .34213 L
s
.16136 .34213 m
.16046 .35081 L
s
.892 .189 1 r
.25185 .34578 m
.25107 .35517 L
s
.25115 .35502 m
.25185 .34578 L
s
.744 .222 1 r
.30203 .34301 m
.30141 .35214 L
s
.3015 .3518 m
.30203 .34301 L
s
.892 .189 1 r
.25107 .35517 m
.25187 .34573 L
s
.25187 .34573 m
.25115 .35502 L
s
.869 .194 1 r
.639 .35834 m
.63895 .35876 L
s
.744 .222 1 r
.30141 .35214 m
.30205 .34297 L
s
.30205 .34297 m
.3015 .3518 L
s
.811 .206 1 r
.49831 .35772 m
.49824 .35807 L
s
.711 .229 1 r
.77429 .34247 m
.77496 .35152 L
s
.775 .35118 m
.77429 .34247 L
s
.569 .264 1 r
.18641 .34109 m
.18552 .34972 L
s
.1856 .34957 m
.18641 .34109 L
s
.711 .229 1 r
.77496 .35152 m
.77432 .34243 L
s
.77432 .34243 m
.775 .35118 L
s
.569 .264 1 r
.18552 .34972 m
.18643 .34104 L
s
.18643 .34104 m
.1856 .34957 L
s
.375 .32 1 r
.09588 .33778 m
.09482 .34585 L
s
.09489 .34574 m
.09588 .33778 L
s
.559 .267 1 r
.83339 .28825 m
.8375 .3298 L
s
.978 .171 1 r
.52689 .28825 m
.52715 .33465 L
s
.88 .191 1 r
.22039 .28825 m
.21643 .33352 L
s
.375 .32 1 r
.09482 .34585 m
.09589 .33774 L
s
.09589 .33774 m
.09489 .34574 L
s
.669 .239 1 r
.855 .35526 m
.85497 .35556 L
s
.722 .227 1 r
.63361 .34222 m
.6339 .35131 L
s
.63395 .35093 m
.63361 .34222 L
s
.733 .224 1 r
.21687 .35686 m
.21679 .35705 L
s
.722 .227 1 r
.6339 .35131 m
.63364 .34218 L
s
.63364 .34218 m
.63395 .35093 L
s
1 .141 .868 r
.87027 .36315 m
.87022 .36335 L
s
.559 .267 1 r
.46247 .32634 m
.46228 .33502 L
s
.4623 .33497 m
.46247 .32634 L
s
.46247 .32634 m
.46218 .34336 L
s
.629 .249 1 r
.69271 .28799 m
.69509 .33029 L
s
.35 .414 1 r
.38617 .28799 m
.38478 .32545 L
s
.598 .257 1 r
.07963 .28799 m
.07406 .33066 L
s
.892 .189 1 r
.27688 .34528 m
.27617 .35468 L
s
.27625 .35452 m
.27688 .34528 L
s
.27617 .35468 m
.2769 .34524 L
s
.2769 .34524 m
.27625 .35452 L
s
.375 .32 1 r
.81472 .3497 m
.81468 .34981 L
s
.711 .229 1 r
.32705 .34281 m
.32651 .35179 L
s
.32658 .35168 m
.32705 .34281 L
s
.467 .292 1 r
.15137 .35254 m
.15131 .3525 L
s
.40235 .33866 m
.40203 .34703 L
s
.4021 .34685 m
.40235 .33866 L
s
.88 .191 1 r
.85858 .28774 m
.86341 .33302 L
s
.4 .312 1 r
.55199 .28774 m
.55252 .32706 L
s
.754 .219 1 r
.24541 .28774 m
.24184 .33227 L
s
.711 .229 1 r
.32651 .35179 m
.32707 .34277 L
s
.32707 .34277 m
.32658 .35168 L
s
.669 .239 1 r
.71434 .35538 m
.71429 .35557 L
s
.467 .292 1 r
.40203 .34703 m
.40237 .33862 L
s
.40237 .33862 m
.4021 .34685 L
s
.94 .179 1 r
.44269 .34504 m
.44245 .35458 L
s
.44252 .35427 m
.44269 .34504 L
s
.477 .289 1 r
.87479 .33812 m
.87567 .34656 L
s
.87569 .34623 m
.87479 .33812 L
s
.94 .179 1 r
.44245 .35458 m
.44271 .34499 L
s
.44271 .34499 m
.44252 .35427 L
s
.845 .199 1 r
.88471 .32906 m
.88569 .33843 L
s
.88572 .33838 m
.88471 .32906 L
s
.88471 .32906 m
.88673 .34745 L
s
.608 .254 1 r
.73945 .35415 m
.7394 .35433 L
s
.477 .289 1 r
.87567 .34656 m
.87481 .33808 L
s
.87481 .33808 m
.87569 .34623 L
s
.608 .254 1 r
.37724 .34034 m
.37684 .34913 L
s
.37691 .34883 m
.37724 .34034 L
s
.649 .244 1 r
.62832 .32642 m
.62857 .33536 L
s
.62859 .33531 m
.62832 .32642 L
s
.62832 .32642 m
.62889 .34385 L
s
.608 .254 1 r
.37684 .34913 m
.37726 .3403 L
s
.37726 .3403 m
.37691 .34883 L
s
.55 .269 1 r
.3217 .32645 m
.32115 .33506 L
s
.32117 .33502 m
.3217 .32645 L
s
.3217 .32645 m
.32068 .34348 L
s
.485 .287 1 r
.48756 .3258 m
.48743 .33422 L
s
.48745 .33418 m
.48756 .3258 L
s
.48756 .3258 m
.48739 .34249 L
s
.618 .252 1 r
.21137 .34118 m
.21053 .34993 L
s
.21061 .34982 m
.21137 .34118 L
s
1 .133 .827 r
.71786 .28748 m
.72096 .33613 L
s
.69 .234 1 r
.41124 .28748 m
.40994 .33127 L
s
.608 .254 1 r
.10462 .28748 m
.09942 .32978 L
s
.618 .252 1 r
.21053 .34993 m
.21138 .34114 L
s
.21138 .34114 m
.21061 .34982 L
s
.904 .186 1 r
.71889 .33012 m
.7194 .33956 L
s
.71943 .33952 m
.71889 .33012 L
s
.71889 .33012 m
.72 .34882 L
s
.744 .221 1 r
.65876 .34202 m
.65912 .35115 L
s
.65917 .35081 m
.65876 .34202 L
s
.628 .249 1 r
.12621 .35452 m
.12613 .35467 L
s
.365 .486 1 r
.60857 .34476 m
.60852 .34509 L
s
.418 .307 1 r
.86501 .3476 m
.86502 .34823 L
s
.845 .199 1 r
.13072 .32882 m
.12959 .33818 L
s
.1296 .33813 m
.13072 .32882 L
s
.13072 .32882 m
.12856 .3472 L
s
.744 .221 1 r
.65912 .35115 m
.65878 .34197 L
s
.65878 .34197 m
.65917 .35081 L
s
.55 .269 1 r
.23645 .34009 m
.23569 .34866 L
s
.23576 .34858 m
.23645 .34009 L
s
.702 .231 1 r
.84975 .34009 m
.85064 .34922 L
s
.85064 .34858 m
.84975 .34009 L
s
.367 .322 1 r
.28665 .33732 m
.28607 .34532 L
s
.28612 .34536 m
.28665 .33732 L
s
.55 .269 1 r
.23569 .34866 m
.23646 .34005 L
s
.23646 .34005 m
.23576 .34858 L
s
.702 .231 1 r
.85064 .34922 m
.84978 .34005 L
s
.84978 .34005 m
.85064 .34858 L
s
.367 .322 1 r
.28607 .34532 m
.28667 .33729 L
s
.28667 .33729 m
.28612 .34536 L
s
.88 .191 1 r
.43736 .32904 m
.43708 .33847 L
s
.4371 .33843 m
.43736 .32904 L
s
.43736 .32904 m
.43689 .34757 L
s
.522 .277 1 r
.18089 .32631 m
.17998 .33481 L
s
.18 .33477 m
.18089 .32631 L
s
.18089 .32631 m
.17916 .34324 L
s
.503 .282 1 r
.57711 .28723 m
.57797 .32804 L
s
.442 .299 1 r
.27045 .28723 m
.26749 .32804 L
s
.441 .3 1 r
.37188 .32424 m
.37147 .33258 L
s
.37149 .33254 m
.37188 .32424 L
s
.37188 .32424 m
.37115 .34063 L
s
.712 .229 1 r
.15578 .32777 m
.15475 .33679 L
s
.15477 .33675 m
.15578 .32777 L
s
.15578 .32777 m
.15382 .34559 L
s
.752 1 .697 r
.43188 .31242 m
.43175 .31685 L
s
.43179 .31644 m
.43188 .31242 L
s
.649 .244 1 r
.5431 .34039 m
.54314 .34929 L
s
.5432 .34895 m
.5431 .34039 L
s
.752 1 .697 r
.43175 .31685 m
.43189 .3124 L
s
.43189 .3124 m
.43179 .31644 L
s
1 .154 .933 r
.41225 .33064 m
.41188 .34045 L
s
.4119 .34041 m
.41225 .33064 L
s
.41225 .33064 m
.41162 .34993 L
s
.845 .199 1 r
.60324 .32856 m
.60343 .33793 L
s
.60346 .33788 m
.60324 .32856 L
s
.60324 .32856 m
.6037 .34695 L
s
.648 .244 1 r
.76462 .35365 m
.76459 .35399 L
s
.649 .244 1 r
.54314 .34929 m
.54312 .34034 L
s
.54312 .34034 m
.5432 .34895 L
s
.579 .262 1 r
.34677 .32584 m
.34627 .33456 L
s
.34629 .33452 m
.34677 .32584 L
s
.34677 .32584 m
.34587 .34299 L
s
.68 .237 1 r
.79426 .32672 m
.79496 .3357 L
s
.79498 .33566 m
.79426 .32672 L
s
.79426 .32672 m
.79572 .34435 L
s
.559 .267 1 r
.34225 .3518 m
.34217 .35214 L
s
.51266 .32533 m
.5126 .33402 L
s
.51262 .33397 m
.51266 .32533 L
s
.51266 .32533 m
.51263 .34236 L
s
1 .062 .414 r
.83996 .34982 m
.84098 .36067 L
s
.84099 .35997 m
.83996 .34982 L
s
.459 .294 1 r
.74303 .28697 m
.74601 .3289 L
s
.352 .427 1 r
.43632 .28697 m
.4355 .32444 L
s
.669 .239 1 r
.12962 .28697 m
.12456 .33077 L
s
.822 .204 1 r
.2418 .35748 m
.24172 .35764 L
s
.845 .199 1 r
.35209 .34291 m
.35159 .35226 L
s
.35167 .35192 m
.35209 .34291 L
s
.69 .234 1 r
.6839 .34152 m
.68433 .35047 L
s
.68438 .35031 m
.6839 .34152 L
s
1 .062 .414 r
.84098 .36067 m
.84 .34977 L
s
.84 .34977 m
.84099 .35997 L
s
.845 .199 1 r
.35159 .35226 m
.3521 .34286 L
s
.3521 .34286 m
.35167 .35192 L
s
.69 .234 1 r
.68433 .35047 m
.68393 .34148 L
s
.68393 .34148 m
.68438 .35031 L
s
.754 .219 1 r
.2669 .35625 m
.26682 .3564 L
s
.467 .895 1 r
.83461 .33328 m
.83465 .33419 L
s
.512 .279 1 r
.50815 .35155 m
.50809 .3517 L
s
.34 .366 1 r
.19599 .3349 m
.1952 .34278 L
s
.19527 .34264 m
.19599 .3349 L
s
.711 .229 1 r
.60224 .28671 m
.60349 .33014 L
s
.733 .224 1 r
.29549 .28671 m
.29266 .33051 L
s
.965 .174 1 r
.79964 .34404 m
.80043 .35367 L
s
.80046 .35329 m
.79964 .34404 L
s
.34 .366 1 r
.1952 .34278 m
.196 .33486 L
s
.196 .33486 m
.19527 .34264 L
s
.712 .229 1 r
.62387 .35378 m
.62382 .35423 L
s
.628 .249 1 r
.3171 .35378 m
.31703 .35393 L
s
.648 .244 1 r
.56822 .33989 m
.56833 .34879 L
s
.56839 .34845 m
.56822 .33989 L
s
.822 .204 1 r
.7692 .32872 m
.76984 .33797 L
s
.76987 .33793 m
.7692 .32872 L
s
.7692 .32872 m
.77057 .34708 L
s
.965 .174 1 r
.80043 .35367 m
.79967 .344 L
s
.79967 .344 m
.80046 .35329 L
s
.648 .244 1 r
.56833 .34879 m
.56825 .33985 L
s
.56825 .33985 m
.56839 .34845 L
s
.424 .305 1 r
.39244 .3497 m
.39237 .34981 L
s
.811 .206 1 r
.43281 .356 m
.43274 .35634 L
s
.777 .214 1 r
.6535 .32679 m
.65383 .33604 L
s
.65385 .336 m
.6535 .32679 L
s
.6535 .32679 m
.65423 .34484 L
s
.598 .257 1 r
.20588 .32618 m
.20502 .3349 L
s
.20503 .33486 m
.20588 .32618 L
s
.20588 .32618 m
.20424 .34348 L
s
.68 .237 1 r
.76821 .28646 m
.77159 .32914 L
s
.541 .272 1 r
.46142 .28646 m
.46083 .32765 L
s
.638 .247 1 r
.15463 .28646 m
.1499 .33026 L
s
.608 .254 1 r
.73419 .33964 m
.73473 .34839 L
s
.73478 .34821 m
.73419 .33964 L
s
.649 .244 1 r
.12059 .33964 m
.1195 .34854 L
s
.1196 .3482 m
.12059 .33964 L
s
.495 .284 1 r
.5629 .32359 m
.56297 .33213 L
s
.56299 .33208 m
.5629 .32359 L
s
.5629 .32359 m
.56311 .34025 L
s
.608 .254 1 r
.73473 .34839 m
.73421 .3396 L
s
.73421 .3396 m
.73478 .34821 L
s
.711 .229 1 r
.81947 .32643 m
.82024 .33549 L
s
.82027 .33545 m
.81947 .32643 L
s
.81947 .32643 m
.82108 .34422 L
s
.649 .244 1 r
.1195 .34854 m
.1206 .3396 L
s
.1206 .3396 m
.1196 .3482 L
s
.811 .206 1 r
.59877 .35575 m
.59871 .35609 L
s
.578 .262 1 r
.59335 .3391 m
.59352 .34777 L
s
.59358 .34759 m
.59335 .3391 L
s
.59352 .34777 m
.59337 .33905 L
s
.59337 .33905 m
.59358 .34759 L
s
.336 .332 1 r
.28119 .32248 m
.28058 .33044 L
s
.28059 .33041 m
.28119 .32248 L
s
.28119 .32248 m
.28005 .33827 L
s
.345 .39 1 r
.62739 .2862 m
.62876 .32405 L
s
.34 .366 1 r
.32056 .2862 m
.31835 .32479 L
s
.711 .229 1 r
.48304 .3539 m
.48297 .35424 L
s
.382 .563 1 r
.26142 .34068 m
.26132 .3413 L
s
.619 .252 1 r
.20131 .35266 m
.20122 .35289 L
s
.711 .229 1 r
.67865 .32618 m
.67904 .33524 L
s
.67907 .3352 m
.67865 .32618 L
s
.67865 .32618 m
.6795 .34397 L
s
.977 .171 1 r
.54853 .35896 m
.54847 .35916 L
s
.531 .274 1 r
.25606 .32411 m
.25534 .33272 L
s
.25535 .33268 m
.25606 .32411 L
s
.25606 .32411 m
.25471 .34099 L
s
.54 .272 1 r
.22641 .35143 m
.22634 .35158 L
s
.953 .176 1 r
.88052 .35773 m
.8805 .35807 L
s
.68 .237 1 r
.23092 .32571 m
.2301 .3347 L
s
.23012 .33465 m
.23092 .32571 L
s
.23092 .32571 m
.22939 .34335 L
s
.55 .269 1 r
.31162 .3383 m
.31106 .34691 L
s
.31113 .34672 m
.31162 .3383 L
s
.344 .33 1 r
.38698 .33415 m
.38664 .34218 L
s
.38671 .34189 m
.38698 .33415 L
s
.811 .206 1 r
.7934 .28595 m
.79727 .3305 L
s
.701 .232 1 r
.48653 .28595 m
.48624 .32938 L
s
.765 .217 1 r
.17966 .28595 m
.17511 .33124 L
s
.55 .269 1 r
.31106 .34691 m
.31163 .33826 L
s
.31163 .33826 m
.31113 .34672 L
s
.344 .33 1 r
.38664 .34218 m
.387 .33411 L
s
.387 .33411 m
.38671 .34189 L
s
.733 .224 1 r
.42737 .34053 m
.42709 .34962 L
s
.42716 .34932 m
.42737 .34053 L
s
.56 .267 1 r
.42204 .32375 m
.42174 .33247 L
s
.42176 .33243 m
.42204 .32375 L
s
.42204 .32375 m
.42153 .34074 L
s
.494 .284 1 r
.09002 .32517 m
.0889 .33356 L
s
.08891 .33352 m
.09002 .32517 L
s
.09002 .32517 m
.08784 .34198 L
s
.467 .292 1 r
.41752 .34957 m
.41745 .34976 L
s
.733 .224 1 r
.42709 .34962 m
.42739 .34049 L
s
.42739 .34049 m
.42716 .34932 L
s
.335 .34 1 r
.49289 .3455 m
.49283 .34583 L
s
.669 .239 1 r
.53779 .32608 m
.5378 .33499 L
s
.53782 .33495 m
.53779 .32608 L
s
.53779 .32608 m
.53788 .34372 L
s
.75939 .33944 m
.76002 .34838 L
s
.76006 .34808 m
.75939 .33944 L
s
.56 .267 1 r
.47761 .33806 m
.47748 .3467 L
s
.47754 .34647 m
.47761 .33806 L
s
.357 .451 1 r
.65254 .28569 m
.65418 .3228 L
s
.476 .29 1 r
.34563 .28569 m
.34363 .32615 L
s
.669 .239 1 r
.76002 .34838 m
.75942 .3394 L
s
.75942 .3394 m
.76006 .34808 L
s
.56 .267 1 r
.47748 .3467 m
.47763 .33802 L
s
.47763 .33802 m
.47754 .34647 L
s
.392 .315 1 r
.30625 .32205 m
.30569 .33024 L
s
.3057 .3302 m
.30625 .32205 L
s
.30625 .32205 m
.30521 .33814 L
s
.952 .176 1 r
.82491 .34443 m
.82576 .35391 L
s
.82583 .3539 m
.82491 .34443 L
s
.531 .274 1 r
.58354 .34933 m
.58348 .34978 L
s
.952 .176 1 r
.82576 .35391 m
.82494 .34439 L
s
.82494 .34439 m
.82583 .3539 L
s
.476 .29 1 r
.44715 .32292 m
.44692 .33138 L
s
.44694 .33133 m
.44715 .32292 L
s
.44715 .32292 m
.44678 .3395 L
s
.375 .32 1 r
.47227 .32154 m
.47212 .32969 L
s
.47213 .32965 m
.47227 .32154 L
s
.47227 .32154 m
.47204 .33751 L
s
.55 .269 1 r
.08544 .35155 m
.08536 .35163 L
s
.756 .219 1 r
.84473 .32644 m
.84558 .33558 L
s
.84561 .33554 m
.84473 .32644 L
s
.84473 .32644 m
.8465 .34446 L
s
.811 .206 1 r
.8186 .28543 m
.82282 .32999 L
s
.579 .262 1 r
.51165 .28543 m
.5117 .32701 L
s
.648 .244 1 r
.2047 .28543 m
.20075 .32813 L
s
.744 .222 1 r
.45248 .34003 m
.45227 .34916 L
s
.45234 .34882 m
.45248 .34003 L
s
.503 .282 1 r
.74959 .34908 m
.74956 .34942 L
s
.744 .222 1 r
.45227 .34916 m
.4525 .33999 L
s
.4525 .33999 m
.45234 .34882 L
s
.777 .214 1 r
.39688 .32612 m
.3965 .33534 L
s
.39652 .33529 m
.39688 .32612 L
s
.39688 .32612 m
.39621 .34421 L
s
.588 .259 1 r
.58806 .32405 m
.5882 .33281 L
s
.58822 .33277 m
.58806 .32405 L
s
.58806 .32405 m
.58841 .34124 L
s
1 0 0 r
.17602 .35556 m
.17483 .36676 L
s
.1749 .36692 m
.17602 .35556 L
s
.649 .244 1 r
.33668 .3381 m
.33617 .34704 L
s
.33626 .34659 m
.33668 .3381 L
s
.33617 .34704 m
.3367 .33806 L
s
.3367 .33806 m
.33626 .34659 L
s
1 0 0 r
.17483 .36676 m
.17604 .3555 L
s
.17604 .3555 m
.1749 .36692 L
s
.523 .277 1 r
.52787 .33617 m
.52787 .34477 L
s
.52793 .34436 m
.52787 .33617 L
s
.383 .317 1 r
.67771 .28518 m
.67976 .32489 L
s
.531 .274 1 r
.37072 .28518 m
.36898 .32675 L
s
.658 .242 1 r
.06372 .28518 m
.05784 .32862 L
s
.523 .277 1 r
.52787 .34477 m
.52789 .33613 L
s
.52789 .33613 m
.52793 .34436 L
s
.754 .219 1 r
.70387 .32653 m
.70433 .33563 L
s
.70436 .33559 m
.70387 .32653 L
s
.70387 .32653 m
.70487 .34459 L
s
.658 .242 1 r
.17058 .33924 m
.16962 .34811 L
s
.1697 .34796 m
.17058 .33924 L
s
.578 .262 1 r
.11046 .35106 m
.11037 .35124 L
s
.777 .214 1 r
.36721 .3539 m
.36713 .35424 L
s
.658 .242 1 r
.16962 .34811 m
.17059 .33919 L
s
.17059 .33919 m
.1697 .34796 L
s
.11496 .32537 m
.11384 .33424 L
s
.11385 .3342 m
.11496 .32537 L
s
.11496 .32537 m
.11281 .34297 L
s
.777 .214 1 r
.61855 .34008 m
.6188 .34929 L
s
.61885 .34895 m
.61855 .34008 L
s
.723 .226 1 r
.64369 .33869 m
.64401 .34783 L
s
.64405 .34733 m
.64369 .33869 L
s
.744 .221 1 r
.84382 .28492 m
.84831 .32874 L
s
.88 .191 1 r
.53679 .28492 m
.53718 .33135 L
s
.766 .216 1 r
.22975 .28492 m
.226 .32911 L
s
.777 .214 1 r
.6188 .34929 m
.61857 .34003 L
s
.61857 .34003 m
.61885 .34895 L
s
.723 .226 1 r
.64401 .34783 m
.64371 .33865 L
s
.64371 .33865 m
.64405 .34733 L
s
.869 .194 1 r
.6491 .35551 m
.64905 .35582 L
s
.788 .212 1 r
.14541 .34092 m
.14435 .35009 L
s
.14444 .34994 m
.14541 .34092 L
s
.504 .282 1 r
.63835 .32205 m
.63862 .33062 L
s
.63864 .33058 m
.63835 .32205 L
s
.63835 .32205 m
.63895 .33875 L
s
.752 1 .697 r
.43179 .31644 m
.43175 .31685 L
s
.788 .212 1 r
.14435 .35009 m
.14543 .34087 L
s
.14543 .34087 m
.14444 .34994 L
s
.588 .259 1 r
.72452 .35143 m
.72446 .35154 L
s
1 .156 .946 r
.45788 .35773 m
.45781 .35815 L
s
1 .133 .827 r
.4076 .36058 m
.40752 .36078 L
s
.494 .284 1 r
.86008 .33567 m
.86094 .34416 L
s
.86097 .34387 m
.86008 .33567 L
s
.376 .32 1 r
.7029 .28467 m
.70519 .32327 L
s
.385 .574 1 r
.39582 .28467 m
.39462 .31992 L
s
.638 .247 1 r
.08874 .28466 m
.08308 .32885 L
s
.494 .284 1 r
.86094 .34416 m
.86011 .33563 L
s
.86011 .33563 m
.86097 .34387 L
s
.649 .244 1 r
.14003 .32457 m
.13898 .33345 L
s
.13899 .33341 m
.14003 .32457 L
s
.14003 .32457 m
.13802 .3421 L
s
.648 .244 1 r
.66885 .3379 m
.66923 .34681 L
s
.66927 .34647 m
.66885 .3379 L
s
.845 .199 1 r
.67427 .35464 m
.67422 .35499 L
s
.512 .279 1 r
.16516 .32326 m
.16421 .33176 L
s
.16422 .33172 m
.16516 .32326 L
s
.16516 .32326 m
.16335 .34011 L
s
.648 .244 1 r
.66923 .34681 m
.66887 .33786 L
s
.66887 .33786 m
.66927 .34647 L
s
.352 .327 1 r
.70928 .34426 m
.70925 .3447 L
s
.744 .221 1 r
.55844 .35279 m
.55838 .35313 L
s
.836 .201 1 r
.86906 .28441 m
.87388 .32823 L
s
.669 .239 1 r
.56194 .28441 m
.56265 .32786 L
s
.54 .272 1 r
.25482 .28441 m
.25157 .32637 L
s
.357 .45 1 r
.40668 .31868 m
.40638 .32646 L
s
.4064 .32642 m
.40668 .31868 L
s
.40668 .31868 m
.40616 .33391 L
s
.834 .201 1 r
.78471 .34042 m
.78544 .34975 L
s
.78548 .34944 m
.78471 .34042 L
s
.598 .257 1 r
.22074 .33765 m
.21993 .34637 L
s
.22001 .34622 m
.22074 .33765 L
s
.476 .29 1 r
.57816 .33488 m
.57829 .34333 L
s
.57834 .343 m
.57816 .33488 L
s
.834 .201 1 r
.78544 .34975 m
.78474 .34038 L
s
.78474 .34038 m
.78548 .34944 L
s
.598 .257 1 r
.13545 .35093 m
.13537 .35108 L
s
.21993 .34637 m
.22076 .33761 L
s
.22076 .33761 m
.22001 .34622 L
s
.711 .229 1 r
.61325 .32443 m
.61346 .33349 L
s
.61348 .33345 m
.61325 .32443 L
s
.61325 .32443 m
.61375 .34222 L
s
.476 .29 1 r
.57829 .34333 m
.57818 .33484 L
s
.57818 .33484 m
.57834 .343 L
s
.846 .199 1 r
.69944 .35378 m
.6994 .35423 L
s
.531 .274 1 r
.10488 .33572 m
.10378 .34432 L
s
.10388 .34399 m
.10488 .33572 L
s
.744 .221 1 r
.75425 .32523 m
.75484 .33434 L
s
.75487 .33429 m
.75425 .32523 L
s
.75425 .32523 m
.75552 .34322 L
s
.45 .297 1 r
.74431 .33433 m
.74486 .34271 L
s
.7449 .34237 m
.74431 .33433 L
s
.531 .274 1 r
.10378 .34432 m
.10489 .33568 L
s
.10489 .33568 m
.10388 .34399 L
s
.45 .297 1 r
.74486 .34271 m
.74434 .33429 L
s
.74434 .33429 m
.7449 .34237 L
s
.55 .269 1 r
.7281 .28415 m
.73088 .32574 L
s
.378 .543 1 r
.42094 .28415 m
.41994 .32127 L
s
.658 .242 1 r
.11378 .28415 m
.10855 .3276 L
s
.711 .229 1 r
.89075 .35192 m
.89073 .35226 L
s
.701 .232 1 r
.36172 .33878 m
.36127 .34777 L
s
.36134 .34758 m
.36172 .33878 L
s
.36127 .34777 m
.36174 .33874 L
s
.36174 .33874 m
.36134 .34758 L
s
.561 .266 1 r
.51803 .34722 m
.51797 .3479 L
s
.835 .201 1 r
.50273 .33962 m
.50266 .34899 L
s
.50273 .34857 m
.50273 .33962 L
s
.395 .62 1 r
.76414 .31657 m
.76465 .32398 L
s
.76467 .32394 m
.76414 .31657 L
s
.76414 .31657 m
.76521 .33105 L
s
.599 .257 1 r
.66356 .32217 m
.6639 .33101 L
s
.66393 .33097 m
.66356 .32217 L
s
.66356 .32217 m
.66431 .33936 L
s
.835 .201 1 r
.50266 .34899 m
.50275 .33958 L
s
.50275 .33958 m
.50273 .34857 L
s
1 .146 .894 r
.87017 .32785 m
.87116 .33775 L
s
.87119 .3377 m
.87017 .32785 L
s
.87017 .32785 m
.87222 .34732 L
s
.744 .222 1 r
.5871 .2839 m
.58815 .32772 L
s
.68 .237 1 r
.2799 .2839 m
.27693 .3266 L
s
.69 .234 1 r
.77945 .32458 m
.78011 .33354 L
s
.78013 .33349 m
.77945 .32458 L
s
.77945 .32458 m
.78084 .34234 L
s
.638 .247 1 r
.46772 .35044 m
.46765 .35074 L
s
1 .156 .946 r
.72916 .32742 m
.72973 .33721 L
s
.72976 .33716 m
.72916 .32742 L
s
.72916 .32742 m
.73038 .34669 L
s
.701 .232 1 r
.69407 .33799 m
.69452 .34702 L
s
.69457 .34671 m
.69407 .33799 L
s
.608 .254 1 r
.07961 .33799 m
.07843 .34668 L
s
.07849 .34671 m
.07961 .33799 L
s
.701 .232 1 r
.69452 .34702 m
.69409 .33795 L
s
.69409 .33795 m
.69457 .34671 L
s
.608 .254 1 r
.07843 .34668 m
.07963 .33795 L
s
.07963 .33795 m
.07849 .34671 L
s
.375 .32 1 r
.09489 .34574 m
.09482 .34585 L
s
.69 .234 1 r
.2458 .33745 m
.24503 .34647 L
s
.24512 .34609 m
.2458 .33745 L
s
.68 .237 1 r
.55304 .33745 m
.5531 .34643 L
s
.55316 .34609 m
.55304 .33745 L
s
.649 .244 1 r
.27095 .33606 m
.27025 .34504 L
s
.27036 .34448 m
.27095 .33606 L
s
.618 .252 1 r
.35635 .32276 m
.35587 .3316 L
s
.35589 .33156 m
.35635 .32276 L
s
.35635 .32276 m
.35549 .34011 L
s
.494 .284 1 r
.2961 .33468 m
.2955 .34317 L
s
.29558 .34287 m
.2961 .33468 L
s
.352 .327 1 r
.2656 .3193 m
.26494 .32739 L
s
.26496 .32735 m
.2656 .3193 L
s
.2656 .3193 m
.26438 .33514 L
s
.766 .216 1 r
.75331 .28364 m
.75661 .32784 L
s
.522 .277 1 r
.44607 .28364 m
.44528 .32486 L
s
.733 .224 1 r
.13882 .28364 m
.13384 .32784 L
s
.69 .234 1 r
.24503 .34647 m
.24581 .3374 L
s
.24581 .3374 m
.24512 .34609 L
s
.68 .237 1 r
.5531 .34643 m
.55306 .3374 L
s
.55306 .3374 m
.55316 .34609 L
s
.649 .244 1 r
.27025 .34504 m
.27097 .33602 L
s
.27097 .33602 m
.27036 .34448 L
s
.494 .284 1 r
.2955 .34317 m
.29611 .33463 L
s
.29611 .33463 m
.29558 .34287 L
s
.578 .262 1 r
.16046 .35081 m
.1604 .35077 L
s
.569 .264 1 r
.1856 .34957 m
.18552 .34972 L
s
.66 .241 1 r
.82982 .32236 m
.83061 .33135 L
s
.83064 .3313 m
.82982 .32236 L
s
.82982 .32236 m
.83145 .33985 L
s
.744 .222 1 r
.3015 .3518 m
.30141 .35214 L
s
.45 .297 1 r
.09935 .32044 m
.09825 .32882 L
s
.09826 .32878 m
.09935 .32044 L
s
.09935 .32044 m
.09726 .33687 L
s
.599 .257 1 r
.61228 .28338 m
.6136 .32497 L
s
.904 .186 1 r
.30499 .28338 m
.30214 .32945 L
s
.711 .229 1 r
.775 .35118 m
.77496 .35152 L
s
.609 .254 1 r
.38148 .32196 m
.38107 .3308 L
s
.38109 .33076 m
.38148 .32196 L
s
.38148 .32196 m
.38076 .33923 L
s
.337 .353 1 r
.12448 .3192 m
.1235 .32713 L
s
.12351 .3271 m
.12448 .3192 L
s
.12448 .3192 m
.12261 .33489 L
s
1 .149 .908 r
.79029 .3591 m
.79023 .35907 L
s
.892 .189 1 r
.25115 .35502 m
.25107 .35517 L
s
.722 .227 1 r
.19007 .3243 m
.18913 .33333 L
s
.18914 .33329 m
.19007 .3243 L
s
.19007 .3243 m
.18828 .34222 L
s
.68 .237 1 r
.52255 .32295 m
.52251 .33194 L
s
.52253 .3319 m
.52255 .32295 L
s
.52255 .32295 m
.52256 .3406 L
s
.722 .227 1 r
.63395 .35093 m
.6339 .35131 L
s
.68 .237 1 r
.77853 .28313 m
.78206 .32584 L
s
.416 .307 1 r
.47121 .28313 m
.47076 .32286 L
s
.628 .249 1 r
.16388 .28313 m
.15935 .32621 L
s
.56 .267 1 r
.71396 .32098 m
.71442 .32971 L
s
.71445 .32967 m
.71396 .32098 L
s
.71396 .32098 m
.71495 .33799 L
s
.55 .269 1 r
.2152 .3231 m
.21438 .33165 L
s
.21439 .3316 m
.2152 .3231 L
s
.2152 .3231 m
.21363 .34023 L
s
.559 .267 1 r
.46228 .33502 m
.46211 .3437 L
s
.46218 .34336 m
.46228 .33502 L
s
.539 1 .893 r
.46679 .30912 m
.46667 .31509 L
s
.46668 .31506 m
.46679 .30912 L
s
.46679 .30912 m
.46661 .32075 L
s
.467 .292 1 r
.4021 .34685 m
.40203 .34703 L
s
.559 .267 1 r
.46211 .3437 m
.4623 .33497 L
s
.4623 .33497 m
.46218 .34336 L
s
1 .161 .972 r
.81007 .3414 m
.8109 .35115 L
s
.81094 .3508 m
.81007 .3414 L
s
.477 .289 1 r
.87569 .34623 m
.87567 .34656 L
s
1 .161 .972 r
.8109 .35115 m
.8101 .34136 L
s
.8101 .34136 m
.81094 .3508 L
s
.67 .239 1 r
.63747 .28287 m
.63916 .32558 L
s
.383 .317 1 r
.3301 .28287 m
.32794 .32261 L
s
.88 .191 1 r
.33111 .32569 m
.33054 .33506 L
s
.33055 .33502 m
.33111 .32569 L
s
.33111 .32569 m
.33005 .34433 L
s
.35 .414 1 r
.48209 .31738 m
.48196 .32524 L
s
.48198 .3252 m
.48209 .31738 L
s
.48209 .31738 m
.48191 .33277 L
s
.608 .254 1 r
.37691 .34883 m
.37684 .34913 L
s
.485 .287 1 r
.48743 .33422 m
.48733 .34264 L
s
.48739 .34249 m
.48743 .33422 L
s
.367 .322 1 r
.28612 .34536 m
.28607 .34532 L
s
.711 .229 1 r
.32658 .35168 m
.32651 .35179 L
s
.868 .194 1 r
.49739 .32514 m
.49728 .33452 L
s
.4973 .33447 m
.49739 .32514 L
s
.49739 .32514 m
.49726 .3437 L
s
.485 .287 1 r
.48733 .34264 m
.48745 .33418 L
s
.48745 .33418 m
.48739 .34249 L
s
.892 .189 1 r
.27625 .35452 m
.27617 .35468 L
s
.68 .237 1 r
.54772 .32245 m
.54775 .33144 L
s
.54777 .3314 m
.54772 .32245 L
s
.54772 .32245 m
.54786 .3401 L
s
.55 .269 1 r
.32115 .33506 m
.32061 .34367 L
s
.32068 .34348 m
.32115 .33506 L
s
.503 .282 1 r
.80377 .28261 m
.80746 .32347 L
s
.608 .254 1 r
.49636 .28261 m
.49621 .32533 L
s
.599 .257 1 r
.18896 .28261 m
.18471 .32608 L
s
1 .161 .972 r
.8048 .32532 m
.80559 .33511 L
s
.80562 .33506 m
.8048 .32532 L
s
.8048 .32532 m
.80645 .34445 L
s
.55 .269 1 r
.32061 .34367 m
.32117 .33502 L
s
.32117 .33502 m
.32068 .34348 L
s
.629 .249 1 r
.57289 .32113 m
.57299 .33005 L
s
.57301 .33001 m
.57289 .32113 L
s
.57289 .32113 m
.57316 .33848 L
s
.618 .252 1 r
.21061 .34982 m
.21053 .34993 L
s
.424 .305 1 r
.45692 .31921 m
.45672 .32752 L
s
.45674 .32748 m
.45692 .31921 L
s
.45692 .31921 m
.45661 .3355 L
s
.55 .269 1 r
.23576 .34858 m
.23569 .34866 L
s
.649 .244 1 r
.62857 .33536 m
.62884 .34431 L
s
.62889 .34385 m
.62857 .33536 L
s
.702 .231 1 r
.85064 .34858 m
.85064 .34922 L
s
.441 .3 1 r
.37147 .33258 m
.37107 .34093 L
s
.37115 .34063 m
.37147 .33258 L
s
.733 .224 1 r
.68886 .32351 m
.68927 .33258 L
s
.6893 .33253 m
.68886 .32351 L
s
.68886 .32351 m
.68977 .34146 L
s
.649 .244 1 r
.62884 .34431 m
.62859 .33531 L
s
.62859 .33531 m
.62889 .34385 L
s
.94 .179 1 r
.44252 .35427 m
.44245 .35458 L
s
.441 .3 1 r
.37107 .34093 m
.37149 .33254 L
s
.37149 .33254 m
.37115 .34063 L
s
.744 .221 1 r
.65917 .35081 m
.65912 .35115 L
s
.744 .222 1 r
.85517 .32289 m
.85605 .33203 L
s
.85608 .33199 m
.85517 .32289 L
s
.85517 .32289 m
.85698 .34084 L
s
.522 .277 1 r
.17998 .33481 m
.17909 .34331 L
s
.17916 .34324 m
.17998 .33481 L
s
.733 .224 1 r
.24027 .32293 m
.23947 .33203 L
s
.23948 .33199 m
.24027 .32293 L
s
.24027 .32293 m
.23876 .34084 L
s
.845 .199 1 r
.66267 .28235 m
.66479 .32732 L
s
.45 .297 1 r
.35522 .28235 m
.35335 .32247 L
s
.522 .277 1 r
.17909 .34331 m
.18 .33477 L
s
.18 .33477 m
.17916 .34324 L
s
.691 .234 1 r
.88035 .32157 m
.88129 .33064 L
s
.88132 .3306 m
.88035 .32157 L
s
.88035 .32157 m
.88227 .33922 L
s
.845 .199 1 r
.88569 .33843 m
.88671 .34779 L
s
.88673 .34745 m
.88569 .33843 L
s
.754 .219 1 r
.07394 .32377 m
.07268 .33288 L
s
.07269 .33283 m
.07394 .32377 L
s
.07394 .32377 m
.07151 .34184 L
s
.34 .366 1 r
.19527 .34264 m
.1952 .34278 L
s
.845 .199 1 r
.88671 .34779 m
.88572 .33838 L
s
.88572 .33838 m
.88673 .34745 L
s
.649 .244 1 r
.5432 .34895 m
.54314 .34929 L
s
.345 .391 1 r
.34092 .31772 m
.34046 .32558 L
s
.34048 .32554 m
.34092 .31772 L
s
.34092 .31772 m
.34008 .33326 L
s
.579 .262 1 r
.34627 .33456 m
.34579 .34329 L
s
.34587 .34299 m
.34627 .33456 L
s
.4 .312 1 r
.82903 .2821 m
.83288 .32147 L
s
.811 .206 1 r
.52153 .2821 m
.52172 .32632 L
s
.834 .201 1 r
.21404 .2821 m
.20993 .32781 L
s
.579 .262 1 r
.34579 .34329 m
.34629 .33452 L
s
.34629 .33452 m
.34587 .34299 L
s
.904 .186 1 r
.7194 .33956 m
.71995 .34901 L
s
.72 .34882 m
.7194 .33956 L
s
.845 .199 1 r
.12959 .33818 m
.12845 .34755 L
s
.12856 .3472 m
.12959 .33818 L
s
.712 .229 1 r
.15475 .33679 m
.15373 .34582 L
s
.15382 .34559 m
.15475 .33679 L
s
.559 .267 1 r
.5126 .33402 m
.51256 .3427 L
s
.51263 .34236 m
.5126 .33402 L
s
.904 .186 1 r
.71995 .34901 m
.71943 .33952 L
s
.71943 .33952 m
.72 .34882 L
s
.845 .199 1 r
.12845 .34755 m
.1296 .33813 L
s
.1296 .33813 m
.12856 .3472 L
s
.712 .229 1 r
.15373 .34582 m
.15477 .33675 L
s
.15477 .33675 m
.15382 .34559 L
s
.559 .267 1 r
.51256 .3427 m
.51262 .33397 L
s
.51262 .33397 m
.51263 .34236 L
s
.88 .191 1 r
.43708 .33847 m
.43682 .34792 L
s
.43689 .34757 m
.43708 .33847 L
s
.69 .234 1 r
.68438 .35031 m
.68433 .35047 L
s
.68 .237 1 r
.79496 .3357 m
.79568 .34469 L
s
.79572 .34435 m
.79496 .3357 L
s
.36 .325 1 r
.81478 .3175 m
.81547 .32563 L
s
.81549 .32559 m
.81478 .3175 L
s
.81478 .3175 m
.8162 .33338 L
s
.88 .191 1 r
.43682 .34792 m
.4371 .33843 L
s
.4371 .33843 m
.43689 .34757 L
s
.56 .267 1 r
.68789 .28184 m
.69015 .32308 L
s
.892 .189 1 r
.38036 .28184 m
.37856 .32793 L
s
.523 .277 1 r
.07282 .28184 m
.06709 .32494 L
s
.68 .237 1 r
.79568 .34469 m
.79498 .33566 L
s
.79498 .33566 m
.79572 .34435 L
s
.845 .199 1 r
.60343 .33793 m
.60365 .3473 L
s
.6037 .34695 m
.60343 .33793 L
s
.352 .327 1 r
.67362 .31696 m
.67395 .32508 L
s
.67398 .32504 m
.67362 .31696 L
s
.67362 .31696 m
.67435 .33276 L
s
.845 .199 1 r
.35167 .35192 m
.35159 .35226 L
s
.60365 .3473 m
.60346 .33788 L
s
.60346 .33788 m
.6037 .34695 L
s
.648 .244 1 r
.56839 .34845 m
.56833 .34879 L
s
.336 .332 1 r
.28058 .33044 m
.27998 .33841 L
s
.28005 .33827 m
.28058 .33044 L
s
.27998 .33841 m
.28059 .33041 L
s
.28059 .33041 m
.28005 .33827 L
s
.68 .237 1 r
.5981 .32144 m
.59827 .33044 L
s
.59829 .33039 m
.5981 .32144 L
s
.5981 .32144 m
.59851 .33909 L
s
.744 .221 1 r
.85429 .28158 m
.85892 .32543 L
s
1 .123 .772 r
.54672 .28158 m
.54729 .32992 L
s
.658 .242 1 r
.23914 .28158 m
.23557 .32506 L
s
1 .154 .933 r
.41188 .34045 m
.41154 .35028 L
s
.41162 .34993 m
.41188 .34045 L
s
.598 .257 1 r
.20502 .3349 m
.20416 .34363 L
s
.20424 .34348 m
.20502 .3349 L
s
.7 .232 1 r
.7393 .32228 m
.73985 .33128 L
s
.73988 .33123 m
.7393 .32228 L
s
.7393 .32228 m
.74048 .34009 L
s
.521 .277 1 r
.31569 .3202 m
.31513 .32875 L
s
.31514 .3287 m
.31569 .3202 L
s
.31569 .3202 m
.31465 .3371 L
s
.495 .284 1 r
.56297 .33213 m
.56306 .34066 L
s
.56311 .34025 m
.56297 .33213 L
s
1 .154 .933 r
.41154 .35028 m
.4119 .34041 L
s
.4119 .34041 m
.41162 .34993 L
s
.344 .33 1 r
.38671 .34189 m
.38664 .34218 L
s
.608 .254 1 r
.73478 .34821 m
.73473 .34839 L
s
.649 .244 1 r
.1196 .3482 m
.1195 .34854 L
s
.598 .257 1 r
.20416 .34363 m
.20503 .33486 L
s
.20503 .33486 m
.20424 .34348 L
s
.495 .284 1 r
.56306 .34066 m
.56299 .33208 L
s
.56299 .33208 m
.56311 .34025 L
s
.578 .262 1 r
.59358 .34759 m
.59352 .34777 L
s
.649 .244 1 r
.62329 .32039 m
.62353 .32934 L
s
.62355 .3293 m
.62329 .32039 L
s
.62329 .32039 m
.62383 .33785 L
s
.965 .174 1 r
.80046 .35329 m
.80043 .35367 L
s
.822 .204 1 r
.76984 .33797 m
.77052 .34723 L
s
.77057 .34708 m
.76984 .33797 L
s
.77052 .34723 m
.76987 .33793 L
s
.76987 .33793 m
.77057 .34708 L
s
.744 .221 1 r
.71312 .28133 m
.71586 .32518 L
s
.45 .297 1 r
.40551 .28133 m
.40425 .32145 L
s
.467 .292 1 r
.09789 .28133 m
.09267 .32294 L
s
.777 .214 1 r
.65383 .33604 m
.65418 .3453 L
s
.65423 .34484 m
.65383 .33604 L
s
.65418 .3453 m
.65385 .336 L
s
.65385 .336 m
.65423 .34484 L
s
.427 .751 1 r
.18432 .31094 m
.18356 .31812 L
s
.18357 .31809 m
.18432 .31094 L
s
.18432 .31094 m
.18292 .32468 L
s
.711 .229 1 r
.82024 .33549 m
.82105 .34456 L
s
.82108 .34422 m
.82024 .33549 L
s
.531 .274 1 r
.25534 .33272 m
.25462 .34133 L
s
.25471 .34099 m
.25534 .33272 L
s
1 .062 .414 r
.84099 .35997 m
.84098 .36067 L
s
.711 .229 1 r
.82105 .34456 m
.82027 .33545 L
s
.82027 .33545 m
.82108 .34422 L
s
.55 .269 1 r
.31113 .34672 m
.31106 .34691 L
s
.531 .274 1 r
.25462 .34133 m
.25535 .33268 L
s
.25535 .33268 m
.25471 .34099 L
s
.54 .272 1 r
.17442 .32021 m
.17348 .32879 L
s
.1735 .32875 m
.17442 .32021 L
s
.17442 .32021 m
.17264 .33723 L
s
.648 .244 1 r
.14923 .32163 m
.1482 .33048 L
s
.14821 .33044 m
.14923 .32163 L
s
.14923 .32163 m
.14726 .33922 L
s
.494 .284 1 r
.0889 .33356 m
.08778 .34195 L
s
.08784 .34198 m
.0889 .33356 L
s
.833 .201 1 r
.57191 .28107 m
.57279 .32642 L
s
.344 .33 1 r
.26426 .28107 m
.26138 .3197 L
s
.494 .284 1 r
.08778 .34195 m
.08891 .33352 L
s
.08891 .33352 m
.08784 .34198 L
s
.392 .315 1 r
.30569 .33024 m
.30513 .33843 L
s
.30521 .33814 m
.30569 .33024 L
s
.744 .222 1 r
.29045 .32254 m
.28978 .33162 L
s
.2898 .33158 m
.29045 .32254 L
s
.29045 .32254 m
.2892 .34058 L
s
.392 .315 1 r
.30513 .33843 m
.3057 .3302 L
s
.3057 .3302 m
.30521 .33814 L
s
.711 .229 1 r
.67904 .33524 m
.67946 .34431 L
s
.6795 .34397 m
.67904 .33524 L
s
.56 .267 1 r
.42174 .33247 m
.42146 .34119 L
s
.42153 .34074 m
.42174 .33247 L
s
.375 .32 1 r
.47212 .32969 m
.47198 .33785 L
s
.47204 .33751 m
.47212 .32969 L
s
.711 .229 1 r
.67946 .34431 m
.67907 .3352 L
s
.67907 .3352 m
.6795 .34397 L
s
.56 .267 1 r
.47754 .34647 m
.47748 .3467 L
s
.42146 .34119 m
.42176 .33243 L
s
.42176 .33243 m
.42153 .34074 L
s
.375 .32 1 r
.47198 .33785 m
.47213 .32965 L
s
.47213 .32965 m
.47204 .33751 L
s
.733 .224 1 r
.42716 .34932 m
.42709 .34962 L
s
.68 .237 1 r
.2301 .3347 m
.22929 .34369 L
s
.22939 .34335 m
.2301 .3347 L
s
.638 .247 1 r
.73837 .28081 m
.74137 .32355 L
s
.55 .269 1 r
.43067 .28081 m
.42967 .3228 L
s
.598 .257 1 r
.12297 .28081 m
.11794 .32355 L
s
.68 .237 1 r
.22929 .34369 m
.23012 .33465 L
s
.23012 .33465 m
.22939 .34335 L
s
.669 .239 1 r
.76006 .34808 m
.76002 .34838 L
s
.476 .29 1 r
.44692 .33138 m
.44671 .33983 L
s
.44678 .3395 m
.44692 .33138 L
s
.44671 .33983 m
.44694 .33133 L
s
.44694 .33133 m
.44678 .3395 L
s
.669 .239 1 r
.5378 .33499 m
.53782 .34391 L
s
.53788 .34372 m
.5378 .33499 L
s
.53782 .34391 m
.53782 .33495 L
s
.53782 .33495 m
.53788 .34372 L
s
.639 .247 1 r
.59712 .28055 m
.59828 .32292 L
s
.589 .259 1 r
.28938 .28055 m
.28661 .32217 L
s
.523 .277 1 r
.52793 .34436 m
.52787 .34477 L
s
.649 .244 1 r
.33626 .34659 m
.33617 .34704 L
s
.744 .222 1 r
.45234 .34882 m
.45227 .34916 L
s
.756 .219 1 r
.84558 .33558 m
.84646 .34473 L
s
.8465 .34446 m
.84558 .33558 L
s
.588 .259 1 r
.5882 .33281 m
.58836 .34157 L
s
.58841 .34124 m
.5882 .33281 L
s
.618 .252 1 r
.36597 .31949 m
.36552 .32833 L
s
.36553 .32829 m
.36597 .31949 L
s
.36597 .31949 m
.36516 .33684 L
s
.416 .307 1 r
.76363 .2803 m
.76672 .32006 L
s
.618 .252 1 r
.45584 .2803 m
.45518 .32229 L
s
.522 .277 1 r
.14806 .2803 m
.1434 .32267 L
s
.756 .219 1 r
.84646 .34473 m
.84561 .33554 L
s
.84561 .33554 m
.8465 .34446 L
s
.588 .259 1 r
.58836 .34157 m
.58822 .33277 L
s
.58822 .33277 m
.58841 .34124 L
s
.952 .176 1 r
.82583 .3539 m
.82576 .35391 L
s
.628 .249 1 r
.19946 .32037 m
.19857 .32918 L
s
.19858 .32913 m
.19946 .32037 L
s
.19946 .32037 m
.19777 .33784 L
s
.589 .259 1 r
.53246 .31901 m
.53245 .32778 L
s
.53247 .32774 m
.53246 .31901 L
s
.53246 .31901 m
.53252 .33622 L
s
.57 .264 1 r
.84026 .31908 m
.84106 .32778 L
s
.84109 .32774 m
.84026 .31908 L
s
.84026 .31908 m
.84192 .33622 L
s
.777 .214 1 r
.3965 .33534 m
.39613 .34456 L
s
.39621 .34421 m
.3965 .33534 L
s
.4 .312 1 r
.27503 .31646 m
.27439 .3247 L
s
.2744 .32466 m
.27503 .31646 L
s
.27503 .31646 m
.27383 .33261 L
s
.703 .231 1 r
.62235 .28004 m
.62384 .32278 L
s
.628 .249 1 r
.31452 .28004 m
.31197 .32316 L
s
.658 .242 1 r
.1697 .34796 m
.16962 .34811 L
s
.777 .214 1 r
.39613 .34456 m
.39652 .33529 L
s
.39652 .33529 m
.39621 .34421 L
s
.723 .226 1 r
.64405 .34733 m
.64401 .34783 L
s
.701 .232 1 r
.50726 .32077 m
.50718 .32977 L
s
.5072 .32972 m
.50726 .32077 L
s
.50726 .32077 m
.50719 .33858 L
s
.494 .284 1 r
.86097 .34387 m
.86094 .34416 L
s
.822 .204 1 r
.78989 .32219 m
.7906 .33146 L
s
.79063 .33141 m
.78989 .32219 L
s
.78989 .32219 m
.79139 .34058 L
s
.504 .282 1 r
.63862 .33062 m
.63891 .3392 L
s
.63895 .33875 m
.63862 .33062 L
s
.357 .45 1 r
.40638 .32646 m
.4061 .33424 L
s
.40616 .33391 m
.40638 .32646 L
s
.504 .282 1 r
.63891 .3392 m
.63864 .33058 L
s
.63864 .33058 m
.63895 .33875 L
s
.754 .219 1 r
.70433 .33563 m
.70482 .34474 L
s
.70487 .34459 m
.70433 .33563 L
s
.357 .45 1 r
.4061 .33424 m
.4064 .32642 L
s
.4064 .32642 m
.40616 .33391 L
s
.658 .242 1 r
.11384 .33424 m
.11273 .34312 L
s
.11281 .34297 m
.11384 .33424 L
s
.777 .214 1 r
.61885 .34895 m
.6188 .34929 L
s
.754 .219 1 r
.70482 .34474 m
.70436 .33559 L
s
.70436 .33559 m
.70487 .34459 L
s
.658 .242 1 r
.11273 .34312 m
.11385 .3342 L
s
.11385 .3342 m
.11281 .34297 L
s
.344 .33 1 r
.13367 .31614 m
.1327 .32416 L
s
.13271 .32412 m
.13367 .31614 L
s
.13367 .31614 m
.13182 .33199 L
s
.608 .254 1 r
.69899 .31902 m
.69943 .32783 L
s
.69945 .32779 m
.69899 .31902 L
s
.69899 .31902 m
.69993 .33634 L
s
.588 .259 1 r
.7889 .27978 m
.7925 .32178 L
s
.712 .229 1 r
.48103 .27978 m
.48068 .3229 L
s
.766 .217 1 r
.17317 .27978 m
.16852 .32514 L
s
.395 .62 1 r
.76465 .32398 m
.76518 .33138 L
s
.76521 .33105 m
.76465 .32398 L
s
.76518 .33138 m
.76467 .32394 L
s
.76467 .32394 m
.76521 .33105 L
s
.638 .247 1 r
.22459 .31982 m
.22376 .32867 L
s
.22377 .32863 m
.22459 .31982 L
s
.22459 .31982 m
.22302 .33734 L
s
.512 .279 1 r
.16421 .33176 m
.16327 .34026 L
s
.16335 .34011 m
.16421 .33176 L
s
.788 .212 1 r
.14444 .34994 m
.14435 .35009 L
s
.648 .244 1 r
.66927 .34647 m
.66923 .34681 L
s
.512 .279 1 r
.16327 .34026 m
.16422 .33172 L
s
.16422 .33172 m
.16335 .34011 L
s
.476 .29 1 r
.57834 .343 m
.57829 .34333 L
s
.539 1 .893 r
.46667 .31509 m
.46656 .32106 L
s
.46661 .32075 m
.46667 .31509 L
s
.45 .297 1 r
.7449 .34237 m
.74486 .34271 L
s
.539 1 .893 r
.46656 .32106 m
.46668 .31506 L
s
.46668 .31506 m
.46661 .32075 L
s
.649 .244 1 r
.13898 .33345 m
.13793 .34233 L
s
.13802 .3421 m
.13898 .33345 L
s
.559 .267 1 r
.41632 .31804 m
.41601 .32673 L
s
.41603 .32669 m
.41632 .31804 L
s
.41632 .31804 m
.41579 .33509 L
s
.4 .312 1 r
.60808 .31596 m
.60826 .3242 L
s
.60828 .32416 m
.60808 .31596 L
s
.60808 .31596 m
.60851 .33211 L
s
.618 .252 1 r
.64759 .27952 m
.64939 .3219 L
s
.425 .304 1 r
.33968 .27952 m
.33766 .31892 L
s
.649 .244 1 r
.13793 .34233 m
.13899 .33341 L
s
.13899 .33341 m
.13802 .3421 L
s
.485 .287 1 r
.3911 .3195 m
.39074 .32783 L
s
.39076 .32779 m
.3911 .3195 L
s
.3911 .3195 m
.39044 .33634 L
s
.531 .274 1 r
.10388 .34399 m
.10378 .34432 L
s
.1084 .31814 m
.1073 .32673 L
s
.10731 .32669 m
.1084 .31814 L
s
.1084 .31814 m
.10629 .33509 L
s
.598 .257 1 r
.22001 .34622 m
.21993 .34637 L
s
1 .153 .933 r
.64863 .32252 m
.64896 .3324 L
s
.64899 .33235 m
.64863 .32252 L
s
.64863 .32252 m
.64938 .34182 L
s
.503 .282 1 r
.74946 .31709 m
.75001 .32564 L
s
.75004 .3256 m
.74946 .31709 L
s
.74946 .31709 m
.75063 .33385 L
s
.88 .191 1 r
.81418 .27927 m
.81842 .32463 L
s
.598 .257 1 r
.50624 .27927 m
.50621 .32202 L
s
.579 .262 1 r
.19829 .27926 m
.19431 .32127 L
s
.834 .201 1 r
.78548 .34944 m
.78544 .34975 L
s
.711 .229 1 r
.61346 .33349 m
.61369 .34256 L
s
.61375 .34222 m
.61346 .33349 L
s
.589 .259 1 r
.44152 .31742 m
.44127 .32623 L
s
.44128 .32619 m
.44152 .31742 L
s
.44152 .31742 m
.44111 .33459 L
s
.711 .229 1 r
.61369 .34256 m
.61348 .33345 L
s
.61348 .33345 m
.61375 .34222 L
s
.744 .221 1 r
.75484 .33434 m
.75547 .34345 L
s
.75552 .34322 m
.75484 .33434 L
s
.701 .232 1 r
.36134 .34758 m
.36127 .34777 L
s
.352 .327 1 r
.26494 .32739 m
.2643 .33547 L
s
.26438 .33514 m
.26494 .32739 L
s
.744 .221 1 r
.75547 .34345 m
.75487 .33429 L
s
.75487 .33429 m
.75552 .34322 L
s
.799 .209 1 r
.67284 .27901 m
.6751 .324 L
s
.638 .247 1 r
.36485 .27901 m
.36292 .32288 L
s
.701 .232 1 r
.05686 .27901 m
.0507 .32363 L
s
.352 .327 1 r
.2643 .33547 m
.26496 .32735 L
s
.26496 .32735 m
.26438 .33514 L
s
.7 .232 1 r
.86568 .31976 m
.86658 .32876 L
s
.86661 .32872 m
.86568 .31976 L
s
.86568 .31976 m
.86754 .33758 L
s
.599 .257 1 r
.6639 .33101 m
.66427 .33985 L
s
.66431 .33936 m
.6639 .33101 L
s
.494 .284 1 r
.29558 .34287 m
.2955 .34317 L
s
.599 .257 1 r
.66427 .33985 m
.66393 .33097 L
s
.66393 .33097 m
.66431 .33936 L
s
.835 .201 1 r
.50273 .34857 m
.50266 .34899 L
s
1 0 0 r
.1749 .36692 m
.17483 .36676 L
s
.701 .232 1 r
.08305 .32068 m
.08183 .32961 L
s
.08184 .32956 m
.08305 .32068 L
s
.08305 .32068 m
.08068 .33858 L
s
.649 .244 1 r
.27036 .34448 m
.27025 .34504 L
s
.417 .307 1 r
.49193 .31512 m
.49183 .32344 L
s
.49184 .3234 m
.49193 .31512 L
s
.49193 .31512 m
.4918 .33135 L
s
.744 .222 1 r
.72431 .31936 m
.72483 .32851 L
s
.72486 .32847 m
.72431 .31936 L
s
.72431 .31936 m
.72542 .33733 L
s
.337 .353 1 r
.1235 .32713 m
.12253 .33507 L
s
.12261 .33489 m
.1235 .32713 L
s
.523 .276 1 r
.83948 .27875 m
.84355 .31889 L
s
.701 .232 1 r
.69457 .34671 m
.69452 .34702 L
s
.7 .232 1 r
.53145 .27875 m
.53176 .32263 L
s
.494 .284 1 r
.22342 .27875 m
.21987 .31964 L
s
.608 .254 1 r
.07849 .34671 m
.07843 .34668 L
s
.756 .219 1 r
.58292 .31873 m
.58305 .32796 L
s
.58307 .32792 m
.58292 .31873 L
s
.58292 .31873 m
.58326 .3367 L
s
.337 .353 1 r
.12253 .33507 m
.12351 .3271 L
s
.12351 .3271 m
.12261 .33489 L
s
.69 .234 1 r
.78011 .33354 m
.78079 .3425 L
s
.78084 .34234 m
.78011 .33354 L
s
.24512 .34609 m
.24503 .34647 L
s
.68 .237 1 r
.55316 .34609 m
.5531 .34643 L
s
.69 .234 1 r
.78079 .3425 m
.78013 .33349 L
s
.78013 .33349 m
.78084 .34234 L
s
.385 .575 1 r
.42617 .31053 m
.42592 .31812 L
s
.42594 .31809 m
.42617 .31053 L
s
.42617 .31053 m
.42576 .32513 L
s
.618 .252 1 r
.35587 .3316 m
.35541 .34044 L
s
.35549 .34011 m
.35587 .3316 L
s
.45 .297 1 r
.09825 .32882 m
.09716 .33721 L
s
.09726 .33687 m
.09825 .32882 L
s
.618 .252 1 r
.35541 .34044 m
.35589 .33156 L
s
.35589 .33156 m
.35549 .34011 L
s
.45 .297 1 r
.09716 .33721 m
.09826 .32878 L
s
.09826 .32878 m
.09726 .33687 L
s
.618 .252 1 r
.30007 .31772 m
.29944 .32657 L
s
.29946 .32653 m
.30007 .31772 L
s
.30007 .31772 m
.29891 .33508 L
s
.45 .297 1 r
.6981 .27849 m
.70041 .31827 L
s
.485 .287 1 r
.39003 .27849 m
.38854 .31976 L
s
.54 .272 1 r
.08196 .27849 m
.07648 .3205 L
s
.916 .184 1 r
.55771 .32071 m
.55777 .33025 L
s
.55779 .3302 m
.55771 .32071 L
s
.55771 .32071 m
.55792 .33944 L
s
.66 .241 1 r
.83061 .33135 m
.83144 .34035 L
s
.83145 .33985 m
.83061 .33135 L
s
.589 .259 1 r
.63337 .31666 m
.63363 .32547 L
s
.63366 .32543 m
.63337 .31666 L
s
.63337 .31666 m
.63396 .33384 L
s
.66 .241 1 r
.83144 .34035 m
.83064 .3313 L
s
.83064 .3313 m
.83145 .33985 L
s
1 .146 .894 r
.87116 .33775 m
.87219 .34766 L
s
.87222 .34732 m
.87116 .33775 L
s
.41 .682 1 r
.45137 .30973 m
.45119 .31703 L
s
.4512 .31699 m
.45137 .30973 L
s
.45137 .30973 m
.45108 .32389 L
s
.609 .254 1 r
.38107 .3308 m
.38067 .33965 L
s
.38076 .33923 m
.38107 .3308 L
s
.559 .267 1 r
.46218 .34336 m
.46211 .3437 L
s
1 .146 .894 r
.87219 .34766 m
.87119 .3377 L
s
.87119 .3377 m
.87222 .34732 L
s
.916 .184 1 r
.8648 .27823 m
.86978 .32399 L
s
.871 .193 1 r
.55668 .27823 m
.55734 .32212 L
s
.578 .262 1 r
.24857 .27823 m
.2452 .32062 L
s
.35 .414 1 r
.48196 .32524 m
.48185 .3331 L
s
.48191 .33277 m
.48196 .32524 L
s
.609 .254 1 r
.38067 .33965 m
.38109 .33076 L
s
.38109 .33076 m
.38076 .33923 L
s
1 .156 .946 r
.72973 .33721 m
.73033 .347 L
s
.73038 .34669 m
.72973 .33721 L
s
.35 .414 1 r
.48185 .3331 m
.48198 .3252 L
s
.48198 .3252 m
.48191 .33277 L
s
.55 .269 1 r
.21438 .33165 m
.21357 .34019 L
s
.21363 .34023 m
.21438 .33165 L
s
1 .156 .946 r
.73033 .347 m
.72976 .33716 L
s
.72976 .33716 m
.73038 .34669 L
s
.55 .269 1 r
.21357 .34019 m
.21439 .3316 L
s
.21439 .3316 m
.21363 .34023 L
s
.367 .322 1 r
.06755 .31426 m
.06641 .32239 L
s
.06642 .32235 m
.06755 .31426 L
s
.06755 .31426 m
.06537 .33023 L
s
.56 .267 1 r
.71442 .32971 m
.71492 .33844 L
s
.71495 .33799 m
.71442 .32971 L
s
.71492 .33844 m
.71445 .32967 L
s
.71445 .32967 m
.71495 .33799 L
s
.722 .227 1 r
.18913 .33333 m
.1882 .34237 L
s
.18828 .34222 m
.18913 .33333 L
s
.36 .463 1 r
.40091 .31298 m
.4006 .3207 L
s
.40061 .32066 m
.40091 .31298 L
s
.40091 .31298 m
.40036 .32823 L
s
.68 .237 1 r
.52251 .33194 m
.5225 .34094 L
s
.52256 .3406 m
.52251 .33194 L
s
.953 .176 1 r
.72338 .27798 m
.72641 .3241 L
s
.589 .259 1 r
.41522 .27797 m
.41403 .31999 L
s
.345 .39 1 r
.10707 .27797 m
.10233 .31664 L
s
.722 .227 1 r
.1882 .34237 m
.18914 .33329 L
s
.18914 .33329 m
.18828 .34222 L
s
.68 .237 1 r
.5225 .34094 m
.52253 .3319 L
s
.52253 .3319 m
.52256 .3406 L
s
.485 .287 1 r
.48739 .34249 m
.48733 .34264 L
s
.441 .3 1 r
.37115 .34063 m
.37107 .34093 L
s
.68 .237 1 r
.15851 .31823 m
.1575 .3272 L
s
.15751 .32716 m
.15851 .31823 L
s
.15851 .31823 m
.15658 .33595 L
s
.55 .269 1 r
.32068 .34348 m
.32061 .34367 L
s
.744 .222 1 r
.77489 .31835 m
.77555 .3275 L
s
.77558 .32746 m
.77489 .31835 L
s
.77489 .31835 m
.77628 .33632 L
s
.424 .305 1 r
.45672 .32752 m
.45654 .33583 L
s
.45661 .3355 m
.45672 .32752 L
s
.701 .232 1 r
.58193 .27772 m
.58291 .32123 L
s
.744 .222 1 r
.27373 .27772 m
.27059 .3216 L
s
.424 .305 1 r
.45654 .33583 m
.45674 .32748 L
s
.45674 .32748 m
.45661 .3355 L
s
.618 .252 1 r
.65865 .31638 m
.65898 .32526 L
s
.659 .32522 m
.65865 .31638 L
s
.65865 .31638 m
.65937 .3337 L
s
.345 .391 1 r
.34046 .32558 m
.34001 .33344 L
s
.34008 .33326 m
.34046 .32558 L
s
1 .161 .972 r
.81094 .3508 m
.8109 .35115 L
s
.345 .391 1 r
.34001 .33344 m
.34048 .32554 L
s
.34048 .32554 m
.34008 .33326 L
s
.649 .244 1 r
.62889 .34385 m
.62884 .34431 L
s
.522 .277 1 r
.17916 .34324 m
.17909 .34331 L
s
.68 .237 1 r
.54775 .33144 m
.5478 .34044 L
s
.54786 .3401 m
.54775 .33144 L
s
.629 .249 1 r
.57299 .33005 m
.57311 .33897 L
s
.57316 .33848 m
.57299 .33005 L
s
.905 .186 1 r
.74867 .27746 m
.75201 .32284 L
s
.618 .252 1 r
.44043 .27746 m
.43957 .31948 L
s
.722 .227 1 r
.13219 .27746 m
.12711 .32172 L
s
.342 .378 1 r
.73436 .31255 m
.73483 .32049 L
s
.73486 .32045 m
.73436 .31255 L
s
.73436 .31255 m
.73537 .3281 L
s
.68 .237 1 r
.5478 .34044 m
.54777 .3314 L
s
.54777 .3314 m
.54786 .3401 L
s
.629 .249 1 r
.57311 .33897 m
.57301 .33001 L
s
.57301 .33001 m
.57316 .33848 L
s
.88 .191 1 r
.33054 .33506 m
.32997 .34445 L
s
.33005 .34433 m
.33054 .33506 L
s
.32997 .34445 m
.33055 .33502 L
s
.33055 .33502 m
.33005 .34433 L
s
.868 .194 1 r
.49728 .33452 m
.49719 .3439 L
s
.49726 .3437 m
.49728 .33452 L
s
.49719 .3439 m
.4973 .33447 L
s
.4973 .33447 m
.49726 .3437 L
s
.579 .262 1 r
.34587 .34299 m
.34579 .34329 L
s
1 .141 .867 r
.24946 .32274 m
.24861 .33262 L
s
.24862 .33257 m
.24946 .32274 L
s
.24946 .32274 m
.24785 .34243 L
s
.733 .224 1 r
.68927 .33258 m
.68972 .34166 L
s
.68977 .34146 m
.68927 .33258 L
s
.588 .259 1 r
.3504 .31715 m
.34991 .32586 L
s
.34993 .32581 m
.3504 .31715 L
s
.3504 .31715 m
.34951 .33445 L
s
.559 .267 1 r
.51263 .34236 m
.51256 .3427 L
s
.36 .325 1 r
.81547 .32563 m
.81618 .33375 L
s
.8162 .33338 m
.81547 .32563 L
s
.702 .231 1 r
.60718 .2772 m
.60847 .3196 L
s
.442 .299 1 r
.2989 .2772 m
.29628 .31811 L
s
.733 .224 1 r
.68972 .34166 m
.6893 .33253 L
s
.6893 .33253 m
.68977 .34146 L
s
.36 .325 1 r
.81618 .33375 m
.81549 .32559 L
s
.81549 .32559 m
.8162 .33338 L
s
.336 .332 1 r
.28005 .33827 m
.27998 .33841 L
s
.618 .252 1 r
.68393 .31587 m
.68432 .32476 L
s
.68435 .32471 m
.68393 .31587 L
s
.68393 .31587 m
.68478 .3332 L
s
.733 .224 1 r
.23947 .33203 m
.23867 .34115 L
s
.23876 .34084 m
.23947 .33203 L
s
.744 .222 1 r
.85605 .33203 m
.85696 .34118 L
s
.85698 .34084 m
.85605 .33203 L
s
.691 .234 1 r
.88129 .33064 m
.88226 .33972 L
s
.88227 .33922 m
.88129 .33064 L
s
.845 .199 1 r
.88673 .34745 m
.88671 .34779 L
s
.367 .322 1 r
.25934 .31383 m
.25866 .32192 L
s
.25867 .32188 m
.25934 .31383 L
s
.25934 .31383 m
.25807 .32984 L
s
.352 .327 1 r
.67395 .32508 m
.67432 .3332 L
s
.67435 .33276 m
.67395 .32508 L
s
.733 .224 1 r
.23867 .34115 m
.23948 .33199 L
s
.23948 .33199 m
.23876 .34084 L
s
.744 .222 1 r
.85696 .34118 m
.85608 .33199 L
s
.85608 .33199 m
.85698 .34084 L
s
.691 .234 1 r
.88226 .33972 m
.88132 .3306 L
s
.88132 .3306 m
.88227 .33922 L
s
.378 .543 1 r
.47658 .31039 m
.47644 .318 L
s
.47646 .31796 m
.47658 .31039 L
s
.47658 .31039 m
.47638 .32524 L
s
.427 .751 1 r
.18356 .31812 m
.1828 .3253 L
s
.18292 .32468 m
.18356 .31812 L
s
.352 .327 1 r
.67432 .3332 m
.67398 .32504 L
s
.67398 .32504 m
.67435 .33276 L
s
.754 .219 1 r
.07268 .33288 m
.07142 .34199 L
s
.07151 .34184 m
.07268 .33288 L
s
.427 .751 1 r
.1828 .3253 m
.18357 .31809 L
s
.18357 .31809 m
.18292 .32468 L
s
.754 .219 1 r
.07142 .34199 m
.07269 .33283 L
s
.07269 .33283 m
.07151 .34184 L
s
1 .161 .972 r
.80559 .33511 m
.80642 .34491 L
s
.80645 .34445 m
.80559 .33511 L
s
.712 .229 1 r
.15382 .34559 m
.15373 .34582 L
s
1 .161 .972 r
.80642 .34491 m
.80562 .33506 L
s
.80562 .33506 m
.80645 .34445 L
s
.811 .206 1 r
.77398 .27694 m
.7776 .32158 L
s
.504 .282 1 r
.46566 .27694 m
.46513 .31748 L
s
.659 .242 1 r
.15733 .27694 m
.15254 .32158 L
s
.833 .201 1 r
.32513 .31913 m
.32454 .32844 L
s
.32456 .32839 m
.32513 .31913 L
s
.32513 .31913 m
.32405 .33756 L
s
.68 .237 1 r
.79572 .34435 m
.79568 .34469 L
s
.845 .199 1 r
.12856 .3472 m
.12845 .34755 L
s
.45 .297 1 r
.0925 .31504 m
.09139 .32336 L
s
.0914 .32332 m
.0925 .31504 L
s
.0925 .31504 m
.09036 .33158 L
s
.495 .284 1 r
.56311 .34025 m
.56306 .34066 L
s
.638 .247 1 r
.37561 .31646 m
.37518 .32535 L
s
.3752 .32531 m
.37561 .31646 L
s
.37561 .31646 m
.37485 .33395 L
s
.904 .186 1 r
.72 .34882 m
.71995 .34901 L
s
.618 .252 1 r
.63246 .27668 m
.63405 .31871 L
s
.932 .18 1 r
.32409 .27668 m
.32161 .32095 L
s
.88 .191 1 r
.43689 .34757 m
.43682 .34792 L
s
.521 .277 1 r
.31513 .32875 m
.31457 .33729 L
s
.31465 .3371 m
.31513 .32875 L
s
.845 .199 1 r
.6037 .34695 m
.60365 .3473 L
s
.598 .257 1 r
.20424 .34348 m
.20416 .34363 L
s
.777 .214 1 r
.82555 .31756 m
.82635 .32679 L
s
.82638 .32674 m
.82555 .31756 L
s
.82555 .31756 m
.82722 .33569 L
s
.521 .277 1 r
.31457 .33729 m
.31514 .3287 L
s
.31514 .3287 m
.31465 .3371 L
s
.598 .257 1 r
.23401 .31636 m
.23321 .3251 L
s
.23323 .32506 m
.23401 .31636 L
s
.23401 .31636 m
.23251 .33369 L
s
.68 .237 1 r
.59827 .33044 m
.59846 .33943 L
s
.59851 .33909 m
.59827 .33044 L
s
.392 .315 1 r
.30521 .33814 m
.30513 .33843 L
s
.822 .204 1 r
.7993 .27642 m
.80327 .32107 L
s
.531 .274 1 r
.49089 .27642 m
.49068 .31734 L
s
.669 .239 1 r
.18248 .27642 m
.17807 .3207 L
s
.68 .237 1 r
.59846 .33943 m
.59829 .33039 L
s
.59829 .33039 m
.59851 .33909 L
s
.531 .274 1 r
.25471 .34099 m
.25462 .34133 L
s
.375 .32 1 r
.47204 .33751 m
.47198 .33785 L
s
.7 .232 1 r
.73985 .33128 m
.74043 .34028 L
s
.74048 .34009 m
.73985 .33128 L
s
.766 .217 1 r
.51716 .31792 m
.51711 .32709 L
s
.51713 .32704 m
.51716 .31792 L
s
.51716 .31792 m
.51715 .33606 L
s
.539 1 .893 r
.46661 .32075 m
.46656 .32106 L
s
.99 .169 1 r
.80034 .31939 m
.80111 .32908 L
s
.80114 .32903 m
.80034 .31939 L
s
.80034 .31939 m
.80195 .33843 L
s
.7 .232 1 r
.74043 .34028 m
.73988 .33123 L
s
.73988 .33123 m
.74048 .34009 L
s
.649 .244 1 r
.62353 .32934 m
.62379 .3383 L
s
.62383 .33785 m
.62353 .32934 L
s
.494 .284 1 r
.08784 .34198 m
.08778 .34195 L
s
.649 .244 1 r
.62379 .3383 m
.62355 .3293 L
s
.62355 .3293 m
.62383 .33785 L
s
.777 .214 1 r
.65423 .34484 m
.65418 .3453 L
s
.54 .272 1 r
.17348 .32879 m
.17256 .33738 L
s
.17264 .33723 m
.17348 .32879 L
s
.669 .239 1 r
.20871 .31826 m
.20784 .32708 L
s
.20785 .32704 m
.20871 .31826 L
s
.20871 .31826 m
.20703 .33606 L
s
.476 .29 1 r
.65774 .27617 m
.65959 .31671 L
s
.61 .254 1 r
.34929 .27617 m
.34732 .31708 L
s
.711 .229 1 r
.82108 .34422 m
.82105 .34456 L
s
.54 .272 1 r
.17256 .33738 m
.1735 .32875 L
s
.1735 .32875 m
.17264 .33723 L
s
.56 .267 1 r
.42153 .34074 m
.42146 .34119 L
s
.811 .206 1 r
.85088 .31694 m
.85176 .32629 L
s
.85179 .32624 m
.85088 .31694 L
s
.85088 .31694 m
.8527 .33518 L
s
.822 .204 1 r
.77057 .34708 m
.77052 .34723 L
s
1 .154 .933 r
.41162 .34993 m
.41154 .35028 L
s
.476 .29 1 r
.44678 .3395 m
.44671 .33983 L
s
.648 .244 1 r
.1482 .33048 m
.14718 .33933 L
s
.14726 .33922 m
.1482 .33048 L
s
.14718 .33933 m
.14821 .33044 L
s
.14821 .33044 m
.14726 .33922 L
s
.811 .206 1 r
.54242 .31727 m
.54244 .32658 L
s
.54246 .32654 m
.54242 .31727 L
s
.54242 .31727 m
.54255 .33555 L
s
.744 .222 1 r
.70929 .31658 m
.70977 .32574 L
s
.7098 .32569 m
.70929 .31658 L
s
.70929 .31658 m
.71032 .33456 L
s
.559 .267 1 r
.82463 .27591 m
.82866 .31757 L
s
.833 .201 1 r
.51614 .27591 m
.51625 .32131 L
s
.733 .224 1 r
.20765 .27591 m
.20358 .32019 L
s
.711 .229 1 r
.6795 .34397 m
.67946 .34431 L
s
.68 .237 1 r
.22939 .34335 m
.22929 .34369 L
s
.744 .222 1 r
.28978 .33162 m
.28912 .3407 L
s
.2892 .34058 m
.28978 .33162 L
s
.28912 .3407 m
.2898 .33158 L
s
.2898 .33158 m
.2892 .34058 L
s
.395 .62 1 r
.76521 .33105 m
.76518 .33138 L
s
.953 .176 1 r
.68304 .27565 m
.68552 .32218 L
s
.395 .62 1 r
.37451 .27565 m
.37307 .31098 L
s
.531 .274 1 r
.06597 .27565 m
.06029 .31769 L
s
.669 .239 1 r
.53788 .34372 m
.53782 .34391 L
s
.357 .45 1 r
.40616 .33391 m
.4061 .33424 L
s
.811 .206 1 r
.87623 .31643 m
.87718 .32578 L
s
.87721 .32573 m
.87623 .31643 L
s
.87623 .31643 m
.87819 .33468 L
s
.45 .297 1 r
.64346 .31227 m
.64374 .3207 L
s
.64376 .32066 m
.64346 .31227 L
s
.64346 .31227 m
.64407 .32869 L
s
.638 .247 1 r
.1175 .31578 m
.11638 .32464 L
s
.1164 .32459 m
.1175 .31578 L
s
.1175 .31578 m
.11536 .33331 L
s
.588 .259 1 r
.58841 .34124 m
.58836 .34157 L
s
.904 .186 1 r
.84998 .27539 m
.8548 .32154 L
s
.54 .272 1 r
.54141 .27539 m
.54183 .31743 L
s
.476 .29 1 r
.23283 .27539 m
.22942 .31594 L
s
.494 .285 1 r
.1427 .31483 m
.1417 .32324 L
s
.14172 .3232 m
.1427 .31483 L
s
.1427 .31483 m
.14077 .33168 L
s
.4 .312 1 r
.27439 .3247 m
.27375 .33295 L
s
.27383 .33261 m
.27439 .3247 L
s
.504 .282 1 r
.63895 .33875 m
.63891 .3392 L
s
.4 .312 1 r
.27375 .33295 m
.2744 .32466 L
s
.2744 .32466 m
.27383 .33261 L
s
.35 .414 1 r
.38541 .31004 m
.38505 .31791 L
s
.38507 .31787 m
.38541 .31004 L
s
.38541 .31004 m
.38478 .32545 L
s
.618 .252 1 r
.36552 .32833 m
.36508 .33718 L
s
.36516 .33684 m
.36552 .32833 L
s
.487 .287 1 r
.50182 .31219 m
.50173 .32074 L
s
.50175 .3207 m
.50182 .31219 L
s
.50182 .31219 m
.50173 .32881 L
s
.344 .33 1 r
.1327 .32416 m
.13174 .33217 L
s
.13182 .33199 m
.1327 .32416 L
s
.756 .219 1 r
.8465 .34446 m
.84646 .34473 L
s
.618 .252 1 r
.36508 .33718 m
.36553 .32829 L
s
.36553 .32829 m
.36516 .33684 L
s
.344 .33 1 r
.13174 .33217 m
.13271 .32412 L
s
.13271 .32412 m
.13182 .33199 L
s
.628 .249 1 r
.19857 .32918 m
.19769 .33799 L
s
.19777 .33784 m
.19857 .32918 L
s
.589 .259 1 r
.53245 .32778 m
.53246 .33656 L
s
.53252 .33622 m
.53245 .32778 L
s
.57 .264 1 r
.84106 .32778 m
.84189 .33649 L
s
.84192 .33622 m
.84106 .32778 L
s
.559 .267 1 r
.78517 .31373 m
.78582 .32244 L
s
.78585 .3224 m
.78517 .31373 L
s
.78517 .31373 m
.78653 .33081 L
s
.618 .252 1 r
.70835 .27513 m
.71093 .31717 L
s
1 .161 .972 r
.39973 .27513 m
.39818 .32204 L
s
.55 .269 1 r
.09112 .27513 m
.08566 .31792 L
s
.628 .249 1 r
.19769 .33799 m
.19858 .32913 L
s
.19858 .32913 m
.19777 .33784 L
s
.589 .259 1 r
.53246 .33656 m
.53247 .32774 L
s
.53247 .32774 m
.53252 .33622 L
s
.57 .264 1 r
.84189 .33649 m
.84109 .32774 L
s
.84109 .32774 m
.84192 .33622 L
s
.916 .184 1 r
.56771 .31743 m
.5678 .32697 L
s
.56782 .32692 m
.56771 .31743 L
s
.56771 .31743 m
.56798 .33617 L
s
.766 .216 1 r
.28434 .31608 m
.28364 .32528 L
s
.28366 .32523 m
.28434 .31608 L
s
.28434 .31608 m
.28304 .33418 L
s
.777 .214 1 r
.39621 .34421 m
.39613 .34456 L
s
.512 .279 1 r
.16335 .34011 m
.16327 .34026 L
s
1 .156 .947 r
.56668 .27487 m
.56753 .32253 L
s
.469 .292 1 r
.25803 .27487 m
.25477 .31729 L
s
.658 .242 1 r
.11281 .34297 m
.11273 .34312 L
s
.701 .232 1 r
.50718 .32977 m
.50712 .33877 L
s
.50719 .33858 m
.50718 .32977 L
s
.4 .312 1 r
.60826 .3242 m
.60846 .33244 L
s
.60851 .33211 m
.60826 .3242 L
s
.701 .232 1 r
.50712 .33877 m
.5072 .32972 L
s
.5072 .32972 m
.50719 .33858 L
s
.4 .312 1 r
.60846 .33244 m
.60828 .32416 L
s
.60828 .32416 m
.60851 .33211 L
s
.754 .219 1 r
.70487 .34459 m
.70482 .34474 L
s
.608 .254 1 r
.69943 .32783 m
.69989 .33664 L
s
.69993 .33634 m
.69943 .32783 L
s
.485 .287 1 r
.39074 .32783 m
.39039 .33616 L
s
.39044 .33634 m
.39074 .32783 L
s
.608 .254 1 r
.69989 .33664 m
.69945 .32779 L
s
.69945 .32779 m
.69993 .33634 L
s
.485 .287 1 r
.39039 .33616 m
.39076 .32779 L
s
.39076 .32779 m
.39044 .33634 L
s
.822 .204 1 r
.7906 .33146 m
.79134 .34073 L
s
.79139 .34058 m
.7906 .33146 L
s
.638 .247 1 r
.22376 .32867 m
.22294 .33753 L
s
.22302 .33734 m
.22376 .32867 L
s
.822 .204 1 r
.79134 .34073 m
.79063 .33141 L
s
.79063 .33141 m
.79139 .34058 L
s
.638 .247 1 r
.73368 .27461 m
.73662 .31741 L
s
.395 .62 1 r
.42498 .27461 m
.42408 .30995 L
s
.368 .322 1 r
.11628 .27461 m
.1115 .31442 L
s
.638 .247 1 r
.22294 .33753 m
.22377 .32863 L
s
.22377 .32863 m
.22302 .33734 L
s
.649 .244 1 r
.13802 .3421 m
.13793 .34233 L
s
.559 .267 1 r
.41601 .32673 m
.41571 .33543 L
s
.41579 .33509 m
.41601 .32673 L
s
.702 .231 1 r
.19312 .31337 m
.19217 .32252 L
s
.19218 .32248 m
.19312 .31337 L
s
.19312 .31337 m
.19137 .33105 L
s
.531 .274 1 r
.1073 .32673 m
.1062 .33532 L
s
.10629 .33509 m
.1073 .32673 L
s
.352 .327 1 r
.26438 .33514 m
.2643 .33547 L
s
.559 .267 1 r
.41571 .33543 m
.41603 .32669 L
s
.41603 .32669 m
.41579 .33509 L
s
.531 .274 1 r
.1062 .33532 m
.10731 .32669 L
s
.10731 .32669 m
.10629 .33509 L
s
.953 .176 1 r
.593 .31714 m
.59317 .32676 L
s
.59319 .32671 m
.593 .31714 L
s
.593 .31714 m
.59342 .33604 L
s
.503 .282 1 r
.75001 .32564 m
.75059 .33418 L
s
.75063 .33385 m
.75001 .32564 L
s
.4 .312 1 r
.55236 .31089 m
.5524 .31914 L
s
.55242 .3191 m
.55236 .31089 L
s
.55236 .31089 m
.55252 .32706 L
s
.467 .292 1 r
.59197 .27435 m
.59301 .31491 L
s
.788 .211 1 r
.28323 .27435 m
.28005 .32052 L
s
.503 .282 1 r
.75059 .33418 m
.75004 .3256 L
s
.75004 .3256 m
.75063 .33385 L
s
.669 .239 1 r
.30952 .3159 m
.30892 .32477 L
s
.30893 .32472 m
.30952 .3159 L
s
.30952 .3159 m
.30839 .33367 L
s
.337 .353 1 r
.12261 .33489 m
.12253 .33507 L
s
.81 .206 1 r
.76002 .31667 m
.76064 .32591 L
s
.76067 .32587 m
.76002 .31667 L
s
.76002 .31667 m
.76135 .33504 L
s
.385 .575 1 r
.42592 .31812 m
.42569 .32572 L
s
.42576 .32513 m
.42592 .31812 L
s
.42569 .32572 m
.42594 .31809 L
s
.42594 .31809 m
.42576 .32513 L
s
.352 .427 1 r
.43589 .30906 m
.43566 .3169 L
s
.43568 .31686 m
.43589 .30906 L
s
.43589 .30906 m
.4355 .32444 L
s
.599 .257 1 r
.66431 .33936 m
.66427 .33985 L
s
.559 .267 1 r
.83587 .31272 m
.83666 .32142 L
s
.83669 .32138 m
.83587 .31272 L
s
.83587 .31272 m
.8375 .3298 L
s
.777 .214 1 r
.75902 .27409 m
.76241 .31839 L
s
.352 .327 1 r
.45023 .27409 m
.44955 .31279 L
s
.7 .232 1 r
.14145 .27409 m
.13643 .31876 L
s
.711 .229 1 r
.61375 .34222 m
.61369 .34256 L
s
.41 .682 1 r
.45119 .31703 m
.45102 .32432 L
s
.45108 .32389 m
.45119 .31703 L
s
.589 .259 1 r
.44127 .32623 m
.44103 .33504 L
s
.44111 .33459 m
.44127 .32623 L
s
.41 .682 1 r
.45102 .32432 m
.4512 .31699 L
s
.4512 .31699 m
.45108 .32389 L
s
.417 .307 1 r
.49183 .32344 m
.49173 .33176 L
s
.4918 .33135 m
.49183 .32344 L
s
.589 .259 1 r
.44103 .33504 m
.44128 .32619 L
s
.44128 .32619 m
.44111 .33459 L
s
.417 .307 1 r
.49173 .33176 m
.49184 .3234 L
s
.49184 .3234 m
.4918 .33135 L
s
.45 .297 1 r
.09726 .33687 m
.09716 .33721 L
s
.744 .221 1 r
.75552 .34322 m
.75547 .34345 L
s
.953 .176 1 r
.61831 .31663 m
.61855 .32625 L
s
.61857 .3262 m
.61831 .31663 L
s
.61831 .31663 m
.61887 .33553 L
s
.35 .414 1 r
.48191 .33277 m
.48185 .3331 L
s
.823 .204 1 r
.61728 .27383 m
.61875 .31776 L
s
.579 .262 1 r
.30845 .27383 m
.30583 .31664 L
s
.7 .232 1 r
.86658 .32876 m
.8675 .33777 L
s
.86754 .33758 m
.86658 .32876 L
s
.765 .217 1 r
.33476 .31539 m
.3342 .32456 L
s
.33422 .32451 m
.33476 .31539 L
s
.33476 .31539 m
.33374 .33354 L
s
.7 .232 1 r
.8675 .33777 m
.86661 .32872 L
s
.86661 .32872 m
.86754 .33758 L
s
1 .153 .933 r
.64896 .3324 m
.64933 .34228 L
s
.64938 .34182 m
.64896 .3324 L
s
.701 .232 1 r
.08183 .32961 m
.08062 .33854 L
s
.08068 .33858 m
.08183 .32961 L
s
.618 .252 1 r
.35549 .34011 m
.35541 .34044 L
s
.881 .191 1 r
.16768 .31627 m
.16664 .3257 L
s
.16665 .32565 m
.16768 .31627 L
s
.16768 .31627 m
.1657 .3349 L
s
1 .153 .933 r
.64933 .34228 m
.64899 .33235 L
s
.64899 .33235 m
.64938 .34182 L
s
.701 .232 1 r
.08062 .33854 m
.08184 .32956 L
s
.08184 .32956 m
.08068 .33858 L
s
.629 .249 1 r
.69417 .31287 m
.69459 .32177 L
s
.69462 .32172 m
.69417 .31287 L
s
.69417 .31287 m
.69509 .33029 L
s
.69 .234 1 r
.78084 .34234 m
.78079 .3425 L
s
.658 .242 1 r
.78437 .27358 m
.78804 .31713 L
s
.522 .277 1 r
.4755 .27357 m
.4751 .31451 L
s
.69 .234 1 r
.16664 .27357 m
.16204 .3175 L
s
.36 .463 1 r
.4006 .3207 m
.4003 .32841 L
s
.40036 .32823 m
.4006 .3207 L
s
.4003 .32841 m
.40061 .32066 L
s
.40061 .32066 m
.40036 .32823 L
s
.744 .222 1 r
.72483 .32851 m
.72538 .33767 L
s
.72542 .33733 m
.72483 .32851 L
s
.72538 .33767 m
.72486 .32847 L
s
.72486 .32847 m
.72542 .33733 L
s
.756 .219 1 r
.58305 .32796 m
.5832 .3372 L
s
.58326 .3367 m
.58305 .32796 L
s
.618 .252 1 r
.29944 .32657 m
.29883 .33542 L
s
.29891 .33508 m
.29944 .32657 L
s
.66 .241 1 r
.83145 .33985 m
.83144 .34035 L
s
.367 .322 1 r
.06641 .32239 m
.06527 .33052 L
s
.06537 .33023 m
.06641 .32239 L
s
.756 .219 1 r
.5832 .3372 m
.58307 .32792 L
s
.58307 .32792 m
.58326 .3367 L
s
.618 .252 1 r
.29883 .33542 m
.29946 .32653 L
s
.29946 .32653 m
.29891 .33508 L
s
.609 .254 1 r
.38076 .33923 m
.38067 .33965 L
s
.367 .322 1 r
.06527 .33052 m
.06642 .32235 L
s
.06642 .32235 m
.06537 .33023 L
s
.598 .257 1 r
.07639 .31331 m
.07518 .32206 L
s
.07519 .32202 m
.07639 .31331 L
s
.07639 .31331 m
.07406 .33066 L
s
.503 .282 1 r
.57768 .31126 m
.57779 .31982 L
s
.57781 .31977 m
.57768 .31126 L
s
.57768 .31126 m
.57797 .32804 L
s
.68 .237 1 r
.6426 .27332 m
.64437 .3165 L
s
.811 .206 1 r
.33369 .27332 m
.33131 .31799 L
s
.56 .267 1 r
.71495 .33799 m
.71492 .33844 L
s
.345 .39 1 r
.62825 .30852 m
.62847 .31643 L
s
.62849 .31639 m
.62825 .30852 L
s
.62825 .30852 m
.62876 .32405 L
s
.427 .751 1 r
.18292 .32468 m
.1828 .3253 L
s
.589 .259 1 r
.63363 .32547 m
.63392 .33429 L
s
.63396 .33384 m
.63363 .32547 L
s
.55 .269 1 r
.21363 .34023 m
.21357 .34019 L
s
.589 .259 1 r
.63392 .33429 m
.63366 .32543 L
s
.63366 .32543 m
.63396 .33384 L
s
.345 .391 1 r
.34008 .33326 m
.34001 .33344 L
s
.442 .299 1 r
.26874 .31152 m
.26808 .31982 L
s
.26809 .31978 m
.26874 .31152 L
s
.26874 .31152 m
.26749 .32804 L
s
.881 .191 1 r
.81074 .31576 m
.81152 .3252 L
s
.81156 .32515 m
.81074 .31576 L
s
.81074 .31576 m
.81238 .33441 L
s
.917 .184 1 r
.66893 .31507 m
.66931 .32465 L
s
.66934 .3246 m
.66893 .31507 L
s
.66893 .31507 m
.66977 .33378 L
s
.424 .305 1 r
.45661 .3355 m
.45654 .33583 L
s
.608 .254 1 r
.10162 .31243 m
.10046 .32126 L
s
.10047 .32121 m
.10162 .31243 L
s
.10162 .31243 m
.09942 .32978 L
s
.504 .282 1 r
.80974 .27306 m
.81348 .31363 L
s
.712 .229 1 r
.50079 .27306 m
.50069 .31624 L
s
.608 .254 1 r
.19184 .27306 m
.18761 .31661 L
s
.357 .451 1 r
.65356 .30753 m
.65384 .31533 L
s
.65386 .31529 m
.65356 .30753 L
s
.65356 .30753 m
.65418 .3228 L
s
.68 .237 1 r
.52256 .3406 m
.5225 .34094 L
s
.34 .366 1 r
.3193 .30911 m
.31878 .31702 L
s
.3188 .31698 m
.3193 .30911 L
s
.3193 .30911 m
.31835 .32479 L
s
.916 .184 1 r
.55777 .33025 m
.55786 .33979 L
s
.55792 .33944 m
.55777 .33025 L
s
.55786 .33979 m
.55779 .3302 L
s
.55779 .3302 m
.55792 .33944 L
s
.722 .227 1 r
.18828 .34222 m
.1882 .34237 L
s
.342 .378 1 r
.73483 .32049 m
.73533 .32843 L
s
.73537 .3281 m
.73483 .32049 L
s
.73533 .32843 m
.73486 .32045 L
s
.73486 .32045 m
.73537 .3281 L
s
.88 .191 1 r
.21812 .31492 m
.21722 .32439 L
s
.21723 .32435 m
.21812 .31492 L
s
.21812 .31492 m
.21643 .33352 L
s
.953 .176 1 r
.66793 .2728 m
.67019 .31898 L
s
.669 .239 1 r
.35894 .2728 m
.35696 .31599 L
s
.638 .247 1 r
.04994 .2728 m
.04389 .31598 L
s
1 .146 .894 r
.87222 .34732 m
.87219 .34766 L
s
1 .156 .946 r
.73038 .34669 m
.73033 .347 L
s
.385 .574 1 r
.39518 .30525 m
.39486 .31283 L
s
.39487 .31279 m
.39518 .30525 L
s
.39518 .30525 m
.39462 .31992 L
s
.36 .325 1 r
.8162 .33338 m
.81618 .33375 L
s
.378 .543 1 r
.47644 .318 m
.47632 .3256 L
s
.47638 .32524 m
.47644 .318 L
s
.352 .327 1 r
.67435 .33276 m
.67432 .3332 L
s
.378 .543 1 r
.47632 .3256 m
.47646 .31796 L
s
.47646 .31796 m
.47638 .32524 L
s
.68 .237 1 r
.1575 .3272 m
.15649 .33618 L
s
.15658 .33595 m
.1575 .3272 L
s
.15649 .33618 m
.15751 .32716 L
s
.15751 .32716 m
.15658 .33595 L
s
.629 .249 1 r
.57316 .33848 m
.57311 .33897 L
s
.618 .252 1 r
.65898 .32526 m
.65933 .33416 L
s
.65937 .3337 m
.65898 .32526 L
s
.68 .237 1 r
.83512 .27254 m
.8394 .31535 L
s
.822 .204 1 r
.52608 .27254 m
.52633 .31797 L
s
.441 .3 1 r
.21705 .27254 m
.21347 .31274 L
s
.618 .252 1 r
.65933 .33416 m
.659 .32522 L
s
.659 .32522 m
.65937 .3337 L
s
.744 .222 1 r
.77555 .3275 m
.77624 .33666 L
s
.77628 .33632 m
.77555 .3275 L
s
.68 .237 1 r
.54786 .3401 m
.5478 .34044 L
s
.754 .219 1 r
.24336 .31416 m
.24256 .32329 L
s
.24257 .32325 m
.24336 .31416 L
s
.24336 .31416 m
.24184 .33227 L
s
.69 .234 1 r
.41053 .31347 m
.41019 .32244 L
s
.41021 .3224 m
.41053 .31347 L
s
.41053 .31347 m
.40994 .33127 L
s
.367 .322 1 r
.25866 .32192 m
.258 .33002 L
s
.25807 .32984 m
.25866 .32192 L
s
.541 .272 1 r
.46114 .31068 m
.46094 .31935 L
s
.46096 .31931 m
.46114 .31068 L
s
.46114 .31068 m
.46083 .32765 L
s
.744 .222 1 r
.77624 .33666 m
.77558 .32746 L
s
.77558 .32746 m
.77628 .33632 L
s
.978 .171 1 r
.52711 .31562 m
.52709 .32529 L
s
.52711 .32524 m
.52711 .31562 L
s
.52711 .31562 m
.52715 .33465 L
s
.367 .322 1 r
.258 .33002 m
.25867 .32188 L
s
.25867 .32188 m
.25807 .32984 L
s
.459 .294 1 r
.74488 .31219 m
.7454 .32045 L
s
.74542 .32041 m
.74488 .31219 L
s
.74488 .31219 m
.74601 .3289 L
s
1 .166 .998 r
.35993 .31647 m
.35942 .32613 L
s
.35944 .32608 m
.35993 .31647 L
s
.35993 .31647 m
.359 .33564 L
s
.88 .191 1 r
.86149 .31442 m
.86241 .32389 L
s
.86245 .32384 m
.86149 .31442 L
s
.86149 .31442 m
.86341 .33302 L
s
.767 .216 1 r
.69328 .27228 m
.69577 .31622 L
s
.559 .267 1 r
.3842 .27228 m
.38262 .31397 L
s
.522 .277 1 r
.07512 .27228 m
.06949 .31472 L
s
.588 .259 1 r
.34991 .32586 m
.34944 .33456 L
s
.34951 .33445 m
.34991 .32586 L
s
.691 .234 1 r
.88227 .33922 m
.88226 .33972 L
s
.588 .259 1 r
.34944 .33456 m
.34993 .32581 L
s
.34993 .32581 m
.34951 .33445 L
s
.733 .224 1 r
.68977 .34146 m
.68972 .34166 L
s
.88 .191 1 r
.33005 .34433 m
.32997 .34445 L
s
.733 .224 1 r
.23876 .34084 m
.23867 .34115 L
s
.744 .222 1 r
.85698 .34084 m
.85696 .34118 L
s
.618 .252 1 r
.68432 .32476 m
.68475 .33365 L
s
.68478 .3332 m
.68432 .32476 L
s
.45 .297 1 r
.09139 .32336 m
.09029 .33169 L
s
.09036 .33158 m
.09139 .32336 L
s
.868 .194 1 r
.49726 .3437 m
.49719 .3439 L
s
.754 .219 1 r
.86051 .27202 m
.86532 .31671 L
s
.811 .206 1 r
.55139 .27202 m
.55198 .31634 L
s
.618 .252 1 r
.24228 .27202 m
.23882 .31446 L
s
.68475 .33365 m
.68435 .32471 L
s
.68435 .32471 m
.68478 .3332 L
s
.45 .297 1 r
.09029 .33169 m
.0914 .32332 L
s
.0914 .32332 m
.09036 .33158 L
s
.68 .237 1 r
.77025 .31149 m
.77089 .32054 L
s
.77092 .32049 m
.77025 .31149 L
s
.77025 .31149 m
.77159 .32914 L
s
.711 .229 1 r
.60304 .31229 m
.60322 .32139 L
s
.60325 .32134 m
.60304 .31229 L
s
.60304 .31229 m
.60349 .33014 L
s
.669 .239 1 r
.12667 .31303 m
.12558 .32194 L
s
.12559 .32189 m
.12667 .31303 L
s
.12667 .31303 m
.12456 .33077 L
s
.476 .29 1 r
.34451 .30951 m
.34402 .318 L
s
.34404 .31795 m
.34451 .30951 L
s
.34451 .30951 m
.34363 .32615 L
s
.754 .219 1 r
.07151 .34184 m
.07142 .34199 L
s
.521 .277 1 r
.31465 .3371 m
.31457 .33729 L
s
.733 .224 1 r
.29389 .31255 m
.29322 .32168 L
s
.29324 .32164 m
.29389 .31255 L
s
.29389 .31255 m
.29266 .33051 L
s
.648 .244 1 r
.71863 .27176 m
.72139 .31458 L
s
.744 .221 1 r
.40947 .27176 m
.40816 .31533 L
s
.473 .913 1 r
.10031 .27176 m
.09656 .30191 L
s
.638 .247 1 r
.37518 .32535 m
.37477 .33425 L
s
.37485 .33395 m
.37518 .32535 L
s
.37477 .33425 m
.3752 .32531 L
s
.3752 .32531 m
.37485 .33395 L
s
1 .161 .972 r
.80645 .34445 m
.80642 .34491 L
s
1 .141 .867 r
.24861 .33262 m
.24777 .34252 L
s
.24785 .34243 m
.24861 .33262 L
s
.376 .32 1 r
.7043 .30728 m
.70472 .3155 L
s
.70474 .31546 m
.7043 .30728 L
s
.7043 .30728 m
.70519 .32327 L
s
.833 .201 1 r
.32454 .32844 m
.32397 .33775 L
s
.32405 .33756 m
.32454 .32844 L
s
.383 .317 1 r
.67899 .30875 m
.67934 .31689 L
s
.67936 .31685 m
.67899 .30875 L
s
.67899 .30875 m
.67976 .32489 L
s
1 .141 .867 r
.24777 .34252 m
.24862 .33257 L
s
.24862 .33257 m
.24785 .34243 L
s
.833 .201 1 r
.32397 .33775 m
.32456 .32839 L
s
.32456 .32839 m
.32405 .33756 L
s
.68 .237 1 r
.57672 .2715 m
.57763 .3147 L
s
.868 .194 1 r
.26752 .2715 m
.26408 .31807 L
s
.68 .237 1 r
.59851 .33909 m
.59846 .33943 L
s
.598 .257 1 r
.23321 .3251 m
.23243 .33384 L
s
.23251 .33369 m
.23321 .3251 L
s
.23243 .33384 m
.23323 .32506 L
s
.23323 .32506 m
.23251 .33369 L
s
.649 .244 1 r
.62383 .33785 m
.62379 .3383 L
s
.378 .543 1 r
.4204 .30629 m
.42014 .3138 L
s
.42015 .31376 m
.4204 .30629 L
s
.4204 .30629 m
.41994 .32127 L
s
.638 .247 1 r
.15187 .31263 m
.15085 .32143 L
s
.15087 .32138 m
.15187 .31263 L
s
.15187 .31263 m
.1499 .33026 L
s
.54 .272 1 r
.17264 .33723 m
.17256 .33738 L
s
.579 .262 1 r
.51174 .30984 m
.51168 .31863 L
s
.5117 .31859 m
.51174 .30984 L
s
.51174 .30984 m
.5117 .32701 L
s
.777 .214 1 r
.82635 .32679 m
.82719 .33603 L
s
.82722 .33569 m
.82635 .32679 L
s
.7 .232 1 r
.74048 .34009 m
.74043 .34028 L
s
.845 .199 1 r
.74401 .27124 m
.74726 .31631 L
s
.589 .259 1 r
.43476 .27124 m
.43382 .31332 L
s
.766 .217 1 r
.12552 .27124 m
.12019 .31669 L
s
.777 .214 1 r
.82719 .33603 m
.82638 .32674 L
s
.82638 .32674 m
.82722 .33569 L
s
.701 .232 1 r
.48642 .31157 m
.48629 .32062 L
s
.48631 .32058 m
.48642 .31157 L
s
.48642 .31157 m
.48624 .32938 L
s
.766 .217 1 r
.51711 .32709 m
.51708 .33625 L
s
.51715 .33606 m
.51711 .32709 L
s
.669 .239 1 r
.20784 .32708 m
.20698 .33591 L
s
.20703 .33606 m
.20784 .32708 L
s
.766 .217 1 r
.51708 .33625 m
.51713 .32704 L
s
.51713 .32704 m
.51715 .33606 L
s
.669 .239 1 r
.20698 .33591 m
.20785 .32704 L
s
.20785 .32704 m
.20703 .33606 L
s
.618 .252 1 r
.60206 .27098 m
.60327 .31306 L
s
.69 .234 1 r
.29277 .27098 m
.28984 .3153 L
s
.648 .244 1 r
.14726 .33922 m
.14718 .33933 L
s
.531 .274 1 r
.36975 .30977 m
.36932 .31837 L
s
.36934 .31833 m
.36975 .30977 L
s
.36975 .30977 m
.36898 .32675 L
s
.648 .244 1 r
.20244 .31058 m
.20154 .31952 L
s
.20155 .31948 m
.20244 .31058 L
s
.20244 .31058 m
.20075 .32813 L
s
1 .133 .827 r
.71977 .3163 m
.72032 .32631 L
s
.72035 .32626 m
.71977 .3163 L
s
.71977 .3163 m
.72096 .33613 L
s
.99 .169 1 r
.80111 .32908 m
.80192 .33877 L
s
.80195 .33843 m
.80111 .32908 L
s
.811 .206 1 r
.85176 .32629 m
.85268 .33564 L
s
.8527 .33518 m
.85176 .32629 L
s
.79574 .31219 m
.79647 .32152 L
s
.7965 .32147 m
.79574 .31219 L
s
.79574 .31219 m
.79727 .3305 L
s
.45 .297 1 r
.64374 .3207 m
.64403 .32914 L
s
.64407 .32869 m
.64374 .3207 L
s
.99 .169 1 r
.80192 .33877 m
.80114 .32903 L
s
.80114 .32903 m
.80195 .33843 L
s
.4 .312 1 r
.27383 .33261 m
.27375 .33295 L
s
.459 .295 1 r
.7694 .27072 m
.77267 .31168 L
s
.372 .52 1 r
.46007 .27072 m
.45954 .30683 L
s
.588 .259 1 r
.15074 .27072 m
.14605 .31355 L
s
.811 .206 1 r
.85268 .33564 m
.85179 .32624 L
s
.85179 .32624 m
.8527 .33518 L
s
.35 .414 1 r
.38505 .31791 m
.38471 .32578 L
s
.38478 .32545 m
.38505 .31791 L
s
.45 .297 1 r
.64403 .32914 m
.64376 .32066 L
s
.64376 .32066 m
.64407 .32869 L
s
.344 .33 1 r
.13182 .33199 m
.13174 .33217 L
s
.35 .414 1 r
.38471 .32578 m
.38507 .31787 L
s
.38507 .31787 m
.38478 .32545 L
s
.744 .222 1 r
.70977 .32574 m
.71028 .3349 L
s
.71032 .33456 m
.70977 .32574 L
s
.71028 .3349 m
.7098 .32569 L
s
.7098 .32569 m
.71032 .33456 L
s
.2892 .34058 m
.28912 .3407 L
s
.811 .206 1 r
.54244 .32658 m
.54248 .3359 L
s
.54255 .33555 m
.54244 .32658 L
s
.54248 .3359 m
.54246 .32654 L
s
.54246 .32654 m
.54255 .33555 L
s
.638 .247 1 r
.11638 .32464 m
.11528 .3335 L
s
.11536 .33331 m
.11638 .32464 L
s
.494 .285 1 r
.1417 .32324 m
.14072 .33165 L
s
.14077 .33168 m
.1417 .32324 L
s
.486 .287 1 r
.62741 .27046 m
.62887 .3103 L
s
.868 .194 1 r
.31804 .27046 m
.31537 .31629 L
s
.638 .247 1 r
.11528 .3335 m
.1164 .32459 L
s
.1164 .32459 m
.11536 .33331 L
s
.494 .285 1 r
.14072 .33165 m
.14172 .3232 L
s
.14172 .3232 m
.14077 .33168 L
s
.618 .252 1 r
.36516 .33684 m
.36508 .33718 L
s
.487 .287 1 r
.50173 .32074 m
.50167 .3293 L
s
.50173 .32881 m
.50173 .32074 L
s
.765 .217 1 r
.17701 .31301 m
.17603 .32211 L
s
.17604 .32206 m
.17701 .31301 L
s
.17701 .31301 m
.17511 .33124 L
s
.589 .259 1 r
.53252 .33622 m
.53246 .33656 L
s
.57 .264 1 r
.84192 .33622 m
.84189 .33649 L
s
.487 .287 1 r
.50167 .3293 m
.50175 .3207 L
s
.50175 .3207 m
.50173 .32881 L
s
.658 .242 1 r
.0603 .31095 m
.05902 .31986 L
s
.05903 .31982 m
.0603 .31095 L
s
.0603 .31095 m
.05784 .32862 L
s
.811 .206 1 r
.87718 .32578 m
.87818 .33513 L
s
.87819 .33468 m
.87718 .32578 L
s
.82115 .31168 m
.82195 .32101 L
s
.82198 .32096 m
.82115 .31168 L
s
.82115 .31168 m
.82282 .32999 L
s
.4 .312 1 r
.60851 .33211 m
.60846 .33244 L
s
.503 .282 1 r
.7948 .2702 m
.79839 .31117 L
s
.88 .191 1 r
.48538 .2702 m
.48507 .31566 L
s
.485 .287 1 r
.17597 .2702 m
.17176 .31154 L
s
.811 .206 1 r
.87818 .33513 m
.87721 .32573 L
s
.87721 .32573 m
.87819 .33468 L
s
.385 .575 1 r
.42576 .32513 m
.42569 .32572 L
s
.628 .249 1 r
.19777 .33784 m
.19769 .33799 L
s
.559 .267 1 r
.78582 .32244 m
.7865 .33115 L
s
.78653 .33081 m
.78582 .32244 L
s
.7865 .33115 m
.78585 .3224 L
s
.78585 .3224 m
.78653 .33081 L
s
.41 .682 1 r
.45108 .32389 m
.45102 .32432 L
s
.54 .272 1 r
.25296 .30931 m
.25222 .31791 L
s
.25224 .31787 m
.25296 .30931 L
s
.25296 .30931 m
.25157 .32637 L
s
.744 .221 1 r
.84653 .31073 m
.84738 .3199 L
s
.84741 .31986 m
.84653 .31073 L
s
.84653 .31073 m
.84831 .32874 L
s
1 .166 .996 r
.65278 .26994 m
.65481 .31577 L
s
.55 .269 1 r
.7298 .30868 m
.73031 .31736 L
s
.73033 .31732 m
.7298 .30868 L
s
.7298 .30868 m
.73088 .32574 L
s
.88 .191 1 r
.34332 .26994 m
.34103 .3154 L
s
.485 .287 1 r
.39044 .33634 m
.39039 .33616 L
s
.766 .216 1 r
.22761 .31099 m
.22675 .3202 L
s
.22677 .32016 m
.22761 .31099 L
s
.22761 .31099 m
.226 .32911 L
s
.608 .254 1 r
.69993 .33634 m
.69989 .33664 L
s
.766 .216 1 r
.28364 .32528 m
.28296 .33448 L
s
.28304 .33418 m
.28364 .32528 L
s
.701 .232 1 r
.50719 .33858 m
.50712 .33877 L
s
.559 .267 1 r
.41579 .33509 m
.41571 .33543 L
s
.531 .274 1 r
.10629 .33509 m
.1062 .33532 L
s
.953 .176 1 r
.82021 .26968 m
.82459 .31552 L
s
.846 .199 1 r
.51072 .26968 m
.51075 .31439 L
s
.352 .427 1 r
.43566 .3169 m
.43544 .32473 L
s
.4355 .32444 m
.43566 .3169 L
s
.488 .962 1 r
.20122 .26968 m
.19809 .30282 L
s
.766 .216 1 r
.28296 .33448 m
.28366 .32523 L
s
.28366 .32523 m
.28304 .33418 L
s
.352 .427 1 r
.43544 .32473 m
.43568 .31686 L
s
.43568 .31686 m
.4355 .32444 L
s
.638 .247 1 r
.22302 .33734 m
.22294 .33753 L
s
.836 .201 1 r
.87193 .30992 m
.87289 .3194 L
s
.87292 .31935 m
.87193 .30992 L
s
.87193 .30992 m
.87388 .32823 L
s
.503 .282 1 r
.75063 .33385 m
.75059 .33418 L
s
.4 .312 1 r
.5524 .31914 m
.55247 .32739 L
s
.55252 .32706 m
.5524 .31914 L
s
.55247 .32739 m
.55242 .3191 L
s
.55242 .3191 m
.55252 .32706 L
s
.916 .184 1 r
.5678 .32697 m
.56791 .33651 L
s
.56798 .33617 m
.5678 .32697 L
s
.522 .277 1 r
.44567 .30795 m
.44543 .31655 L
s
.44545 .31651 m
.44567 .30795 L
s
.44567 .30795 m
.44528 .32486 L
s
.416 .307 1 r
.471 .30656 m
.47084 .31486 L
s
.47086 .31482 m
.471 .30656 L
s
.471 .30656 m
.47076 .32286 L
s
.916 .184 1 r
.56791 .33651 m
.56782 .32692 L
s
.56782 .32692 m
.56798 .33617 L
s
.669 .239 1 r
.56242 .31015 m
.56249 .3191 L
s
.56251 .31905 m
.56242 .31015 L
s
.56242 .31015 m
.56265 .32786 L
s
.417 .307 1 r
.4918 .33135 m
.49173 .33176 L
s
.599 .257 1 r
.67815 .26942 m
.68035 .31152 L
s
.337 .353 1 r
.36862 .26941 m
.36698 .30778 L
s
.598 .257 1 r
.05908 .26941 m
.05302 .31338 L
s
.822 .204 1 r
.79139 .34058 m
.79134 .34073 L
s
.68 .237 1 r
.27822 .30894 m
.27752 .318 L
s
.27754 .31795 m
.27822 .30894 L
s
.27822 .30894 m
.27693 .3266 L
s
.638 .247 1 r
.08541 .31118 m
.08422 .31994 L
s
.08423 .3199 m
.08541 .31118 L
s
.08541 .31118 m
.08308 .32885 L
s
.702 .231 1 r
.19217 .32252 m
.19124 .33169 L
s
.19137 .33105 m
.19217 .32252 L
s
.599 .257 1 r
.61312 .30773 m
.61332 .31659 L
s
.61335 .31655 m
.61312 .30773 L
s
.61312 .30773 m
.6136 .32497 L
s
.702 .231 1 r
.19124 .33169 m
.19218 .32248 L
s
.19218 .32248 m
.19137 .33105 L
s
.658 .242 1 r
.11074 .30993 m
.1096 .31884 L
s
.10961 .3188 m
.11074 .30993 L
s
.11074 .30993 m
.10855 .3276 L
s
.669 .239 1 r
.30892 .32477 m
.30833 .33363 L
s
.30839 .33367 m
.30892 .32477 L
s
.36 .463 1 r
.40036 .32823 m
.4003 .32841 L
s
.383 .317 1 r
.32888 .30645 m
.32837 .3146 L
s
.32838 .31456 m
.32888 .30645 L
s
.32888 .30645 m
.32794 .32261 L
s
.589 .259 1 r
.44111 .33459 m
.44103 .33504 L
s
.648 .244 1 r
.84564 .26915 m
.85007 .312 L
s
.34 .366 1 r
.53606 .26915 m
.53639 .30789 L
s
.628 .249 1 r
.22648 .26915 m
.22275 .31238 L
s
.669 .239 1 r
.30833 .33363 m
.30893 .32472 L
s
.30893 .32472 m
.30839 .33367 L
s
.559 .267 1 r
.83666 .32142 m
.83748 .33013 L
s
.8375 .3298 m
.83666 .32142 L
s
.83748 .33013 m
.83669 .32138 L
s
.83669 .32138 m
.8375 .3298 L
s
.81 .206 1 r
.76064 .32591 m
.76129 .33516 L
s
.76135 .33504 m
.76064 .32591 L
s
.744 .222 1 r
.58779 .30971 m
.58793 .31889 L
s
.58795 .31884 m
.58779 .30971 L
s
.58779 .30971 m
.58815 .32772 L
s
.81 .206 1 r
.76129 .33516 m
.76067 .32587 L
s
.76067 .32587 m
.76135 .33504 L
s
1 .141 .867 r
.70355 .26889 m
.70641 .31662 L
s
.649 .244 1 r
.39393 .26889 m
.39244 .31137 L
s
.628 .249 1 r
.0843 .26889 m
.07869 .31212 L
s
.88 .191 1 r
.53709 .31261 m
.53709 .32198 L
s
.53711 .32194 m
.53709 .31261 L
s
.53709 .31261 m
.53718 .33135 L
s
.953 .176 1 r
.59317 .32676 m
.59336 .33638 L
s
.59342 .33604 m
.59317 .32676 L
s
.367 .322 1 r
.06537 .33023 m
.06527 .33052 L
s
.953 .176 1 r
.59336 .33638 m
.59319 .32671 L
s
.59319 .32671 m
.59342 .33604 L
s
.345 .39 1 r
.62847 .31643 m
.62871 .32434 L
s
.62876 .32405 m
.62847 .31643 L
s
.62871 .32434 m
.62849 .31639 L
s
.62849 .31639 m
.62876 .32405 L
s
.7 .232 1 r
.86754 .33758 m
.8675 .33777 L
s
.503 .282 1 r
.806 .30667 m
.8067 .31524 L
s
.80673 .31519 m
.806 .30667 L
s
.806 .30667 m
.80746 .32347 L
s
.45 .297 1 r
.35418 .30597 m
.35372 .31439 L
s
.35374 .31434 m
.35418 .30597 L
s
.35418 .30597 m
.35335 .32247 L
s
.4 .312 1 r
.83135 .30528 m
.83209 .31354 L
s
.83211 .3135 m
.83135 .30528 L
s
.83135 .30528 m
.83288 .32147 L
s
.45 .297 1 r
.56142 .26863 m
.56207 .3085 L
s
.55 .269 1 r
.25175 .26863 m
.24841 .31112 L
s
.68 .237 1 r
.78066 .30817 m
.78133 .31723 L
s
.78136 .31719 m
.78066 .30817 L
s
.78066 .30817 m
.78206 .32584 L
s
.357 .451 1 r
.65384 .31533 m
.65414 .32313 L
s
.65418 .3228 m
.65384 .31533 L
s
.766 .216 1 r
.75532 .30972 m
.75593 .31893 L
s
.75596 .31889 m
.75532 .30972 L
s
.75532 .30972 m
.75661 .32784 L
s
.701 .232 1 r
.08068 .33858 m
.08062 .33854 L
s
.765 .217 1 r
.3342 .32456 m
.33366 .33373 L
s
.33374 .33354 m
.3342 .32456 L
s
.357 .451 1 r
.65414 .32313 m
.65386 .31529 L
s
.65386 .31529 m
.65418 .3228 L
s
.629 .249 1 r
.69459 .32177 m
.69505 .33067 L
s
.69509 .33029 m
.69459 .32177 L
s
.618 .252 1 r
.29891 .33508 m
.29883 .33542 L
s
.378 .543 1 r
.47638 .32524 m
.47632 .3256 L
s
.765 .217 1 r
.33366 .33373 m
.33422 .32451 L
s
.33422 .32451 m
.33374 .33354 L
s
.342 .378 1 r
.73537 .3281 m
.73533 .32843 L
s
.733 .224 1 r
.13594 .30983 m
.13484 .31893 L
s
.13486 .31888 m
.13594 .30983 L
s
.13594 .30983 m
.13384 .32784 L
s
.629 .249 1 r
.69505 .33067 m
.69462 .32172 L
s
.69462 .32172 m
.69509 .33029 L
s
.744 .222 1 r
.72542 .33733 m
.72538 .33767 L
s
.589 .259 1 r
.63396 .33384 m
.63392 .33429 L
s
.442 .299 1 r
.26808 .31982 m
.26742 .32812 L
s
.26749 .32804 m
.26808 .31982 L
s
.503 .282 1 r
.57779 .31982 m
.57792 .32838 L
s
.57797 .32804 m
.57779 .31982 L
s
.34 .366 1 r
.31878 .31702 m
.31828 .32494 L
s
.31835 .32479 m
.31878 .31702 L
s
.965 .174 1 r
.72896 .26837 m
.73208 .3146 L
s
.531 .274 1 r
.41925 .26837 m
.41814 .30936 L
s
.416 .307 1 r
.10954 .26837 m
.10448 .30973 L
s
.756 .219 1 r
.58326 .3367 m
.5832 .3372 L
s
.385 .574 1 r
.39486 .31283 m
.39455 .3204 L
s
.39462 .31992 m
.39486 .31283 L
s
.442 .299 1 r
.26742 .32812 m
.26809 .31978 L
s
.26809 .31978 m
.26749 .32804 L
s
.503 .282 1 r
.57792 .32838 m
.57781 .31977 L
s
.57781 .31977 m
.57797 .32804 L
s
.953 .176 1 r
.61855 .32625 m
.61881 .33588 L
s
.61887 .33553 m
.61855 .32625 L
s
.34 .366 1 r
.31828 .32494 m
.3188 .31698 L
s
.3188 .31698 m
.31835 .32479 L
s
.598 .257 1 r
.07518 .32206 m
.07397 .33081 L
s
.07406 .33066 m
.07518 .32206 L
s
.385 .574 1 r
.39455 .3204 m
.39487 .31279 L
s
.39487 .31279 m
.39462 .31992 L
s
.67 .239 1 r
.63852 .30795 m
.6388 .31697 L
s
.63883 .31693 m
.63852 .30795 L
s
.63852 .30795 m
.63916 .32558 L
s
.628 .249 1 r
.16126 .30869 m
.16026 .31753 L
s
.16028 .31748 m
.16126 .30869 L
s
.16126 .30869 m
.15935 .32621 L
s
.953 .176 1 r
.61881 .33588 m
.61857 .3262 L
s
.61857 .3262 m
.61887 .33553 L
s
.598 .257 1 r
.07397 .33081 m
.07519 .32202 L
s
.07519 .32202 m
.07406 .33066 L
s
1 .153 .933 r
.64938 .34182 m
.64933 .34228 L
s
.881 .191 1 r
.16664 .3257 m
.1656 .33514 L
s
.1657 .3349 m
.16664 .3257 L
s
.1656 .33514 m
.16665 .32565 L
s
.16665 .32565 m
.1657 .3349 L
s
.45 .297 1 r
.58679 .26811 m
.58776 .30835 L
s
.569 .264 1 r
.27704 .26811 m
.27409 .30985 L
s
.608 .254 1 r
.10046 .32126 m
.09931 .33008 L
s
.09942 .32978 m
.10046 .32126 L
s
.09931 .33008 m
.10047 .32121 L
s
.10047 .32121 m
.09942 .32978 L
s
.49633 .30792 m
.49623 .31672 L
s
.49625 .31668 m
.49633 .30792 L
s
.49633 .30792 m
.49621 .32533 L
s
.367 .322 1 r
.25807 .32984 m
.258 .33002 L
s
.639 .247 1 r
.75438 .26785 m
.75758 .31034 L
s
.408 .31 1 r
.44459 .26785 m
.44382 .30735 L
s
.569 .264 1 r
.1348 .26785 m
.12984 .31109 L
s
.344 .33 1 r
.26262 .30385 m
.26195 .31192 L
s
.26197 .31188 m
.26262 .30385 L
s
.26262 .30385 m
.26138 .3197 L
s
.56 .267 1 r
.68928 .30601 m
.68968 .31477 L
s
.68971 .31472 m
.68928 .30601 L
s
.68928 .30601 m
.69015 .32308 L
s
.881 .191 1 r
.81152 .3252 m
.81234 .33464 L
s
.81238 .33441 m
.81152 .3252 L
s
.81234 .33464 m
.81156 .32515 L
s
.81156 .32515 m
.81238 .33441 L
s
.618 .252 1 r
.65937 .3337 m
.65933 .33416 L
s
.917 .184 1 r
.66931 .32465 m
.66973 .33424 L
s
.66977 .33378 m
.66931 .32465 L
s
.459 .294 1 r
.7454 .32045 m
.74595 .32872 L
s
.74601 .3289 m
.7454 .32045 L
s
.916 .184 1 r
.55792 .33944 m
.55786 .33979 L
s
.45 .297 1 r
.40483 .30495 m
.4045 .31337 L
s
.40451 .31332 m
.40483 .30495 L
s
.40483 .30495 m
.40425 .32145 L
s
.917 .184 1 r
.66973 .33424 m
.66934 .3246 L
s
.66934 .3246 m
.66977 .33378 L
s
.477 .289 1 r
.61218 .26759 m
.61346 .30784 L
s
.30234 .26759 m
.29981 .30783 L
s
.68 .237 1 r
.15658 .33595 m
.15649 .33618 L
s
.459 .294 1 r
.74595 .32872 m
.74542 .32041 L
s
.74542 .32041 m
.74601 .3289 L
s
.904 .186 1 r
.30337 .31068 m
.30271 .32016 L
s
.30272 .32011 m
.30337 .31068 L
s
.30337 .31068 m
.30214 .32945 L
s
.599 .257 1 r
.18648 .30862 m
.18556 .31732 L
s
.18558 .31727 m
.18648 .30862 L
s
.18648 .30862 m
.18471 .32608 L
s
.541 .272 1 r
.46094 .31935 m
.46076 .32803 L
s
.46083 .32765 m
.46094 .31935 L
s
.46076 .32803 m
.46096 .31931 L
s
.46096 .31931 m
.46083 .32765 L
s
.88 .191 1 r
.21722 .32439 m
.21632 .33387 L
s
.21643 .33352 m
.21722 .32439 L
s
.744 .222 1 r
.77628 .33632 m
.77624 .33666 L
s
.88 .191 1 r
.21632 .33387 m
.21723 .32435 L
s
.21723 .32435 m
.21643 .33352 L
s
.588 .259 1 r
.77981 .26733 m
.78332 .30945 L
s
.503 .282 1 r
.46994 .26733 m
.46946 .30832 L
s
.88 .191 1 r
.16006 .26733 m
.15521 .31282 L
s
.69 .234 1 r
.41019 .32244 m
.40987 .33143 L
s
.40994 .33127 m
.41019 .32244 L
s
.45 .297 1 r
.09036 .33158 m
.09029 .33169 L
s
.69 .234 1 r
.40987 .33143 m
.41021 .3224 L
s
.41021 .3224 m
.40994 .33127 L
s
.588 .259 1 r
.34951 .33445 m
.34944 .33456 L
s
.754 .219 1 r
.24256 .32329 m
.24176 .33243 L
s
.24184 .33227 m
.24256 .32329 L
s
.24176 .33243 m
.24257 .32325 L
s
.24257 .32325 m
.24184 .33227 L
s
.618 .252 1 r
.68478 .3332 m
.68475 .33365 L
s
.777 .214 1 r
.63758 .26707 m
.63932 .31106 L
s
.375 .532 1 r
.32766 .26707 m
.32555 .30507 L
s
.811 .206 1 r
.52171 .30803 m
.52167 .3174 L
s
.52169 .31735 m
.52171 .30803 L
s
.52171 .30803 m
.52172 .32632 L
s
.476 .29 1 r
.34402 .318 m
.34355 .32648 L
s
.34363 .32615 m
.34402 .318 L
s
.845 .199 1 r
.66399 .30884 m
.66435 .31825 L
s
.66438 .3182 m
.66399 .30884 L
s
.66399 .30884 m
.66479 .32732 L
s
.378 .543 1 r
.42014 .3138 m
.41989 .3213 L
s
.41994 .32127 m
.42014 .3138 L
s
.476 .29 1 r
.34355 .32648 m
.34404 .31795 L
s
.34404 .31795 m
.34363 .32615 L
s
.378 .543 1 r
.41989 .3213 m
.42015 .31376 L
s
.42015 .31376 m
.41994 .32127 L
s
.467 .292 1 r
.09483 .30621 m
.09372 .31455 L
s
.09373 .31451 m
.09483 .30621 L
s
.09483 .30621 m
.09267 .32294 L
s
.978 .171 1 r
.52709 .32529 m
.52709 .33496 L
s
.52715 .33465 m
.52709 .32529 L
s
.88 .191 1 r
.86241 .32389 m
.86338 .33336 L
s
.86341 .33302 m
.86241 .32389 L
s
.383 .317 1 r
.67934 .31689 m
.67971 .32504 L
s
.67976 .32489 m
.67934 .31689 L
s
.978 .171 1 r
.52709 .33496 m
.52711 .32524 L
s
.52711 .32524 m
.52715 .33465 L
s
.376 .32 1 r
.70472 .3155 m
.70516 .32371 L
s
.70519 .32327 m
.70472 .3155 L
s
.88 .191 1 r
.86338 .33336 m
.86245 .32384 L
s
.86245 .32384 m
.86341 .33302 L
s
.845 .199 1 r
.80526 .26681 m
.80943 .31268 L
s
.4953 .26681 m
.49512 .31193 L
s
1 .146 .894 r
.18534 .26681 m
.18054 .3153 L
s
1 .166 .998 r
.35942 .32613 m
.35892 .3358 L
s
.359 .33564 m
.35942 .32613 L
s
.383 .317 1 r
.67971 .32504 m
.67936 .31685 L
s
.67936 .31685 m
.67976 .32489 L
s
.376 .32 1 r
.70516 .32371 m
.70474 .31546 L
s
.70474 .31546 m
.70519 .32327 L
s
.669 .239 1 r
.12558 .32194 m
.12448 .33085 L
s
.12456 .33077 m
.12558 .32194 L
s
.68 .237 1 r
.77089 .32054 m
.77156 .32959 L
s
.77159 .32914 m
.77089 .32054 L
s
.523 .277 1 r
.06943 .30782 m
.06824 .31625 L
s
.06825 .31621 m
.06943 .30782 L
s
.06943 .30782 m
.06709 .32494 L
s
1 .166 .998 r
.35892 .3358 m
.35944 .32608 L
s
.35944 .32608 m
.359 .33564 L
s
.669 .239 1 r
.12448 .33085 m
.12559 .32189 L
s
.12559 .32189 m
.12456 .33077 L
s
.638 .247 1 r
.37485 .33395 m
.37477 .33425 L
s
.68 .237 1 r
.77156 .32959 m
.77092 .32049 L
s
.77092 .32049 m
.77159 .32914 L
s
.711 .229 1 r
.60322 .32139 m
.60343 .33048 L
s
.60349 .33014 m
.60322 .32139 L
s
.416 .307 1 r
.76551 .30374 m
.76609 .31205 L
s
.76611 .31201 m
.76551 .30374 L
s
.76551 .30374 m
.76672 .32006 L
s
.711 .229 1 r
.60343 .33048 m
.60325 .32134 L
s
.60325 .32134 m
.60349 .33014 L
s
.658 .242 1 r
.23709 .30738 m
.23628 .31629 L
s
.2363 .31625 m
.23709 .30738 L
s
.23709 .30738 m
.23557 .32506 L
s
.744 .221 1 r
.85708 .30741 m
.85797 .31659 L
s
.858 .31655 m
.85708 .30741 L
s
.85708 .30741 m
.85892 .32543 L
s
.824 .204 1 r
.66299 .26654 m
.6651 .31091 L
s
.4 .312 1 r
.35299 .26654 m
.35111 .30605 L
s
.833 .201 1 r
.04299 .26654 m
.03639 .31279 L
s
.733 .224 1 r
.29322 .32168 m
.29257 .33082 L
s
.29266 .33051 m
.29322 .32168 L
s
.29257 .33082 m
.29324 .32164 L
s
.29324 .32164 m
.29266 .33051 L
s
.598 .257 1 r
.23251 .33369 m
.23243 .33384 L
s
.589 .259 1 r
.28782 .30495 m
.28716 .31379 L
s
.28718 .31374 m
.28782 .30495 L
s
.28782 .30495 m
.28661 .32217 L
s
.55 .269 1 r
.43014 .30569 m
.42986 .31434 L
s
.42988 .3143 m
.43014 .30569 L
s
.43014 .30569 m
.42967 .3228 L
s
.35 .414 1 r
.38478 .32545 m
.38471 .32578 L
s
.744 .221 1 r
.7148 .30716 m
.7153 .31634 L
s
.71532 .31629 m
.7148 .30716 L
s
.7148 .30716 m
.71586 .32518 L
s
.834 .201 1 r
.21167 .30929 m
.21076 .31859 L
s
.21077 .31854 m
.21167 .30929 L
s
.21167 .30929 m
.20993 .32781 L
s
.638 .247 1 r
.83072 .26628 m
.83496 .30916 L
s
.45 .297 1 r
.52068 .26628 m
.52083 .30654 L
s
.733 .224 1 r
.21064 .26628 m
.20659 .31066 L
s
.833 .201 1 r
.32405 .33756 m
.32397 .33775 L
s
.638 .247 1 r
.15085 .32143 m
.14984 .33022 L
s
.1499 .33026 m
.15085 .32143 L
s
.579 .262 1 r
.51168 .31863 m
.51163 .32742 L
s
.5117 .32701 m
.51168 .31863 L
s
.638 .247 1 r
.14984 .33022 m
.15087 .32138 L
s
.15087 .32138 m
.1499 .33026 L
s
.579 .262 1 r
.51163 .32742 m
.5117 .31859 L
s
.5117 .31859 m
.5117 .32701 L
s
.638 .247 1 r
.7402 .30602 m
.74075 .31494 L
s
.74077 .31489 m
.7402 .30602 L
s
.7402 .30602 m
.74137 .32355 L
s
.777 .214 1 r
.82722 .33569 m
.82719 .33603 L
s
.425 .304 1 r
.33856 .3026 m
.33806 .31098 L
s
.33807 .31094 m
.33856 .3026 L
s
.33856 .3026 m
.33766 .31892 L
s
.639 .247 1 r
.59787 .30543 m
.59803 .31438 L
s
.59806 .31434 m
.59787 .30543 L
s
.59787 .30543 m
.59828 .32292 L
s
.45 .297 1 r
.64407 .32869 m
.64403 .32914 L
s
.598 .257 1 r
.12005 .30617 m
.11895 .31493 L
s
.11896 .31489 m
.12005 .30617 L
s
.12005 .30617 m
.11794 .32355 L
s
.48 .289 1 r
.68842 .26602 m
.69063 .3059 L
s
.43 .761 1 r
.37833 .26602 m
.37702 .29919 L
s
.588 .259 1 r
.06825 .26602 m
.06241 .30927 L
s
.618 .252 1 r
.45552 .30492 m
.4553 .31383 L
s
.45532 .31379 m
.45552 .30492 L
s
.45552 .30492 m
.45518 .32229 L
s
.669 .239 1 r
.20703 .33606 m
.20698 .33591 L
s
.892 .189 1 r
.37936 .30918 m
.37891 .31863 L
s
.37893 .31859 m
.37936 .30918 L
s
.37936 .30918 m
.37856 .32793 L
s
.531 .274 1 r
.36932 .31837 m
.3689 .32698 L
s
.36898 .32675 m
.36932 .31837 L
s
.3689 .32698 m
.36934 .31833 L
s
.36934 .31833 m
.36898 .32675 L
s
.766 .217 1 r
.51715 .33606 m
.51708 .33625 L
s
1 .141 .867 r
.24785 .34243 m
.24777 .34252 L
s
.701 .232 1 r
.48629 .32062 m
.48617 .32969 L
s
.48624 .32938 m
.48629 .32062 L
s
.48617 .32969 m
.48631 .32058 L
s
.48631 .32058 m
.48624 .32938 L
s
1 .138 .854 r
.8562 .26576 m
.86129 .31352 L
s
.588 .259 1 r
.54607 .26576 m
.54656 .30789 L
s
.754 .219 1 r
.23594 .26576 m
.23221 .31052 L
s
.648 .244 1 r
.20154 .31952 m
.20065 .32847 L
s
.20075 .32813 m
.20154 .31952 L
s
.20065 .32847 m
.20155 .31948 L
s
.20155 .31948 m
.20075 .32813 L
s
.487 .287 1 r
.50173 .32881 m
.50167 .3293 L
s
.811 .206 1 r
.8527 .33518 m
.85268 .33564 L
s
.494 .285 1 r
.14077 .33168 m
.14072 .33165 L
s
.522 .277 1 r
.14534 .30562 m
.14433 .31413 L
s
.14435 .31408 m
.14534 .30562 L
s
.14534 .30562 m
.1434 .32267 L
s
.744 .222 1 r
.71032 .33456 m
.71028 .3349 L
s
.703 .231 1 r
.62329 .30502 m
.62353 .31417 L
s
.62355 .31412 m
.62329 .30502 L
s
.62329 .30502 m
.62384 .32278 L
s
.928 .181 1 r
.71386 .2655 m
.71679 .31213 L
s
.777 .214 1 r
.40369 .2655 m
.40227 .30988 L
s
.45 .297 1 r
.09352 .2655 m
.0884 .30576 L
s
.833 .201 1 r
.5725 .30794 m
.5726 .31727 L
s
.57263 .31722 m
.5725 .30794 L
s
.5725 .30794 m
.57279 .32642 L
s
.638 .247 1 r
.11536 .33331 m
.11528 .3335 L
s
.588 .259 1 r
.79108 .30452 m
.79176 .31332 L
s
.79178 .31327 m
.79108 .30452 L
s
.79108 .30452 m
.7925 .32178 L
s
.811 .206 1 r
.54255 .33555 m
.54248 .3359 L
s
.79647 .32152 m
.79724 .33084 L
s
.79727 .3305 m
.79647 .32152 L
s
.99 .169 1 r
.80195 .33843 m
.80192 .33877 L
s
.811 .206 1 r
.79724 .33084 m
.7965 .32147 L
s
.7965 .32147 m
.79727 .3305 L
s
.352 .427 1 r
.4355 .32444 m
.43544 .32473 L
s
.559 .267 1 r
.78653 .33081 m
.7865 .33115 L
s
.744 .221 1 r
.57148 .26524 m
.57233 .30887 L
s
.578 .262 1 r
.26127 .26524 m
.25804 .30775 L
s
.523 .276 1 r
.84191 .30209 m
.84272 .31081 L
s
.84275 .31077 m
.84191 .30209 L
s
.84191 .30209 m
.84355 .31889 L
s
.628 .249 1 r
.31307 .30562 m
.31248 .31446 L
s
.3125 .31442 m
.31307 .30562 L
s
.31307 .30562 m
.31197 .32316 L
s
1 .123 .772 r
.54712 .30996 m
.54716 .32016 L
s
.54718 .32011 m
.54712 .30996 L
s
.54712 .30996 m
.54729 .32992 L
s
.658 .242 1 r
.05902 .31986 m
.05775 .32877 L
s
.05784 .32862 m
.05902 .31986 L
s
.712 .229 1 r
.48089 .30507 m
.48074 .31421 L
s
.48076 .31416 m
.48089 .30507 L
s
.48089 .30507 m
.48068 .3229 L
s
.811 .206 1 r
.87819 .33468 m
.87818 .33513 L
s
.658 .242 1 r
.05775 .32877 m
.05903 .31982 L
s
.05903 .31982 m
.05784 .32862 L
s
1 .133 .827 r
.72032 .32631 m
.72091 .33633 L
s
.72096 .33613 m
.72032 .32631 L
s
.765 .217 1 r
.17603 .32211 m
.17505 .33121 L
s
.17511 .33124 m
.17603 .32211 L
s
.54 .272 1 r
.25222 .31791 m
.2515 .32652 L
s
.25157 .32637 m
.25222 .31791 L
s
.618 .252 1 r
.64871 .30448 m
.64901 .31336 L
s
.64904 .31331 m
.64871 .30448 L
s
.64871 .30448 m
.64939 .3219 L
s
1 .133 .827 r
.72091 .33633 m
.72035 .32626 L
s
.72035 .32626 m
.72096 .33613 L
s
.4 .312 1 r
.55252 .32706 m
.55247 .32739 L
s
.765 .217 1 r
.17505 .33121 m
.17604 .32206 L
s
.17604 .32206 m
.17511 .33124 L
s
.588 .259 1 r
.73931 .26498 m
.7423 .30712 L
s
1 .146 .894 r
.42906 .26498 m
.42791 .31236 L
s
.733 .224 1 r
.1188 .26498 m
.1135 .30936 L
s
.54 .272 1 r
.2515 .32652 m
.25224 .31787 L
s
.25224 .31787 m
.25157 .32637 L
s
.45 .297 1 r
.69952 .3018 m
.69993 .31026 L
s
.69996 .31021 m
.69952 .3018 L
s
.69952 .3018 m
.70041 .31827 L
s
.55 .269 1 r
.73031 .31736 m
.73084 .32604 L
s
.73088 .32574 m
.73031 .31736 L
s
.73084 .32604 m
.73033 .31732 L
s
.73033 .31732 m
.73088 .32574 L
s
.811 .206 1 r
.82195 .32101 m
.82279 .33034 L
s
.82282 .32999 m
.82195 .32101 L
s
.579 .262 1 r
.19601 .30404 m
.19511 .31281 L
s
.19512 .31276 m
.19601 .30404 L
s
.19601 .30404 m
.19431 .32127 L
s
.811 .206 1 r
.82279 .33034 m
.82198 .32096 L
s
.82198 .32096 m
.82282 .32999 L
s
.416 .307 1 r
.47084 .31486 m
.4707 .32316 L
s
.47076 .32286 m
.47084 .31486 L
s
.811 .206 1 r
.5969 .26471 m
.59811 .30948 L
s
.385 .574 1 r
.2866 .26471 m
.2842 .30013 L
s
.494 .284 1 r
.22139 .30287 m
.22058 .3114 L
s
.22059 .31136 m
.22139 .30287 L
s
.22139 .30287 m
.21987 .31964 L
s
.416 .307 1 r
.4707 .32316 m
.47086 .31482 L
s
.47086 .31482 m
.47076 .32286 L
s
.744 .221 1 r
.84738 .3199 m
.84828 .32908 L
s
.84831 .32874 m
.84738 .3199 L
s
.84828 .32908 m
.84741 .31986 L
s
.84741 .31986 m
.84831 .32874 L
s
.345 .39 1 r
.1043 .30099 m
.10328 .30885 L
s
.10329 .30881 m
.1043 .30099 L
s
.1043 .30099 m
.10233 .31664 L
s
.522 .277 1 r
.44543 .31655 m
.44522 .32516 L
s
.44528 .32486 m
.44543 .31655 L
s
.766 .216 1 r
.28304 .33418 m
.28296 .33448 L
s
.522 .277 1 r
.44522 .32516 m
.44545 .31651 L
s
.44545 .31651 m
.44528 .32486 L
s
.598 .257 1 r
.50628 .30463 m
.5062 .3134 L
s
.50622 .31336 m
.50628 .30463 L
s
.50628 .30463 m
.50621 .32202 L
s
.766 .216 1 r
.22675 .3202 m
.22591 .32942 L
s
.226 .32911 m
.22675 .3202 L
s
.383 .317 1 r
.32837 .3146 m
.32787 .32275 L
s
.32794 .32261 m
.32837 .3146 L
s
.375 .32 1 r
.76478 .26445 m
.76786 .3036 L
s
.811 .206 1 r
.45444 .26445 m
.45371 .30885 L
s
.4 .312 1 r
.1441 .26445 m
.13974 .3036 L
s
.766 .216 1 r
.22591 .32942 m
.22677 .32016 L
s
.22677 .32016 m
.226 .32911 L
s
.383 .317 1 r
.32787 .32275 m
.32838 .31456 L
s
.32838 .31456 m
.32794 .32261 L
s
.669 .239 1 r
.56249 .3191 m
.56259 .32805 L
s
.56265 .32786 m
.56249 .3191 L
s
.702 .231 1 r
.19137 .33105 m
.19124 .33169 L
s
.345 .39 1 r
.62876 .32405 m
.62871 .32434 L
s
.669 .239 1 r
.56259 .32805 m
.56251 .31905 L
s
.56251 .31905 m
.56265 .32786 L
s
.638 .247 1 r
.08422 .31994 m
.08304 .32871 L
s
.08308 .32885 m
.08422 .31994 L
s
.485 .287 1 r
.3892 .30298 m
.38883 .31144 L
s
.38885 .3114 m
.3892 .30298 L
s
.3892 .30298 m
.38854 .31976 L
s
.559 .267 1 r
.8375 .3298 m
.83748 .33013 L
s
.385 .574 1 r
.39462 .31992 m
.39455 .3204 L
s
.916 .184 1 r
.56798 .33617 m
.56791 .33651 L
s
.425 .304 1 r
.62233 .26419 m
.62372 .30372 L
s
.441 .3 1 r
.31195 .26419 m
.30953 .30447 L
s
.638 .247 1 r
.08304 .32871 m
.08423 .3199 L
s
.08423 .3199 m
.08308 .32885 L
s
.357 .451 1 r
.65418 .3228 m
.65414 .32313 L
s
.836 .201 1 r
.87289 .3194 m
.87389 .32888 L
s
.87388 .32823 m
.87289 .3194 L
s
.68 .237 1 r
.27752 .318 m
.27683 .32706 L
s
.27693 .3266 m
.27752 .318 L
s
.599 .257 1 r
.61332 .31659 m
.61355 .32547 L
s
.6136 .32497 m
.61332 .31659 L
s
.836 .201 1 r
.87389 .32888 m
.87292 .31935 L
s
.87292 .31935 m
.87388 .32823 L
s
.68 .237 1 r
.27683 .32706 m
.27754 .31795 L
s
.27754 .31795 m
.27693 .3266 L
s
.599 .257 1 r
.61355 .32547 m
.61335 .31655 L
s
.61335 .31655 m
.6136 .32497 L
s
.658 .242 1 r
.1096 .31884 m
.10846 .32776 L
s
.10855 .3276 m
.1096 .31884 L
s
.669 .239 1 r
.30839 .33367 m
.30833 .33363 L
s
.766 .217 1 r
.17046 .30688 m
.16945 .31599 L
s
.16947 .31595 m
.17046 .30688 L
s
.17046 .30688 m
.16852 .32514 L
s
.658 .242 1 r
.10846 .32776 m
.10961 .3188 L
s
.10961 .3188 m
.10855 .3276 L
s
.54 .272 1 r
.07877 .30342 m
.07758 .31204 L
s
.0776 .31199 m
.07877 .30342 L
s
.07877 .30342 m
.07648 .3205 L
s
.638 .247 1 r
.79026 .26393 m
.79397 .30683 L
s
.504 .282 1 r
.47984 .26393 m
.47949 .30458 L
s
.522 .277 1 r
.16942 .26393 m
.16512 .30533 L
s
.4 .312 1 r
.83209 .31354 m
.83286 .3218 L
s
.83288 .32147 m
.83209 .31354 L
s
.34 .366 1 r
.31835 .32479 m
.31828 .32494 L
s
.4 .312 1 r
.83286 .3218 m
.83211 .3135 L
s
.83211 .3135 m
.83288 .32147 L
s
.45 .297 1 r
.35372 .31439 m
.35327 .3228 L
s
.35335 .32247 m
.35372 .31439 L
s
.638 .247 1 r
.36376 .30523 m
.3633 .31404 L
s
.36332 .31399 m
.36376 .30523 L
s
.36376 .30523 m
.36292 .32288 L
s
.45 .297 1 r
.35327 .3228 m
.35374 .31434 L
s
.35374 .31434 m
.35335 .32247 L
s
.88 .191 1 r
.81675 .30599 m
.81755 .31548 L
s
.81758 .31544 m
.81675 .30599 L
s
.81675 .30599 m
.81842 .32463 L
s
.503 .282 1 r
.8067 .31524 m
.80743 .3238 L
s
.80746 .32347 m
.8067 .31524 L
s
.618 .252 1 r
.64778 .26367 m
.6496 .30619 L
s
.7 .232 1 r
.33731 .26367 m
.335 .30769 L
s
.503 .282 1 r
.80743 .3238 m
.80673 .31519 L
s
.80673 .31519 m
.80746 .32347 L
s
.81 .206 1 r
.76135 .33504 m
.76129 .33516 L
s
.744 .222 1 r
.58793 .31889 m
.5881 .32807 L
s
.58815 .32772 m
.58793 .31889 L
s
.7 .232 1 r
.5317 .30475 m
.53169 .31378 L
s
.53171 .31373 m
.5317 .30475 L
s
.5317 .30475 m
.53176 .32263 L
s
.578 .262 1 r
.24664 .30335 m
.24588 .31208 L
s
.24589 .31203 m
.24664 .30335 L
s
.24664 .30335 m
.2452 .32062 L
s
.442 .299 1 r
.26749 .32804 m
.26742 .32812 L
s
.503 .282 1 r
.57797 .32804 m
.57792 .32838 L
s
.744 .222 1 r
.5881 .32807 m
.58795 .31884 L
s
.58795 .31884 m
.58815 .32772 L
s
.589 .259 1 r
.41459 .30272 m
.41426 .31152 L
s
.41428 .31148 m
.41459 .30272 L
s
.41459 .30272 m
.41403 .31999 L
s
.629 .249 1 r
.69509 .33029 m
.69505 .33067 L
s
.395 .62 1 r
.37371 .29643 m
.37335 .30387 L
s
.37336 .30383 m
.37371 .29643 L
s
.37371 .29643 m
.37307 .31098 L
s
.799 .209 1 r
.67424 .30567 m
.67463 .31493 L
s
.67465 .31488 m
.67424 .30567 L
s
.67424 .30567 m
.6751 .324 L
s
.701 .232 1 r
.05325 .30567 m
.05194 .31463 L
s
.05195 .31459 m
.05325 .30567 L
s
.05325 .30567 m
.0507 .32363 L
s
.953 .176 1 r
.59342 .33604 m
.59336 .33638 L
s
.88 .191 1 r
.53709 .32198 m
.53712 .33136 L
s
.53718 .33135 m
.53709 .32198 L
s
.871 .193 1 r
.55713 .30368 m
.5572 .31327 L
s
.55722 .31322 m
.55713 .30368 L
s
.55713 .30368 m
.55734 .32212 L
s
.88 .191 1 r
.53712 .33136 m
.53711 .32194 L
s
.53711 .32194 m
.53718 .33135 L
s
.503 .282 1 r
.81576 .2634 m
.8197 .30518 L
s
.953 .176 1 r
.50525 .2634 m
.50521 .30968 L
s
.521 .277 1 r
.19475 .2634 m
.19065 .30593 L
s
.68 .237 1 r
.78133 .31723 m
.78203 .32629 L
s
.78206 .32584 m
.78133 .31723 L
s
.598 .257 1 r
.07406 .33066 m
.07397 .33081 L
s
.68 .237 1 r
.78203 .32629 m
.78136 .31719 L
s
.78136 .31719 m
.78206 .32584 L
s
.765 .217 1 r
.33374 .33354 m
.33366 .33373 L
s
.766 .216 1 r
.75593 .31893 m
.75657 .32815 L
s
.75661 .32784 m
.75593 .31893 L
s
.733 .224 1 r
.13484 .31893 m
.13375 .32803 L
s
.13384 .32784 m
.13484 .31893 L
s
.628 .249 1 r
.16026 .31753 m
.15927 .32637 L
s
.15935 .32621 m
.16026 .31753 L
s
.344 .33 1 r
.26195 .31192 m
.2613 .32 L
s
.26138 .3197 m
.26195 .31192 L
s
.744 .222 1 r
.67324 .26314 m
.67547 .30717 L
s
.766 .216 1 r
.75657 .32815 m
.75596 .31889 L
s
.75596 .31889 m
.75661 .32784 L
s
.55 .269 1 r
.36269 .26314 m
.36077 .30605 L
s
.754 .219 1 r
.05214 .26314 m
.04587 .30792 L
s
.733 .224 1 r
.13375 .32803 m
.13486 .31888 L
s
.13486 .31888 m
.13384 .32784 L
s
.628 .249 1 r
.15927 .32637 m
.16028 .31748 L
s
.16028 .31748 m
.15935 .32621 L
s
.344 .33 1 r
.2613 .32 m
.26197 .31188 L
s
.26197 .31188 m
.26138 .3197 L
s
.618 .252 1 r
.43999 .3021 m
.43973 .31101 L
s
.43975 .31097 m
.43999 .3021 L
s
.43999 .3021 m
.43957 .31948 L
s
.504 .282 1 r
.46541 .3007 m
.46523 .30931 L
s
.46525 .30927 m
.46541 .3007 L
s
.46541 .3007 m
.46513 .31748 L
s
.67 .239 1 r
.6388 .31697 m
.63911 .326 L
s
.63916 .32558 m
.6388 .31697 L
s
.63911 .326 m
.63883 .31693 L
s
.63883 .31693 m
.63916 .32558 L
s
.442 .299 1 r
.2974 .30155 m
.2968 .30987 L
s
.29682 .30982 m
.2974 .30155 L
s
.2974 .30155 m
.29628 .31811 L
s
.608 .254 1 r
.09942 .32978 m
.09931 .33008 L
s
.953 .176 1 r
.61887 .33553 m
.61881 .33588 L
s
.881 .191 1 r
.1657 .3349 m
.1656 .33514 L
s
.845 .199 1 r
.84127 .26288 m
.84588 .30804 L
s
.744 .221 1 r
.53068 .26288 m
.53098 .30691 L
s
.701 .232 1 r
.22009 .26288 m
.21619 .30691 L
s
.608 .254 1 r
.49623 .31672 m
.49614 .32552 L
s
.49621 .32533 m
.49623 .31672 L
s
.702 .231 1 r
.608 .30187 m
.6082 .31105 L
s
.60822 .31101 m
.608 .30187 L
s
.608 .30187 m
.60847 .3196 L
s
.459 .294 1 r
.74601 .3289 m
.74595 .32872 L
s
.608 .254 1 r
.49614 .32552 m
.49625 .31668 L
s
.49625 .31668 m
.49621 .32533 L
s
.701 .232 1 r
.58257 .30339 m
.5827 .31246 L
s
.58272 .31241 m
.58257 .30339 L
s
.58257 .30339 m
.58291 .32123 L
s
.56 .267 1 r
.68968 .31477 m
.69012 .32353 L
s
.69015 .32308 m
.68968 .31477 L
s
.45 .297 1 r
.4045 .31337 m
.40418 .32178 L
s
.40425 .32145 m
.4045 .31337 L
s
.56 .267 1 r
.69012 .32353 m
.68971 .31472 L
s
.68971 .31472 m
.69015 .32308 L
s
.45 .297 1 r
.40418 .32178 m
.40451 .31332 L
s
.40451 .31332 m
.40425 .32145 L
s
.744 .222 1 r
.27195 .30357 m
.27121 .31276 L
s
.27123 .31271 m
.27195 .30357 L
s
.27195 .30357 m
.27059 .3216 L
s
.434 .302 1 r
.69871 .26262 m
.70103 .30216 L
s
.869 .194 1 r
.38808 .26262 m
.3864 .30815 L
s
.467 .292 1 r
.07745 .26262 m
.07191 .3044 L
s
.378 .543 1 r
.41994 .32127 m
.41989 .3213 L
s
.541 .272 1 r
.46083 .32765 m
.46076 .32803 L
s
.916 .184 1 r
.8678 .30519 m
.86876 .31476 L
s
.86879 .31471 m
.8678 .30519 L
s
.8678 .30519 m
.86978 .32399 L
s
.599 .257 1 r
.18556 .31732 m
.18466 .32601 L
s
.18471 .32608 m
.18556 .31732 L
s
.395 .62 1 r
.4245 .2954 m
.42425 .30284 L
s
.42427 .3028 m
.4245 .2954 L
s
.4245 .2954 m
.42408 .30995 L
s
.599 .257 1 r
.18466 .32601 m
.18558 .31727 L
s
.18558 .31727 m
.18471 .32608 L
s
.531 .274 1 r
.49083 .3004 m
.49071 .30909 L
s
.49073 .30905 m
.49083 .3004 L
s
.49083 .3004 m
.49068 .31734 L
s
.881 .191 1 r
.81238 .33441 m
.81234 .33464 L
s
.618 .252 1 r
.55612 .26235 m
.55675 .30602 L
s
.7 .232 1 r
.24544 .26235 m
.24189 .30639 L
s
.61 .254 1 r
.34821 .29985 m
.34771 .30884 L
s
.34772 .3088 m
.34821 .29985 L
s
.34821 .29985 m
.34732 .31708 L
s
.917 .184 1 r
.66977 .33378 m
.66973 .33424 L
s
.618 .252 1 r
.63346 .30132 m
.63372 .31024 L
s
.63374 .3102 m
.63346 .30132 L
s
.63346 .30132 m
.63405 .31871 L
s
.376 .32 1 r
.70519 .32327 m
.70516 .32371 L
s
.476 .29 1 r
.34363 .32615 m
.34355 .32648 L
s
.65889 .30004 m
.65921 .30854 L
s
.65923 .3085 m
.65889 .30004 L
s
.65889 .30004 m
.65959 .31671 L
s
.722 .227 1 r
.12924 .30372 m
.12813 .3128 L
s
.12814 .31275 m
.12924 .30372 L
s
.12924 .30372 m
.12711 .32172 L
s
.383 .317 1 r
.67976 .32489 m
.67971 .32504 L
s
.953 .176 1 r
.72523 .30515 m
.72579 .3148 L
s
.72581 .31475 m
.72523 .30515 L
s
.72523 .30515 m
.72641 .3241 L
s
.69 .234 1 r
.40994 .33127 m
.40987 .33143 L
s
.81 .206 1 r
.7242 .26209 m
.72721 .30763 L
s
.345 .33 1 r
.41348 .26209 m
.41237 .30051 L
s
.904 .186 1 r
.10276 .26209 m
.0969 .30914 L
s
.88 .191 1 r
.21643 .33352 m
.21632 .33387 L
s
.904 .186 1 r
.30271 .32016 m
.30205 .32965 L
s
.30214 .32945 m
.30271 .32016 L
s
.467 .292 1 r
.09372 .31455 m
.09261 .3229 L
s
.09267 .32294 m
.09372 .31455 L
s
.904 .186 1 r
.30205 .32965 m
.30272 .32011 L
s
.30272 .32011 m
.30214 .32945 L
s
.467 .292 1 r
.09261 .3229 m
.09373 .31451 L
s
.09373 .31451 m
.09267 .32294 L
s
.754 .219 1 r
.24184 .33227 m
.24176 .33243 L
s
.905 .186 1 r
.7507 .30412 m
.75132 .31369 L
s
.75135 .31364 m
.7507 .30412 L
s
.7507 .30412 m
.75201 .32284 L
s
.523 .277 1 r
.06824 .31625 m
.06706 .32468 L
s
.06709 .32494 m
.06824 .31625 L
s
.416 .307 1 r
.76609 .31205 m
.76669 .32035 L
s
.76672 .32006 m
.76609 .31205 L
s
.45 .297 1 r
.58157 .26183 m
.58248 .30212 L
s
.648 .244 1 r
.27081 .26183 m
.26769 .30475 L
s
.523 .277 1 r
.06706 .32468 m
.06825 .31621 L
s
.06825 .31621 m
.06709 .32494 L
s
.416 .307 1 r
.76669 .32035 m
.76611 .31201 L
s
.76611 .31201 m
.76672 .32006 L
s
.932 .18 1 r
.32273 .30227 m
.32211 .31203 L
s
.32212 .31198 m
.32273 .30227 L
s
.32273 .30227 m
.32161 .32095 L
s
.68 .237 1 r
.77159 .32914 m
.77156 .32959 L
s
.473 .913 1 r
.09822 .28906 m
.09732 .29586 L
s
.09732 .29582 m
.09822 .28906 L
s
.09822 .28906 m
.09656 .30191 L
s
.669 .239 1 r
.12456 .33077 m
.12448 .33085 L
s
.811 .206 1 r
.52167 .3174 m
.52165 .32677 L
s
.52172 .32632 m
.52167 .3174 L
s
.77618 .30324 m
.77686 .31258 L
s
.77689 .31254 m
.77618 .30324 L
s
.77618 .30324 m
.7776 .32158 L
s
.559 .267 1 r
.82707 .30044 m
.82783 .30918 L
s
.82786 .30913 m
.82707 .30044 L
s
.82707 .30044 m
.82866 .31757 L
s
1 .154 .933 r
.74971 .26157 m
.75322 .30899 L
s
.486 .287 1 r
.4389 .26157 m
.43805 .30186 L
s
.54 .272 1 r
.1281 .26157 m
.12318 .30374 L
s
.711 .229 1 r
.60349 .33014 m
.60343 .33048 L
s
.811 .206 1 r
.52165 .32677 m
.52169 .31735 L
s
.52169 .31735 m
.52172 .32632 L
s
.88 .191 1 r
.86341 .33302 m
.86338 .33336 L
s
.845 .199 1 r
.66435 .31825 m
.66474 .32766 L
s
.66479 .32732 m
.66435 .31825 L
s
.66474 .32766 m
.66438 .3182 L
s
.66438 .3182 m
.66479 .32732 L
s
.476 .29 1 r
.23089 .29927 m
.2301 .30777 L
s
.23012 .30773 m
.23089 .29927 L
s
.23089 .29927 m
.22942 .31594 L
s
.658 .242 1 r
.23628 .31629 m
.23549 .32521 L
s
.23557 .32506 m
.23628 .31629 L
s
.978 .171 1 r
.52715 .33465 m
.52709 .33496 L
s
.658 .242 1 r
.23549 .32521 m
.2363 .31625 L
s
.2363 .31625 m
.23557 .32506 L
s
.733 .224 1 r
.29266 .33051 m
.29257 .33082 L
s
.55 .269 1 r
.42986 .31434 m
.42961 .32299 L
s
.42967 .3228 m
.42986 .31434 L
s
.579 .262 1 r
.5117 .32701 m
.51163 .32742 L
s
.953 .176 1 r
.60704 .2613 m
.60844 .3076 L
s
.578 .262 1 r
.29619 .2613 m
.29337 .3046 L
s
.659 .242 1 r
.15451 .30376 m
.1535 .31258 L
s
.15351 .31254 m
.15451 .30376 L
s
.15451 .30376 m
.15254 .32158 L
s
.55 .269 1 r
.42961 .32299 m
.42988 .3143 L
s
.42988 .3143 m
.42967 .3228 L
s
.744 .221 1 r
.85797 .31659 m
.8589 .32578 L
s
.85892 .32543 m
.85797 .31659 L
s
1 .166 .998 r
.359 .33564 m
.35892 .3358 L
s
.589 .259 1 r
.28716 .31379 m
.28651 .32263 L
s
.28661 .32217 m
.28716 .31379 L
s
.425 .304 1 r
.33806 .31098 m
.33757 .31936 L
s
.33766 .31892 m
.33806 .31098 L
s
.744 .221 1 r
.8589 .32578 m
.858 .31655 L
s
.858 .31655 m
.85892 .32543 L
s
.589 .259 1 r
.28651 .32263 m
.28718 .31374 L
s
.28718 .31374 m
.28661 .32217 L
s
.425 .304 1 r
.33757 .31936 m
.33807 .31094 L
s
.33807 .31094 m
.33766 .31892 L
s
.822 .204 1 r
.8017 .30269 m
.80245 .31207 L
s
.80248 .31202 m
.8017 .30269 L
s
.8017 .30269 m
.80327 .32107 L
s
.638 .247 1 r
.1499 .33026 m
.14984 .33022 L
s
.531 .274 1 r
.36898 .32675 m
.3689 .32698 L
s
.06266 .30063 m
.06143 .30922 L
s
.06144 .30917 m
.06266 .30063 L
s
.06266 .30063 m
.06029 .31769 L
s
.77522 .26104 m
.77862 .30247 L
s
.624 1 .72 r
.46433 .26104 m
.46401 .28533 L
s
.521 .277 1 r
.15345 .26104 m
.1488 .30359 L
s
.744 .221 1 r
.7153 .31634 m
.71582 .32552 L
s
.71586 .32518 m
.7153 .31634 L
s
.669 .239 1 r
.17991 .30288 m
.17896 .31177 L
s
.17897 .31173 m
.17991 .30288 L
s
.17991 .30288 m
.17807 .3207 L
s
.638 .247 1 r
.74075 .31494 m
.74133 .32385 L
s
.74137 .32355 m
.74075 .31494 L
s
.598 .257 1 r
.11895 .31493 m
.11786 .3237 L
s
.11794 .32355 m
.11895 .31493 L
s
.744 .221 1 r
.71582 .32552 m
.71532 .31629 L
s
.71532 .31629 m
.71586 .32518 L
s
.638 .247 1 r
.74133 .32385 m
.74077 .31489 L
s
.74077 .31489 m
.74137 .32355 L
s
.598 .257 1 r
.11786 .3237 m
.11896 .31489 L
s
.11896 .31489 m
.11794 .32355 L
s
.834 .201 1 r
.21076 .31859 m
.20986 .3279 L
s
.20993 .32781 m
.21076 .31859 L
s
.639 .247 1 r
.59803 .31438 m
.59823 .32334 L
s
.59828 .32292 m
.59803 .31438 L
s
.834 .201 1 r
.20986 .3279 m
.21077 .31854 L
s
.21077 .31854 m
.20993 .32781 L
s
.639 .247 1 r
.59823 .32334 m
.59806 .31434 L
s
.59806 .31434 m
.59828 .32292 L
s
.54 .272 1 r
.54172 .30034 m
.54173 .30896 L
s
.54175 .30892 m
.54172 .30034 L
s
.54172 .30034 m
.54183 .31743 L
s
.618 .252 1 r
.4553 .31383 m
.4551 .32274 L
s
.45518 .32229 m
.4553 .31383 L
s
.352 .327 1 r
.44989 .29687 m
.44968 .305 L
s
.4497 .30496 m
.44989 .29687 L
s
.44989 .29687 m
.44955 .31279 L
s
.88 .191 1 r
.63252 .26078 m
.63426 .30633 L
s
.701 .232 1 r
.48624 .32938 m
.48617 .32969 L
s
.658 .242 1 r
.32159 .26078 m
.31908 .30446 L
s
.368 .322 1 r
.1135 .29831 m
.11246 .3064 L
s
.11247 .30636 m
.1135 .29831 L
s
.1135 .29831 m
.1115 .31442 L
s
.618 .252 1 r
.4551 .32274 m
.45532 .31379 L
s
.45532 .31379 m
.45518 .32229 L
s
.70992 .29978 m
.71039 .3087 L
s
.71042 .30866 m
.70992 .29978 L
s
.70992 .29978 m
.71093 .31717 L
s
.648 .244 1 r
.20075 .32813 m
.20065 .32847 L
s
.522 .277 1 r
.14433 .31413 m
.14334 .32263 L
s
.1434 .32267 m
.14433 .31413 L
s
.733 .224 1 r
.20531 .30214 m
.2044 .31126 L
s
.20441 .31121 m
.20531 .30214 L
s
.20531 .30214 m
.20358 .32019 L
s
.522 .277 1 r
.14334 .32263 m
.14435 .31408 L
s
.14435 .31408 m
.1434 .32267 L
s
.559 .267 1 r
.80075 .26052 m
.80451 .30232 L
s
.589 .259 1 r
.48978 .26052 m
.48955 .30232 L
s
.669 .239 1 r
.17881 .26051 m
.17443 .30382 L
s
.892 .189 1 r
.37891 .31863 m
.37848 .32809 L
s
.37856 .32793 m
.37891 .31863 L
s
.37848 .32809 m
.37893 .31859 L
s
.37893 .31859 m
.37856 .32793 L
s
.467 .292 1 r
.59265 .29827 m
.59279 .30674 L
s
.59281 .3067 m
.59265 .29827 L
s
.59265 .29827 m
.59301 .31491 L
s
.588 .259 1 r
.79176 .31332 m
.79247 .32212 L
s
.7925 .32178 m
.79176 .31332 L
s
.811 .206 1 r
.65802 .26025 m
.66008 .30506 L
s
.559 .267 1 r
.347 .26025 m
.34493 .30206 L
s
.588 .259 1 r
.79247 .32212 m
.79178 .31327 L
s
.79178 .31327 m
.7925 .32178 L
s
.833 .201 1 r
.51627 .3028 m
.51622 .31215 L
s
.51624 .3121 m
.51627 .3028 L
s
.51627 .3028 m
.51625 .32131 L
s
.703 .231 1 r
.62353 .31417 m
.6238 .32332 L
s
.62384 .32278 m
.62353 .31417 L
s
.55 .269 1 r
.08792 .30071 m
.08675 .3093 L
s
.08677 .30925 m
.08792 .30071 L
s
.08792 .30071 m
.08566 .31792 L
s
.703 .231 1 r
.6238 .32332 m
.62355 .31412 L
s
.62355 .31412 m
.62384 .32278 L
s
.811 .206 1 r
.79727 .3305 m
.79724 .33084 L
s
.523 .276 1 r
.84272 .31081 m
.84356 .31953 L
s
.84355 .31889 m
.84272 .31081 L
s
.54 .272 1 r
.25157 .32637 m
.2515 .32652 L
s
.523 .276 1 r
.84356 .31953 m
.84275 .31077 L
s
.84275 .31077 m
.84355 .31889 L
s
.416 .307 1 r
.47076 .32286 m
.4707 .32316 L
s
.833 .201 1 r
.5726 .31727 m
.57273 .32661 L
s
.57279 .32642 m
.5726 .31727 L
s
.628 .249 1 r
.31248 .31446 m
.3119 .32331 L
s
.31197 .32316 m
.31248 .31446 L
s
.55 .269 1 r
.73088 .32574 m
.73084 .32604 L
s
.45 .297 1 r
.69993 .31026 m
.70038 .31871 L
s
.70041 .31827 m
.69993 .31026 L
s
.345 .39 1 r
.10328 .30885 m
.10226 .31671 L
s
.10233 .31664 m
.10328 .30885 L
s
.833 .201 1 r
.57273 .32661 m
.57263 .31722 L
s
.57263 .31722 m
.57279 .32642 L
s
.57 .264 1 r
.8263 .25999 m
.83032 .30105 L
s
.559 .267 1 r
.51524 .25999 m
.51533 .3018 L
s
.503 .282 1 r
.20418 .25999 m
.20024 .30217 L
s
.658 .242 1 r
.05784 .32862 m
.05775 .32877 L
s
.628 .249 1 r
.3119 .32331 m
.3125 .31442 L
s
.3125 .31442 m
.31197 .32316 L
s
.45 .297 1 r
.70038 .31871 m
.69996 .31021 L
s
.69996 .31021 m
.70041 .31827 L
s
.345 .39 1 r
.10226 .31671 m
.10329 .30881 L
s
.10329 .30881 m
.10233 .31664 L
s
.469 .292 1 r
.25612 .30045 m
.25542 .30874 L
s
.25543 .3087 m
.25612 .30045 L
s
.25612 .30045 m
.25477 .31729 L
s
.638 .247 1 r
.73548 .29986 m
.73601 .30878 L
s
.73604 .30874 m
.73548 .29986 L
s
.73548 .29986 m
.73662 .31741 L
s
.618 .252 1 r
.64901 .31336 m
.64934 .32224 L
s
.64939 .3219 m
.64901 .31336 L
s
.64934 .32224 m
.64904 .31331 L
s
.64904 .31331 m
.64939 .3219 L
s
.383 .317 1 r
.32794 .32261 m
.32787 .32275 L
s
.712 .229 1 r
.48074 .31421 m
.48061 .32336 L
s
.48068 .3229 m
.48074 .31421 L
s
.579 .262 1 r
.19511 .31281 m
.19422 .32157 L
s
.19431 .32127 m
.19511 .31281 L
s
.494 .284 1 r
.22058 .3114 m
.21978 .31994 L
s
.21987 .31964 m
.22058 .3114 L
s
.476 .29 1 r
.68353 .25973 m
.68572 .30042 L
s
.376 .319 1 r
.37242 .25973 m
.37083 .29817 L
s
.711 .229 1 r
.06132 .25973 m
.05517 .30454 L
s
.712 .229 1 r
.48061 .32336 m
.48076 .31416 L
s
.48076 .31416 m
.48068 .3229 L
s
.579 .262 1 r
.19422 .32157 m
.19512 .31276 L
s
.19512 .31276 m
.19431 .32127 L
s
.522 .277 1 r
.44528 .32486 m
.44522 .32516 L
s
.494 .284 1 r
.21978 .31994 m
.22059 .31136 L
s
.22059 .31136 m
.21987 .31964 L
s
.765 .217 1 r
.17511 .33124 m
.17505 .33121 L
s
.811 .206 1 r
.82282 .32999 m
.82279 .33034 L
s
.953 .176 1 r
.68457 .30318 m
.685 .31279 L
s
.68503 .31274 m
.68457 .30318 L
s
.68457 .30318 m
.68552 .32218 L
s
.522 .277 1 r
.47533 .2976 m
.47517 .30626 L
s
.47519 .30622 m
.47533 .2976 L
s
.47533 .2976 m
.4751 .31451 L
s
.744 .221 1 r
.84831 .32874 m
.84828 .32908 L
s
.834 .201 1 r
.85186 .25946 m
.85659 .30428 L
s
.811 .206 1 r
.54071 .25946 m
.54116 .30428 L
s
.569 .264 1 r
.22957 .25946 m
.22592 .30203 L
s
.904 .186 1 r
.8529 .30273 m
.85381 .31223 L
s
.85384 .31219 m
.8529 .30273 L
s
.8529 .30273 m
.8548 .32154 L
s
.598 .257 1 r
.5062 .3134 m
.50614 .32217 L
s
.50621 .32202 m
.5062 .3134 L
s
.50614 .32217 m
.50622 .31336 L
s
.50622 .31336 m
.50621 .32202 L
s
1 .133 .827 r
.72096 .33613 m
.72091 .33633 L
s
.485 .287 1 r
.38883 .31144 m
.38847 .31991 L
s
.38854 .31976 m
.38883 .31144 L
s
.766 .216 1 r
.226 .32911 m
.22591 .32942 L
s
.485 .287 1 r
.38847 .31991 m
.38885 .3114 L
s
.38885 .3114 m
.38854 .31976 L
s
.599 .257 1 r
.6136 .32497 m
.61355 .32547 L
s
.4 .312 1 r
.83288 .32147 m
.83286 .3218 L
s
.70905 .2592 m
.71147 .2984 L
s
.7 .232 1 r
.39786 .2592 m
.39637 .30327 L
s
.733 .224 1 r
.08668 .2592 m
.08097 .30327 L
s
.669 .239 1 r
.56265 .32786 m
.56259 .32805 L
s
1 .123 .772 r
.54716 .32016 m
.54722 .33039 L
s
.54729 .32992 m
.54716 .32016 L
s
.395 .62 1 r
.37335 .30387 m
.373 .3113 L
s
.37307 .31098 m
.37335 .30387 L
s
.504 .282 1 r
.81199 .29683 m
.81271 .30545 L
s
.81274 .30541 m
.81199 .29683 L
s
.81199 .29683 m
.81348 .31363 L
s
.395 .62 1 r
.373 .3113 m
.37336 .30383 L
s
.37336 .30383 m
.37307 .31098 L
s
1 .123 .772 r
.54722 .33039 m
.54718 .32011 L
s
.54718 .32011 m
.54729 .32992 L
s
.68 .237 1 r
.27693 .3266 m
.27683 .32706 L
s
.638 .247 1 r
.08308 .32885 m
.08304 .32871 L
s
.45 .297 1 r
.35335 .32247 m
.35327 .3228 L
s
1 .161 .972 r
.39889 .30277 m
.39849 .31257 L
s
.3985 .31252 m
.39889 .30277 L
s
.39889 .30277 m
.39818 .32204 L
s
.836 .201 1 r
.87388 .32823 m
.87389 .32888 L
s
.54 .272 1 r
.07758 .31204 m
.0764 .32066 L
s
.07648 .3205 m
.07758 .31204 L
s
.579 .262 1 r
.30696 .29931 m
.30635 .30801 L
s
.30637 .30797 m
.30696 .29931 L
s
.30696 .29931 m
.30583 .31664 L
s
.777 .214 1 r
.5662 .25894 m
.56699 .30338 L
s
.733 .224 1 r
.25497 .25894 m
.25154 .30301 L
s
.658 .242 1 r
.10855 .3276 m
.10846 .32776 L
s
.54 .272 1 r
.0764 .32066 m
.0776 .31199 L
s
.0776 .31199 m
.07648 .3205 L
s
.503 .282 1 r
.80746 .32347 m
.80743 .3238 L
s
.823 .204 1 r
.6182 .29945 m
.61844 .30891 L
s
.61847 .30886 m
.6182 .29945 L
s
.6182 .29945 m
.61875 .31776 L
s
.777 .214 1 r
.76108 .30019 m
.76171 .30946 L
s
.76174 .30941 m
.76108 .30019 L
s
.76108 .30019 m
.76241 .31839 L
s
.766 .217 1 r
.16945 .31599 m
.16846 .32511 L
s
.16852 .32514 m
.16945 .31599 L
s
.16846 .32511 m
.16947 .31595 L
s
.16947 .31595 m
.16852 .32514 L
s
.648 .244 1 r
.73459 .25867 m
.73757 .30162 L
s
.608 .254 1 r
.42331 .25867 m
.4222 .30125 L
s
.416 .307 1 r
.11204 .25867 m
.10714 .299 L
s
.441 .3 1 r
.215 .29624 m
.21419 .30464 L
s
.2142 .3046 m
.215 .29624 L
s
.215 .29624 m
.21347 .31274 L
s
.638 .247 1 r
.3633 .31404 m
.36286 .32285 L
s
.36292 .32288 m
.3633 .31404 L
s
.344 .33 1 r
.26138 .3197 m
.2613 .32 L
s
.638 .247 1 r
.36286 .32285 m
.36332 .31399 L
s
.36332 .31399 m
.36292 .32288 L
s
.578 .262 1 r
.24588 .31208 m
.24512 .32081 L
s
.2452 .32062 m
.24588 .31208 L
s
.7 .232 1 r
.13852 .30078 m
.13744 .30976 L
s
.13745 .30971 m
.13852 .30078 L
s
.13852 .30078 m
.13643 .31876 L
s
.578 .262 1 r
.24512 .32081 m
.24589 .31203 L
s
.24589 .31203 m
.2452 .32062 L
s
.658 .242 1 r
.78661 .29942 m
.78729 .30835 L
s
.78731 .3083 m
.78661 .29942 L
s
.78661 .29942 m
.78804 .31713 L
s
.744 .222 1 r
.58815 .32772 m
.5881 .32807 L
s
.68 .237 1 r
.64371 .29875 m
.644 .30779 L
s
.64403 .30775 m
.64371 .29875 L
s
.64371 .29875 m
.64437 .3165 L
s
.589 .259 1 r
.41426 .31152 m
.41396 .32033 L
s
.41403 .31999 m
.41426 .31152 L
s
.618 .252 1 r
.5917 .25841 m
.59279 .30061 L
s
1 .149 .907 r
.28039 .25841 m
.27704 .30624 L
s
.589 .259 1 r
.41396 .32033 m
.41428 .31148 L
s
.41428 .31148 m
.41403 .31999 L
s
1 .156 .947 r
.56725 .3031 m
.56735 .31291 L
s
.56737 .31286 m
.56725 .3031 L
s
.56725 .3031 m
.56753 .32253 L
s
.7 .232 1 r
.53169 .31378 m
.5317 .32282 L
s
.53176 .32263 m
.53169 .31378 L
s
.69 .234 1 r
.16398 .29964 m
.16297 .30865 L
s
.16298 .3086 m
.16398 .29964 L
s
.16398 .29964 m
.16204 .3175 L
s
.372 .52 1 r
.45982 .29185 m
.45964 .29956 L
s
.45965 .29953 m
.45982 .29185 L
s
.45982 .29185 m
.45954 .30683 L
s
.7 .232 1 r
.5317 .32282 m
.53171 .31373 L
s
.53171 .31373 m
.53176 .32263 L
s
.68 .237 1 r
.78206 .32584 m
.78203 .32629 L
s
.701 .232 1 r
.05194 .31463 m
.05064 .3236 L
s
.0507 .32363 m
.05194 .31463 L
s
.712 .229 1 r
.5008 .29838 m
.5007 .30754 L
s
.50072 .30749 m
.5008 .29838 L
s
.5008 .29838 m
.50069 .31624 L
s
.701 .232 1 r
.05064 .3236 m
.05195 .31459 L
s
.05195 .31459 m
.0507 .32363 L
s
.88 .191 1 r
.81755 .31548 m
.81839 .32498 L
s
.81842 .32463 m
.81755 .31548 L
s
.442 .299 1 r
.2968 .30987 m
.29621 .31818 L
s
.29628 .31811 m
.2968 .30987 L
s
.88 .191 1 r
.81839 .32498 m
.81758 .31544 L
s
.81758 .31544 m
.81842 .32463 L
s
.788 .211 1 r
.28138 .30208 m
.28068 .3112 L
s
.2807 .31116 m
.28138 .30208 L
s
.28138 .30208 m
.28005 .32052 L
s
.777 .214 1 r
.76014 .25815 m
.76355 .30222 L
s
.618 .252 1 r
.44878 .25815 m
.448 .30072 L
s
.13743 .25815 m
.13258 .30072 L
s
.395 .62 1 r
.42425 .30284 m
.42402 .31028 L
s
.42408 .30995 m
.42425 .30284 L
s
.442 .299 1 r
.29621 .31818 m
.29682 .30982 L
s
.29682 .30982 m
.29628 .31811 L
s
.799 .209 1 r
.67463 .31493 m
.67504 .3242 L
s
.6751 .324 m
.67463 .31493 L
s
.628 .249 1 r
.15935 .32621 m
.15927 .32637 L
s
.395 .62 1 r
.42402 .31028 m
.42427 .3028 L
s
.42427 .3028 m
.42408 .30995 L
s
.504 .282 1 r
.46523 .30931 m
.46506 .31793 L
s
.46513 .31748 m
.46523 .30931 L
s
.799 .209 1 r
.67504 .3242 m
.67465 .31488 L
s
.67465 .31488 m
.6751 .324 L
s
.67 .239 1 r
.63916 .32558 m
.63911 .326 L
s
.504 .282 1 r
.46506 .31793 m
.46525 .30927 L
s
.46525 .30927 m
.46513 .31748 L
s
.88 .191 1 r
.53718 .33135 m
.53712 .33136 L
s
.45 .297 1 r
.40425 .32145 m
.40418 .32178 L
s
.766 .216 1 r
.75661 .32784 m
.75657 .32815 L
s
.733 .224 1 r
.13384 .32784 m
.13375 .32803 L
s
.811 .206 1 r
.33235 .29964 m
.33178 .30898 L
s
.3318 .30894 m
.33235 .29964 L
s
.33235 .29964 m
.33131 .31799 L
s
.618 .252 1 r
.43973 .31101 m
.43949 .31993 L
s
.43957 .31948 m
.43973 .31101 L
s
.559 .267 1 r
.38333 .29683 m
.38293 .30557 L
s
.38295 .30553 m
.38333 .29683 L
s
.38333 .29683 m
.38262 .31397 L
s
.669 .239 1 r
.35784 .29827 m
.35735 .30728 L
s
.35737 .30724 m
.35784 .29827 L
s
.35784 .29827 m
.35696 .31599 L
s
.834 .201 1 r
.61722 .25788 m
.61872 .30271 L
s
.459 .294 1 r
.30582 .25788 m
.30318 .30009 L
s
.618 .252 1 r
.43949 .31993 m
.43975 .31097 L
s
.43975 .31097 m
.43957 .31948 L
s
.56 .267 1 r
.69015 .32308 m
.69012 .32353 L
s
.68 .237 1 r
.83769 .29764 m
.83852 .30672 L
s
.83855 .30668 m
.83769 .29764 L
s
.83769 .29764 m
.8394 .31535 L
s
.871 .193 1 r
.5572 .31327 m
.55728 .32288 L
s
.55734 .32212 m
.5572 .31327 L
s
.488 .962 1 r
.19936 .28986 m
.19871 .29615 L
s
.19873 .29612 m
.19936 .28986 L
s
.19936 .28986 m
.19809 .30282 L
s
.608 .254 1 r
.18938 .29909 m
.18846 .30783 L
s
.18847 .30779 m
.18938 .29909 L
s
.18938 .29909 m
.18761 .31661 L
s
.638 .247 1 r
.04642 .29838 m
.04511 .30728 L
s
.04512 .30723 m
.04642 .29838 L
s
.04642 .29838 m
.04389 .31598 L
s
.871 .193 1 r
.55728 .32288 m
.55722 .31322 L
s
.55722 .31322 m
.55734 .32212 L
s
.608 .254 1 r
.49621 .32533 m
.49614 .32552 L
s
.473 .913 1 r
.09732 .29586 m
.09642 .30264 L
s
.09656 .30191 m
.09732 .29586 L
s
.09642 .30264 m
.09732 .29582 L
s
.09732 .29582 m
.09656 .30191 L
s
.777 .214 1 r
.7857 .25762 m
.78946 .3017 L
s
.628 .249 1 r
.47426 .25762 m
.4738 .30095 L
s
.367 .322 1 r
.16282 .25762 m
.15853 .29795 L
s
.701 .232 1 r
.5827 .31246 m
.58285 .32154 L
s
.58291 .32123 m
.5827 .31246 L
s
.702 .231 1 r
.6082 .31105 m
.60843 .32024 L
s
.60847 .3196 m
.6082 .31105 L
s
.701 .232 1 r
.58285 .32154 m
.58272 .31241 L
s
.58272 .31241 m
.58291 .32123 L
s
.702 .231 1 r
.60843 .32024 m
.60822 .31101 L
s
.60822 .31101 m
.60847 .3196 L
s
.522 .277 1 r
.07182 .29765 m
.07062 .30617 L
s
.07064 .30612 m
.07182 .29765 L
s
.07182 .29765 m
.06949 .31472 L
s
.618 .252 1 r
.24031 .29702 m
.23951 .30591 L
s
.23953 .30586 m
.24031 .29702 L
s
.24031 .29702 m
.23882 .31446 L
s
.531 .274 1 r
.49071 .30909 m
.49061 .31779 L
s
.49068 .31734 m
.49071 .30909 L
s
.599 .257 1 r
.18471 .32608 m
.18466 .32601 L
s
.88 .191 1 r
.64275 .25735 m
.64463 .30294 L
s
.869 .194 1 r
.33126 .25735 m
.32878 .30294 L
s
.531 .274 1 r
.49061 .31779 m
.49073 .30905 L
s
.49073 .30905 m
.49068 .31734 L
s
.744 .222 1 r
.27121 .31276 m
.27049 .32195 L
s
.27059 .3216 m
.27121 .31276 L
s
.476 .29 1 r
.65921 .30854 m
.65955 .31704 L
s
.65959 .31671 m
.65921 .30854 L
s
.744 .222 1 r
.27049 .32195 m
.27123 .31271 L
s
.27123 .31271 m
.27059 .3216 L
s
.476 .29 1 r
.65955 .31704 m
.65923 .3085 L
s
.65923 .3085 m
.65959 .31671 L
s
.767 .216 1 r
.6948 .29808 m
.69525 .30736 L
s
.69528 .30731 m
.6948 .29808 L
s
.6948 .29808 m
.69577 .31622 L
s
.416 .307 1 r
.76672 .32006 m
.76669 .32035 L
s
.467 .292 1 r
.09267 .32294 m
.09261 .3229 L
s
.618 .252 1 r
.63372 .31024 m
.63401 .31917 L
s
.63405 .31871 m
.63372 .31024 L
s
.61 .254 1 r
.34771 .30884 m
.34721 .31783 L
s
.34732 .31708 m
.34771 .30884 L
s
.433 .302 1 r
.81128 .25709 m
.81507 .2978 L
s
.822 .204 1 r
.49975 .25709 m
.49963 .30268 L
s
.588 .259 1 r
.18823 .25709 m
.18408 .2993 L
s
.618 .252 1 r
.63401 .31917 m
.63374 .3102 L
s
.63374 .3102 m
.63405 .31871 L
s
.61 .254 1 r
.34721 .31783 m
.34772 .3088 L
s
.34772 .3088 m
.34732 .31708 L
s
.648 .244 1 r
.72032 .29698 m
.72082 .30595 L
s
.72085 .3059 m
.72032 .29698 L
s
.72032 .29698 m
.72139 .31458 L
s
.916 .184 1 r
.86876 .31476 m
.86975 .32433 L
s
.86978 .32399 m
.86876 .31476 L
s
.86975 .32433 m
.86879 .31471 L
s
.86879 .31471 m
.86978 .32399 L
s
.523 .277 1 r
.06709 .32494 m
.06706 .32468 L
s
.953 .176 1 r
.66933 .30001 m
.66972 .30966 L
s
.66974 .30961 m
.66933 .30001 L
s
.66933 .30001 m
.67019 .31898 L
s
.722 .227 1 r
.12813 .3128 m
.12702 .32188 L
s
.12711 .32172 m
.12813 .3128 L
s
.486 .287 1 r
.62832 .29366 m
.62856 .30228 L
s
.62859 .30224 m
.62832 .29366 L
s
.62832 .29366 m
.62887 .3103 L
s
.733 .224 1 r
.66829 .25683 m
.67049 .30167 L
s
.881 .191 1 r
.35672 .25683 m
.3546 .30242 L
s
.722 .227 1 r
.12702 .32188 m
.12814 .31275 L
s
.12814 .31275 m
.12711 .32172 L
s
.811 .206 1 r
.55181 .29801 m
.55185 .3074 L
s
.55188 .30735 m
.55181 .29801 L
s
.55181 .29801 m
.55198 .31634 L
s
.744 .221 1 r
.40877 .29731 m
.40842 .30655 L
s
.40844 .3065 m
.40877 .29731 L
s
.40877 .29731 m
.40816 .31533 L
s
.822 .204 1 r
.52629 .29949 m
.52627 .30881 L
s
.52629 .30876 m
.52629 .29949 L
s
.52629 .29949 m
.52633 .31797 L
s
.589 .259 1 r
.43427 .29602 m
.434 .30484 L
s
.43402 .30479 m
.43427 .29602 L
s
.43427 .29602 m
.43382 .31332 L
s
.904 .186 1 r
.30214 .32945 m
.30205 .32965 L
s
.68 .237 1 r
.57732 .29694 m
.57743 .30599 L
s
.57745 .30594 m
.57732 .29694 L
s
.57732 .29694 m
.57763 .3147 L
s
.425 .304 1 r
.33766 .31892 m
.33757 .31936 L
s
.811 .206 1 r
.83687 .25656 m
.84144 .30179 L
s
.701 .231 1 r
.52526 .25656 m
.52549 .2999 L
s
.639 .247 1 r
.21365 .25656 m
.20969 .30028 L
s
.953 .176 1 r
.72579 .3148 m
.72637 .32445 L
s
.72641 .3241 m
.72579 .3148 L
s
.618 .252 1 r
.60283 .29565 m
.60301 .30458 L
s
.60304 .30454 m
.60283 .29565 L
s
.60283 .29565 m
.60327 .31306 L
s
.559 .267 1 r
.82783 .30918 m
.82863 .31791 L
s
.82866 .31757 m
.82783 .30918 L
s
.476 .29 1 r
.2301 .30777 m
.22933 .31627 L
s
.22942 .31594 m
.2301 .30777 L
s
.754 .219 1 r
.86343 .29853 m
.86434 .3077 L
s
.86437 .30765 m
.86343 .29853 L
s
.86343 .29853 m
.86532 .31671 L
s
.953 .176 1 r
.72637 .32445 m
.72581 .31475 L
s
.72581 .31475 m
.72641 .3241 L
s
.459 .295 1 r
.77139 .29503 m
.77199 .30343 L
s
.77202 .30339 m
.77139 .29503 L
s
.77139 .29503 m
.77267 .31168 L
s
.559 .267 1 r
.82863 .31791 m
.82786 .30913 L
s
.82786 .30913 m
.82866 .31757 L
s
.476 .29 1 r
.22933 .31627 m
.23012 .30773 L
s
.23012 .30773 m
.22942 .31594 L
s
.811 .206 1 r
.52172 .32632 m
.52165 .32677 L
s
.55 .269 1 r
.42967 .3228 m
.42961 .32299 L
s
.905 .186 1 r
.75132 .31369 m
.75197 .32327 L
s
.75201 .32284 m
.75132 .31369 L
s
.589 .259 1 r
.28661 .32217 m
.28651 .32263 L
s
.905 .186 1 r
.75197 .32327 m
.75135 .31364 L
s
.75135 .31364 m
.75201 .32284 L
s
.711 .229 1 r
.69385 .2563 m
.69634 .30002 L
s
.424 .305 1 r
.38219 .2563 m
.38065 .29627 L
s
.669 .239 1 r
.07054 .2563 m
.06455 .30077 L
s
.658 .242 1 r
.23557 .32506 m
.23549 .32521 L
s
.845 .199 1 r
.66479 .32732 m
.66474 .32766 L
s
.811 .206 1 r
.77686 .31258 m
.77757 .32193 L
s
.7776 .32158 m
.77686 .31258 L
s
.659 .242 1 r
.1535 .31258 m
.15249 .3214 L
s
.15254 .32158 m
.1535 .31258 L
s
.337 .353 1 r
.36771 .29203 m
.3673 .30005 L
s
.36732 .30001 m
.36771 .29203 L
s
.36771 .29203 m
.36698 .30778 L
s
.659 .242 1 r
.15249 .3214 m
.15351 .31254 L
s
.15351 .31254 m
.15254 .32158 L
s
.811 .206 1 r
.77757 .32193 m
.77689 .31254 L
s
.77689 .31254 m
.7776 .32158 L
s
.932 .18 1 r
.32211 .31203 m
.32149 .32179 L
s
.32161 .32095 m
.32211 .31203 L
s
.744 .221 1 r
.85892 .32543 m
.8589 .32578 L
s
.531 .274 1 r
.06143 .30922 m
.06021 .3178 L
s
.06029 .31769 m
.06143 .30922 L
s
.503 .282 1 r
.79697 .29432 m
.79765 .30291 L
s
.79768 .30287 m
.79697 .29432 L
s
.79697 .29432 m
.79839 .31117 L
s
.368 .322 1 r
.11246 .3064 m
.11143 .3145 L
s
.1115 .31442 m
.11246 .3064 L
s
.352 .327 1 r
.44968 .305 m
.44948 .31312 L
s
.44955 .31279 m
.44968 .305 L
s
.777 .214 1 r
.55078 .25603 m
.55137 .30051 L
s
.834 .201 1 r
.23909 .25603 m
.23535 .30126 L
s
.932 .18 1 r
.32149 .32179 m
.32212 .31198 L
s
.32212 .31198 m
.32161 .32095 L
s
.531 .274 1 r
.06021 .3178 m
.06144 .30917 L
s
.06144 .30917 m
.06029 .31769 L
s
.368 .322 1 r
.11143 .3145 m
.11247 .30636 L
s
.11247 .30636 m
.1115 .31442 L
s
.352 .327 1 r
.44948 .31312 m
.4497 .30496 L
s
.4497 .30496 m
.44955 .31279 L
s
.638 .247 1 r
.74137 .32355 m
.74133 .32385 L
s
.598 .257 1 r
.11794 .32355 m
.11786 .3237 L
s
.639 .247 1 r
.59828 .32292 m
.59823 .32334 L
s
.618 .252 1 r
.45518 .32229 m
.4551 .32274 L
s
.744 .221 1 r
.71586 .32518 m
.71582 .32552 L
s
.669 .239 1 r
.17896 .31177 m
.17801 .32067 L
s
.17807 .3207 m
.17896 .31177 L
s
.485 .287 1 r
.17354 .29473 m
.17261 .30321 L
s
.17262 .30317 m
.17354 .29473 L
s
.17354 .29473 m
.17176 .31154 L
s
.54 .272 1 r
.54173 .30896 m
.54177 .31758 L
s
.54183 .31743 m
.54173 .30896 L
s
.588 .259 1 r
.14802 .29617 m
.14699 .30492 L
s
.147 .30487 m
.14802 .29617 L
s
.14802 .29617 m
.14605 .31355 L
s
1 .98 .857 r
.71942 .25577 m
.72017 .26715 L
s
.81 .206 1 r
.40768 .25577 m
.40625 .30175 L
s
.701 .232 1 r
.09594 .25577 m
.0904 .2995 L
s
.669 .239 1 r
.17801 .32067 m
.17897 .31173 L
s
.17897 .31173 m
.17807 .3207 L
s
.54 .272 1 r
.54177 .31758 m
.54175 .30892 L
s
.54175 .30892 m
.54183 .31743 L
s
.845 .199 1 r
.74599 .29779 m
.74659 .30722 L
s
.74662 .30717 m
.74599 .29779 L
s
.74599 .29779 m
.74726 .31631 L
s
.34 .366 1 r
.53631 .29214 m
.53631 .30009 L
s
.53633 .30005 m
.53631 .29214 L
s
.53631 .29214 m
.53639 .30789 L
s
.822 .204 1 r
.80245 .31207 m
.80324 .32146 L
s
.80327 .32107 m
.80245 .31207 L
s
.522 .277 1 r
.1434 .32267 m
.14334 .32263 L
s
.822 .204 1 r
.80324 .32146 m
.80248 .31202 L
s
.80248 .31202 m
.80327 .32107 L
s
.618 .252 1 r
.71039 .3087 m
.71089 .31763 L
s
.71093 .31717 m
.71039 .3087 L
s
.834 .201 1 r
.20993 .32781 m
.20986 .3279 L
s
.599 .257 1 r
.57632 .25551 m
.5772 .29736 L
s
.799 .209 1 r
.26454 .25551 m
.26115 .30074 L
s
.69 .234 1 r
.29109 .29739 m
.29043 .30636 L
s
.29044 .30632 m
.29109 .29739 L
s
.29109 .29739 m
.28984 .3153 L
s
.618 .252 1 r
.71089 .31763 m
.71042 .30866 L
s
.71042 .30866 m
.71093 .31717 L
s
.467 .292 1 r
.59279 .30674 m
.59296 .31521 L
s
.59301 .31491 m
.59279 .30674 L
s
.345 .39 1 r
.10233 .31664 m
.10226 .31671 L
s
.467 .292 1 r
.59296 .31521 m
.59281 .3067 L
s
.59281 .3067 m
.59301 .31491 L
s
.523 .276 1 r
.84355 .31889 m
.84356 .31953 L
s
.766 .217 1 r
.1224 .29839 m
.12126 .30752 L
s
.12127 .30747 m
.1224 .29839 L
s
.1224 .29839 m
.12019 .31669 L
s
.588 .259 1 r
.7925 .32178 m
.79247 .32212 L
s
.45 .297 1 r
.70041 .31827 m
.70038 .31871 L
s
.733 .224 1 r
.2044 .31126 m
.2035 .32038 L
s
.20358 .32019 m
.2044 .31126 L
s
.559 .267 1 r
.745 .25524 m
.74805 .2971 L
s
.477 .289 1 r
.43318 .25524 m
.43225 .2956 L
s
.521 .277 1 r
.12136 .25524 m
.11628 .29784 L
s
.733 .224 1 r
.2035 .32038 m
.20441 .31121 L
s
.20441 .31121 m
.20358 .32019 L
s
.868 .194 1 r
.26553 .29931 m
.26477 .30867 L
s
.26478 .30862 m
.26553 .29931 L
s
.26553 .29931 m
.26408 .31807 L
s
.55 .269 1 r
.08675 .3093 m
.0856 .31788 L
s
.08566 .31792 m
.08675 .3093 L
s
.703 .231 1 r
.62384 .32278 m
.6238 .32332 L
s
.55 .269 1 r
.0856 .31788 m
.08677 .30925 L
s
.08677 .30925 m
.08566 .31792 L
s
.469 .292 1 r
.25542 .30874 m
.25473 .31703 L
s
.25477 .31729 m
.25542 .30874 L
s
.25473 .31703 m
.25543 .3087 L
s
.25543 .3087 m
.25477 .31729 L
s
.892 .189 1 r
.37856 .32793 m
.37848 .32809 L
s
.395 .62 1 r
.37307 .31098 m
.373 .3113 L
s
.41 .683 1 r
.60187 .25498 m
.60287 .28972 L
s
.659 .242 1 r
.29 .25498 m
.28704 .29908 L
s
.628 .249 1 r
.31197 .32316 m
.3119 .32331 L
s
.45 .297 1 r
.56186 .29199 m
.56193 .30047 L
s
.56195 .30042 m
.56186 .29199 L
s
.56186 .29199 m
.56207 .3085 L
s
.494 .284 1 r
.21987 .31964 m
.21978 .31994 L
s
.599 .257 1 r
.6795 .29417 m
.67989 .30303 L
s
.67992 .30299 m
.6795 .29417 L
s
.6795 .29417 m
.68035 .31152 L
s
.618 .252 1 r
.64939 .3219 m
.64934 .32224 L
s
.579 .262 1 r
.19431 .32127 m
.19422 .32157 L
s
.833 .201 1 r
.51622 .31215 m
.51618 .3215 L
s
.51625 .32131 m
.51622 .31215 L
s
.51618 .3215 m
.51624 .3121 L
s
.51624 .3121 m
.51625 .32131 L
s
.845 .199 1 r
.7706 .25471 m
.77426 .29995 L
s
.54 .272 1 r
.45869 .25471 m
.45804 .29732 L
s
.372 .52 1 r
.14679 .25471 m
.14276 .29095 L
s
.833 .201 1 r
.57279 .32642 m
.57273 .32661 L
s
.712 .229 1 r
.48068 .3229 m
.48061 .32336 L
s
.638 .247 1 r
.73601 .30878 m
.73658 .31772 L
s
.73662 .31741 m
.73601 .30878 L
s
.43 .761 1 r
.37762 .28537 m
.37728 .29252 L
s
.37729 .29248 m
.37762 .28537 L
s
.37762 .28537 m
.37702 .29919 L
s
.638 .247 1 r
.73658 .31772 m
.73604 .30874 L
s
.73604 .30874 m
.73662 .31741 L
s
.868 .194 1 r
.31653 .29761 m
.3159 .30704 L
s
.31592 .307 m
.31653 .29761 L
s
.31653 .29761 m
.31537 .31629 L
s
.88 .191 1 r
.48527 .29698 m
.48512 .30649 L
s
.48514 .30644 m
.48527 .29698 L
s
.48527 .29698 m
.48507 .31566 L
s
.522 .277 1 r
.47517 .30626 m
.47503 .31493 L
s
.4751 .31451 m
.47517 .30626 L
s
.777 .214 1 r
.62743 .25445 m
.62906 .29894 L
s
.456 .855 1 r
.31548 .25445 m
.31358 .28658 L
s
.485 .287 1 r
.38854 .31976 m
.38847 .31991 L
s
.522 .277 1 r
.47503 .31493 m
.47519 .30622 L
s
.47519 .30622 m
.4751 .31451 L
s
.598 .257 1 r
.50621 .32202 m
.50614 .32217 L
s
.648 .244 1 r
.84831 .29439 m
.84916 .30337 L
s
.84919 .30332 m
.84831 .29439 L
s
.84831 .29439 m
.85007 .312 L
s
.846 .199 1 r
.51081 .29591 m
.51073 .30537 L
s
.51076 .30533 m
.51081 .29591 L
s
.51081 .29591 m
.51075 .31439 L
s
.649 .244 1 r
.39312 .2938 m
.39273 .30281 L
s
.39275 .30276 m
.39312 .2938 L
s
.39312 .2938 m
.39244 .31137 L
s
.531 .274 1 r
.41866 .29239 m
.41835 .3011 L
s
.41837 .30106 m
.41866 .29239 L
s
.41866 .29239 m
.41814 .30936 L
s
1 .166 .996 r
.65403 .29668 m
.65439 .30653 L
s
.65441 .30648 m
.65403 .29668 L
s
.65403 .29668 m
.65481 .31577 L
s
.88 .191 1 r
.34204 .29672 m
.34148 .30623 L
s
.3415 .30618 m
.34204 .29672 L
s
.34204 .29672 m
.34103 .3154 L
s
.408 .31 1 r
.44419 .29107 m
.44396 .29939 L
s
.44398 .29935 m
.44419 .29107 L
s
.44419 .29107 m
.44382 .30735 L
s
.45 .297 1 r
.58742 .2918 m
.58755 .30025 L
s
.58757 .3002 m
.58742 .2918 L
s
.58742 .2918 m
.58776 .30835 L
s
.79622 .25418 m
.79979 .29455 L
s
.536 1 .9 r
.48422 .25418 m
.48402 .28222 L
s
.598 .257 1 r
.17223 .25418 m
.16778 .29717 L
s
.488 .962 1 r
.19871 .29615 m
.19808 .30244 L
s
.19809 .30282 m
.19871 .29615 L
s
.19808 .30244 m
.19873 .29612 L
s
.19873 .29612 m
.19809 .30282 L
s
.504 .282 1 r
.81271 .30545 m
.81346 .31408 L
s
.81348 .31363 m
.81271 .30545 L
s
.628 .249 1 r
.22433 .2948 m
.22349 .30366 L
s
.22351 .30362 m
.22433 .2948 L
s
.22433 .2948 m
.22275 .31238 L
s
.473 .913 1 r
.09656 .30191 m
.09642 .30264 L
s
.504 .282 1 r
.81346 .31408 m
.81274 .30541 L
s
.81274 .30541 m
.81348 .31363 L
s
.54 .272 1 r
.07648 .3205 m
.0764 .32066 L
s
.953 .176 1 r
.685 .31279 m
.68547 .32242 L
s
.68552 .32218 m
.685 .31279 L
s
.395 .62 1 r
.42408 .30995 m
.42402 .31028 L
s
.953 .176 1 r
.68547 .32242 m
.68503 .31274 L
s
.68503 .31274 m
.68552 .32218 L
s
.711 .229 1 r
.65301 .25392 m
.65496 .29766 L
s
.658 .242 1 r
.34097 .25392 m
.33872 .29766 L
s
.598 .257 1 r
.0555 .29584 m
.05424 .30452 L
s
.05425 .30447 m
.0555 .29584 L
s
.0555 .29584 m
.05302 .31338 L
s
.953 .176 1 r
.82285 .29657 m
.82369 .30627 L
s
.82372 .30622 m
.82285 .29657 L
s
.82285 .29657 m
.82459 .31552 L
s
.904 .186 1 r
.85381 .31223 m
.85475 .32174 L
s
.8548 .32154 m
.85381 .31223 L
s
.579 .262 1 r
.30635 .30801 m
.30576 .31672 L
s
.30583 .31664 m
.30635 .30801 L
s
.904 .186 1 r
.85475 .32174 m
.85384 .31219 L
s
.85384 .31219 m
.8548 .32154 L
s
.628 .249 1 r
.08104 .29454 m
.07982 .30341 L
s
.07983 .30336 m
.08104 .29454 L
s
.08104 .29454 m
.07869 .31212 L
s
.579 .262 1 r
.30576 .31672 m
.30637 .30797 L
s
.30637 .30797 m
.30583 .31664 L
s
.372 .52 1 r
.45964 .29956 m
.45948 .30727 L
s
.45954 .30683 m
.45964 .29956 L
s
.55 .269 1 r
.24983 .29391 m
.24908 .30255 L
s
.2491 .30251 m
.24983 .29391 L
s
.24983 .29391 m
.24841 .31112 L
s
.416 .307 1 r
.10657 .29321 m
.1055 .30139 L
s
.10551 .30135 m
.10657 .29321 L
s
.10657 .29321 m
.10448 .30973 L
s
.372 .52 1 r
.45948 .30727 m
.45965 .29953 L
s
.45965 .29953 m
.45954 .30683 L
s
.441 .3 1 r
.21419 .30464 m
.21338 .31304 L
s
.21347 .31274 m
.21419 .30464 L
s
.477 .289 1 r
.61299 .29117 m
.61319 .29973 L
s
.61321 .29969 m
.61299 .29117 L
s
.61299 .29117 m
.61346 .30784 L
s
.30092 .29117 m
.30031 .29973 L
s
.30033 .29968 m
.30092 .29117 L
s
.30092 .29117 m
.29981 .30783 L
s
.441 .3 1 r
.21338 .31304 m
.2142 .3046 L
s
.2142 .3046 m
.21347 .31274 L
s
.569 .264 1 r
.27537 .29265 m
.27468 .30144 L
s
.27469 .30139 m
.27537 .29265 L
s
.27537 .29265 m
.27409 .30985 L
s
.744 .222 1 r
.82184 .25365 m
.8261 .29778 L
s
.608 .254 1 r
.50976 .25365 m
.50978 .29627 L
s
.19768 .25365 m
.1935 .2974 L
s
.375 .532 1 r
.32644 .28992 m
.32597 .29742 L
s
.32598 .29738 m
.32644 .28992 L
s
.32644 .28992 m
.32555 .30507 L
s
.578 .262 1 r
.2452 .32062 m
.24512 .32081 L
s
1 .123 .772 r
.54729 .32992 m
.54722 .33039 L
s
.589 .259 1 r
.41403 .31999 m
.41396 .32033 L
s
.638 .247 1 r
.36292 .32288 m
.36286 .32285 L
s
.777 .214 1 r
.76171 .30946 m
.76238 .31874 L
s
.76241 .31839 m
.76171 .30946 L
s
.434 .302 1 r
.6786 .25339 m
.68068 .29301 L
s
.531 .274 1 r
.36648 .25339 m
.36467 .29488 L
s
.777 .214 1 r
.76238 .31874 m
.76174 .30941 L
s
.76174 .30941 m
.76241 .31839 L
s
.766 .217 1 r
.16852 .32514 m
.16846 .32511 L
s
.823 .204 1 r
.61844 .30891 m
.6187 .31837 L
s
.61875 .31776 m
.61844 .30891 L
s
.442 .299 1 r
.29628 .31811 m
.29621 .31818 L
s
.823 .204 1 r
.6187 .31837 m
.61847 .30886 L
s
.61847 .30886 m
.61875 .31776 L
s
.504 .282 1 r
.46513 .31748 m
.46506 .31793 L
s
1 .161 .972 r
.39849 .31257 m
.3981 .32239 L
s
.39818 .32204 m
.39849 .31257 L
s
.7 .232 1 r
.13744 .30976 m
.13637 .31873 L
s
.13643 .31876 m
.13744 .30976 L
s
.658 .242 1 r
.78729 .30835 m
.78799 .31728 L
s
.78804 .31713 m
.78729 .30835 L
s
1 .161 .972 r
.3981 .32239 m
.3985 .31252 L
s
.3985 .31252 m
.39818 .32204 L
s
.7 .232 1 r
.13637 .31873 m
.13745 .30971 L
s
.13745 .30971 m
.13643 .31876 L
s
.658 .242 1 r
.78799 .31728 m
.78731 .3083 L
s
.78731 .3083 m
.78804 .31713 L
s
.639 .247 1 r
.75632 .2928 m
.75692 .30177 L
s
.75695 .30173 m
.75632 .2928 L
s
.75632 .2928 m
.75758 .31034 L
s
.7 .232 1 r
.53176 .32263 m
.5317 .32282 L
s
.68 .237 1 r
.644 .30779 m
.64432 .31684 L
s
.64437 .3165 m
.644 .30779 L
s
.503 .282 1 r
.46972 .29147 m
.46954 .30006 L
s
.46956 .30002 m
.46972 .29147 L
s
.46972 .29147 m
.46946 .30832 L
s
.669 .239 1 r
.84749 .25312 m
.85205 .29687 L
s
.744 .222 1 r
.53532 .25312 m
.53569 .29725 L
s
.541 .272 1 r
.22316 .25312 m
.21952 .29462 L
s
.68 .237 1 r
.64432 .31684 m
.64403 .30775 L
s
.64403 .30775 m
.64437 .3165 L
s
.69 .234 1 r
.16297 .30865 m
.16196 .31766 L
s
.16204 .3175 m
.16297 .30865 L
s
.16196 .31766 m
.16298 .3086 L
s
.16298 .3086 m
.16204 .3175 L
s
.701 .232 1 r
.0507 .32363 m
.05064 .3236 L
s
.618 .252 1 r
.43957 .31948 m
.43949 .31993 L
s
.712 .229 1 r
.5007 .30754 m
.50062 .3167 L
s
.50069 .31624 m
.5007 .30754 L
s
.4 .312 1 r
.35194 .2898 m
.35148 .29809 L
s
.3515 .29805 m
.35194 .2898 L
s
.35194 .2898 m
.35111 .30605 L
s
.66 .241 1 r
.70421 .25286 m
.70678 .29548 L
s
.904 .186 1 r
.392 .25286 m
.39035 .29887 L
s
.504 .282 1 r
.07979 .25286 m
.07432 .29436 L
s
.712 .229 1 r
.50062 .3167 m
.50072 .30749 L
s
.50072 .30749 m
.50069 .31624 L
s
.88 .191 1 r
.81842 .32463 m
.81839 .32498 L
s
.788 .211 1 r
.28068 .3112 m
.27999 .32034 L
s
.28005 .32052 m
.28068 .3112 L
s
.559 .267 1 r
.38293 .30557 m
.38254 .31431 L
s
.38262 .31397 m
.38293 .30557 L
s
.799 .209 1 r
.6751 .324 m
.67504 .3242 L
s
.788 .211 1 r
.27999 .32034 m
.2807 .31116 L
s
.2807 .31116 m
.28005 .32052 L
s
.559 .267 1 r
.38254 .31431 m
.38295 .30553 L
s
.38295 .30553 m
.38262 .31397 L
s
.588 .259 1 r
.78194 .29213 m
.78259 .30096 L
s
.78262 .30091 m
.78194 .29213 L
s
.78194 .29213 m
.78332 .30945 L
s
.608 .254 1 r
.18846 .30783 m
.18755 .31658 L
s
.18761 .31661 m
.18846 .30783 L
s
.18755 .31658 m
.18847 .30779 L
s
.18847 .30779 m
.18761 .31661 L
s
1 .156 .947 r
.56735 .31291 m
.56747 .32273 L
s
.56753 .32253 m
.56735 .31291 L
s
.569 .264 1 r
.13189 .29373 m
.13084 .30237 L
s
.13085 .30233 m
.13189 .29373 L
s
.13189 .29373 m
.12984 .31109 L
s
.871 .193 1 r
.55734 .32212 m
.55728 .32288 L
s
.669 .239 1 r
.35735 .30728 m
.35688 .31629 L
s
.35696 .31599 m
.35735 .30728 L
s
.638 .247 1 r
.04511 .30728 m
.04379 .31617 L
s
.04389 .31598 m
.04511 .30728 L
s
.624 1 .72 r
.46418 .2753 m
.46407 .28046 L
s
.46408 .28043 m
.46418 .2753 L
s
.46418 .2753 m
.46401 .28533 L
s
1 .156 .947 r
.56747 .32273 m
.56737 .31286 L
s
.56737 .31286 m
.56753 .32253 L
s
.744 .221 1 r
.56089 .25259 m
.5616 .29635 L
s
.522 .277 1 r
.24864 .25259 m
.24526 .29485 L
s
.669 .239 1 r
.35688 .31629 m
.35737 .30724 L
s
.35737 .30724 m
.35696 .31599 L
s
.638 .247 1 r
.04379 .31617 m
.04512 .30723 L
s
.04512 .30723 m
.04389 .31598 L
s
.68 .237 1 r
.83852 .30672 m
.83938 .31581 L
s
.8394 .31535 m
.83852 .30672 L
s
.385 .574 1 r
.28526 .28539 m
.28468 .293 L
s
.28469 .29296 m
.28526 .28539 L
s
.28526 .28539 m
.2842 .30013 L
s
.531 .274 1 r
.49068 .31734 m
.49061 .31779 L
s
.68 .237 1 r
.83938 .31581 m
.83855 .30668 L
s
.83855 .30668 m
.8394 .31535 L
s
.476 .29 1 r
.65959 .31671 m
.65955 .31704 L
s
.811 .206 1 r
.33178 .30898 m
.33122 .31834 L
s
.33131 .31799 m
.33178 .30898 L
s
.702 .231 1 r
.60847 .3196 m
.60843 .32024 L
s
.522 .277 1 r
.07062 .30617 m
.06943 .31469 L
s
.06949 .31472 m
.07062 .30617 L
s
1 .141 .867 r
.7053 .29694 m
.70581 .30699 L
s
.70584 .30694 m
.7053 .29694 L
s
.7053 .29694 m
.70641 .31662 L
s
.811 .206 1 r
.33122 .31834 m
.3318 .30894 L
s
.3318 .30894 m
.33131 .31799 L
s
.522 .277 1 r
.06943 .31469 m
.07064 .30612 L
s
.07064 .30612 m
.06949 .31472 L
s
.965 .174 1 r
.73086 .29557 m
.73143 .30528 L
s
.73146 .30523 m
.73086 .29557 L
s
.73086 .29557 m
.73208 .3146 L
s
.45 .297 1 r
.52083 .28999 m
.52079 .29843 L
s
.52081 .29839 m
.52083 .28999 L
s
.52083 .28999 m
.52083 .30654 L
s
.48 .289 1 r
.68977 .28927 m
.69017 .29787 L
s
.69019 .29783 m
.68977 .28927 L
s
.68977 .28927 m
.69063 .3059 L
s
.55 .269 1 r
.72983 .25233 m
.73271 .29458 L
s
.701 .232 1 r
.58291 .32123 m
.58285 .32154 L
s
.344 .33 1 r
.41753 .25233 m
.41642 .29196 L
s
.588 .259 1 r
.10524 .25233 m
.09985 .29571 L
s
.61 .254 1 r
.34732 .31708 m
.34721 .31783 L
s
.618 .252 1 r
.23951 .30591 m
.23873 .3148 L
s
.23882 .31446 m
.23951 .30591 L
s
.63405 .31871 m
.63401 .31917 L
s
.23873 .3148 m
.23953 .30586 L
s
.23953 .30586 m
.23882 .31446 L
s
1 .98 .857 r
.71985 .2619 m
.72002 .26487 L
s
.72003 .26486 m
.71985 .2619 L
s
.71985 .2619 m
.72017 .26715 L
s
.744 .222 1 r
.27059 .3216 m
.27049 .32195 L
s
.799 .209 1 r
.58647 .25206 m
.58756 .29733 L
s
.905 .186 1 r
.27414 .25206 m
.27067 .29996 L
s
.777 .214 1 r
.63867 .29287 m
.63896 .30219 L
s
.63898 .30214 m
.63867 .29287 L
s
.63867 .29287 m
.63932 .31106 L
s
.486 .287 1 r
.62856 .30228 m
.62883 .3109 L
s
.62887 .3103 m
.62856 .30228 L
s
.953 .176 1 r
.75546 .2518 m
.75899 .29819 L
s
.531 .274 1 r
.44308 .2518 m
.44225 .29331 L
s
.669 .239 1 r
.1307 .2518 m
.12561 .29556 L
s
.486 .287 1 r
.62883 .3109 m
.62859 .30224 L
s
.62859 .30224 m
.62887 .3103 L
s
.767 .216 1 r
.69525 .30736 m
.69573 .31664 L
s
.69577 .31622 m
.69525 .30736 L
s
.648 .244 1 r
.72082 .30595 m
.72135 .31492 L
s
.72139 .31458 m
.72082 .30595 L
s
.767 .216 1 r
.69573 .31664 m
.69528 .30731 L
s
.69528 .30731 m
.69577 .31622 L
s
.648 .244 1 r
.72135 .31492 m
.72085 .3059 L
s
.72085 .3059 m
.72139 .31458 L
s
.476 .29 1 r
.22942 .31594 m
.22933 .31627 L
s
.722 .227 1 r
.12711 .32172 m
.12702 .32188 L
s
.88 .191 1 r
.15728 .29413 m
.15619 .30364 L
s
.1562 .30359 m
.15728 .29413 L
s
.15728 .29413 m
.15521 .31282 L
s
.589 .259 1 r
.434 .30484 m
.43375 .31366 L
s
.43382 .31332 m
.434 .30484 L
s
.559 .267 1 r
.82866 .31757 m
.82863 .31791 L
s
.459 .295 1 r
.77199 .30343 m
.77262 .31183 L
s
.77267 .31168 m
.77199 .30343 L
s
.916 .184 1 r
.86978 .32399 m
.86975 .32433 L
s
.45 .297 1 r
.09057 .2892 m
.08943 .29765 L
s
.08944 .29761 m
.09057 .2892 L
s
.09057 .2892 m
.0884 .30576 L
s
.733 .224 1 r
.61207 .25153 m
.61348 .29568 L
s
1 .158 .959 r
.29965 .25153 m
.29652 .30019 L
s
.589 .259 1 r
.43375 .31366 m
.43402 .30479 L
s
.43402 .30479 m
.43382 .31332 L
s
.459 .295 1 r
.77262 .31183 m
.77202 .30339 L
s
.77202 .30339 m
.77267 .31168 L
s
.337 .353 1 r
.3673 .30005 m
.36691 .30807 L
s
.36698 .30778 m
.3673 .30005 L
s
.352 .327 1 r
.44955 .31279 m
.44948 .31312 L
s
.337 .353 1 r
.36691 .30807 m
.36732 .30001 L
s
.36732 .30001 m
.36698 .30778 L
s
.638 .247 1 r
.83328 .29158 m
.83409 .30052 L
s
.83412 .30047 m
.83328 .29158 L
s
.83328 .29158 m
.83496 .30916 L
s
.744 .221 1 r
.40842 .30655 m
.40808 .31579 L
s
.40816 .31533 m
.40842 .30655 L
s
.40808 .31579 m
.40844 .3065 L
s
.40844 .3065 m
.40816 .31533 L
s
.368 .322 1 r
.1115 .31442 m
.11143 .3145 L
s
.822 .204 1 r
.52627 .30881 m
.52626 .31813 L
s
.52633 .31797 m
.52627 .30881 L
s
.811 .206 1 r
.55185 .3074 m
.55192 .31679 L
s
.55198 .31634 m
.55185 .3074 L
s
.68 .237 1 r
.57743 .30599 m
.57757 .31504 L
s
.57763 .3147 m
.57743 .30599 L
s
.618 .252 1 r
.60301 .30458 m
.60322 .31351 L
s
.60327 .31306 m
.60301 .30458 L
s
.822 .204 1 r
.52626 .31813 m
.52629 .30876 L
s
.52629 .30876 m
.52633 .31797 L
s
.56 .267 1 r
.78111 .25127 m
.7846 .29278 L
s
.522 .277 1 r
.46864 .25127 m
.46814 .29278 L
s
.541 .272 1 r
.15618 .25127 m
.15146 .29466 L
s
.811 .206 1 r
.55192 .31679 m
.55188 .30735 L
s
.55188 .30735 m
.55198 .31634 L
s
.824 .204 1 r
.66429 .29253 m
.66466 .30197 L
s
.66468 .30192 m
.66429 .29253 L
s
.66429 .29253 m
.6651 .31091 L
s
.68 .237 1 r
.57757 .31504 m
.57745 .30594 L
s
.57745 .30594 m
.57763 .3147 L
s
.618 .252 1 r
.60322 .31351 m
.60304 .30454 L
s
.60304 .30454 m
.60327 .31306 L
s
.953 .176 1 r
.66972 .30966 m
.67014 .31933 L
s
.67019 .31898 m
.66972 .30966 L
s
.67014 .31933 m
.66974 .30961 L
s
.66974 .30961 m
.67019 .31898 L
s
.845 .199 1 r
.49526 .29339 m
.49515 .30283 L
s
.49517 .30278 m
.49526 .29339 L
s
.49526 .29339 m
.49512 .31193 L
s
.588 .259 1 r
.54642 .29057 m
.54645 .2994 L
s
.54647 .29936 m
.54642 .29057 L
s
.54642 .29057 m
.54656 .30789 L
s
.754 .219 1 r
.86434 .3077 m
.86528 .31687 L
s
.86532 .31671 m
.86434 .3077 L
s
.86528 .31687 m
.86437 .30765 L
s
.86437 .30765 m
.86532 .31671 L
s
.531 .274 1 r
.06029 .31769 m
.06021 .3178 L
s
.953 .176 1 r
.72641 .3241 m
.72637 .32445 L
s
.503 .282 1 r
.79765 .30291 m
.79836 .3115 L
s
.79839 .31117 m
.79765 .30291 L
s
.34 .366 1 r
.53631 .30009 m
.53633 .30804 L
s
.53639 .30789 m
.53631 .30009 L
s
.766 .217 1 r
.63768 .251 m
.63946 .29553 L
s
.362 .473 1 r
.32518 .251 m
.32312 .28764 L
s
.503 .282 1 r
.79836 .3115 m
.79768 .30287 L
s
.79768 .30287 m
.79839 .31117 L
s
.905 .186 1 r
.75201 .32284 m
.75197 .32327 L
s
.34 .366 1 r
.53633 .30804 m
.53633 .30005 L
s
.53633 .30005 m
.53639 .30789 L
s
.659 .242 1 r
.15254 .32158 m
.15249 .3214 L
s
.4 .312 1 r
.14161 .28739 m
.14061 .29572 L
s
.14063 .29568 m
.14161 .28739 L
s
.14161 .28739 m
.13974 .3036 L
s
.811 .206 1 r
.7776 .32158 m
.77757 .32193 L
s
.375 .32 1 r
.76665 .2875 m
.76723 .29572 L
s
.76725 .29568 m
.76665 .2875 L
s
.76665 .2875 m
.76786 .3036 L
s
.485 .287 1 r
.17261 .30321 m
.17169 .31169 L
s
.17176 .31154 m
.17261 .30321 L
s
.588 .259 1 r
.06483 .29183 m
.06358 .30055 L
s
.06359 .30051 m
.06483 .29183 L
s
.06483 .29183 m
.06241 .30927 L
s
.932 .18 1 r
.32161 .32095 m
.32149 .32179 L
s
.733 .224 1 r
.20831 .29257 m
.2074 .30171 L
s
.20741 .30166 m
.20831 .29257 L
s
.20831 .29257 m
.20659 .31066 L
s
.54 .272 1 r
.54183 .31743 m
.54177 .31758 L
s
.485 .287 1 r
.17169 .31169 m
.17262 .30317 L
s
.17262 .30317 m
.17176 .31154 L
s
.845 .199 1 r
.8078 .29406 m
.80857 .30342 L
s
.8086 .30338 m
.8078 .29406 L
s
.8078 .29406 m
.80943 .31268 L
s
.68 .237 1 r
.80677 .25074 m
.81076 .29413 L
s
.744 .222 1 r
.49422 .25074 m
.49403 .29489 L
s
.522 .277 1 r
.18167 .25074 m
.17746 .29263 L
s
.588 .259 1 r
.14699 .30492 m
.14597 .31367 L
s
.14605 .31355 m
.14699 .30492 L
s
.14597 .31367 m
.147 .30487 L
s
.147 .30487 m
.14605 .31355 L
s
.467 .292 1 r
.59301 .31491 m
.59296 .31521 L
s
.669 .239 1 r
.17807 .3207 m
.17801 .32067 L
s
.618 .252 1 r
.71093 .31717 m
.71089 .31763 L
s
.425 .304 1 r
.6232 .28735 m
.62343 .29576 L
s
.62345 .29571 m
.6232 .28735 L
s
.6232 .28735 m
.62372 .30372 L
s
.425 .305 1 r
.66331 .25047 m
.66522 .29049 L
s
.34 .366 1 r
.35072 .25047 m
.34883 .28937 L
s
.43 .761 1 r
.37728 .29252 m
.37695 .29967 L
s
.37702 .29919 m
.37728 .29252 L
s
.488 .962 1 r
.19809 .30282 m
.19808 .30244 L
s
.578 .262 1 r
.25942 .29042 m
.25869 .29918 L
s
.2587 .29914 m
.25942 .29042 L
s
.25942 .29042 m
.25804 .30775 L
s
.43 .761 1 r
.37695 .29967 m
.37729 .29248 L
s
.37729 .29248 m
.37702 .29919 L
s
1 .98 .857 r
.72002 .26487 m
.72019 .26784 L
s
.72017 .26715 m
.72002 .26487 L
s
.72019 .26784 m
.72003 .26486 L
s
.72003 .26486 m
.72017 .26715 L
s
.588 .259 1 r
.74113 .28979 m
.74168 .29862 L
s
.74171 .29858 m
.74113 .28979 L
s
.74113 .28979 m
.7423 .30712 L
s
.822 .204 1 r
.80327 .32107 m
.80324 .32146 L
s
.833 .201 1 r
.03911 .29417 m
.03772 .30346 L
s
.03773 .30341 m
.03911 .29417 L
s
.03911 .29417 m
.03639 .31279 L
s
.69 .234 1 r
.29043 .30636 m
.28977 .31535 L
s
.28984 .3153 m
.29043 .30636 L
s
.627 1 .715 r
.83245 .2502 m
.83454 .27083 L
s
1 .156 .946 r
.51981 .2502 m
.51998 .29737 L
s
.608 .254 1 r
.20717 .2502 m
.20322 .29286 L
s
.69 .234 1 r
.28977 .31535 m
.29044 .30632 L
s
.29044 .30632 m
.28984 .3153 L
s
.469 .292 1 r
.25477 .31729 m
.25473 .31703 L
s
.441 .3 1 r
.31058 .28794 m
.31001 .29635 L
s
.31002 .29631 m
.31058 .28794 L
s
.31058 .28794 m
.30953 .30447 L
s
.744 .221 1 r
.57204 .29083 m
.57214 .30008 L
s
.57217 .30003 m
.57204 .29083 L
s
.57204 .29083 m
.57233 .30887 L
s
.845 .199 1 r
.74659 .30722 m
.74722 .31666 L
s
.74726 .31631 m
.74659 .30722 L
s
.754 .219 1 r
.23379 .29231 m
.23295 .30149 L
s
.23297 .30144 m
.23379 .29231 L
s
.23379 .29231 m
.23221 .31052 L
s
.845 .199 1 r
.74722 .31666 m
.74662 .30717 L
s
.74662 .30717 m
.74726 .31631 L
s
.55 .269 1 r
.08566 .31792 m
.0856 .31788 L
s
.777 .214 1 r
.40292 .29164 m
.40254 .30093 L
s
.40256 .30088 m
.40292 .29164 L
s
.40292 .29164 m
.40227 .30988 L
s
.733 .224 1 r
.20358 .32019 m
.2035 .32038 L
s
.766 .217 1 r
.12126 .30752 m
.12012 .31666 L
s
.12019 .31669 m
.12126 .30752 L
s
.45 .297 1 r
.56193 .30047 m
.56202 .30894 L
s
.56207 .3085 m
.56193 .30047 L
s
.766 .217 1 r
.12012 .31666 m
.12127 .30747 L
s
.12127 .30747 m
.12019 .31669 L
s
.503 .282 1 r
.68895 .24994 m
.69124 .29109 L
s
.638 .247 1 r
.37627 .24994 m
.37452 .29297 L
s
.45 .297 1 r
.56202 .30894 m
.56195 .30042 L
s
.56195 .30042 m
.56207 .3085 L
s
.504 .282 1 r
.4797 .28775 m
.47955 .29639 L
s
.47957 .29635 m
.4797 .28775 L
s
.4797 .28775 m
.47949 .30458 L
s
1 .146 .894 r
.18256 .29561 m
.1815 .30551 L
s
.18152 .30546 m
.18256 .29561 L
s
.18256 .29561 m
.18054 .3153 L
s
.868 .194 1 r
.26477 .30867 m
.26401 .31804 L
s
.26408 .31807 m
.26477 .30867 L
s
.599 .257 1 r
.67989 .30303 m
.6803 .31189 L
s
.68035 .31152 m
.67989 .30303 L
s
.868 .194 1 r
.26401 .31804 m
.26478 .30862 L
s
.26478 .30862 m
.26408 .31807 L
s
.669 .239 1 r
.54541 .24967 m
.54591 .29308 L
s
.765 .217 1 r
.23269 .24967 m
.22881 .29534 L
s
.599 .257 1 r
.6803 .31189 m
.67992 .30299 L
s
.67992 .30299 m
.68035 .31152 L
s
.522 .277 1 r
.4751 .31451 m
.47503 .31493 L
s
.624 1 .72 r
.46407 .28046 m
.46397 .2856 L
s
.46401 .28533 m
.46407 .28046 L
s
.638 .247 1 r
.73662 .31741 m
.73658 .31772 L
s
.624 1 .72 r
.46397 .2856 m
.46408 .28043 L
s
.46408 .28043 m
.46401 .28533 L
s
.522 .277 1 r
.16695 .28835 m
.16598 .29699 L
s
.16599 .29694 m
.16695 .28835 L
s
.16695 .28835 m
.16512 .30533 L
s
.372 .52 1 r
.45954 .30683 m
.45948 .30727 L
s
.733 .224 1 r
.11573 .29127 m
.11457 .30041 L
s
.11458 .30037 m
.11573 .29127 L
s
.11573 .29127 m
.1135 .30936 L
s
.822 .204 1 r
.7146 .24941 m
.7175 .29507 L
s
.35 .414 1 r
.40184 .24941 m
.40062 .28681 L
s
.609 .254 1 r
.08907 .24941 m
.08331 .29395 L
s
.833 .201 1 r
.51625 .32131 m
.51618 .3215 L
s
.408 .31 1 r
.44396 .29939 m
.44375 .30772 L
s
.44382 .30735 m
.44396 .29939 L
s
.504 .282 1 r
.81348 .31363 m
.81346 .31408 L
s
.408 .31 1 r
.44375 .30772 m
.44398 .29935 L
s
.44398 .29935 m
.44382 .30735 L
s
1 .138 .854 r
.85926 .29379 m
.86025 .30388 L
s
.86028 .30383 m
.85926 .29379 L
s
.85926 .29379 m
.86129 .31352 L
s
.45 .297 1 r
.58755 .30025 m
.58771 .30869 L
s
.58776 .30835 m
.58755 .30025 L
s
.375 .532 1 r
.32597 .29742 m
.3255 .30492 L
s
.32555 .30507 m
.32597 .29742 L
s
.928 .181 1 r
.71566 .29316 m
.71618 .30272 L
s
.71621 .30268 m
.71566 .29316 L
s
.71566 .29316 m
.71679 .31213 L
s
.45 .297 1 r
.58771 .30869 m
.58757 .3002 L
s
.58757 .3002 m
.58776 .30835 L
s
.375 .532 1 r
.3255 .30492 m
.32598 .29738 L
s
.32598 .29738 m
.32555 .30507 L
s
.811 .206 1 r
.59768 .29108 m
.59786 .30045 L
s
.59788 .3004 m
.59768 .29108 L
s
.59768 .29108 m
.59811 .30948 L
s
.531 .274 1 r
.41835 .3011 m
.41806 .30981 L
s
.41814 .30936 m
.41835 .3011 L
s
.649 .244 1 r
.57103 .24914 m
.57187 .29218 L
s
.833 .201 1 r
.25822 .24914 m
.25471 .29481 L
s
.531 .274 1 r
.41806 .30981 m
.41837 .30106 L
s
.41837 .30106 m
.41814 .30936 L
s
.811 .206 1 r
.45408 .29049 m
.45385 .29989 L
s
.45387 .29985 m
.45408 .29049 L
s
.45408 .29049 m
.45371 .30885 L
s
.648 .244 1 r
.84916 .30337 m
.85004 .31234 L
s
.85007 .312 m
.84916 .30337 L
s
.85004 .31234 m
.84919 .30332 L
s
.84919 .30332 m
.85007 .312 L
s
.868 .194 1 r
.3159 .30704 m
.31529 .31648 L
s
.31537 .31629 m
.3159 .30704 L
s
.638 .247 1 r
.79251 .28923 m
.79321 .29818 L
s
.79324 .29814 m
.79251 .28923 L
s
.79251 .28923 m
.79397 .30683 L
s
1 .98 .857 r
.72017 .26715 m
.72019 .26784 L
s
.649 .244 1 r
.39273 .30281 m
.39236 .31182 L
s
.39244 .31137 m
.39273 .30281 L
s
.416 .307 1 r
.1055 .30139 m
.10444 .30958 L
s
.10448 .30973 m
.1055 .30139 L
s
.441 .3 1 r
.21347 .31274 m
.21338 .31304 L
s
.434 .302 1 r
.70013 .28574 m
.70055 .29419 L
s
.70057 .29415 m
.70013 .28574 L
s
.70013 .28574 m
.70103 .30216 L
s
.868 .194 1 r
.31529 .31648 m
.31592 .307 L
s
.31592 .307 m
.31537 .31629 L
s
.649 .244 1 r
.39236 .31182 m
.39275 .30276 L
s
.39275 .30276 m
.39244 .31137 L
s
.416 .307 1 r
.10444 .30958 m
.10551 .30135 L
s
.10551 .30135 m
.10448 .30973 L
s
.88 .191 1 r
.48512 .30649 m
.485 .316 L
s
.48507 .31566 m
.48512 .30649 L
s
.628 .249 1 r
.22349 .30366 m
.22267 .31253 L
s
.22275 .31238 m
.22349 .30366 L
s
.618 .252 1 r
.64891 .28871 m
.64922 .29762 L
s
.64924 .29758 m
.64891 .28871 L
s
.64891 .28871 m
.6496 .30619 L
s
.88 .191 1 r
.485 .316 m
.48514 .30644 L
s
.48514 .30644 m
.48507 .31566 L
s
.966 .173 1 r
.74027 .24887 m
.74357 .29492 L
s
1 .116 .73 r
.42742 .24887 m
.42619 .29832 L
s
.521 .277 1 r
.11457 .24887 m
.10939 .29154 L
s
.628 .249 1 r
.22267 .31253 m
.22351 .30362 L
s
.22351 .30362 m
.22275 .31238 L
s
.598 .257 1 r
.05424 .30452 m
.05298 .3132 L
s
.05302 .31338 m
.05424 .30452 L
s
.345 .33 1 r
.41289 .28463 m
.41259 .29278 L
s
.4126 .29274 m
.41289 .28463 L
s
.41289 .28463 m
.41237 .30051 L
s
.579 .262 1 r
.30583 .31664 m
.30576 .31672 L
s
.598 .257 1 r
.05298 .3132 m
.05425 .30447 L
s
.05425 .30447 m
.05302 .31338 L
s
.503 .282 1 r
.81816 .28823 m
.81889 .29676 L
s
.81891 .29672 m
.81816 .28823 L
s
.81816 .28823 m
.8197 .30518 L
s
.846 .199 1 r
.51073 .30537 m
.51068 .31485 L
s
.51075 .31439 m
.51073 .30537 L
s
.55 .269 1 r
.24908 .30255 m
.24834 .31119 L
s
.24841 .31112 m
.24908 .30255 L
s
.477 .289 1 r
.61319 .29973 m
.61341 .30828 L
s
.61346 .30784 m
.61319 .29973 L
s
.30031 .29973 m
.29972 .30828 L
s
.29981 .30783 m
.30031 .29973 L
s
.846 .199 1 r
.51068 .31485 m
.51076 .30533 L
s
.51076 .30533 m
.51075 .31439 L
s
.55 .269 1 r
.24834 .31119 m
.2491 .30251 L
s
.2491 .30251 m
.24841 .31112 L
s
.477 .289 1 r
.61341 .30828 m
.61321 .29969 L
s
.61321 .29969 m
.61346 .30784 L
s
.29972 .30828 m
.30033 .29968 L
s
.30033 .29968 m
.29981 .30783 L
s
.88 .191 1 r
.34148 .30623 m
.34094 .31574 L
s
.34103 .3154 m
.34148 .30623 L
s
.628 .249 1 r
.07982 .30341 m
.0786 .31227 L
s
.07869 .31212 m
.07982 .30341 L
s
.88 .191 1 r
.34094 .31574 m
.3415 .30618 L
s
.3415 .30618 m
.34103 .3154 L
s
.559 .267 1 r
.59667 .24861 m
.59781 .29052 L
s
.55 .269 1 r
.28377 .24861 m
.28087 .29052 L
s
.628 .249 1 r
.0786 .31227 m
.07983 .30336 L
s
.07983 .30336 m
.07869 .31212 L
s
1 .146 .894 r
.42846 .29279 m
.42813 .3028 L
s
.42815 .30275 m
.42846 .29279 L
s
.42846 .29279 m
.42791 .31236 L
s
.569 .264 1 r
.27468 .30144 m
.274 .31023 L
s
.27409 .30985 m
.27468 .30144 L
s
.274 .31023 m
.27469 .30139 L
s
.27469 .30139 m
.27409 .30985 L
s
1 .166 .996 r
.65439 .30653 m
.65477 .31639 L
s
.65481 .31577 m
.65439 .30653 L
s
.953 .176 1 r
.68552 .32218 m
.68547 .32242 L
s
1 .166 .996 r
.65477 .31639 m
.65441 .30648 L
s
.65441 .30648 m
.65481 .31577 L
s
.521 .277 1 r
.19236 .28882 m
.19147 .29736 L
s
.19148 .29732 m
.19236 .28882 L
s
.19236 .28882 m
.19065 .30593 L
s
.904 .186 1 r
.8548 .32154 m
.85475 .32174 L
s
.55 .269 1 r
.76595 .24834 m
.76931 .29063 L
s
.789 .211 1 r
.45302 .24834 m
.45227 .29251 L
s
.639 .247 1 r
.14008 .24834 m
.13511 .29214 L
s
.7 .232 1 r
.33601 .28975 m
.33546 .29881 L
s
.33548 .29877 m
.33601 .28975 L
s
.33601 .28975 m
.335 .30769 L
s
.953 .176 1 r
.82369 .30627 m
.82457 .31598 L
s
.82459 .31552 m
.82369 .30627 L
s
.82457 .31598 m
.82372 .30622 L
s
.82372 .30622 m
.82459 .31552 L
s
.777 .214 1 r
.76241 .31839 m
.76238 .31874 L
s
.823 .204 1 r
.61875 .31776 m
.6187 .31837 L
s
.503 .282 1 r
.46954 .30006 m
.46939 .30866 L
s
.46946 .30832 m
.46954 .30006 L
s
.618 .252 1 r
.62231 .24808 m
.6238 .29037 L
s
.588 .259 1 r
.30933 .24808 m
.30674 .29037 L
s
.658 .242 1 r
.78804 .31713 m
.78799 .31728 L
s
.385 .574 1 r
.28468 .293 m
.28411 .30061 L
s
.2842 .30013 m
.28468 .293 L
s
.503 .282 1 r
.46939 .30866 m
.46956 .30002 L
s
.46956 .30002 m
.46946 .30832 L
s
.68 .237 1 r
.64437 .3165 m
.64432 .31684 L
s
.385 .574 1 r
.28411 .30061 m
.28469 .29296 L
s
.28469 .29296 m
.2842 .30013 L
s
.55 .269 1 r
.3616 .28879 m
.36114 .2974 L
s
.36116 .29735 m
.3616 .28879 L
s
.3616 .28879 m
.36077 .30605 L
s
.4 .312 1 r
.35148 .29809 m
.35103 .30639 L
s
.35111 .30605 m
.35148 .29809 L
s
.35103 .30639 m
.3515 .29805 L
s
.3515 .29805 m
.35111 .30605 L
s
.7 .232 1 r
.13643 .31876 m
.13637 .31873 L
s
.639 .247 1 r
.75692 .30177 m
.75755 .31075 L
s
.75758 .31034 m
.75692 .30177 L
s
.75755 .31075 m
.75695 .30173 L
s
.75695 .30173 m
.75758 .31034 L
s
.467 .292 1 r
.0742 .2876 m
.07303 .29598 L
s
.07304 .29594 m
.0742 .2876 L
s
.0742 .2876 m
.07191 .3044 L
s
.69 .234 1 r
.16204 .3175 m
.16196 .31766 L
s
.744 .222 1 r
.67462 .28908 m
.675 .29829 L
s
.67503 .29825 m
.67462 .28908 L
s
.67462 .28908 m
.67547 .30717 L
s
.559 .267 1 r
.38262 .31397 m
.38254 .31431 L
s
.45 .297 1 r
.58217 .28555 m
.58229 .29401 L
s
.58231 .29396 m
.58217 .28555 L
s
.58217 .28555 m
.58248 .30212 L
s
.67 .239 1 r
.79165 .24781 m
.79542 .29086 L
s
.733 .224 1 r
.47863 .24781 m
.47823 .29199 L
s
.359 .325 1 r
.16561 .24781 m
.16141 .28748 L
s
.712 .229 1 r
.50069 .31624 m
.50062 .3167 L
s
1 .161 .972 r
.39818 .32204 m
.3981 .32239 L
s
.486 .287 1 r
.43847 .28514 m
.43821 .29375 L
s
.43823 .2937 m
.43847 .28514 L
s
.43847 .28514 m
.43805 .30186 L
s
.569 .264 1 r
.13084 .30237 m
.12978 .31102 L
s
.12984 .31109 m
.13084 .30237 L
s
.744 .221 1 r
.53092 .28882 m
.53091 .29803 L
s
.53093 .29799 m
.53092 .28882 L
s
.53092 .28882 m
.53098 .30691 L
s
.588 .259 1 r
.78259 .30096 m
.78328 .30979 L
s
.78332 .30945 m
.78259 .30096 L
s
1 .078 .51 r
.64797 .24754 m
.65018 .29889 L
s
.41 .683 1 r
.33491 .24754 m
.33305 .28234 L
s
.608 .254 1 r
.18761 .31661 m
.18755 .31658 L
s
.569 .264 1 r
.12978 .31102 m
.13085 .30233 L
s
.13085 .30233 m
.12984 .31109 L
s
.588 .259 1 r
.78328 .30979 m
.78262 .30091 L
s
.78262 .30091 m
.78332 .30945 L
s
.669 .239 1 r
.35696 .31599 m
.35688 .31629 L
s
.638 .247 1 r
.04389 .31598 m
.04379 .31617 L
s
.701 .232 1 r
.21785 .28896 m
.21697 .29803 L
s
.21699 .29799 m
.21785 .28896 L
s
.21785 .28896 m
.21619 .30691 L
s
.754 .219 1 r
.04849 .28971 m
.04713 .29889 L
s
.04714 .29884 m
.04849 .28971 L
s
.04849 .28971 m
.04587 .30792 L
s
.68 .237 1 r
.8394 .31535 m
.83938 .31581 L
s
.788 .211 1 r
.28005 .32052 m
.27999 .32034 L
s
.522 .277 1 r
.06949 .31472 m
.06943 .31469 L
s
.45 .297 1 r
.52079 .29843 m
.52077 .30688 L
s
.52083 .30654 m
.52079 .29843 L
s
.52077 .30688 m
.52081 .29839 L
s
.52081 .29839 m
.52083 .30654 L
s
.953 .176 1 r
.5053 .29067 m
.50521 .30035 L
s
.50523 .3003 m
.5053 .29067 L
s
.5053 .29067 m
.50521 .30968 L
s
.48 .289 1 r
.69017 .29787 m
.6906 .30648 L
s
.69063 .3059 m
.69017 .29787 L
s
.68 .237 1 r
.81736 .24728 m
.8215 .29071 L
s
.811 .206 1 r
.50425 .24728 m
.5042 .29184 L
s
.55 .269 1 r
.19114 .24728 m
.18701 .28958 L
s
.48 .289 1 r
.6906 .30648 m
.69019 .29783 L
s
.69019 .29783 m
.69063 .3059 L
s
.845 .199 1 r
.84405 .28948 m
.84494 .29893 L
s
.84497 .29888 m
.84405 .28948 L
s
.84405 .28948 m
.84588 .30804 L
s
.811 .206 1 r
.33131 .31799 m
.33122 .31834 L
s
.618 .252 1 r
.23882 .31446 m
.23873 .3148 L
s
.486 .287 1 r
.62887 .3103 m
.62883 .3109 L
s
.916 .184 1 r
.67365 .24701 m
.676 .29308 L
s
.811 .206 1 r
.3605 .24701 m
.35845 .29195 L
s
1 .156 .947 r
.56753 .32253 m
.56747 .32273 L
s
.618 .252 1 r
.55656 .28841 m
.55661 .29721 L
s
.55664 .29717 m
.55656 .28841 L
s
.55656 .28841 m
.55675 .30602 L
s
.7 .232 1 r
.2434 .28844 m
.2426 .29751 L
s
.24261 .29747 m
.2434 .28844 L
s
.2434 .28844 m
.24189 .30639 L
s
.648 .244 1 r
.26904 .28711 m
.26831 .2961 L
s
.26832 .29605 m
.26904 .28711 L
s
.26904 .28711 m
.26769 .30475 L
s
.337 .353 1 r
.36698 .30778 m
.36691 .30807 L
s
.54 .272 1 r
.12524 .28659 m
.12416 .29524 L
s
.12418 .29519 m
.12524 .28659 L
s
.12524 .28659 m
.12318 .30374 L
s
.869 .194 1 r
.38716 .28948 m
.38673 .29897 L
s
.38675 .29892 m
.38716 .28948 L
s
.38716 .28948 m
.3864 .30815 L
s
.755 .219 1 r
.84309 .24674 m
.84783 .29281 L
s
.45 .297 1 r
.52989 .24674 m
.53016 .28717 L
s
.578 .262 1 r
.2167 .24674 m
.21279 .29018 L
s
.965 .174 1 r
.73143 .30528 m
.73204 .31499 L
s
.73208 .3146 m
.73143 .30528 L
s
.459 .295 1 r
.77267 .31168 m
.77262 .31183 L
s
.624 1 .72 r
.46401 .28533 m
.46397 .2856 L
s
.965 .174 1 r
.73204 .31499 m
.73146 .30523 L
s
.73146 .30523 m
.73208 .3146 L
s
.648 .244 1 r
.72139 .31458 m
.72135 .31492 L
s
.531 .274 1 r
.77728 .28543 m
.77792 .29412 L
s
.77795 .29408 m
.77728 .28543 L
s
.77728 .28543 m
.77862 .30247 L
s
.45 .297 1 r
.08943 .29765 m
.08829 .3061 L
s
.0884 .30576 m
.08943 .29765 L
s
.589 .259 1 r
.43382 .31332 m
.43375 .31366 L
s
1 .141 .867 r
.70581 .30699 m
.70636 .31705 L
s
.70641 .31662 m
.70581 .30699 L
s
.45 .297 1 r
.08829 .3061 m
.08944 .29761 L
s
.08944 .29761 m
.0884 .30576 L
s
.767 .216 1 r
.69577 .31622 m
.69573 .31664 L
s
1 .141 .867 r
.70636 .31705 m
.70584 .30694 L
s
.70584 .30694 m
.70641 .31662 L
s
.376 .319 1 r
.37156 .28213 m
.37114 .29043 L
s
.37116 .29039 m
.37156 .28213 L
s
.37156 .28213 m
.37083 .29817 L
s
.43 .761 1 r
.37702 .29919 m
.37695 .29967 L
s
.845 .199 1 r
.69934 .24648 m
.70201 .29179 L
s
.486 .956 1 r
.3861 .24648 m
.38495 .27717 L
s
.777 .214 1 r
.63896 .30219 m
.63927 .31152 L
s
.63932 .31106 m
.63896 .30219 L
s
.34 .366 1 r
.53639 .30789 m
.53633 .30804 L
s
.777 .214 1 r
.63927 .31152 m
.63898 .30214 L
s
.63898 .30214 m
.63932 .31106 L
s
.618 .252 1 r
.60327 .31306 m
.60322 .31351 L
s
.823 .204 1 r
.55554 .24621 m
.55621 .29266 L
s
1 .159 .96 r
.24226 .24621 m
.23833 .29417 L
s
.744 .221 1 r
.40816 .31533 m
.40808 .31579 L
s
.68 .237 1 r
.57763 .3147 m
.57757 .31504 L
s
.638 .247 1 r
.83409 .30052 m
.83493 .30946 L
s
.83496 .30916 m
.83409 .30052 L
s
.503 .282 1 r
.79839 .31117 m
.79836 .3115 L
s
.81 .206 1 r
.72606 .28915 m
.72659 .29845 L
s
.72662 .2984 m
.72606 .28915 L
s
.72606 .28915 m
.72721 .30763 L
s
.638 .247 1 r
.83493 .30946 m
.83412 .30047 L
s
.83412 .30047 m
.83496 .30916 L
s
.375 .32 1 r
.76723 .29572 m
.76783 .30394 L
s
.76786 .3036 m
.76723 .29572 L
s
.4 .312 1 r
.14061 .29572 m
.13962 .30405 L
s
.13974 .3036 m
.14061 .29572 L
s
.811 .206 1 r
.55198 .31634 m
.55192 .31679 L
s
.589 .259 1 r
.48971 .28502 m
.48958 .2939 L
s
.4896 .29385 m
.48971 .28502 L
s
.48971 .28502 m
.48955 .30232 L
s
.578 .262 1 r
.29457 .28718 m
.29393 .29587 L
s
.29395 .29583 m
.29457 .28718 L
s
.29457 .28718 m
.29337 .3046 L
s
.521 .277 1 r
.15073 .28648 m
.14974 .29501 L
s
.14975 .29497 m
.15073 .28648 L
s
.15073 .28648 m
.1488 .30359 L
s
.375 .32 1 r
.76783 .30394 m
.76725 .29568 L
s
.76725 .29568 m
.76786 .3036 L
s
.4 .312 1 r
.13962 .30405 m
.14063 .29568 L
s
.14063 .29568 m
.13974 .3036 L
s
.88 .191 1 r
.15619 .30364 m
.1551 .31316 L
s
.15521 .31282 m
.15619 .30364 L
s
.588 .259 1 r
.54645 .2994 m
.5465 .30823 L
s
.54656 .30789 m
.54645 .2994 L
s
.559 .267 1 r
.80303 .28513 m
.80374 .2939 L
s
.80376 .29385 m
.80303 .28513 L
s
.80303 .28513 m
.80451 .30232 L
s
.88 .191 1 r
.1551 .31316 m
.1562 .30359 L
s
.1562 .30359 m
.15521 .31282 L
s
.845 .199 1 r
.72504 .24594 m
.72807 .29127 L
s
.56 .267 1 r
.41171 .24594 m
.41048 .28751 L
s
.628 .249 1 r
.09839 .24594 m
.09275 .29051 L
s
.588 .259 1 r
.5465 .30823 m
.54647 .29936 L
s
.54647 .29936 m
.54656 .30789 L
s
.485 .287 1 r
.17176 .31154 m
.17169 .31169 L
s
.822 .204 1 r
.52633 .31797 m
.52626 .31813 L
s
.57 .264 1 r
.8287 .28391 m
.82949 .29278 L
s
.82952 .29273 m
.8287 .28391 L
s
.8287 .28391 m
.83032 .30105 L
s
.754 .219 1 r
.86532 .31671 m
.86528 .31687 L
s
.953 .176 1 r
.67019 .31898 m
.67014 .31933 L
s
.824 .204 1 r
.66466 .30197 m
.66506 .31141 L
s
.6651 .31091 m
.66466 .30197 L
s
.588 .259 1 r
.06358 .30055 m
.06234 .30928 L
s
.06241 .30927 m
.06358 .30055 L
s
.559 .267 1 r
.34585 .28487 m
.34534 .29363 L
s
.34536 .29359 m
.34585 .28487 L
s
.34585 .28487 m
.34493 .30206 L
s
.953 .176 1 r
.58121 .24568 m
.58225 .29176 L
s
.648 .244 1 r
.26784 .24568 m
.26465 .28874 L
s
.824 .204 1 r
.66506 .31141 m
.66468 .30192 L
s
.66468 .30192 m
.6651 .31091 L
s
.588 .259 1 r
.06234 .30928 m
.06359 .30051 L
s
.06359 .30051 m
.06241 .30927 L
s
.845 .199 1 r
.49515 .30283 m
.49505 .31227 L
s
.49512 .31193 m
.49515 .30283 L
s
.4 .312 1 r
.71053 .28216 m
.71097 .2905 L
s
.71099 .29046 m
.71053 .28216 L
s
.71053 .28216 m
.71147 .2984 L
s
.425 .304 1 r
.62343 .29576 m
.62367 .30417 L
s
.62372 .30372 m
.62343 .29576 L
s
.845 .199 1 r
.49505 .31227 m
.49517 .30278 L
s
.49517 .30278 m
.49512 .31193 L
s
.588 .259 1 r
.14605 .31355 m
.14597 .31367 L
s
.476 .29 1 r
.68488 .28368 m
.68526 .29222 L
s
.68529 .29217 m
.68488 .28368 L
s
.68488 .28368 m
.68572 .30042 L
s
.425 .304 1 r
.62367 .30417 m
.62345 .29571 L
s
.62345 .29571 m
.62372 .30372 L
s
.904 .186 1 r
.09934 .29018 m
.09808 .29964 L
s
.0981 .29959 m
.09934 .29018 L
s
.09934 .29018 m
.0969 .30914 L
s
.658 .242 1 r
.32017 .28669 m
.31958 .29565 L
s
.3196 .29561 m
.32017 .28669 L
s
.32017 .28669 m
.31908 .30446 L
s
.733 .224 1 r
.2074 .30171 m
.2065 .31085 L
s
.20659 .31066 m
.2074 .30171 L
s
.559 .267 1 r
.51536 .28461 m
.5153 .29337 L
s
.51532 .29333 m
.51536 .28461 L
s
.51536 .28461 m
.51533 .3018 L
s
.669 .239 1 r
.17629 .28606 m
.17531 .29509 L
s
.17532 .29505 m
.17629 .28606 L
s
.17629 .28606 m
.17443 .30382 L
s
.811 .206 1 r
.75075 .24541 m
.75412 .29036 L
s
.68 .237 1 r
.43735 .24541 m
.4364 .28886 L
s
.648 .244 1 r
.12394 .24541 m
.11874 .28923 L
s
.733 .224 1 r
.2065 .31085 m
.20741 .30166 L
s
.20741 .30166 m
.20659 .31066 L
s
.845 .199 1 r
.80857 .30342 m
.80938 .3128 L
s
.80943 .31268 m
.80857 .30342 L
s
.578 .262 1 r
.25869 .29918 m
.25797 .30794 L
s
.25804 .30775 m
.25869 .29918 L
s
.441 .3 1 r
.31001 .29635 m
.30945 .30477 L
s
.30953 .30447 m
.31001 .29635 L
s
.845 .199 1 r
.80938 .3128 m
.8086 .30338 L
s
.8086 .30338 m
.80943 .31268 L
s
.578 .262 1 r
.25797 .30794 m
.2587 .29914 L
s
.2587 .29914 m
.25804 .30775 L
s
.441 .3 1 r
.30945 .30477 m
.31002 .29631 L
s
.31002 .29631 m
.30953 .30447 L
s
.45 .297 1 r
.56207 .3085 m
.56202 .30894 L
s
.953 .176 1 r
.60794 .28858 m
.60815 .29826 L
s
.60817 .29822 m
.60794 .28858 L
s
.60794 .28858 m
.60844 .3076 L
s
.588 .259 1 r
.74168 .29862 m
.74226 .30746 L
s
.7423 .30712 m
.74168 .29862 L
s
.88 .191 1 r
.60689 .24514 m
.60828 .29085 L
s
.94 .179 1 r
.29344 .24514 m
.29028 .29273 L
s
.588 .259 1 r
.74226 .30746 m
.74171 .29858 L
s
.74171 .29858 m
.7423 .30712 L
s
.503 .282 1 r
.20189 .28517 m
.20103 .29367 L
s
.20104 .29363 m
.20189 .28517 L
s
.20189 .28517 m
.20024 .30217 L
s
1 .154 .933 r
.75185 .28951 m
.75249 .29942 L
s
.75252 .29937 m
.75185 .28951 L
s
.75185 .28951 m
.75322 .30899 L
s
.69 .234 1 r
.28984 .3153 m
.28977 .31535 L
s
.88 .191 1 r
.63361 .28762 m
.6339 .29714 L
s
.63392 .2971 m
.63361 .28762 L
s
.63361 .28762 m
.63426 .30633 L
s
.441 .3 1 r
.77649 .24487 m
.77986 .28569 L
s
.589 .259 1 r
.46299 .24487 m
.4624 .2872 L
s
.512 .279 1 r
.14949 .24487 m
.14485 .28682 L
s
.833 .201 1 r
.03772 .30346 m
.03632 .31276 L
s
.03639 .31279 m
.03772 .30346 L
s
.504 .282 1 r
.47955 .29639 m
.47942 .30503 L
s
.47949 .30458 m
.47955 .29639 L
s
.845 .199 1 r
.74726 .31631 m
.74722 .31666 L
s
.833 .201 1 r
.03632 .31276 m
.03773 .30341 L
s
.03773 .30341 m
.03639 .31279 L
s
.375 .532 1 r
.32555 .30507 m
.3255 .30492 L
s
.504 .282 1 r
.47942 .30503 m
.47957 .29635 L
s
.47957 .29635 m
.47949 .30458 L
s
.754 .219 1 r
.23295 .30149 m
.23212 .31067 L
s
.23221 .31052 m
.23295 .30149 L
s
.744 .221 1 r
.57214 .30008 m
.57227 .30933 L
s
.57233 .30887 m
.57214 .30008 L
s
.754 .219 1 r
.23212 .31067 m
.23297 .30144 L
s
.23297 .30144 m
.23221 .31052 L
s
.744 .221 1 r
.57227 .30933 m
.57217 .30003 L
s
.57217 .30003 m
.57233 .30887 L
s
.599 .257 1 r
.68035 .31152 m
.6803 .31189 L
s
.777 .214 1 r
.40254 .30093 m
.40219 .31023 L
s
.40227 .30988 m
.40254 .30093 L
s
.811 .206 1 r
.6593 .28665 m
.65965 .29602 L
s
.65967 .29598 m
.6593 .28665 L
s
.6593 .28665 m
.66008 .30506 L
s
.408 .31 1 r
.44382 .30735 m
.44375 .30772 L
s
.811 .206 1 r
.63259 .24461 m
.63431 .28957 L
s
.376 .32 1 r
.31905 .24461 m
.31678 .28355 L
s
.777 .214 1 r
.40219 .31023 m
.40256 .30088 L
s
.40256 .30088 m
.40227 .30988 L
s
.766 .217 1 r
.12019 .31669 m
.12012 .31666 L
s
.416 .307 1 r
.1092 .28256 m
.10812 .29087 L
s
.10813 .29083 m
.1092 .28256 L
s
.1092 .28256 m
.10714 .299 L
s
.569 .264 1 r
.22747 .28472 m
.22665 .29345 L
s
.22667 .2934 m
.22747 .28472 L
s
.22747 .28472 m
.22592 .30203 L
s
.536 1 .9 r
.48415 .27048 m
.48406 .27659 L
s
.48407 .27656 m
.48415 .27048 L
s
.48415 .27048 m
.48402 .28222 L
s
.522 .277 1 r
.16598 .29699 m
.16502 .30563 L
s
.16512 .30533 m
.16598 .29699 L
s
.45 .297 1 r
.58776 .30835 m
.58771 .30869 L
s
.522 .277 1 r
.16502 .30563 m
.16599 .29694 L
s
.16599 .29694 m
.16512 .30533 L
s
.428 .751 1 r
.80223 .24434 m
.80529 .27804 L
s
.845 .199 1 r
.48865 .24434 m
.48838 .28968 L
s
.701 .232 1 r
.17507 .24434 m
.17056 .28817 L
s
.531 .274 1 r
.41814 .30936 m
.41806 .30981 L
s
.868 .194 1 r
.26408 .31807 m
.26401 .31804 L
s
.416 .307 1 r
.10448 .30973 m
.10444 .30958 L
s
.733 .224 1 r
.11457 .30041 m
.11341 .30956 L
s
.1135 .30936 m
.11457 .30041 L
s
1 .138 .854 r
.6583 .24407 m
.66054 .29243 L
s
.648 .244 1 r
.34467 .24407 m
.3425 .28715 L
s
.733 .224 1 r
.11341 .30956 m
.11458 .30037 L
s
.11458 .30037 m
.1135 .30936 L
s
1 .146 .894 r
.1815 .30551 m
.18045 .31543 L
s
.18054 .3153 m
.1815 .30551 L
s
.18045 .31543 m
.18152 .30546 L
s
.18152 .30546 m
.18054 .3153 L
s
.434 .302 1 r
.70055 .29419 m
.701 .30265 L
s
.70103 .30216 m
.70055 .29419 L
s
.345 .33 1 r
.41259 .29278 m
.4123 .30092 L
s
.41237 .30051 m
.41259 .29278 L
s
.648 .244 1 r
.85007 .312 m
.85004 .31234 L
s
.434 .302 1 r
.701 .30265 m
.70057 .29415 L
s
.70057 .29415 m
.70103 .30216 L
s
.345 .33 1 r
.4123 .30092 m
.4126 .29274 L
s
.4126 .29274 m
.41237 .30051 L
s
.649 .244 1 r
.39244 .31137 m
.39236 .31182 L
s
.477 .289 1 r
.61346 .30784 m
.61341 .30828 L
s
.29981 .30783 m
.29972 .30828 L
s
.711 .229 1 r
.05772 .28646 m
.05641 .2955 L
s
.05642 .29545 m
.05772 .28646 L
s
.05772 .28646 m
.05517 .30454 L
s
.834 .201 1 r
.8547 .28579 m
.85562 .29524 L
s
.85565 .29519 m
.8547 .28579 L
s
.8547 .28579 m
.85659 .30428 L
s
.811 .206 1 r
.54104 .28586 m
.54106 .29524 L
s
.54108 .29519 m
.54104 .28586 L
s
.54104 .28586 m
.54116 .30428 L
s
.385 .574 1 r
.2842 .30013 m
.28411 .30061 L
s
.733 .224 1 r
.08338 .2852 m
.08212 .29438 L
s
.08213 .29434 m
.08338 .2852 L
s
.08338 .2852 m
.08097 .30327 L
s
.608 .254 1 r
.42272 .28378 m
.42242 .29267 L
s
.42244 .29262 m
.42272 .28378 L
s
.42272 .28378 m
.4222 .30125 L
s
1 .154 .934 r
.82799 .2438 m
.83276 .29217 L
s
.4 .312 1 r
.51432 .2438 m
.5144 .2835 L
s
.433 .302 1 r
.20065 .2438 m
.19678 .28463 L
s
.618 .252 1 r
.5924 .28315 m
.59256 .2921 L
s
.59258 .29206 m
.5924 .28315 L
s
.5924 .28315 m
.59279 .30061 L
s
.628 .249 1 r
.22275 .31238 m
.22267 .31253 L
s
.638 .247 1 r
.79321 .29818 m
.79394 .30713 L
s
.79397 .30683 m
.79321 .29818 L
s
.7 .232 1 r
.39704 .28531 m
.39666 .29438 L
s
.39668 .29434 m
.39704 .28531 L
s
.39704 .28531 m
.39637 .30327 L
s
.503 .282 1 r
.81889 .29676 m
.81965 .3053 L
s
.8197 .30518 m
.81889 .29676 L
s
.638 .247 1 r
.79394 .30713 m
.79324 .29814 L
s
.79324 .29814 m
.79397 .30683 L
s
.503 .282 1 r
.81965 .3053 m
.81891 .29672 L
s
.81891 .29672 m
.8197 .30518 L
s
.648 .244 1 r
.73641 .28397 m
.73696 .29296 L
s
.73698 .29292 m
.73641 .28397 L
s
.73641 .28397 m
.73757 .30162 L
s
.811 .206 1 r
.59786 .30045 m
.59806 .30982 L
s
.59811 .30948 m
.59786 .30045 L
s
.598 .257 1 r
.05302 .31338 m
.05298 .3132 L
s
.55 .269 1 r
.24841 .31112 m
.24834 .31119 L
s
.618 .252 1 r
.64922 .29762 m
.64955 .30653 L
s
.6496 .30619 m
.64922 .29762 L
s
.811 .206 1 r
.59806 .30982 m
.59788 .3004 L
s
.59788 .3004 m
.59811 .30948 L
s
.618 .252 1 r
.64955 .30653 m
.64924 .29758 L
s
.64924 .29758 m
.6496 .30619 L
s
.627 1 .715 r
.83361 .26127 m
.83411 .2667 L
s
.83412 .26667 m
.83361 .26127 L
s
.83361 .26127 m
.83454 .27083 L
s
.928 .181 1 r
.71618 .30272 m
.71674 .31229 L
s
.71679 .31213 m
.71618 .30272 L
s
.811 .206 1 r
.45385 .29989 m
.45364 .3093 L
s
.45371 .30885 m
.45385 .29989 L
s
.569 .264 1 r
.27409 .30985 m
.274 .31023 L
s
.868 .194 1 r
.31537 .31629 m
.31529 .31648 L
s
.733 .224 1 r
.25302 .28493 m
.25223 .29412 L
s
.25225 .29408 m
.25302 .28493 L
s
.25302 .28493 m
.25154 .30301 L
s
.928 .181 1 r
.71674 .31229 m
.71621 .30268 L
s
.71621 .30268 m
.71679 .31213 L
s
.777 .214 1 r
.68402 .24354 m
.68644 .28813 L
s
.929 .181 1 r
.37031 .24354 m
.36835 .28964 L
s
.811 .206 1 r
.45364 .3093 m
.45387 .29985 L
s
.45387 .29985 m
.45371 .30885 L
s
.88 .191 1 r
.48507 .31566 m
.485 .316 L
s
.628 .249 1 r
.07869 .31212 m
.0786 .31227 L
s
.777 .214 1 r
.56673 .28512 m
.56682 .29442 L
s
.56684 .29437 m
.56673 .28512 L
s
.56673 .28512 m
.56699 .30338 L
s
.846 .199 1 r
.51075 .31439 m
.51068 .31485 L
s
.521 .277 1 r
.19147 .29736 m
.19059 .30589 L
s
.19065 .30593 m
.19147 .29736 L
s
.19059 .30589 m
.19148 .29732 L
s
.19148 .29732 m
.19065 .30593 L
s
1 .138 .854 r
.86025 .30388 m
.86127 .31398 L
s
.86129 .31352 m
.86025 .30388 L
s
.367 .322 1 r
.16032 .28174 m
.15939 .28982 L
s
.1594 .28978 m
.16032 .28174 L
s
.16032 .28174 m
.15853 .29795 L
s
.456 .855 1 r
.31442 .27322 m
.31396 .28012 L
s
.31397 .28009 m
.31442 .27322 L
s
.31442 .27322 m
.31358 .28658 L
s
.618 .252 1 r
.44839 .28322 m
.44815 .29214 L
s
.44817 .2921 m
.44839 .28322 L
s
.44839 .28322 m
.448 .30072 L
s
.13464 .28322 m
.13355 .29214 L
s
.13356 .2921 m
.13464 .28322 L
s
.13464 .28322 m
.13258 .30072 L
s
1 .138 .854 r
.86127 .31398 m
.86028 .30383 L
s
.86028 .30383 m
.86129 .31352 L
s
.4 .312 1 r
.35111 .30605 m
.35103 .30639 L
s
.711 .229 1 r
.54001 .24327 m
.54044 .28711 L
s
.368 .497 1 r
.22625 .24327 m
.22292 .28147 L
s
.88 .191 1 r
.34103 .3154 m
.34094 .31574 L
s
.503 .282 1 r
.46946 .30832 m
.46939 .30866 L
s
1 .166 .996 r
.65481 .31577 m
.65477 .31639 L
s
.569 .264 1 r
.70976 .243 m
.71241 .28572 L
s
.618 .252 1 r
.39596 .243 m
.39448 .28572 L
s
.7 .232 1 r
.33546 .29881 m
.33493 .30788 L
s
.335 .30769 m
.33546 .29881 L
s
.55 .269 1 r
.36114 .2974 m
.3607 .30601 L
s
.36077 .30605 m
.36114 .2974 L
s
.467 .292 1 r
.07303 .29598 m
.07186 .30437 L
s
.07191 .3044 m
.07303 .29598 L
s
.7 .232 1 r
.33493 .30788 m
.33548 .29877 L
s
.33548 .29877 m
.335 .30769 L
s
.55 .269 1 r
.3607 .30601 m
.36116 .29735 L
s
.36116 .29735 m
.36077 .30605 L
s
.467 .292 1 r
.07186 .30437 m
.07304 .29594 L
s
.07304 .29594 m
.07191 .3044 L
s
.639 .247 1 r
.75758 .31034 m
.75755 .31075 L
s
.459 .294 1 r
.30429 .28326 m
.30371 .29158 L
s
.30372 .29154 m
.30429 .28326 L
s
.30429 .28326 m
.30318 .30009 L
s
.41 .683 1 r
.60251 .27541 m
.60266 .28273 L
s
.60268 .28269 m
.60251 .27541 L
s
.60251 .27541 m
.60287 .28972 L
s
.45 .297 1 r
.58229 .29401 m
.58243 .30246 L
s
.58248 .30212 m
.58229 .29401 L
s
.777 .214 1 r
.7622 .284 m
.76285 .29334 L
s
.76287 .29329 m
.7622 .284 L
s
.7622 .284 m
.76355 .30222 L
s
.45 .297 1 r
.58243 .30246 m
.58231 .29396 L
s
.58231 .29396 m
.58248 .30212 L
s
.433 .302 1 r
.81358 .28125 m
.81429 .2896 L
s
.81432 .28956 m
.81358 .28125 L
s
.81358 .28125 m
.81507 .2978 L
s
.953 .176 1 r
.82459 .31552 m
.82457 .31598 L
s
.57 .264 1 r
.56571 .24273 m
.56645 .28432 L
s
.39 .597 1 r
.25187 .24273 m
.24886 .28057 L
s
1 .146 .894 r
.42813 .3028 m
.42783 .31283 L
s
.42791 .31236 m
.42813 .3028 L
s
.42783 .31283 m
.42815 .30275 L
s
.42815 .30275 m
.42791 .31236 L
s
.45 .297 1 r
.52083 .30654 m
.52077 .30688 L
s
.486 .287 1 r
.43821 .29375 m
.43798 .30235 L
s
.43805 .30186 m
.43821 .29375 L
s
.588 .259 1 r
.78332 .30945 m
.78328 .30979 L
s
.486 .287 1 r
.43798 .30235 m
.43823 .2937 L
s
.43823 .2937 m
.43805 .30186 L
s
.48 .289 1 r
.69063 .3059 m
.6906 .30648 L
s
.477 .289 1 r
.73551 .24247 m
.73838 .28331 L
s
.589 .259 1 r
.42162 .24247 m
.42051 .28443 L
s
.344 .33 1 r
.10774 .24247 m
.10278 .28255 L
s
.569 .264 1 r
.12984 .31109 m
.12978 .31102 L
s
.744 .222 1 r
.675 .29829 m
.67542 .30752 L
s
.67547 .30717 m
.675 .29829 L
s
.628 .249 1 r
.47405 .28333 m
.47389 .29222 L
s
.47391 .29217 m
.47405 .28333 L
s
.47405 .28333 m
.4738 .30095 L
s
.744 .222 1 r
.67542 .30752 m
.67503 .29825 L
s
.67503 .29825 m
.67547 .30717 L
s
.588 .259 1 r
.18585 .28195 m
.18491 .29079 L
s
.18492 .29075 m
.18585 .28195 L
s
.18585 .28195 m
.18408 .2993 L
s
.424 .305 1 r
.38135 .27983 m
.38095 .28822 L
s
.38097 .28817 m
.38135 .27983 L
s
.38135 .27983 m
.38065 .29627 L
s
.777 .214 1 r
.78797 .28347 m
.78869 .29281 L
s
.78872 .29277 m
.78797 .28347 L
s
.78797 .28347 m
.78946 .3017 L
s
.834 .201 1 r
.61817 .28421 m
.61841 .29367 L
s
.61843 .29362 m
.61817 .28421 L
s
.61817 .28421 m
.61872 .30271 L
s
.701 .232 1 r
.59143 .2422 m
.59255 .28605 L
s
.777 .214 1 r
.2775 .2422 m
.27432 .2868 L
s
.744 .221 1 r
.53091 .29803 m
.53092 .30726 L
s
.53098 .30691 m
.53091 .29803 L
s
.701 .232 1 r
.21697 .29803 m
.21611 .3071 L
s
.21619 .30691 m
.21697 .29803 L
s
.372 .52 1 r
.14449 .27592 m
.14357 .28366 L
s
.14358 .28362 m
.14449 .27592 L
s
.14449 .27592 m
.14276 .29095 L
s
.744 .221 1 r
.53092 .30726 m
.53093 .29799 L
s
.53093 .29799 m
.53098 .30691 L
s
.701 .232 1 r
.21611 .3071 m
.21699 .29799 L
s
.21699 .29799 m
.21619 .30691 L
s
.754 .219 1 r
.04713 .29889 m
.04578 .30808 L
s
.04587 .30792 m
.04713 .29889 L
s
.04578 .30808 m
.04714 .29884 L
s
.04714 .29884 m
.04587 .30792 L
s
.68 .237 1 r
.76127 .24193 m
.76467 .28541 L
s
.559 .267 1 r
.4473 .24193 m
.44652 .2839 L
s
.513 .279 1 r
.13333 .24193 m
.12833 .28503 L
s
.618 .252 1 r
.55661 .29721 m
.55669 .30602 L
s
.55675 .30602 m
.55661 .29721 L
s
.45 .297 1 r
.0884 .30576 m
.08829 .3061 L
s
.618 .252 1 r
.55669 .30602 m
.55664 .29717 L
s
.55664 .29717 m
.55675 .30602 L
s
1 .149 .907 r
.27849 .28663 m
.27771 .29659 L
s
.27773 .29654 m
.27849 .28663 L
s
.27849 .28663 m
.27704 .30624 L
s
.54 .272 1 r
.12416 .29524 m
.12309 .30389 L
s
.12318 .30374 m
.12416 .29524 L
s
.845 .199 1 r
.61716 .24166 m
.61868 .28703 L
s
.869 .194 1 r
.30314 .24166 m
.30024 .28741 L
s
.54 .272 1 r
.12309 .30389 m
.12418 .29519 L
s
.12418 .29519 m
.12318 .30374 L
s
.953 .176 1 r
.50521 .30035 m
.50514 .31003 L
s
.50521 .30968 m
.50521 .30035 L
s
.845 .199 1 r
.84494 .29893 m
.84586 .30838 L
s
.84588 .30804 m
.84494 .29893 L
s
.7 .232 1 r
.2426 .29751 m
.24181 .30658 L
s
.24189 .30639 m
.2426 .29751 L
s
.648 .244 1 r
.26831 .2961 m
.26759 .30509 L
s
.26769 .30475 m
.26831 .2961 L
s
.953 .176 1 r
.50514 .31003 m
.50523 .3003 L
s
.50523 .3003 m
.50521 .30968 L
s
.376 .319 1 r
.37114 .29043 m
.37074 .29873 L
s
.37083 .29817 m
.37114 .29043 L
s
.845 .199 1 r
.84586 .30838 m
.84497 .29888 L
s
.84497 .29888 m
.84588 .30804 L
s
.7 .232 1 r
.24181 .30658 m
.24261 .29747 L
s
.24261 .29747 m
.24189 .30639 L
s
.648 .244 1 r
.26759 .30509 m
.26832 .29605 L
s
.26832 .29605 m
.26769 .30475 L
s
.376 .319 1 r
.37074 .29873 m
.37116 .29039 L
s
.37116 .29039 m
.37083 .29817 L
s
.531 .274 1 r
.77792 .29412 m
.77859 .30281 L
s
.77862 .30247 m
.77792 .29412 L
s
.701 .231 1 r
.52546 .28201 m
.52544 .29117 L
s
.52546 .29112 m
.52546 .28201 L
s
.52546 .28201 m
.52549 .2999 L
s
.531 .274 1 r
.77859 .30281 m
.77795 .29408 L
s
.77795 .29408 m
.77862 .30247 L
s
.88 .191 1 r
.64393 .28421 m
.64424 .29375 L
s
.64426 .2937 m
.64393 .28421 L
s
.64393 .28421 m
.64463 .30294 L
s
.869 .194 1 r
.32987 .28425 m
.32928 .29375 L
s
.3293 .2937 m
.32987 .28425 L
s
.32987 .28425 m
.32878 .30294 L
s
.928 .181 1 r
.78706 .24139 m
.79109 .28827 L
s
.649 .244 1 r
.473 .24139 m
.47253 .2845 L
s
.639 .247 1 r
.15894 .24139 m
.1542 .28526 L
s
.375 .32 1 r
.76786 .3036 m
.76783 .30394 L
s
.4 .312 1 r
.13974 .3036 m
.13962 .30405 L
s
.477 .289 1 r
.4327 .27889 m
.43243 .28747 L
s
.43245 .28742 m
.4327 .27889 L
s
.4327 .27889 m
.43225 .2956 L
s
.965 .174 1 r
.73208 .3146 m
.73204 .31499 L
s
.869 .194 1 r
.38673 .29897 m
.38632 .30846 L
s
.3864 .30815 m
.38673 .29897 L
s
.777 .214 1 r
.63932 .31106 m
.63927 .31152 L
s
.639 .247 1 r
.21136 .28258 m
.21048 .29147 L
s
.2105 .29142 m
.21136 .28258 L
s
.21136 .28258 m
.20969 .30028 L
s
.869 .194 1 r
.38632 .30846 m
.38675 .29892 L
s
.38675 .29892 m
.3864 .30815 L
s
.521 .277 1 r
.6429 .24113 m
.64464 .28311 L
s
.733 .224 1 r
.3288 .24112 m
.3263 .28612 L
s
.822 .204 1 r
.49975 .28414 m
.49964 .29349 L
s
.49967 .29344 m
.49975 .28414 L
s
.49975 .28414 m
.49963 .30268 L
s
.638 .247 1 r
.83496 .30916 m
.83493 .30946 L
s
.711 .229 1 r
.69538 .28205 m
.69583 .2912 L
s
.69585 .29116 m
.69538 .28205 L
s
.69538 .28205 m
.69634 .30002 L
s
.733 .224 1 r
.66966 .28351 m
.67003 .29263 L
s
.67006 .29258 m
.66966 .28351 L
s
.66966 .28351 m
.67049 .30167 L
s
.521 .277 1 r
.14974 .29501 m
.14874 .30355 L
s
.1488 .30359 m
.14974 .29501 L
s
.599 .257 1 r
.5769 .28 m
.57701 .28892 L
s
.57703 .28888 m
.5769 .28 L
s
.5769 .28 m
.5772 .29736 L
s
.588 .259 1 r
.54656 .30789 m
.5465 .30823 L
s
.521 .277 1 r
.14874 .30355 m
.14975 .29497 L
s
.14975 .29497 m
.1488 .30359 L
s
.881 .191 1 r
.35554 .28369 m
.35502 .29322 L
s
.35504 .29317 m
.35554 .28369 L
s
.35554 .28369 m
.3546 .30242 L
s
.578 .262 1 r
.29393 .29587 m
.29331 .30457 L
s
.29337 .3046 m
.29393 .29587 L
s
.536 1 .9 r
.48406 .27659 m
.48397 .28269 L
s
.48402 .28222 m
.48406 .27659 L
s
.425 .304 1 r
.62372 .30372 m
.62367 .30417 L
s
.648 .244 1 r
.81285 .24086 m
.81691 .28397 L
s
.49871 .24086 m
.49858 .28397 L
s
.701 .232 1 r
.18456 .24086 m
.18018 .28472 L
s
.578 .262 1 r
.29331 .30457 m
.29395 .29583 L
s
.29395 .29583 m
.29337 .3046 L
s
.536 1 .9 r
.48397 .28269 m
.48407 .27656 L
s
.48407 .27656 m
.48402 .28222 L
s
1 .141 .867 r
.70641 .31662 m
.70636 .31705 L
s
.589 .259 1 r
.48958 .2939 m
.48948 .30278 L
s
.48955 .30232 m
.48958 .2939 L
s
.559 .267 1 r
.80374 .2939 m
.80448 .30266 L
s
.80451 .30232 m
.80374 .2939 L
s
.589 .259 1 r
.48948 .30278 m
.4896 .29385 L
s
.4896 .29385 m
.48955 .30232 L
s
.559 .267 1 r
.80448 .30266 m
.80376 .29385 L
s
.80376 .29385 m
.80451 .30232 L
s
.811 .206 1 r
.83964 .28332 m
.8405 .29267 L
s
.84053 .29262 m
.83964 .28332 L
s
.83964 .28332 m
.84144 .30179 L
s
.4 .312 1 r
.71097 .2905 m
.71144 .29884 L
s
.71147 .2984 m
.71097 .2905 L
s
.71144 .29884 m
.71099 .29046 L
s
.71099 .29046 m
.71147 .2984 L
s
.81 .206 1 r
.72659 .29845 m
.72716 .30775 L
s
.72721 .30763 m
.72659 .29845 L
s
.57 .264 1 r
.82949 .29278 m
.83031 .30165 L
s
.83032 .30105 m
.82949 .29278 L
s
.559 .267 1 r
.74686 .27989 m
.74742 .28866 L
s
.74745 .28862 m
.74686 .27989 L
s
.74686 .27989 m
.74805 .2971 L
s
.81 .206 1 r
.72716 .30775 m
.72662 .2984 L
s
.72662 .2984 m
.72721 .30763 L
s
1 .146 .894 r
.66866 .24059 m
.67104 .28861 L
s
.766 .217 1 r
.35447 .24059 m
.35235 .28521 L
s
.57 .264 1 r
.83031 .30165 m
.82952 .29273 L
s
.82952 .29273 m
.83032 .30105 L
s
.88 .191 1 r
.15521 .31282 m
.1551 .31316 L
s
.669 .239 1 r
.06703 .28287 m
.06576 .2918 L
s
.06577 .29176 m
.06703 .28287 L
s
.06703 .28287 m
.06455 .30077 L
s
.588 .259 1 r
.06241 .30927 m
.06234 .30928 L
s
.559 .267 1 r
.34534 .29363 m
.34485 .3024 L
s
.34493 .30206 m
.34534 .29363 L
s
.476 .29 1 r
.68526 .29222 m
.68567 .30075 L
s
.68572 .30042 m
.68526 .29222 L
s
.777 .214 1 r
.55119 .28223 m
.55124 .29154 L
s
.55126 .29149 m
.55119 .28223 L
s
.55119 .28223 m
.55137 .30051 L
s
.559 .267 1 r
.34485 .3024 m
.34536 .29359 L
s
.34536 .29359 m
.34493 .30206 L
s
.476 .29 1 r
.68567 .30075 m
.68529 .29217 L
s
.68529 .29217 m
.68572 .30042 L
s
.701 .232 1 r
.09274 .28156 m
.09151 .29068 L
s
.09153 .29063 m
.09274 .28156 L
s
.09274 .28156 m
.0904 .2995 L
s
.441 .3 1 r
.30953 .30447 m
.30945 .30477 L
s
.824 .204 1 r
.6651 .31091 m
.66506 .31141 L
s
.627 1 .715 r
.83411 .2667 m
.83462 .27212 L
s
.83454 .27083 m
.83411 .2667 L
s
.83462 .27212 m
.83412 .26667 L
s
.83412 .26667 m
.83454 .27083 L
s
.57 .264 1 r
.83866 .24032 m
.84291 .28193 L
s
.628 .249 1 r
.52443 .24032 m
.52464 .28381 L
s
.69 .234 1 r
.2102 .24032 m
.20612 .28457 L
s
.559 .267 1 r
.5153 .29337 m
.51527 .30214 L
s
.51533 .3018 m
.5153 .29337 L
s
.845 .199 1 r
.49512 .31193 m
.49505 .31227 L
s
.559 .267 1 r
.51527 .30214 m
.51532 .29333 L
s
.51532 .29333 m
.51533 .3018 L
s
.834 .201 1 r
.23695 .28272 m
.23609 .29214 L
s
.23611 .29209 m
.23695 .28272 L
s
.23695 .28272 m
.23535 .30126 L
s
.658 .242 1 r
.31958 .29565 m
.31901 .30461 L
s
.31908 .30446 m
.31958 .29565 L
s
.578 .262 1 r
.25804 .30775 m
.25797 .30794 L
s
.733 .224 1 r
.20659 .31066 m
.2065 .31085 L
s
.658 .242 1 r
.31901 .30461 m
.3196 .29561 L
s
.3196 .29561 m
.31908 .30446 L
s
.588 .259 1 r
.7423 .30712 m
.74226 .30746 L
s
.521 .277 1 r
.11839 .28071 m
.1173 .28926 L
s
.11731 .28921 m
.11839 .28071 L
s
.11839 .28071 m
.11628 .29784 L
s
.669 .239 1 r
.17531 .29509 m
.17433 .30413 L
s
.17443 .30382 m
.17531 .29509 L
s
.503 .282 1 r
.20103 .29367 m
.20017 .30217 L
s
.20024 .30217 m
.20103 .29367 L
s
.45 .297 1 r
.79838 .27795 m
.79906 .28642 L
s
.79908 .28637 m
.79838 .27795 L
s
.79838 .27795 m
.79979 .29455 L
s
1 .118 .745 r
.69443 .24005 m
.6973 .28996 L
s
.416 .307 1 r
.38016 .24005 m
.37857 .28016 L
s
.669 .239 1 r
.17433 .30413 m
.17532 .29505 L
s
.17532 .29505 m
.17443 .30382 L
s
.503 .282 1 r
.20017 .30217 m
.20104 .29363 L
s
.20104 .29363 m
.20024 .30217 L
s
.504 .282 1 r
.47949 .30458 m
.47942 .30503 L
s
.904 .186 1 r
.09808 .29964 m
.09684 .30911 L
s
.0969 .30914 m
.09808 .29964 L
s
.09684 .30911 m
.0981 .29959 L
s
.0981 .29959 m
.0969 .30914 L
s
.845 .199 1 r
.80943 .31268 m
.80938 .3128 L
s
.531 .274 1 r
.55016 .23978 m
.5507 .2814 L
s
.345 .39 1 r
.23585 .23978 m
.23253 .27914 L
s
.54 .272 1 r
.45837 .2801 m
.45816 .28873 L
s
.45818 .28869 m
.45837 .2801 L
s
.45837 .2801 m
.45804 .29732 L
s
.416 .307 1 r
.10812 .29087 m
.10705 .29918 L
s
.10714 .299 m
.10812 .29087 L
s
.434 .302 1 r
.67988 .27656 m
.68025 .28503 L
s
.68028 .28499 m
.67988 .27656 L
s
.67988 .27656 m
.68068 .29301 L
s
.799 .209 1 r
.2626 .2823 m
.26182 .29161 L
s
.26184 .29157 m
.2626 .2823 L
s
.2626 .2823 m
.26115 .30074 L
s
.416 .307 1 r
.10705 .29918 m
.10813 .29083 L
s
.10813 .29083 m
.10714 .299 L
s
.744 .222 1 r
.72022 .23951 m
.72316 .28452 L
s
.45 .297 1 r
.40586 .23951 m
.40458 .28 L
s
.744 .221 1 r
.57233 .30887 m
.57227 .30933 L
s
.522 .277 1 r
.16512 .30533 m
.16502 .30563 L
s
.81 .206 1 r
.4069 .28319 m
.40653 .29247 L
s
.40655 .29243 m
.4069 .28319 L
s
.4069 .28319 m
.40625 .30175 L
s
.953 .176 1 r
.60815 .29826 m
.60839 .30795 L
s
.60844 .3076 m
.60815 .29826 L
s
.60839 .30795 m
.60817 .29822 L
s
.60817 .29822 m
.60844 .3076 L
s
.754 .219 1 r
.23221 .31052 m
.23212 .31067 L
s
.345 .33 1 r
.41237 .30051 m
.4123 .30092 L
s
.659 .242 1 r
.2883 .28126 m
.28763 .29019 L
s
.28764 .29014 m
.2883 .28126 L
s
.2883 .28126 m
.28704 .29908 L
s
.569 .264 1 r
.22665 .29345 m
.22585 .30218 L
s
.22592 .30203 m
.22665 .29345 L
s
.777 .214 1 r
.40227 .30988 m
.40219 .31023 L
s
.569 .264 1 r
.22585 .30218 m
.22667 .2934 L
s
.22667 .2934 m
.22592 .30203 L
s
.833 .201 1 r
.03639 .31279 m
.03632 .31276 L
s
.88 .191 1 r
.6339 .29714 m
.63421 .30668 L
s
.63426 .30633 m
.6339 .29714 L
s
.434 .302 1 r
.70103 .30216 m
.701 .30265 L
s
.88 .191 1 r
.63421 .30668 m
.63392 .2971 L
s
.63392 .2971 m
.63426 .30633 L
s
.46 .294 1 r
.57591 .23925 m
.57676 .27936 L
s
.822 .204 1 r
.26151 .23925 m
.25792 .28614 L
s
1 .154 .933 r
.75249 .29942 m
.75318 .30934 L
s
.75322 .30899 m
.75249 .29942 L
s
.456 .855 1 r
.31396 .28012 m
.3135 .28702 L
s
.31358 .28658 m
.31396 .28012 L
s
1 .154 .933 r
.75318 .30934 m
.75252 .29937 L
s
.75252 .29937 m
.75322 .30899 L
s
.456 .855 1 r
.3135 .28702 m
.31397 .28009 L
s
.31397 .28009 m
.31358 .28658 L
s
.811 .206 1 r
.65965 .29602 m
.66003 .30541 L
s
.66008 .30506 m
.65965 .29602 L
s
.66003 .30541 m
.65967 .29598 L
s
.65967 .29598 m
.66008 .30506 L
s
.598 .257 1 r
.16966 .27969 m
.16867 .28851 L
s
.16869 .28846 m
.16966 .27969 L
s
.16966 .27969 m
.16778 .29717 L
s
.531 .274 1 r
.74602 .23898 m
.74905 .28022 L
s
.36 .325 1 r
.43157 .23898 m
.43065 .27797 L
s
.425 .305 1 r
.11712 .23898 m
.11228 .27909 L
s
.845 .199 1 r
.77282 .28136 m
.7735 .29083 L
s
.77353 .29078 m
.77282 .28136 L
s
.77282 .28136 m
.77426 .29995 L
s
.777 .214 1 r
.62846 .28066 m
.62872 .28997 L
s
.62875 .28992 m
.62846 .28066 L
s
.62846 .28066 m
.62906 .29894 L
s
.531 .274 1 r
.36548 .27782 m
.36503 .28652 L
s
.36505 .28648 m
.36548 .27782 L
s
.36548 .27782 m
.36467 .29488 L
s
.733 .224 1 r
.1135 .30936 m
.11341 .30956 L
s
.503 .282 1 r
.8197 .30518 m
.81965 .3053 L
s
.608 .254 1 r
.50984 .27879 m
.50977 .28768 L
s
.50979 .28764 m
.50984 .27879 L
s
.50984 .27879 m
.50978 .29627 L
s
.589 .259 1 r
.60168 .23871 m
.6029 .28108 L
s
.765 .217 1 r
.28719 .23871 m
.28411 .28372 L
s
.541 .272 1 r
.22108 .27752 m
.22024 .28626 L
s
.22026 .28622 m
.22108 .27752 L
s
.22108 .27752 m
.21952 .29462 L
s
.638 .247 1 r
.79397 .30683 m
.79394 .30713 L
s
.711 .229 1 r
.65422 .27968 m
.65455 .28884 L
s
.65458 .2888 m
.65422 .27968 L
s
.65422 .27968 m
.65496 .29766 L
s
.05641 .2955 m
.0551 .30454 L
s
.05517 .30454 m
.05641 .2955 L
s
.618 .252 1 r
.6496 .30619 m
.64955 .30653 L
s
.608 .254 1 r
.42242 .29267 m
.42213 .30155 L
s
.4222 .30125 m
.42242 .29267 L
s
.367 .322 1 r
.15939 .28982 m
.15848 .29791 L
s
.15853 .29795 m
.15939 .28982 L
s
.711 .229 1 r
.0551 .30454 m
.05642 .29545 L
s
.05642 .29545 m
.05517 .30454 L
s
.608 .254 1 r
.42213 .30155 m
.42244 .29262 L
s
.42244 .29262 m
.4222 .30125 L
s
.41 .683 1 r
.60266 .28273 m
.60283 .29005 L
s
.60287 .28972 m
.60266 .28273 L
s
.367 .322 1 r
.15848 .29791 m
.1594 .28978 L
s
.1594 .28978 m
.15853 .29795 L
s
.658 .242 1 r
.3397 .27987 m
.33917 .28884 L
s
.33918 .2888 m
.3397 .27987 L
s
.3397 .27987 m
.33872 .29766 L
s
.618 .252 1 r
.59256 .2921 m
.59274 .30106 L
s
.59279 .30061 m
.59256 .2921 L
s
.41 .683 1 r
.60283 .29005 m
.60268 .28269 L
s
.60268 .28269 m
.60287 .28972 L
s
.486 .287 1 r
.77183 .23844 m
.77511 .27856 L
s
.733 .224 1 r
.4573 .23844 m
.4566 .28271 L
s
.569 .264 1 r
.14276 .23844 m
.1378 .28233 L
s
.618 .252 1 r
.59274 .30106 m
.59258 .29206 L
s
.59258 .29206 m
.59279 .30061 L
s
.733 .224 1 r
.08212 .29438 m
.08086 .30358 L
s
.08097 .30327 m
.08212 .29438 L
s
.7 .232 1 r
.39666 .29438 m
.39629 .30346 L
s
.39637 .30327 m
.39666 .29438 L
s
.648 .244 1 r
.73696 .29296 m
.73753 .30196 L
s
.73757 .30162 m
.73696 .29296 L
s
.733 .224 1 r
.08086 .30358 m
.08213 .29434 L
s
.08213 .29434 m
.08097 .30327 L
s
.7 .232 1 r
.39629 .30346 m
.39668 .29434 L
s
.39668 .29434 m
.39637 .30327 L
s
.648 .244 1 r
.73753 .30196 m
.73698 .29292 L
s
.73698 .29292 m
.73757 .30162 L
s
.811 .206 1 r
.59811 .30948 m
.59806 .30982 L
s
.54106 .29524 m
.5411 .30463 L
s
.54116 .30428 m
.54106 .29524 L
s
.834 .201 1 r
.85562 .29524 m
.85657 .3047 L
s
.85659 .30428 m
.85562 .29524 L
s
.521 .277 1 r
.19065 .30593 m
.19059 .30589 L
s
.344 .33 1 r
.41693 .27592 m
.41664 .28398 L
s
.41666 .28394 m
.41693 .27592 L
s
.41693 .27592 m
.41642 .29196 L
s
.811 .206 1 r
.45371 .30885 m
.45364 .3093 L
s
.504 .282 1 r
.07662 .27741 m
.07542 .286 L
s
.07543 .28595 m
.07662 .27741 L
s
.07662 .27741 m
.07432 .29436 L
s
.811 .206 1 r
.5411 .30463 m
.54108 .29519 L
s
.54108 .29519 m
.54116 .30428 L
s
.834 .201 1 r
.85657 .3047 m
.85565 .29519 L
s
.85565 .29519 m
.85659 .30428 L
s
1 .146 .894 r
.18054 .3153 m
.18045 .31543 L
s
.362 .473 1 r
.32403 .27241 m
.32353 .28027 L
s
.32354 .28023 m
.32403 .27241 L
s
.32403 .27241 m
.32312 .28764 L
s
.744 .222 1 r
.82442 .27964 m
.82523 .28888 L
s
.82526 .28883 m
.82442 .27964 L
s
.82442 .27964 m
.8261 .29778 L
s
.352 .327 1 r
.62746 .23817 m
.6289 .27717 L
s
.916 .184 1 r
.31288 .23817 m
.31004 .28508 L
s
.733 .224 1 r
.25223 .29412 m
.25145 .30332 L
s
.25154 .30301 m
.25223 .29412 L
s
.608 .254 1 r
.19525 .2798 m
.19434 .28858 L
s
.19435 .28853 m
.19525 .2798 L
s
.19525 .2798 m
.1935 .2974 L
s
.733 .224 1 r
.25145 .30332 m
.25225 .29408 L
s
.25225 .29408 m
.25154 .30301 L
s
.618 .252 1 r
.44815 .29214 m
.44793 .30106 L
s
.448 .30072 m
.44815 .29214 L
s
.13355 .29214 m
.13247 .30106 L
s
.13258 .30072 m
.13355 .29214 L
s
.66 .241 1 r
.70578 .27781 m
.70625 .28689 L
s
.70628 .28685 m
.70578 .27781 L
s
.70578 .27781 m
.70678 .29548 L
s
.928 .181 1 r
.71679 .31213 m
.71674 .31229 L
s
.45 .297 1 r
.58248 .30212 m
.58243 .30246 L
s
.618 .252 1 r
.44793 .30106 m
.44817 .2921 L
s
.44817 .2921 m
.448 .30072 L
s
.13247 .30106 m
.13356 .2921 L
s
.13356 .2921 m
.13258 .30072 L
s
.777 .214 1 r
.56682 .29442 m
.56693 .30373 L
s
.56699 .30338 m
.56682 .29442 L
s
.467 .292 1 r
.07191 .3044 m
.07186 .30437 L
s
.459 .294 1 r
.30371 .29158 m
.30313 .2999 L
s
.30318 .30009 m
.30371 .29158 L
s
.628 .249 1 r
.79766 .2379 m
.80155 .28142 L
s
.799 .209 1 r
.48304 .2379 m
.48269 .2833 L
s
.66 .241 1 r
.16842 .2379 m
.16393 .28066 L
s
.777 .214 1 r
.56693 .30373 m
.56684 .29437 L
s
.56684 .29437 m
.56699 .30338 L
s
.627 1 .715 r
.83454 .27083 m
.83462 .27212 L
s
.459 .294 1 r
.30313 .2999 m
.30372 .29154 L
s
.30372 .29154 m
.30318 .30009 L
s
.433 .302 1 r
.81429 .2896 m
.81502 .29795 L
s
.81507 .2978 m
.81429 .2896 L
s
.55 .269 1 r
.36077 .30605 m
.3607 .30601 L
s
.433 .302 1 r
.81502 .29795 m
.81432 .28956 L
s
.81432 .28956 m
.81507 .2978 L
s
.486 .287 1 r
.43805 .30186 m
.43798 .30235 L
s
.669 .239 1 r
.85025 .27904 m
.85111 .28805 L
s
.85114 .28801 m
.85025 .27904 L
s
.85025 .27904 m
.85205 .29687 L
s
.7 .232 1 r
.335 .30769 m
.33493 .30788 L
s
.744 .222 1 r
.5356 .27912 m
.5356 .28835 L
s
.53563 .28831 m
.5356 .27912 L
s
.5356 .27912 m
.53569 .29725 L
s
.522 .277 1 r
.24669 .27774 m
.24593 .28633 L
s
.24595 .28629 m
.24669 .27774 L
s
.24669 .27774 m
.24526 .29485 L
s
.977 .171 1 r
.65325 .23763 m
.65535 .28455 L
s
.441 .3 1 r
.33859 .23763 m
.33644 .27851 L
s
1 .138 .854 r
.86129 .31352 m
.86127 .31398 L
s
.372 .52 1 r
.14357 .28366 m
.14265 .2914 L
s
.14276 .29095 m
.14357 .28366 L
s
.536 1 .9 r
.48402 .28222 m
.48397 .28269 L
s
.372 .52 1 r
.14265 .2914 m
.14358 .28362 L
s
.14358 .28362 m
.14276 .29095 L
s
.55 .269 1 r
.73159 .27736 m
.73211 .28607 L
s
.73214 .28602 m
.73159 .27736 L
s
.73159 .27736 m
.73271 .29458 L
s
.424 .305 1 r
.38095 .28822 m
.38057 .2966 L
s
.38065 .29627 m
.38095 .28822 L
s
.99 .169 1 r
.82351 .23736 m
.82808 .28428 L
s
.494 .284 1 r
.5088 .23736 m
.5088 .28013 L
s
.352 .327 1 r
.19409 .23736 m
.1903 .27637 L
s
.424 .305 1 r
.38057 .2966 m
.38097 .28817 L
s
.38097 .28817 m
.38065 .29627 L
s
.744 .221 1 r
.56138 .27825 m
.56145 .28753 L
s
.56147 .28748 m
.56138 .27825 L
s
.56138 .27825 m
.5616 .29635 L
s
.777 .214 1 r
.76285 .29334 m
.76352 .30268 L
s
.76355 .30222 m
.76285 .29334 L
s
.76352 .30268 m
.76287 .29329 L
s
.76287 .29329 m
.76355 .30222 L
s
.531 .274 1 r
.44266 .27624 m
.44241 .28494 L
s
.44243 .2849 m
.44266 .27624 L
s
.44266 .27624 m
.44225 .29331 L
s
.744 .222 1 r
.67547 .30717 m
.67542 .30752 L
s
.628 .249 1 r
.47389 .29222 m
.47374 .30111 L
s
.4738 .30095 m
.47389 .29222 L
s
.588 .259 1 r
.18491 .29079 m
.18398 .29964 L
s
.18408 .2993 m
.18491 .29079 L
s
.711 .229 1 r
.67906 .23709 m
.68138 .28099 L
s
.669 .239 1 r
.36431 .23709 m
.36237 .28062 L
s
.628 .249 1 r
.47374 .30111 m
.47391 .29217 L
s
.47391 .29217 m
.4738 .30095 L
s
.588 .259 1 r
.18398 .29964 m
.18492 .29075 L
s
.18492 .29075 m
.18408 .2993 L
s
1 .146 .894 r
.42791 .31236 m
.42783 .31283 L
s
.376 .319 1 r
.37083 .29817 m
.37074 .29873 L
s
.588 .259 1 r
.10209 .27822 m
.10094 .28696 L
s
.10095 .28692 m
.10209 .27822 L
s
.10209 .27822 m
.09985 .29571 L
s
.744 .221 1 r
.53098 .30691 m
.53092 .30726 L
s
.701 .232 1 r
.21619 .30691 m
.21611 .3071 L
s
1 .159 .96 r
.53457 .23682 m
.53496 .28488 L
s
.384 .317 1 r
.21977 .23682 m
.21605 .27846 L
s
.777 .214 1 r
.78869 .29281 m
.78944 .30216 L
s
.78946 .3017 m
.78869 .29281 L
s
.56 .267 1 r
.78322 .2756 m
.78388 .28442 L
s
.78391 .28437 m
.78322 .2756 L
s
.78322 .2756 m
.7846 .29278 L
s
.777 .214 1 r
.78944 .30216 m
.78872 .29277 L
s
.78872 .29277 m
.78946 .3017 L
s
.904 .186 1 r
.3911 .28 m
.39068 .28959 L
s
.3907 .28954 m
.3911 .28 L
s
.3911 .28 m
.39035 .29887 L
s
.34 .366 1 r
.34965 .27355 m
.3492 .28153 L
s
.34922 .28149 m
.34965 .27355 L
s
.34965 .27355 m
.34883 .28937 L
s
.754 .219 1 r
.04587 .30792 m
.04578 .30808 L
s
.834 .201 1 r
.61841 .29367 m
.61867 .30314 L
s
.61872 .30271 m
.61841 .29367 L
s
.522 .277 1 r
.46841 .27575 m
.46823 .28442 L
s
.46825 .28437 m
.46841 .27575 L
s
.46841 .27575 m
.46814 .29278 L
s
.834 .201 1 r
.61867 .30314 m
.61843 .29362 L
s
.61843 .29362 m
.61872 .30271 L
s
.54 .272 1 r
.12318 .30374 m
.12309 .30389 L
s
.531 .274 1 r
.70488 .23655 m
.70741 .2782 L
s
.68 .237 1 r
.39004 .23655 m
.38844 .28046 L
s
.618 .252 1 r
.55675 .30602 m
.55669 .30602 L
s
.531 .274 1 r
.77862 .30247 m
.77859 .30281 L
s
.648 .244 1 r
.26769 .30475 m
.26759 .30509 L
s
.425 .305 1 r
.6645 .27403 m
.66483 .28243 L
s
.66485 .28239 m
.6645 .27403 L
s
.6645 .27403 m
.66522 .29049 L
s
.669 .239 1 r
.12776 .27772 m
.12664 .28674 L
s
.12665 .28669 m
.12776 .27772 L
s
.12776 .27772 m
.12561 .29556 L
s
.35 .414 1 r
.40118 .27131 m
.40086 .27928 L
s
.40087 .27924 m
.40118 .27131 L
s
.40118 .27131 m
.40062 .28681 L
s
.7 .232 1 r
.24189 .30639 m
.24181 .30658 L
s
.649 .244 1 r
.56035 .23628 m
.56105 .27906 L
s
.67 .239 1 r
.24547 .23628 m
.24177 .2817 L
s
.845 .199 1 r
.84588 .30804 m
.84586 .30838 L
s
.477 .289 1 r
.43243 .28747 m
.43218 .29605 L
s
.43225 .2956 m
.43243 .28747 L
s
.799 .209 1 r
.58718 .27888 m
.58733 .2882 L
s
.58735 .28815 m
.58718 .27888 L
s
.58718 .27888 m
.58756 .29733 L
s
.953 .176 1 r
.50521 .30968 m
.50514 .31003 L
s
.477 .289 1 r
.43218 .29605 m
.43245 .28742 L
s
.43245 .28742 m
.43225 .2956 L
s
.701 .231 1 r
.52544 .29117 m
.52543 .30032 L
s
.52549 .2999 m
.52544 .29117 L
s
.733 .224 1 r
.61297 .27757 m
.61318 .28677 L
s
.61321 .28673 m
.61297 .27757 L
s
.61297 .27757 m
.61348 .29568 L
s
.789 .211 1 r
.73071 .23601 m
.73377 .2803 L
s
.618 .252 1 r
.41579 .23601 m
.41458 .27842 L
s
.701 .231 1 r
.52543 .30032 m
.52546 .29112 L
s
.52546 .29112 m
.52549 .2999 L
s
.4 .312 1 r
.71147 .2984 m
.71144 .29884 L
s
.522 .277 1 r
.17924 .27555 m
.1783 .28419 L
s
.17831 .28414 m
.17924 .27555 L
s
.17924 .27555 m
.17746 .29263 L
s
.639 .247 1 r
.21048 .29147 m
.20961 .30036 L
s
.20969 .30028 m
.21048 .29147 L
s
.521 .277 1 r
.1488 .30359 m
.14874 .30355 L
s
.639 .247 1 r
.20961 .30036 m
.2105 .29142 L
s
.2105 .29142 m
.20969 .30028 L
s
1 .149 .907 r
.27771 .29659 m
.27694 .30656 L
s
.27704 .30624 m
.27771 .29659 L
s
.869 .194 1 r
.32928 .29375 m
.3287 .30325 L
s
.32878 .30294 m
.32928 .29375 L
s
.88 .191 1 r
.64424 .29375 m
.64458 .30329 L
s
.64463 .30294 m
.64424 .29375 L
s
.589 .259 1 r
.48955 .30232 m
.48948 .30278 L
s
.559 .267 1 r
.80451 .30232 m
.80448 .30266 L
s
1 .149 .907 r
.27694 .30656 m
.27773 .29654 L
s
.27773 .29654 m
.27704 .30624 L
s
.486 .956 1 r
.38548 .2644 m
.38517 .271 L
s
.38519 .27097 m
.38548 .2644 L
s
.38548 .2644 m
.38495 .27717 L
s
.869 .194 1 r
.3287 .30325 m
.3293 .2937 L
s
.3293 .2937 m
.32878 .30294 L
s
.88 .191 1 r
.64458 .30329 m
.64426 .2937 L
s
.64426 .2937 m
.64463 .30294 L
s
.352 .327 1 r
.58615 .23574 m
.58709 .27439 L
s
.788 .212 1 r
.27118 .23574 m
.26785 .28117 L
s
.541 .272 1 r
.15341 .27735 m
.15241 .28591 L
s
.15242 .28587 m
.15341 .27735 L
s
.15341 .27735 m
.15146 .29466 L
s
.869 .194 1 r
.3864 .30815 m
.38632 .30846 L
s
.578 .262 1 r
.29337 .3046 m
.29331 .30457 L
s
.599 .257 1 r
.57701 .28892 m
.57715 .29785 L
s
.5772 .29736 m
.57701 .28892 L
s
.57 .264 1 r
.83032 .30105 m
.83031 .30165 L
s
.599 .257 1 r
.57715 .29785 m
.57703 .28888 L
s
.57703 .28888 m
.5772 .29736 L
s
.476 .29 1 r
.68572 .30042 m
.68567 .30075 L
s
.733 .224 1 r
.67003 .29263 m
.67043 .30175 L
s
.67049 .30167 m
.67003 .29263 L
s
.711 .229 1 r
.69583 .2912 m
.6963 .30036 L
s
.69634 .30002 m
.69583 .2912 L
s
.733 .224 1 r
.67043 .30175 m
.67006 .29258 L
s
.67006 .29258 m
.67049 .30167 L
s
.711 .229 1 r
.6963 .30036 m
.69585 .29116 L
s
.69585 .29116 m
.69634 .30002 L
s
.822 .204 1 r
.49964 .29349 m
.49956 .30284 L
s
.49963 .30268 m
.49964 .29349 L
s
.953 .176 1 r
.75761 .27913 m
.75826 .28883 L
s
.75829 .28878 m
.75761 .27913 L
s
.75761 .27913 m
.75899 .29819 L
s
.68 .237 1 r
.80918 .2763 m
.80994 .28538 L
s
.80997 .28534 m
.80918 .2763 L
s
.80918 .2763 m
.81076 .29413 L
s
.559 .267 1 r
.34493 .30206 m
.34485 .3024 L
s
.503 .282 1 r
.69036 .27417 m
.69077 .2828 L
s
.69079 .28275 m
.69036 .27417 L
s
.69036 .27417 m
.69124 .29109 L
s
.822 .204 1 r
.49956 .30284 m
.49967 .29344 L
s
.49967 .29344 m
.49963 .30268 L
s
.766 .216 1 r
.75656 .23547 m
.75999 .28015 L
s
.438 .79 1 r
.44155 .23547 m
.44088 .26849 L
s
.54 .272 1 r
.12654 .23547 m
.12153 .27788 L
s
.559 .267 1 r
.74742 .28866 m
.74802 .29744 L
s
.74805 .2971 m
.74742 .28866 L
s
.74802 .29744 m
.74745 .28862 L
s
.74745 .28862 m
.74805 .2971 L
s
.766 .217 1 r
.6388 .27727 m
.63909 .28655 L
s
.63911 .2865 m
.6388 .27727 L
s
.6388 .27727 m
.63946 .29553 L
s
.456 .855 1 r
.31358 .28658 m
.3135 .28702 L
s
.41 .683 1 r
.33387 .26801 m
.33342 .27534 L
s
.33343 .2753 m
.33387 .26801 L
s
.33387 .26801 m
.33305 .28234 L
s
.881 .191 1 r
.35502 .29322 m
.35451 .30277 L
s
.3546 .30242 m
.35502 .29322 L
s
.669 .239 1 r
.06576 .2918 m
.06449 .30074 L
s
.06455 .30077 m
.06576 .2918 L
s
.744 .222 1 r
.49418 .27674 m
.49406 .28598 L
s
.49408 .28594 m
.49418 .27674 L
s
.49418 .27674 m
.49403 .29489 L
s
.559 .267 1 r
.51533 .3018 m
.51527 .30214 L
s
.608 .254 1 r
.20491 .27536 m
.20401 .28426 L
s
.20403 .28421 m
.20491 .27536 L
s
.20491 .27536 m
.20322 .29286 L
s
.881 .191 1 r
.35451 .30277 m
.35504 .29317 L
s
.35504 .29317 m
.3546 .30242 L
s
.61197 .2352 m
.61343 .28063 L
s
.69 .234 1 r
.29691 .2352 m
.29401 .2795 L
s
.669 .239 1 r
.06449 .30074 m
.06577 .29176 L
s
.06577 .29176 m
.06455 .30077 L
s
.81 .206 1 r
.72721 .30763 m
.72716 .30775 L
s
.811 .206 1 r
.8405 .29267 m
.8414 .30202 L
s
.84144 .30179 m
.8405 .29267 L
s
.8414 .30202 m
.84053 .29262 L
s
.84053 .29262 m
.84144 .30179 L
s
.701 .232 1 r
.09151 .29068 m
.09029 .2998 L
s
.0904 .2995 m
.09151 .29068 L
s
.521 .277 1 r
.1173 .28926 m
.11622 .29781 L
s
.11628 .29784 m
.1173 .28926 L
s
.45 .297 1 r
.79906 .28642 m
.79976 .29488 L
s
.79979 .29455 m
.79906 .28642 L
s
.701 .232 1 r
.09029 .2998 m
.09153 .29063 L
s
.09153 .29063 m
.0904 .2995 L
s
.521 .277 1 r
.11622 .29781 m
.11731 .28921 L
s
.11731 .28921 m
.11628 .29784 L
s
.503 .282 1 r
.20024 .30217 m
.20017 .30217 L
s
.45 .297 1 r
.79976 .29488 m
.79908 .28637 L
s
.79908 .28637 m
.79979 .29455 L
s
.777 .214 1 r
.55124 .29154 m
.5513 .30085 L
s
.55137 .30051 m
.55124 .29154 L
s
.799 .209 1 r
.78243 .23494 m
.78634 .28112 L
s
.467 .292 1 r
.46733 .23493 m
.46681 .27584 L
s
.638 .247 1 r
.15223 .23493 m
.14743 .27848 L
s
.658 .242 1 r
.31908 .30446 m
.31901 .30461 L
s
.777 .214 1 r
.5513 .30085 m
.55126 .29149 L
s
.55126 .29149 m
.55137 .30051 L
s
.905 .186 1 r
.27212 .28089 m
.27136 .2903 L
s
.27138 .29025 m
.27212 .28089 L
s
.27212 .28089 m
.27067 .29996 L
s
.669 .239 1 r
.17443 .30382 m
.17433 .30413 L
s
.638 .247 1 r
.37531 .27532 m
.37487 .28429 L
s
.37488 .28425 m
.37531 .27532 L
s
.37531 .27532 m
.37452 .29297 L
s
.416 .307 1 r
.10714 .299 m
.10705 .29918 L
s
.767 .216 1 r
.63779 .23466 m
.63957 .27896 L
s
.904 .186 1 r
.32265 .23466 m
.32 .28085 L
s
.834 .201 1 r
.23609 .29214 m
.23525 .30157 L
s
.23535 .30126 m
.23609 .29214 L
s
.434 .302 1 r
.68025 .28503 m
.68065 .2935 L
s
.68068 .29301 m
.68025 .28503 L
s
.834 .201 1 r
.23525 .30157 m
.23611 .29209 L
s
.23611 .29209 m
.23535 .30126 L
s
.434 .302 1 r
.68065 .2935 m
.68028 .28499 L
s
.68028 .28499 m
.68068 .29301 L
s
.54 .272 1 r
.45816 .28873 m
.45798 .29736 L
s
.45804 .29732 m
.45816 .28873 L
s
.45798 .29736 m
.45818 .28869 L
s
.45818 .28869 m
.45804 .29732 L
s
.669 .239 1 r
.54577 .27528 m
.5458 .28433 L
s
.54582 .28428 m
.54577 .27528 L
s
.54577 .27528 m
.54591 .29308 L
s
.88 .191 1 r
.80831 .2344 m
.81256 .28021 L
s
.711 .229 1 r
.49312 .23439 m
.49292 .27832 L
s
.669 .239 1 r
.17793 .23439 m
.17344 .27832 L
s
.41 .683 1 r
.60287 .28972 m
.60283 .29005 L
s
.904 .186 1 r
.0969 .30914 m
.09684 .30911 L
s
.569 .264 1 r
.22592 .30203 m
.22585 .30218 L
s
1 .158 .959 r
.29785 .28062 m
.29714 .29037 L
s
.29716 .29032 m
.29785 .28062 L
s
.29785 .28062 m
.29652 .30019 L
s
.357 .45 1 r
.66364 .23412 m
.66544 .27165 L
s
.811 .206 1 r
.34841 .23412 m
.34618 .27918 L
s
.799 .209 1 r
.26182 .29161 m
.26106 .30093 L
s
.26115 .30074 m
.26182 .29161 L
s
.659 .242 1 r
.28763 .29019 m
.28697 .29913 L
s
.28704 .29908 m
.28763 .29019 L
s
.799 .209 1 r
.26106 .30093 m
.26184 .29157 L
s
.26184 .29157 m
.26115 .30074 L
s
.659 .242 1 r
.28697 .29913 m
.28764 .29014 L
s
.28764 .29014 m
.28704 .29908 L
s
.649 .244 1 r
.57159 .27449 m
.57169 .2835 L
s
.57171 .28345 m
.57159 .27449 L
s
.57159 .27449 m
.57187 .29218 L
s
.81 .206 1 r
.40653 .29247 m
.40618 .30176 L
s
.40625 .30175 m
.40653 .29247 L
s
.40618 .30176 m
.40655 .29243 L
s
.40655 .29243 m
.40625 .30175 L
s
.953 .176 1 r
.60844 .3076 m
.60839 .30795 L
s
.559 .267 1 r
.5974 .27329 m
.59757 .28208 L
s
.59759 .28203 m
.5974 .27329 L
s
.5974 .27329 m
.59781 .29052 L
s
.55 .269 1 r
.28213 .27333 m
.28145 .28208 L
s
.28147 .28203 m
.28213 .27333 L
s
.28213 .27333 m
.28087 .29052 L
s
.367 .495 1 r
.8342 .23385 m
.83784 .26988 L
s
.916 .184 1 r
.51893 .23385 m
.51908 .28005 L
s
.335 .341 1 r
.20365 .23385 m
.20001 .27251 L
s
.88 .191 1 r
.63426 .30633 m
.63421 .30668 L
s
.598 .257 1 r
.16867 .28851 m
.1677 .29733 L
s
.16778 .29717 m
.16867 .28851 L
s
.1677 .29733 m
.16869 .28846 L
s
.16869 .28846 m
.16778 .29717 L
s
.359 .325 1 r
.16318 .27135 m
.16225 .27949 L
s
.16227 .27945 m
.16318 .27135 L
s
.16318 .27135 m
.16141 .28748 L
s
.811 .206 1 r
.66008 .30506 m
.66003 .30541 L
s
.531 .274 1 r
.36503 .28652 m
.36459 .29522 L
s
.36467 .29488 m
.36503 .28652 L
s
.367 .322 1 r
.15853 .29795 m
.15848 .29791 L
s
1 .156 .946 r
.51998 .27792 m
.51994 .28785 L
s
.51996 .2878 m
.51998 .27792 L
s
.51998 .27792 m
.51998 .29737 L
s
.521 .277 1 r
.11154 .27437 m
.11043 .28294 L
s
.11044 .28289 m
.11154 .27437 L
s
.11154 .27437 m
.10939 .29154 L
s
.531 .274 1 r
.36459 .29522 m
.36505 .28648 L
s
.36505 .28648 m
.36467 .29488 L
s
.88 .191 1 r
.68949 .23358 m
.69206 .2794 L
s
.569 .264 1 r
.37418 .23358 m
.37243 .27563 L
s
.362 .473 1 r
.32353 .28027 m
.32303 .28813 L
s
.32312 .28764 m
.32353 .28027 L
s
.32303 .28813 m
.32354 .28023 L
s
.32354 .28023 m
.32312 .28764 L
s
1 .154 .933 r
.75322 .30899 m
.75318 .30934 L
s
.344 .33 1 r
.41664 .28398 m
.41636 .29203 L
s
.41642 .29196 m
.41664 .28398 L
s
.41636 .29203 m
.41666 .28394 L
s
.41666 .28394 m
.41642 .29196 L
s
.608 .254 1 r
.4222 .30125 m
.42213 .30155 L
s
.50977 .28768 m
.50972 .29658 L
s
.50978 .29627 m
.50977 .28768 L
s
.541 .272 1 r
.22024 .28626 m
.21942 .295 L
s
.21952 .29462 m
.22024 .28626 L
s
.765 .217 1 r
.23044 .27695 m
.22959 .28612 L
s
.2296 .28608 m
.23044 .27695 L
s
.23044 .27695 m
.22881 .29534 L
s
.609 .254 1 r
.08567 .27624 m
.08447 .28496 L
s
.08448 .28492 m
.08567 .27624 L
s
.08567 .27624 m
.08331 .29395 L
s
.608 .254 1 r
.50972 .29658 m
.50979 .28764 L
s
.50979 .28764 m
.50978 .29627 L
s
.618 .252 1 r
.59279 .30061 m
.59274 .30106 L
s
.541 .272 1 r
.21942 .295 m
.22026 .28622 L
s
.22026 .28622 m
.21952 .29462 L
s
.55 .269 1 r
.768 .2734 m
.76862 .28211 L
s
.76865 .28207 m
.768 .2734 L
s
.768 .2734 m
.76931 .29063 L
s
.777 .214 1 r
.62872 .28997 m
.62901 .29928 L
s
.62906 .29894 m
.62872 .28997 L
s
.352 .327 1 r
.54475 .23331 m
.54519 .27197 L
s
.522 .277 1 r
.22939 .23331 m
.22572 .27574 L
s
.777 .214 1 r
.62901 .29928 m
.62875 .28992 L
s
.62875 .28992 m
.62906 .29894 L
s
.845 .199 1 r
.7735 .29083 m
.77422 .3003 L
s
.77426 .29995 m
.7735 .29083 L
s
.618 .252 1 r
.62325 .27287 m
.62349 .28185 L
s
.62351 .2818 m
.62325 .27287 L
s
.62325 .27287 m
.6238 .29037 L
s
.822 .204 1 r
.71639 .2765 m
.7169 .28586 L
s
.71693 .28582 m
.71639 .2765 L
s
.71639 .2765 m
.7175 .29507 L
s
.845 .199 1 r
.77422 .3003 m
.77353 .29078 L
s
.77353 .29078 m
.77426 .29995 L
s
.648 .244 1 r
.73757 .30162 m
.73753 .30196 L
s
.588 .259 1 r
.30787 .27298 m
.30726 .28185 L
s
.30727 .2818 m
.30787 .27298 L
s
.30787 .27298 m
.30674 .29037 L
s
.711 .229 1 r
.05517 .30454 m
.0551 .30454 L
s
.65455 .28884 m
.65491 .29801 L
s
.65496 .29766 m
.65455 .28884 L
s
.658 .242 1 r
.33917 .28884 m
.33864 .29782 L
s
.33872 .29766 m
.33917 .28884 L
s
.372 .52 1 r
.14276 .29095 m
.14265 .2914 L
s
.504 .282 1 r
.07542 .286 m
.07422 .29459 L
s
.07432 .29436 m
.07542 .286 L
s
.658 .242 1 r
.33864 .29782 m
.33918 .2888 L
s
.33918 .2888 m
.33872 .29766 L
s
.711 .229 1 r
.65491 .29801 m
.65458 .2888 L
s
.65458 .2888 m
.65496 .29766 L
s
.504 .282 1 r
.07422 .29459 m
.07543 .28595 L
s
.07543 .28595 m
.07432 .29436 L
s
.733 .224 1 r
.08097 .30327 m
.08086 .30358 L
s
.7 .232 1 r
.39637 .30327 m
.39629 .30346 L
s
.881 .191 1 r
.71536 .23304 m
.7183 .27887 L
s
.589 1 .781 r
.39996 .23304 m
.39909 .25897 L
s
.833 .201 1 r
.25621 .2762 m
.25541 .2856 L
s
.25542 .28555 m
.25621 .2762 L
s
.25621 .2762 m
.25471 .29481 L
s
.459 .294 1 r
.30318 .30009 m
.30313 .2999 L
s
.433 .302 1 r
.81507 .2978 m
.81502 .29795 L
s
.811 .206 1 r
.54116 .30428 m
.5411 .30463 L
s
.834 .201 1 r
.85659 .30428 m
.85657 .3047 L
s
.608 .254 1 r
.19434 .28858 m
.19344 .29736 L
s
.1935 .2974 m
.19434 .28858 L
s
.618 .252 1 r
.448 .30072 m
.44793 .30106 L
s
.789 .211 1 r
.45265 .27421 m
.45241 .28361 L
s
.45243 .28356 m
.45265 .27421 L
s
.45265 .27421 m
.45227 .29251 L
s
.618 .252 1 r
.13258 .30072 m
.13247 .30106 L
s
.608 .254 1 r
.19344 .29736 m
.19435 .28853 L
s
.19435 .28853 m
.1935 .2974 L
s
.733 .224 1 r
.25154 .30301 m
.25145 .30332 L
s
.639 .247 1 r
.13719 .2744 m
.13611 .28331 L
s
.13612 .28326 m
.13719 .2744 L
s
.13719 .2744 m
.13511 .29214 L
s
.966 .173 1 r
.74227 .27585 m
.74289 .28563 L
s
.74292 .28558 m
.74227 .27585 L
s
.74227 .27585 m
.74357 .29492 L
s
.649 .244 1 r
.57058 .23277 m
.57141 .27558 L
s
.745 .221 1 r
.25513 .23277 m
.25153 .2786 L
s
.744 .222 1 r
.82523 .28888 m
.82607 .29812 L
s
.8261 .29778 m
.82523 .28888 L
s
.67 .239 1 r
.79393 .27308 m
.79464 .28218 L
s
.79467 .28213 m
.79393 .27308 L
s
.79393 .27308 m
.79542 .29086 L
s
.744 .222 1 r
.82607 .29812 m
.82526 .28883 L
s
.82526 .28883 m
.8261 .29778 L
s
.66 .241 1 r
.70625 .28689 m
.70675 .29598 L
s
.70678 .29548 m
.70625 .28689 L
s
.777 .214 1 r
.56699 .30338 m
.56693 .30373 L
s
.66 .241 1 r
.70675 .29598 m
.70628 .28685 L
s
.70628 .28685 m
.70678 .29548 L
s
.424 .305 1 r
.38065 .29627 m
.38057 .2966 L
s
.522 .277 1 r
.24593 .28633 m
.24519 .29493 L
s
.24526 .29485 m
.24593 .28633 L
s
.428 .751 1 r
.80408 .26407 m
.80467 .27126 L
s
.80469 .27122 m
.80408 .26407 L
s
.80408 .26407 m
.80529 .27804 L
s
.45 .297 1 r
.53011 .27054 m
.5301 .27903 L
s
.53012 .27898 m
.53011 .27054 L
s
.53011 .27054 m
.53016 .28717 L
s
.711 .229 1 r
.74125 .2325 m
.74442 .27644 L
s
.531 .274 1 r
.42576 .2325 m
.42471 .27381 L
s
.522 .277 1 r
.24519 .29493 m
.24595 .28629 L
s
.24595 .28629 m
.24526 .29485 L
s
.669 .239 1 r
.85111 .28805 m
.85201 .29707 L
s
.85205 .29687 m
.85111 .28805 L
s
.85201 .29707 m
.85114 .28801 L
s
.85114 .28801 m
.85205 .29687 L
s
.55 .269 1 r
.18876 .27234 m
.18784 .28105 L
s
.18785 .28101 m
.18876 .27234 L
s
.18876 .27234 m
.18701 .28958 L
s
.73211 .28607 m
.73266 .29477 L
s
.73271 .29458 m
.73211 .28607 L
s
.733 .224 1 r
.47846 .27387 m
.4783 .28308 L
s
.47832 .28303 m
.47846 .27387 L
s
.47846 .27387 m
.47823 .29199 L
s
1 .161 .972 r
.59643 .23223 m
.59772 .2792 L
s
.711 .229 1 r
.28089 .23223 m
.27774 .27693 L
s
.55 .269 1 r
.73266 .29477 m
.73214 .28602 L
s
.73214 .28602 m
.73271 .29458 L
s
.744 .222 1 r
.5356 .28835 m
.53563 .29759 L
s
.53569 .29725 m
.5356 .28835 L
s
.53563 .29759 m
.53563 .28831 L
s
.53563 .28831 m
.53569 .29725 L
s
.531 .274 1 r
.44241 .28494 m
.44218 .29365 L
s
.44225 .29331 m
.44241 .28494 L
s
.588 .259 1 r
.18408 .2993 m
.18398 .29964 L
s
.531 .274 1 r
.44218 .29365 m
.44243 .2849 L
s
.44243 .2849 m
.44225 .29331 L
s
.777 .214 1 r
.76355 .30222 m
.76352 .30268 L
s
.68 .237 1 r
.81986 .27286 m
.82065 .28195 L
s
.82068 .2819 m
.81986 .27286 L
s
.81986 .27286 m
.8215 .29071 L
s
.34 .366 1 r
.3492 .28153 m
.34876 .28951 L
s
.34883 .28937 m
.3492 .28153 L
s
.733 .224 1 r
.76715 .23196 m
.77076 .27704 L
s
.88 .191 1 r
.45157 .23196 m
.45077 .2778 L
s
.459 .295 1 r
.13599 .23196 m
.13123 .27327 L
s
.34 .366 1 r
.34876 .28951 m
.34922 .28149 L
s
.34922 .28149 m
.34883 .28937 L
s
.628 .249 1 r
.4738 .30095 m
.47374 .30111 L
s
.744 .221 1 r
.56145 .28753 m
.56154 .29681 L
s
.5616 .29635 m
.56145 .28753 L
s
.486 .956 1 r
.38517 .271 m
.38488 .2776 L
s
.38495 .27717 m
.38517 .271 L
s
.38488 .2776 m
.38519 .27097 L
s
.38519 .27097 m
.38495 .27717 L
s
.744 .221 1 r
.56154 .29681 m
.56147 .28748 L
s
.56147 .28748 m
.5616 .29635 L
s
.588 .259 1 r
.10094 .28696 m
.09979 .29571 L
s
.09985 .29571 m
.10094 .28696 L
s
.744 .222 1 r
.62229 .23169 m
.62386 .27602 L
s
.45 .297 1 r
.30667 .23169 m
.30406 .27337 L
s
.588 .259 1 r
.09979 .29571 m
.10095 .28692 L
s
.10095 .28692 m
.09985 .29571 L
s
.811 .206 1 r
.50429 .27341 m
.5042 .28285 L
s
.50422 .2828 m
.50429 .27341 L
s
.50429 .27341 m
.5042 .29184 L
s
.35 .414 1 r
.40086 .27928 m
.40054 .28726 L
s
.40062 .28681 m
.40086 .27928 L
s
.40054 .28726 m
.40087 .27924 L
s
.40087 .27924 m
.40062 .28681 L
s
.522 .277 1 r
.46823 .28442 m
.46807 .29308 L
s
.46814 .29278 m
.46823 .28442 L
s
.56 .267 1 r
.78388 .28442 m
.78458 .29324 L
s
.7846 .29278 m
.78388 .28442 L
s
.522 .277 1 r
.46807 .29308 m
.46825 .28437 L
s
.46825 .28437 m
.46814 .29278 L
s
.56 .267 1 r
.78458 .29324 m
.78391 .28437 L
s
.78391 .28437 m
.7846 .29278 L
s
1 .116 .73 r
.42677 .27801 m
.42643 .28833 L
s
.42645 .28828 m
.42677 .27801 L
s
.42677 .27801 m
.42619 .29832 L
s
.777 .214 1 r
.78946 .3017 m
.78944 .30216 L
s
.425 .305 1 r
.66483 .28243 m
.66518 .29083 L
s
.66522 .29049 m
.66483 .28243 L
s
.669 .239 1 r
.79306 .23142 m
.797 .27613 L
s
.559 .267 1 r
.4774 .23142 m
.477 .27348 L
s
.569 .264 1 r
.16173 .23142 m
.15713 .27424 L
s
.425 .305 1 r
.66518 .29083 m
.66485 .28239 L
s
.66485 .28239 m
.66522 .29049 L
s
.56 .267 1 r
.41106 .2703 m
.41072 .27913 L
s
.41074 .27909 m
.41106 .2703 L
s
.41106 .2703 m
.41048 .28751 L
s
.834 .201 1 r
.61872 .30271 m
.61867 .30314 L
s
.477 .289 1 r
.43225 .2956 m
.43218 .29605 L
s
.578 .262 1 r
.21442 .2727 m
.21357 .28142 L
s
.21358 .28138 m
.21442 .2727 L
s
.21442 .2727 m
.21279 .29018 L
s
.811 .206 1 r
.35936 .27348 m
.35885 .28288 L
s
.35887 .28284 m
.35936 .27348 L
s
.35936 .27348 m
.35845 .29195 L
s
.88 .191 1 r
.64817 .23115 m
.65016 .27699 L
s
.638 .247 1 r
.33246 .23115 m
.33011 .27435 L
s
.904 .186 1 r
.39068 .28959 m
.39027 .29918 L
s
.39035 .29887 m
.39068 .28959 L
s
.669 .239 1 r
.12664 .28674 m
.12552 .29575 L
s
.12561 .29556 m
.12664 .28674 L
s
.904 .186 1 r
.39027 .29918 m
.3907 .28954 L
s
.3907 .28954 m
.39035 .29887 L
s
.669 .239 1 r
.12552 .29575 m
.12665 .28669 L
s
.12665 .28669 m
.12561 .29556 L
s
.376 .32 1 r
.31778 .26742 m
.31723 .27571 L
s
.31725 .27567 m
.31778 .26742 L
s
.31778 .26742 m
.31678 .28355 L
s
.41 .683 1 r
.33342 .27534 m
.33298 .28267 L
s
.33305 .28234 m
.33342 .27534 L
s
.33298 .28267 m
.33343 .2753 L
s
.33343 .2753 m
.33305 .28234 L
s
.711 .229 1 r
.81899 .23088 m
.82322 .27483 L
s
.892 .189 1 r
.50324 .23088 m
.50316 .27748 L
s
.467 .292 1 r
.18748 .23088 m
.18338 .27219 L
s
.701 .231 1 r
.52549 .2999 m
.52543 .30032 L
s
.522 .277 1 r
.1783 .28419 m
.17737 .29282 L
s
.17746 .29263 m
.1783 .28419 L
s
.916 .184 1 r
.6751 .27415 m
.67551 .28378 L
s
.67553 .28373 m
.6751 .27415 L
s
.6751 .27415 m
.676 .29308 L
s
.522 .277 1 r
.17737 .29282 m
.17831 .28414 L
s
.17831 .28414 m
.17746 .29263 L
s
.541 .272 1 r
.15241 .28591 m
.15142 .29447 L
s
.15146 .29466 m
.15241 .28591 L
s
.599 .257 1 r
.5772 .29736 m
.57715 .29785 L
s
.639 .247 1 r
.20969 .30028 m
.20961 .30036 L
s
.733 .224 1 r
.67406 .23061 m
.67634 .27494 L
s
.513 .279 1 r
.35826 .23061 m
.35637 .27155 L
s
.541 .272 1 r
.15142 .29447 m
.15242 .28587 L
s
.15242 .28587 m
.15146 .29466 L
s
.799 .209 1 r
.58733 .2882 m
.5875 .29752 L
s
.58756 .29733 m
.58733 .2882 L
s
.733 .224 1 r
.61318 .28677 m
.61343 .29598 L
s
.61348 .29568 m
.61318 .28677 L
s
.799 .209 1 r
.5875 .29752 m
.58735 .28815 L
s
.58735 .28815 m
.58756 .29733 L
s
.733 .224 1 r
.61343 .29598 m
.61321 .28673 L
s
.61321 .28673 m
.61348 .29568 L
s
.845 .199 1 r
.70098 .27317 m
.70145 .28265 L
s
.70148 .28261 m
.70098 .27317 L
s
.70098 .27317 m
.70201 .29179 L
s
.648 .244 1 r
.26603 .27104 m
.26529 .28006 L
s
.26531 .28002 m
.26603 .27104 L
s
.26603 .27104 m
.26465 .28874 L
s
.441 .3 1 r
.77854 .26906 m
.77917 .27747 L
s
.77919 .27743 m
.77854 .26906 L
s
.77854 .26906 m
.77986 .28569 L
s
.559 .267 1 r
.74805 .2971 m
.74802 .29744 L
s
.503 .282 1 r
.69077 .2828 m
.6912 .29143 L
s
.69124 .29109 m
.69077 .2828 L
s
.845 .199 1 r
.52909 .23033 m
.52939 .27581 L
s
.777 .214 1 r
.21325 .23033 m
.20916 .27505 L
s
.711 .229 1 r
.69634 .30002 m
.6963 .30036 L
s
.503 .282 1 r
.6912 .29143 m
.69079 .28275 L
s
.69079 .28275 m
.69124 .29109 L
s
.869 .194 1 r
.32878 .30294 m
.3287 .30325 L
s
.88 .191 1 r
.64463 .30294 m
.64458 .30329 L
s
.733 .224 1 r
.67049 .30167 m
.67043 .30175 L
s
.755 .219 1 r
.846 .27441 m
.84685 .28352 L
s
.84689 .28347 m
.846 .27441 L
s
.846 .27441 m
.84783 .29281 L
s
.45 .297 1 r
.79979 .29455 m
.79976 .29488 L
s
.68 .237 1 r
.80994 .28538 m
.81073 .29448 L
s
.81076 .29413 m
.80994 .28538 L
s
.43685 .271 m
.43658 .2801 L
s
.4366 .28005 m
.43685 .271 L
s
.43685 .271 m
.4364 .28886 L
s
.845 .199 1 r
.69997 .23006 m
.70267 .27554 L
s
.342 .378 1 r
.38408 .23006 m
.38257 .26913 L
s
.68 .237 1 r
.81073 .29448 m
.80997 .28534 L
s
.80997 .28534 m
.81076 .29413 L
s
1 .149 .907 r
.27704 .30624 m
.27694 .30656 L
s
.822 .204 1 r
.49963 .30268 m
.49956 .30284 L
s
.512 .279 1 r
.1468 .26976 m
.14578 .27837 L
s
.14579 .27832 m
.1468 .26976 L
s
.1468 .26976 m
.14485 .28682 L
s
.845 .199 1 r
.72689 .27264 m
.72744 .28212 L
s
.72747 .28208 m
.72689 .27264 L
s
.72689 .27264 m
.72807 .29127 L
s
.589 .259 1 r
.46271 .2698 m
.46251 .27867 L
s
.46253 .27862 m
.46271 .2698 L
s
.46271 .2698 m
.4624 .2872 L
s
.628 .249 1 r
.09506 .27272 m
.09388 .28152 L
s
.09389 .28148 m
.09506 .27272 L
s
.09506 .27272 m
.09275 .29051 L
s
.521 .277 1 r
.11628 .29784 m
.11622 .29781 L
s
.608 .254 1 r
.20401 .28426 m
.20312 .29316 L
s
.20322 .29286 m
.20401 .28426 L
s
.669 .239 1 r
.06455 .30077 m
.06449 .30074 L
s
.608 .254 1 r
.20312 .29316 m
.20403 .28421 L
s
.20403 .28421 m
.20322 .29286 L
s
.766 .217 1 r
.63909 .28655 m
.6394 .29583 L
s
.63946 .29553 m
.63909 .28655 L
s
.648 .244 1 r
.12091 .27145 m
.11978 .2804 L
s
.11979 .28035 m
.12091 .27145 L
s
.12091 .27145 m
.11874 .28923 L
s
.434 .302 1 r
.68068 .29301 m
.68065 .2935 L
s
.4 .312 1 r
.51443 .26717 m
.51437 .27551 L
s
.51439 .27547 m
.51443 .26717 L
s
.51443 .26717 m
.5144 .2835 L
s
.618 .252 1 r
.55496 .22979 m
.55558 .27263 L
s
.722 .227 1 r
.23903 .22979 m
.2353 .27452 L
s
.701 .232 1 r
.0904 .2995 m
.09029 .2998 L
s
.766 .217 1 r
.6394 .29583 m
.63911 .2865 L
s
.63911 .2865 m
.63946 .29553 L
s
.953 .176 1 r
.75826 .28883 m
.75895 .29854 L
s
.75899 .29819 m
.75826 .28883 L
s
.881 .191 1 r
.3546 .30242 m
.35451 .30277 L
s
.744 .222 1 r
.49406 .28598 m
.49396 .29523 L
s
.49403 .29489 m
.49406 .28598 L
s
.811 .206 1 r
.84144 .30179 m
.8414 .30202 L
s
.953 .176 1 r
.75895 .29854 m
.75829 .28878 L
s
.75829 .28878 m
.75899 .29819 L
s
.744 .222 1 r
.49396 .29523 m
.49408 .28594 L
s
.49408 .28594 m
.49403 .29489 L
s
.777 .214 1 r
.55137 .30051 m
.5513 .30085 L
s
.823 .204 1 r
.55601 .27399 m
.55606 .28329 L
s
.55609 .28324 m
.55601 .27399 L
s
.55601 .27399 m
.55621 .29266 L
s
.368 .497 1 r
.22432 .26613 m
.22359 .27378 L
s
.2236 .27374 m
.22432 .26613 L
s
.22432 .26613 m
.22292 .28147 L
s
.811 .206 1 r
.7528 .27189 m
.75342 .28129 L
s
.75345 .28125 m
.7528 .27189 L
s
.7528 .27189 m
.75412 .29036 L
s
.916 .184 1 r
.72589 .22952 m
.72901 .27576 L
s
.531 .274 1 r
.40991 .22952 m
.40866 .27085 L
s
.953 .176 1 r
.58189 .27271 m
.58203 .28246 L
s
.58205 .28241 m
.58189 .27271 L
s
.58189 .27271 m
.58225 .29176 L
s
.638 .247 1 r
.37487 .28429 m
.37444 .29327 L
s
.37452 .29297 m
.37487 .28429 L
s
1 .078 .51 r
.64935 .2778 m
.64972 .28852 L
s
.64975 .28846 m
.64935 .2778 L
s
.64935 .2778 m
.65018 .29889 L
s
.638 .247 1 r
.37444 .29327 m
.37488 .28425 L
s
.37488 .28425 m
.37452 .29297 L
s
.54 .272 1 r
.45804 .29732 m
.45798 .29736 L
s
.905 .186 1 r
.27136 .2903 m
.27062 .29971 L
s
.27067 .29996 m
.27136 .2903 L
s
.433 .302 1 r
.19842 .26803 m
.19755 .27641 L
s
.19757 .27636 m
.19842 .26803 L
s
.19842 .26803 m
.19678 .28463 L
s
.905 .186 1 r
.27062 .29971 m
.27138 .29025 L
s
.27138 .29025 m
.27067 .29996 L
s
.789 .211 1 r
.58084 .22925 m
.58184 .27322 L
s
.755 .219 1 r
.26483 .22925 m
.26139 .27473 L
s
1 .159 .96 r
.24 .27466 m
.23911 .28449 L
s
.23913 .28444 m
.24 .27466 L
s
.24 .27466 m
.23833 .29417 L
s
.834 .201 1 r
.23535 .30126 m
.23525 .30157 L
s
.362 .473 1 r
.32312 .28764 m
.32303 .28813 L
s
.88 .191 1 r
.60778 .27207 m
.60799 .28163 L
s
.60802 .28158 m
.60778 .27207 L
s
.60778 .27207 m
.60828 .29085 L
s
.39 .597 1 r
.25011 .2656 m
.24946 .27295 L
s
.24948 .27291 m
.25011 .2656 L
s
.25011 .2656 m
.24886 .28057 L
s
.669 .239 1 r
.5458 .28433 m
.54585 .29339 L
s
.54591 .29308 m
.5458 .28433 L
s
.443 .299 1 r
.75182 .22898 m
.75486 .26918 L
s
.734 .224 1 r
.43576 .22898 m
.43478 .27295 L
s
.669 .239 1 r
.54585 .29339 m
.54582 .28428 L
s
.54582 .28428 m
.54591 .29308 L
s
.359 .325 1 r
.16225 .27949 m
.16134 .28762 L
s
.16141 .28748 m
.16225 .27949 L
s
.648 .244 1 r
.34346 .26945 m
.34293 .27847 L
s
.34295 .27842 m
.34346 .26945 L
s
.34346 .26945 m
.3425 .28715 L
s
.359 .325 1 r
.16134 .28762 m
.16227 .27945 L
s
.16227 .27945 m
.16141 .28748 L
s
.701 .232 1 r
.17248 .2702 m
.17146 .27934 L
s
.17148 .27929 m
.17248 .2702 L
s
.17248 .2702 m
.17056 .28817 L
s
.659 .242 1 r
.28704 .29908 m
.28697 .29913 L
s
.811 .206 1 r
.63367 .27109 m
.63395 .2805 L
s
.63398 .28045 m
.63367 .27109 L
s
.63367 .27109 m
.63431 .28957 L
s
.344 .33 1 r
.41642 .29196 m
.41636 .29203 L
s
.845 .199 1 r
.60674 .22871 m
.60813 .27419 L
s
.54 .272 1 r
.29064 .2287 m
.28777 .27117 L
s
.531 .274 1 r
.36467 .29488 m
.36459 .29522 L
s
.649 .244 1 r
.57169 .2835 m
.57181 .29252 L
s
.57187 .29218 m
.57169 .2835 L
s
.55 .269 1 r
.28145 .28208 m
.28079 .29083 L
s
.28087 .29052 m
.28145 .28208 L
s
.559 .267 1 r
.59757 .28208 m
.59775 .29086 L
s
.59781 .29052 m
.59757 .28208 L
s
.799 .209 1 r
.26115 .30074 m
.26106 .30093 L
s
.598 .257 1 r
.16778 .29717 m
.1677 .29733 L
s
.649 .244 1 r
.57181 .29252 m
.57171 .28345 L
s
.57171 .28345 m
.57187 .29218 L
s
.55 .269 1 r
.28079 .29083 m
.28147 .28203 L
s
.28147 .28203 m
.28087 .29052 L
s
.559 .267 1 r
.59775 .29086 m
.59759 .28203 L
s
.59759 .28203 m
.59781 .29052 L
s
.521 .277 1 r
.11043 .28294 m
.10933 .2915 L
s
.10939 .29154 m
.11043 .28294 L
s
.10933 .2915 m
.11044 .28289 L
s
.11044 .28289 m
.10939 .29154 L
s
.81 .206 1 r
.40625 .30175 m
.40618 .30176 L
s
.384 .317 1 r
.77777 .22843 m
.78104 .26751 L
s
.424 .305 1 r
.46162 .22843 m
.46104 .26864 L
s
.459 .294 1 r
.14548 .22843 m
.14073 .27053 L
s
1 .158 .959 r
.29714 .29037 m
.29645 .30013 L
s
.29652 .30019 m
.29714 .29037 L
s
.541 .272 1 r
.21952 .29462 m
.21942 .295 L
s
1 .158 .959 r
.29645 .30013 m
.29716 .29032 L
s
.29716 .29032 m
.29652 .30019 L
s
.845 .199 1 r
.48856 .27105 m
.48842 .28053 L
s
.48844 .28048 m
.48856 .27105 L
s
.48856 .27105 m
.48838 .28968 L
s
.608 .254 1 r
.50978 .29627 m
.50972 .29658 L
s
.428 .751 1 r
.80467 .27126 m
.80528 .27844 L
s
.80529 .27804 m
.80467 .27126 L
s
.609 .254 1 r
.08447 .28496 m
.08328 .29368 L
s
.08331 .29395 m
.08447 .28496 L
s
.55 .269 1 r
.76862 .28211 m
.76927 .29082 L
s
.76931 .29063 m
.76862 .28211 L
s
.428 .751 1 r
.80528 .27844 m
.80469 .27122 L
s
.80469 .27122 m
.80529 .27804 L
s
.834 .201 1 r
.63266 .22816 m
.63441 .27366 L
s
.648 .244 1 r
.31646 .22816 m
.31389 .27139 L
s
.609 .254 1 r
.08328 .29368 m
.08448 .28492 L
s
.08448 .28492 m
.08331 .29395 L
s
.55 .269 1 r
.76927 .29082 m
.76865 .28207 L
s
.76865 .28207 m
.76931 .29063 L
s
.504 .282 1 r
.07432 .29436 m
.07422 .29459 L
s
.57 .264 1 r
.56621 .26707 m
.56629 .27594 L
s
.56631 .2759 m
.56621 .26707 L
s
.56621 .26707 m
.56645 .28432 L
s
.94 .179 1 r
.29162 .27356 m
.29091 .28313 L
s
.29093 .28308 m
.29162 .27356 L
s
.29162 .27356 m
.29028 .29273 L
s
.486 .956 1 r
.38495 .27717 m
.38488 .2776 L
s
.344 .33 1 r
.10483 .26644 m
.10377 .27448 L
s
.10378 .27444 m
.10483 .26644 L
s
.10483 .26644 m
.10278 .28255 L
s
.477 .289 1 r
.73726 .26651 m
.73778 .27508 L
s
.73781 .27503 m
.73726 .26651 L
s
.73726 .26651 m
.73838 .28331 L
s
.777 .214 1 r
.62906 .29894 m
.62901 .29928 L
s
.765 .217 1 r
.22959 .28612 m
.22874 .2953 L
s
.22881 .29534 m
.22959 .28612 L
s
.618 .252 1 r
.62349 .28185 m
.62375 .29083 L
s
.6238 .29037 m
.62349 .28185 L
s
.588 .259 1 r
.30726 .28185 m
.30665 .29071 L
s
.30674 .29037 m
.30726 .28185 L
s
.618 .252 1 r
.39515 .26816 m
.39477 .27711 L
s
.39479 .27706 m
.39515 .26816 L
s
.39515 .26816 m
.39448 .28572 L
s
.765 .217 1 r
.22874 .2953 m
.2296 .28608 L
s
.2296 .28608 m
.22881 .29534 L
s
1 .146 .894 r
.80373 .22789 m
.80815 .27604 L
s
.588 .259 1 r
.4875 .22789 m
.48723 .27036 L
s
.476 .29 1 r
.17126 .22789 m
.1669 .26961 L
s
.658 .242 1 r
.33872 .29766 m
.33864 .29782 L
s
.711 .229 1 r
.65496 .29766 m
.65491 .29801 L
s
.618 .252 1 r
.62375 .29083 m
.62351 .2818 L
s
.62351 .2818 m
.6238 .29037 L
s
.588 .259 1 r
.30665 .29071 m
.30727 .2818 L
s
.30727 .2818 m
.30674 .29037 L
s
.845 .199 1 r
.77426 .29995 m
.77422 .3003 L
s
.569 .264 1 r
.71139 .26835 m
.71186 .27711 L
s
.71189 .27706 m
.71139 .26835 L
s
.71139 .26835 m
.71241 .28572 L
s
.777 .214 1 r
.68551 .2698 m
.68594 .27914 L
s
.68596 .27909 m
.68551 .2698 L
s
.68551 .2698 m
.68644 .28813 L
s
.711 .229 1 r
.54033 .26909 m
.54034 .27827 L
s
.54036 .27822 m
.54033 .26909 L
s
.54033 .26909 m
.54044 .28711 L
s
1 .156 .946 r
.51994 .28785 m
.51991 .2978 L
s
.51998 .29737 m
.51994 .28785 L
s
.51991 .2978 m
.51996 .2878 L
s
.51996 .2878 m
.51998 .29737 L
s
.589 .259 1 r
.42104 .26707 m
.42072 .27598 L
s
.42074 .27593 m
.42104 .26707 L
s
.42104 .26707 m
.42051 .28443 L
s
.822 .204 1 r
.7169 .28586 m
.71745 .29523 L
s
.7175 .29507 m
.7169 .28586 L
s
.71745 .29523 m
.71693 .28582 L
s
.71693 .28582 m
.7175 .29507 L
s
.811 .206 1 r
.65858 .22762 m
.66069 .27274 L
s
.799 .209 1 r
.3423 .22762 m
.33996 .27312 L
s
.608 .254 1 r
.1935 .2974 m
.19344 .29736 L
s
.639 .247 1 r
.13611 .28331 m
.13503 .29222 L
s
.13511 .29214 m
.13611 .28331 L
s
.66 .241 1 r
.70678 .29548 m
.70675 .29598 L
s
.45 .297 1 r
.5301 .27903 m
.5301 .28751 L
s
.53016 .28717 m
.5301 .27903 L
s
.639 .247 1 r
.13503 .29222 m
.13612 .28326 L
s
.13612 .28326 m
.13511 .29214 L
s
.522 .277 1 r
.24526 .29485 m
.24519 .29493 L
s
.45 .297 1 r
.5301 .28751 m
.53012 .27898 L
s
.53012 .27898 m
.53016 .28717 L
s
.833 .201 1 r
.25541 .2856 m
.25462 .29501 L
s
.25471 .29481 m
.25541 .2856 L
s
.744 .222 1 r
.8261 .29778 m
.82607 .29812 L
s
.833 .201 1 r
.25462 .29501 m
.25542 .28555 L
s
.25542 .28555 m
.25471 .29481 L
s
.869 .194 1 r
.82971 .22735 m
.83428 .27323 L
s
.846 .199 1 r
.51339 .22735 m
.51346 .27247 L
s
.345 .391 1 r
.19707 .22735 m
.19333 .26605 L
s
.789 .211 1 r
.45241 .28361 m
.45219 .29301 L
s
.45227 .29251 m
.45241 .28361 L
s
.67 .239 1 r
.79464 .28218 m
.79539 .29128 L
s
.79542 .29086 m
.79464 .28218 L
s
.929 .181 1 r
.36923 .27066 m
.36873 .28034 L
s
.36875 .28029 m
.36923 .27066 L
s
.36923 .27066 m
.36835 .28964 L
s
.34 .366 1 r
.34883 .28937 m
.34876 .28951 L
s
.789 .211 1 r
.45219 .29301 m
.45243 .28356 L
s
.45243 .28356 m
.45227 .29251 L
s
.67 .239 1 r
.79539 .29128 m
.79467 .28213 L
s
.79467 .28213 m
.79542 .29086 L
s
.55 .269 1 r
.73271 .29458 m
.73266 .29477 L
s
.18784 .28105 m
.18692 .28977 L
s
.18701 .28958 m
.18784 .28105 L
s
.559 .267 1 r
.4469 .26664 m
.44667 .27544 L
s
.44668 .2754 m
.4469 .26664 L
s
.4469 .26664 m
.44652 .2839 L
s
.94 .179 1 r
.68452 .22707 m
.68707 .27371 L
s
.628 .249 1 r
.36816 .22707 m
.36626 .27069 L
s
.669 .239 1 r
.85205 .29687 m
.85201 .29707 L
s
.35 .414 1 r
.40062 .28681 m
.40054 .28726 L
s
.55 .269 1 r
.18692 .28977 m
.18785 .28101 L
s
.18785 .28101 m
.18701 .28958 L
s
.531 .274 1 r
.44225 .29331 m
.44218 .29365 L
s
1 .138 .854 r
.65969 .27257 m
.66007 .28267 L
s
.6601 .28262 m
.65969 .27257 L
s
.65969 .27257 m
.66054 .29243 L
s
.966 .173 1 r
.74289 .28563 m
.74354 .29543 L
s
.74357 .29492 m
.74289 .28563 L
s
.74354 .29543 m
.74292 .28558 L
s
.74292 .28558 m
.74357 .29492 L
s
.744 .222 1 r
.53569 .29725 m
.53563 .29759 L
s
.917 .184 1 r
.53929 .2268 m
.53974 .27458 L
s
1 .149 .908 r
.22288 .2268 m
.21858 .27534 L
s
.733 .224 1 r
.4783 .28308 m
.47816 .29229 L
s
.47823 .29199 m
.4783 .28308 L
s
.41 .683 1 r
.33305 .28234 m
.33298 .28267 L
s
.733 .224 1 r
.47816 .29229 m
.47832 .28303 L
s
.47832 .28303 m
.47823 .29199 L
s
.701 .232 1 r
.59216 .26807 m
.59231 .27721 L
s
.59234 .27716 m
.59216 .26807 L
s
.59216 .26807 m
.59255 .28605 L
s
1 .154 .934 r
.83089 .27253 m
.83178 .28241 L
s
.83181 .28236 m
.83089 .27253 L
s
.83089 .27253 m
.83276 .29217 L
s
.425 .305 1 r
.66522 .29049 m
.66518 .29083 L
s
.68 .237 1 r
.82065 .28195 m
.82147 .29105 L
s
.8215 .29071 m
.82065 .28195 L
s
.76334 .26754 m
.76397 .27664 L
s
.764 .2766 m
.76334 .26754 L
s
.76334 .26754 m
.76467 .28541 L
s
.424 .305 1 r
.71048 .22653 m
.713 .26675 L
s
.56 .267 1 r
.39402 .22653 m
.39255 .26826 L
s
.744 .221 1 r
.5616 .29635 m
.56154 .29681 L
s
.68 .237 1 r
.82147 .29105 m
.82068 .2819 L
s
.82068 .2819 m
.8215 .29071 L
s
.522 .277 1 r
.46814 .29278 m
.46807 .29308 L
s
.56 .267 1 r
.7846 .29278 m
.78458 .29324 L
s
.588 .259 1 r
.09985 .29571 m
.09979 .29571 L
s
.777 .214 1 r
.2757 .26847 m
.27496 .27781 L
s
.27497 .27776 m
.2757 .26847 L
s
.2757 .26847 m
.27432 .2868 L
s
.513 .279 1 r
.13039 .26784 m
.12934 .27634 L
s
.12935 .2763 m
.13039 .26784 L
s
.13039 .26784 m
.12833 .28503 L
s
.4 .312 1 r
.56521 .22626 m
.56592 .2661 L
s
.669 .239 1 r
.24871 .22626 m
.24517 .27026 L
s
.521 .277 1 r
.64399 .266 m
.64428 .27464 L
s
.6443 .2746 m
.64399 .266 L
s
.64399 .266 m
.64464 .28311 L
s
.649 .244 1 r
.47279 .26678 m
.47261 .27581 L
s
.47263 .27576 m
.47279 .26678 L
s
.47279 .26678 m
.47253 .2845 L
s
.56 .267 1 r
.41072 .27913 m
.4104 .28796 L
s
.41048 .28751 m
.41072 .27913 L
s
.4104 .28796 m
.41074 .27909 L
s
.41074 .27909 m
.41048 .28751 L
s
.811 .206 1 r
.5042 .28285 m
.50413 .2923 L
s
.5042 .29184 m
.5042 .28285 L
s
.578 .262 1 r
.21357 .28142 m
.21272 .29014 L
s
.21279 .29018 m
.21357 .28142 L
s
.376 .32 1 r
.31723 .27571 m
.31669 .284 L
s
.31678 .28355 m
.31723 .27571 L
s
.588 .259 1 r
.73645 .22598 m
.73946 .26848 L
s
.365 .486 1 r
.41991 .22598 m
.41889 .2632 L
s
.811 .206 1 r
.50413 .2923 m
.50422 .2828 L
s
.50422 .2828 m
.5042 .29184 L
s
.578 .262 1 r
.21272 .29014 m
.21358 .28138 L
s
.21358 .28138 m
.21279 .29018 L
s
.376 .32 1 r
.31669 .284 m
.31725 .27567 L
s
.31725 .27567 m
.31678 .28355 L
s
.416 .307 1 r
.37928 .2637 m
.37888 .27208 L
s
.3789 .27204 m
.37928 .2637 L
s
.37928 .2637 m
.37857 .28016 L
s
.522 .277 1 r
.17746 .29263 m
.17737 .29282 L
s
.639 .247 1 r
.15619 .26749 m
.15515 .27641 L
s
.15517 .27637 m
.15619 .26749 L
s
.15619 .26749 m
.1542 .28526 L
s
.409 .309 1 r
.59115 .22571 m
.59216 .26481 L
s
.416 .307 1 r
.27456 .22571 m
.27164 .26594 L
s
.669 .239 1 r
.12561 .29556 m
.12552 .29575 L
s
.57 .264 1 r
.84121 .26467 m
.84204 .27355 L
s
.84207 .2735 m
.84121 .26467 L
s
.84121 .26467 m
.84291 .28193 L
s
.345 .39 1 r
.23392 .26333 m
.23319 .27121 L
s
.2332 .27117 m
.23392 .26333 L
s
.23392 .26333 m
.23253 .27914 L
s
.845 .199 1 r
.61812 .26839 m
.61836 .27788 L
s
.61839 .27783 m
.61812 .26839 L
s
.61812 .26839 m
.61868 .28703 L
s
.648 .244 1 r
.8153 .26625 m
.81607 .27528 L
s
.8161 .27523 m
.8153 .26625 L
s
.8153 .26625 m
.81691 .28397 L
s
.4987 .26625 m
.49859 .27528 L
s
.49862 .27523 m
.4987 .26625 L
s
.4987 .26625 m
.49858 .28397 L
s
.811 .206 1 r
.35885 .28288 m
.35836 .29229 L
s
.35845 .29195 m
.35885 .28288 L
s
.35836 .29229 m
.35887 .28284 L
s
.35887 .28284 m
.35845 .29195 L
s
.541 .272 1 r
.15146 .29466 m
.15142 .29447 L
s
.869 .194 1 r
.3015 .26865 m
.30082 .27818 L
s
.30084 .27813 m
.3015 .26865 L
s
.3015 .26865 m
.30024 .28741 L
s
.904 .186 1 r
.39035 .29887 m
.39027 .29918 L
s
.744 .221 1 r
.76243 .22544 m
.76594 .26982 L
s
.916 .184 1 r
.4458 .22544 m
.44491 .27172 L
s
.503 .282 1 r
.69124 .29109 m
.6912 .29143 L
s
.441 .3 1 r
.77917 .27747 m
.77982 .28588 L
s
.77986 .28569 m
.77917 .27747 L
s
1 .116 .73 r
.42643 .28833 m
.42611 .29867 L
s
.42619 .29832 m
.42643 .28833 L
s
.441 .3 1 r
.77982 .28588 m
.77919 .27743 L
s
.77919 .27743 m
.77986 .28569 L
s
.701 .232 1 r
.18204 .26673 m
.18106 .27588 L
s
.18107 .27583 m
.18204 .26673 L
s
.18204 .26673 m
.18018 .28472 L
s
1 .116 .73 r
.42611 .29867 m
.42645 .28828 L
s
.42645 .28828 m
.42619 .29832 L
s
.733 .224 1 r
.61348 .29568 m
.61343 .29598 L
s
.36 .325 1 r
.43109 .26189 m
.43083 .27012 L
s
.43084 .27007 m
.43109 .26189 L
s
.43109 .26189 m
.43065 .27797 L
s
.45 .297 1 r
.40517 .26335 m
.40483 .27185 L
s
.40484 .2718 m
.40517 .26335 L
s
.40517 .26335 m
.40458 .28 L
s
1 .166 .996 r
.61709 .22517 m
.61868 .27182 L
s
.453 .844 1 r
.30042 .22517 m
.29834 .2575 L
s
.46 .294 1 r
.57647 .26271 m
.57658 .27128 L
s
.5766 .27124 m
.57647 .26271 L
s
.57647 .26271 m
.57676 .27936 L
s
.648 .244 1 r
.26529 .28006 m
.26456 .28909 L
s
.26465 .28874 m
.26529 .28006 L
s
.799 .209 1 r
.58756 .29733 m
.5875 .29752 L
s
.648 .244 1 r
.26456 .28909 m
.26531 .28002 L
s
.26531 .28002 m
.26465 .28874 L
s
.733 .224 1 r
.32738 .26789 m
.3268 .27705 L
s
.32681 .277 m
.32738 .26789 L
s
.32738 .26789 m
.3263 .28612 L
s
.531 .274 1 r
.55054 .26429 m
.55058 .27301 L
s
.55061 .27297 m
.55054 .26429 L
s
.55054 .26429 m
.5507 .2814 L
s
.916 .184 1 r
.67551 .28378 m
.67595 .29343 L
s
.676 .29308 m
.67551 .28378 L
s
.67595 .29343 m
.67553 .28373 L
s
.67553 .28373 m
.676 .29308 L
s
.368 .497 1 r
.22359 .27378 m
.22287 .28143 L
s
.22292 .28147 m
.22359 .27378 L
s
.22287 .28143 m
.2236 .27374 L
s
.2236 .27374 m
.22292 .28147 L
s
1 .121 .757 r
.78843 .22489 m
.79269 .27383 L
s
.744 .222 1 r
.47171 .22489 m
.47121 .26928 L
s
.928 .181 1 r
.15499 .22489 m
.14983 .27193 L
s
.845 .199 1 r
.70145 .28265 m
.70196 .29214 L
s
.70201 .29179 m
.70145 .28265 L
s
.68 .237 1 r
.81076 .29413 m
.81073 .29448 L
s
.512 .279 1 r
.14578 .27837 m
.14477 .28697 L
s
.14485 .28682 m
.14578 .27837 L
s
.4 .312 1 r
.51437 .27551 m
.51434 .28384 L
s
.5144 .2835 m
.51437 .27551 L
s
.628 .249 1 r
.52462 .26613 m
.52459 .27505 L
s
.52461 .275 m
.52462 .26613 L
s
.52462 .26613 m
.52464 .28381 L
s
.845 .199 1 r
.70196 .29214 m
.70148 .28261 L
s
.70148 .28261 m
.70201 .29179 L
s
.512 .279 1 r
.14477 .28697 m
.14579 .27832 L
s
.14579 .27832 m
.14485 .28682 L
s
.766 .217 1 r
.35329 .26691 m
.35277 .27621 L
s
.35279 .27617 m
.35329 .26691 L
s
.35329 .26691 m
.35235 .28521 L
s
.4 .312 1 r
.51434 .28384 m
.51439 .27547 L
s
.51439 .27547 m
.5144 .2835 L
s
.755 .219 1 r
.84685 .28352 m
.84775 .29263 L
s
.84783 .29281 m
.84685 .28352 L
s
.425 .305 1 r
.11433 .26259 m
.11325 .27101 L
s
.11326 .27097 m
.11433 .26259 L
s
.11433 .26259 m
.11228 .27909 L
s
.608 .254 1 r
.20322 .29286 m
.20312 .29316 L
s
.755 .219 1 r
.84775 .29263 m
.84689 .28347 L
s
.84689 .28347 m
.84783 .29281 L
s
.928 .181 1 r
.78951 .2692 m
.79026 .27881 L
s
.79029 .27876 m
.78951 .2692 L
s
.78951 .2692 m
.79109 .28827 L
s
.628 .249 1 r
.09388 .28152 m
.0927 .29033 L
s
.09275 .29051 m
.09388 .28152 L
s
.68 .237 1 r
.43658 .2801 m
.43632 .2892 L
s
.4364 .28886 m
.43658 .2801 L
s
.589 .259 1 r
.46251 .27867 m
.46233 .28754 L
s
.4624 .2872 m
.46251 .27867 L
s
.893 .189 1 r
.64306 .22462 m
.64495 .26977 L
s
.503 .282 1 r
.32629 .22462 m
.32396 .26599 L
s
.628 .249 1 r
.0927 .29033 m
.09389 .28148 L
s
.09389 .28148 m
.09275 .29051 L
s
.39 .597 1 r
.24946 .27295 m
.24883 .2803 L
s
.24886 .28057 m
.24946 .27295 L
s
.68 .237 1 r
.43632 .2892 m
.4366 .28005 L
s
.4366 .28005 m
.4364 .28886 L
s
.589 .259 1 r
.46233 .28754 m
.46253 .27862 L
s
.46253 .27862 m
.4624 .2872 L
s
.39 .597 1 r
.24883 .2803 m
.24948 .27291 L
s
.24948 .27291 m
.24886 .28057 L
s
.69 .234 1 r
.20785 .26657 m
.20694 .27565 L
s
.20695 .2756 m
.20785 .26657 L
s
.20785 .26657 m
.20612 .28457 L
s
.648 .244 1 r
.11978 .2804 m
.11865 .28935 L
s
.11874 .28923 m
.11978 .2804 L
s
.766 .217 1 r
.63946 .29553 m
.6394 .29583 L
s
.648 .244 1 r
.11865 .28935 m
.11979 .28035 L
s
.11979 .28035 m
.11874 .28923 L
s
.531 .274 1 r
.74786 .26315 m
.74843 .27191 L
s
.74845 .27187 m
.74786 .26315 L
s
.74786 .26315 m
.74905 .28022 L
s
.744 .222 1 r
.49403 .29489 m
.49396 .29523 L
s
.486 .287 1 r
.7738 .2618 m
.77443 .27048 L
s
.77446 .27044 m
.7738 .2618 L
s
.7738 .2618 m
.77511 .27856 L
s
.352 .327 1 r
.62836 .26112 m
.62859 .26931 L
s
.62862 .26927 m
.62836 .26112 L
s
.62836 .26112 m
.6289 .27717 L
s
.916 .184 1 r
.81445 .22435 m
.81885 .27064 L
s
.777 .214 1 r
.49764 .22435 m
.49749 .26912 L
s
.559 .267 1 r
.18083 .22435 m
.17655 .26648 L
s
.845 .199 1 r
.72744 .28212 m
.72803 .29161 L
s
.72807 .29127 m
.72744 .28212 L
s
.433 .302 1 r
.19755 .27641 m
.1967 .28478 L
s
.19678 .28463 m
.19755 .27641 L
s
.845 .199 1 r
.72803 .29161 m
.72747 .28208 L
s
.72747 .28208 m
.72807 .29127 L
s
.638 .247 1 r
.37452 .29297 m
.37444 .29327 L
s
.433 .302 1 r
.1967 .28478 m
.19757 .27636 L
s
.19757 .27636 m
.19678 .28463 L
s
.953 .176 1 r
.75899 .29819 m
.75895 .29854 L
s
.428 .751 1 r
.80529 .27804 m
.80528 .27844 L
s
.359 .325 1 r
.16141 .28748 m
.16134 .28762 L
s
.811 .206 1 r
.66903 .22408 m
.67129 .26923 L
s
.691 .234 1 r
.35218 .22407 m
.35011 .26696 L
s
.823 .204 1 r
.55606 .28329 m
.55614 .2926 L
s
.55621 .29266 m
.55606 .28329 L
s
.55614 .2926 m
.55609 .28324 L
s
.55609 .28324 m
.55621 .29266 L
s
.811 .206 1 r
.75342 .28129 m
.75408 .29071 L
s
.75412 .29036 m
.75342 .28129 L
s
.75408 .29071 m
.75345 .28125 L
s
.75345 .28125 m
.75412 .29036 L
s
.589 1 .781 r
.3995 .2482 m
.39926 .25376 L
s
.39927 .25373 m
.3995 .2482 L
s
.3995 .2482 m
.39909 .25897 L
s
.438 .79 1 r
.44121 .25473 m
.44101 .26185 L
s
.44102 .26181 m
.44121 .25473 L
s
.44121 .25473 m
.44088 .26849 L
s
.833 .201 1 r
.52358 .2238 m
.52379 .26972 L
s
.648 .244 1 r
.20668 .2238 m
.20263 .26707 L
s
.669 .239 1 r
.54591 .29308 m
.54585 .29339 L
s
.589 .259 1 r
.60246 .26366 m
.60264 .27254 L
s
.60267 .2725 m
.60246 .26366 L
s
.60246 .26366 m
.6029 .28108 L
s
.953 .176 1 r
.58203 .28246 m
.58219 .29222 L
s
.58225 .29176 m
.58203 .28246 L
s
.905 .186 1 r
.27067 .29996 m
.27062 .29971 L
s
.953 .176 1 r
.58219 .29222 m
.58205 .28241 L
s
.58205 .28241 m
.58225 .29176 L
s
1 .146 .894 r
.67013 .26888 m
.67054 .27891 L
s
.67057 .27886 m
.67013 .26888 L
s
.67013 .26888 m
.67104 .28861 L
s
.55 .269 1 r
.28087 .29052 m
.28079 .29083 L
s
.559 .267 1 r
.59781 .29052 m
.59775 .29086 L
s
.352 .327 1 r
.19192 .26032 m
.19106 .26851 L
s
.19107 .26847 m
.19192 .26032 L
s
.19192 .26032 m
.1903 .27637 L
s
.368 .322 1 r
.69502 .22353 m
.69731 .26302 L
s
.58 .261 1 r
.37808 .22353 m
.37639 .26566 L
s
.648 .244 1 r
.34293 .27847 m
.34241 .2875 L
s
.3425 .28715 m
.34293 .27847 L
s
.744 .222 1 r
.72203 .26625 m
.72255 .27545 L
s
.72258 .2754 m
.72203 .26625 L
s
.72203 .26625 m
.72316 .28452 L
s
.649 .244 1 r
.57187 .29218 m
.57181 .29252 L
s
.648 .244 1 r
.34241 .2875 m
.34295 .27842 L
s
.34295 .27842 m
.3425 .28715 L
s
.701 .232 1 r
.17146 .27934 m
.17046 .28848 L
s
.17056 .28817 m
.17146 .27934 L
s
.521 .277 1 r
.10939 .29154 m
.10933 .2915 L
s
.701 .232 1 r
.17046 .28848 m
.17148 .27929 L
s
.17148 .27929 m
.17056 .28817 L
s
1 .159 .96 r
.23911 .28449 m
.23824 .29433 L
s
.23833 .29417 m
.23911 .28449 L
s
.88 .191 1 r
.60799 .28163 m
.60823 .2912 L
s
.60828 .29085 m
.60799 .28163 L
s
1 .159 .96 r
.23824 .29433 m
.23913 .28444 L
s
.23913 .28444 m
.23833 .29417 L
s
.344 .33 1 r
.10377 .27448 m
.10272 .28251 L
s
.10278 .28255 m
.10377 .27448 L
s
.88 .191 1 r
.60823 .2912 m
.60802 .28158 L
s
.60802 .28158 m
.60828 .29085 L
s
.559 .267 1 r
.54953 .22326 m
.55007 .26539 L
s
.799 .209 1 r
.23255 .22326 m
.22858 .26955 L
s
.344 .33 1 r
.10272 .28251 m
.10378 .27444 L
s
.10378 .27444 m
.10278 .28255 L
s
.811 .206 1 r
.63395 .2805 m
.63426 .28991 L
s
.63431 .28957 m
.63395 .2805 L
s
1 .078 .51 r
.64972 .28852 m
.65012 .29925 L
s
.65018 .29889 m
.64972 .28852 L
s
.811 .206 1 r
.63426 .28991 m
.63398 .28045 L
s
.63398 .28045 m
.63431 .28957 L
s
.55 .269 1 r
.76931 .29063 m
.76927 .29082 L
s
.441 .3 1 r
.33738 .26185 m
.33687 .27028 L
s
.33688 .27023 m
.33738 .26185 L
s
.33738 .26185 m
.33644 .27851 L
s
1 .078 .51 r
.65012 .29925 m
.64975 .28846 L
s
.64975 .28846 m
.65018 .29889 L
s
.811 .206 1 r
.72103 .22298 m
.72401 .26815 L
s
.494 .284 1 r
.404 .22298 m
.40266 .26437 L
s
.609 .254 1 r
.08331 .29395 m
.08328 .29368 L
s
.477 .289 1 r
.73778 .27508 m
.73834 .28364 L
s
.73838 .28331 m
.73778 .27508 L
s
.73834 .28364 m
.73781 .27503 L
s
.73781 .27503 m
.73838 .28331 L
s
.66 .241 1 r
.16586 .26293 m
.16484 .27204 L
s
.16485 .272 m
.16586 .26293 L
s
.16586 .26293 m
.16393 .28066 L
s
.57 .264 1 r
.56629 .27594 m
.5664 .28482 L
s
.56645 .28432 m
.56629 .27594 L
s
.618 .252 1 r
.6238 .29037 m
.62375 .29083 L
s
.588 .259 1 r
.30674 .29037 m
.30665 .29071 L
s
.57 .264 1 r
.5664 .28482 m
.56631 .2759 L
s
.56631 .2759 m
.56645 .28432 L
s
.733 .224 1 r
.45695 .26455 m
.45673 .27378 L
s
.45675 .27373 m
.45695 .26455 L
s
.45695 .26455 m
.4566 .28271 L
s
.68 .237 1 r
.5755 .22271 m
.57641 .26599 L
s
.928 .181 1 r
.25843 .22271 m
.25477 .26977 L
s
.845 .199 1 r
.48842 .28053 m
.48831 .29003 L
s
.48838 .28968 m
.48842 .28053 L
s
.765 .217 1 r
.28543 .26538 m
.28472 .27464 L
s
.28474 .2746 m
.28543 .26538 L
s
.28543 .26538 m
.28411 .28372 L
s
.845 .199 1 r
.48831 .29003 m
.48844 .28048 L
s
.48844 .28048 m
.48838 .28968 L
s
.569 .264 1 r
.13984 .26481 m
.13879 .27348 L
s
.13881 .27343 m
.13984 .26481 L
s
.13984 .26481 m
.1378 .28233 L
s
.71186 .27711 m
.71236 .28587 L
s
.71241 .28572 m
.71186 .27711 L
s
.618 .252 1 r
.39477 .27711 m
.3944 .28606 L
s
.39448 .28572 m
.39477 .27711 L
s
.45 .297 1 r
.53016 .28717 m
.5301 .28751 L
s
1 .158 .959 r
.29652 .30019 m
.29645 .30013 L
s
.569 .264 1 r
.71236 .28587 m
.71189 .27706 L
s
.71189 .27706 m
.71241 .28572 L
s
.618 .252 1 r
.3944 .28606 m
.39479 .27706 L
s
.39479 .27706 m
.39448 .28572 L
s
.531 .274 1 r
.74705 .22244 m
.75015 .2642 L
s
1 .161 .972 r
.42993 .22244 m
.42879 .2695 L
s
.94 .179 1 r
.29091 .28313 m
.29021 .29271 L
s
.29028 .29273 m
.29091 .28313 L
s
.765 .217 1 r
.22881 .29534 m
.22874 .2953 L
s
.589 .259 1 r
.42072 .27598 m
.42043 .28489 L
s
.42051 .28443 m
.42072 .27598 L
s
.94 .179 1 r
.29021 .29271 m
.29093 .28308 L
s
.29093 .28308 m
.29028 .29273 L
s
.628 .249 1 r
.80003 .26372 m
.80075 .27264 L
s
.80078 .2726 m
.80003 .26372 L
s
.80003 .26372 m
.80155 .28142 L
s
.589 .259 1 r
.42043 .28489 m
.42074 .27593 L
s
.42074 .27593 m
.42051 .28443 L
s
.822 .204 1 r
.25942 .2674 m
.25864 .27668 L
s
.25866 .27663 m
.25942 .2674 L
s
.25942 .2674 m
.25792 .28614 L
s
.711 .229 1 r
.54034 .27827 m
.54038 .28746 L
s
.54044 .28711 m
.54034 .27827 L
s
1 .118 .745 r
.6962 .26961 m
.6967 .27989 L
s
.69673 .27983 m
.6962 .26961 L
s
.6962 .26961 m
.6973 .28996 L
s
.711 .229 1 r
.54038 .28746 m
.54036 .27822 L
s
.54036 .27822 m
.54044 .28711 L
s
.777 .214 1 r
.68594 .27914 m
.68639 .28848 L
s
.68644 .28813 m
.68594 .27914 L
s
.639 .247 1 r
.13511 .29214 m
.13503 .29222 L
s
.638 .247 1 r
.60148 .22216 m
.60274 .26544 L
s
.857 .196 1 r
.28432 .22216 m
.2811 .26847 L
s
.777 .214 1 r
.68639 .28848 m
.68596 .27909 L
s
.68596 .27909 m
.68644 .28813 L
s
.822 .204 1 r
.7175 .29507 m
.71745 .29523 L
s
.352 .327 1 r
.58676 .25837 m
.58689 .2666 L
s
.58691 .26656 m
.58676 .25837 L
s
.58676 .25837 m
.58709 .27439 L
s
.67 .239 1 r
.79542 .29086 m
.79539 .29128 L
s
1 .156 .946 r
.51998 .29737 m
.51991 .2978 L
s
.55 .269 1 r
.18701 .28958 m
.18692 .28977 L
s
.789 .211 1 r
.45227 .29251 m
.45219 .29301 L
s
.494 .284 1 r
.50886 .26303 m
.50879 .27151 L
s
.50881 .27146 m
.50886 .26303 L
s
.50886 .26303 m
.5088 .28013 L
s
1 .108 .687 r
.77308 .22189 m
.77718 .27161 L
s
.648 .244 1 r
.45588 .22189 m
.45518 .26517 L
s
.833 .201 1 r
.25471 .29481 m
.25462 .29501 L
s
.559 .267 1 r
.44667 .27544 m
.44645 .28424 L
s
.44652 .2839 m
.44667 .27544 L
s
.44645 .28424 m
.44668 .2754 L
s
.44668 .2754 m
.44652 .2839 L
s
.531 .274 1 r
.70643 .26107 m
.70689 .26981 L
s
.70691 .26976 m
.70643 .26107 L
s
.70643 .26107 m
.70741 .2782 L
s
.799 .209 1 r
.4829 .26479 m
.48275 .27414 L
s
.48277 .27409 m
.4829 .26479 L
s
.4829 .26479 m
.48269 .2833 L
s
.384 .317 1 r
.21758 .26198 m
.21679 .27007 L
s
.21681 .27003 m
.21758 .26198 L
s
.21758 .26198 m
.21605 .27846 L
s
.669 .239 1 r
.36323 .26277 m
.36275 .27184 L
s
.36277 .2718 m
.36323 .26277 L
s
.36323 .26277 m
.36237 .28062 L
s
.648 .244 1 r
.62748 .22161 m
.62909 .2649 L
s
.618 .252 1 r
.31023 .22161 m
.30752 .26565 L
s
.711 .229 1 r
.68049 .26295 m
.68089 .27214 L
s
.68092 .27209 m
.68049 .26295 L
s
.68049 .26295 m
.68138 .28099 L
s
.929 .181 1 r
.36873 .28034 m
.36826 .29003 L
s
.36835 .28964 m
.36873 .28034 L
s
.36826 .29003 m
.36875 .28029 L
s
.36875 .28029 m
.36835 .28964 L
s
.916 .184 1 r
.31126 .26603 m
.31061 .27561 L
s
.31063 .27556 m
.31126 .26603 L
s
.31126 .26603 m
.31004 .28508 L
s
.733 .224 1 r
.47823 .29199 m
.47816 .29229 L
s
.966 .173 1 r
.74357 .29492 m
.74354 .29543 L
s
.881 .191 1 r
.79913 .22134 m
.80325 .2669 L
s
.733 .224 1 r
.48184 .22134 m
.48147 .26614 L
s
.409 .309 1 r
.16455 .22134 m
.16034 .26085 L
s
.68 .237 1 r
.8215 .29071 m
.82147 .29105 L
s
.513 .279 1 r
.12934 .27634 m
.12829 .28484 L
s
.12833 .28503 m
.12934 .27634 L
s
.376 .32 1 r
.31678 .28355 m
.31669 .284 L
s
.513 .279 1 r
.12829 .28484 m
.12935 .2763 L
s
.12935 .2763 m
.12833 .28503 L
s
.367 .495 1 r
.83637 .25474 m
.8371 .26263 L
s
.83712 .26259 m
.83637 .25474 L
s
.83637 .25474 m
.83784 .26988 L
s
.701 .232 1 r
.59231 .27721 m
.59249 .28636 L
s
.59255 .28605 m
.59231 .27721 L
s
.649 .244 1 r
.56083 .26136 m
.5609 .27044 L
s
.56092 .27039 m
.56083 .26136 L
s
.56083 .26136 m
.56105 .27906 L
s
.701 .232 1 r
.59249 .28636 m
.59234 .27716 L
s
.59234 .27716 m
.59255 .28605 L
s
.68 .237 1 r
.76397 .27664 m
.76464 .28575 L
s
.76467 .28541 m
.76397 .27664 L
s
.928 .181 1 r
.65349 .22107 m
.65561 .26814 L
s
.638 .247 1 r
.33616 .22107 m
.33377 .26549 L
s
.68 .237 1 r
.76464 .28575 m
.764 .2766 L
s
.764 .2766 m
.76467 .28541 L
s
.56 .267 1 r
.41048 .28751 m
.4104 .28796 L
s
.618 .252 1 r
.41515 .26087 m
.41482 .26987 L
s
.41483 .26983 m
.41515 .26087 L
s
.41515 .26087 m
.41458 .27842 L
s
.521 .277 1 r
.64428 .27464 m
.64459 .28329 L
s
.64464 .28311 m
.64428 .27464 L
s
.977 .171 1 r
.65456 .26531 m
.65491 .27508 L
s
.65494 .27503 m
.65456 .26531 L
s
.65456 .26531 m
.65535 .28455 L
s
.521 .277 1 r
.64459 .28329 m
.6443 .2746 L
s
.6443 .2746 m
.64464 .28311 L
s
1 .138 .854 r
.66007 .28267 m
.66048 .29279 L
s
.66054 .29243 m
.66007 .28267 L
s
.66048 .29279 m
.6601 .28262 L
s
.6601 .28262 m
.66054 .29243 L
s
.68 .237 1 r
.38916 .26252 m
.38875 .2716 L
s
.38877 .27156 m
.38916 .26252 L
s
.38916 .26252 m
.38844 .28046 L
s
.345 .39 1 r
.23319 .27121 m
.23247 .2791 L
s
.23253 .27914 m
.23319 .27121 L
s
.23247 .2791 m
.2332 .27117 L
s
.2332 .27117 m
.23253 .27914 L
s
.777 .214 1 r
.27496 .27781 m
.27423 .28715 L
s
.27432 .2868 m
.27496 .27781 L
s
.416 .307 1 r
.37888 .27208 m
.3785 .28046 L
s
.37857 .28016 m
.37888 .27208 L
s
.777 .214 1 r
.82519 .22079 m
.82961 .2656 L
s
.953 .176 1 r
.50781 .22079 m
.50781 .26749 L
s
.531 .274 1 r
.19043 .22079 m
.18619 .26371 L
s
.777 .214 1 r
.27423 .28715 m
.27497 .27776 L
s
.27497 .27776 m
.27432 .2868 L
s
.357 .45 1 r
.66476 .25621 m
.66507 .2641 L
s
.66509 .26405 m
.66476 .25621 L
s
.66476 .25621 m
.66544 .27165 L
s
.416 .307 1 r
.3785 .28046 m
.3789 .27204 L
s
.3789 .27204 m
.37857 .28016 L
s
.578 .262 1 r
.21279 .29018 m
.21272 .29014 L
s
.649 .244 1 r
.47261 .27581 m
.47246 .28484 L
s
.47253 .2845 m
.47261 .27581 L
s
.99 .169 1 r
.82627 .265 m
.82714 .27481 L
s
.82717 .27476 m
.82627 .265 L
s
.82627 .265 m
.82808 .28428 L
s
.649 .244 1 r
.47246 .28484 m
.47263 .27576 L
s
.47263 .27576 m
.47253 .2845 L
s
1 .154 .934 r
.83178 .28241 m
.8327 .29229 L
s
.83276 .29217 m
.83178 .28241 L
s
.8327 .29229 m
.83181 .28236 L
s
.83181 .28236 m
.83276 .29217 L
s
.811 .206 1 r
.5042 .29184 m
.50413 .2923 L
s
.589 1 .781 r
.39926 .25376 m
.39904 .25931 L
s
.39909 .25897 m
.39926 .25376 L
s
.618 .252 1 r
.67952 .22052 m
.68181 .26344 L
s
.929 .181 1 r
.3621 .22052 m
.35999 .26684 L
s
.589 1 .781 r
.39904 .25931 m
.39927 .25373 L
s
.39927 .25373 m
.39909 .25897 L
s
.441 .3 1 r
.77986 .28569 m
.77982 .28588 L
s
.639 .247 1 r
.15515 .27641 m
.15413 .28534 L
s
.1542 .28526 m
.15515 .27641 L
s
.467 .292 1 r
.46709 .25906 m
.46691 .2676 L
s
.46693 .26756 m
.46709 .25906 L
s
.46709 .25906 m
.46681 .27584 L
s
.789 .211 1 r
.73257 .26195 m
.73314 .27137 L
s
.73316 .27132 m
.73257 .26195 L
s
.73257 .26195 m
.73377 .2803 L
s
.57 .264 1 r
.84204 .27355 m
.8429 .28242 L
s
.84291 .28193 m
.84204 .27355 L
s
.368 .497 1 r
.22292 .28147 m
.22287 .28143 L
s
.639 .247 1 r
.15413 .28534 m
.15517 .27637 L
s
.15517 .27637 m
.1542 .28526 L
s
.57 .264 1 r
.8429 .28242 m
.84207 .2735 L
s
.84207 .2735 m
.84291 .28193 L
s
.54 .272 1 r
.12363 .26064 m
.12254 .26933 L
s
.12255 .26929 m
.12363 .26064 L
s
.12363 .26064 m
.12153 .27788 L
s
.36 .325 1 r
.43083 .27012 m
.43058 .27834 L
s
.43065 .27797 m
.43083 .27012 L
s
1 .161 .972 r
.5338 .22025 m
.53418 .26771 L
s
.822 .204 1 r
.21634 .22025 m
.21216 .26619 L
s
.36 .325 1 r
.43058 .27834 m
.43084 .27007 L
s
.43084 .27007 m
.43065 .27797 L
s
.648 .244 1 r
.81607 .27528 m
.81688 .28431 L
s
.81691 .28397 m
.81607 .27528 L
s
.49859 .27528 m
.49851 .28431 L
s
.49858 .28397 m
.49859 .27528 L
s
.39 .597 1 r
.24886 .28057 m
.24883 .2803 L
s
.648 .244 1 r
.81688 .28431 m
.8161 .27523 L
s
.8161 .27523 m
.81691 .28397 L
s
.49851 .28431 m
.49862 .27523 L
s
.49862 .27523 m
.49858 .28397 L
s
.811 .206 1 r
.35845 .29195 m
.35836 .29229 L
s
.335 .341 1 r
.20157 .25661 m
.20074 .26473 L
s
.20075 .26468 m
.20157 .25661 L
s
.20157 .25661 m
.20001 .27251 L
s
.45 .297 1 r
.40483 .27185 m
.4045 .28034 L
s
.40458 .28 m
.40483 .27185 L
s
.4045 .28034 m
.40484 .2718 L
s
.40484 .2718 m
.40458 .28 L
s
.46 .294 1 r
.57658 .27128 m
.57671 .27985 L
s
.57676 .27936 m
.57658 .27128 L
s
.4 .312 1 r
.5144 .2835 m
.51434 .28384 L
s
.711 .229 1 r
.70556 .21997 m
.70826 .26403 L
s
.8 .209 1 r
.38805 .21997 m
.38636 .26517 L
s
.46 .294 1 r
.57671 .27985 m
.5766 .27124 L
s
.5766 .27124 m
.57676 .27936 L
s
.845 .199 1 r
.61836 .27788 m
.61863 .28738 L
s
.61868 .28703 m
.61836 .27788 L
s
.61863 .28738 m
.61839 .27783 L
s
.61839 .27783 m
.61868 .28703 L
s
.648 .244 1 r
.26465 .28874 m
.26456 .28909 L
s
.701 .232 1 r
.18106 .27588 m
.18008 .28503 L
s
.18018 .28472 m
.18106 .27588 L
s
.531 .274 1 r
.55058 .27301 m
.55065 .28174 L
s
.5507 .2814 m
.55058 .27301 L
s
.67 .239 1 r
.24331 .26364 m
.24251 .27254 L
s
.24252 .27249 m
.24331 .26364 L
s
.24331 .26364 m
.24177 .2817 L
s
.701 .232 1 r
.18008 .28503 m
.18107 .27583 L
s
.18107 .27583 m
.18018 .28472 L
s
.531 .274 1 r
.55065 .28174 m
.55061 .27297 L
s
.55061 .27297 m
.5507 .2814 L
s
.869 .194 1 r
.30082 .27818 m
.30015 .28772 L
s
.30024 .28741 m
.30082 .27818 L
s
.512 .279 1 r
.14485 .28682 m
.14477 .28697 L
s
.425 .305 1 r
.11325 .27101 m
.11217 .27943 L
s
.11228 .27909 m
.11325 .27101 L
s
.869 .194 1 r
.30015 .28772 m
.30084 .27813 L
s
.30084 .27813 m
.30024 .28741 L
s
.45 .297 1 r
.55981 .2197 m
.56046 .26035 L
s
.24225 .2197 m
.23889 .26035 L
s
.425 .305 1 r
.11217 .27943 m
.11326 .27097 L
s
.11326 .27097 m
.11228 .27909 L
s
1 .159 .96 r
.53487 .26533 m
.53486 .27518 L
s
.53489 .27513 m
.53487 .26533 L
s
.53487 .26533 m
.53496 .28488 L
s
.352 .327 1 r
.54507 .25595 m
.54509 .26419 L
s
.54511 .26415 m
.54507 .25595 L
s
.54507 .25595 m
.54519 .27197 L
s
.766 .216 1 r
.75865 .26183 m
.75929 .27114 L
s
.75932 .27109 m
.75865 .26183 L
s
.75865 .26183 m
.75999 .28015 L
s
.438 .79 1 r
.44101 .26185 m
.44082 .26896 L
s
.44088 .26849 m
.44101 .26185 L
s
.733 .224 1 r
.3268 .27705 m
.32623 .2862 L
s
.3263 .28612 m
.3268 .27705 L
s
.438 .79 1 r
.44082 .26896 m
.44102 .26181 L
s
.44102 .26181 m
.44088 .26849 L
s
.733 .224 1 r
.32623 .2862 m
.32681 .277 L
s
.32681 .277 m
.3263 .28612 L
s
.589 .259 1 r
.4624 .2872 m
.46233 .28754 L
s
.788 .212 1 r
.26928 .26269 m
.26852 .27201 L
s
.26853 .27196 m
.26928 .26269 L
s
.26928 .26269 m
.26785 .28117 L
s
.628 .249 1 r
.52459 .27505 m
.52458 .28397 L
s
.52464 .28381 m
.52459 .27505 L
s
.916 .184 1 r
.676 .29308 m
.67595 .29343 L
s
.352 .327 1 r
.62859 .26931 m
.62885 .2775 L
s
.6289 .27717 m
.62859 .26931 L
s
.68 .237 1 r
.73162 .21942 m
.73465 .26311 L
s
.845 .199 1 r
.41402 .21942 m
.41268 .265 L
s
.628 .249 1 r
.52458 .28397 m
.52461 .275 L
s
.52461 .275 m
.52464 .28381 L
s
.352 .327 1 r
.62885 .2775 m
.62862 .26927 L
s
.62862 .26927 m
.6289 .27717 L
s
.68 .237 1 r
.4364 .28886 m
.43632 .2892 L
s
.638 .247 1 r
.14946 .26073 m
.1484 .2697 L
s
.14841 .26965 m
.14946 .26073 L
s
.14946 .26073 m
.14743 .27848 L
s
.69 .234 1 r
.29526 .26148 m
.29459 .27057 L
s
.29461 .27052 m
.29526 .26148 L
s
.29526 .26148 m
.29401 .2795 L
s
.845 .199 1 r
.70201 .29179 m
.70196 .29214 L
s
.628 .249 1 r
.09275 .29051 m
.0927 .29033 L
s
1 .116 .73 r
.42619 .29832 m
.42611 .29867 L
s
.433 .302 1 r
.19678 .28463 m
.1967 .28478 L
s
.755 .219 1 r
.84783 .29281 m
.84775 .29263 L
s
.766 .217 1 r
.35277 .27621 m
.35227 .28552 L
s
.35235 .28521 m
.35277 .27621 L
s
.531 .274 1 r
.74843 .27191 m
.74902 .28068 L
s
.74905 .28022 m
.74843 .27191 L
s
.486 .287 1 r
.77443 .27048 m
.7751 .27917 L
s
.77511 .27856 m
.77443 .27048 L
s
.777 .214 1 r
.58583 .21915 m
.5869 .26359 L
s
.857 .196 1 r
.26818 .21915 m
.26472 .26549 L
s
.648 .244 1 r
.11874 .28923 m
.11865 .28935 L
s
.766 .217 1 r
.35227 .28552 m
.35279 .27617 L
s
.35279 .27617 m
.35235 .28521 L
s
.531 .274 1 r
.74902 .28068 m
.74845 .27187 L
s
.74845 .27187 m
.74905 .28022 L
s
.881 .191 1 r
.61289 .26185 m
.61312 .27147 L
s
.61315 .27142 m
.61289 .26185 L
s
.61289 .26185 m
.61343 .28063 L
s
.486 .287 1 r
.7751 .27917 m
.77446 .27044 L
s
.77446 .27044 m
.77511 .27856 L
s
.69 .234 1 r
.20694 .27565 m
.20604 .28472 L
s
.20612 .28457 m
.20694 .27565 L
s
.20604 .28472 m
.20695 .2756 L
s
.20695 .2756 m
.20612 .28457 L
s
.767 .216 1 r
.63891 .26068 m
.6392 .27003 L
s
.63923 .26998 m
.63891 .26068 L
s
.63891 .26068 m
.63957 .27896 L
s
.928 .181 1 r
.79026 .27881 m
.79103 .28843 L
s
.79109 .28827 m
.79026 .27881 L
s
.79103 .28843 m
.79029 .27876 L
s
.79029 .27876 m
.79109 .28827 L
s
.588 .259 1 r
.75769 .21887 m
.76099 .26143 L
s
.589 .259 1 r
.44 .21887 m
.4391 .26143 L
s
.845 .199 1 r
.72807 .29127 m
.72803 .29161 L
s
.711 .229 1 r
.49307 .26026 m
.49295 .26946 L
s
.49297 .26942 m
.49307 .26026 L
s
.49307 .26026 m
.49292 .27832 L
s
.669 .239 1 r
.17534 .26041 m
.17434 .26946 L
s
.17436 .26941 m
.17534 .26041 L
s
.17534 .26041 m
.17344 .27832 L
s
.569 .264 1 r
.37322 .25831 m
.37278 .26716 L
s
.37279 .26711 m
.37322 .25831 L
s
.37322 .25831 m
.37243 .27563 L
s
.352 .327 1 r
.19106 .26851 m
.19021 .2767 L
s
.1903 .27637 m
.19106 .26851 L
s
.56 .267 1 r
.61186 .2186 m
.61321 .2604 L
s
.598 .257 1 r
.29413 .2186 m
.29115 .26305 L
s
.352 .327 1 r
.19021 .2767 m
.19107 .26847 L
s
.19107 .26847 m
.1903 .27637 L
s
.811 .206 1 r
.75412 .29036 m
.75408 .29071 L
s
.823 .204 1 r
.55621 .29266 m
.55614 .2926 L
s
.344 .33 1 r
.10278 .28255 m
.10272 .28251 L
s
.589 .259 1 r
.60264 .27254 m
.60285 .28143 L
s
.6029 .28108 m
.60264 .27254 L
s
1 .156 .947 r
.78377 .21833 m
.7879 .26657 L
s
1 .154 .933 r
.46599 .21832 m
.46536 .26619 L
s
.589 .259 1 r
.60285 .28143 m
.60267 .2725 L
s
.60267 .2725 m
.6029 .28108 L
s
.799 .209 1 r
.78483 .26252 m
.78553 .2718 L
s
.78556 .27175 m
.78483 .26252 L
s
.78483 .26252 m
.78634 .28112 L
s
.648 .244 1 r
.3425 .28715 m
.34241 .2875 L
s
.904 .186 1 r
.32116 .26191 m
.32053 .27154 L
s
.32055 .27149 m
.32116 .26191 L
s
.32116 .26191 m
.32 .28085 L
s
.88 .191 1 r
.81088 .26138 m
.81169 .27097 L
s
.81172 .27092 m
.81088 .26138 L
s
.81088 .26138 m
.81256 .28021 L
s
.811 .206 1 r
.34716 .26067 m
.34662 .2701 L
s
.34664 .27005 m
.34716 .26067 L
s
.34716 .26067 m
.34618 .27918 L
s
.953 .176 1 r
.58225 .29176 m
.58219 .29222 L
s
.522 .277 1 r
.22727 .25856 m
.22645 .26719 L
s
.22647 .26715 m
.22727 .25856 L
s
.22727 .25856 m
.22572 .27574 L
s
.701 .232 1 r
.17056 .28817 m
.17046 .28848 L
s
.55 .269 1 r
.63791 .21805 m
.63961 .26023 L
s
.679 .237 1 r
.32008 .21805 m
.31745 .26288 L
s
.441 .3 1 r
.33687 .27028 m
.33637 .2787 L
s
.33644 .27851 m
.33687 .27028 L
s
.33637 .2787 m
.33688 .27023 L
s
.33688 .27023 m
.33644 .27851 L
s
.477 .289 1 r
.73838 .28331 m
.73834 .28364 L
s
.744 .222 1 r
.72255 .27545 m
.7231 .28464 L
s
.72316 .28452 m
.72255 .27545 L
s
.7231 .28464 m
.72258 .2754 L
s
.72258 .2754 m
.72316 .28452 L
s
.531 .274 1 r
.42521 .25671 m
.42491 .26548 L
s
.42493 .26544 m
.42521 .25671 L
s
.42521 .25671 m
.42471 .27381 L
s
.881 .191 1 r
.80987 .21778 m
.81418 .26375 L
s
.811 .206 1 r
.492 .21778 m
.49178 .26299 L
s
.531 .274 1 r
.17414 .21778 m
.16979 .25958 L
s
.57 .264 1 r
.56645 .28432 m
.5664 .28482 L
s
.88 .191 1 r
.60828 .29085 m
.60823 .2912 L
s
.811 .206 1 r
.63431 .28957 m
.63426 .28991 L
s
.649 .244 1 r
.57113 .25787 m
.57123 .26695 L
s
.57125 .26691 m
.57113 .25787 L
s
.57113 .25787 m
.57141 .27558 L
s
1 .146 .894 r
.67054 .27891 m
.67098 .28896 L
s
.67104 .28861 m
.67054 .27891 L
s
.67098 .28896 m
.67057 .27886 L
s
.67057 .27886 m
.67104 .28861 L
s
.766 .217 1 r
.66397 .2175 m
.66614 .26234 L
s
.559 .267 1 r
.34606 .2175 m
.34393 .25969 L
s
1 .159 .96 r
.23833 .29417 m
.23824 .29433 L
s
.916 .184 1 r
.51909 .26107 m
.51904 .27073 L
s
.51906 .27068 m
.51909 .26107 L
s
.51909 .26107 m
.51908 .28005 L
s
.569 .264 1 r
.13879 .27348 m
.13775 .28214 L
s
.1378 .28233 m
.13879 .27348 L
s
.71241 .28572 m
.71236 .28587 L
s
.589 1 .781 r
.39909 .25897 m
.39904 .25931 L
s
.618 .252 1 r
.39448 .28572 m
.3944 .28606 L
s
.66 .241 1 r
.16484 .27204 m
.16381 .28116 L
s
.16393 .28066 m
.16484 .27204 L
s
.569 .264 1 r
.13775 .28214 m
.13881 .27343 L
s
.13881 .27343 m
.1378 .28233 L
s
.66 .241 1 r
.16381 .28116 m
.16485 .272 L
s
.16485 .272 m
.16393 .28066 L
s
.88 .191 1 r
.69108 .26058 m
.69153 .27016 L
s
.69156 .27011 m
.69108 .26058 L
s
.69108 .26058 m
.69206 .2794 L
s
.589 .259 1 r
.42051 .28443 m
.42043 .28489 L
s
.357 .451 1 r
.51803 .21723 m
.51814 .25488 L
s
.833 .201 1 r
.20007 .21723 m
.19558 .26396 L
s
.733 .224 1 r
.45673 .27378 m
.45653 .28301 L
s
.4566 .28271 m
.45673 .27378 L
s
.845 .199 1 r
.48838 .28968 m
.48831 .29003 L
s
.352 .327 1 r
.58689 .2666 m
.58704 .27483 L
s
.58709 .27439 m
.58689 .2666 L
s
.733 .224 1 r
.45653 .28301 m
.45675 .27373 L
s
.45675 .27373 m
.4566 .28271 L
s
.459 .295 1 r
.13323 .25647 m
.13218 .26494 L
s
.13219 .2649 m
.13323 .25647 L
s
.13323 .25647 m
.13123 .27327 L
s
.352 .327 1 r
.58704 .27483 m
.58691 .26656 L
s
.58691 .26656 m
.58709 .27439 L
s
.765 .217 1 r
.28472 .27464 m
.28403 .28392 L
s
.28411 .28372 m
.28472 .27464 L
s
.28403 .28392 m
.28474 .2746 L
s
.28474 .2746 m
.28411 .28372 L
s
.628 .249 1 r
.80075 .27264 m
.8015 .28157 L
s
.80155 .28142 m
.80075 .27264 L
s
.7 .232 1 r
.69005 .21695 m
.69256 .26141 L
s
.779 .213 1 r
.37205 .21695 m
.3702 .26065 L
s
.711 .229 1 r
.54044 .28711 m
.54038 .28746 L
s
.628 .249 1 r
.8015 .28157 m
.80078 .2726 L
s
.80078 .2726 m
.80155 .28142 L
s
.711 .229 1 r
.74318 .25838 m
.74377 .26758 L
s
.74379 .26754 m
.74318 .25838 L
s
.74318 .25838 m
.74442 .27644 L
s
1 .078 .51 r
.65018 .29889 m
.65012 .29925 L
s
.494 .284 1 r
.50879 .27151 m
.50873 .27998 L
s
.5088 .28013 m
.50879 .27151 L
s
.384 .317 1 r
.21679 .27007 m
.21601 .27816 L
s
.21605 .27846 m
.21679 .27007 L
s
.777 .214 1 r
.68644 .28813 m
.68639 .28848 L
s
.494 .284 1 r
.50873 .27998 m
.50881 .27146 L
s
.50881 .27146 m
.5088 .28013 L
s
.384 .317 1 r
.21601 .27816 m
.21681 .27003 L
s
.21681 .27003 m
.21605 .27846 L
s
.822 .204 1 r
.25864 .27668 m
.25787 .28596 L
s
.25792 .28614 m
.25864 .27668 L
s
.881 .191 1 r
.71716 .26004 m
.7177 .26962 L
s
.71772 .26957 m
.71716 .26004 L
s
.71716 .26004 m
.7183 .27887 L
s
.559 .267 1 r
.44652 .2839 m
.44645 .28424 L
s
.822 .204 1 r
.25787 .28596 m
.25866 .27663 L
s
.25866 .27663 m
.25792 .28614 L
s
.476 .29 1 r
.54407 .21668 m
.54453 .25774 L
s
.485 .287 1 r
.22602 .21668 m
.22235 .25849 L
s
.45 .297 1 r
.30517 .25657 m
.30458 .26497 L
s
.3046 .26493 m
.30517 .25657 L
s
.30517 .25657 m
.30406 .27337 L
s
.94 .179 1 r
.29028 .29273 m
.29021 .29271 L
s
.531 .274 1 r
.70689 .26981 m
.70737 .27854 L
s
.70741 .2782 m
.70689 .26981 L
s
.367 .495 1 r
.8371 .26263 m
.83785 .27051 L
s
.83784 .26988 m
.8371 .26263 L
s
.531 .274 1 r
.70737 .27854 m
.70691 .26976 L
s
.70691 .26976 m
.70741 .2782 L
s
.367 .495 1 r
.83785 .27051 m
.83712 .26259 L
s
.83712 .26259 m
.83784 .26988 L
s
.559 .267 1 r
.47722 .25619 m
.47707 .26501 L
s
.47709 .26496 m
.47722 .25619 L
s
.47722 .25619 m
.477 .27348 L
s
.916 .184 1 r
.71614 .2164 m
.71914 .26276 L
s
.512 .279 1 r
.39805 .2164 m
.3966 .2586 L
s
.745 .221 1 r
.25304 .26022 m
.25225 .26936 L
s
.25227 .26931 m
.25304 .26022 L
s
.25304 .26022 m
.25153 .2786 L
s
.711 .229 1 r
.27909 .25879 m
.27837 .26792 L
s
.27839 .26787 m
.27909 .25879 L
s
.27909 .25879 m
.27774 .27693 L
s
.669 .239 1 r
.36275 .27184 m
.36229 .28092 L
s
.36237 .28062 m
.36275 .27184 L
s
.638 .247 1 r
.57012 .21613 m
.57095 .25946 L
s
.67 .239 1 r
.25199 .21613 m
.24854 .25946 L
s
.513 .279 1 r
.12833 .28503 m
.12829 .28484 L
s
1 .118 .745 r
.6967 .27989 m
.69724 .29017 L
s
.6973 .28996 m
.6967 .27989 L
s
.669 .239 1 r
.36229 .28092 m
.36277 .2718 L
s
.36277 .2718 m
.36237 .28062 L
s
.345 .39 1 r
.23253 .27914 m
.23247 .2791 L
s
.513 .279 1 r
.35722 .25456 m
.35674 .2633 L
s
.35676 .26325 m
.35722 .25456 L
s
.35722 .25456 m
.35637 .27155 L
s
.799 .209 1 r
.48275 .27414 m
.48262 .2835 L
s
.48269 .2833 m
.48275 .27414 L
s
1 .118 .745 r
.69724 .29017 m
.69673 .27983 L
s
.69673 .27983 m
.6973 .28996 L
s
.467 .292 1 r
.18511 .25535 m
.1842 .26387 L
s
.18421 .26382 m
.18511 .25535 L
s
.18511 .25535 m
.18338 .27219 L
s
.569 .264 1 r
.15907 .25682 m
.15805 .26561 L
s
.15807 .26556 m
.15907 .25682 L
s
.15907 .25682 m
.15713 .27424 L
s
.799 .209 1 r
.48262 .2835 m
.48277 .27409 L
s
.48277 .27409 m
.48269 .2833 L
s
.357 .45 1 r
.66507 .2641 m
.6654 .27198 L
s
.66544 .27165 m
.66507 .2641 L
s
.342 .378 1 r
.38324 .25328 m
.38287 .26126 L
s
.38289 .26122 m
.38324 .25328 L
s
.38324 .25328 m
.38257 .26913 L
s
.357 .45 1 r
.6654 .27198 m
.66509 .26405 L
s
.66509 .26405 m
.66544 .27165 L
s
.711 .229 1 r
.68089 .27214 m
.68133 .28134 L
s
.68138 .28099 m
.68089 .27214 L
s
.68133 .28134 m
.68092 .27209 L
s
.68092 .27209 m
.68138 .28099 L
s
.416 .307 1 r
.37857 .28016 m
.3785 .28046 L
s
.744 .222 1 r
.62328 .2578 m
.62353 .26708 L
s
.62355 .26703 m
.62328 .2578 L
s
.62328 .2578 m
.62386 .27602 L
s
.521 .277 1 r
.64464 .28311 m
.64459 .28329 L
s
.929 .181 1 r
.36835 .28964 m
.36826 .29003 L
s
.777 .214 1 r
.74224 .21585 m
.74551 .2607 L
s
.701 .232 1 r
.59255 .28605 m
.59249 .28636 L
s
.393 .314 1 r
.42407 .21585 m
.42306 .25465 L
s
.68 .237 1 r
.76467 .28541 m
.76464 .28575 L
s
.733 .224 1 r
.76936 .25877 m
.77002 .26795 L
s
.77004 .2679 m
.76936 .25877 L
s
.76936 .25877 m
.77076 .27704 L
s
.638 .247 1 r
.33114 .25663 m
.33057 .26564 L
s
.33059 .26559 m
.33114 .25663 L
s
.33114 .25663 m
.33011 .27435 L
s
.649 .244 1 r
.5609 .27044 m
.56099 .27952 L
s
.56105 .27906 m
.5609 .27044 L
s
.56099 .27952 m
.56092 .27039 L
s
.56092 .27039 m
.56105 .27906 L
s
.916 .184 1 r
.31061 .27561 m
.30996 .2852 L
s
.31004 .28508 m
.31061 .27561 L
s
.88 .191 1 r
.45117 .25896 m
.45092 .26855 L
s
.45094 .2685 m
.45117 .25896 L
s
.45117 .25896 m
.45077 .2778 L
s
.618 .252 1 r
.41482 .26987 m
.4145 .27887 L
s
.41458 .27842 m
.41482 .26987 L
s
.916 .184 1 r
.30996 .2852 m
.31063 .27556 L
s
.31063 .27556 m
.31004 .28508 L
s
.917 .184 1 r
.59619 .21558 m
.59745 .26157 L
s
.628 .249 1 r
.27797 .21557 m
.27483 .25929 L
s
.618 .252 1 r
.4145 .27887 m
.41483 .26983 L
s
.41483 .26983 m
.41458 .27842 L
s
1 .161 .972 r
.59726 .25979 m
.59744 .26972 L
s
.59747 .26967 m
.59726 .25979 L
s
.59726 .25979 m
.59772 .2792 L
s
.438 .79 1 r
.44088 .26849 m
.44082 .26896 L
s
.36 .325 1 r
.43065 .27797 m
.43058 .27834 L
s
.649 .244 1 r
.47253 .2845 m
.47246 .28484 L
s
.68 .237 1 r
.38875 .2716 m
.38836 .28069 L
s
.38844 .28046 m
.38875 .2716 L
s
.777 .214 1 r
.27432 .2868 m
.27423 .28715 L
s
.68 .237 1 r
.38836 .28069 m
.38877 .27156 L
s
.38877 .27156 m
.38844 .28046 L
s
.531 .274 1 r
.76836 .2153 m
.77175 .25713 L
s
.503 .282 1 r
.4501 .2153 m
.44935 .25675 L
s
.57 .264 1 r
.84291 .28193 m
.8429 .28242 L
s
.669 .239 1 r
.79547 .25813 m
.79619 .26711 L
s
.79622 .26706 m
.79547 .25813 L
s
.79547 .25813 m
.797 .27613 L
s
.467 .292 1 r
.46691 .2676 m
.46675 .27614 L
s
.46681 .27584 m
.46691 .2676 L
s
.335 .341 1 r
.20074 .26473 m
.19992 .27284 L
s
.20001 .27251 m
.20074 .26473 L
s
.711 .229 1 r
.82155 .25677 m
.82235 .26597 L
s
.82238 .26592 m
.82155 .25677 L
s
.82155 .25677 m
.82322 .27483 L
s
.467 .292 1 r
.46675 .27614 m
.46693 .26756 L
s
.46693 .26756 m
.46681 .27584 L
s
.335 .341 1 r
.19992 .27284 m
.20075 .26468 L
s
.20075 .26468 m
.20001 .27251 L
s
.45 .297 1 r
.40458 .28 m
.4045 .28034 L
s
.977 .171 1 r
.65491 .27508 m
.6553 .28486 L
s
.65535 .28455 m
.65491 .27508 L
s
.46 .294 1 r
.57676 .27936 m
.57671 .27985 L
s
1 .138 .854 r
.66054 .29243 m
.66048 .29279 L
s
.54 .272 1 r
.12254 .26933 m
.12144 .27803 L
s
.12153 .27788 m
.12254 .26933 L
s
.977 .171 1 r
.6553 .28486 m
.65494 .27503 L
s
.65494 .27503 m
.65535 .28455 L
s
.639 .247 1 r
.1542 .28526 m
.15413 .28534 L
s
.777 .214 1 r
.62227 .21502 m
.62386 .2595 L
s
.88 .191 1 r
.30396 .21502 m
.30098 .26178 L
s
.54 .272 1 r
.12144 .27803 m
.12255 .26929 L
s
.12255 .26929 m
.12153 .27788 L
s
.648 .244 1 r
.81691 .28397 m
.81688 .28431 L
s
.49858 .28397 m
.49851 .28431 L
s
.531 .274 1 r
.40924 .25374 m
.4089 .26252 L
s
.40892 .26248 m
.40924 .25374 L
s
.40924 .25374 m
.40866 .27085 L
s
.99 .169 1 r
.82714 .27481 m
.82805 .28463 L
s
.82808 .28428 m
.82714 .27481 L
s
.425 .305 1 r
.11228 .27909 m
.11217 .27943 L
s
.88 .191 1 r
.64941 .25815 m
.64974 .26774 L
s
.64977 .26769 m
.64941 .25815 L
s
.64941 .25815 m
.65016 .27699 L
s
1 .154 .934 r
.83276 .29217 m
.8327 .29229 L
s
.733 .224 1 r
.67547 .25676 m
.67586 .266 L
s
.67589 .26596 m
.67547 .25676 L
s
.67547 .25676 m
.67634 .27494 L
s
.99 .169 1 r
.82805 .28463 m
.82717 .27476 L
s
.82717 .27476 m
.82808 .28428 L
s
.38 .554 1 r
.7945 .21475 m
.79773 .25091 L
s
.799 .209 1 r
.47614 .21475 m
.47569 .25999 L
s
.531 .274 1 r
.5507 .2814 m
.55065 .28174 L
s
.789 .211 1 r
.73314 .27137 m
.73373 .2808 L
s
.73377 .2803 m
.73314 .27137 L
s
.443 .299 1 r
.75367 .25256 m
.75424 .26108 L
s
.75426 .26103 m
.75367 .25256 L
s
.75367 .25256 m
.75486 .26918 L
s
.352 .327 1 r
.6289 .27717 m
.62885 .2775 L
s
.54509 .26419 m
.54513 .27242 L
s
.54519 .27197 m
.54509 .26419 L
s
.789 .211 1 r
.73373 .2808 m
.73316 .27132 L
s
.73316 .27132 m
.73377 .2803 L
s
.352 .327 1 r
.54513 .27242 m
.54511 .26415 L
s
.54511 .26415 m
.54519 .27197 L
s
.384 .317 1 r
.77974 .25128 m
.78037 .25964 L
s
.78039 .2596 m
.77974 .25128 L
s
.77974 .25128 m
.78104 .26751 L
s
.618 .252 1 r
.55539 .25502 m
.55545 .26399 L
s
.55547 .26394 m
.55539 .25502 L
s
.55539 .25502 m
.55558 .27263 L
s
.953 .176 1 r
.64837 .21447 m
.65041 .26123 L
s
.69 .234 1 r
.32997 .21447 m
.3275 .25896 L
s
.701 .232 1 r
.18018 .28472 m
.18008 .28503 L
s
.67 .239 1 r
.24251 .27254 m
.24172 .28144 L
s
.24177 .2817 m
.24251 .27254 L
s
.845 .199 1 r
.61868 .28703 m
.61863 .28738 L
s
.67 .239 1 r
.24172 .28144 m
.24252 .27249 L
s
.24252 .27249 m
.24177 .2817 L
s
.777 .214 1 r
.21091 .25667 m
.20998 .26603 L
s
.21 .26599 m
.21091 .25667 L
s
.21091 .25667 m
.20916 .27505 L
s
.486 .287 1 r
.77511 .27856 m
.7751 .27917 L
s
.733 .224 1 r
.82065 .2142 m
.82501 .25906 L
s
.67 .239 1 r
.5022 .2142 m
.50213 .25755 L
s
.588 .259 1 r
.18376 .2142 m
.17946 .25679 L
s
.869 .194 1 r
.30024 .28741 m
.30015 .28772 L
s
.628 .249 1 r
.52464 .28381 m
.52458 .28397 L
s
.892 .189 1 r
.50326 .25852 m
.50316 .26808 L
s
.50319 .26803 m
.50326 .25852 L
s
.50326 .25852 m
.50316 .27748 L
s
.531 .274 1 r
.74905 .28022 m
.74902 .28068 L
s
.845 .199 1 r
.52933 .25712 m
.52932 .26663 L
s
.52934 .26659 m
.52933 .25712 L
s
.52933 .25712 m
.52939 .27581 L
s
.733 .224 1 r
.3263 .28612 m
.32623 .2862 L
s
.424 .305 1 r
.46134 .2521 m
.46115 .26054 L
s
.46117 .2605 m
.46134 .2521 L
s
.46134 .2521 m
.46104 .26864 L
s
.766 .216 1 r
.75929 .27114 m
.75995 .28046 L
s
.75999 .28015 m
.75929 .27114 L
s
.638 .247 1 r
.1484 .2697 m
.14734 .27867 L
s
.14743 .27848 m
.1484 .2697 L
s
.904 .186 1 r
.67448 .21392 m
.67688 .26031 L
s
.766 .216 1 r
.75995 .28046 m
.75932 .27109 L
s
.75932 .27109 m
.75999 .28015 L
s
.441 .3 1 r
.35599 .21392 m
.35404 .255 L
s
.638 .247 1 r
.14734 .27867 m
.14841 .26965 L
s
.14841 .26965 m
.14743 .27848 L
s
.788 .212 1 r
.26852 .27201 m
.26777 .28132 L
s
.26785 .28117 m
.26852 .27201 L
s
.69 .234 1 r
.29459 .27057 m
.29393 .27966 L
s
.29401 .2795 m
.29459 .27057 L
s
.352 .327 1 r
.1903 .27637 m
.19021 .2767 L
s
.788 .212 1 r
.26777 .28132 m
.26853 .27196 L
s
.26853 .27196 m
.26785 .28117 L
s
.845 .199 1 r
.70163 .25685 m
.70211 .26637 L
s
.70214 .26632 m
.70163 .25685 L
s
.70163 .25685 m
.70267 .27554 L
s
.69 .234 1 r
.29393 .27966 m
.29461 .27052 L
s
.29461 .27052 m
.29401 .2795 L
s
.766 .217 1 r
.35235 .28521 m
.35227 .28552 L
s
1 .159 .96 r
.53486 .27518 m
.53489 .28504 L
s
.53496 .28488 m
.53486 .27518 L
s
.722 .227 1 r
.23689 .25632 m
.23604 .2655 L
s
.23606 .26545 m
.23689 .25632 L
s
.23689 .25632 m
.2353 .27452 L
s
.789 .211 1 r
.58149 .25488 m
.58163 .26436 L
s
.58165 .26431 m
.58149 .25488 L
s
.58149 .25488 m
.58184 .27322 L
s
.453 .844 1 r
.29926 .24401 m
.29875 .251 L
s
.29877 .25096 m
.29926 .24401 L
s
.29926 .24401 m
.29834 .2575 L
s
.69 .234 1 r
.20612 .28457 m
.20604 .28472 L
s
1 .159 .96 r
.53489 .28504 m
.53489 .27513 L
s
.53489 .27513 m
.53496 .28488 L
s
.733 .224 1 r
.52828 .21365 m
.52855 .25814 L
s
.799 .209 1 r
.20975 .21365 m
.2055 .25927 L
s
.54 .272 1 r
.289 .2539 m
.28834 .26261 L
s
.28836 .26257 m
.289 .2539 L
s
.289 .2539 m
.28777 .27117 L
s
.345 .391 1 r
.19491 .25028 m
.19408 .25826 L
s
.19409 .25822 m
.19491 .25028 L
s
.19491 .25028 m
.19333 .26605 L
s
.744 .221 1 r
.70061 .21337 m
.70328 .25786 L
s
.578 .262 1 r
.38203 .21337 m
.3803 .25711 L
s
.881 .191 1 r
.61312 .27147 m
.61337 .2811 L
s
.61343 .28063 m
.61312 .27147 L
s
.767 .216 1 r
.6392 .27003 m
.63952 .27939 L
s
.63957 .27896 m
.6392 .27003 L
s
.734 .224 1 r
.43525 .2548 m
.43497 .26408 L
s
.43499 .26404 m
.43525 .2548 L
s
.43525 .2548 m
.43478 .27295 L
s
.569 .264 1 r
.37278 .26716 m
.37235 .27601 L
s
.37243 .27563 m
.37278 .26716 L
s
.881 .191 1 r
.61337 .2811 m
.61315 .27142 L
s
.61315 .27142 m
.61343 .28063 L
s
.767 .216 1 r
.63952 .27939 m
.63923 .26998 L
s
.63923 .26998 m
.63957 .27896 L
s
.569 .264 1 r
.37235 .27601 m
.37279 .26711 L
s
.37279 .26711 m
.37243 .27563 L
s
.711 .229 1 r
.49295 .26946 m
.49285 .27867 L
s
.49292 .27832 m
.49295 .26946 L
s
.669 .239 1 r
.17434 .26946 m
.17335 .27851 L
s
.17344 .27832 m
.17434 .26946 L
s
.928 .181 1 r
.79109 .28827 m
.79103 .28843 L
s
.711 .229 1 r
.49285 .27867 m
.49297 .26942 L
s
.49297 .26942 m
.49292 .27832 L
s
.669 .239 1 r
.17335 .27851 m
.17436 .26941 L
s
.17436 .26941 m
.17344 .27832 L
s
.589 .259 1 r
.6029 .28108 m
.60285 .28143 L
s
.459 .294 1 r
.1427 .25363 m
.14168 .26204 L
s
.1417 .262 m
.1427 .25363 L
s
.1427 .25363 m
.14073 .27053 L
s
.811 .206 1 r
.55437 .21309 m
.55502 .25835 L
s
.467 .292 1 r
.23575 .21309 m
.23222 .25456 L
s
.916 .184 1 r
.72779 .25676 m
.72836 .26643 L
s
.72839 .26638 m
.72779 .25676 L
s
.72779 .25676 m
.72901 .27576 L
s
.441 .3 1 r
.33644 .27851 m
.33637 .2787 L
s
.522 .277 1 r
.22645 .26719 m
.22565 .27582 L
s
.22572 .27574 m
.22645 .26719 L
s
.476 .29 1 r
.16873 .25268 m
.16777 .2612 L
s
.16779 .26116 m
.16873 .25268 L
s
.16873 .25268 m
.1669 .26961 L
s
.618 .252 1 r
.72675 .21282 m
.72968 .2558 L
s
.352 .327 1 r
.40808 .21282 m
.40685 .2524 L
s
.755 .219 1 r
.26285 .25634 m
.26208 .26556 L
s
.26209 .26551 m
.26285 .25634 L
s
.26285 .25634 m
.26139 .27473 L
s
.522 .277 1 r
.22565 .27582 m
.22647 .26715 L
s
.22647 .26715 m
.22572 .27574 L
s
.648 .244 1 r
.31502 .25362 m
.31441 .26267 L
s
.31442 .26263 m
.31502 .25362 L
s
.31502 .25362 m
.31389 .27139 L
s
.588 .259 1 r
.4874 .2529 m
.48727 .2618 L
s
.48729 .26176 m
.4874 .2529 L
s
.4874 .2529 m
.48723 .27036 L
s
.799 .209 1 r
.78553 .2718 m
.78627 .28109 L
s
.78634 .28112 m
.78553 .2718 L
s
.365 .486 1 r
.41936 .24788 m
.41909 .25571 L
s
.4191 .25567 m
.41936 .24788 L
s
.41936 .24788 m
.41889 .2632 L
s
.799 .209 1 r
.78627 .28109 m
.78556 .27175 L
s
.78556 .27175 m
.78634 .28112 L
s
.531 .274 1 r
.42491 .26548 m
.42463 .27426 L
s
.42471 .27381 m
.42491 .26548 L
s
.375 .32 1 r
.58047 .21254 m
.58136 .25212 L
s
.868 .194 1 r
.26176 .21254 m
.25813 .2597 L
s
.531 .274 1 r
.42463 .27426 m
.42493 .26544 L
s
.42493 .26544 m
.42471 .27381 L
s
.845 .199 1 r
.60763 .2555 m
.60784 .26502 L
s
.60786 .26497 m
.60763 .2555 L
s
.60763 .2555 m
.60813 .27419 L
s
.904 .186 1 r
.32053 .27154 m
.31991 .28117 L
s
.32 .28085 m
.32053 .27154 L
s
.744 .222 1 r
.72316 .28452 m
.7231 .28464 L
s
.811 .206 1 r
.34662 .2701 m
.34609 .27953 L
s
.34618 .27918 m
.34662 .2701 L
s
.352 .327 1 r
.58709 .27439 m
.58704 .27483 L
s
.904 .186 1 r
.31991 .28117 m
.32055 .27149 L
s
.32055 .27149 m
.32 .28085 L
s
.811 .206 1 r
.34609 .27953 m
.34664 .27005 L
s
.34664 .27005 m
.34618 .27918 L
s
.88 .191 1 r
.81169 .27097 m
.81253 .28056 L
s
.81256 .28021 m
.81169 .27097 L
s
.81253 .28056 m
.81172 .27092 L
s
.81172 .27092 m
.81256 .28021 L
s
.648 .244 1 r
.75291 .21227 m
.75621 .25563 L
s
.834 .201 1 r
.43415 .21226 m
.4331 .25791 L
s
.424 .305 1 r
.71202 .25021 m
.71248 .25865 L
s
.71251 .2586 m
.71202 .25021 L
s
.71202 .25021 m
.713 .26675 L
s
.649 .244 1 r
.57123 .26695 m
.57135 .27604 L
s
.57141 .27558 m
.57123 .26695 L
s
.66 .241 1 r
.16393 .28066 m
.16381 .28116 L
s
.569 .264 1 r
.1378 .28233 m
.13775 .28214 L
s
.649 .244 1 r
.57135 .27604 m
.57125 .26691 L
s
.57125 .26691 m
.57141 .27558 L
s
.367 .495 1 r
.83784 .26988 m
.83785 .27051 L
s
.459 .295 1 r
.13218 .26494 m
.13114 .27342 L
s
.13123 .27327 m
.13218 .26494 L
s
.4 .312 1 r
.56569 .24971 m
.56577 .25808 L
s
.56579 .25803 m
.56569 .24971 L
s
.56569 .24971 m
.56592 .2661 L
s
.551 .269 1 r
.60659 .21199 m
.60788 .25384 L
s
.579 .262 1 r
.28779 .21199 m
.28475 .25611 L
s
.459 .295 1 r
.13114 .27342 m
.13219 .2649 L
s
.13219 .2649 m
.13123 .27327 L
s
.409 .309 1 r
.5918 .24846 m
.59194 .25694 L
s
.59197 .25689 m
.5918 .24846 L
s
.5918 .24846 m
.59216 .26481 L
s
.834 .201 1 r
.63376 .255 m
.63404 .26448 L
s
.63407 .26443 m
.63376 .255 L
s
.63376 .255 m
.63441 .27366 L
s
.384 .317 1 r
.21605 .27846 m
.21601 .27816 L
s
.733 .224 1 r
.4566 .28271 m
.45653 .28301 L
s
.578 .262 1 r
.77908 .21171 m
.78276 .25546 L
s
.69 .234 1 r
.46023 .21171 m
.45956 .25622 L
s
1 .146 .894 r
.67104 .28861 m
.67098 .28896 L
s
.628 .249 1 r
.80155 .28142 m
.8015 .28157 L
s
.56 .267 1 r
.39323 .25099 m
.39284 .25985 L
s
.39286 .25981 m
.39323 .25099 L
s
.39323 .25099 m
.39255 .26826 L
s
.494 .284 1 r
.5088 .28013 m
.50873 .27998 L
s
.916 .184 1 r
.51904 .27073 m
.51901 .2804 L
s
.51908 .28005 m
.51904 .27073 L
s
.765 .217 1 r
.28411 .28372 m
.28403 .28392 L
s
.45 .297 1 r
.30458 .26497 m
.304 .27337 L
s
.30406 .27337 m
.30458 .26497 L
s
.916 .184 1 r
.51901 .2804 m
.51906 .27068 L
s
.51906 .27068 m
.51908 .28005 L
s
.45 .297 1 r
.304 .27337 m
.3046 .26493 L
s
.3046 .26493 m
.30406 .27337 L
s
.88 .191 1 r
.69153 .27016 m
.69202 .27975 L
s
.69206 .2794 m
.69153 .27016 L
s
.811 .206 1 r
.65989 .2542 m
.66025 .26364 L
s
.66027 .26359 m
.65989 .2542 L
s
.65989 .2542 m
.66069 .27274 L
s
.88 .191 1 r
.69202 .27975 m
.69156 .27011 L
s
.69156 .27011 m
.69206 .2794 L
s
.711 .229 1 r
.63272 .21144 m
.63444 .25557 L
s
.669 .239 1 r
.31383 .21144 m
.31116 .25557 L
s
.357 .45 1 r
.66544 .27165 m
.6654 .27198 L
s
.531 .274 1 r
.70741 .2782 m
.70737 .27854 L
s
.628 .249 1 r
.3671 .25295 m
.36663 .26189 L
s
.36665 .26185 m
.3671 .25295 L
s
.3671 .25295 m
.36626 .27069 L
s
.711 .229 1 r
.74377 .26758 m
.74438 .27679 L
s
.74442 .27644 m
.74377 .26758 L
s
.416 .307 1 r
.2729 .24943 m
.27222 .25784 L
s
.27224 .25779 m
.2729 .24943 L
s
.2729 .24943 m
.27164 .26594 L
s
.846 .199 1 r
.5135 .25381 m
.51344 .26337 L
s
.51346 .26332 m
.5135 .25381 L
s
.5135 .25381 m
.51346 .27247 L
s
.799 .209 1 r
.34098 .25457 m
.34042 .26394 L
s
.34044 .26389 m
.34098 .25457 L
s
.34098 .25457 m
.33996 .27312 L
s
.711 .229 1 r
.74438 .27679 m
.74379 .26754 L
s
.74379 .26754 m
.74442 .27644 L
s
.342 .378 1 r
.38287 .26126 m
.38251 .26923 L
s
.38257 .26913 m
.38287 .26126 L
s
.99 .169 1 r
.80526 .21116 m
.80963 .25833 L
s
.916 .184 1 r
.48633 .21116 m
.486 .25833 L
s
.342 .378 1 r
.38251 .26923 m
.38289 .26122 L
s
.38289 .26122 m
.38257 .26913 L
s
.559 .267 1 r
.47707 .26501 m
.47693 .27383 L
s
.477 .27348 m
.47707 .26501 L
s
.822 .204 1 r
.25792 .28614 m
.25787 .28596 L
s
.559 .267 1 r
.47693 .27383 m
.47709 .26496 L
s
.47709 .26496 m
.477 .27348 L
s
.881 .191 1 r
.7177 .26962 m
.71826 .27922 L
s
.7183 .27887 m
.7177 .26962 L
s
.869 .194 1 r
.83247 .25441 m
.83334 .26397 L
s
.83338 .26392 m
.83247 .25441 L
s
.83247 .25441 m
.83428 .27323 L
s
.467 .292 1 r
.1842 .26387 m
.18329 .27238 L
s
.18338 .27219 m
.1842 .26387 L
s
.881 .191 1 r
.71826 .27922 m
.71772 .26957 L
s
.71772 .26957 m
.7183 .27887 L
s
.559 .267 1 r
.65887 .21088 m
.66086 .25313 L
s
.669 .239 1 r
.33989 .21088 m
.33758 .25502 L
s
.467 .292 1 r
.18329 .27238 m
.18421 .26382 L
s
.18421 .26382 m
.18338 .27219 L
s
.669 .239 1 r
.36237 .28062 m
.36229 .28092 L
s
.513 .279 1 r
.35674 .2633 m
.35628 .27204 L
s
.35637 .27155 m
.35674 .2633 L
s
.588 .259 1 r
.73828 .25101 m
.73884 .25991 L
s
.73886 .25986 m
.73828 .25101 L
s
.73828 .25101 m
.73946 .26848 L
s
.513 .279 1 r
.35628 .27204 m
.35676 .26325 L
s
.35676 .26325 m
.35637 .27155 L
s
.569 .264 1 r
.15805 .26561 m
.15705 .27439 L
s
.15713 .27424 m
.15805 .26561 L
s
.15705 .27439 m
.15807 .26556 L
s
.15807 .26556 m
.15713 .27424 L
s
1 .146 .894 r
.8064 .25626 m
.80724 .26632 L
s
.80727 .26627 m
.8064 .25626 L
s
.8064 .25626 m
.80815 .27604 L
s
.745 .221 1 r
.25225 .26936 m
.25147 .2785 L
s
.25153 .2786 m
.25225 .26936 L
s
.711 .229 1 r
.27837 .26792 m
.27767 .27705 L
s
.27774 .27693 m
.27837 .26792 L
s
.745 .221 1 r
.25147 .2785 m
.25227 .26931 L
s
.25227 .26931 m
.25153 .2786 L
s
.766 .216 1 r
.51244 .21061 m
.5125 .25551 L
s
.513 .279 1 r
.19342 .21061 m
.18919 .25361 L
s
.711 .229 1 r
.27767 .27705 m
.27839 .26787 L
s
.27839 .26787 m
.27774 .27693 L
s
.68138 .28099 m
.68133 .28134 L
s
.799 .209 1 r
.48269 .2833 m
.48262 .2835 L
s
.335 .341 1 r
.20001 .27251 m
.19992 .27284 L
s
.649 .244 1 r
.56105 .27906 m
.56099 .27952 L
s
.618 .252 1 r
.41458 .27842 m
.4145 .27887 L
s
.669 .239 1 r
.24668 .25232 m
.24588 .26138 L
s
.24589 .26134 m
.24668 .25232 L
s
.24668 .25232 m
.24517 .27026 L
s
.94 .179 1 r
.68609 .25459 m
.68654 .2643 L
s
.68657 .26425 m
.68609 .25459 L
s
.68609 .25459 m
.68707 .27371 L
s
.88 .191 1 r
.68503 .21033 m
.68757 .25637 L
s
1 .161 .972 r
.36597 .21033 m
.3638 .25903 L
s
.744 .222 1 r
.62353 .26708 m
.62381 .27636 L
s
.62386 .27602 m
.62353 .26708 L
s
.638 .247 1 r
.33057 .26564 m
.33002 .27465 L
s
.33011 .27435 m
.33057 .26564 L
s
.744 .222 1 r
.62381 .27636 m
.62355 .26703 L
s
.62355 .26703 m
.62386 .27602 L
s
.638 .247 1 r
.33002 .27465 m
.33059 .26559 L
s
.33059 .26559 m
.33011 .27435 L
s
.467 .292 1 r
.46681 .27584 m
.46675 .27614 L
s
.733 .224 1 r
.77002 .26795 m
.7707 .27712 L
s
.77076 .27704 m
.77002 .26795 L
s
.7707 .27712 m
.77004 .2679 L
s
.77004 .2679 m
.77076 .27704 L
s
.425 .304 1 r
.53857 .21005 m
.53895 .25003 L
s
.531 .274 1 r
.21945 .21005 m
.21557 .25306 L
s
.68 .237 1 r
.38844 .28046 m
.38836 .28069 L
s
1 .118 .745 r
.6973 .28996 m
.69724 .29017 L
s
.352 .327 1 r
.54519 .27197 m
.54513 .27242 L
s
.916 .184 1 r
.31004 .28508 m
.30996 .2852 L
s
.54 .272 1 r
.12153 .27788 m
.12144 .27803 L
s
.88 .191 1 r
.45092 .26855 m
.45069 .27815 L
s
.45077 .2778 m
.45092 .26855 L
s
.669 .239 1 r
.79619 .26711 m
.79693 .27609 L
s
.797 .27613 m
.79619 .26711 L
s
.503 .282 1 r
.32498 .24898 m
.32442 .25765 L
s
.32444 .25761 m
.32498 .24898 L
s
.32498 .24898 m
.32396 .26599 L
s
.88 .191 1 r
.45069 .27815 m
.45094 .2685 L
s
.45094 .2685 m
.45077 .2778 L
s
.834 .201 1 r
.71121 .20978 m
.7141 .25544 L
s
.376 .32 1 r
.39206 .20978 m
.39064 .249 L
s
.669 .239 1 r
.79693 .27609 m
.79622 .26706 L
s
.79622 .26706 m
.797 .27613 L
s
.711 .229 1 r
.82235 .26597 m
.82319 .27518 L
s
.82322 .27483 m
.82235 .26597 L
s
.82319 .27518 m
.82238 .26592 L
s
.82238 .26592 m
.82322 .27483 L
s
1 .161 .972 r
.59744 .26972 m
.59766 .27967 L
s
.59772 .2792 m
.59744 .26972 L
s
.744 .221 1 r
.76456 .25158 m
.76521 .26087 L
s
.76524 .26082 m
.76456 .25158 L
s
.76456 .25158 m
.76594 .26982 L
s
.531 .274 1 r
.4089 .26252 m
.40858 .2713 L
s
.40866 .27085 m
.4089 .26252 L
s
.443 .299 1 r
.75424 .26108 m
.75483 .26959 L
s
.75486 .26918 m
.75424 .26108 L
s
1 .161 .972 r
.59766 .27967 m
.59747 .26967 L
s
.59747 .26967 m
.59772 .2792 L
s
.384 .317 1 r
.78037 .25964 m
.78102 .268 L
s
.78104 .26751 m
.78037 .25964 L
s
.618 .252 1 r
.56471 .2095 m
.56546 .25213 L
s
.733 .224 1 r
.2455 .2095 m
.24182 .25441 L
s
.531 .274 1 r
.40858 .2713 m
.40892 .26248 L
s
.40892 .26248 m
.40866 .27085 L
s
.443 .299 1 r
.75483 .26959 m
.75426 .26103 L
s
.75426 .26103 m
.75486 .26918 L
s
.384 .317 1 r
.78102 .268 m
.78039 .2596 L
s
.78039 .2596 m
.78104 .26751 L
s
.453 .844 1 r
.29875 .251 m
.29826 .25798 L
s
.29834 .2575 m
.29875 .251 L
s
.917 .184 1 r
.53963 .2554 m
.53964 .26494 L
s
.53966 .26489 m
.53963 .2554 L
s
.53963 .2554 m
.53974 .27458 L
s
.453 .844 1 r
.29826 .25798 m
.29877 .25096 L
s
.29877 .25096 m
.29834 .2575 L
s
.368 .322 1 r
.69643 .24681 m
.69684 .25507 L
s
.69686 .25503 m
.69643 .24681 L
s
.69643 .24681 m
.69731 .26302 L
s
.977 .171 1 r
.65535 .28455 m
.6553 .28486 L
s
1 .149 .908 r
.22041 .25555 m
.21945 .26554 L
s
.21946 .26549 m
.22041 .25555 L
s
.22041 .25555 m
.21858 .27534 L
s
.789 .211 1 r
.73377 .2803 m
.73373 .2808 L
s
.559 .267 1 r
.17838 .24915 m
.17741 .25798 L
s
.17742 .25794 m
.17838 .24915 L
s
.17838 .24915 m
.17655 .26648 L
s
.711 .229 1 r
.7374 .20922 m
.74063 .25451 L
s
.441 .3 1 r
.41816 .20922 m
.41701 .24996 L
s
.733 .224 1 r
.67586 .266 m
.67629 .27525 L
s
.67634 .27494 m
.67586 .266 L
s
.67629 .27525 m
.67589 .26596 L
s
.67589 .26596 m
.67634 .27494 L
s
.618 .252 1 r
.55545 .26399 m
.55552 .27297 L
s
.55558 .27263 m
.55545 .26399 L
s
.99 .169 1 r
.82808 .28428 m
.82805 .28463 L
s
.618 .252 1 r
.55552 .27297 m
.55547 .26394 L
s
.55547 .26394 m
.55558 .27263 L
s
.67 .239 1 r
.24177 .2817 m
.24172 .28144 L
s
.88 .191 1 r
.64974 .26774 m
.6501 .27734 L
s
.65016 .27699 m
.64974 .26774 L
s
.744 .222 1 r
.47149 .25104 m
.4713 .26033 L
s
.47132 .26028 m
.47149 .25104 L
s
.47149 .25104 m
.47121 .26928 L
s
.424 .305 1 r
.46115 .26054 m
.46098 .26898 L
s
.46104 .26864 m
.46115 .26054 L
s
.88 .191 1 r
.6501 .27734 m
.64977 .26769 L
s
.64977 .26769 m
.65016 .27699 L
s
.578 .262 1 r
.59086 .20894 m
.59197 .25196 L
s
.669 .239 1 r
.27157 .20894 m
.26827 .25348 L
s
.424 .305 1 r
.46098 .26898 m
.46117 .2605 L
s
.46117 .2605 m
.46104 .26864 L
s
.691 .234 1 r
.35104 .24907 m
.35052 .25832 L
s
.35054 .25827 m
.35104 .24907 L
s
.35104 .24907 m
.35011 .26696 L
s
.916 .184 1 r
.44535 .2527 m
.44508 .26238 L
s
.4451 .26233 m
.44535 .2527 L
s
.44535 .2527 m
.44491 .27172 L
s
.777 .214 1 r
.20998 .26603 m
.20906 .2754 L
s
.20916 .27505 m
.20998 .26603 L
s
.522 .277 1 r
.76361 .20867 m
.76692 .25017 L
s
.734 .224 1 r
.44428 .20867 m
.4434 .25282 L
s
.777 .214 1 r
.20906 .2754 m
.21 .26599 L
s
.21 .26599 m
.20916 .27505 L
s
.638 .247 1 r
.14743 .27848 m
.14734 .27867 L
s
.893 .189 1 r
.64423 .25095 m
.64456 .26066 L
s
.64458 .26061 m
.64423 .25095 L
s
.64423 .25095 m
.64495 .26977 L
s
.345 .391 1 r
.19408 .25826 m
.19325 .26624 L
s
.19333 .26605 m
.19408 .25826 L
s
.19325 .26624 m
.19409 .25822 L
s
.19409 .25822 m
.19333 .26605 L
s
1 .166 .996 r
.61809 .2525 m
.61834 .26241 L
s
.61837 .26236 m
.61809 .2525 L
s
.61809 .2525 m
.61868 .27182 L
s
.766 .216 1 r
.75999 .28015 m
.75995 .28046 L
s
.58 .261 1 r
.37715 .24826 m
.37672 .25717 L
s
.37674 .25712 m
.37715 .24826 L
s
.37715 .24826 m
.37639 .26566 L
s
.69 .234 1 r
.29401 .2795 m
.29393 .27966 L
s
.599 .257 1 r
.61703 .20839 m
.61848 .25104 L
s
.69 .234 1 r
.29765 .20839 m
.29464 .25407 L
s
.892 .189 1 r
.50316 .26808 m
.50309 .27764 L
s
.50316 .27748 m
.50316 .26808 L
s
.845 .199 1 r
.52932 .26663 m
.52932 .27616 L
s
.52939 .27581 m
.52932 .26663 L
s
.788 .212 1 r
.26785 .28117 m
.26777 .28132 L
s
.892 .189 1 r
.50309 .27764 m
.50319 .26803 L
s
.50319 .26803 m
.50316 .27748 L
s
.845 .199 1 r
.52932 .27616 m
.52934 .26659 L
s
.52934 .26659 m
.52939 .27581 L
s
.777 .214 1 r
.49762 .25072 m
.49751 .26009 L
s
.49753 .26004 m
.49762 .25072 L
s
.49762 .25072 m
.49749 .26912 L
s
.648 .244 1 r
.20437 .24928 m
.20345 .25835 L
s
.20346 .2583 m
.20437 .24928 L
s
.20437 .24928 m
.20263 .26707 L
s
.722 .227 1 r
.23604 .2655 m
.23522 .27467 L
s
.2353 .27452 m
.23604 .2655 L
s
.569 .264 1 r
.37243 .27563 m
.37235 .27601 L
s
.54 .272 1 r
.28834 .26261 m
.2877 .27132 L
s
.28777 .27117 m
.28834 .26261 L
s
.559 .267 1 r
.54992 .24807 m
.54995 .2569 L
s
.54998 .25685 m
.54992 .24807 L
s
.54992 .24807 m
.55007 .26539 L
s
.68 .237 1 r
.78983 .20811 m
.79368 .25189 L
s
1 .113 .716 r
.47041 .20811 m
.4698 .25874 L
s
.722 .227 1 r
.23522 .27467 m
.23606 .26545 L
s
.23606 .26545 m
.2353 .27452 L
s
.494 .284 1 r
.40328 .24739 m
.40292 .25603 L
s
.40294 .25598 m
.40328 .24739 L
s
.40328 .24739 m
.40266 .26437 L
s
.54 .272 1 r
.2877 .27132 m
.28836 .26257 L
s
.28836 .26257 m
.28777 .27117 L
s
.845 .199 1 r
.70211 .26637 m
.70262 .27589 L
s
.70267 .27554 m
.70211 .26637 L
s
.459 .294 1 r
.14168 .26204 m
.14068 .27045 L
s
.14073 .27053 m
.14168 .26204 L
s
.845 .199 1 r
.70262 .27589 m
.70214 .26632 L
s
.70214 .26632 m
.70267 .27554 L
s
.459 .294 1 r
.14068 .27045 m
.1417 .262 L
s
.1417 .262 m
.14073 .27053 L
s
.789 .211 1 r
.58163 .26436 m
.58179 .27383 L
s
.58184 .27322 m
.58163 .26436 L
s
.365 .486 1 r
.41909 .25571 m
.41882 .26353 L
s
.41889 .2632 m
.41909 .25571 L
s
.789 .211 1 r
.58179 .27383 m
.58165 .26431 L
s
.58165 .26431 m
.58184 .27322 L
s
.928 .181 1 r
.15201 .2528 m
.15087 .26244 L
s
.15088 .26239 m
.15201 .2528 L
s
.15201 .2528 m
.14983 .27193 L
s
.767 .216 1 r
.63957 .27896 m
.63952 .27939 L
s
.365 .486 1 r
.41882 .26353 m
.4191 .25567 L
s
.4191 .25567 m
.41889 .2632 L
s
.811 .206 1 r
.67043 .25067 m
.67082 .26012 L
s
.67084 .26007 m
.67043 .25067 L
s
.67043 .25067 m
.67129 .26923 L
s
.649 .244 1 r
.64321 .20783 m
.64504 .25124 L
s
.777 .214 1 r
.32374 .20783 m
.32108 .25389 L
s
.711 .229 1 r
.49292 .27832 m
.49285 .27867 L
s
.669 .239 1 r
.17344 .27832 m
.17335 .27851 L
s
1 .159 .96 r
.53496 .28488 m
.53489 .28504 L
s
.881 .191 1 r
.61343 .28063 m
.61337 .2811 L
s
.916 .184 1 r
.8171 .25162 m
.81794 .2613 L
s
.81797 .26125 m
.8171 .25162 L
s
.8171 .25162 m
.81885 .27064 L
s
.734 .224 1 r
.43497 .26408 m
.4347 .27337 L
s
.43478 .27295 m
.43497 .26408 L
s
.476 .29 1 r
.16777 .2612 m
.16682 .26972 L
s
.1669 .26961 m
.16777 .2612 L
s
.734 .224 1 r
.4347 .27337 m
.43499 .26404 L
s
.43499 .26404 m
.43478 .27295 L
s
.522 .277 1 r
.22572 .27574 m
.22565 .27582 L
s
.476 .29 1 r
.16682 .26972 m
.16779 .26116 L
s
.16779 .26116 m
.1669 .26961 L
s
.531 .274 1 r
.81607 .20756 m
.82009 .24945 L
s
.88 .191 1 r
.49655 .20756 m
.49639 .25362 L
s
.531 .274 1 r
.42471 .27381 m
.42463 .27426 L
s
.74893 .24703 m
.74951 .25579 L
s
.74953 .25574 m
.74893 .24703 L
s
.74893 .24703 m
.75015 .2642 L
s
1 .121 .757 r
.791 .25357 m
.79181 .26395 L
s
.79185 .26389 m
.791 .25357 L
s
.791 .25357 m
.79269 .27383 L
s
.588 .259 1 r
.48727 .2618 m
.48716 .27071 L
s
.48723 .27036 m
.48727 .2618 L
s
.559 .267 1 r
.66941 .20728 m
.67154 .24955 L
s
.441 .3 1 r
.34985 .20728 m
.34782 .24841 L
s
.588 .259 1 r
.48716 .27071 m
.48729 .26176 L
s
.48729 .26176 m
.48723 .27036 L
s
.68 .237 1 r
.5761 .24808 m
.57621 .25726 L
s
.57624 .25721 m
.5761 .24808 L
s
.5761 .24808 m
.57641 .26599 L
s
.755 .219 1 r
.26208 .26556 m
.26132 .27477 L
s
.26139 .27473 m
.26208 .26556 L
s
.409 .309 1 r
.16215 .24444 m
.16118 .25289 L
s
.16119 .25285 m
.16215 .24444 L
s
.16215 .24444 m
.16034 .26085 L
s
.833 .201 1 r
.52377 .251 m
.52374 .26045 L
s
.52376 .2604 m
.52377 .251 L
s
.52377 .251 m
.52379 .26972 L
s
.648 .244 1 r
.31441 .26267 m
.31381 .27173 L
s
.31389 .27139 m
.31441 .26267 L
s
.755 .219 1 r
.26132 .27477 m
.26209 .26551 L
s
.26209 .26551 m
.26139 .27473 L
s
.648 .244 1 r
.31381 .27173 m
.31442 .26263 L
s
.31442 .26263 m
.31389 .27139 L
s
.916 .184 1 r
.72836 .26643 m
.72896 .27611 L
s
.72901 .27576 m
.72836 .26643 L
s
.72896 .27611 m
.72839 .26638 L
s
.72839 .26638 m
.72901 .27576 L
s
.799 .209 1 r
.78634 .28112 m
.78627 .28109 L
s
.424 .305 1 r
.71248 .25865 m
.71297 .26709 L
s
.713 .26675 m
.71248 .25865 L
s
.733 .224 1 r
.52271 .207 m
.52292 .25155 L
s
.94 .179 1 r
.20311 .207 m
.19861 .25421 L
s
.424 .305 1 r
.71297 .26709 m
.71251 .2586 L
s
.71251 .2586 m
.713 .26675 L
s
.459 .295 1 r
.13123 .27327 m
.13114 .27342 L
s
.4 .312 1 r
.56577 .25808 m
.56586 .26644 L
s
.56592 .2661 m
.56577 .25808 L
s
.56586 .26644 m
.56579 .25803 L
s
.56579 .25803 m
.56592 .2661 L
s
.811 .206 1 r
.34618 .27918 m
.34609 .27953 L
s
.649 .244 1 r
.57141 .27558 m
.57135 .27604 L
s
.811 .206 1 r
.72285 .24959 m
.7234 .25904 L
s
.72342 .25899 m
.72285 .24959 L
s
.72285 .24959 m
.72401 .26815 L
s
.904 .186 1 r
.32 .28085 m
.31991 .28117 L
s
.409 .309 1 r
.59194 .25694 m
.59211 .26541 L
s
.59216 .26481 m
.59194 .25694 L
s
.811 .206 1 r
.69563 .20672 m
.69828 .25204 L
s
.733 .224 1 r
.37598 .20672 m
.37408 .25242 L
s
.88 .191 1 r
.81256 .28021 m
.81253 .28056 L
s
.409 .309 1 r
.59211 .26541 m
.59197 .25689 L
s
.59197 .25689 m
.59216 .26481 L
s
.845 .199 1 r
.60784 .26502 m
.60808 .27454 L
s
.60813 .27419 m
.60784 .26502 L
s
.60808 .27454 m
.60786 .26497 L
s
.60786 .26497 m
.60813 .27419 L
s
.638 .247 1 r
.60229 .24769 m
.60247 .25672 L
s
.6025 .25667 m
.60229 .24769 L
s
.60229 .24769 m
.60274 .26544 L
s
1 .093 .6 r
.54889 .20645 m
.54954 .25747 L
s
.377 .542 1 r
.2292 .20645 m
.22587 .24456 L
s
.45 .297 1 r
.30406 .27337 m
.304 .27337 L
s
.799 .209 1 r
.23025 .25091 m
.22937 .26021 L
s
.22939 .26016 m
.23025 .25091 L
s
.23025 .25091 m
.22858 .26955 L
s
.342 .378 1 r
.38257 .26913 m
.38251 .26923 L
s
.648 .244 1 r
.45553 .24738 m
.45531 .25645 L
s
.45533 .2564 m
.45553 .24738 L
s
.45553 .24738 m
.45518 .26517 L
s
.56 .267 1 r
.39284 .25985 m
.39247 .26872 L
s
.39255 .26826 m
.39284 .25985 L
s
.39247 .26872 m
.39286 .25981 L
s
.39286 .25981 m
.39255 .26826 L
s
.416 .307 1 r
.27222 .25784 m
.27156 .26624 L
s
.27164 .26594 m
.27222 .25784 L
s
.916 .184 1 r
.72185 .20617 m
.72495 .25263 L
s
.388 .587 1 r
.40211 .20617 m
.40093 .24202 L
s
.416 .307 1 r
.27156 .26624 m
.27224 .25779 L
s
.27224 .25779 m
.27164 .26594 L
s
.834 .201 1 r
.63404 .26448 m
.63435 .27397 L
s
.63441 .27366 m
.63404 .26448 L
s
.63435 .27397 m
.63407 .26443 L
s
.63407 .26443 m
.63441 .27366 L
s
.648 .244 1 r
.62849 .24711 m
.62875 .25617 L
s
.62877 .25613 m
.62849 .24711 L
s
.62849 .24711 m
.62909 .2649 L
s
.628 .249 1 r
.36663 .26189 m
.36618 .27084 L
s
.36626 .27069 m
.36663 .26189 L
s
.559 .267 1 r
.477 .27348 m
.47693 .27383 L
s
.916 .184 1 r
.51908 .28005 m
.51901 .2804 L
s
.512 .279 1 r
.57508 .20589 m
.57596 .24818 L
s
.733 .224 1 r
.2553 .20589 m
.25168 .25159 L
s
.711 .229 1 r
.74442 .27644 m
.74438 .27679 L
s
.628 .249 1 r
.36618 .27084 m
.36665 .26185 L
s
.36665 .26185 m
.36626 .27069 L
s
.88 .191 1 r
.69206 .2794 m
.69202 .27975 L
s
.467 .292 1 r
.18338 .27219 m
.18329 .27238 L
s
.513 .279 1 r
.35637 .27155 m
.35628 .27204 L
s
.811 .206 1 r
.66025 .26364 m
.66064 .27309 L
s
.66069 .27274 m
.66025 .26364 L
s
.66064 .27309 m
.66027 .26359 L
s
.66027 .26359 m
.66069 .27274 L
s
.928 .181 1 r
.25633 .25062 m
.25551 .26027 L
s
.25552 .26022 m
.25633 .25062 L
s
.25633 .25062 m
.25477 .26977 L
s
.423 .733 1 r
.7481 .20561 m
.75067 .23996 L
s
.424 .305 1 r
.42827 .20561 m
.42726 .246 L
s
1 .161 .972 r
.42934 .25005 m
.42901 .26 L
s
.42903 .25995 m
.42934 .25005 L
s
.42934 .25005 m
.42879 .2695 L
s
.618 .252 1 r
.30868 .24789 m
.30806 .25677 L
s
.30808 .25673 m
.30868 .24789 L
s
.30868 .24789 m
.30752 .26565 L
s
.799 .209 1 r
.34042 .26394 m
.33988 .27331 L
s
.33996 .27312 m
.34042 .26394 L
s
.33988 .27331 m
.34044 .26389 L
s
.34044 .26389 m
.33996 .27312 L
s
.846 .199 1 r
.51344 .26337 m
.5134 .27293 L
s
.51346 .27247 m
.51344 .26337 L
s
.453 .844 1 r
.29834 .2575 m
.29826 .25798 L
s
.569 .264 1 r
.15713 .27424 m
.15705 .27439 L
s
.846 .199 1 r
.5134 .27293 m
.51346 .26332 L
s
.51346 .26332 m
.51346 .27247 L
s
.857 .196 1 r
.28248 .24963 m
.28174 .25913 L
s
.28176 .25908 m
.28248 .24963 L
s
.28248 .24963 m
.2811 .26847 L
s
.588 .259 1 r
.73884 .25991 m
.73942 .26882 L
s
.73946 .26848 m
.73884 .25991 L
s
.4 .312 1 r
.60129 .20533 m
.60245 .24535 L
s
.826 .203 1 r
.28141 .20533 m
.27832 .24914 L
s
.588 .259 1 r
.73942 .26882 m
.73886 .25986 L
s
.73886 .25986 m
.73946 .26848 L
s
.881 .191 1 r
.7183 .27887 m
.71826 .27922 L
s
.711 .229 1 r
.27774 .27693 m
.27767 .27705 L
s
.531 .274 1 r
.18797 .2464 m
.18704 .25505 L
s
.18705 .25501 m
.18797 .2464 L
s
.18797 .2464 m
.18619 .26371 L
s
.733 .224 1 r
.48169 .24788 m
.48153 .25711 L
s
.48156 .25706 m
.48169 .24788 L
s
.48169 .24788 m
.48147 .26614 L
s
.869 .194 1 r
.83334 .26397 m
.83425 .27354 L
s
.83428 .27323 m
.83334 .26397 L
s
.618 .252 1 r
.68093 .24579 m
.68133 .25479 L
s
.68136 .25474 m
.68093 .24579 L
s
.68093 .24579 m
.68181 .26344 L
s
.745 .221 1 r
.25153 .2786 m
.25147 .2785 L
s
.45 .297 1 r
.24034 .24363 m
.23956 .25216 L
s
.23958 .25212 m
.24034 .24363 L
s
.24034 .24363 m
.23889 .26035 L
s
.56026 .24363 m
.56032 .25216 L
s
.56034 .25212 m
.56026 .24363 L
s
.56026 .24363 m
.56046 .26035 L
s
.869 .194 1 r
.83425 .27354 m
.83338 .26392 L
s
.83338 .26392 m
.83428 .27323 L
s
.859 .196 1 r
.77435 .20506 m
.77813 .25038 L
s
.443 .299 1 r
.45444 .20506 m
.45378 .24469 L
s
.881 .191 1 r
.80162 .24806 m
.8024 .25771 L
s
.80243 .25766 m
.80162 .24806 L
s
.80162 .24806 m
.80325 .2669 L
s
.638 .247 1 r
.33011 .27435 m
.33002 .27465 L
s
.669 .239 1 r
.24588 .26138 m
.24508 .27045 L
s
.24517 .27026 m
.24588 .26138 L
s
.24508 .27045 m
.24589 .26134 L
s
.24589 .26134 m
.24517 .27026 L
s
.638 .247 1 r
.3348 .24761 m
.33425 .25653 L
s
.33426 .25649 m
.3348 .24761 L
s
.3348 .24761 m
.33377 .26549 L
s
.744 .222 1 r
.62386 .27602 m
.62381 .27636 L
s
.735 .224 1 r
.62751 .20478 m
.62916 .24896 L
s
.485 .287 1 r
.30754 .20478 m
.30483 .24783 L
s
.384 .317 1 r
.78104 .26751 m
.78102 .268 L
s
.777 .214 1 r
.82786 .24718 m
.8287 .25656 L
s
.82873 .25651 m
.82786 .24718 L
s
.82786 .24718 m
.82961 .2656 L
s
.733 .224 1 r
.77076 .27704 m
.7707 .27712 L
s
1 .146 .894 r
.80724 .26632 m
.80811 .27639 L
s
.80815 .27604 m
.80724 .26632 L
s
.443 .299 1 r
.75486 .26918 m
.75483 .26959 L
s
.503 .282 1 r
.32442 .25765 m
.32387 .26633 L
s
.32396 .26599 m
.32442 .25765 L
s
1 .146 .894 r
.80811 .27639 m
.80727 .26627 L
s
.80727 .26627 m
.80815 .27604 L
s
.845 .199 1 r
.80063 .2045 m
.8048 .25021 L
s
.669 .239 1 r
.48062 .2045 m
.48024 .24831 L
s
.503 .282 1 r
.32387 .26633 m
.32444 .25761 L
s
.32444 .25761 m
.32396 .26599 L
s
.94 .179 1 r
.68654 .2643 m
.68702 .27403 L
s
.68707 .27371 m
.68654 .2643 L
s
.531 .274 1 r
.40866 .27085 m
.40858 .2713 L
s
.94 .179 1 r
.68702 .27403 m
.68657 .26425 L
s
.68657 .26425 m
.68707 .27371 L
s
.368 .322 1 r
.69684 .25507 m
.69727 .26332 L
s
.69731 .26302 m
.69684 .25507 L
s
.669 .239 1 r
.797 .27613 m
.79693 .27609 L
s
.368 .322 1 r
.69727 .26332 m
.69686 .25503 L
s
.69686 .25503 m
.69731 .26302 L
s
.337 .352 1 r
.65374 .20422 m
.6555 .24273 L
s
.7 .232 1 r
.33369 .20422 m
.33125 .2488 L
s
.711 .229 1 r
.82322 .27483 m
.82319 .27518 L
s
.88 .191 1 r
.45077 .2778 m
.45069 .27815 L
s
.711 .229 1 r
.70722 .24592 m
.7077 .25514 L
s
.70773 .2551 m
.70722 .24592 L
s
.70722 .24592 m
.70826 .26403 L
s
1 .108 .687 r
.77556 .25107 m
.77633 .26157 L
s
.77636 .26152 m
.77556 .25107 L
s
.77556 .25107 m
.77718 .27161 L
s
.928 .181 1 r
.65482 .24899 m
.65517 .25864 L
s
.6552 .25859 m
.65482 .24899 L
s
.65482 .24899 m
.65561 .26814 L
s
.424 .305 1 r
.46104 .26864 m
.46098 .26898 L
s
.953 .176 1 r
.50788 .2483 m
.5078 .25807 L
s
.50782 .25802 m
.50788 .2483 L
s
.50788 .2483 m
.50781 .26749 L
s
.618 .252 1 r
.50681 .20394 m
.5068 .247 L
s
.744 .221 1 r
.76521 .26087 m
.7659 .27017 L
s
.76594 .26982 m
.76521 .26087 L
s
.559 .267 1 r
.17741 .25798 m
.17645 .26682 L
s
.17655 .26648 m
.17741 .25798 L
s
.929 .181 1 r
.36093 .24777 m
.36041 .2575 L
s
.36043 .25745 m
.36093 .24777 L
s
.36093 .24777 m
.35999 .26684 L
s
.744 .221 1 r
.7659 .27017 m
.76524 .26082 L
s
.76524 .26082 m
.76594 .26982 L
s
.559 .267 1 r
.17645 .26682 m
.17742 .25794 L
s
.17742 .25794 m
.17655 .26648 L
s
.345 .391 1 r
.19333 .26605 m
.19325 .26624 L
s
.618 .252 1 r
.55558 .27263 m
.55552 .27297 L
s
1 .161 .972 r
.59772 .2792 m
.59766 .27967 L
s
.733 .224 1 r
.67634 .27494 m
.67629 .27525 L
s
.68 .237 1 r
.73347 .24515 m
.73402 .2543 L
s
.73405 .25425 m
.73347 .24515 L
s
.73347 .24515 m
.73465 .26311 L
s
.8 .209 1 r
.38712 .24663 m
.38669 .25605 L
s
.38671 .256 m
.38712 .24663 L
s
.38712 .24663 m
.38636 .26517 L
s
.94 .179 1 r
.67999 .20366 m
.6825 .25053 L
s
.386 .316 1 r
.35985 .20366 m
.3582 .23991 L
s
.357 .451 1 r
.51815 .23938 m
.51811 .2473 L
s
.51813 .24726 m
.51815 .23938 L
s
.51815 .23938 m
.51814 .25488 L
s
.917 .184 1 r
.53964 .26494 m
.53967 .27448 L
s
.53974 .27458 m
.53964 .26494 L
s
.56 .267 1 r
.61272 .2431 m
.61293 .25198 L
s
.61295 .25193 m
.61272 .2431 L
s
.61272 .2431 m
.61321 .2604 L
s
.822 .204 1 r
.21393 .2475 m
.213 .25692 L
s
.21302 .25687 m
.21393 .2475 L
s
.21393 .2475 m
.21216 .26619 L
s
.917 .184 1 r
.53967 .27448 m
.53966 .26489 L
s
.53966 .26489 m
.53974 .27458 L
s
.588 .259 1 r
.75969 .24393 m
.76031 .25285 L
s
.76033 .2528 m
.75969 .24393 L
s
.75969 .24393 m
.76099 .26143 L
s
.589 .259 1 r
.43953 .24393 m
.43927 .25285 L
s
.43929 .2528 m
.43953 .24393 L
s
.43953 .24393 m
.4391 .26143 L
s
.476 .29 1 r
.53303 .20338 m
.53335 .24455 L
s
.618 .252 1 r
.21284 .20338 m
.2089 .24607 L
s
.88 .191 1 r
.65016 .27699 m
.6501 .27734 L
s
.744 .222 1 r
.4713 .26033 m
.47114 .26963 L
s
.47121 .26928 m
.4713 .26033 L
s
.365 .486 1 r
.41889 .2632 m
.41882 .26353 L
s
.744 .222 1 r
.47114 .26963 m
.47132 .26028 L
s
.47132 .26028 m
.47121 .26928 L
s
1 .149 .908 r
.21945 .26554 m
.21849 .27554 L
s
.21858 .27534 m
.21945 .26554 L
s
.691 .234 1 r
.35052 .25832 m
.35001 .26757 L
s
.35011 .26696 m
.35052 .25832 L
s
1 .149 .908 r
.21849 .27554 m
.21946 .26549 L
s
.21946 .26549 m
.21858 .27534 L
s
.777 .214 1 r
.58653 .24521 m
.58667 .25463 L
s
.5867 .25458 m
.58653 .24521 L
s
.58653 .24521 m
.5869 .26359 L
s
.20916 .27505 m
.20906 .2754 L
s
.691 .234 1 r
.35001 .26757 m
.35054 .25827 L
s
.35054 .25827 m
.35011 .26696 L
s
1 .161 .972 r
.5341 .24821 m
.53409 .25813 L
s
.53412 .25808 m
.5341 .24821 L
s
.5341 .24821 m
.53418 .26771 L
s
.744 .222 1 r
.70625 .20311 m
.70901 .24769 L
s
.477 .289 1 r
.38602 .2031 m
.38445 .24427 L
s
.58 .261 1 r
.37672 .25717 m
.3763 .26608 L
s
.37639 .26566 m
.37672 .25717 L
s
.845 .199 1 r
.4133 .24627 m
.41294 .25581 L
s
.41296 .25576 m
.4133 .24627 L
s
.4133 .24627 m
.41268 .265 L
s
.58 .261 1 r
.3763 .26608 m
.37674 .25712 L
s
.37674 .25712 m
.37639 .26566 L
s
.916 .184 1 r
.44508 .26238 m
.44483 .27207 L
s
.44491 .27172 m
.44508 .26238 L
s
.44483 .27207 m
.4451 .26233 L
s
.4451 .26233 m
.44491 .27172 L
s
.54 .272 1 r
.28777 .27117 m
.2877 .27132 L
s
.459 .294 1 r
.14073 .27053 m
.14068 .27045 L
s
.494 .284 1 r
.40292 .25603 m
.40259 .26467 L
s
.40266 .26437 m
.40292 .25603 L
s
.811 .206 1 r
.55925 .20283 m
.55998 .24817 L
s
.55 .269 1 r
.63897 .24293 m
.63925 .25173 L
s
.63928 .25169 m
.63897 .24293 L
s
.63897 .24293 m
.63961 .26023 L
s
.766 .217 1 r
.23898 .20283 m
.23516 .24817 L
s
.494 .284 1 r
.40259 .26467 m
.40294 .25598 L
s
.40294 .25598 m
.40266 .26437 L
s
.648 .244 1 r
.20345 .25835 m
.20253 .26741 L
s
.20263 .26707 m
.20345 .25835 L
s
.559 .267 1 r
.54995 .2569 m
.55001 .26573 L
s
.55007 .26539 m
.54995 .2569 L
s
.845 .199 1 r
.52939 .27581 m
.52932 .27616 L
s
.648 .244 1 r
.20253 .26741 m
.20346 .2583 L
s
.20346 .2583 m
.20263 .26707 L
s
.559 .267 1 r
.55001 .26573 m
.54998 .25685 L
s
.54998 .25685 m
.55007 .26539 L
s
.531 .274 1 r
.17165 .24239 m
.17066 .25116 L
s
.17068 .25111 m
.17165 .24239 L
s
.17165 .24239 m
.16979 .25958 L
s
.893 .189 1 r
.64456 .26066 m
.64491 .27039 L
s
.64495 .26977 m
.64456 .26066 L
s
.722 .227 1 r
.2353 .27452 m
.23522 .27467 L
s
.893 .189 1 r
.64491 .27039 m
.64458 .26061 L
s
.64458 .26061 m
.64495 .26977 L
s
.892 .189 1 r
.50316 .27748 m
.50309 .27764 L
s
.777 .214 1 r
.49751 .26009 m
.49742 .26947 L
s
.49749 .26912 m
.49751 .26009 L
s
.766 .217 1 r
.73253 .20255 m
.73569 .24752 L
s
.618 .252 1 r
.41221 .20255 m
.41092 .24562 L
s
.789 .211 1 r
.58184 .27322 m
.58179 .27383 L
s
.777 .214 1 r
.49742 .26947 m
.49753 .26004 L
s
.49753 .26004 m
.49749 .26912 L
s
.476 .29 1 r
.1669 .26961 m
.16682 .26972 L
s
1 .166 .996 r
.61834 .26241 m
.61862 .27233 L
s
.61868 .27182 m
.61834 .26241 L
s
.845 .199 1 r
.70267 .27554 m
.70262 .27589 L
s
1 .166 .996 r
.61862 .27233 m
.61837 .26236 L
s
.61837 .26236 m
.61868 .27182 L
s
.857 .196 1 r
.2662 .24663 m
.26541 .25614 L
s
.26543 .25609 m
.2662 .24663 L
s
.2662 .24663 m
.26472 .26549 L
s
.559 .267 1 r
.34487 .24234 m
.34435 .25118 L
s
.34437 .25114 m
.34487 .24234 L
s
.34487 .24234 m
.34393 .25969 L
s
.618 .252 1 r
.58549 .20227 m
.58654 .24534 L
s
.503 .282 1 r
.26513 .20227 m
.26191 .24458 L
s
.734 .224 1 r
.43478 .27295 m
.4347 .27337 L
s
.598 .257 1 r
.2924 .24531 m
.29175 .25408 L
s
.29176 .25404 m
.2924 .24531 L
s
.2924 .24531 m
.29115 .26305 L
s
.811 .206 1 r
.67082 .26012 m
.67124 .26958 L
s
.67129 .26923 m
.67082 .26012 L
s
.531 .274 1 r
.74951 .25579 m
.75011 .26454 L
s
.75015 .2642 m
.74951 .25579 L
s
.409 .309 1 r
.16118 .25289 m
.16022 .26134 L
s
.16034 .26085 m
.16118 .25289 L
s
.811 .206 1 r
.67124 .26958 m
.67084 .26007 L
s
.67084 .26007 m
.67129 .26923 L
s
.588 .259 1 r
.48723 .27036 m
.48716 .27071 L
s
.531 .274 1 r
.75011 .26454 m
.74953 .25574 L
s
.74953 .25574 m
.75015 .2642 L
s
.928 .181 1 r
.15087 .26244 m
.14974 .27209 L
s
.14983 .27193 m
.15087 .26244 L
s
.424 .305 1 r
.713 .26675 m
.71297 .26709 L
s
.409 .309 1 r
.16022 .26134 m
.16119 .25285 L
s
.16119 .25285 m
.16034 .26085 L
s
.393 .314 1 r
.42354 .23838 m
.42325 .24684 L
s
.42327 .24679 m
.42354 .23838 L
s
.42354 .23838 m
.42306 .25465 L
s
.928 .181 1 r
.14974 .27209 m
.15088 .26239 L
s
.15088 .26239 m
.14983 .27193 L
s
.4 .312 1 r
.56592 .2661 m
.56586 .26644 L
s
.377 .541 1 r
.75883 .20199 m
.76167 .23824 L
s
.618 .252 1 r
.43841 .20199 m
.43748 .24507 L
s
.409 .309 1 r
.59216 .26481 m
.59211 .26541 L
s
.648 .244 1 r
.31389 .27139 m
.31381 .27173 L
s
.476 .29 1 r
.5444 .24085 m
.54442 .24946 L
s
.54444 .24942 m
.5444 .24085 L
s
.5444 .24085 m
.54453 .25774 L
s
.916 .184 1 r
.81794 .2613 m
.81881 .27099 L
s
.81885 .27064 m
.81794 .2613 L
s
.81881 .27099 m
.81797 .26125 L
s
.81797 .26125 m
.81885 .27064 L
s
.38 .554 1 r
.79644 .23591 m
.79706 .24364 L
s
.79709 .2436 m
.79644 .23591 L
s
.79644 .23591 m
.79773 .25091 L
s
.391 .315 1 r
.61175 .20171 m
.61305 .24176 L
s
.649 .244 1 r
.29129 .20171 m
.28838 .24479 L
s
.679 .237 1 r
.31858 .24479 m
.31798 .25384 L
s
.31799 .25379 m
.31858 .24479 L
s
.31858 .24479 m
.31745 .26288 L
s
.68 .237 1 r
.57621 .25726 m
.57635 .26644 L
s
.57641 .26599 m
.57621 .25726 L
s
.755 .219 1 r
.26139 .27473 m
.26132 .27477 L
s
.68 .237 1 r
.57635 .26644 m
.57624 .25721 L
s
.57624 .25721 m
.57641 .26599 L
s
.833 .201 1 r
.52374 .26045 m
.52373 .26991 L
s
.52379 .26972 m
.52374 .26045 L
s
.485 .287 1 r
.22391 .24149 m
.22308 .25006 L
s
.2231 .25002 m
.22391 .24149 L
s
.22391 .24149 m
.22235 .25849 L
s
.811 .206 1 r
.49194 .24441 m
.49181 .25387 L
s
.49183 .25382 m
.49194 .24441 L
s
.49194 .24441 m
.49178 .26299 L
s
.916 .184 1 r
.72901 .27576 m
.72896 .27611 L
s
.833 .201 1 r
.52373 .26991 m
.52376 .2604 L
s
.52376 .2604 m
.52379 .26972 L
s
.799 .209 1 r
.78514 .20143 m
.78906 .24679 L
s
.542 .271 1 r
.46463 .20143 m
.46407 .24299 L
s
.779 .213 1 r
.37105 .24235 m
.37057 .25184 L
s
.37059 .25179 m
.37105 .24235 L
s
.37105 .24235 m
.3702 .26065 L
s
.766 .217 1 r
.66532 .24395 m
.66569 .2533 L
s
.66571 .25325 m
.66532 .24395 L
s
.66532 .24395 m
.66614 .26234 L
s
.416 .307 1 r
.27164 .26594 m
.27156 .26624 L
s
.881 .191 1 r
.81248 .24485 m
.8133 .25447 L
s
.81333 .25442 m
.81248 .24485 L
s
.81248 .24485 m
.81418 .26375 L
s
.701 .231 1 r
.63802 .20115 m
.6398 .24499 L
s
.335 .341 1 r
.31747 .20115 m
.31515 .24006 L
s
1 .121 .757 r
.79181 .26395 m
.79266 .27434 L
s
.79269 .27383 m
.79181 .26395 L
s
.56 .267 1 r
.39255 .26826 m
.39247 .26872 L
s
.638 .247 1 r
.60247 .25672 m
.60268 .26575 L
s
.60274 .26544 m
.60247 .25672 L
s
1 .121 .757 r
.79266 .27434 m
.79185 .26389 L
s
.79185 .26389 m
.79269 .27383 L
s
1 .154 .933 r
.4657 .24652 m
.46548 .25653 L
s
.4655 .25647 m
.4657 .24652 L
s
.4657 .24652 m
.46536 .26619 L
s
.845 .199 1 r
.60813 .27419 m
.60808 .27454 L
s
.512 .279 1 r
.39725 .24144 m
.39688 .25009 L
s
.3969 .25005 m
.39725 .24144 L
s
.39725 .24144 m
.3966 .2586 L
s
.638 .247 1 r
.60268 .26575 m
.6025 .25667 L
s
.6025 .25667 m
.60274 .26544 L
s
.811 .206 1 r
.7234 .25904 m
.72397 .2685 L
s
.72401 .26815 m
.7234 .25904 L
s
.72397 .2685 m
.72342 .25899 L
s
.72342 .25899 m
.72401 .26815 L
s
.799 .209 1 r
.81146 .20087 m
.81576 .24624 L
s
.467 .292 1 r
.49087 .20087 m
.49064 .24244 L
s
1 .156 .947 r
.78629 .2469 m
.78705 .25683 L
s
.78708 .25678 m
.78629 .2469 L
s
.78629 .2469 m
.7879 .26657 L
s
.648 .244 1 r
.45531 .25645 m
.4551 .26552 L
s
.45518 .26517 m
.45531 .25645 L
s
.7 .232 1 r
.6916 .24329 m
.69204 .25245 L
s
.69206 .2524 m
.6916 .24329 L
s
.6916 .24329 m
.69256 .26141 L
s
.648 .244 1 r
.4551 .26552 m
.45533 .2564 L
s
.45533 .2564 m
.45518 .26517 L
s
.799 .209 1 r
.22937 .26021 m
.22851 .26952 L
s
.22858 .26955 m
.22937 .26021 L
s
.22851 .26952 m
.22939 .26016 L
s
.22939 .26016 m
.22858 .26955 L
s
.618 .252 1 r
.66431 .20059 m
.66641 .24368 L
s
.857 .196 1 r
.34367 .20059 m
.34127 .2471 L
s
.628 .249 1 r
.36626 .27069 m
.36618 .27084 L
s
.648 .244 1 r
.62875 .25617 m
.62903 .26524 L
s
.62909 .2649 m
.62875 .25617 L
s
.67 .239 1 r
.25003 .24156 m
.24923 .25072 L
s
.24924 .25067 m
.25003 .24156 L
s
.25003 .24156 m
.24854 .25946 L
s
.834 .201 1 r
.63441 .27366 m
.63435 .27397 L
s
.648 .244 1 r
.62903 .26524 m
.62877 .25613 L
s
.62877 .25613 m
.62909 .2649 L
s
.638 .247 1 r
.57068 .24168 m
.57077 .25073 L
s
.5708 .25068 m
.57068 .24168 L
s
.57068 .24168 m
.57095 .25946 L
s
.503 .282 1 r
.44972 .2397 m
.44949 .2484 L
s
.44951 .24835 m
.44972 .2397 L
s
.44972 .2397 m
.44935 .25675 L
s
.881 .191 1 r
.51711 .20031 m
.51724 .24606 L
s
.531 .274 1 r
.77042 .23993 m
.77105 .2487 L
s
.77108 .24865 m
.77042 .23993 L
s
.77042 .23993 m
.77175 .25713 L
s
.811 .206 1 r
.66069 .27274 m
.66064 .27309 L
s
.618 .252 1 r
.30806 .25677 m
.30745 .26566 L
s
.30752 .26565 m
.30806 .25677 L
s
.833 .201 1 r
.19746 .24514 m
.19648 .25453 L
s
.1965 .25448 m
.19746 .24514 L
s
.19746 .24514 m
.19558 .26396 L
s
.618 .252 1 r
.30745 .26566 m
.30808 .25673 L
s
.30808 .25673 m
.30752 .26565 L
s
.588 .259 1 r
.73946 .26848 m
.73942 .26882 L
s
.777 .214 1 r
.69061 .20003 m
.69317 .24503 L
s
1 .111 .702 r
.36988 .20003 m
.3677 .25036 L
s
.799 .209 1 r
.33996 .27312 m
.33988 .27331 L
s
.846 .199 1 r
.51346 .27247 m
.5134 .27293 L
s
.531 .274 1 r
.18704 .25505 m
.18612 .26371 L
s
.18619 .26371 m
.18704 .25505 L
s
.45 .297 1 r
.23956 .25216 m
.2388 .26069 L
s
.23889 .26035 m
.23956 .25216 L
s
.56032 .25216 m
.56041 .26069 L
s
.56046 .26035 m
.56032 .25216 L
s
.531 .274 1 r
.18612 .26371 m
.18705 .25501 L
s
.18705 .25501 m
.18619 .26371 L
s
.45 .297 1 r
.2388 .26069 m
.23958 .25212 L
s
.23958 .25212 m
.23889 .26035 L
s
.56041 .26069 m
.56034 .25212 L
s
.56034 .25212 m
.56046 .26035 L
s
.928 .181 1 r
.25551 .26027 m
.25469 .26993 L
s
.25477 .26977 m
.25551 .26027 L
s
.25469 .26993 m
.25552 .26022 L
s
.25552 .26022 m
.25477 .26977 L
s
.845 .199 1 r
.54338 .19975 m
.54388 .24551 L
s
.701 .231 1 r
.2226 .19975 m
.21847 .24589 L
s
.628 .249 1 r
.27617 .24151 m
.27546 .25048 L
s
.27547 .25043 m
.27617 .24151 L
s
.27617 .24151 m
.27483 .25929 L
s
.916 .184 1 r
.71797 .24371 m
.71852 .25341 L
s
.71854 .25336 m
.71797 .24371 L
s
.71797 .24371 m
.71914 .26276 L
s
.777 .214 1 r
.74423 .24227 m
.74483 .25166 L
s
.74486 .25161 m
.74423 .24227 L
s
.74423 .24227 m
.74551 .2607 L
s
.857 .196 1 r
.28174 .25913 m
.28102 .26863 L
s
.2811 .26847 m
.28174 .25913 L
s
.618 .252 1 r
.68133 .25479 m
.68176 .26378 L
s
.68181 .26344 m
.68133 .25479 L
s
.857 .196 1 r
.28102 .26863 m
.28176 .25908 L
s
.28176 .25908 m
.2811 .26847 L
s
.618 .252 1 r
.68176 .26378 m
.68136 .25474 L
s
.68136 .25474 m
.68181 .26344 L
s
1 .161 .972 r
.42901 .26 m
.42871 .26997 L
s
.42879 .2695 m
.42901 .26 L
s
.733 .224 1 r
.48153 .25711 m
.4814 .26634 L
s
.48147 .26614 m
.48153 .25711 L
s
1 .161 .972 r
.42871 .26997 m
.42903 .25995 L
s
.42903 .25995 m
.42879 .2695 L
s
.36 .324 1 r
.71692 .19947 m
.71947 .2384 L
s
.395 .62 1 r
.3961 .19947 m
.39485 .23537 L
s
.669 .239 1 r
.24517 .27026 m
.24508 .27045 L
s
.733 .224 1 r
.4814 .26634 m
.48156 .25706 L
s
.48156 .25706 m
.48147 .26614 L
s
.869 .194 1 r
.83428 .27323 m
.83425 .27354 L
s
.368 .322 1 r
.69731 .26302 m
.69727 .26332 L
s
.638 .247 1 r
.33425 .25653 m
.33371 .26546 L
s
.33377 .26549 m
.33425 .25653 L
s
.503 .282 1 r
.32396 .26599 m
.32387 .26633 L
s
.638 .247 1 r
.33371 .26546 m
.33426 .25649 L
s
.33426 .25649 m
.33377 .26549 L
s
.531 .274 1 r
.56965 .19919 m
.57046 .24115 L
s
.904 .186 1 r
.24879 .19919 m
.24498 .2461 L
s
.881 .191 1 r
.8024 .25771 m
.80323 .26736 L
s
.80325 .2669 m
.8024 .25771 L
s
.80323 .26736 m
.80243 .25766 L
s
.80243 .25766 m
.80325 .2669 L
s
.917 .184 1 r
.597 .24255 m
.59718 .25229 L
s
.59721 .25224 m
.597 .24255 L
s
.597 .24255 m
.59745 .26157 L
s
.777 .214 1 r
.62327 .24111 m
.62352 .25053 L
s
.62355 .25049 m
.62327 .24111 L
s
.62327 .24111 m
.62386 .2595 L
s
.441 .3 1 r
.3549 .23826 m
.35443 .24672 L
s
.35445 .24668 m
.3549 .23826 L
s
.3549 .23826 m
.35404 .255 L
s
.777 .214 1 r
.8287 .25656 m
.82958 .26595 L
s
.82961 .2656 m
.8287 .25656 L
s
.892 .189 1 r
.74325 .19891 m
.7467 .24582 L
s
.777 .214 1 r
.42234 .19891 m
.42114 .24392 L
s
.82958 .26595 m
.82873 .25651 L
s
.82873 .25651 m
.82961 .2656 L
s
.357 .451 1 r
.51811 .2473 m
.51809 .25522 L
s
.51814 .25488 m
.51811 .2473 L
s
.588 .259 1 r
.18129 .23928 m
.18032 .2482 L
s
.18033 .24816 m
.18129 .23928 L
s
.18129 .23928 m
.17946 .25679 L
s
.357 .451 1 r
.51809 .25522 m
.51813 .24726 L
s
.51813 .24726 m
.51814 .25488 L
s
.94 .179 1 r
.68707 .27371 m
.68702 .27403 L
s
.559 .267 1 r
.17655 .26648 m
.17645 .26682 L
s
.711 .229 1 r
.59595 .19863 m
.59716 .24288 L
s
.467 .292 1 r
.27499 .19863 m
.27195 .24022 L
s
1 .146 .894 r
.80815 .27604 m
.80811 .27639 L
s
.67 .239 1 r
.50222 .23965 m
.50213 .24881 L
s
.50215 .24876 m
.50222 .23965 L
s
.50222 .23965 m
.50213 .25755 L
s
.711 .229 1 r
.7077 .25514 m
.70822 .26437 L
s
.70826 .26403 m
.7077 .25514 L
s
.70822 .26437 m
.70773 .2551 L
s
.70773 .2551 m
.70826 .26403 L
s
.352 .327 1 r
.40741 .23623 m
.40709 .24443 L
s
.40711 .24438 m
.40741 .23623 L
s
.40741 .23623 m
.40685 .2524 L
s
.744 .221 1 r
.76594 .26982 m
.7659 .27017 L
s
.799 .209 1 r
.47594 .24144 m
.47577 .25087 L
s
.47579 .25082 m
.47594 .24144 L
s
.47594 .24144 m
.47569 .25999 L
s
.36 .324 1 r
.7696 .19835 m
.77279 .23729 L
s
.531 .274 1 r
.4486 .19835 m
.4478 .24108 L
s
.69 .234 1 r
.32857 .24086 m
.32799 .24999 L
s
.32801 .24994 m
.32857 .24086 L
s
.32857 .24086 m
.3275 .25896 L
s
.375 .32 1 r
.58106 .23584 m
.58117 .24415 L
s
.58119 .24411 m
.58106 .23584 L
s
.58106 .23584 m
.58136 .25212 L
s
.56 .267 1 r
.61293 .25198 m
.61316 .26085 L
s
.61321 .2604 m
.61293 .25198 L
s
.61316 .26085 m
.61295 .25193 L
s
.61295 .25193 m
.61321 .2604 L
s
.928 .181 1 r
.65517 .25864 m
.65555 .26831 L
s
.65561 .26814 m
.65517 .25864 L
s
.68 .237 1 r
.73402 .2543 m
.73461 .26345 L
s
.73465 .26311 m
.73402 .2543 L
s
.588 .259 1 r
.76031 .25285 m
.76095 .26177 L
s
.76099 .26143 m
.76031 .25285 L
s
.589 .259 1 r
.43927 .25285 m
.43902 .26177 L
s
.4391 .26143 m
.43927 .25285 L
s
.928 .181 1 r
.65555 .26831 m
.6552 .25859 L
s
.6552 .25859 m
.65561 .26814 L
s
.417 .307 1 r
.62225 .19807 m
.62369 .23814 L
s
.701 .231 1 r
.30121 .19807 m
.2982 .24423 L
s
.68 .237 1 r
.73461 .26345 m
.73405 .25425 L
s
.73405 .25425 m
.73465 .26311 L
s
.588 .259 1 r
.76095 .26177 m
.76033 .2528 L
s
.76033 .2528 m
.76099 .26143 L
s
.589 .259 1 r
.43902 .26177 m
.43929 .2528 L
s
.43929 .2528 m
.4391 .26143 L
s
.953 .176 1 r
.5078 .25807 m
.50774 .26784 L
s
.50781 .26749 m
.5078 .25807 L
s
.467 .292 1 r
.23372 .23766 m
.23293 .2462 L
s
.23294 .24616 m
.23372 .23766 L
s
.23372 .23766 m
.23222 .25456 L
s
.953 .176 1 r
.50774 .26784 m
.50782 .25802 L
s
.50782 .25802 m
.50781 .26749 L
s
.88 .191 1 r
.30226 .2428 m
.30158 .25235 L
s
.3016 .2523 m
.30226 .2428 L
s
.30226 .2428 m
.30098 .26178 L
s
.929 .181 1 r
.36041 .2575 m
.3599 .26723 L
s
.35999 .26684 m
.36041 .2575 L
s
.8 .209 1 r
.38669 .25605 m
.38628 .26548 L
s
.38636 .26517 m
.38669 .25605 L
s
.691 .234 1 r
.35011 .26696 m
.35001 .26757 L
s
.929 .181 1 r
.3599 .26723 m
.36043 .25745 L
s
.36043 .25745 m
.35999 .26684 L
s
.8 .209 1 r
.38628 .26548 m
.38671 .256 L
s
.38671 .256 m
.38636 .26517 L
s
.733 .224 1 r
.82329 .24077 m
.82411 .25001 L
s
.82414 .24997 m
.82329 .24077 L
s
.82329 .24077 m
.82501 .25906 L
s
.822 .204 1 r
.213 .25692 m
.21208 .26635 L
s
.21216 .26619 m
.213 .25692 L
s
.744 .222 1 r
.47121 .26928 m
.47114 .26963 L
s
.58 .261 1 r
.37639 .26566 m
.3763 .26608 L
s
.822 .204 1 r
.21208 .26635 m
.21302 .25687 L
s
.21302 .25687 m
.21216 .26619 L
s
.869 .194 1 r
.79596 .19779 m
.80011 .24395 L
s
.811 .206 1 r
.47487 .19779 m
.4744 .24281 L
s
.917 .184 1 r
.53974 .27458 m
.53967 .27448 L
s
.494 .284 1 r
.40266 .26437 m
.40259 .26467 L
s
1 .108 .687 r
.77633 .26157 m
.77714 .27209 L
s
.77718 .27161 m
.77633 .26157 L
s
.77714 .27209 m
.77636 .26152 L
s
.77636 .26152 m
.77718 .27161 L
s
.953 .176 1 r
.64964 .24202 m
.64999 .2518 L
s
.65001 .25175 m
.64964 .24202 L
s
.64964 .24202 m
.65041 .26123 L
s
.559 .267 1 r
.55007 .26539 m
.55001 .26573 L
s
.733 .224 1 r
.52851 .23989 m
.52849 .24917 L
s
.52851 .24912 m
.52851 .23989 L
s
.52851 .23989 m
.52855 .25814 L
s
.68 .237 1 r
.64858 .19751 m
.65049 .24101 L
s
.904 .186 1 r
.32744 .19751 m
.32481 .24405 L
s
.777 .214 1 r
.58667 .25463 m
.58685 .26405 L
s
.5869 .26359 m
.58667 .25463 L
s
.55 .269 1 r
.63925 .25173 m
.63956 .26054 L
s
.63961 .26023 m
.63925 .25173 L
s
.777 .214 1 r
.58685 .26405 m
.5867 .25458 L
s
.5867 .25458 m
.5869 .26359 L
s
.648 .244 1 r
.20263 .26707 m
.20253 .26741 L
s
.55 .269 1 r
.63956 .26054 m
.63928 .25169 L
s
.63928 .25169 m
.63961 .26023 L
s
.531 .274 1 r
.17066 .25116 m
.16969 .25992 L
s
.16979 .25958 m
.17066 .25116 L
s
.578 .262 1 r
.38106 .23951 m
.38064 .24829 L
s
.38066 .24824 m
.38106 .23951 L
s
.38106 .23951 m
.3803 .25711 L
s
.531 .274 1 r
.16969 .25992 m
.17068 .25111 L
s
.17068 .25111 m
.16979 .25958 L
s
.744 .221 1 r
.70225 .23957 m
.70272 .24889 L
s
.70275 .24884 m
.70225 .23957 L
s
.70225 .23957 m
.70328 .25786 L
s
1 .149 .908 r
.21858 .27534 m
.21849 .27554 L
s
.618 .252 1 r
.72854 .23813 m
.72907 .24714 L
s
.7291 .24709 m
.72854 .23813 L
s
.72854 .23813 m
.72968 .2558 L
s
.916 .184 1 r
.44491 .27172 m
.44483 .27207 L
s
1 .149 .908 r
.50115 .19723 m
.50104 .24606 L
s
.845 .199 1 r
.41294 .25581 m
.4126 .26535 L
s
.41268 .265 m
.41294 .25581 L
s
.409 .309 1 r
.16034 .26085 m
.16022 .26134 L
s
.845 .199 1 r
.4126 .26535 m
.41296 .25576 L
s
.41296 .25576 m
.41268 .265 L
s
.904 .186 1 r
.67597 .24129 m
.67638 .25095 L
s
.67641 .2509 m
.67597 .24129 L
s
.67597 .24129 m
.67688 .26031 L
s
1 .161 .972 r
.53409 .25813 m
.53411 .26806 L
s
.53418 .26771 m
.53409 .25813 L
s
.893 .189 1 r
.64495 .26977 m
.64491 .27039 L
s
1 .161 .972 r
.53411 .26806 m
.53412 .25808 L
s
.53412 .25808 m
.53418 .26771 L
s
.777 .214 1 r
.49749 .26912 m
.49742 .26947 L
s
.799 .209 1 r
.2073 .24067 m
.20635 .25007 L
s
.20637 .25002 m
.2073 .24067 L
s
.2073 .24067 m
.2055 .25927 L
s
.38 .554 1 r
.79706 .24364 m
.79771 .25136 L
s
.79773 .25091 m
.79706 .24364 L
s
.79771 .25136 m
.79709 .2436 L
s
.79709 .2436 m
.79773 .25091 L
s
.701 .232 1 r
.67491 .19695 m
.67722 .24121 L
s
.476 .924 1 r
.35369 .19695 m
.35215 .22871 L
s
.531 .274 1 r
.75015 .2642 m
.75011 .26454 L
s
.598 .257 1 r
.29175 .25408 m
.2911 .26286 L
s
.29115 .26305 m
.29175 .25408 L
s
.559 .267 1 r
.34435 .25118 m
.34385 .26003 L
s
.34393 .25969 m
.34435 .25118 L
s
.551 .269 1 r
.60741 .23655 m
.60761 .24541 L
s
.60763 .24536 m
.60741 .23655 L
s
.60741 .23655 m
.60788 .25384 L
s
.393 .314 1 r
.42325 .24684 m
.42298 .25529 L
s
.42306 .25465 m
.42325 .24684 L
s
.598 .257 1 r
.2911 .26286 m
.29176 .25404 L
s
.29176 .25404 m
.29115 .26305 L
s
.559 .267 1 r
.34385 .26003 m
.34437 .25114 L
s
.34437 .25114 m
.34393 .25969 L
s
.393 .314 1 r
.42298 .25529 m
.42327 .24679 L
s
.42327 .24679 m
.42306 .25465 L
s
1 .166 .996 r
.61868 .27182 m
.61862 .27233 L
s
.811 .206 1 r
.55482 .23975 m
.55488 .24922 L
s
.5549 .24917 m
.55482 .23975 L
s
.55482 .23975 m
.55502 .25835 L
s
.4 .312 1 r
.52745 .19667 m
.52769 .23675 L
s
.476 .29 1 r
.54442 .24946 m
.54447 .25808 L
s
.54453 .25774 m
.54442 .24946 L
s
.648 .244 1 r
.75492 .2378 m
.75553 .24689 L
s
.75556 .24684 m
.75492 .2378 L
s
.75492 .2378 m
.75621 .25563 L
s
.476 .29 1 r
.54447 .25808 m
.54444 .24942 L
s
.54444 .24942 m
.54453 .25774 L
s
.857 .196 1 r
.26541 .25614 m
.26464 .26564 L
s
.26472 .26549 m
.26541 .25614 L
s
.811 .206 1 r
.67129 .26923 m
.67124 .26958 L
s
.857 .196 1 r
.26464 .26564 m
.26543 .25609 L
s
.26543 .25609 m
.26472 .26549 L
s
.648 .244 1 r
.70126 .19639 m
.70389 .23989 L
s
.669 .239 1 r
.37995 .19639 m
.37813 .24141 L
s
.68 .237 1 r
.57641 .26599 m
.57635 .26644 L
s
.485 .287 1 r
.22308 .25006 m
.22227 .25864 L
s
.22235 .25849 m
.22308 .25006 L
s
.928 .181 1 r
.14983 .27193 m
.14974 .27209 L
s
.485 .287 1 r
.22227 .25864 m
.2231 .25002 L
s
.2231 .25002 m
.22235 .25849 L
s
.679 .237 1 r
.31798 .25384 m
.31739 .26288 L
s
.31745 .26288 m
.31798 .25384 L
s
.916 .184 1 r
.81885 .27064 m
.81881 .27099 L
s
.589 .259 1 r
.55376 .19611 m
.55437 .23848 L
s
.2324 .19611 m
.22875 .23847 L
s
.679 .237 1 r
.31739 .26288 m
.31799 .25379 L
s
.31799 .25379 m
.31745 .26288 L
s
.977 .171 1 r
.72763 .19583 m
.7309 .24352 L
s
.467 .292 1 r
.40622 .19583 m
.40486 .2382 L
s
.833 .201 1 r
.52379 .26972 m
.52373 .26991 L
s
.512 .279 1 r
.39688 .25009 m
.39653 .25875 L
s
.3966 .2586 m
.39688 .25009 L
s
.638 .247 1 r
.60274 .26544 m
.60268 .26575 L
s
.512 .279 1 r
.39653 .25875 m
.3969 .25005 L
s
.3969 .25005 m
.3966 .2586 L
s
.834 .201 1 r
.4336 .23919 m
.4333 .2487 L
s
.43332 .24865 m
.4336 .23919 L
s
.4336 .23919 m
.4331 .25791 L
s
.579 .262 1 r
.28603 .23847 m
.28536 .24722 L
s
.28537 .24717 m
.28603 .23847 L
s
.28603 .23847 m
.28475 .25611 L
s
.811 .206 1 r
.49181 .25387 m
.4917 .26334 L
s
.49178 .26299 m
.49181 .25387 L
s
.4917 .26334 m
.49183 .25382 L
s
.49183 .25382 m
.49178 .26299 L
s
.578 .262 1 r
.78134 .23786 m
.782 .24664 L
s
.78203 .24659 m
.78134 .23786 L
s
.78134 .23786 m
.78276 .25546 L
s
.425 .304 1 r
.53885 .23347 m
.53886 .24198 L
s
.53888 .24193 m
.53885 .23347 L
s
.53885 .23347 m
.53895 .25003 L
s
.376 .32 1 r
.39129 .23275 m
.39092 .2411 L
s
.39093 .24106 m
.39129 .23275 L
s
.39129 .23275 m
.39064 .249 L
s
.766 .217 1 r
.66569 .2533 m
.66609 .26265 L
s
.66614 .26234 m
.66569 .2533 L
s
.779 .213 1 r
.37057 .25184 m
.3701 .26135 L
s
.3702 .26065 m
.37057 .25184 L
s
.559 .267 1 r
.6601 .23576 m
.66044 .24461 L
s
.66047 .24456 m
.6601 .23576 L
s
.6601 .23576 m
.66086 .25313 L
s
.68 .237 1 r
.58009 .19555 m
.58108 .23944 L
s
.55 .269 1 r
.25864 .19555 m
.2553 .2383 L
s
.766 .217 1 r
.66609 .26265 m
.66571 .25325 L
s
.66571 .25325 m
.66614 .26234 L
s
.779 .213 1 r
.3701 .26135 m
.37059 .25179 L
s
.37059 .25179 m
.3702 .26065 L
s
.69 .234 1 r
.4599 .23812 m
.45969 .24725 L
s
.45971 .2472 m
.4599 .23812 L
s
.4599 .23812 m
.45956 .25622 L
s
.648 .244 1 r
.45518 .26517 m
.4551 .26552 L
s
.711 .229 1 r
.6338 .23743 m
.63408 .24667 L
s
.6341 .24662 m
.6338 .23743 L
s
.6338 .23743 m
.63444 .25557 L
s
.811 .206 1 r
.72401 .26815 m
.72397 .2685 L
s
.669 .239 1 r
.31232 .23758 m
.31169 .24667 L
s
.31171 .24662 m
.31232 .23758 L
s
.31232 .23758 m
.31116 .25557 L
s
.881 .191 1 r
.8133 .25447 m
.81415 .2641 L
s
.81418 .26375 m
.8133 .25447 L
s
.81415 .2641 m
.81333 .25442 L
s
.81333 .25442 m
.81418 .26375 L
s
.36 .325 1 r
.75401 .19527 m
.75704 .23461 L
s
.373 .52 1 r
.43251 .19527 m
.43164 .23233 L
s
.868 .194 1 r
.25966 .2407 m
.25886 .25018 L
s
.25887 .25013 m
.25966 .2407 L
s
.25966 .2407 m
.25813 .2597 L
s
.7 .232 1 r
.69204 .25245 m
.6925 .26161 L
s
.69256 .26141 m
.69204 .25245 L
s
.6925 .26161 m
.69206 .2524 L
s
.69206 .2524 m
.69256 .26141 L
s
.648 .244 1 r
.62909 .2649 m
.62903 .26524 L
s
1 .121 .757 r
.79269 .27383 m
.79266 .27434 L
s
.503 .282 1 r
.44949 .2484 m
.44928 .25709 L
s
.44935 .25675 m
.44949 .2484 L
s
.799 .209 1 r
.22858 .26955 m
.22851 .26952 L
s
.99 .169 1 r
.60644 .19498 m
.60789 .24231 L
s
.68 .236 1 r
.28489 .19498 m
.2817 .24041 L
s
1 .154 .933 r
.46548 .25653 m
.46529 .26654 L
s
.46536 .26619 m
.46548 .25653 L
s
.503 .282 1 r
.44928 .25709 m
.44951 .24835 L
s
.44951 .24835 m
.44935 .25675 L
s
.638 .247 1 r
.57077 .25073 m
.5709 .25977 L
s
.57095 .25946 m
.57077 .25073 L
s
.67 .239 1 r
.24923 .25072 m
.24843 .25988 L
s
.24854 .25946 m
.24923 .25072 L
s
1 .154 .933 r
.46529 .26654 m
.4655 .25647 L
s
.4655 .25647 m
.46536 .26619 L
s
.638 .247 1 r
.5709 .25977 m
.5708 .25068 L
s
.5708 .25068 m
.57095 .25946 L
s
.67 .239 1 r
.24843 .25988 m
.24924 .25067 L
s
.24924 .25067 m
.24854 .25946 L
s
.531 .274 1 r
.77105 .2487 m
.77172 .25747 L
s
.77175 .25713 m
.77105 .2487 L
s
.45 .297 1 r
.23889 .26035 m
.2388 .26069 L
s
.56046 .26035 m
.56041 .26069 L
s
.669 .239 1 r
.33859 .23703 m
.33804 .24612 L
s
.33805 .24607 m
.33859 .23703 L
s
.33859 .23703 m
.33758 .25502 L
s
1 .156 .947 r
.78705 .25683 m
.78785 .26677 L
s
.7879 .26657 m
.78705 .25683 L
s
.531 .274 1 r
.77172 .25747 m
.77108 .24865 L
s
.77108 .24865 m
.77175 .25713 L
s
.513 .279 1 r
.19095 .23634 m
.19003 .24494 L
s
.19005 .24489 m
.19095 .23634 L
s
.19095 .23634 m
.18919 .25361 L
s
1 .156 .947 r
.78785 .26677 m
.78708 .25678 L
s
.78708 .25678 m
.7879 .26657 L
s
.712 .229 1 r
.78041 .1947 m
.78412 .23823 L
s
.477 .289 1 r
.45882 .1947 m
.45819 .23556 L
s
.618 .252 1 r
.30752 .26565 m
.30745 .26566 L
s
.531 .274 1 r
.18619 .26371 m
.18612 .26371 L
s
.345 .39 1 r
.63279 .19442 m
.6343 .23301 L
s
.467 .292 1 r
.31116 .19442 m
.30859 .23604 L
s
.441 .3 1 r
.41755 .23325 m
.41723 .24176 L
s
.41725 .24171 m
.41755 .23325 L
s
.41755 .23325 m
.41701 .24996 L
s
.833 .201 1 r
.19648 .25453 m
.19552 .26393 L
s
.19558 .26396 m
.19648 .25453 L
s
.19552 .26393 m
.1965 .25448 L
s
.1965 .25448 m
.19558 .26396 L
s
.766 .216 1 r
.51254 .23709 m
.51247 .24645 L
s
.5125 .2464 m
.51254 .23709 L
s
.51254 .23709 m
.5125 .25551 L
s
.618 .252 1 r
.68181 .26344 m
.68176 .26378 L
s
.531 .274 1 r
.2172 .23572 m
.21635 .24439 L
s
.21636 .24434 m
.2172 .23572 L
s
.2172 .23572 m
.21557 .25306 L
s
.628 .249 1 r
.27546 .25048 m
.27475 .25945 L
s
.27483 .25929 m
.27546 .25048 L
s
1 .156 .946 r
.80682 .19414 m
.81132 .24224 L
s
.8 .209 1 r
.48514 .19414 m
.48481 .23957 L
s
.357 .451 1 r
.51814 .25488 m
.51809 .25522 L
s
.628 .249 1 r
.27475 .25945 m
.27547 .25043 L
s
.27547 .25043 m
.27483 .25929 L
s
.618 .252 1 r
.56521 .23449 m
.5653 .24354 L
s
.56532 .24349 m
.56521 .23449 L
s
.56521 .23449 m
.56546 .25213 L
s
.99 .169 1 r
.80791 .23895 m
.80873 .24881 L
s
.80876 .24876 m
.80791 .23895 L
s
.80791 .23895 m
.80963 .25833 L
s
.928 .181 1 r
.25477 .26977 m
.25469 .26993 L
s
.733 .224 1 r
.48147 .26614 m
.4814 .26634 L
s
.916 .184 1 r
.4862 .23918 m
.48606 .24881 L
s
.48608 .24876 m
.4862 .23918 L
s
.4862 .23918 m
.486 .25833 L
s
.638 .247 1 r
.33377 .26549 m
.33371 .26546 L
s
.777 .214 1 r
.74483 .25166 m
.74547 .26105 L
s
.74551 .2607 m
.74483 .25166 L
s
.857 .196 1 r
.2811 .26847 m
.28102 .26863 L
s
.811 .206 1 r
.65917 .19386 m
.6613 .23891 L
s
.68 .237 1 r
.33744 .19386 m
.3351 .23776 L
s
.777 .214 1 r
.74547 .26105 m
.74486 .25161 L
s
.74486 .25161 m
.74551 .2607 L
s
.441 .3 1 r
.35443 .24672 m
.35397 .25519 L
s
.35404 .255 m
.35443 .24672 L
s
.35397 .25519 m
.35445 .24668 L
s
.35445 .24668 m
.35404 .255 L
s
.916 .184 1 r
.71852 .25341 m
.71909 .26311 L
s
.71914 .26276 m
.71852 .25341 L
s
1 .161 .972 r
.42879 .2695 m
.42871 .26997 L
s
.916 .184 1 r
.71909 .26311 m
.71854 .25336 L
s
.71854 .25336 m
.71914 .26276 L
s
.522 .277 1 r
.76562 .23302 m
.76624 .24181 L
s
.76627 .24176 m
.76562 .23302 L
s
.76562 .23302 m
.76692 .25017 L
s
.88 .191 1 r
.6866 .23745 m
.68705 .24708 L
s
.68707 .24703 m
.6866 .23745 L
s
.6866 .23745 m
.68757 .25637 L
s
.777 .214 1 r
.51147 .19358 m
.51152 .23863 L
s
.881 .191 1 r
.80325 .2669 m
.80323 .26736 L
s
.352 .327 1 r
.40709 .24443 m
.40678 .25262 L
s
.40685 .2524 m
.40709 .24443 L
s
.777 .214 1 r
.82961 .2656 m
.82958 .26595 L
s
.352 .327 1 r
.40678 .25262 m
.40711 .24438 L
s
.40711 .24438 m
.40685 .2524 L
s
.588 .259 1 r
.18032 .2482 m
.17935 .25713 L
s
.17946 .25679 m
.18032 .2482 L
s
.904 .186 1 r
.68556 .1933 m
.68822 .2414 L
s
.398 .631 1 r
.36374 .1933 m
.36209 .22961 L
s
.588 .259 1 r
.17935 .25713 m
.18033 .24816 L
s
.18033 .24816 m
.17946 .25679 L
s
.777 .214 1 r
.62352 .25053 m
.6238 .25997 L
s
.62386 .2595 m
.62352 .25053 L
s
.578 .262 1 r
.59158 .23443 m
.59173 .24329 L
s
.59175 .24324 m
.59158 .23443 L
s
.59158 .23443 m
.59197 .25196 L
s
.388 .587 1 r
.40148 .22714 m
.40116 .2348 L
s
.40118 .23476 m
.40148 .22714 L
s
.40148 .22714 m
.40093 .24202 L
s
.777 .214 1 r
.6238 .25997 m
.62355 .25049 L
s
.62355 .25049 m
.62386 .2595 L
s
.834 .201 1 r
.71298 .23671 m
.7135 .24623 L
s
.71353 .24618 m
.71298 .23671 L
s
.71298 .23671 m
.7141 .25544 L
s
.423 .733 1 r
.74966 .22577 m
.75014 .23305 L
s
.75016 .23301 m
.74966 .22577 L
s
.74966 .22577 m
.75067 .23996 L
s
.375 .32 1 r
.58117 .24415 m
.58131 .25246 L
s
.58136 .25212 m
.58117 .24415 L
s
.733 .224 1 r
.24339 .2361 m
.24256 .24535 L
s
.24257 .2453 m
.24339 .2361 L
s
.24339 .2361 m
.24182 .25441 L
s
.375 .32 1 r
.58131 .25246 m
.58119 .24411 L
s
.58119 .24411 m
.58136 .25212 L
s
.917 .184 1 r
.59718 .25229 m
.59739 .26203 L
s
.59745 .26157 m
.59718 .25229 L
s
.59739 .26203 m
.59721 .25224 L
s
.59721 .25224 m
.59745 .26157 L
s
.68 .237 1 r
.53782 .19301 m
.53823 .23693 L
s
.711 .229 1 r
.70826 .26403 m
.70822 .26437 L
s
.56 .267 1 r
.61321 .2604 m
.61316 .26085 L
s
.67 .239 1 r
.50213 .24881 m
.50206 .25797 L
s
.50213 .25755 m
.50213 .24881 L
s
.599 .257 1 r
.61794 .23346 m
.61817 .24244 L
s
.6182 .24239 m
.61794 .23346 L
s
.61794 .23346 m
.61848 .25104 L
s
.67 .239 1 r
.50206 .25797 m
.50215 .24876 L
s
.50215 .24876 m
.50213 .25755 L
s
.588 .259 1 r
.76099 .26143 m
.76095 .26177 L
s
.589 .259 1 r
.4391 .26143 m
.43902 .26177 L
s
.467 .292 1 r
.23293 .2462 m
.23214 .25475 L
s
.23222 .25456 m
.23293 .2462 L
s
.579 .262 1 r
.71196 .19273 m
.71469 .23551 L
s
.765 .217 1 r
.39005 .19273 m
.38837 .23817 L
s
.467 .292 1 r
.23214 .25475 m
.23294 .24616 L
s
.23294 .24616 m
.23222 .25456 L
s
.69 .234 1 r
.32799 .24999 m
.32742 .25911 L
s
.3275 .25896 m
.32799 .24999 L
s
.68 .237 1 r
.73465 .26311 m
.73461 .26345 L
s
.734 .224 1 r
.44383 .23459 m
.44357 .24392 L
s
.44359 .24387 m
.44383 .23459 L
s
.44383 .23459 m
.4434 .25282 L
s
.69 .234 1 r
.32742 .25911 m
.32801 .24994 L
s
.32801 .24994 m
.3275 .25896 L
s
.669 .239 1 r
.26968 .23544 m
.26893 .2445 L
s
.26895 .24445 m
.26968 .23544 L
s
.26968 .23544 m
.26827 .25348 L
s
.799 .209 1 r
.47577 .25087 m
.47562 .2603 L
s
.47569 .25999 m
.47577 .25087 L
s
.711 .229 1 r
.73939 .23624 m
.73997 .24537 L
s
.73999 .24533 m
.73939 .23624 L
s
.73939 .23624 m
.74063 .25451 L
s
.799 .209 1 r
.47562 .2603 m
.47579 .25082 L
s
.47579 .25082 m
.47569 .25999 L
s
.38 .554 1 r
.79773 .25091 m
.79771 .25136 L
s
.618 .252 1 r
.56419 .19245 m
.56494 .23523 L
s
.658 .242 1 r
.24224 .19245 m
.23854 .23675 L
s
1 .161 .972 r
.36475 .23936 m
.36423 .2492 L
s
.36425 .24914 m
.36475 .23936 L
s
.36475 .23936 m
.3638 .25903 L
s
.377 .542 1 r
.22726 .22929 m
.22653 .23689 L
s
.22655 .23685 m
.22726 .22929 L
s
.22726 .22929 m
.22587 .24456 L
s
.531 .274 1 r
.8185 .23222 m
.81927 .24101 L
s
.81929 .24096 m
.8185 .23222 L
s
.8185 .23222 m
.82009 .24945 L
s
.8 .209 1 r
.38636 .26517 m
.38628 .26548 L
s
.928 .181 1 r
.65561 .26814 m
.65555 .26831 L
s
.953 .176 1 r
.50781 .26749 m
.50774 .26784 L
s
.441 .3 1 r
.34871 .23165 m
.34822 .24013 L
s
.34824 .24008 m
.34871 .23165 L
s
.34871 .23165 m
.34782 .24841 L
s
.733 .224 1 r
.82411 .25001 m
.82496 .25926 L
s
.82501 .25906 m
.82411 .25001 L
s
.68 .237 1 r
.79216 .2339 m
.79289 .24307 L
s
.79292 .24302 m
.79216 .2339 L
s
.79216 .2339 m
.79368 .25189 L
s
.55 .269 1 r
.63961 .26023 m
.63956 .26054 L
s
.929 .181 1 r
.35999 .26684 m
.3599 .26723 L
s
.45 .297 1 r
.73838 .19217 m
.7413 .23267 L
s
.599 .257 1 r
.41638 .19217 m
.41509 .23647 L
s
.733 .224 1 r
.82496 .25926 m
.82414 .24997 L
s
.82414 .24997 m
.82501 .25906 L
s
.531 .274 1 r
.16979 .25958 m
.16969 .25992 L
s
.88 .191 1 r
.30158 .25235 m
.3009 .2619 L
s
.30098 .26178 m
.30158 .25235 L
s
.822 .204 1 r
.21216 .26619 m
.21208 .26635 L
s
.88 .191 1 r
.3009 .2619 m
.3016 .2523 L
s
.3016 .2523 m
.30098 .26178 L
s
.649 .244 1 r
.64436 .23339 m
.64466 .24249 L
s
.64469 .24244 m
.64436 .23339 L
s
.64436 .23339 m
.64504 .25124 L
s
.393 .314 1 r
.42306 .25465 m
.42298 .25529 L
s
.777 .214 1 r
.5869 .26359 m
.58685 .26405 L
s
.578 .262 1 r
.38064 .24829 m
.38024 .25707 L
s
.3803 .25711 m
.38064 .24829 L
s
.559 .267 1 r
.67073 .23217 m
.6711 .24103 L
s
.67112 .24099 m
.67073 .23217 L
s
.67073 .23217 m
.67154 .24955 L
s
.669 .239 1 r
.59057 .19189 m
.5917 .23581 L
s
.701 .232 1 r
.26853 .19189 m
.26513 .23695 L
s
.578 .262 1 r
.38024 .25707 m
.38066 .24824 L
s
.38066 .24824 m
.3803 .25711 L
s
.733 .224 1 r
.52849 .24917 m
.52849 .25845 L
s
.52855 .25814 m
.52849 .24917 L
s
.52849 .25845 m
.52851 .24912 L
s
.52851 .24912 m
.52855 .25814 L
s
.618 .252 1 r
.72907 .24714 m
.72964 .25615 L
s
.72968 .2558 m
.72907 .24714 L
s
.72964 .25615 m
.7291 .24709 L
s
.7291 .24709 m
.72968 .2558 L
s
.559 .267 1 r
.34393 .25969 m
.34385 .26003 L
s
.834 .201 1 r
.76481 .19161 m
.76849 .23744 L
s
.45 .297 1 r
.44272 .19161 m
.44188 .23249 L
s
.953 .176 1 r
.64999 .2518 m
.65036 .26158 L
s
.65041 .26123 m
.64999 .2518 L
s
.744 .221 1 r
.70272 .24889 m
.70323 .25821 L
s
.70328 .25786 m
.70272 .24889 L
s
.845 .199 1 r
.41268 .265 m
.4126 .26535 L
s
.953 .176 1 r
.65036 .26158 m
.65001 .25175 L
s
.65001 .25175 m
.65041 .26123 L
s
1 .108 .687 r
.77718 .27161 m
.77714 .27209 L
s
.744 .221 1 r
.70323 .25821 m
.70275 .24884 L
s
.70275 .24884 m
.70328 .25786 L
s
.476 .29 1 r
.54453 .25774 m
.54447 .25808 L
s
.598 .257 1 r
.29115 .26305 m
.2911 .26286 L
s
.69 .234 1 r
.29591 .23582 m
.29524 .24485 L
s
.29525 .2448 m
.29591 .23582 L
s
.29591 .23582 m
.29464 .25407 L
s
.551 .269 1 r
.60761 .24541 m
.60783 .25426 L
s
.60788 .25384 m
.60761 .24541 L
s
.60783 .25426 m
.60763 .24536 L
s
.60763 .24536 m
.60788 .25384 L
s
.578 .262 1 r
.61696 .19132 m
.61843 .23449 L
s
.766 .217 1 r
.29483 .19132 m
.29181 .23639 L
s
.799 .209 1 r
.20635 .25007 m
.20541 .25947 L
s
.2055 .25927 m
.20635 .25007 L
s
.20541 .25947 m
.20637 .25002 L
s
.20637 .25002 m
.2055 .25927 L
s
1 .161 .972 r
.53418 .26771 m
.53411 .26806 L
s
.904 .186 1 r
.67638 .25095 m
.67683 .26062 L
s
.67688 .26031 m
.67638 .25095 L
s
.67683 .26062 m
.67641 .2509 L
s
.67641 .2509 m
.67688 .26031 L
s
.386 .316 1 r
.35899 .22394 m
.35852 .23261 L
s
.35854 .23257 m
.35899 .22394 L
s
.35899 .22394 m
.3582 .23991 L
s
.722 .227 1 r
.79126 .19104 m
.79525 .23611 L
s
.744 .221 1 r
.46908 .19104 m
.46854 .23535 L
s
.485 .287 1 r
.22235 .25849 m
.22227 .25864 L
s
.648 .244 1 r
.75553 .24689 m
.75618 .25598 L
s
.75621 .25563 m
.75553 .24689 L
s
.75618 .25598 m
.75556 .24684 L
s
.75556 .24684 m
.75621 .25563 L
s
.424 .305 1 r
.42774 .22939 m
.42745 .23787 L
s
.42747 .23782 m
.42774 .22939 L
s
.42774 .22939 m
.42726 .246 L
s
.811 .206 1 r
.55488 .24922 m
.55496 .2587 L
s
.55502 .25835 m
.55488 .24922 L
s
.777 .214 1 r
.32223 .23531 m
.32161 .2446 L
s
.32163 .24455 m
.32223 .23531 L
s
.32223 .23531 m
.32108 .25389 L
s
.811 .206 1 r
.55496 .2587 m
.5549 .24917 L
s
.5549 .24917 m
.55502 .25835 L
s
.443 .299 1 r
.45412 .22808 m
.4539 .23671 L
s
.45392 .23667 m
.45412 .22808 L
s
.45412 .22808 m
.45378 .24469 L
s
.88 .191 1 r
.49653 .23469 m
.49641 .24433 L
s
.49643 .24428 m
.49653 .23469 L
s
.49653 .23469 m
.49639 .25362 L
s
.857 .196 1 r
.26472 .26549 m
.26464 .26564 L
s
.733 .224 1 r
.5229 .23328 m
.52286 .24257 L
s
.52289 .24252 m
.5229 .23328 L
s
.5229 .23328 m
.52292 .25155 L
s
.4 .312 1 r
.60203 .22889 m
.60221 .23729 L
s
.60223 .23724 m
.60203 .22889 L
s
.60203 .22889 m
.60245 .24535 L
s
.392 .314 1 r
.64337 .19076 m
.64506 .23051 L
s
.342 .378 1 r
.32115 .19076 m
.31889 .22937 L
s
.679 .237 1 r
.31745 .26288 m
.31739 .26288 L
s
.512 .279 1 r
.3966 .2586 m
.39653 .25875 L
s
.376 .32 1 r
.39092 .2411 m
.39056 .24945 L
s
.39064 .249 m
.39092 .2411 L
s
.357 .448 1 r
.49545 .19048 m
.49531 .22719 L
s
.376 .32 1 r
.39056 .24945 m
.39093 .24106 L
s
.39093 .24106 m
.39064 .249 L
s
.425 .304 1 r
.53886 .24198 m
.53889 .25048 L
s
.53895 .25003 m
.53886 .24198 L
s
.512 .279 1 r
.57566 .23098 m
.57577 .23965 L
s
.57579 .23961 m
.57566 .23098 L
s
.57566 .23098 m
.57596 .24818 L
s
.425 .304 1 r
.53889 .25048 m
.53888 .24193 L
s
.53888 .24193 m
.53895 .25003 L
s
.579 .262 1 r
.28536 .24722 m
.28469 .25596 L
s
.28475 .25611 m
.28536 .24722 L
s
.28469 .25596 m
.28537 .24717 L
s
.28537 .24717 m
.28475 .25611 L
s
.337 .352 1 r
.65483 .2268 m
.65513 .23497 L
s
.65515 .23493 m
.65483 .2268 L
s
.65483 .2268 m
.6555 .24273 L
s
.811 .206 1 r
.69725 .23341 m
.69773 .2429 L
s
.69775 .24285 m
.69725 .23341 L
s
.69725 .23341 m
.69828 .25204 L
s
.578 .262 1 r
.782 .24664 m
.7827 .25543 L
s
.78276 .25546 m
.782 .24664 L
s
.68 .237 1 r
.6698 .19019 m
.67201 .23375 L
s
.395 .619 1 r
.34748 .19019 m
.34569 .22578 L
s
.578 .262 1 r
.7827 .25543 m
.78203 .24659 L
s
.78203 .24659 m
.78276 .25546 L
s
.779 .213 1 r
.3702 .26065 m
.3701 .26135 L
s
.559 .267 1 r
.66044 .24461 m
.66081 .25347 L
s
.66086 .25313 m
.66044 .24461 L
s
.66081 .25347 m
.66047 .24456 L
s
.66047 .24456 m
.66086 .25313 L
s
.811 .206 1 r
.49178 .26299 m
.4917 .26334 L
s
.766 .217 1 r
.66614 .26234 m
.66609 .26265 L
s
.372 .52 1 r
.52184 .18991 m
.52199 .2274 L
s
.834 .201 1 r
.4333 .2487 m
.43302 .25822 L
s
.4331 .25791 m
.4333 .2487 L
s
.69 .234 1 r
.45969 .24725 m
.45949 .25638 L
s
.45956 .25622 m
.45969 .24725 L
s
.733 .224 1 r
.37491 .23402 m
.37445 .2432 L
s
.37447 .24315 m
.37491 .23402 L
s
.37491 .23402 m
.37408 .25242 L
s
.503 .282 1 r
.44935 .25675 m
.44928 .25709 L
s
.834 .201 1 r
.43302 .25822 m
.43332 .24865 L
s
.43332 .24865 m
.4331 .25791 L
s
.69 .234 1 r
.45949 .25638 m
.45971 .2472 L
s
.45971 .2472 m
.45956 .25622 L
s
.711 .229 1 r
.63408 .24667 m
.63438 .25592 L
s
.63444 .25557 m
.63408 .24667 L
s
.669 .239 1 r
.31169 .24667 m
.31108 .25576 L
s
.31116 .25557 m
.31169 .24667 L
s
.94 .179 1 r
.20052 .23496 m
.19951 .24468 L
s
.19953 .24463 m
.20052 .23496 L
s
.20052 .23496 m
.19861 .25421 L
s
.711 .229 1 r
.63438 .25592 m
.6341 .24662 L
s
.6341 .24662 m
.63444 .25557 L
s
.669 .239 1 r
.31108 .25576 m
.31171 .24662 L
s
.31171 .24662 m
.31116 .25557 L
s
.826 .203 1 r
.2797 .23064 m
.27894 .24031 L
s
.27896 .24026 m
.2797 .23064 L
s
.2797 .23064 m
.27832 .24914 L
s
.7 .232 1 r
.69256 .26141 m
.6925 .26161 L
s
1 .154 .933 r
.69624 .18963 m
.69908 .23776 L
s
.388 .588 1 r
.37383 .18963 m
.37224 .22711 L
s
.531 .274 1 r
.77175 .25713 m
.77172 .25747 L
s
.881 .191 1 r
.81418 .26375 m
.81415 .2641 L
s
1 .113 .716 r
.47013 .23813 m
.46991 .24851 L
s
.46994 .24846 m
.47013 .23813 L
s
.47013 .23813 m
.4698 .25874 L
s
.638 .247 1 r
.57095 .25946 m
.5709 .25977 L
s
.67 .239 1 r
.24854 .25946 m
.24843 .25988 L
s
.513 .279 1 r
.19003 .24494 m
.18913 .25354 L
s
.18919 .25361 m
.19003 .24494 L
s
.18913 .25354 m
.19005 .24489 L
s
.19005 .24489 m
.18919 .25361 L
s
.868 .194 1 r
.25886 .25018 m
.25806 .25967 L
s
.25813 .2597 m
.25886 .25018 L
s
.25806 .25967 m
.25887 .25013 L
s
.25887 .25013 m
.25813 .2597 L
s
.991 .169 1 r
.54824 .18935 m
.54883 .23634 L
s
.916 .184 1 r
.72375 .23354 m
.72431 .24325 L
s
.72434 .2432 m
.72375 .23354 L
s
.72375 .23354 m
.72495 .25263 L
s
.669 .239 1 r
.33804 .24612 m
.3375 .25521 L
s
.33758 .25502 m
.33804 .24612 L
s
.441 .3 1 r
.41723 .24176 m
.41694 .25027 L
s
.41701 .24996 m
.41723 .24176 L
s
.669 .239 1 r
.3375 .25521 m
.33805 .24607 L
s
.33805 .24607 m
.33758 .25502 L
s
.441 .3 1 r
.41694 .25027 m
.41725 .24171 L
s
.41725 .24171 m
.41701 .24996 L
s
.788 .211 1 r
.72269 .18906 m
.72573 .23415 L
s
.765 .217 1 r
.4002 .18906 m
.39865 .23453 L
s
.733 .224 1 r
.2532 .23319 m
.2524 .24237 L
s
.25242 .24232 m
.2532 .23319 L
s
.2532 .23319 m
.25168 .25159 L
s
1 .154 .933 r
.46536 .26619 m
.46529 .26654 L
s
.531 .274 1 r
.21635 .24439 m
.21551 .25306 L
s
.21557 .25306 m
.21635 .24439 L
s
.21551 .25306 m
.21636 .24434 L
s
.21636 .24434 m
.21557 .25306 L
s
.377 .541 1 r
.76055 .22316 m
.76109 .23095 L
s
.76111 .23091 m
.76055 .22316 L
s
.76055 .22316 m
.76167 .23824 L
s
.589 .259 1 r
.57465 .18878 m
.57555 .23159 L
s
.701 .232 1 r
.25211 .18878 m
.24855 .23311 L
s
1 .156 .947 r
.7879 .26657 m
.78785 .26677 L
s
.485 .287 1 r
.30598 .23066 m
.30537 .23915 L
s
.30539 .2391 m
.30598 .23066 L
s
.30598 .23066 m
.30483 .24783 L
s
.628 .249 1 r
.27483 .25929 m
.27475 .25945 L
s
.735 .224 1 r
.62854 .23072 m
.62881 .24005 L
s
.62884 .24 m
.62854 .23072 L
s
.62854 .23072 m
.62916 .24896 L
s
.423 .733 1 r
.75014 .23305 m
.75065 .24032 L
s
.75067 .23996 m
.75014 .23305 L
s
.441 .3 1 r
.35404 .255 m
.35397 .25519 L
s
.859 .196 1 r
.77663 .2316 m
.77735 .24124 L
s
.77738 .24119 m
.77663 .2316 L
s
.77663 .2316 m
.77813 .25038 L
s
.423 .733 1 r
.75065 .24032 m
.75016 .23301 L
s
.75016 .23301 m
.75067 .23996 L
s
.833 .201 1 r
.19558 .26396 m
.19552 .26393 L
s
.766 .216 1 r
.51247 .24645 m
.51243 .25582 L
s
.5125 .25551 m
.51247 .24645 L
s
.618 .252 1 r
.5653 .24354 m
.5654 .25259 L
s
.56546 .25213 m
.5653 .24354 L
s
.669 .239 1 r
.48046 .23034 m
.4803 .23948 L
s
.48033 .23943 m
.48046 .23034 L
s
.48046 .23034 m
.48024 .24831 L
s
.4 .312 1 r
.74916 .1885 m
.7522 .22864 L
s
.639 .246 1 r
.42657 .1885 m
.42543 .23282 L
s
.766 .216 1 r
.51243 .25582 m
.5125 .2464 L
s
.5125 .2464 m
.5125 .25551 L
s
.618 .252 1 r
.5654 .25259 m
.56532 .24349 L
s
.56532 .24349 m
.56546 .25213 L
s
.388 .587 1 r
.40116 .2348 m
.40086 .24246 L
s
.40093 .24202 m
.40116 .2348 L
s
.352 .327 1 r
.40685 .2524 m
.40678 .25262 L
s
.388 .587 1 r
.40086 .24246 m
.40118 .23476 L
s
.40118 .23476 m
.40093 .24202 L
s
.476 .29 1 r
.53328 .22762 m
.53327 .23626 L
s
.53329 .23621 m
.53328 .22762 L
s
.53328 .22762 m
.53335 .24455 L
s
.777 .214 1 r
.74551 .2607 m
.74547 .26105 L
s
.618 .252 1 r
.50687 .2293 m
.50679 .23832 L
s
.50681 .23827 m
.50687 .2293 L
s
.50687 .2293 m
.5068 .247 L
s
.522 .277 1 r
.76624 .24181 m
.76689 .25059 L
s
.76692 .25017 m
.76624 .24181 L
s
.365 .486 1 r
.60109 .18821 m
.60218 .22571 L
s
.522 .277 1 r
.27845 .18821 m
.27542 .23027 L
s
.76689 .25059 m
.76627 .24176 L
s
.76627 .24176 m
.76692 .25017 L
s
.375 .32 1 r
.58136 .25212 m
.58131 .25246 L
s
.477 .289 1 r
.38516 .22734 m
.38476 .23598 L
s
.38478 .23593 m
.38516 .22734 L
s
.38516 .22734 m
.38445 .24427 L
s
.588 .259 1 r
.17946 .25679 m
.17935 .25713 L
s
.916 .184 1 r
.48606 .24881 m
.48593 .25845 L
s
.486 .25833 m
.48606 .24881 L
s
.99 .169 1 r
.80873 .24881 m
.8096 .25868 L
s
.80963 .25833 m
.80873 .24881 L
s
.916 .184 1 r
.71914 .26276 m
.71909 .26311 L
s
.48593 .25845 m
.48608 .24876 L
s
.48608 .24876 m
.486 .25833 L
s
.99 .169 1 r
.8096 .25868 m
.80876 .24876 L
s
.80876 .24876 m
.80963 .25833 L
s
.777 .214 1 r
.77565 .18793 m
.77941 .23265 L
s
.712 .229 1 r
.45297 .18793 m
.45221 .23189 L
s
.618 .252 1 r
.2106 .22841 m
.20969 .23747 L
s
.20971 .23742 m
.2106 .22841 L
s
.2106 .22841 m
.2089 .24607 L
s
.7 .232 1 r
.33232 .23062 m
.33174 .23981 L
s
.33176 .23976 m
.33232 .23062 L
s
.33232 .23062 m
.33125 .2488 L
s
1 .093 .6 r
.54935 .23651 m
.54939 .24716 L
s
.54942 .24711 m
.54935 .23651 L
s
.54935 .23651 m
.54954 .25747 L
s
.845 .199 1 r
.80315 .23142 m
.80394 .24099 L
s
.80397 .24094 m
.80315 .23142 L
s
.80315 .23142 m
.8048 .25021 L
s
.578 .262 1 r
.59173 .24329 m
.59191 .25215 L
s
.59197 .25196 m
.59173 .24329 L
s
.59191 .25215 m
.59175 .24324 L
s
.59175 .24324 m
.59197 .25196 L
s
.88 .191 1 r
.68705 .24708 m
.68752 .25672 L
s
.68757 .25637 m
.68705 .24708 L
s
.777 .214 1 r
.62386 .2595 m
.6238 .25997 L
s
.88 .191 1 r
.68752 .25672 m
.68707 .24703 L
s
.68707 .24703 m
.68757 .25637 L
s
.833 .201 1 r
.62753 .18765 m
.62926 .23389 L
s
.531 .274 1 r
.30481 .18765 m
.30207 .23047 L
s
.377 .542 1 r
.22653 .23689 m
.22582 .24448 L
s
.22587 .24456 m
.22653 .23689 L
s
.22582 .24448 m
.22655 .23685 L
s
.22655 .23685 m
.22587 .24456 L
s
.467 .292 1 r
.23222 .25456 m
.23214 .25475 L
s
.67 .239 1 r
.50213 .25755 m
.50206 .25797 L
s
.733 .224 1 r
.24256 .24535 m
.24174 .2546 L
s
.24182 .25441 m
.24256 .24535 L
s
.599 .257 1 r
.61817 .24244 m
.61843 .25142 L
s
.61848 .25104 m
.61817 .24244 L
s
.857 .196 1 r
.80215 .18736 m
.80645 .234 L
s
.68 .237 1 r
.47937 .18736 m
.47898 .23132 L
s
.733 .224 1 r
.24174 .2546 m
.24257 .2453 L
s
.24257 .2453 m
.24182 .25441 L
s
.599 .257 1 r
.61843 .25142 m
.6182 .24239 L
s
.6182 .24239 m
.61848 .25104 L
s
.917 .184 1 r
.59745 .26157 m
.59739 .26203 L
s
.834 .201 1 r
.7135 .24623 m
.71405 .25575 L
s
.7141 .25544 m
.7135 .24623 L
s
.71405 .25575 m
.71353 .24618 L
s
.71353 .24618 m
.7141 .25544 L
s
.69 .234 1 r
.3275 .25896 m
.32742 .25911 L
s
.711 .229 1 r
.65399 .18708 m
.65602 .23143 L
s
.722 .227 1 r
.33118 .18708 m
.32871 .23143 L
s
.391 .315 1 r
.61257 .22532 m
.61277 .23369 L
s
.6128 .23364 m
.61257 .22532 L
s
.61257 .22532 m
.61305 .24176 L
s
.669 .239 1 r
.26893 .2445 m
.2682 .25356 L
s
.26827 .25348 m
.26893 .2445 L
s
.441 .3 1 r
.34822 .24013 m
.34774 .2486 L
s
.34782 .24841 m
.34822 .24013 L
s
.669 .239 1 r
.2682 .25356 m
.26895 .24445 L
s
.26895 .24445 m
.26827 .25348 L
s
.441 .3 1 r
.34774 .2486 m
.34824 .24008 L
s
.34824 .24008 m
.34782 .24841 L
s
.799 .209 1 r
.47569 .25999 m
.47562 .2603 L
s
.711 .229 1 r
.73997 .24537 m
.74057 .25451 L
s
.74063 .25451 m
.73997 .24537 L
s
.335 .341 1 r
.31617 .22405 m
.31562 .23223 L
s
.31563 .23218 m
.31617 .22405 L
s
.31617 .22405 m
.31515 .24006 L
s
.734 .224 1 r
.44357 .24392 m
.44332 .25325 L
s
.4434 .25282 m
.44357 .24392 L
s
.531 .274 1 r
.81927 .24101 m
.82006 .24979 L
s
.82009 .24945 m
.81927 .24101 L
s
.711 .229 1 r
.74057 .25451 m
.73999 .24533 L
s
.73999 .24533 m
.74063 .25451 L
s
.734 .224 1 r
.44332 .25325 m
.44359 .24387 L
s
.44359 .24387 m
.4434 .25282 L
s
.531 .274 1 r
.82006 .24979 m
.81929 .24096 L
s
.81929 .24096 m
.82009 .24945 L
s
.744 .222 1 r
.70795 .22936 m
.70844 .2387 L
s
.70847 .23865 m
.70795 .22936 L
s
.70795 .22936 m
.70901 .24769 L
s
.618 .252 1 r
.41152 .22791 m
.41117 .23694 L
s
.41119 .23689 m
.41152 .22791 L
s
.41152 .22791 m
.41092 .24562 L
s
.701 .232 1 r
.5058 .1868 m
.50576 .23115 L
s
.503 .282 1 r
.26328 .22741 m
.26255 .23605 L
s
.26257 .23601 m
.26328 .22741 L
s
.26328 .22741 m
.26191 .24458 L
s
.733 .224 1 r
.82501 .25906 m
.82496 .25926 L
s
.68 .237 1 r
.79289 .24307 m
.79365 .25224 L
s
.79368 .25189 m
.79289 .24307 L
s
.94 .179 1 r
.68154 .23131 m
.68198 .24107 L
s
.68201 .24102 m
.68154 .23131 L
s
.68154 .23131 m
.6825 .25053 L
s
.618 .252 1 r
.58617 .22763 m
.58631 .23666 L
s
.58634 .23661 m
.58617 .22763 L
s
.58617 .22763 m
.58654 .24534 L
s
.559 .267 1 r
.68047 .18651 m
.68277 .22896 L
s
.365 .485 1 r
.35756 .18651 m
.35581 .22364 L
s
.68 .237 1 r
.79365 .25224 m
.79292 .24302 L
s
.79292 .24302 m
.79368 .25189 L
s
.578 .262 1 r
.3803 .25711 m
.38024 .25707 L
s
.649 .244 1 r
.64466 .24249 m
.64499 .25159 L
s
.64504 .25124 m
.64466 .24249 L
s
.559 .267 1 r
.6711 .24103 m
.67149 .2499 L
s
.67154 .24955 m
.6711 .24103 L
s
.649 .244 1 r
.64499 .25159 m
.64469 .24244 L
s
.64469 .24244 m
.64504 .25124 L
s
.559 .267 1 r
.67149 .2499 m
.67112 .24099 L
s
.67112 .24099 m
.67154 .24955 L
s
1 .161 .972 r
.36423 .2492 m
.36373 .25904 L
s
.3638 .25903 m
.36423 .2492 L
s
.618 .252 1 r
.72968 .2558 m
.72964 .25615 L
s
.395 .62 1 r
.39542 .22059 m
.39509 .22815 L
s
.39511 .22811 m
.39542 .22059 L
s
.39542 .22059 m
.39485 .23537 L
s
1 .161 .972 r
.36373 .25904 m
.36425 .24914 L
s
.36425 .24914 m
.3638 .25903 L
s
.542 .271 1 r
.46437 .22574 m
.46418 .23462 L
s
.46419 .23457 m
.46437 .22574 L
s
.46437 .22574 m
.46407 .24299 L
s
.88 .191 1 r
.30098 .26178 m
.3009 .2619 L
s
.733 .224 1 r
.52855 .25814 m
.52849 .25845 L
s
.811 .206 1 r
.55975 .22954 m
.55982 .23903 L
s
.55984 .23898 m
.55975 .22954 L
s
.55975 .22954 m
.55998 .24817 L
s
.618 .252 1 r
.43793 .22736 m
.43766 .23638 L
s
.43768 .23633 m
.43793 .22736 L
s
.43793 .22736 m
.43748 .24507 L
s
.649 .244 1 r
.53224 .18623 m
.53257 .22982 L
s
.551 .269 1 r
.60788 .25384 m
.60783 .25426 L
s
.766 .217 1 r
.23678 .22969 m
.23592 .23903 L
s
.23594 .23898 m
.23678 .22969 L
s
.23678 .22969 m
.23516 .24817 L
s
.73446 .22907 m
.73503 .23845 L
s
.73506 .2384 m
.73446 .22907 L
s
.73446 .22907 m
.73569 .24752 L
s
.649 .244 1 r
.28965 .22696 m
.28896 .2361 L
s
.28897 .23606 m
.28965 .22696 L
s
.28965 .22696 m
.28838 .24479 L
s
.744 .221 1 r
.70328 .25786 m
.70323 .25821 L
s
.777 .214 1 r
.70696 .18595 m
.70978 .23106 L
s
.352 .327 1 r
.38396 .18595 m
.38237 .22649 L
s
.69 .234 1 r
.29524 .24485 m
.29458 .25388 L
s
.29464 .25407 m
.29524 .24485 L
s
.29458 .25388 m
.29525 .2448 L
s
.29525 .2448 m
.29464 .25407 L
s
.386 .316 1 r
.35852 .23261 m
.35806 .24128 L
s
.3582 .23991 m
.35852 .23261 L
s
.953 .176 1 r
.65041 .26123 m
.65036 .26158 L
s
.386 .316 1 r
.35806 .24128 m
.35854 .23257 L
s
.35854 .23257 m
.3582 .23991 L
s
.424 .305 1 r
.42745 .23787 m
.42719 .24634 L
s
.42726 .246 m
.42745 .23787 L
s
.531 .274 1 r
.55869 .18566 m
.55935 .22735 L
s
.424 .305 1 r
.42719 .24634 m
.42747 .23782 L
s
.42747 .23782 m
.42726 .246 L
s
.467 .292 1 r
.49079 .2255 m
.49067 .23406 L
s
.49069 .23402 m
.49079 .2255 L
s
.49079 .2255 m
.49064 .24244 L
s
.4 .312 1 r
.60221 .23729 m
.6024 .24569 L
s
.60245 .24535 m
.60221 .23729 L
s
.799 .209 1 r
.2055 .25927 m
.20541 .25947 L
s
.376 .32 1 r
.39064 .249 m
.39056 .24945 L
s
.648 .244 1 r
.75621 .25563 m
.75618 .25598 L
s
.4 .312 1 r
.6024 .24569 m
.60223 .23724 L
s
.60223 .23724 m
.60245 .24535 L
s
.443 .299 1 r
.4539 .23671 m
.4537 .24534 L
s
.45378 .24469 m
.4539 .23671 L
s
.4537 .24534 m
.45392 .23667 L
s
.45392 .23667 m
.45378 .24469 L
s
.904 .186 1 r
.67688 .26031 m
.67683 .26062 L
s
.425 .304 1 r
.53895 .25003 m
.53889 .25048 L
s
.88 .191 1 r
.73347 .18538 m
.73674 .23165 L
s
.352 .327 1 r
.41037 .18538 m
.40918 .22441 L
s
.476 .924 1 r
.35284 .21557 m
.35245 .22233 L
s
.35247 .22229 m
.35284 .21557 L
s
.35284 .21557 m
.35215 .22871 L
s
.36 .324 1 r
.71847 .22223 m
.71894 .23056 L
s
.71897 .23051 m
.71847 .22223 L
s
.71847 .22223 m
.71947 .2384 L
s
.811 .206 1 r
.55502 .25835 m
.55496 .2587 L
s
.337 .352 1 r
.65513 .23497 m
.65546 .24314 L
s
.6555 .24273 m
.65513 .23497 L
s
.701 .231 1 r
.63914 .22689 m
.63943 .23615 L
s
.63946 .2361 m
.63914 .22689 L
s
.63914 .22689 m
.6398 .24499 L
s
.777 .214 1 r
.32161 .2446 m
.32101 .2539 L
s
.32108 .25389 m
.32161 .2446 L
s
.337 .352 1 r
.65546 .24314 m
.65515 .23493 L
s
.65515 .23493 m
.6555 .24273 L
s
.777 .214 1 r
.32101 .2539 m
.32163 .24455 L
s
.32163 .24455 m
.32108 .25389 L
s
.504 .282 1 r
.58516 .1851 m
.58616 .22641 L
s
.701 .232 1 r
.26202 .1851 m
.25852 .23022 L
s
.733 .224 1 r
.52286 .24257 m
.52285 .25186 L
s
.52292 .25155 m
.52286 .24257 L
s
.512 .279 1 r
.57577 .23965 m
.5759 .24833 L
s
.57596 .24818 m
.57577 .23965 L
s
.733 .224 1 r
.52285 .25186 m
.52289 .24252 L
s
.52289 .24252 m
.52292 .25155 L
s
.512 .279 1 r
.5759 .24833 m
.57579 .23961 L
s
.57579 .23961 m
.57596 .24818 L
s
.579 .262 1 r
.28475 .25611 m
.28469 .25596 L
s
.88 .191 1 r
.49641 .24433 m
.49631 .25397 L
s
.49639 .25362 m
.49641 .24433 L
s
.559 .267 1 r
.66086 .25313 m
.66081 .25347 L
s
.618 .252 1 r
.66561 .22596 m
.66597 .23499 L
s
.666 .23495 m
.66561 .22596 L
s
.66561 .22596 m
.66641 .24368 L
s
.799 .209 1 r
.78752 .22819 m
.78825 .23764 L
s
.78828 .23759 m
.78752 .22819 L
s
.78752 .22819 m
.78906 .24679 L
s
.88 .191 1 r
.49631 .25397 m
.49643 .24428 L
s
.49643 .24428 m
.49639 .25362 L
s
.744 .221 1 r
.75999 .18481 m
.76353 .22956 L
s
.638 .247 1 r
.4368 .18481 m
.43582 .22842 L
s
.578 .262 1 r
.78276 .25546 m
.7827 .25543 L
s
.811 .206 1 r
.61164 .18453 m
.61311 .22966 L
s
.766 .217 1 r
.28841 .18453 m
.28529 .22966 L
s
.811 .206 1 r
.69773 .2429 m
.69823 .25239 L
s
.69828 .25204 m
.69773 .2429 L
s
.423 .733 1 r
.75067 .23996 m
.75065 .24032 L
s
.811 .206 1 r
.69823 .25239 m
.69775 .24285 L
s
.69775 .24285 m
.69828 .25204 L
s
.69 .234 1 r
.45956 .25622 m
.45949 .25638 L
s
.799 .209 1 r
.81406 .22763 m
.81487 .23709 L
s
.81491 .23704 m
.81406 .22763 L
s
.81406 .22763 m
.81576 .24624 L
s
.531 .274 1 r
.78652 .18424 m
.79021 .22633 L
s
.69 .234 1 r
.46325 .18424 m
.46263 .22823 L
s
.711 .229 1 r
.63444 .25557 m
.63438 .25592 L
s
.669 .239 1 r
.31116 .25557 m
.31108 .25576 L
s
.733 .224 1 r
.37445 .2432 m
.37401 .25238 L
s
.37408 .25242 m
.37445 .2432 L
s
.36 .324 1 r
.77152 .22111 m
.77213 .22945 L
s
.77216 .2294 m
.77152 .22111 L
s
.77152 .22111 m
.77279 .23729 L
s
.834 .201 1 r
.4331 .25791 m
.43302 .25822 L
s
.733 .224 1 r
.37401 .25238 m
.37447 .24315 L
s
.37447 .24315 m
.37408 .25242 L
s
.513 .279 1 r
.18919 .25361 m
.18913 .25354 L
s
.441 .3 1 r
.41701 .24996 m
.41694 .25027 L
s
.377 .541 1 r
.76109 .23095 m
.76166 .23873 L
s
.76167 .23824 m
.76109 .23095 L
s
.76166 .23873 m
.76111 .23091 L
s
.76111 .23091 m
.76167 .23824 L
s
.388 .587 1 r
.40093 .24202 m
.40086 .24246 L
s
.881 .191 1 r
.63814 .18396 m
.64002 .22986 L
s
.569 .264 1 r
.31482 .18396 m
.31218 .22719 L
s
.531 .274 1 r
.57019 .2239 m
.57029 .2327 L
s
.57031 .23265 m
.57019 .2239 L
s
.57019 .2239 m
.57046 .24115 L
s
.94 .179 1 r
.19951 .24468 m
.19852 .25441 L
s
.19861 .25421 m
.19951 .24468 L
s
.826 .203 1 r
.27894 .24031 m
.27819 .24999 L
s
.27832 .24914 m
.27894 .24031 L
s
.94 .179 1 r
.19852 .25441 m
.19953 .24463 L
s
.19953 .24463 m
.19861 .25421 L
s
.701 .232 1 r
.48971 .18367 m
.48945 .22805 L
s
.669 .239 1 r
.33758 .25502 m
.3375 .25521 L
s
.826 .203 1 r
.27819 .24999 m
.27896 .24026 L
s
.27896 .24026 m
.27832 .24914 L
s
.881 .191 1 r
.51726 .22715 m
.51721 .23683 L
s
.51723 .23678 m
.51726 .22715 L
s
.51726 .22715 m
.51724 .24606 L
s
.777 .214 1 r
.69219 .22653 m
.69264 .23595 L
s
.69267 .2359 m
.69219 .22653 L
s
.69219 .22653 m
.69317 .24503 L
s
.531 .274 1 r
.21557 .25306 m
.21551 .25306 L
s
.485 .287 1 r
.30537 .23915 m
.30478 .24764 L
s
.30483 .24783 m
.30537 .23915 L
s
.868 .194 1 r
.25813 .2597 m
.25806 .25967 L
s
.485 .287 1 r
.30478 .24764 m
.30539 .2391 L
s
.30539 .2391 m
.30483 .24783 L
s
.857 .196 1 r
.34232 .22818 m
.34175 .23772 L
s
.34177 .23767 m
.34232 .22818 L
s
.34232 .22818 m
.34127 .2471 L
s
.417 .307 1 r
.62316 .22158 m
.62339 .23007 L
s
.62341 .23003 m
.62316 .22158 L
s
.62316 .22158 m
.62369 .23814 L
s
.744 .221 1 r
.66465 .18339 m
.66684 .22777 L
s
.483 .948 1 r
.34124 .18339 m
.33959 .21486 L
s
.733 .224 1 r
.2524 .24237 m
.25161 .25156 L
s
.25168 .25159 m
.2524 .24237 L
s
.467 .292 1 r
.27326 .22327 m
.27256 .23184 L
s
.27258 .23179 m
.27326 .22327 L
s
.27326 .22327 m
.27195 .24022 L
s
.733 .224 1 r
.25161 .25156 m
.25242 .24232 L
s
.25242 .24232 m
.25168 .25159 L
s
.916 .184 1 r
.72431 .24325 m
.72491 .25298 L
s
.72495 .25263 m
.72431 .24325 L
s
.72491 .25298 m
.72434 .2432 L
s
.72434 .2432 m
.72495 .25263 L
s
1 .113 .716 r
.46991 .24851 m
.46973 .2589 L
s
.4698 .25874 m
.46991 .24851 L
s
.618 .252 1 r
.56546 .25213 m
.5654 .25259 L
s
1 .113 .716 r
.46973 .2589 m
.46994 .24846 L
s
.46994 .24846 m
.4698 .25874 L
s
.375 .32 1 r
.51618 .18311 m
.51628 .22292 L
s
.522 .277 1 r
.76692 .25017 m
.76689 .25059 L
s
.476 .29 1 r
.53327 .23626 m
.53329 .24489 L
s
.53335 .24455 m
.53327 .23626 L
s
.845 .199 1 r
.54374 .2267 m
.54377 .23628 L
s
.54379 .23623 m
.54374 .2267 L
s
.54374 .2267 m
.54388 .24551 L
s
.476 .29 1 r
.53329 .24489 m
.53329 .23621 L
s
.53329 .23621 m
.53335 .24455 L
s
.735 .224 1 r
.62881 .24005 m
.62911 .2494 L
s
.62916 .24896 m
.62881 .24005 L
s
.766 .216 1 r
.5125 .25551 m
.51243 .25582 L
s
.735 .224 1 r
.62911 .2494 m
.62884 .24 L
s
.62884 .24 m
.62916 .24896 L
s
.377 .542 1 r
.22587 .24456 m
.22582 .24448 L
s
.669 .239 1 r
.4803 .23948 m
.48017 .24862 L
s
.48024 .24831 m
.4803 .23948 L
s
.424 .305 1 r
.69118 .18282 m
.69351 .22339 L
s
.45 .297 1 r
.36767 .18282 m
.36587 .22377 L
s
.669 .239 1 r
.48017 .24862 m
.48033 .23943 L
s
.48033 .23943 m
.48024 .24831 L
s
.477 .289 1 r
.38476 .23598 m
.38437 .24462 L
s
.38445 .24427 m
.38476 .23598 L
s
.38437 .24462 m
.38478 .23593 L
s
.38478 .23593 m
.38445 .24427 L
s
.859 .196 1 r
.77735 .24124 m
.7781 .25089 L
s
.77813 .25038 m
.77735 .24124 L
s
.618 .252 1 r
.50679 .23832 m
.50673 .24735 L
s
.5068 .247 m
.50679 .23832 L
s
.859 .196 1 r
.7781 .25089 m
.77738 .24119 L
s
.77738 .24119 m
.77813 .25038 L
s
.618 .252 1 r
.50673 .24735 m
.50681 .23827 L
s
.50681 .23827 m
.5068 .247 L
s
.531 .274 1 r
.44818 .22374 m
.44795 .23247 L
s
.44797 .23242 m
.44818 .22374 L
s
.44818 .22374 m
.4478 .24108 L
s
.66 .241 1 r
.54267 .18254 m
.54315 .22577 L
s
.701 .231 1 r
.22018 .22754 m
.21929 .23658 L
s
.21931 .23653 m
.22018 .22754 L
s
.22018 .22754 m
.21847 .24589 L
s
.777 .214 1 r
.4217 .22542 m
.42137 .23484 L
s
.42139 .23479 m
.4217 .22542 L
s
.4217 .22542 m
.42114 .24392 L
s
.711 .229 1 r
.59673 .22469 m
.5969 .23396 L
s
.59693 .23391 m
.59673 .22469 L
s
.59673 .22469 m
.59716 .24288 L
s
.578 .262 1 r
.59197 .25196 m
.59191 .25215 L
s
.618 .252 1 r
.20969 .23747 m
.20879 .24653 L
s
.2089 .24607 m
.20969 .23747 L
s
.811 .206 1 r
.71772 .18225 m
.72072 .22778 L
s
.56 .267 1 r
.39413 .18225 m
.39258 .22512 L
s
.618 .252 1 r
.20879 .24653 m
.20971 .23742 L
s
.20971 .23742 m
.2089 .24607 L
s
.7 .232 1 r
.33174 .23981 m
.33118 .24899 L
s
.33125 .2488 m
.33174 .23981 L
s
.33118 .24899 m
.33176 .23976 L
s
.33176 .23976 m
.33125 .2488 L
s
.916 .184 1 r
.486 .25833 m
.48593 .25845 L
s
.99 .169 1 r
.80963 .25833 m
.8096 .25868 L
s
.599 .257 1 r
.61848 .25104 m
.61843 .25142 L
s
.4 .312 1 r
.52766 .22026 m
.52763 .22868 L
s
.52765 .22863 m
.52766 .22026 L
s
.52766 .22026 m
.52769 .23675 L
s
.468 .292 1 r
.56918 .18197 m
.56997 .22292 L
s
.88 .191 1 r
.68757 .25637 m
.68752 .25672 L
s
.845 .199 1 r
.80394 .24099 m
.80477 .25056 L
s
.8048 .25021 m
.80394 .24099 L
s
.904 .186 1 r
.24661 .22697 m
.24574 .23663 L
s
.24576 .23658 m
.24661 .22697 L
s
.24661 .22697 m
.24498 .2461 L
s
.391 .315 1 r
.61277 .23369 m
.613 .24206 L
s
.61305 .24176 m
.61277 .23369 L
s
.335 .341 1 r
.31562 .23223 m
.31507 .2404 L
s
.31515 .24006 m
.31562 .23223 L
s
.845 .199 1 r
.80477 .25056 m
.80397 .24094 L
s
.80397 .24094 m
.8048 .25021 L
s
.441 .3 1 r
.34782 .24841 m
.34774 .2486 L
s
.391 .315 1 r
.613 .24206 m
.6128 .23364 L
s
.6128 .23364 m
.61305 .24176 L
s
.335 .341 1 r
.31507 .2404 m
.31563 .23218 L
s
.31563 .23218 m
.31515 .24006 L
s
.733 .224 1 r
.24182 .25441 m
.24174 .2546 L
s
.495 .284 1 r
.74428 .18168 m
.74735 .22302 L
s
.45 .297 1 r
.42059 .18168 m
.41948 .22226 L
s
.373 .52 1 r
.43206 .21707 m
.43181 .22487 L
s
.43182 .22483 m
.43206 .21707 L
s
.43206 .21707 m
.43164 .23233 L
s
.395 .62 1 r
.39509 .22815 m
.39478 .2357 L
s
.39485 .23537 m
.39509 .22815 L
s
.531 .274 1 r
.82009 .24945 m
.82006 .24979 L
s
.68 .237 1 r
.64976 .22301 m
.65009 .23224 L
s
.65012 .23219 m
.64976 .22301 L
s
.64976 .22301 m
.65049 .24101 L
s
.395 .62 1 r
.39478 .2357 m
.39511 .22811 L
s
.39511 .22811 m
.39485 .23537 L
s
.892 .189 1 r
.74536 .22673 m
.74598 .23635 L
s
.74602 .2363 m
.74536 .22673 L
s
.74536 .22673 m
.7467 .24582 L
s
.834 .201 1 r
.7141 .25544 m
.71405 .25575 L
s
1 .111 .702 r
.36867 .22972 m
.36813 .2402 L
s
.36815 .24014 m
.36867 .22972 L
s
.36867 .22972 m
.3677 .25036 L
s
.669 .239 1 r
.26827 .25348 m
.2682 .25356 L
s
.56 .267 1 r
.5957 .1814 m
.59686 .2235 L
s
.598 .257 1 r
.27196 .1814 m
.26862 .22617 L
s
.734 .224 1 r
.4434 .25282 m
.44332 .25325 L
s
.811 .206 1 r
.47466 .22419 m
.47448 .23373 L
s
.47451 .23368 m
.47466 .22419 L
s
.47466 .22419 m
.4744 .24281 L
s
.503 .282 1 r
.26255 .23605 m
.26183 .2447 L
s
.26191 .24458 m
.26255 .23605 L
s
1 .093 .6 r
.54939 .24716 m
.54947 .25783 L
s
.54954 .25747 m
.54939 .24716 L
s
.503 .282 1 r
.26183 .2447 m
.26257 .23601 L
s
.26257 .23601 m
.26191 .24458 L
s
.711 .229 1 r
.74063 .25451 m
.74057 .25451 L
s
1 .093 .6 r
.54947 .25783 m
.54942 .24711 L
s
.54942 .24711 m
.54954 .25747 L
s
.618 .252 1 r
.41117 .23694 m
.41084 .24596 L
s
.41092 .24562 m
.41117 .23694 L
s
.41084 .24596 m
.41119 .23689 L
s
.41119 .23689 m
.41092 .24562 L
s
.386 .316 1 r
.3582 .23991 m
.35806 .24128 L
s
.476 .924 1 r
.35245 .22233 m
.35208 .22907 L
s
.35215 .22871 m
.35245 .22233 L
s
.559 .267 1 r
.67154 .24955 m
.67149 .2499 L
s
.476 .924 1 r
.35208 .22907 m
.35247 .22229 L
s
.35247 .22229 m
.35215 .22871 L
s
.777 .214 1 r
.77085 .18111 m
.77459 .22627 L
s
1 .161 .972 r
.44707 .18111 m
.44615 .22894 L
s
.744 .222 1 r
.70844 .2387 m
.70897 .24804 L
s
.70901 .24769 m
.70844 .2387 L
s
.68 .237 1 r
.79368 .25189 m
.79365 .25224 L
s
.744 .222 1 r
.70897 .24804 m
.70847 .23865 L
s
.70847 .23865 m
.70901 .24769 L
s
.649 .244 1 r
.64504 .25124 m
.64499 .25159 L
s
.618 .252 1 r
.58631 .23666 m
.58648 .24569 L
s
.58654 .24534 m
.58631 .23666 L
s
.58648 .24569 m
.58634 .23661 L
s
.58634 .23661 m
.58654 .24534 L
s
.36 .325 1 r
.75585 .21838 m
.75642 .22668 L
s
.75644 .22664 m
.75585 .21838 L
s
.75585 .21838 m
.75704 .23461 L
s
.869 .194 1 r
.79848 .22502 m
.79926 .23464 L
s
.79929 .23459 m
.79848 .22502 L
s
.79848 .22502 m
.80011 .24395 L
s
.542 .271 1 r
.46418 .23462 m
.464 .24349 L
s
.46407 .24299 m
.46418 .23462 L
s
.335 .34 1 r
.62223 .18083 m
.62363 .21951 L
s
.701 .232 1 r
.29841 .18083 m
.29548 .22523 L
s
.542 .271 1 r
.464 .24349 m
.46419 .23457 L
s
.46419 .23457 m
.46407 .24299 L
s
.701 .231 1 r
.29947 .22586 m
.2988 .23491 L
s
.29882 .23486 m
.29947 .22586 L
s
.29947 .22586 m
.2982 .24423 L
s
.701 .232 1 r
.67634 .22306 m
.67674 .23229 L
s
.67677 .23224 m
.67634 .22306 L
s
.67634 .22306 m
.67722 .24121 L
s
.618 .252 1 r
.43766 .23638 m
.4374 .24541 L
s
.43748 .24507 m
.43766 .23638 L
s
.589 .259 1 r
.55419 .22094 m
.55424 .22994 L
s
.55426 .22989 m
.55419 .22094 L
s
.55419 .22094 m
.55437 .23848 L
s
.23033 .22094 m
.22948 .22994 L
s
.22949 .22989 m
.23033 .22094 L
s
.23033 .22094 m
.22875 .23847 L
s
.618 .252 1 r
.4374 .24541 m
.43768 .23633 L
s
.43768 .23633 m
.43748 .24507 L
s
.424 .305 1 r
.42726 .246 m
.42719 .24634 L
s
.4 .312 1 r
.60245 .24535 m
.6024 .24569 L
s
.638 .247 1 r
.79744 .18054 m
.80141 .22418 L
s
.56 .267 1 r
.47357 .18054 m
.4731 .22341 L
s
.94 .179 1 r
.68198 .24107 m
.68245 .25084 L
s
.6825 .25053 m
.68198 .24107 L
s
.443 .299 1 r
.45378 .24469 m
.4537 .24534 L
s
.94 .179 1 r
.68245 .25084 m
.68201 .24102 L
s
.68201 .24102 m
.6825 .25053 L
s
.648 .244 1 r
.70288 .22201 m
.70335 .23112 L
s
.70338 .23107 m
.70288 .22201 L
s
.70288 .22201 m
.70389 .23989 L
s
.904 .186 1 r
.32596 .22496 m
.32533 .23466 L
s
.32535 .23461 m
.32596 .22496 L
s
.32596 .22496 m
.32481 .24405 L
s
.811 .206 1 r
.55982 .23903 m
.55991 .24852 L
s
.55998 .24817 m
.55982 .23903 L
s
.766 .217 1 r
.23592 .23903 m
.23507 .24837 L
s
.23516 .24817 m
.23592 .23903 L
s
.649 .244 1 r
.28896 .2361 m
.28827 .24525 L
s
.28838 .24479 m
.28896 .2361 L
s
.811 .206 1 r
.55991 .24852 m
.55984 .23898 L
s
.55984 .23898 m
.55998 .24817 L
s
.766 .217 1 r
.23507 .24837 m
.23594 .23898 L
s
.23594 .23898 m
.23516 .24817 L
s
.337 .352 1 r
.6555 .24273 m
.65546 .24314 L
s
.649 .244 1 r
.28827 .24525 m
.28897 .23606 L
s
.28897 .23606 m
.28838 .24479 L
s
.766 .217 1 r
.73503 .23845 m
.73564 .24783 L
s
.73569 .24752 m
.73503 .23845 L
s
1 .161 .972 r
.3638 .25903 m
.36373 .25904 L
s
.467 .292 1 r
.49067 .23406 m
.49057 .24263 L
s
.49064 .24244 m
.49067 .23406 L
s
.69 .234 1 r
.29464 .25407 m
.29458 .25388 L
s
.744 .222 1 r
.64878 .18026 m
.65077 .22504 L
s
.788 .212 1 r
.32487 .18026 m
.32219 .22657 L
s
.766 .217 1 r
.73564 .24783 m
.73506 .2384 L
s
.73506 .2384 m
.73569 .24752 L
s
.467 .292 1 r
.49057 .24263 m
.49069 .23402 L
s
.49069 .23402 m
.49064 .24244 L
s
.345 .39 1 r
.63374 .21717 m
.63398 .22524 L
s
.63401 .2252 m
.63374 .21717 L
s
.63374 .21717 m
.6343 .23301 L
s
.36 .324 1 r
.71894 .23056 m
.71944 .23889 L
s
.71947 .2384 m
.71894 .23056 L
s
.71944 .23889 m
.71897 .23051 L
s
.71897 .23051 m
.71947 .2384 L
s
.467 .292 1 r
.40547 .22115 m
.40513 .22966 L
s
.40515 .22961 m
.40547 .22115 L
s
.40547 .22115 m
.40486 .2382 L
s
.834 .201 1 r
.50008 .17997 m
.49996 .22591 L
s
.398 .631 1 r
.36282 .21481 m
.36242 .22231 L
s
.36243 .22227 m
.36282 .21481 L
s
.36282 .21481 m
.36209 .22961 L
s
.477 .289 1 r
.45852 .21864 m
.45831 .22733 L
s
.45833 .22728 m
.45852 .21864 L
s
.45852 .21864 m
.45819 .23556 L
s
.55 .269 1 r
.25673 .22087 m
.25596 .22968 L
s
.25598 .22963 m
.25673 .22087 L
s
.25673 .22087 m
.2553 .2383 L
s
.512 .279 1 r
.57596 .24818 m
.5759 .24833 L
s
.649 .244 1 r
.67535 .17969 m
.67765 .22333 L
s
.541 .272 1 r
.35134 .17969 m
.34924 .22218 L
s
.669 .239 1 r
.37893 .22329 m
.37849 .23233 L
s
.37851 .23228 m
.37893 .22329 L
s
.37893 .22329 m
.37813 .24141 L
s
.377 .541 1 r
.76167 .23824 m
.76166 .23873 L
s
.733 .224 1 r
.52292 .25155 m
.52285 .25186 L
s
.701 .231 1 r
.63943 .23615 m
.63975 .24542 L
s
.6398 .24499 m
.63943 .23615 L
s
.68 .237 1 r
.58074 .22139 m
.58087 .23059 L
s
.58089 .23054 m
.58074 .22139 L
s
.58074 .22139 m
.58108 .23944 L
s
.618 .252 1 r
.52661 .1794 m
.52686 .22266 L
s
.701 .231 1 r
.63975 .24542 m
.63946 .2361 L
s
.63946 .2361 m
.6398 .24499 L
s
.777 .214 1 r
.32108 .25389 m
.32101 .2539 L
s
.618 .252 1 r
.66597 .23499 m
.66636 .24403 L
s
.66641 .24368 m
.66597 .23499 L
s
1 .149 .908 r
.50116 .22615 m
.50105 .2362 L
s
.50107 .23615 m
.50116 .22615 L
s
.50116 .22615 m
.50104 .24606 L
s
.618 .252 1 r
.66636 .24403 m
.666 .23495 L
s
.666 .23495 m
.66641 .24368 L
s
.712 .229 1 r
.70193 .17911 m
.70462 .22315 L
s
.335 .341 1 r
.37783 .17911 m
.37622 .21819 L
s
.88 .191 1 r
.49639 .25362 m
.49631 .25397 L
s
.467 .292 1 r
.3097 .21908 m
.3091 .22765 L
s
.30912 .22761 m
.3097 .21908 L
s
.3097 .21908 m
.30859 .23604 L
s
.36 .324 1 r
.77213 .22945 m
.77277 .23778 L
s
.77279 .23729 m
.77213 .22945 L
s
.77277 .23778 m
.77216 .2294 L
s
.77216 .2294 m
.77279 .23729 L
s
.799 .209 1 r
.78825 .23764 m
.78902 .2471 L
s
.78906 .24679 m
.78825 .23764 L
s
.78902 .2471 m
.78828 .23759 L
s
.78828 .23759 m
.78906 .24679 L
s
.712 .229 1 r
.78264 .22011 m
.78336 .22945 L
s
.78339 .2294 m
.78264 .22011 L
s
.78264 .22011 m
.78412 .23823 L
s
.337 .332 1 r
.55315 .17883 m
.5537 .21753 L
s
.811 .206 1 r
.69828 .25204 m
.69823 .25239 L
s
.744 .222 1 r
.72852 .17854 m
.73163 .22334 L
s
.476 .29 1 r
.40433 .17854 m
.40298 .21991 L
s
.733 .224 1 r
.37408 .25242 m
.37401 .25238 L
s
.799 .209 1 r
.81487 .23709 m
.81572 .24655 L
s
.81576 .24624 m
.81487 .23709 L
s
.531 .274 1 r
.57029 .2327 m
.5704 .2415 L
s
.57046 .24115 m
.57029 .2327 L
s
.799 .209 1 r
.81572 .24655 m
.81491 .23704 L
s
.81491 .23704 m
.81576 .24624 L
s
.531 .274 1 r
.5704 .2415 m
.57031 .23265 L
s
.57031 .23265 m
.57046 .24115 L
s
.505 .281 1 r
.57971 .17826 m
.58063 .21886 L
s
.977 .171 1 r
.72964 .22408 m
.73023 .2339 L
s
.73026 .23384 m
.72964 .22408 L
s
.72964 .22408 m
.7309 .24352 L
s
.826 .203 1 r
.27832 .24914 m
.27819 .24999 L
s
.485 .287 1 r
.30483 .24783 m
.30478 .24764 L
s
.417 .307 1 r
.62339 .23007 m
.62364 .23856 L
s
.62369 .23814 m
.62339 .23007 L
s
.62364 .23856 m
.62341 .23003 L
s
.62341 .23003 m
.62369 .23814 L
s
.68 .236 1 r
.28305 .22219 m
.28234 .23124 L
s
.28236 .23119 m
.28305 .22219 L
s
.28305 .22219 m
.2817 .24041 L
s
.467 .292 1 r
.27256 .23184 m
.27188 .24041 L
s
.27195 .24022 m
.27256 .23184 L
s
.711 .229 1 r
.75513 .17797 m
.75859 .22239 L
s
.476 .29 1 r
.43085 .17797 m
.42984 .21934 L
s
.467 .292 1 r
.27188 .24041 m
.27258 .23179 L
s
.27258 .23179 m
.27195 .24022 L
s
.476 .29 1 r
.53335 .24455 m
.53329 .24489 L
s
.94 .179 1 r
.19861 .25421 m
.19852 .25441 L
s
.777 .214 1 r
.69264 .23595 m
.69313 .24537 L
s
.69317 .24503 m
.69264 .23595 L
s
.68 .237 1 r
.33613 .21971 m
.33556 .22891 L
s
.33558 .22886 m
.33613 .21971 L
s
.33613 .21971 m
.3351 .23776 L
s
.754 .219 1 r
.60628 .17769 m
.60768 .22326 L
s
.589 .259 1 r
.28195 .17769 m
.27889 .22058 L
s
.777 .214 1 r
.69313 .24537 m
.69267 .2359 L
s
.69267 .2359 m
.69317 .24503 L
s
.881 .191 1 r
.51721 .23683 m
.51717 .24653 L
s
.51724 .24606 m
.51721 .23683 L
s
.733 .224 1 r
.25168 .25159 m
.25161 .25156 L
s
.99 .169 1 r
.60737 .22286 m
.60758 .23276 L
s
.60761 .23271 m
.60737 .22286 L
s
.60737 .22286 m
.60789 .24231 L
s
.881 .191 1 r
.51717 .24653 m
.51723 .23678 L
s
.51723 .23678 m
.51724 .24606 L
s
.477 .289 1 r
.38445 .24427 m
.38437 .24462 L
s
.857 .196 1 r
.34175 .23772 m
.34119 .24726 L
s
.34127 .2471 m
.34175 .23772 L
s
.34119 .24726 m
.34177 .23767 L
s
.34177 .23767 m
.34127 .2471 L
s
.8 .209 1 r
.48501 .22094 m
.48486 .23041 L
s
.48489 .23036 m
.48501 .22094 L
s
.48501 .22094 m
.48481 .23957 L
s
.916 .184 1 r
.72495 .25263 m
.72491 .25298 L
s
.579 .262 1 r
.78176 .1774 m
.78545 .2203 L
s
.599 .257 1 r
.45738 .1774 m
.45671 .21954 L
s
.735 .224 1 r
.62916 .24896 m
.62911 .2494 L
s
.811 .206 1 r
.66049 .22028 m
.66086 .22982 L
s
.66088 .22977 m
.66049 .22028 L
s
.66049 .22028 m
.6613 .23891 L
s
.669 .239 1 r
.48024 .24831 m
.48017 .24862 L
s
.45 .297 1 r
.74015 .2159 m
.7407 .22451 L
s
.74072 .22446 m
.74015 .2159 L
s
.74015 .2159 m
.7413 .23267 L
s
.618 .252 1 r
.5068 .247 m
.50673 .24735 L
s
.357 .448 1 r
.49543 .21173 m
.49533 .2198 L
s
.49535 .21976 m
.49543 .21173 L
s
.49543 .21173 m
.49531 .22719 L
s
.395 .619 1 r
.34649 .21101 m
.34605 .21862 L
s
.34606 .21858 m
.34649 .21101 L
s
.34649 .21101 m
.34569 .22578 L
s
.476 .924 1 r
.35215 .22871 m
.35208 .22907 L
s
.531 .274 1 r
.44795 .23247 m
.44773 .2412 L
s
.4478 .24108 m
.44795 .23247 L
s
.395 .62 1 r
.39485 .23537 m
.39478 .2357 L
s
.477 .289 1 r
.63287 .17711 m
.63449 .21849 L
s
.799 .209 1 r
.30844 .17711 m
.30555 .22307 L
s
.531 .274 1 r
.44773 .2412 m
.44797 .23242 L
s
.44797 .23242 m
.4478 .24108 L
s
.845 .199 1 r
.54377 .23628 m
.54381 .24586 L
s
.54388 .24551 m
.54377 .23628 L
s
.54381 .24586 m
.54379 .23623 L
s
.54379 .23623 m
.54388 .24551 L
s
.777 .214 1 r
.51157 .22011 m
.5115 .22954 L
s
.51152 .22949 m
.51157 .22011 L
s
.51157 .22011 m
.51152 .23863 L
s
.859 .196 1 r
.77813 .25038 m
.7781 .25089 L
s
.579 .262 1 r
.71363 .21796 m
.71412 .22689 L
s
.71415 .22684 m
.71363 .21796 L
s
.71363 .21796 m
.71469 .23551 L
s
.335 .341 1 r
.31515 .24006 m
.31507 .2404 L
s
.618 .252 1 r
.2089 .24607 m
.20879 .24653 L
s
.701 .231 1 r
.21929 .23658 m
.21842 .24563 L
s
.21847 .24589 m
.21929 .23658 L
s
.68 .237 1 r
.53813 .21888 m
.53814 .22807 L
s
.53816 .22802 m
.53813 .21888 L
s
.53813 .21888 m
.53823 .23693 L
s
.391 .315 1 r
.61305 .24176 m
.613 .24206 L
s
1 .113 .716 r
.4698 .25874 m
.46973 .2589 L
s
.701 .231 1 r
.21842 .24563 m
.21931 .23653 L
s
.21931 .23653 m
.21847 .24589 L
s
.88 .191 1 r
.48393 .17683 m
.48358 .22317 L
s
.373 .52 1 r
.43181 .22487 m
.43157 .23266 L
s
.43164 .23233 m
.43181 .22487 L
s
.618 .252 1 r
.5647 .21753 m
.56478 .22661 L
s
.5648 .22656 m
.5647 .21753 L
s
.5647 .21753 m
.56494 .23523 L
s
.373 .52 1 r
.43157 .23266 m
.43182 .22483 L
s
.43182 .22483 m
.43164 .23233 L
s
.4 .312 1 r
.52763 .22868 m
.52763 .23709 L
s
.52769 .23675 m
.52763 .22868 L
s
.52763 .23709 m
.52765 .22863 L
s
.52765 .22863 m
.52769 .23675 L
s
.711 .229 1 r
.5969 .23396 m
.5971 .24323 L
s
.59716 .24288 m
.5969 .23396 L
s
.5971 .24323 m
.59693 .23391 L
s
.59693 .23391 m
.59716 .24288 L
s
.7 .232 1 r
.33125 .2488 m
.33118 .24899 L
s
.777 .214 1 r
.42137 .23484 m
.42106 .24426 L
s
.42114 .24392 m
.42137 .23484 L
s
.45 .297 1 r
.44229 .21567 m
.44204 .22425 L
s
.44206 .2242 m
.44229 .21567 L
s
.44229 .21567 m
.44188 .23249 L
s
.744 .221 1 r
.65947 .17654 m
.66161 .22136 L
s
.451 .837 1 r
.33495 .17654 m
.33313 .20994 L
s
.777 .214 1 r
.42106 .24426 m
.42139 .23479 L
s
.42139 .23479 m
.42114 .24392 L
s
.342 .378 1 r
.31988 .21348 m
.31934 .22159 L
s
.31935 .22155 m
.31988 .21348 L
s
.31988 .21348 m
.31889 .22937 L
s
1 .156 .946 r
.80954 .22251 m
.81039 .23253 L
s
.81042 .23248 m
.80954 .22251 L
s
.80954 .22251 m
.81132 .24224 L
s
.433 .772 1 r
.51049 .17625 m
.51052 .21041 L
s
.845 .199 1 r
.8048 .25021 m
.80477 .25056 L
s
.392 .314 1 r
.64443 .21408 m
.64471 .2225 L
s
.64473 .22246 m
.64443 .21408 L
s
.64443 .21408 m
.64506 .23051 L
s
.372 .52 1 r
.52199 .21208 m
.52195 .21985 L
s
.52197 .21981 m
.52199 .21208 L
s
.52199 .21208 m
.52199 .2274 L
s
.658 .242 1 r
.24011 .21873 m
.23928 .22782 L
s
.2393 .22777 m
.24011 .21873 L
s
.24011 .21873 m
.23854 .23675 L
s
.503 .282 1 r
.26191 .24458 m
.26183 .2447 L
s
.733 .224 1 r
.68609 .17597 m
.6886 .22079 L
s
.388 .587 1 r
.36148 .17597 m
.35979 .21241 L
s
.904 .186 1 r
.24574 .23663 m
.24489 .24629 L
s
.24498 .2461 m
.24574 .23663 L
s
.765 .217 1 r
.38912 .21965 m
.3887 .229 L
s
.38872 .22895 m
.38912 .21965 L
s
.38912 .21965 m
.38837 .23817 L
s
.68 .237 1 r
.65009 .23224 m
.65044 .24147 L
s
.65049 .24101 m
.65009 .23224 L
s
.904 .186 1 r
.24489 .24629 m
.24576 .23658 L
s
.24576 .23658 m
.24498 .2461 L
s
.68 .237 1 r
.65044 .24147 m
.65012 .23219 L
s
.65012 .23219 m
.65049 .24101 L
s
.618 .252 1 r
.41092 .24562 m
.41084 .24596 L
s
.669 .239 1 r
.5913 .21779 m
.59146 .22696 L
s
.59149 .22691 m
.5913 .21779 L
s
.5913 .21779 m
.5917 .23581 L
s
.36 .325 1 r
.75642 .22668 m
.75701 .23498 L
s
.75704 .23461 m
.75642 .22668 L
s
.722 .227 1 r
.53707 .17568 m
.53748 .22127 L
s
.892 .189 1 r
.74598 .23635 m
.74664 .24598 L
s
.7467 .24582 m
.74598 .23635 L
s
.36 .325 1 r
.75701 .23498 m
.75644 .22664 L
s
.75644 .22664 m
.75704 .23461 L
s
.542 .271 1 r
.46407 .24299 m
.464 .24349 L
s
.599 .257 1 r
.41567 .21868 m
.41534 .22754 L
s
.41536 .22749 m
.41567 .21868 L
s
.41567 .21868 m
.41509 .23647 L
s
.388 .588 1 r
.37294 .21202 m
.37256 .21956 L
s
.37257 .21952 m
.37294 .21202 L
s
.37294 .21202 m
.37224 .22711 L
s
.892 .189 1 r
.74664 .24598 m
.74602 .2363 L
s
.74602 .2363 m
.7467 .24582 L
s
.618 .252 1 r
.58654 .24534 m
.58648 .24569 L
s
.744 .222 1 r
.70901 .24769 m
.70897 .24804 L
s
.811 .206 1 r
.47448 .23373 m
.47433 .24327 L
s
.4744 .24281 m
.47448 .23373 L
s
.638 .247 1 r
.71272 .17539 m
.71555 .21946 L
s
.38802 .17539 m
.38634 .21946 L
s
.811 .206 1 r
.47433 .24327 m
.47451 .23368 L
s
.47451 .23368 m
.4744 .24281 L
s
.578 .262 1 r
.6179 .21689 m
.61812 .22579 L
s
.61815 .22574 m
.6179 .21689 L
s
.6179 .21689 m
.61843 .23449 L
s
.904 .186 1 r
.68722 .22213 m
.68767 .23169 L
s
.68769 .23163 m
.68722 .22213 L
s
.68722 .22213 m
.68822 .2414 L
s
.36 .324 1 r
.71947 .2384 m
.71944 .23889 L
s
.618 .252 1 r
.43748 .24507 m
.4374 .24541 L
s
.345 .39 1 r
.63398 .22524 m
.63425 .23331 L
s
.6343 .23301 m
.63398 .22524 L
s
.398 .631 1 r
.36242 .22231 m
.36203 .22979 L
s
.36209 .22961 m
.36242 .22231 L
s
.701 .231 1 r
.2988 .23491 m
.29815 .24396 L
s
.2982 .24423 m
.2988 .23491 L
s
.345 .39 1 r
.63425 .23331 m
.63401 .2252 L
s
.63401 .2252 m
.6343 .23301 L
s
.398 .631 1 r
.36203 .22979 m
.36243 .22227 L
s
.36243 .22227 m
.36209 .22961 L
s
.701 .232 1 r
.26658 .21869 m
.26581 .22786 L
s
.26583 .22782 m
.26658 .21869 L
s
.26658 .21869 m
.26513 .23695 L
s
.701 .231 1 r
.29815 .24396 m
.29882 .23486 L
s
.29882 .23486 m
.2982 .24423 L
s
.68 .237 1 r
.56367 .17511 m
.56444 .21917 L
s
1 .111 .702 r
.36813 .2402 m
.36761 .25068 L
s
.3677 .25036 m
.36813 .2402 L
s
.36761 .25068 m
.36815 .24014 L
s
.36815 .24014 m
.3677 .25036 L
s
.589 .259 1 r
.55424 .22994 m
.55431 .23893 L
s
.55437 .23848 m
.55424 .22994 L
s
.22948 .22994 m
.22864 .23893 L
s
.22875 .23847 m
.22948 .22994 L
s
.467 .292 1 r
.49064 .24244 m
.49057 .24263 L
s
.589 .259 1 r
.55431 .23893 m
.55426 .22989 L
s
.55426 .22989 m
.55437 .23848 L
s
.22864 .23893 m
.22949 .22989 L
s
.22949 .22989 m
.22875 .23847 L
s
.701 .232 1 r
.67674 .23229 m
.67717 .24152 L
s
.67722 .24121 m
.67674 .23229 L
s
.649 .244 1 r
.28838 .24479 m
.28827 .24525 L
s
.701 .232 1 r
.67717 .24152 m
.67677 .23224 L
s
.67677 .23224 m
.67722 .24121 L
s
.869 .194 1 r
.79926 .23464 m
.80007 .24426 L
s
.80011 .24395 m
.79926 .23464 L
s
1 .093 .6 r
.54954 .25747 m
.54947 .25783 L
s
.869 .194 1 r
.80007 .24426 m
.79929 .23459 L
s
.79929 .23459 m
.80011 .24395 L
s
.81 .206 1 r
.73937 .17482 m
.74276 .22156 L
s
.365 .486 1 r
.41457 .17482 m
.41346 .21241 L
s
.744 .221 1 r
.46883 .21702 m
.46864 .22642 L
s
.46866 .22637 m
.46883 .21702 L
s
.46883 .21702 m
.46854 .23535 L
s
.648 .244 1 r
.70335 .23112 m
.70385 .24024 L
s
.70389 .23989 m
.70335 .23112 L
s
.467 .292 1 r
.40513 .22966 m
.4048 .23816 L
s
.40486 .2382 m
.40513 .22966 L
s
.648 .244 1 r
.70385 .24024 m
.70338 .23107 L
s
.70338 .23107 m
.70389 .23989 L
s
.467 .292 1 r
.4048 .23816 m
.40515 .22961 L
s
.40515 .22961 m
.40486 .2382 L
s
.834 .201 1 r
.76705 .21864 m
.76773 .22819 L
s
.76776 .22814 m
.76705 .21864 L
s
.76705 .21864 m
.76849 .23744 L
s
.766 .217 1 r
.29312 .21791 m
.29242 .2273 L
s
.29243 .22725 m
.29312 .21791 L
s
.29312 .21791 m
.29181 .23639 L
s
.811 .206 1 r
.55998 .24817 m
.55991 .24852 L
s
.766 .217 1 r
.23516 .24817 m
.23507 .24837 L
s
.73569 .24752 m
.73564 .24783 L
s
.94 .179 1 r
.6825 .25053 m
.68245 .25084 L
s
.4 .312 1 r
.59027 .17453 m
.59131 .21441 L
s
.904 .186 1 r
.32533 .23466 m
.32471 .24437 L
s
.32481 .24405 m
.32533 .23466 L
s
.365 .486 1 r
.60179 .21027 m
.60195 .21816 L
s
.60197 .21812 m
.60179 .21027 L
s
.60179 .21027 m
.60218 .22571 L
s
.477 .289 1 r
.45831 .22733 m
.45812 .23602 L
s
.45819 .23556 m
.45831 .22733 L
s
.904 .186 1 r
.32471 .24437 m
.32535 .23461 L
s
.32535 .23461 m
.32481 .24405 L
s
.477 .289 1 r
.45812 .23602 m
.45833 .22728 L
s
.45833 .22728 m
.45819 .23556 L
s
.722 .227 1 r
.79369 .21778 m
.79443 .22702 L
s
.79446 .22697 m
.79369 .21778 L
s
.79369 .21778 m
.79525 .23611 L
s
.55 .269 1 r
.25596 .22968 m
.25521 .23849 L
s
.2553 .2383 m
.25596 .22968 L
s
.942 .178 1 r
.76603 .17425 m
.76983 .22099 L
s
.648 .244 1 r
.44114 .17425 m
.44022 .21794 L
s
.55 .269 1 r
.25521 .23849 m
.25598 .22963 L
s
.25598 .22963 m
.2553 .2383 L
s
.68 .237 1 r
.67116 .21573 m
.67155 .22497 L
s
.67158 .22492 m
.67116 .21573 L
s
.67116 .21573 m
.67201 .23375 L
s
.36 .324 1 r
.77279 .23729 m
.77277 .23778 L
s
.669 .239 1 r
.37849 .23233 m
.37806 .24138 L
s
.37813 .24141 m
.37849 .23233 L
s
.68 .237 1 r
.6169 .17396 m
.6184 .21765 L
s
.618 .252 1 r
.29196 .17396 m
.28901 .21727 L
s
.669 .239 1 r
.37806 .24138 m
.37851 .23228 L
s
.37851 .23228 m
.37813 .24141 L
s
.701 .231 1 r
.6398 .24499 m
.63975 .24542 L
s
.618 .252 1 r
.66641 .24368 m
.66636 .24403 L
s
.68 .237 1 r
.58087 .23059 m
.58102 .23979 L
s
.58108 .23944 m
.58087 .23059 L
s
.467 .292 1 r
.3091 .22765 m
.30851 .23623 L
s
.30859 .23604 m
.3091 .22765 L
s
.4 .312 1 r
.75101 .21213 m
.75157 .22056 L
s
.7516 .22051 m
.75101 .21213 L
s
.75101 .21213 m
.7522 .22864 L
s
.929 .181 1 r
.79271 .17367 m
.79703 .22196 L
s
.56 .267 1 r
.46773 .17367 m
.46717 .21661 L
s
.68 .237 1 r
.58102 .23979 m
.58089 .23054 L
s
.58089 .23054 m
.58108 .23944 L
s
.467 .292 1 r
.30851 .23623 m
.30912 .22761 L
s
.30912 .22761 m
.30859 .23604 L
s
.766 .217 1 r
.64354 .17339 m
.64547 .21861 L
s
.754 .219 1 r
.31851 .17339 m
.31578 .21899 L
s
.799 .209 1 r
.78906 .24679 m
.78902 .2471 L
s
.417 .307 1 r
.62369 .23814 m
.62364 .23856 L
s
.712 .229 1 r
.49433 .1731 m
.49414 .21718 L
s
.531 .274 1 r
.57046 .24115 m
.5704 .2415 L
s
.712 .229 1 r
.78336 .22945 m
.78411 .2388 L
s
.78412 .23823 m
.78336 .22945 L
s
.78411 .2388 m
.78339 .2294 L
s
.78339 .2294 m
.78412 .23823 L
s
1 .149 .908 r
.50105 .2362 m
.50097 .24626 L
s
.50104 .24606 m
.50105 .2362 L
s
.589 .259 1 r
.57525 .21398 m
.57536 .22296 L
s
.57538 .22291 m
.57525 .21398 L
s
.57525 .21398 m
.57555 .23159 L
s
1 .149 .908 r
.50097 .24626 m
.50107 .23615 L
s
.50107 .23615 m
.50104 .24606 L
s
.365 .485 1 r
.35659 .20824 m
.35615 .21617 L
s
.35617 .21613 m
.35659 .20824 L
s
.35659 .20824 m
.35581 .22364 L
s
.68 .237 1 r
.67019 .17281 m
.67245 .21689 L
s
.467 .292 1 r
.34507 .17281 m
.34292 .2146 L
s
.27195 .24022 m
.27188 .24041 L
s
.799 .209 1 r
.81576 .24624 m
.81572 .24655 L
s
.522 .277 1 r
.27673 .21301 m
.27602 .22179 L
s
.27604 .22174 m
.27673 .21301 L
s
.27673 .21301 m
.27542 .23027 L
s
.765 .217 1 r
.52094 .17252 m
.52112 .21814 L
s
.788 .211 1 r
.72455 .21558 m
.7251 .22506 L
s
.72513 .22501 m
.72455 .21558 L
s
.72455 .21558 m
.72573 .23415 L
s
.395 .619 1 r
.34605 .21862 m
.34561 .22622 L
s
.34569 .22578 m
.34605 .21862 L
s
.701 .232 1 r
.25008 .21493 m
.24926 .22417 L
s
.24928 .22412 m
.25008 .21493 L
s
.25008 .21493 m
.24855 .23311 L
s
.68 .236 1 r
.28234 .23124 m
.28164 .2403 L
s
.2817 .24041 m
.28234 .23124 L
s
.395 .619 1 r
.34561 .22622 m
.34606 .21858 L
s
.34606 .21858 m
.34569 .22578 L
s
.68 .236 1 r
.28164 .2403 m
.28236 .23119 L
s
.28236 .23119 m
.2817 .24041 L
s
.691 .234 1 r
.69686 .17224 m
.69947 .21594 L
s
.503 .282 1 r
.37165 .17224 m
.36985 .21403 L
s
.765 .217 1 r
.39935 .216 m
.39895 .22536 L
s
.39897 .22531 m
.39935 .216 L
s
.39935 .216 m
.39865 .23453 L
s
.357 .448 1 r
.49533 .2198 m
.49525 .22787 L
s
.49531 .22719 m
.49533 .2198 L
s
.373 .52 1 r
.43164 .23233 m
.43157 .23266 L
s
.977 .171 1 r
.73023 .2339 m
.73085 .24372 L
s
.7309 .24352 m
.73023 .2339 L
s
.357 .448 1 r
.49525 .22787 m
.49535 .21976 L
s
.49535 .21976 m
.49531 .22719 L
s
.991 .169 1 r
.54866 .21691 m
.5487 .22686 L
s
.54872 .2268 m
.54866 .21691 L
s
.54866 .21691 m
.54883 .23634 L
s
.977 .171 1 r
.73085 .24372 m
.73026 .23384 L
s
.73026 .23384 m
.7309 .24352 L
s
.777 .214 1 r
.69317 .24503 m
.69313 .24537 L
s
.68 .237 1 r
.33556 .22891 m
.33501 .23811 L
s
.3351 .23776 m
.33556 .22891 L
s
.45 .297 1 r
.7407 .22451 m
.74127 .23312 L
s
.7413 .23267 m
.7407 .22451 L
s
.639 .246 1 r
.42596 .21486 m
.42566 .22389 L
s
.42567 .22384 m
.42596 .21486 L
s
.42596 .21486 m
.42543 .23282 L
s
.433 .302 1 r
.54757 .17195 m
.54808 .21337 L
s
.68 .237 1 r
.33501 .23811 m
.33558 .22886 L
s
.33558 .22886 m
.3351 .23776 L
s
.45 .297 1 r
.74127 .23312 m
.74072 .22446 L
s
.74072 .22446 m
.7413 .23267 L
s
1 .154 .933 r
.69798 .21799 m
.69849 .22805 L
s
.69852 .22799 m
.69798 .21799 L
s
.69798 .21799 m
.69908 .23776 L
s
.881 .191 1 r
.51724 .24606 m
.51717 .24653 L
s
.483 .948 1 r
.34032 .20184 m
.33991 .20853 L
s
.33993 .2085 m
.34032 .20184 L
s
.34032 .20184 m
.33959 .21486 L
s
.712 .229 1 r
.45259 .2137 m
.45235 .22303 L
s
.45237 .22298 m
.45259 .2137 L
s
.45259 .2137 m
.45221 .23189 L
s
.531 .274 1 r
.4478 .24108 m
.44773 .2412 L
s
.30324 .21309 m
.30261 .22183 L
s
.30263 .22179 m
.30324 .21309 L
s
.30324 .21309 m
.30207 .23047 L
s
.857 .196 1 r
.34127 .2471 m
.34119 .24726 L
s
.4 .312 1 r
.52769 .23675 m
.52763 .23709 L
s
.846 .199 1 r
.72355 .17166 m
.72667 .21767 L
s
.352 .327 1 r
.39824 .17166 m
.39687 .21117 L
s
.8 .209 1 r
.48486 .23041 m
.48474 .23988 L
s
.48481 .23957 m
.48486 .23041 L
s
.777 .214 1 r
.77792 .21415 m
.77863 .22363 L
s
.77866 .22358 m
.77792 .21415 L
s
.77792 .21415 m
.77941 .23265 L
s
.8 .209 1 r
.48474 .23988 m
.48489 .23036 L
s
.48489 .23036 m
.48481 .23957 L
s
.342 .378 1 r
.31934 .22159 m
.3188 .22971 L
s
.31889 .22937 m
.31934 .22159 L
s
.99 .169 1 r
.60758 .23276 m
.60783 .24266 L
s
.60789 .24231 m
.60758 .23276 L
s
.342 .378 1 r
.3188 .22971 m
.31935 .22155 L
s
.31935 .22155 m
.31889 .22937 L
s
.811 .206 1 r
.66086 .22982 m
.66125 .23937 L
s
.6613 .23891 m
.66086 .22982 L
s
.579 .262 1 r
.71412 .22689 m
.71465 .23582 L
s
.71469 .23551 m
.71412 .22689 L
s
.99 .169 1 r
.60783 .24266 m
.60761 .23271 L
s
.60761 .23271 m
.60789 .24231 L
s
.669 .239 1 r
.57422 .17137 m
.57514 .21547 L
s
.811 .206 1 r
.66125 .23937 m
.66088 .22977 L
s
.66088 .22977 m
.6613 .23891 L
s
.579 .262 1 r
.71465 .23582 m
.71415 .22684 L
s
.71415 .22684 m
.71469 .23551 L
s
.845 .199 1 r
.54388 .24551 m
.54381 .24586 L
s
.45 .297 1 r
.44204 .22425 m
.44181 .23283 L
s
.44188 .23249 m
.44204 .22425 L
s
.701 .231 1 r
.21847 .24589 m
.21842 .24563 L
s
.372 .52 1 r
.52195 .21985 m
.52194 .22762 L
s
.52199 .2274 m
.52195 .21985 L
s
.45 .297 1 r
.44181 .23283 m
.44206 .2242 L
s
.44206 .2242 m
.44188 .23249 L
s
.372 .52 1 r
.52194 .22762 m
.52197 .21981 L
s
.52197 .21981 m
.52199 .2274 L
s
.777 .214 1 r
.5115 .22954 m
.51145 .23898 L
s
.51152 .23863 m
.5115 .22954 L
s
.68 .237 1 r
.53814 .22807 m
.53817 .23727 L
s
.53823 .23693 m
.53814 .22807 L
s
.618 .252 1 r
.56478 .22661 m
.56489 .23569 L
s
.56494 .23523 m
.56478 .22661 L
s
.68 .237 1 r
.47921 .21325 m
.47905 .22246 L
s
.47907 .22241 m
.47921 .21325 L
s
.47921 .21325 m
.47898 .23132 L
s
.916 .184 1 r
.75025 .17108 m
.7539 .21901 L
s
.608 .254 1 r
.42485 .17108 m
.4237 .2148 L
s
.711 .229 1 r
.59716 .24288 m
.5971 .24323 L
s
.777 .214 1 r
.51145 .23898 m
.51152 .22949 L
s
.51152 .22949 m
.51152 .23863 L
s
.68 .237 1 r
.53817 .23727 m
.53816 .22802 L
s
.53816 .22802 m
.53823 .23693 L
s
.618 .252 1 r
.56489 .23569 m
.5648 .22656 L
s
.5648 .22656 m
.56494 .23523 L
s
.352 .327 1 r
.40974 .20824 m
.40941 .21655 L
s
.40943 .21651 m
.40974 .20824 L
s
.40974 .20824 m
.40918 .22441 L
s
.392 .314 1 r
.64471 .2225 m
.64502 .23093 L
s
.64506 .23051 m
.64471 .2225 L
s
.777 .214 1 r
.42114 .24392 m
.42106 .24426 L
s
.388 .588 1 r
.37256 .21956 m
.37219 .2271 L
s
.37224 .22711 m
.37256 .21956 L
s
.392 .314 1 r
.64502 .23093 m
.64473 .22246 L
s
.64473 .22246 m
.64506 .23051 L
s
.388 .588 1 r
.37219 .2271 m
.37257 .21952 L
s
.37257 .21952 m
.37224 .22711 L
s
.559 .267 1 r
.68189 .21151 m
.68229 .2204 L
s
.68232 .22036 m
.68189 .21151 L
s
.68189 .21151 m
.68277 .22896 L
s
.588 .259 1 r
.60088 .1708 m
.60214 .21375 L
s
.352 .327 1 r
.38307 .21016 m
.38268 .21832 L
s
.3827 .21828 m
.38307 .21016 L
s
.38307 .21016 m
.38237 .22649 L
s
.722 .227 1 r
.3298 .21316 m
.3292 .22248 L
s
.32922 .22244 m
.3298 .21316 L
s
.3298 .21316 m
.32871 .23143 L
s
.36 .325 1 r
.75704 .23461 m
.75701 .23498 L
s
.711 .229 1 r
.65526 .2132 m
.6556 .22248 L
s
.65563 .22243 m
.65526 .2132 L
s
.65526 .2132 m
.65602 .23143 L
s
.398 .631 1 r
.36209 .22961 m
.36203 .22979 L
s
.559 .267 1 r
.77696 .17051 m
.78058 .21308 L
s
.701 .232 1 r
.45147 .17051 m
.45067 .21499 L
s
.833 .201 1 r
.62862 .21504 m
.6289 .22456 L
s
.62892 .22451 m
.62862 .21504 L
s
.62862 .21504 m
.62926 .23389 L
s
.68 .237 1 r
.65049 .24101 m
.65044 .24147 L
s
.701 .232 1 r
.50584 .21295 m
.50576 .2222 L
s
.50578 .22215 m
.50584 .21295 L
s
.50584 .21295 m
.50576 .23115 L
s
.658 .242 1 r
.23928 .22782 m
.23846 .23691 L
s
.23854 .23675 m
.23928 .22782 L
s
.345 .39 1 r
.6343 .23301 m
.63425 .23331 L
s
.658 .242 1 r
.23846 .23691 m
.2393 .22777 L
s
.2393 .22777 m
.23854 .23675 L
s
.531 .274 1 r
.55914 .21009 m
.55921 .21895 L
s
.55923 .21891 m
.55914 .21009 L
s
.55914 .21009 m
.55935 .22735 L
s
1 .138 .854 r
.62756 .17022 m
.62941 .2193 L
s
.733 .224 1 r
.30202 .17022 m
.2991 .21509 L
s
1 .156 .946 r
.81039 .23253 m
.81128 .24255 L
s
.81132 .24224 m
.81039 .23253 L
s
.81128 .24255 m
.81042 .23248 L
s
.81042 .23248 m
.81132 .24224 L
s
.649 .244 1 r
.5325 .2119 m
.53249 .22103 L
s
.53251 .22098 m
.5325 .2119 L
s
.5325 .2119 m
.53257 .22982 L
s
.765 .217 1 r
.3887 .229 m
.38829 .23837 L
s
.38837 .23817 m
.3887 .229 L
s
.599 .257 1 r
.41534 .22754 m
.41503 .2364 L
s
.41509 .23647 m
.41534 .22754 L
s
.765 .217 1 r
.38829 .23837 m
.38872 .22895 L
s
.38872 .22895 m
.38837 .23817 L
s
.599 .257 1 r
.41503 .2364 m
.41536 .22749 L
s
.41536 .22749 m
.41509 .23647 L
s
.857 .196 1 r
.80476 .21502 m
.80556 .22459 L
s
.80559 .22454 m
.80476 .21502 L
s
.80476 .21502 m
.80645 .234 L
s
.904 .186 1 r
.24498 .2461 m
.24489 .24629 L
s
.669 .239 1 r
.59146 .22696 m
.59164 .23612 L
s
.5917 .23581 m
.59146 .22696 L
s
.649 .244 1 r
.47811 .16993 m
.47769 .21404 L
s
.669 .239 1 r
.59164 .23612 m
.59149 .22691 L
s
.59149 .22691 m
.5917 .23581 L
s
.504 .282 1 r
.58581 .2093 m
.58595 .21809 L
s
.58597 .21804 m
.58581 .2093 L
s
.58581 .2093 m
.58616 .22641 L
s
.578 .262 1 r
.61812 .22579 m
.61838 .23468 L
s
.61843 .23449 m
.61812 .22579 L
s
.811 .206 1 r
.4744 .24281 m
.47433 .24327 L
s
.578 .262 1 r
.61838 .23468 m
.61815 .22574 L
s
.61815 .22574 m
.61843 .23449 L
s
.892 .189 1 r
.7467 .24582 m
.74664 .24598 L
s
.589 .259 1 r
.55437 .23848 m
.55431 .23893 L
s
.22875 .23847 m
.22864 .23893 L
s
.551 .269 1 r
.65425 .16964 m
.6562 .21184 L
s
.342 .378 1 r
.32862 .16964 m
.32637 .20917 L
s
.701 .231 1 r
.2982 .24423 m
.29815 .24396 L
s
.365 .486 1 r
.60195 .21816 m
.60213 .22604 L
s
.60218 .22571 m
.60195 .21816 L
s
.701 .232 1 r
.26581 .22786 m
.26506 .23704 L
s
.26513 .23695 m
.26581 .22786 L
s
.365 .486 1 r
.60213 .22604 m
.60197 .21812 L
s
.60197 .21812 m
.60218 .22571 L
s
.467 .292 1 r
.40486 .2382 m
.4048 .23816 L
s
.701 .232 1 r
.67722 .24121 m
.67717 .24152 L
s
.26506 .23704 m
.26583 .22782 L
s
.26583 .22782 m
.26513 .23695 L
s
.38 .554 1 r
.50476 .16936 m
.50472 .20622 L
s
.904 .186 1 r
.68767 .23169 m
.68814 .24125 L
s
.68822 .2414 m
.68767 .23169 L
s
.68814 .24125 m
.68769 .23163 L
s
.68769 .23163 m
.68822 .2414 L
s
.648 .244 1 r
.70389 .23989 m
.70385 .24024 L
s
.777 .214 1 r
.70869 .21252 m
.70919 .22196 L
s
.70922 .22191 m
.70869 .21252 L
s
.70869 .21252 m
.70978 .23106 L
s
.477 .289 1 r
.45819 .23556 m
.45812 .23602 L
s
.352 .327 1 r
.68096 .16907 m
.68312 .2086 L
s
.521 .277 1 r
.35523 .16907 m
.35317 .21165 L
s
.869 .194 1 r
.80011 .24395 m
.80007 .24426 L
s
.744 .221 1 r
.46864 .22642 m
.46846 .23581 L
s
.46854 .23535 m
.46864 .22642 L
s
.46846 .23581 m
.46866 .22637 L
s
.46866 .22637 m
.46854 .23535 L
s
.55 .269 1 r
.2553 .2383 m
.25521 .23849 L
s
.766 .217 1 r
.29242 .2273 m
.29172 .2367 L
s
.29181 .23639 m
.29242 .2273 L
s
.648 .244 1 r
.53143 .16878 m
.53175 .21251 L
s
.766 .217 1 r
.29172 .2367 m
.29243 .22725 L
s
.29243 .22725 m
.29181 .23639 L
s
.834 .201 1 r
.76773 .22819 m
.76845 .23775 L
s
.76849 .23744 m
.76773 .22819 L
s
1 .111 .702 r
.3677 .25036 m
.36761 .25068 L
s
.834 .201 1 r
.76845 .23775 m
.76776 .22814 L
s
.76776 .22814 m
.76849 .23744 L
s
.531 .274 1 r
.78876 .20902 m
.78945 .21784 L
s
.78948 .2178 m
.78876 .20902 L
s
.78876 .20902 m
.79021 .22633 L
s
.638 .247 1 r
.43629 .21053 m
.43601 .21962 L
s
.43603 .21958 m
.43629 .21053 L
s
.43629 .21053 m
.43582 .22842 L
s
.722 .227 1 r
.79443 .22702 m
.7952 .23627 L
s
.79525 .23611 m
.79443 .22702 L
s
.904 .186 1 r
.32481 .24405 m
.32471 .24437 L
s
.916 .184 1 r
.70768 .16849 m
.71063 .21529 L
s
.57 .264 1 r
.38186 .16849 m
.38018 .2107 L
s
.722 .227 1 r
.7952 .23627 m
.79446 .22697 L
s
.79446 .22697 m
.79525 .23611 L
s
.68 .237 1 r
.67155 .22497 m
.67197 .23421 L
s
.67201 .23375 m
.67155 .22497 L
s
.467 .292 1 r
.30859 .23604 m
.30851 .23623 L
s
.4 .312 1 r
.75157 .22056 m
.75217 .22898 L
s
.7522 .22864 m
.75157 .22056 L
s
.68 .237 1 r
.67197 .23421 m
.67158 .22492 L
s
.67158 .22492 m
.67201 .23375 L
s
.4 .312 1 r
.75217 .22898 m
.7516 .22051 L
s
.7516 .22051 m
.7522 .22864 L
s
.375 .32 1 r
.5163 .20654 m
.51625 .2149 L
s
.51627 .21485 m
.5163 .20654 L
s
.5163 .20654 m
.51628 .22292 L
s
.669 .239 1 r
.37813 .24141 m
.37806 .24138 L
s
.88 .191 1 r
.73546 .21263 m
.73606 .22231 L
s
.73609 .22226 m
.73546 .21263 L
s
.73546 .21263 m
.73674 .23165 L
s
.744 .221 1 r
.76214 .21116 m
.7628 .22053 L
s
.76283 .22048 m
.76214 .21116 L
s
.76214 .21116 m
.76353 .22956 L
s
.701 .232 1 r
.26001 .21194 m
.25922 .22112 L
s
.25924 .22107 m
.26001 .21194 L
s
.26001 .21194 m
.25852 .23022 L
s
.335 .341 1 r
.55811 .1682 m
.55873 .20736 L
s
.68 .237 1 r
.58108 .23944 m
.58102 .23979 L
s
.69 .234 1 r
.46295 .21011 m
.46274 .21936 L
s
.46277 .21931 m
.46295 .21011 L
s
.46295 .21011 m
.46263 .22823 L
s
.503 .282 1 r
.73442 .16791 m
.73741 .20974 L
s
.702 .231 1 r
.40851 .16791 m
.40712 .21203 L
s
.365 .485 1 r
.35615 .21617 m
.35573 .22409 L
s
.35581 .22364 m
.35615 .21617 L
s
.395 .619 1 r
.34569 .22578 m
.34561 .22622 L
s
.811 .206 1 r
.61257 .21099 m
.6128 .22055 L
s
.61283 .2205 m
.61257 .21099 L
s
.61257 .21099 m
.61311 .22966 L
s
.365 .485 1 r
.35573 .22409 m
.35617 .21613 L
s
.35617 .21613 m
.35581 .22364 L
s
.569 .264 1 r
.31332 .2096 m
.31271 .21847 L
s
.31273 .21842 m
.31332 .2096 L
s
.31332 .2096 m
.31218 .22719 L
s
.766 .217 1 r
.28664 .21115 m
.28591 .22055 L
s
.28593 .2205 m
.28664 .21115 L
s
.28664 .21115 m
.28529 .22966 L
s
.424 .305 1 r
.69261 .2067 m
.69303 .21522 L
s
.69306 .21517 m
.69261 .2067 L
s
.69261 .2067 m
.69351 .22339 L
s
.45 .297 1 r
.36667 .20693 m
.36622 .21552 L
s
.36624 .21548 m
.36667 .20693 L
s
.36667 .20693 m
.36587 .22377 L
s
.723 .226 1 r
.58481 .16762 m
.58589 .21175 L
s
.483 .948 1 r
.33991 .20853 m
.33952 .21522 L
s
.33959 .21486 m
.33991 .20853 L
s
.33952 .21522 m
.33993 .2085 L
s
.33993 .2085 m
.33959 .21486 L
s
.712 .229 1 r
.78412 .23823 m
.78411 .2388 L
s
.357 .448 1 r
.49531 .22719 m
.49525 .22787 L
s
.589 .259 1 r
.57536 .22296 m
.57549 .23193 L
s
.57555 .23159 m
.57536 .22296 L
s
1 .118 .744 r
.76117 .16733 m
.7653 .21913 L
s
.467 .292 1 r
.43517 .16733 m
.4342 .20917 L
s
.589 .259 1 r
.57549 .23193 m
.57538 .22291 L
s
.57538 .22291 m
.57555 .23159 L
s
.701 .232 1 r
.48962 .20985 m
.48949 .2191 L
s
.48951 .21905 m
.48962 .20985 L
s
.48962 .20985 m
.48945 .22805 L
s
.522 .277 1 r
.27602 .22179 m
.27533 .23057 L
s
.27542 .23027 m
.27602 .22179 L
s
.27533 .23057 m
.27604 .22174 L
s
.27604 .22174 m
.27542 .23027 L
s
.845 .199 1 r
.61153 .16705 m
.61303 .21309 L
s
.881 .191 1 r
.63931 .21088 m
.63962 .2206 L
s
.63965 .22055 m
.63931 .21088 L
s
.63931 .21088 m
.64002 .22986 L
s
.744 .221 1 r
.666 .20941 m
.66638 .21882 L
s
.66641 .21877 m
.666 .20941 L
s
.666 .20941 m
.66684 .22777 L
s
.45 .297 1 r
.7413 .23267 m
.74127 .23312 L
s
.468 .292 1 r
.56971 .206 m
.5698 .21467 L
s
.56982 .21463 m
.56971 .206 L
s
.56971 .206 m
.56997 .22292 L
s
1 .149 .908 r
.50104 .24606 m
.50097 .24626 L
s
.788 .211 1 r
.78794 .16676 m
.79194 .21204 L
s
.531 .274 1 r
.46184 .16676 m
.46122 .20898 L
s
.45 .297 1 r
.42 .20546 m
.41969 .21409 L
s
.41971 .21404 m
.42 .20546 L
s
.42 .20546 m
.41948 .22226 L
s
.68 .236 1 r
.2817 .24041 m
.28164 .2403 L
s
.701 .232 1 r
.24926 .22417 m
.24845 .23342 L
s
.24855 .23311 m
.24926 .22417 L
s
.66 .241 1 r
.54302 .20784 m
.54304 .21706 L
s
.54306 .21701 m
.54302 .20784 L
s
.54302 .20784 m
.54315 .22577 L
s
.342 .378 1 r
.31889 .22937 m
.3188 .22971 L
s
.701 .232 1 r
.24845 .23342 m
.24928 .22412 L
s
.24928 .22412 m
.24855 .23311 L
s
.335 .34 1 r
.62311 .20348 m
.62333 .21172 L
s
.62336 .21168 m
.62311 .20348 L
s
.62311 .20348 m
.62363 .21951 L
s
.788 .211 1 r
.7251 .22506 m
.72569 .23454 L
s
.72573 .23415 m
.7251 .22506 L
s
.433 .302 1 r
.63826 .16647 m
.63993 .20717 L
s
.459 .295 1 r
.31211 .16647 m
.30952 .20831 L
s
.788 .211 1 r
.72569 .23454 m
.72513 .22501 L
s
.72513 .22501 m
.72573 .23415 L
s
.68 .237 1 r
.3351 .23776 m
.33501 .23811 L
s
.372 .52 1 r
.52199 .2274 m
.52194 .22762 L
s
.495 .284 1 r
.74615 .20594 m
.74672 .21469 L
s
.74675 .21465 m
.74615 .20594 L
s
.74615 .20594 m
.74735 .22302 L
s
.765 .217 1 r
.39895 .22536 m
.39857 .23473 L
s
.39865 .23453 m
.39895 .22536 L
s
.639 .246 1 r
.42566 .22389 m
.42536 .23291 L
s
.42543 .23282 m
.42566 .22389 L
s
.56 .267 1 r
.39328 .2076 m
.39289 .21648 L
s
.39291 .21643 m
.39328 .2076 L
s
.39328 .2076 m
.39258 .22512 L
s
.765 .217 1 r
.39857 .23473 m
.39897 .22531 L
s
.39897 .22531 m
.39865 .23453 L
s
.639 .246 1 r
.42536 .23291 m
.42567 .22384 L
s
.42567 .22384 m
.42543 .23282 L
s
.531 .274 1 r
.30261 .22183 m
.30199 .23058 L
s
.30207 .23047 m
.30261 .22183 L
s
.569 .264 1 r
.48853 .16618 m
.48826 .20955 L
s
.531 .274 1 r
.30199 .23058 m
.30263 .22179 L
s
.30263 .22179 m
.30207 .23047 L
s
.388 .588 1 r
.37224 .22711 m
.37219 .2271 L
s
.977 .171 1 r
.7309 .24352 m
.73085 .24372 L
s
.45 .297 1 r
.44188 .23249 m
.44181 .23283 L
s
.579 .262 1 r
.71469 .23551 m
.71465 .23582 L
s
.712 .229 1 r
.45235 .22303 m
.45213 .23235 L
s
.45221 .23189 m
.45235 .22303 L
s
.88 .191 1 r
.665 .16589 m
.6673 .21233 L
s
.496 .284 1 r
.33877 .16589 m
.33659 .20659 L
s
.712 .229 1 r
.45213 .23235 m
.45237 .22298 L
s
.45237 .22298 m
.45221 .23189 L
s
.991 .169 1 r
.5487 .22686 m
.54876 .23681 L
s
.54883 .23634 m
.5487 .22686 L
s
.392 .314 1 r
.64506 .23051 m
.64502 .23093 L
s
.56 .267 1 r
.59645 .20607 m
.59661 .21502 L
s
.59664 .21497 m
.59645 .20607 L
s
.59645 .20607 m
.59686 .2235 L
s
.991 .169 1 r
.54876 .23681 m
.54872 .2268 L
s
.54872 .2268 m
.54883 .23634 L
s
.352 .327 1 r
.40941 .21655 m
.4091 .22486 L
s
.40918 .22441 m
.40941 .21655 L
s
.8 .209 1 r
.48481 .23957 m
.48474 .23988 L
s
.352 .327 1 r
.4091 .22486 m
.40943 .21651 L
s
.40943 .21651 m
.40918 .22441 L
s
.811 .206 1 r
.6613 .23891 m
.66125 .23937 L
s
.618 .252 1 r
.56494 .23523 m
.56489 .23569 L
s
.352 .327 1 r
.38268 .21832 m
.38231 .22649 L
s
.38237 .22649 m
.38268 .21832 L
s
.669 .239 1 r
.51524 .1656 m
.51533 .21012 L
s
1 .154 .933 r
.69849 .22805 m
.69903 .23812 L
s
.69908 .23776 m
.69849 .22805 L
s
.352 .327 1 r
.38231 .22649 m
.3827 .21828 L
s
.3827 .21828 m
.38237 .22649 L
s
.777 .214 1 r
.77863 .22363 m
.77938 .23311 L
s
.77941 .23265 m
.77863 .22363 L
s
.68 .237 1 r
.53823 .23693 m
.53817 .23727 L
s
1 .154 .933 r
.69903 .23812 m
.69852 .22799 L
s
.69852 .22799 m
.69908 .23776 L
s
.777 .214 1 r
.77938 .23311 m
.77866 .22358 L
s
.77866 .22358 m
.77941 .23265 L
s
.99 .169 1 r
.60789 .24231 m
.60783 .24266 L
s
.777 .214 1 r
.51152 .23863 m
.51145 .23898 L
s
.811 .206 1 r
.71956 .20907 m
.7201 .2186 L
s
.72013 .21855 m
.71956 .20907 L
s
.71956 .20907 m
.72072 .22778 L
s
.68 .237 1 r
.47905 .22246 m
.47891 .23167 L
s
.47898 .23132 m
.47905 .22246 L
s
.733 .224 1 r
.69176 .16531 m
.69439 .2106 L
s
.365 .486 1 r
.36543 .16531 m
.36373 .20296 L
s
.68 .237 1 r
.47891 .23167 m
.47907 .22241 L
s
.47907 .22241 m
.47898 .23132 L
s
.559 .267 1 r
.68229 .2204 m
.68272 .2293 L
s
.68277 .22896 m
.68229 .2204 L
s
.68272 .2293 m
.68232 .22036 L
s
.68232 .22036 m
.68277 .22896 L
s
.342 .378 1 r
.54196 .16502 m
.54237 .20382 L
s
.722 .227 1 r
.3292 .22248 m
.32862 .23181 L
s
.32871 .23143 m
.3292 .22248 L
s
.711 .229 1 r
.6556 .22248 m
.65597 .23177 L
s
.65602 .23143 m
.6556 .22248 L
s
.722 .227 1 r
.32862 .23181 m
.32922 .22244 L
s
.32922 .22244 m
.32871 .23143 L
s
.711 .229 1 r
.65597 .23177 m
.65563 .22243 L
s
.65563 .22243 m
.65602 .23143 L
s
.531 .274 1 r
.55921 .21895 m
.5593 .22781 L
s
.55935 .22735 m
.55921 .21895 L
s
.811 .206 1 r
.71854 .16473 m
.72158 .21041 L
s
.634 1 .705 r
.39211 .16473 m
.39124 .18873 L
s
.658 .242 1 r
.23854 .23675 m
.23846 .23691 L
s
.531 .274 1 r
.5593 .22781 m
.55923 .21891 L
s
.55923 .21891 m
.55935 .22735 L
s
.365 .486 1 r
.60218 .22571 m
.60213 .22604 L
s
.335 .341 1 r
.37694 .20211 m
.37654 .21032 L
s
.37656 .21028 m
.37694 .20211 L
s
.37694 .20211 m
.37622 .21819 L
s
.701 .232 1 r
.50576 .2222 m
.50569 .23146 L
s
.50576 .23115 m
.50576 .2222 L
s
.56 .267 1 r
.47336 .2059 m
.47319 .21477 L
s
.47321 .21472 m
.47336 .2059 L
s
.47336 .2059 m
.4731 .22341 L
s
.337 .332 1 r
.55354 .20145 m
.55358 .20974 L
s
.5536 .20969 m
.55354 .20145 L
s
.55354 .20145 m
.5537 .21753 L
s
.701 .232 1 r
.50569 .23146 m
.50578 .22215 L
s
.50578 .22215 m
.50576 .23115 L
s
.833 .201 1 r
.6289 .22456 m
.6292 .23409 L
s
.62926 .23389 m
.6289 .22456 L
s
.599 .257 1 r
.41509 .23647 m
.41503 .2364 L
s
.833 .201 1 r
.6292 .23409 m
.62892 .22451 L
s
.62892 .22451 m
.62926 .23389 L
s
.424 .305 1 r
.56869 .16444 m
.56947 .20515 L
s
.598 .257 1 r
.27002 .2083 m
.26929 .21714 L
s
.26931 .21709 m
.27002 .2083 L
s
.27002 .2083 m
.26862 .22617 L
s
.669 .239 1 r
.5917 .23581 m
.59164 .23612 L
s
.649 .244 1 r
.53249 .22103 m
.5325 .23017 L
s
.53257 .22982 m
.53249 .22103 L
s
.504 .282 1 r
.58595 .21809 m
.58611 .22687 L
s
.58616 .22641 m
.58595 .21809 L
s
.777 .214 1 r
.77312 .20771 m
.77382 .21716 L
s
.77385 .21711 m
.77312 .20771 L
s
.77312 .20771 m
.77459 .22627 L
s
.649 .244 1 r
.5325 .23017 m
.53251 .22098 L
s
.53251 .22098 m
.53257 .22982 L
s
.504 .282 1 r
.58611 .22687 m
.58597 .21804 L
s
.58597 .21804 m
.58616 .22641 L
s
.701 .232 1 r
.29675 .20701 m
.29606 .21627 L
s
.29608 .21622 m
.29675 .20701 L
s
.29675 .20701 m
.29548 .22523 L
s
.638 .247 1 r
.79985 .20628 m
.8006 .21538 L
s
.80063 .21533 m
.79985 .20628 L
s
.79985 .20628 m
.80141 .22418 L
s
.765 .217 1 r
.38837 .23817 m
.38829 .23837 L
s
.578 .262 1 r
.61843 .23449 m
.61838 .23468 L
s
.638 .247 1 r
.74533 .16415 m
.74861 .20792 L
s
.522 .277 1 r
.41881 .16415 m
.41761 .2064 L
s
.451 .837 1 r
.33393 .19621 m
.33349 .20322 L
s
.3335 .20319 m
.33393 .19621 L
s
.33393 .19621 m
.33313 .20994 L
s
1 .156 .946 r
.81132 .24224 m
.81128 .24255 L
s
.857 .196 1 r
.80556 .22459 m
.80639 .23416 L
s
.80645 .234 m
.80556 .22459 L
s
.80639 .23416 m
.80559 .22454 L
s
.80559 .22454 m
.80645 .234 L
s
.523 .277 1 r
.59545 .16386 m
.59661 .20572 L
s
.541 .272 1 r
.35017 .20478 m
.34966 .21362 L
s
.34967 .21357 m
.35017 .20478 L
s
.35017 .20478 m
.34924 .22218 L
s
.701 .232 1 r
.26513 .23695 m
.26506 .23704 L
s
.744 .222 1 r
.65002 .20663 m
.65035 .21601 L
s
.65038 .21596 m
.65002 .20663 L
s
.65002 .20663 m
.65077 .22504 L
s
.669 .239 1 r
.77213 .16357 m
.77582 .20773 L
s
.383 .317 1 r
.44552 .16357 m
.44471 .20429 L
s
.483 .948 1 r
.33959 .21486 m
.33952 .21522 L
s
.433 .772 1 r
.51056 .19634 m
.51051 .20354 L
s
.51052 .2035 m
.51056 .19634 L
s
.51056 .19634 m
.51052 .21041 L
s
.649 .244 1 r
.67677 .20539 m
.67717 .21453 L
s
.67719 .21448 m
.67677 .20539 L
s
.67677 .20539 m
.67765 .22333 L
s
.505 .281 1 r
.58031 .20181 m
.58043 .21068 L
s
.58046 .21064 m
.58031 .20181 L
s
.58031 .20181 m
.58063 .21886 L
s
1 .161 .972 r
.44661 .20929 m
.44633 .21929 L
s
.44635 .21924 m
.44661 .20929 L
s
.44661 .20929 m
.44615 .22894 L
s
.777 .214 1 r
.70919 .22196 m
.70973 .23141 L
s
.70978 .23106 m
.70919 .22196 L
s
.618 .252 1 r
.52682 .20488 m
.5268 .21394 L
s
.52682 .21389 m
.52682 .20488 L
s
.52682 .20488 m
.52686 .22266 L
s
.4 .312 1 r
.7522 .22864 m
.75217 .22898 L
s
.904 .186 1 r
.68822 .2414 m
.68814 .24125 L
s
.88 .191 1 r
.62221 .16328 m
.62389 .20974 L
s
.744 .221 1 r
.46854 .23535 m
.46846 .23581 L
s
.777 .214 1 r
.70973 .23141 m
.70922 .22191 L
s
.70922 .22191 m
.70978 .23106 L
s
.365 .485 1 r
.35581 .22364 m
.35573 .22409 L
s
.476 .29 1 r
.4036 .2029 m
.40324 .21157 L
s
.40326 .21153 m
.4036 .2029 L
s
.4036 .2029 m
.40298 .21991 L
s
.531 .274 1 r
.78945 .21784 m
.79017 .22667 L
s
.79021 .22633 m
.78945 .21784 L
s
.375 .32 1 r
.51625 .2149 m
.51622 .22325 L
s
.51628 .22292 m
.51625 .2149 L
s
.766 .217 1 r
.29181 .23639 m
.29172 .2367 L
s
.531 .274 1 r
.79017 .22667 m
.78948 .2178 L
s
.78948 .2178 m
.79021 .22633 L
s
.375 .32 1 r
.51622 .22325 m
.51627 .21485 L
s
.51627 .21485 m
.51628 .22292 L
s
.494 .284 1 r
.47225 .16299 m
.47177 .20486 L
s
.638 .247 1 r
.43601 .21962 m
.43575 .22872 L
s
.43582 .22842 m
.43601 .21962 L
s
.834 .201 1 r
.76849 .23744 m
.76845 .23775 L
s
.68 .237 1 r
.67201 .23375 m
.67197 .23421 L
s
.638 .247 1 r
.43575 .22872 m
.43603 .21958 L
s
.43603 .21958 m
.43582 .22842 L
s
.834 .201 1 r
.50008 .20706 m
.49998 .21664 L
s
.5 .21659 m
.50008 .20706 L
s
.50008 .20706 m
.49996 .22591 L
s
.788 .212 1 r
.32334 .20784 m
.32272 .21722 L
s
.32274 .21717 m
.32334 .20784 L
s
.32334 .20784 m
.32219 .22657 L
s
.712 .229 1 r
.70357 .20493 m
.70406 .21427 L
s
.70409 .21422 m
.70357 .20493 L
s
.70357 .20493 m
.70462 .22315 L
s
.722 .227 1 r
.79525 .23611 m
.7952 .23627 L
s
.589 .259 1 r
.64899 .1627 m
.6509 .20534 L
s
.37 .509 1 r
.32224 .1627 m
.31993 .2019 L
s
.476 .29 1 r
.43032 .20233 m
.43003 .21101 L
s
.43005 .21096 m
.43032 .20233 L
s
.43032 .20233 m
.42984 .21934 L
s
.701 .232 1 r
.25922 .22112 m
.25845 .2303 L
s
.25852 .23022 m
.25922 .22112 L
s
.424 .305 1 r
.69303 .21522 m
.69347 .22373 L
s
.69351 .22339 m
.69303 .21522 L
s
.701 .232 1 r
.25845 .2303 m
.25924 .22107 L
s
.25924 .22107 m
.25852 .23022 L
s
.335 .341 1 r
.49899 .16241 m
.49888 .20161 L
s
.388 .587 1 r
.36054 .1974 m
.36012 .20507 L
s
.36014 .20503 m
.36054 .1974 L
s
.36054 .1974 m
.35979 .21241 L
s
.424 .305 1 r
.69347 .22373 m
.69306 .21517 L
s
.69306 .21517 m
.69351 .22339 L
s
.744 .221 1 r
.7628 .22053 m
.76349 .22991 L
s
.76353 .22956 m
.7628 .22053 L
s
.76349 .22991 m
.76283 .22048 L
s
.76283 .22048 m
.76353 .22956 L
s
.569 .264 1 r
.31271 .21847 m
.31211 .22734 L
s
.31218 .22719 m
.31271 .21847 L
s
.45 .297 1 r
.36622 .21552 m
.36579 .22412 L
s
.36587 .22377 m
.36622 .21552 L
s
.569 .264 1 r
.31211 .22734 m
.31273 .21842 L
s
.31273 .21842 m
.31218 .22719 L
s
.45 .297 1 r
.36579 .22412 m
.36624 .21548 L
s
.36624 .21548 m
.36587 .22377 L
s
.88 .191 1 r
.73606 .22231 m
.7367 .232 L
s
.73674 .23165 m
.73606 .22231 L
s
.69 .234 1 r
.46274 .21936 m
.46255 .22862 L
s
.46263 .22823 m
.46274 .21936 L
s
.88 .191 1 r
.7367 .232 m
.73609 .22226 L
s
.73609 .22226 m
.73674 .23165 L
s
.588 .259 1 r
.67579 .16212 m
.67808 .20514 L
s
.503 .282 1 r
.34895 .16212 m
.34684 .20399 L
s
.69 .234 1 r
.46255 .22862 m
.46277 .21931 L
s
.46277 .21931 m
.46263 .22823 L
s
.589 .259 1 r
.57555 .23159 m
.57549 .23193 L
s
.766 .217 1 r
.28591 .22055 m
.2852 .22997 L
s
.28529 .22966 m
.28591 .22055 L
s
.811 .206 1 r
.6128 .22055 m
.61306 .23012 L
s
.61311 .22966 m
.6128 .22055 L
s
.599 .257 1 r
.45706 .20194 m
.45684 .21105 L
s
.45686 .211 m
.45706 .20194 L
s
.45706 .20194 m
.45671 .21954 L
s
.744 .222 1 r
.73042 .20493 m
.73099 .21431 L
s
.73102 .21426 m
.73042 .20493 L
s
.73042 .20493 m
.73163 .22334 L
s
.648 .244 1 r
.52575 .16183 m
.52599 .20677 L
s
.766 .217 1 r
.2852 .22997 m
.28593 .2205 L
s
.28593 .2205 m
.28529 .22966 L
s
.811 .206 1 r
.61306 .23012 m
.61283 .2205 L
s
.61283 .2205 m
.61311 .22966 L
s
.522 .277 1 r
.27542 .23027 m
.27533 .23057 L
s
.589 .259 1 r
.28022 .20294 m
.2795 .21193 L
s
.27952 .21189 m
.28022 .20294 L
s
.28022 .20294 m
.27889 .22058 L
s
.477 .289 1 r
.63389 .20147 m
.63415 .21015 L
s
.63418 .21011 m
.63389 .20147 L
s
.63389 .20147 m
.63449 .21849 L
s
.916 .184 1 r
.7026 .16154 m
.70549 .2084 L
s
.629 .249 1 r
.37567 .16154 m
.37377 .20648 L
s
.711 .229 1 r
.75724 .20413 m
.75788 .21343 L
s
.75791 .21338 m
.75724 .20413 L
s
.75724 .20413 m
.75859 .22239 L
s
.579 .262 1 r
.784 .2027 m
.78469 .21165 L
s
.78472 .21161 m
.784 .2027 L
s
.784 .2027 m
.78545 .2203 L
s
.701 .232 1 r
.48949 .2191 m
.48938 .22836 L
s
.48945 .22805 m
.48949 .2191 L
s
.468 .292 1 r
.5698 .21467 m
.56991 .22335 L
s
.56997 .22292 m
.5698 .21467 L
s
.335 .34 1 r
.62333 .21172 m
.62358 .21997 L
s
.62363 .21951 m
.62333 .21172 L
s
.701 .232 1 r
.48938 .22836 m
.48951 .21905 L
s
.48951 .21905 m
.48945 .22805 L
s
.468 .292 1 r
.56991 .22335 m
.56982 .21463 L
s
.56982 .21463 m
.56997 .22292 L
s
.335 .34 1 r
.62358 .21997 m
.62336 .21168 L
s
.62336 .21168 m
.62363 .21951 L
s
.45 .297 1 r
.41969 .21409 m
.4194 .22272 L
s
.41948 .22226 m
.41969 .21409 L
s
.531 .274 1 r
.55253 .16125 m
.55312 .20351 L
s
.45 .297 1 r
.4194 .22272 m
.41971 .21404 L
s
.41971 .21404 m
.41948 .22226 L
s
.744 .221 1 r
.66638 .21882 m
.66679 .22823 L
s
.66684 .22777 m
.66638 .21882 L
s
.66679 .22823 m
.66641 .21877 L
s
.66641 .21877 m
.66684 .22777 L
s
.701 .232 1 r
.24855 .23311 m
.24845 .23342 L
s
.424 .305 1 r
.72943 .16096 m
.73229 .20169 L
s
.952 .176 1 r
.4024 .16096 m
.40077 .20935 L
s
.881 .191 1 r
.63962 .2206 m
.63996 .23032 L
s
.64002 .22986 m
.63962 .2206 L
s
.495 .284 1 r
.74672 .21469 m
.74732 .22344 L
s
.74735 .22302 m
.74672 .21469 L
s
.881 .191 1 r
.63996 .23032 m
.63965 .22055 L
s
.63965 .22055 m
.64002 .22986 L
s
.495 .284 1 r
.74732 .22344 m
.74675 .21465 L
s
.74675 .21465 m
.74735 .22302 L
s
.352 .327 1 r
.40918 .22441 m
.4091 .22486 L
s
.365 .486 1 r
.41398 .19694 m
.41368 .20484 L
s
.41369 .2048 m
.41398 .19694 L
s
.41398 .19694 m
.41346 .21241 L
s
.66 .241 1 r
.54304 .21706 m
.54308 .22628 L
s
.54315 .22577 m
.54304 .21706 L
s
.788 .211 1 r
.72573 .23415 m
.72569 .23454 L
s
.531 .274 1 r
.30207 .23047 m
.30199 .23058 L
s
.66 .241 1 r
.54308 .22628 m
.54306 .21701 L
s
.54306 .21701 m
.54315 .22577 L
s
.56 .267 1 r
.39289 .21648 m
.39251 .22535 L
s
.39258 .22512 m
.39289 .21648 L
s
.347 .402 1 r
.57931 .16067 m
.58018 .19912 L
s
.639 .246 1 r
.42543 .23282 m
.42536 .23291 L
s
.56 .267 1 r
.39251 .22535 m
.39291 .21643 L
s
.39291 .21643 m
.39258 .22512 L
s
.754 .219 1 r
.60718 .20472 m
.60738 .21406 L
s
.60741 .21401 m
.60718 .20472 L
s
.60718 .20472 m
.60768 .22326 L
s
.765 .217 1 r
.39865 .23453 m
.39857 .23473 L
s
.352 .327 1 r
.38237 .22649 m
.38231 .22649 L
s
.383 .566 1 r
.75628 .16037 m
.75921 .19768 L
s
.383 .317 1 r
.42915 .16037 m
.42813 .20112 L
s
.712 .229 1 r
.45221 .23189 m
.45213 .23235 L
s
.56 .267 1 r
.59661 .21502 m
.59681 .22396 L
s
.59686 .2235 m
.59661 .21502 L
s
.59681 .22396 m
.59664 .21497 L
s
.59664 .21497 m
.59686 .2235 L
s
.978 .171 1 r
.60612 .16008 m
.60759 .20772 L
s
.799 .209 1 r
.3068 .20433 m
.30612 .2138 L
s
.30614 .21375 m
.3068 .20433 L
s
.3068 .20433 m
.30555 .22307 L
s
.991 .169 1 r
.54883 .23634 m
.54876 .23681 L
s
.777 .214 1 r
.77941 .23265 m
.77938 .23311 L
s
.744 .221 1 r
.66079 .20293 m
.66116 .21232 L
s
.66119 .21227 m
.66079 .20293 L
s
.66079 .20293 m
.66161 .22136 L
s
.559 .267 1 r
.68277 .22896 m
.68272 .2293 L
s
.869 .194 1 r
.78314 .15979 m
.78718 .20628 L
s
.485 .287 1 r
.45592 .15979 m
.45521 .20207 L
s
.68 .237 1 r
.47898 .23132 m
.47891 .23167 L
s
.4 .312 1 r
.59094 .19789 m
.59109 .20638 L
s
.59111 .20633 m
.59094 .19789 L
s
.59094 .19789 m
.59131 .21441 L
s
.451 .837 1 r
.33349 .20322 m
.33306 .21023 L
s
.33313 .20994 m
.33349 .20322 L
s
.33306 .21023 m
.3335 .20319 L
s
.3335 .20319 m
.33313 .20994 L
s
.88 .191 1 r
.48379 .20412 m
.48364 .21382 L
s
.48366 .21377 m
.48379 .20412 L
s
.48379 .20412 m
.48358 .22317 L
s
.375 .32 1 r
.63294 .1595 m
.63452 .19949 L
s
1 .154 .933 r
.69908 .23776 m
.69903 .23812 L
s
.531 .274 1 r
.55935 .22735 m
.5593 .22781 L
s
.335 .341 1 r
.37654 .21032 m
.37615 .21853 L
s
.37622 .21819 m
.37654 .21032 L
s
.37615 .21853 m
.37656 .21028 L
s
.37656 .21028 m
.37622 .21819 L
s
.811 .206 1 r
.7201 .2186 m
.72068 .22813 L
s
.72072 .22778 m
.7201 .2186 L
s
.337 .332 1 r
.55358 .20974 m
.55365 .21802 L
s
.5537 .21753 m
.55358 .20974 L
s
.811 .206 1 r
.72068 .22813 m
.72013 .21855 L
s
.72013 .21855 m
.72072 .22778 L
s
.337 .332 1 r
.55365 .21802 m
.5536 .20969 L
s
.5536 .20969 m
.5537 .21753 L
s
.733 .224 1 r
.68763 .2024 m
.68807 .21175 L
s
.6881 .2117 m
.68763 .2024 L
s
.68763 .2024 m
.6886 .22079 L
s
.722 .227 1 r
.32871 .23143 m
.32862 .23181 L
s
.845 .199 1 r
.4827 .15921 m
.48231 .20647 L
s
.711 .229 1 r
.65602 .23143 m
.65597 .23177 L
s
.504 .282 1 r
.58616 .22641 m
.58611 .22687 L
s
.433 .772 1 r
.51051 .20354 m
.51047 .21074 L
s
.51052 .21041 m
.51051 .20354 L
s
.56 .267 1 r
.47319 .21477 m
.47303 .22365 L
s
.4731 .22341 m
.47319 .21477 L
s
.433 .772 1 r
.51047 .21074 m
.51052 .2035 L
s
.51052 .2035 m
.51052 .21041 L
s
.701 .232 1 r
.50576 .23115 m
.50569 .23146 L
s
.881 .191 1 r
.65977 .15892 m
.66201 .20541 L
s
.649 .244 1 r
.33241 .15892 m
.33 .20235 L
s
.56 .267 1 r
.47303 .22365 m
.47321 .21472 L
s
.47321 .21472 m
.4731 .22341 L
s
.598 .257 1 r
.26929 .21714 m
.26857 .22598 L
s
.26862 .22617 m
.26929 .21714 L
s
.638 .247 1 r
.71446 .20149 m
.71497 .21057 L
s
.71499 .21052 m
.71446 .20149 L
s
.71446 .20149 m
.71555 .21946 L
s
.38709 .20149 m
.38667 .21057 L
s
.38669 .21052 m
.38709 .20149 L
s
.38709 .20149 m
.38634 .21946 L
s
.598 .257 1 r
.26857 .22598 m
.26931 .21709 L
s
.26931 .21709 m
.26862 .22617 L
s
.649 .244 1 r
.53257 .22982 m
.5325 .23017 L
s
.68 .237 1 r
.56419 .20106 m
.56427 .21029 L
s
.56429 .21024 m
.56419 .20106 L
s
.56419 .20106 m
.56444 .21917 L
s
.733 .224 1 r
.50949 .15863 m
.50951 .20359 L
s
.833 .201 1 r
.62926 .23389 m
.6292 .23409 L
s
.638 .247 1 r
.8006 .21538 m
.80138 .22449 L
s
.80141 .22418 m
.8006 .21538 L
s
.80138 .22449 m
.80063 .21533 L
s
.80063 .21533 m
.80141 .22418 L
s
.701 .232 1 r
.29606 .21627 m
.29538 .22554 L
s
.29548 .22523 m
.29606 .21627 L
s
.722 .227 1 r
.53738 .20283 m
.53739 .21207 L
s
.53741 .21202 m
.53738 .20283 L
s
.53738 .20283 m
.53748 .22127 L
s
.701 .232 1 r
.29538 .22554 m
.29608 .21622 L
s
.29608 .21622 m
.29548 .22523 L
s
.777 .214 1 r
.77382 .21716 m
.77455 .22662 L
s
.77459 .22627 m
.77382 .21716 L
s
.68 .237 1 r
.68662 .15834 m
.68911 .20215 L
s
.522 .277 1 r
.35917 .15834 m
.35717 .20062 L
s
.777 .214 1 r
.77455 .22662 m
.77385 .21711 L
s
.77385 .21711 m
.77459 .22627 L
s
.541 .272 1 r
.34966 .21362 m
.34916 .22246 L
s
.34924 .22218 m
.34966 .21362 L
s
.34916 .22246 m
.34967 .21357 L
s
.34967 .21357 m
.34924 .22218 L
s
.857 .196 1 r
.80645 .234 m
.80639 .23416 L
s
.477 .289 1 r
.5363 .15804 m
.53667 .19919 L
s
.375 .32 1 r
.51628 .22292 m
.51622 .22325 L
s
.648 .244 1 r
.44067 .19997 m
.44039 .20913 L
s
.44041 .20908 m
.44067 .19997 L
s
.44067 .19997 m
.44022 .21794 L
s
.618 .252 1 r
.2903 .19946 m
.2896 .20854 L
s
.28962 .20849 m
.2903 .19946 L
s
.2903 .19946 m
.28901 .21727 L
s
.505 .281 1 r
.58043 .21068 m
.58058 .21955 L
s
.58063 .21886 m
.58043 .21068 L
s
.869 .194 1 r
.71349 .15775 m
.71651 .20426 L
s
.702 .231 1 r
.38594 .15775 m
.38409 .20503 L
s
.531 .274 1 r
.79021 .22633 m
.79017 .22667 L
s
.505 .281 1 r
.58058 .21955 m
.58046 .21064 L
s
.58046 .21064 m
.58063 .21886 L
s
.68 .237 1 r
.61785 .19957 m
.61808 .20884 L
s
.61811 .20879 m
.61785 .19957 L
s
.61785 .19957 m
.6184 .21765 L
s
.744 .222 1 r
.65035 .21601 m
.65071 .22539 L
s
.65077 .22504 m
.65035 .21601 L
s
.649 .244 1 r
.67717 .21453 m
.6776 .22368 L
s
.67765 .22333 m
.67717 .21453 L
s
.476 .29 1 r
.40324 .21157 m
.4029 .22025 L
s
.40298 .21991 m
.40324 .21157 L
s
.744 .222 1 r
.65071 .22539 m
.65038 .21596 L
s
.65038 .21596 m
.65077 .22504 L
s
.649 .244 1 r
.6776 .22368 m
.67719 .21448 L
s
.67719 .21448 m
.67765 .22333 L
s
.476 .29 1 r
.4029 .22025 m
.40326 .21153 L
s
.40326 .21153 m
.40298 .21991 L
s
.618 .252 1 r
.5268 .21394 m
.5268 .22301 L
s
.52686 .22266 m
.5268 .21394 L
s
.56 .267 1 r
.46747 .19907 m
.46727 .20795 L
s
.4673 .2079 m
.46747 .19907 L
s
.46747 .19907 m
.46717 .21661 L
s
.777 .214 1 r
.70978 .23106 m
.70973 .23141 L
s
.618 .252 1 r
.5268 .22301 m
.52682 .21389 L
s
.52682 .21389 m
.52686 .22266 L
s
.388 .587 1 r
.36012 .20507 m
.35972 .21274 L
s
.35979 .21241 m
.36012 .20507 L
s
.35972 .21274 m
.36014 .20503 L
s
.36014 .20503 m
.35979 .21241 L
s
.649 .244 1 r
.56313 .15746 m
.56389 .2009 L
s
.638 .247 1 r
.43582 .22842 m
.43575 .22872 L
s
.424 .305 1 r
.69351 .22339 m
.69347 .22373 L
s
.68 .237 1 r
.74037 .15717 m
.74363 .20138 L
s
.559 .267 1 r
.41273 .15717 m
.41144 .19985 L
s
.81 .206 1 r
.74146 .20269 m
.74206 .21213 L
s
.74209 .21208 m
.74146 .20269 L
s
.74146 .20269 m
.74276 .22156 L
s
.476 .29 1 r
.43003 .21101 m
.42977 .21969 L
s
.42984 .21934 m
.43003 .21101 L
s
.467 .292 1 r
.34386 .19757 m
.34335 .20618 L
s
.34336 .20613 m
.34386 .19757 L
s
.34386 .19757 m
.34292 .2146 L
s
.476 .29 1 r
.42977 .21969 m
.43005 .21096 L
s
.43005 .21096 m
.42984 .21934 L
s
1 .161 .972 r
.44633 .21929 m
.44607 .2293 L
s
.44615 .22894 m
.44633 .21929 L
s
.45 .297 1 r
.36587 .22377 m
.36579 .22412 L
s
1 .161 .972 r
.44607 .2293 m
.44635 .21924 L
s
.44635 .21924 m
.44615 .22894 L
s
.788 .212 1 r
.32272 .21722 m
.32211 .22661 L
s
.32219 .22657 m
.32272 .21722 L
s
.712 .229 1 r
.70406 .21427 m
.70458 .22361 L
s
.70462 .22315 m
.70406 .21427 L
s
.788 .212 1 r
.32211 .22661 m
.32274 .21717 L
s
.32274 .21717 m
.32219 .22657 L
s
.352 .327 1 r
.3975 .19492 m
.39714 .20322 L
s
.39716 .20317 m
.3975 .19492 L
s
.3975 .19492 m
.39687 .21117 L
s
.648 .244 1 r
.58997 .15688 m
.59111 .20071 L
s
.712 .229 1 r
.70458 .22361 m
.70409 .21422 L
s
.70409 .21422 m
.70462 .22315 L
s
.834 .201 1 r
.49998 .21664 m
.49989 .22622 L
s
.49996 .22591 m
.49998 .21664 L
s
.942 .178 1 r
.76833 .2017 m
.76905 .21156 L
s
.76908 .21151 m
.76833 .2017 L
s
.76833 .2017 m
.76983 .22099 L
s
.834 .201 1 r
.49989 .22622 m
.5 .21659 L
s
.5 .21659 m
.49996 .22591 L
s
.569 .264 1 r
.31218 .22719 m
.31211 .22734 L
s
.712 .229 1 r
.49429 .19894 m
.49416 .20829 L
s
.49419 .20824 m
.49429 .19894 L
s
.49429 .19894 m
.49414 .21718 L
s
.701 .232 1 r
.25852 .23022 m
.25845 .2303 L
s
.744 .221 1 r
.76353 .22956 m
.76349 .22991 L
s
.503 .282 1 r
.37066 .19684 m
.37021 .20561 L
s
.37022 .20556 m
.37066 .19684 L
s
.37066 .19684 m
.36985 .21403 L
s
.767 .216 1 r
.76727 .15658 m
.77097 .20156 L
s
.521 .277 1 r
.43953 .15658 m
.4386 .19927 L
s
.69 .234 1 r
.46263 .22823 m
.46255 .22862 L
s
.766 .217 1 r
.64474 .20006 m
.64506 .20949 L
s
.64509 .20944 m
.64474 .20006 L
s
.64474 .20006 m
.64547 .21861 L
s
.335 .34 1 r
.62363 .21951 m
.62358 .21997 L
s
.433 .302 1 r
.54794 .19652 m
.54797 .20502 L
s
.54799 .20497 m
.54794 .19652 L
s
.54794 .19652 m
.54808 .21337 L
s
.68 .237 1 r
.67159 .19877 m
.67198 .208 L
s
.672 .20795 m
.67159 .19877 L
s
.67159 .19877 m
.67245 .21689 L
s
.61683 .15629 m
.61836 .20051 L
s
.88 .191 1 r
.73674 .23165 m
.7367 .232 L
s
.477 .289 1 r
.63415 .21015 m
.63444 .21883 L
s
.63449 .21849 m
.63415 .21015 L
s
.754 .219 1 r
.31696 .20044 m
.31632 .20979 L
s
.31634 .20974 m
.31696 .20044 L
s
.31696 .20044 m
.31578 .21899 L
s
.477 .289 1 r
.63444 .21883 m
.63418 .21011 L
s
.63418 .21011 m
.63449 .21849 L
s
.599 .257 1 r
.45684 .21105 m
.45664 .22015 L
s
.45671 .21954 m
.45684 .21105 L
s
.468 .292 1 r
.56997 .22292 m
.56991 .22335 L
s
.766 .217 1 r
.28529 .22966 m
.2852 .22997 L
s
.811 .206 1 r
.61311 .22966 m
.61306 .23012 L
s
.599 .257 1 r
.45664 .22015 m
.45686 .211 L
s
.45686 .211 m
.45671 .21954 L
s
.45 .297 1 r
.41948 .22226 m
.4194 .22272 L
s
.589 .259 1 r
.2795 .21193 m
.2788 .22093 L
s
.27889 .22058 m
.2795 .21193 L
s
.433 .302 1 r
.46635 .156 m
.46579 .19754 L
s
.589 .259 1 r
.2788 .22093 m
.27952 .21189 L
s
.27952 .21189 m
.27889 .22058 L
s
.691 .234 1 r
.69846 .19782 m
.69893 .20713 L
s
.69895 .20708 m
.69846 .19782 L
s
.69846 .19782 m
.69947 .21594 L
s
.744 .222 1 r
.73099 .21431 m
.73159 .22369 L
s
.73163 .22334 m
.73099 .21431 L
s
.73159 .22369 m
.73102 .21426 L
s
.73102 .21426 m
.73163 .22334 L
s
.365 .486 1 r
.41368 .20484 m
.41339 .21274 L
s
.41346 .21241 m
.41368 .20484 L
s
.634 1 .705 r
.39164 .17874 m
.39141 .18392 L
s
.39142 .18389 m
.39164 .17874 L
s
.39164 .17874 m
.39124 .18873 L
s
.365 .486 1 r
.41339 .21274 m
.41369 .2048 L
s
.41369 .2048 m
.41346 .21241 L
s
.579 .262 1 r
.78469 .21165 m
.78542 .22061 L
s
.78545 .2203 m
.78469 .21165 L
s
.811 .206 1 r
.6437 .15571 m
.64567 .20146 L
s
.701 .232 1 r
.48945 .22805 m
.48938 .22836 L
s
.579 .262 1 r
.78542 .22061 m
.78472 .21161 L
s
.78472 .21161 m
.78545 .2203 L
s
.495 .284 1 r
.74735 .22302 m
.74732 .22344 L
s
.711 .229 1 r
.75788 .21343 m
.75855 .22274 L
s
.75859 .22239 m
.75788 .21343 L
s
.38 .554 1 r
.5048 .19104 m
.50472 .1988 L
s
.50474 .19876 m
.5048 .19104 L
s
.5048 .19104 m
.50472 .20622 L
s
.711 .229 1 r
.75855 .22274 m
.75791 .21338 L
s
.75791 .21338 m
.75859 .22239 L
s
.569 .264 1 r
.49318 .15542 m
.49297 .19887 L
s
.744 .221 1 r
.66684 .22777 m
.66679 .22823 L
s
.451 .837 1 r
.33313 .20994 m
.33306 .21023 L
s
.765 .217 1 r
.52112 .19954 m
.52107 .20894 L
s
.5211 .20888 m
.52112 .19954 L
s
.52112 .19954 m
.52112 .21814 L
s
.929 .181 1 r
.79535 .20254 m
.79613 .21221 L
s
.79617 .21216 m
.79535 .20254 L
s
.79535 .20254 m
.79703 .22196 L
s
.66 .241 1 r
.54315 .22577 m
.54308 .22628 L
s
.56 .267 1 r
.39258 .22512 m
.39251 .22535 L
s
.99 .169 1 r
.67059 .15512 m
.67305 .2028 L
s
.477 .289 1 r
.34262 .15512 m
.34044 .19667 L
s
.881 .191 1 r
.64002 .22986 m
.63996 .23032 L
s
.669 .239 1 r
.57483 .19738 m
.57494 .20658 L
s
.57496 .20653 m
.57483 .19738 L
s
.57483 .19738 m
.57514 .21547 L
s
.766 .217 1 r
.52003 .15483 m
.5202 .20174 L
s
.56 .267 1 r
.59686 .2235 m
.59681 .22396 L
s
.588 .259 1 r
.60169 .19609 m
.60187 .20509 L
s
.6019 .20504 m
.60169 .19609 L
s
.60169 .19609 m
.60214 .21375 L
s
.754 .219 1 r
.60738 .21406 m
.60762 .22341 L
s
.60768 .22326 m
.60738 .21406 L
s
.342 .378 1 r
.32734 .19314 m
.32682 .20121 L
s
.32683 .20117 m
.32734 .19314 L
s
.32734 .19314 m
.32637 .20917 L
s
.754 .219 1 r
.60762 .22341 m
.60741 .21401 L
s
.60741 .21401 m
.60768 .22326 L
s
.608 .254 1 r
.42423 .19698 m
.42392 .20598 L
s
.42394 .20594 m
.42423 .19698 L
s
.42423 .19698 m
.4237 .2148 L
s
.433 .772 1 r
.51052 .21041 m
.51047 .21074 L
s
.559 .267 1 r
.77915 .19558 m
.77983 .2045 L
s
.77986 .20445 m
.77915 .19558 L
s
.77915 .19558 m
.78058 .21308 L
s
.476 .29 1 r
.6975 .15454 m
.69999 .19609 L
s
.892 .189 1 r
.36943 .15454 m
.36728 .20299 L
s
.846 .199 1 r
.72545 .19876 m
.72602 .20839 L
s
.72605 .20834 m
.72545 .19876 L
s
.72545 .19876 m
.72667 .21767 L
s
.335 .341 1 r
.37622 .21819 m
.37615 .21853 L
s
.4 .312 1 r
.59109 .20638 m
.59126 .21486 L
s
.59131 .21441 m
.59109 .20638 L
s
.337 .332 1 r
.5537 .21753 m
.55365 .21802 L
s
.4 .312 1 r
.59126 .21486 m
.59111 .20633 L
s
.59111 .20633 m
.59131 .21441 L
s
.352 .327 1 r
.68229 .19233 m
.68267 .20064 L
s
.68269 .20059 m
.68229 .19233 L
s
.68229 .19233 m
.68312 .2086 L
s
.4 .312 1 r
.5469 .15425 m
.54739 .19465 L
s
.72442 .15395 m
.72719 .19436 L
s
.513 .279 1 r
.39626 .15395 m
.39477 .19589 L
s
.799 .209 1 r
.30612 .2138 m
.30546 .22327 L
s
.30555 .22307 m
.30612 .2138 L
s
.744 .221 1 r
.66116 .21232 m
.66155 .22171 L
s
.66161 .22136 m
.66116 .21232 L
s
.551 .269 1 r
.65546 .19441 m
.65579 .20334 L
s
.65582 .20329 m
.65546 .19441 L
s
.65546 .19441 m
.6562 .21184 L
s
.799 .209 1 r
.30546 .22327 m
.30614 .21375 L
s
.30614 .21375 m
.30555 .22307 L
s
.744 .221 1 r
.66155 .22171 m
.66119 .21227 L
s
.66119 .21227 m
.66161 .22136 L
s
.701 .232 1 r
.45107 .19674 m
.45082 .20602 L
s
.45085 .20597 m
.45107 .19674 L
s
.45107 .19674 m
.45067 .21499 L
s
.811 .206 1 r
.57378 .15366 m
.57473 .19943 L
s
.72072 .22778 m
.72068 .22813 L
s
.335 .341 1 r
.55854 .19125 m
.5586 .19947 L
s
.55862 .19943 m
.55854 .19125 L
s
.55854 .19125 m
.55873 .20736 L
s
.56 .267 1 r
.4731 .22341 m
.47303 .22365 L
s
.88 .191 1 r
.48364 .21382 m
.4835 .22352 L
s
.48358 .22317 m
.48364 .21382 L
s
.733 .224 1 r
.30037 .19668 m
.29968 .20604 L
s
.2997 .20599 m
.30037 .19668 L
s
.30037 .19668 m
.2991 .21509 L
s
.88 .191 1 r
.4835 .22352 m
.48366 .21377 L
s
.48366 .21377 m
.48358 .22317 L
s
.669 .239 1 r
.75135 .15337 m
.75482 .19838 L
s
.4231 .15337 m
.42189 .19799 L
s
.649 .244 1 r
.47793 .19602 m
.47776 .20515 L
s
.47778 .2051 m
.47793 .19602 L
s
.47793 .19602 m
.47769 .21404 L
s
.733 .224 1 r
.68807 .21175 m
.68855 .2211 L
s
.6886 .22079 m
.68807 .21175 L
s
.68855 .2211 m
.6881 .2117 L
s
.6881 .2117 m
.6886 .22079 L
s
.598 .257 1 r
.26862 .22617 m
.26857 .22598 L
s
.638 .247 1 r
.71497 .21057 m
.7155 .21965 L
s
.71555 .21946 m
.71497 .21057 L
s
.38667 .21057 m
.38627 .21965 L
s
.38634 .21946 m
.38667 .21057 L
s
.618 .252 1 r
.60067 .15307 m
.60195 .19655 L
s
.638 .247 1 r
.7155 .21965 m
.71499 .21052 L
s
.71499 .21052 m
.71555 .21946 L
s
.38627 .21965 m
.38669 .21052 L
s
.38669 .21052 m
.38634 .21946 L
s
.521 .277 1 r
.35408 .19429 m
.35358 .20307 L
s
.3536 .20302 m
.35408 .19429 L
s
.35408 .19429 m
.35317 .21165 L
s
.638 .247 1 r
.80141 .22418 m
.80138 .22449 L
s
.916 .184 1 r
.75249 .19966 m
.75315 .20933 L
s
.75318 .20928 m
.75249 .19966 L
s
.75249 .19966 m
.7539 .21901 L
s
.388 .587 1 r
.35979 .21241 m
.35972 .21274 L
s
.68 .237 1 r
.56427 .21029 m
.56437 .21952 L
s
.56444 .21917 m
.56427 .21029 L
s
.541 .272 1 r
.34924 .22218 m
.34916 .22246 L
s
.701 .232 1 r
.7783 .15278 m
.78213 .19741 L
s
.578 .262 1 r
.44995 .15278 m
.44914 .19626 L
s
.701 .232 1 r
.29548 .22523 m
.29538 .22554 L
s
.68 .237 1 r
.56437 .21952 m
.56429 .21024 L
s
.56429 .21024 m
.56444 .21917 L
s
.57 .264 1 r
.38095 .19318 m
.38052 .20219 L
s
.38053 .20214 m
.38095 .19318 L
s
.38095 .19318 m
.38018 .2107 L
s
.722 .227 1 r
.53739 .21207 m
.53741 .22131 L
s
.53748 .22127 m
.53739 .21207 L
s
.777 .214 1 r
.77459 .22627 m
.77455 .22662 L
s
.722 .227 1 r
.53741 .22131 m
.53741 .21202 L
s
.53741 .21202 m
.53748 .22127 L
s
.505 .281 1 r
.58063 .21886 m
.58058 .21955 L
s
.811 .206 1 r
.62758 .15249 m
.62932 .19827 L
s
.634 1 .705 r
.39141 .18392 m
.39118 .18908 L
s
.39124 .18873 m
.39141 .18392 L
s
.39118 .18908 m
.39142 .18389 L
s
.39142 .18389 m
.39124 .18873 L
s
.648 .244 1 r
.53169 .19453 m
.53168 .20369 L
s
.5317 .20364 m
.53169 .19453 L
s
.53169 .19453 m
.53175 .21251 L
s
.476 .29 1 r
.40298 .21991 m
.4029 .22025 L
s
.503 .282 1 r
.73624 .19254 m
.73679 .20131 L
s
.73682 .20126 m
.73624 .19254 L
s
.73624 .19254 m
.73741 .20974 L
s
.47682 .15219 m
.47639 .19491 L
s
.648 .244 1 r
.44039 .20913 m
.44014 .21828 L
s
.44022 .21794 m
.44039 .20913 L
s
.649 .244 1 r
.67765 .22333 m
.6776 .22368 L
s
.648 .244 1 r
.44014 .21828 m
.44041 .20908 L
s
.44041 .20908 m
.44022 .21794 L
s
.618 .252 1 r
.52686 .22266 m
.5268 .22301 L
s
.2896 .20854 m
.28892 .21762 L
s
.28901 .21727 m
.2896 .20854 L
s
.28892 .21762 m
.28962 .20849 L
s
.28962 .20849 m
.28901 .21727 L
s
.744 .222 1 r
.65077 .22504 m
.65071 .22539 L
s
.56 .267 1 r
.46727 .20795 m
.46711 .21684 L
s
.46717 .21661 m
.46727 .20795 L
s
.629 .249 1 r
.65451 .1519 m
.65653 .19539 L
s
.56 .267 1 r
.46711 .21684 m
.4673 .2079 L
s
.4673 .2079 m
.46717 .21661 L
s
.68 .237 1 r
.61808 .20884 m
.61835 .21812 L
s
.6184 .21765 m
.61808 .20884 L
s
1 .138 .854 r
.62872 .19913 m
.62902 .20939 L
s
.62905 .20934 m
.62872 .19913 L
s
.62872 .19913 m
.62941 .2193 L
s
.68 .237 1 r
.61835 .21812 m
.61811 .20879 L
s
.61811 .20879 m
.6184 .21765 L
s
.476 .29 1 r
.42984 .21934 m
.42977 .21969 L
s
.467 .292 1 r
.34335 .20618 m
.34284 .21479 L
s
.34292 .2146 m
.34335 .20618 L
s
.352 .327 1 r
.39714 .20322 m
.3968 .21151 L
s
.39687 .21117 m
.39714 .20322 L
s
.711 .229 1 r
.50371 .15161 m
.50365 .19625 L
s
.467 .292 1 r
.34284 .21479 m
.34336 .20613 L
s
.34336 .20613 m
.34292 .2146 L
s
.352 .327 1 r
.3968 .21151 m
.39716 .20317 L
s
.39716 .20317 m
.39687 .21117 L
s
.467 .292 1 r
.43466 .19211 m
.43439 .20074 L
s
.4344 .20069 m
.43466 .19211 L
s
.43466 .19211 m
.4342 .20917 L
s
.702 .231 1 r
.40776 .19381 m
.40739 .20314 L
s
.40741 .20309 m
.40776 .19381 L
s
.40776 .19381 m
.40712 .21203 L
s
.955 .176 1 r
.68145 .15131 m
.684 .19749 L
s
.44 .8 1 r
.35287 .15131 m
.35122 .18487 L
s
.712 .229 1 r
.70462 .22315 m
.70458 .22361 L
s
.433 .302 1 r
.6393 .19039 m
.63958 .19897 L
s
.6396 .19892 m
.6393 .19039 L
s
.6393 .19039 m
.63993 .20717 L
s
.81 .206 1 r
.74206 .21213 m
.7427 .22157 L
s
.74276 .22156 m
.74206 .21213 L
s
.365 .486 1 r
.36449 .18746 m
.36407 .19538 L
s
.36408 .19534 m
.36449 .18746 L
s
.36449 .18746 m
.36373 .20296 L
s
.723 .226 1 r
.58551 .19345 m
.58566 .20285 L
s
.58568 .2028 m
.58551 .19345 L
s
.58551 .19345 m
.58589 .21175 L
s
.81 .206 1 r
.7427 .22157 m
.74209 .21208 L
s
.74209 .21208 m
.74276 .22156 L
s
.503 .282 1 r
.37021 .20561 m
.36977 .21438 L
s
.36985 .21403 m
.37021 .20561 L
s
.477 .289 1 r
.53061 .15102 m
.53091 .19222 L
s
.503 .282 1 r
.36977 .21438 m
.37022 .20556 L
s
.37022 .20556 m
.36985 .21403 L
s
.788 .212 1 r
.32219 .22657 m
.32211 .22661 L
s
.365 .486 1 r
.41346 .21241 m
.41339 .21274 L
s
.433 .302 1 r
.54797 .20502 m
.54802 .21352 L
s
.54808 .21337 m
.54797 .20502 L
s
.834 .201 1 r
.49996 .22591 m
.49989 .22622 L
s
.916 .184 1 r
.70949 .19605 m
.71002 .20584 L
s
.71005 .20579 m
.70949 .19605 L
s
.70949 .19605 m
.71063 .21529 L
s
1 .161 .972 r
.44615 .22894 m
.44607 .2293 L
s
.433 .302 1 r
.54802 .21352 m
.54799 .20497 L
s
.54799 .20497 m
.54808 .21337 L
s
.477 .289 1 r
.63449 .21849 m
.63444 .21883 L
s
.531 .274 1 r
.46154 .19161 m
.46134 .20047 L
s
.46136 .20042 m
.46154 .19161 L
s
.46154 .19161 m
.46122 .20898 L
s
.496 .284 1 r
.33757 .18954 m
.33703 .19839 L
s
.33704 .19834 m
.33757 .18954 L
s
.33757 .18954 m
.33659 .20659 L
s
.712 .229 1 r
.49416 .20829 m
.49407 .21764 L
s
.49414 .21718 m
.49416 .20829 L
s
.978 .171 1 r
.70841 .15073 m
.71144 .19845 L
s
.416 .307 1 r
.37973 .15073 m
.37801 .19269 L
s
.712 .229 1 r
.49407 .21764 m
.49419 .20824 L
s
.49419 .20824 m
.49414 .21718 L
s
.599 .257 1 r
.45671 .21954 m
.45664 .22015 L
s
.459 .295 1 r
.31064 .19129 m
.31003 .19988 L
s
.31005 .19983 m
.31064 .19129 L
s
.31064 .19129 m
.30952 .20831 L
s
.38 .554 1 r
.50472 .1988 m
.50467 .20655 L
s
.50472 .20622 m
.50472 .1988 L
s
.942 .178 1 r
.76905 .21156 m
.7698 .22143 L
s
.76983 .22099 m
.76905 .21156 L
s
.38 .554 1 r
.50467 .20655 m
.50474 .19876 L
s
.50474 .19876 m
.50472 .20622 L
s
.942 .178 1 r
.7698 .22143 m
.76908 .21151 L
s
.76908 .21151 m
.76983 .22099 L
s
.589 .259 1 r
.27889 .22058 m
.2788 .22093 L
s
.766 .217 1 r
.64506 .20949 m
.64541 .21892 L
s
.64547 .21861 m
.64506 .20949 L
s
.68 .237 1 r
.67198 .208 m
.6724 .21724 L
s
.67245 .21689 m
.67198 .208 L
s
.618 .252 1 r
.55753 .15043 m
.55821 .19355 L
s
.766 .217 1 r
.64541 .21892 m
.64509 .20944 L
s
.64509 .20944 m
.64547 .21861 L
s
.342 .378 1 r
.54226 .18785 m
.54228 .19601 L
s
.5423 .19596 m
.54226 .18785 L
s
.54226 .18785 m
.54237 .20382 L
s
.68 .237 1 r
.6724 .21724 m
.672 .20795 L
s
.672 .20795 m
.67245 .21689 L
s
.754 .219 1 r
.31632 .20979 m
.3157 .21915 L
s
.31578 .21899 m
.31632 .20979 L
s
.3157 .21915 m
.31634 .20974 L
s
.31634 .20974 m
.31578 .21899 L
s
.579 .262 1 r
.78545 .2203 m
.78542 .22061 L
s
.744 .222 1 r
.73163 .22334 m
.73159 .22369 L
s
.551 .269 1 r
.73538 .15014 m
.73844 .19249 L
s
.669 .239 1 r
.40661 .15014 m
.40516 .19479 L
s
.691 .234 1 r
.69893 .20713 m
.69943 .21644 L
s
.69947 .21594 m
.69893 .20713 L
s
.69943 .21644 m
.69895 .20708 L
s
.69895 .20708 m
.69947 .21594 L
s
.953 .176 1 r
.58446 .14984 m
.58561 .19719 L
s
.711 .229 1 r
.75859 .22239 m
.75855 .22274 L
s
.788 .211 1 r
.79036 .19339 m
.79112 .20291 L
s
.79115 .20285 m
.79036 .19339 L
s
.79036 .19339 m
.79194 .21204 L
s
.569 .264 1 r
.48843 .19191 m
.4883 .20081 L
s
.48832 .20076 m
.48843 .19191 L
s
.48843 .19191 m
.48826 .20955 L
s
.845 .199 1 r
.61248 .19416 m
.61271 .2038 L
s
.61274 .20375 m
.61248 .19416 L
s
.61248 .19416 m
.61303 .21309 L
s
.342 .378 1 r
.32682 .20121 m
.32631 .20928 L
s
.32637 .20917 m
.32682 .20121 L
s
.669 .239 1 r
.76237 .14955 m
.76598 .1942 L
s
.608 .254 1 r
.4335 .14955 m
.43246 .19344 L
s
.342 .378 1 r
.32631 .20928 m
.32683 .20117 L
s
.32683 .20117 m
.32637 .20917 L
s
.765 .217 1 r
.52107 .20894 m
.52105 .21833 L
s
.52112 .21814 m
.52107 .20894 L
s
.634 1 .705 r
.39124 .18873 m
.39118 .18908 L
s
.765 .217 1 r
.52105 .21833 m
.5211 .20888 L
s
.5211 .20888 m
.52112 .21814 L
s
.588 .259 1 r
.61141 .14926 m
.61283 .19238 L
s
.929 .181 1 r
.79613 .21221 m
.79695 .22189 L
s
.79703 .22196 m
.79613 .21221 L
s
.4 .312 1 r
.59131 .21441 m
.59126 .21486 L
s
.929 .181 1 r
.79695 .22189 m
.79617 .21216 L
s
.79617 .21216 m
.79703 .22196 L
s
.424 .305 1 r
.56922 .1884 m
.56931 .19695 L
s
.56933 .1969 m
.56922 .1884 L
s
.56922 .1884 m
.56947 .20515 L
s
.669 .239 1 r
.57494 .20658 m
.57508 .21578 L
s
.57514 .21547 m
.57494 .20658 L
s
.588 .259 1 r
.60187 .20509 m
.60208 .2141 L
s
.60214 .21375 m
.60187 .20509 L
s
.352 .327 1 r
.68267 .20064 m
.68307 .20894 L
s
.68312 .2086 m
.68267 .20064 L
s
.608 .254 1 r
.46041 .14896 m
.45974 .19285 L
s
.669 .239 1 r
.57508 .21578 m
.57496 .20653 L
s
.57496 .20653 m
.57514 .21547 L
s
.588 .259 1 r
.60208 .2141 m
.6019 .20504 L
s
.6019 .20504 m
.60214 .21375 L
s
.352 .327 1 r
.68307 .20894 m
.68269 .20059 L
s
.68269 .20059 m
.68312 .2086 L
s
.608 .254 1 r
.42392 .20598 m
.42362 .21499 L
s
.4237 .2148 m
.42392 .20598 L
s
.559 .267 1 r
.77983 .2045 m
.78054 .21343 L
s
.78058 .21308 m
.77983 .2045 L
s
.608 .254 1 r
.42362 .21499 m
.42394 .20594 L
s
.42394 .20594 m
.4237 .2148 L
s
.559 .267 1 r
.78054 .21343 m
.77986 .20445 L
s
.77986 .20445 m
.78058 .21308 L
s
.754 .219 1 r
.60768 .22326 m
.60762 .22341 L
s
.669 .239 1 r
.51536 .19197 m
.5153 .20114 L
s
.51533 .20109 m
.51536 .19197 L
s
.51536 .19197 m
.51533 .21012 L
s
.94 .179 1 r
.63838 .14867 m
.64035 .1964 L
s
.88 .191 1 r
.66643 .19324 m
.66682 .20296 L
s
.66685 .2029 m
.66643 .19324 L
s
.66643 .19324 m
.6673 .21233 L
s
.424 .305 1 r
.48733 .14837 m
.48706 .1892 L
s
.846 .199 1 r
.72602 .20839 m
.72663 .21802 L
s
.72667 .21767 m
.72602 .20839 L
s
.72663 .21802 m
.72605 .20834 L
s
.72605 .20834 m
.72667 .21767 L
s
.335 .341 1 r
.5586 .19947 m
.55868 .2077 L
s
.55873 .20736 m
.5586 .19947 L
s
.55868 .2077 m
.55862 .19943 L
s
.55862 .19943 m
.55873 .20736 L
s
.522 .277 1 r
.41817 .18906 m
.41785 .19788 L
s
.41787 .19783 m
.41817 .18906 L
s
.41817 .18906 m
.41761 .2064 L
s
.551 .269 1 r
.65579 .20334 m
.65615 .21227 L
s
.6562 .21184 m
.65579 .20334 L
s
.733 .224 1 r
.69338 .19214 m
.69384 .20147 L
s
.69387 .20141 m
.69338 .19214 L
s
.69338 .19214 m
.69439 .2106 L
s
.551 .269 1 r
.65615 .21227 m
.65582 .20329 L
s
.65582 .20329 m
.6562 .21184 L
s
.523 .277 1 r
.59619 .18842 m
.59636 .19728 L
s
.59638 .19724 m
.59619 .18842 L
s
.59619 .18842 m
.59661 .20572 L
s
.744 .221 1 r
.66161 .22136 m
.66155 .22171 L
s
.383 .317 1 r
.4451 .18773 m
.44487 .19609 L
s
.44488 .19604 m
.4451 .18773 L
s
.4451 .18773 m
.44471 .20429 L
s
.629 .249 1 r
.66536 .14808 m
.66753 .1916 L
s
.799 .209 1 r
.30555 .22307 m
.30546 .22327 L
s
.701 .232 1 r
.45082 .20602 m
.4506 .2153 L
s
.45067 .21499 m
.45082 .20602 L
s
.4506 .2153 m
.45085 .20597 L
s
.45085 .20597 m
.45067 .21499 L
s
.658 .242 1 r
.51427 .14778 m
.51436 .19245 L
s
.638 .247 1 r
.74733 .18996 m
.74793 .1991 L
s
.74796 .19905 m
.74733 .18996 L
s
.74733 .18996 m
.74861 .20792 L
s
.335 .341 1 r
.49899 .18548 m
.49889 .19371 L
s
.49891 .19367 m
.49899 .18548 L
s
.49899 .18548 m
.49888 .20161 L
s
.37 .509 1 r
.32091 .1863 m
.32039 .194 L
s
.3204 .19396 m
.32091 .1863 L
s
.32091 .1863 m
.31993 .2019 L
s
1 .118 .744 r
.76371 .19835 m
.76445 .20866 L
s
.76448 .2086 m
.76371 .19835 L
s
.76371 .19835 m
.7653 .21913 L
s
.733 .224 1 r
.6886 .22079 m
.68855 .2211 L
s
.649 .244 1 r
.47776 .20515 m
.47762 .21428 L
s
.47769 .21404 m
.47776 .20515 L
s
.811 .206 1 r
.72039 .19163 m
.72095 .20119 L
s
.72097 .20114 m
.72039 .19163 L
s
.72039 .19163 m
.72158 .21041 L
s
.805 .208 1 r
.69235 .14749 m
.69496 .19177 L
s
.618 .252 1 r
.36315 .14749 m
.36114 .19101 L
s
.649 .244 1 r
.47762 .21428 m
.47778 .2051 L
s
.47778 .2051 m
.47769 .21404 L
s
.88 .191 1 r
.48358 .22317 m
.4835 .22352 L
s
.733 .224 1 r
.29968 .20604 m
.29901 .2154 L
s
.2991 .21509 m
.29968 .20604 L
s
.638 .247 1 r
.71555 .21946 m
.7155 .21965 L
s
.38634 .21946 m
.38627 .21965 L
s
.521 .277 1 r
.35358 .20307 m
.3531 .21184 L
s
.35317 .21165 m
.35358 .20307 L
s
.733 .224 1 r
.29901 .2154 m
.2997 .20599 L
s
.2997 .20599 m
.2991 .21509 L
s
.521 .277 1 r
.3531 .21184 m
.3536 .20302 L
s
.3536 .20302 m
.35317 .21165 L
s
.531 .274 1 r
.54123 .14719 m
.54168 .18957 L
s
.494 .284 1 r
.47203 .18768 m
.47186 .19642 L
s
.47188 .19637 m
.47203 .18768 L
s
.47203 .18768 m
.47177 .20486 L
s
.68 .237 1 r
.56444 .21917 m
.56437 .21952 L
s
.57 .264 1 r
.38052 .20219 m
.3801 .2112 L
s
.38018 .2107 m
.38052 .20219 L
s
.3801 .2112 m
.38053 .20214 L
s
.38053 .20214 m
.38018 .2107 L
s
.669 .239 1 r
.77437 .18961 m
.77506 .19883 L
s
.77509 .19878 m
.77437 .18961 L
s
.77437 .18961 m
.77582 .20773 L
s
.405 .662 1 r
.71936 .1469 m
.7218 .18315 L
s
.701 .232 1 r
.39007 .1469 m
.38833 .19273 L
s
.916 .184 1 r
.75315 .20933 m
.75383 .21901 L
s
.7539 .21901 m
.75315 .20933 L
s
.722 .227 1 r
.53748 .22127 m
.53741 .22131 L
s
.916 .184 1 r
.75383 .21901 m
.75318 .20928 L
s
.75318 .20928 m
.7539 .21901 L
s
.589 .259 1 r
.65018 .18769 m
.6505 .19674 L
s
.65053 .19669 m
.65018 .18769 L
s
.65018 .18769 m
.6509 .20534 L
s
.503 .282 1 r
.73679 .20131 m
.73737 .21009 L
s
.73741 .20974 m
.73679 .20131 L
s
.723 .226 1 r
.5682 .1466 m
.56905 .1909 L
s
.503 .282 1 r
.73737 .21009 m
.73682 .20126 L
s
.73682 .20126 m
.73741 .20974 L
s
.648 .244 1 r
.53168 .20369 m
.53169 .21286 L
s
.53175 .21251 m
.53168 .20369 L
s
.352 .327 1 r
.39687 .21117 m
.3968 .21151 L
s
.648 .244 1 r
.44022 .21794 m
.44014 .21828 L
s
.53169 .21286 m
.5317 .20364 L
s
.5317 .20364 m
.53175 .21251 L
s
.618 .252 1 r
.28901 .21727 m
.28892 .21762 L
s
.56 .267 1 r
.46717 .21661 m
.46711 .21684 L
s
.503 .282 1 r
.34777 .18677 m
.34726 .19555 L
s
.34727 .19551 m
.34777 .18677 L
s
.34777 .18677 m
.34684 .20399 L
s
.74639 .14631 m
.74957 .1883 L
s
.441 .3 1 r
.417 .14631 m
.41579 .18792 L
s
.467 .292 1 r
.34292 .2146 m
.34284 .21479 L
s
.68 .237 1 r
.6184 .21765 m
.61835 .21812 L
s
.383 .566 1 r
.75807 .18247 m
.7586 .19017 L
s
.75863 .19013 m
.75807 .18247 L
s
.75807 .18247 m
.75921 .19768 L
s
.347 .402 1 r
.57988 .18325 m
.58 .19137 L
s
.58002 .19133 m
.57988 .18325 L
s
.57988 .18325 m
.58018 .19912 L
s
.365 .486 1 r
.36407 .19538 m
.36366 .2033 L
s
.36373 .20296 m
.36407 .19538 L
s
.36366 .2033 m
.36408 .19534 L
s
.36408 .19534 m
.36373 .20296 L
s
.467 .292 1 r
.43439 .20074 m
.43413 .20936 L
s
.4342 .20917 m
.43439 .20074 L
s
.618 .252 1 r
.59519 .14601 m
.59639 .18955 L
s
.467 .292 1 r
.43413 .20936 m
.4344 .20069 L
s
.4344 .20069 m
.4342 .20917 L
s
.588 .259 1 r
.6772 .18745 m
.6776 .19647 L
s
.67763 .19642 m
.6772 .18745 L
s
.6772 .18745 m
.67808 .20514 L
s
.38 .554 1 r
.50472 .20622 m
.50467 .20655 L
s
.88 .191 1 r
.62327 .19064 m
.62354 .20037 L
s
.62356 .20031 m
.62327 .19064 L
s
.62327 .19064 m
.62389 .20974 L
s
.433 .302 1 r
.63958 .19897 m
.63988 .20755 L
s
.63993 .20717 m
.63958 .19897 L
s
.799 .209 1 r
.77343 .14572 m
.7773 .19156 L
s
.344 .33 1 r
.44394 .14572 m
.44312 .1858 L
s
.433 .302 1 r
.63988 .20755 m
.6396 .19892 L
s
.6396 .19892 m
.63993 .20717 L
s
.503 .282 1 r
.36985 .21403 m
.36977 .21438 L
s
.433 .302 1 r
.54808 .21337 m
.54802 .21352 L
s
.424 .305 1 r
.73117 .18494 m
.7317 .19349 L
s
.73172 .19344 m
.73117 .18494 L
s
.73117 .18494 m
.73229 .20169 L
s
.702 .231 1 r
.40739 .20314 m
.40704 .21246 L
s
.40712 .21203 m
.40739 .20314 L
s
.766 .217 1 r
.62219 .14542 m
.62384 .19088 L
s
.702 .231 1 r
.40704 .21246 m
.40741 .20309 L
s
.40741 .20309 m
.40712 .21203 L
s
1 .138 .854 r
.62902 .20939 m
.62935 .21966 L
s
.62941 .2193 m
.62902 .20939 L
s
.531 .274 1 r
.55294 .18613 m
.55299 .19499 L
s
.55301 .19494 m
.55294 .18613 L
s
.55294 .18613 m
.55312 .20351 L
s
.46134 .20047 m
.46115 .20932 L
s
.46122 .20898 m
.46134 .20047 L
s
1 .138 .854 r
.62935 .21966 m
.62905 .20934 L
s
.62905 .20934 m
.62941 .2193 L
s
.342 .378 1 r
.54228 .19601 m
.54232 .20416 L
s
.54237 .20382 m
.54228 .19601 L
s
.531 .274 1 r
.46115 .20932 m
.46136 .20042 L
s
.46136 .20042 m
.46122 .20898 L
s
.342 .378 1 r
.54232 .20416 m
.5423 .19596 L
s
.5423 .19596 m
.54237 .20382 L
s
.723 .226 1 r
.58566 .20285 m
.58583 .21225 L
s
.58589 .21175 m
.58566 .20285 L
s
.459 .295 1 r
.31003 .19988 m
.30944 .20846 L
s
.30952 .20831 m
.31003 .19988 L
s
.81 .206 1 r
.74276 .22156 m
.7427 .22157 L
s
.496 .284 1 r
.33703 .19839 m
.33649 .20724 L
s
.33659 .20659 m
.33703 .19839 L
s
.531 .274 1 r
.47091 .14513 m
.47041 .18752 L
s
.723 .226 1 r
.58583 .21225 m
.58568 .2028 L
s
.58568 .2028 m
.58589 .21175 L
s
.459 .295 1 r
.30944 .20846 m
.31005 .19983 L
s
.31005 .19983 m
.30952 .20831 L
s
.496 .284 1 r
.33649 .20724 m
.33704 .19834 L
s
.33704 .19834 m
.33659 .20659 L
s
.712 .229 1 r
.49414 .21718 m
.49407 .21764 L
s
.383 .317 1 r
.42861 .18455 m
.42833 .19291 L
s
.42834 .19286 m
.42861 .18455 L
s
.42861 .18455 m
.42813 .20112 L
s
.648 .244 1 r
.64921 .14483 m
.65118 .18876 L
s
.68 .237 1 r
.67245 .21689 m
.6724 .21724 L
s
.916 .184 1 r
.71002 .20584 m
.71058 .21564 L
s
.71063 .21529 m
.71002 .20584 L
s
.648 .244 1 r
.52596 .18864 m
.52593 .1977 L
s
.52596 .19765 m
.52596 .18864 L
s
.52596 .18864 m
.52599 .20677 L
s
.766 .217 1 r
.64547 .21861 m
.64541 .21892 L
s
.916 .184 1 r
.71058 .21564 m
.71005 .20579 L
s
.71005 .20579 m
.71063 .21529 L
s
.942 .178 1 r
.76983 .22099 m
.7698 .22143 L
s
.892 .189 1 r
.49789 .14454 m
.49772 .19193 L
s
.342 .378 1 r
.32637 .20917 m
.32631 .20928 L
s
.691 .234 1 r
.69947 .21594 m
.69943 .21644 L
s
.754 .219 1 r
.31578 .21899 m
.3157 .21915 L
s
.375 .32 1 r
.63393 .18303 m
.63419 .19143 L
s
.63421 .19139 m
.63393 .18303 L
s
.63393 .18303 m
.63452 .19949 L
s
.629 .249 1 r
.3746 .18842 m
.37414 .19742 L
s
.37416 .19737 m
.3746 .18842 L
s
.3746 .18842 m
.37377 .20648 L
s
.395 .62 1 r
.67624 .14424 m
.67819 .18051 L
s
.569 .264 1 r
.4883 .20081 m
.48819 .20971 L
s
.48826 .20955 m
.4883 .20081 L
s
.48819 .20971 m
.48832 .20076 L
s
.48832 .20076 m
.48826 .20955 L
s
.658 .242 1 r
.52488 .14395 m
.52511 .18865 L
s
.352 .327 1 r
.68312 .2086 m
.68307 .20894 L
s
.916 .184 1 r
.70437 .18914 m
.70489 .19894 L
s
.70492 .19889 m
.70437 .18914 L
s
.70437 .18914 m
.70549 .2084 L
s
.788 .211 1 r
.79112 .20291 m
.79191 .21243 L
s
.79194 .21204 m
.79112 .20291 L
s
.485 .287 1 r
.45556 .18487 m
.45534 .19355 L
s
.45537 .1935 m
.45556 .18487 L
s
.45556 .18487 m
.45521 .20207 L
s
.424 .305 1 r
.56931 .19695 m
.56942 .20549 L
s
.56947 .20515 m
.56931 .19695 L
s
.822 .204 1 r
.70329 .14365 m
.70618 .19028 L
s
.63 .249 1 r
.37347 .14365 m
.37163 .18681 L
s
.788 .211 1 r
.79191 .21243 m
.79115 .20285 L
s
.79115 .20285 m
.79194 .21204 L
s
.424 .305 1 r
.56942 .20549 m
.56933 .1969 L
s
.56933 .1969 m
.56947 .20515 L
s
.845 .199 1 r
.61271 .2038 m
.61297 .21344 L
s
.61303 .21309 m
.61271 .2038 L
s
.61297 .21344 m
.61274 .20375 L
s
.61274 .20375 m
.61303 .21309 L
s
.765 .217 1 r
.52112 .21814 m
.52105 .21833 L
s
.588 .259 1 r
.60214 .21375 m
.60208 .2141 L
s
.559 .267 1 r
.78058 .21308 m
.78054 .21343 L
s
.357 .45 1 r
.55189 .14336 m
.55242 .18154 L
s
.669 .239 1 r
.57514 .21547 m
.57508 .21578 L
s
.608 .254 1 r
.4237 .2148 m
.42362 .21499 L
s
.335 .341 1 r
.55873 .20736 m
.55868 .2077 L
s
.494 .285 1 r
.73036 .14306 m
.73336 .18546 L
s
.569 .264 1 r
.40044 .14306 m
.39894 .18661 L
s
.929 .181 1 r
.79703 .22196 m
.79695 .22189 L
s
.669 .239 1 r
.5153 .20114 m
.51527 .21032 L
s
.51533 .21012 m
.5153 .20114 L
s
.51527 .21032 m
.51533 .20109 L
s
.51533 .20109 m
.51533 .21012 L
s
.383 .317 1 r
.44487 .19609 m
.44465 .20444 L
s
.44471 .20429 m
.44487 .19609 L
s
1 .106 .673 r
.57891 .14276 m
.58007 .19441 L
s
.551 .269 1 r
.6562 .21184 m
.65615 .21227 L
s
.383 .317 1 r
.44465 .20444 m
.44488 .19604 L
s
.44488 .19604 m
.44471 .20429 L
s
.37 .509 1 r
.32039 .194 m
.31988 .2017 L
s
.31993 .2019 m
.32039 .194 L
s
.31988 .2017 m
.3204 .19396 L
s
.3204 .19396 m
.31993 .2019 L
s
.522 .277 1 r
.41785 .19788 m
.41754 .2067 L
s
.41761 .2064 m
.41785 .19788 L
s
.649 .244 1 r
.33107 .18438 m
.33048 .19359 L
s
.3305 .19354 m
.33107 .18438 L
s
.33107 .18438 m
.33 .20235 L
s
.477 .289 1 r
.53659 .18215 m
.53659 .1909 L
s
.53661 .19085 m
.53659 .18215 L
s
.53659 .18215 m
.53667 .19919 L
s
.522 .277 1 r
.41754 .2067 m
.41787 .19783 L
s
.41787 .19783 m
.41761 .2064 L
s
.523 .277 1 r
.59636 .19728 m
.59655 .20615 L
s
.59661 .20572 m
.59636 .19728 L
s
.845 .199 1 r
.75744 .14247 m
.76111 .18872 L
s
.54 .272 1 r
.42743 .14247 m
.42631 .18564 L
s
.952 .176 1 r
.4015 .18981 m
.40109 .19958 L
s
.40111 .19953 m
.4015 .18981 L
s
.4015 .18981 m
.40077 .20935 L
s
.523 .277 1 r
.59655 .20615 m
.59638 .19724 L
s
.59638 .19724 m
.59661 .20572 L
s
.846 .199 1 r
.72667 .21767 m
.72663 .21802 L
s
.335 .341 1 r
.49889 .19371 m
.49882 .20195 L
s
.49888 .20161 m
.49889 .19371 L
s
.49882 .20195 m
.49891 .19367 L
s
.49891 .19367 m
.49888 .20161 L
s
.522 .277 1 r
.35806 .18327 m
.35757 .1921 L
s
.35759 .19205 m
.35806 .18327 L
s
.35806 .18327 m
.35717 .20062 L
s
.88 .191 1 r
.66682 .20296 m
.66725 .21268 L
s
.6673 .21233 m
.66682 .20296 L
s
.733 .224 1 r
.69384 .20147 m
.69433 .2108 L
s
.69439 .2106 m
.69384 .20147 L
s
.869 .194 1 r
.78559 .18721 m
.78635 .1969 L
s
.78638 .19685 m
.78559 .18721 L
s
.78559 .18721 m
.78718 .20628 L
s
.88 .191 1 r
.66725 .21268 m
.66685 .2029 L
s
.66685 .2029 m
.6673 .21233 L
s
.503 .282 1 r
.60596 .14217 m
.60729 .18535 L
s
.701 .232 1 r
.45067 .21499 m
.4506 .2153 L
s
.733 .224 1 r
.69433 .2108 m
.69387 .20141 L
s
.69387 .20141 m
.69439 .2106 L
s
.978 .171 1 r
.60706 .18818 m
.60728 .19811 L
s
.60731 .19805 m
.60706 .18818 L
s
.60706 .18818 m
.60759 .20772 L
s
.521 .277 1 r
.35317 .21165 m
.3531 .21184 L
s
.799 .209 1 r
.45443 .14187 m
.45363 .18813 L
s
.68 .237 1 r
.68815 .18402 m
.68859 .19332 L
s
.68862 .19327 m
.68815 .18402 L
s
.68815 .18402 m
.68911 .20215 L
s
.649 .244 1 r
.47769 .21404 m
.47762 .21428 L
s
.638 .247 1 r
.74793 .1991 m
.74857 .20823 L
s
.74861 .20792 m
.74793 .1991 L
s
.74857 .20823 m
.74796 .19905 L
s
.74796 .19905 m
.74861 .20792 L
s
.733 .224 1 r
.2991 .21509 m
.29901 .2154 L
s
.494 .284 1 r
.47186 .19642 m
.4717 .20517 L
s
.47177 .20486 m
.47186 .19642 L
s
.733 .224 1 r
.50957 .18515 m
.5095 .19452 L
s
.50952 .19447 m
.50957 .18515 L
s
.50957 .18515 m
.50951 .20359 L
s
.754 .219 1 r
.63301 .14158 m
.63483 .18745 L
s
.494 .284 1 r
.4717 .20517 m
.47188 .19637 L
s
.47188 .19637 m
.47177 .20486 L
s
.57 .264 1 r
.38018 .2107 m
.3801 .2112 L
s
.811 .206 1 r
.72095 .20119 m
.72153 .21076 L
s
.72158 .21041 m
.72095 .20119 L
s
.72153 .21076 m
.72097 .20114 L
s
.72097 .20114 m
.72158 .21041 L
s
.881 .191 1 r
.66116 .1863 m
.66154 .19603 L
s
.66157 .19598 m
.66116 .1863 L
s
.66116 .1863 m
.66201 .20541 L
s
.765 .217 1 r
.48144 .14128 m
.48105 .18716 L
s
.383 .566 1 r
.7586 .19017 m
.75917 .19786 L
s
.75921 .19768 m
.7586 .19017 L
s
.75917 .19786 m
.75863 .19013 L
s
.75863 .19013 m
.75921 .19768 L
s
.365 .486 1 r
.36373 .20296 m
.36366 .2033 L
s
.503 .282 1 r
.73741 .20974 m
.73737 .21009 L
s
.845 .199 1 r
.48254 .18739 m
.48238 .19693 L
s
.4824 .19688 m
.48254 .18739 L
s
.48254 .18739 m
.48231 .20647 L
s
.649 .244 1 r
.56364 .18293 m
.56373 .19215 L
s
.56375 .19209 m
.56364 .18293 L
s
.56364 .18293 m
.56389 .2009 L
s
.669 .239 1 r
.77506 .19883 m
.77578 .20804 L
s
.77582 .20773 m
.77506 .19883 L
s
.559 .267 1 r
.41204 .1823 m
.41169 .19124 L
s
.41171 .19119 m
.41204 .1823 L
s
.41204 .1823 m
.41144 .19985 L
s
.347 .402 1 r
.58 .19137 m
.58013 .19949 L
s
.58018 .19912 m
.58 .19137 L
s
.648 .244 1 r
.66008 .14099 m
.66221 .18494 L
s
1 .118 .744 r
.76445 .20866 m
.76521 .21899 L
s
.7653 .21913 m
.76445 .20866 L
s
.669 .239 1 r
.77578 .20804 m
.77509 .19878 L
s
.77509 .19878 m
.77582 .20773 L
s
.347 .402 1 r
.58013 .19949 m
.58002 .19133 L
s
.58002 .19133 m
.58018 .19912 L
s
1 .118 .744 r
.76521 .21899 m
.76448 .2086 L
s
.76448 .2086 m
.7653 .21913 L
s
.589 .259 1 r
.6505 .19674 m
.65085 .2058 L
s
.6509 .20534 m
.6505 .19674 L
s
.648 .244 1 r
.53175 .21251 m
.53169 .21286 L
s
.589 .259 1 r
.65085 .2058 m
.65053 .19669 L
s
.65053 .19669 m
.6509 .20534 L
s
.503 .282 1 r
.34726 .19555 m
.34675 .20434 L
s
.34684 .20399 m
.34726 .19555 L
s
.765 .217 1 r
.50848 .14069 m
.50848 .18657 L
s
.503 .282 1 r
.34675 .20434 m
.34727 .19551 L
s
.34727 .19551 m
.34684 .20399 L
s
.467 .292 1 r
.4342 .20917 m
.43413 .20936 L
s
.916 .184 1 r
.7539 .21901 m
.75383 .21901 L
s
.433 .302 1 r
.63993 .20717 m
.63988 .20755 L
s
.68 .237 1 r
.74235 .1832 m
.74295 .19246 L
s
.74298 .19241 m
.74235 .1832 L
s
.74235 .1832 m
.74363 .20138 L
s
.45 .297 1 r
.68717 .14039 m
.68953 .18166 L
s
.521 .277 1 r
.43905 .18187 m
.43878 .19066 L
s
.4388 .19061 m
.43905 .18187 L
s
.43905 .18187 m
.4386 .19927 L
s
.648 .244 1 r
.59071 .18269 m
.59087 .19187 L
s
.59089 .19182 m
.59071 .18269 L
s
.59071 .18269 m
.59111 .20071 L
s
.342 .378 1 r
.54237 .20382 m
.54232 .20416 L
s
.433 .302 1 r
.46608 .18065 m
.4659 .18917 L
s
.46592 .18912 m
.46608 .18065 L
s
.46608 .18065 m
.46579 .19754 L
s
.588 .259 1 r
.6776 .19647 m
.67803 .20549 L
s
.67808 .20514 m
.6776 .19647 L
s
.869 .194 1 r
.71534 .18518 m
.71589 .19488 L
s
.71592 .19482 m
.71534 .18518 L
s
.71534 .18518 m
.71651 .20426 L
s
.424 .305 1 r
.7317 .19349 m
.73225 .20204 L
s
.73229 .20169 m
.7317 .19349 L
s
1 .156 .946 r
.53552 .14009 m
.53595 .18868 L
s
.588 .259 1 r
.67803 .20549 m
.67763 .19642 L
s
.67763 .19642 m
.67808 .20514 L
s
.424 .305 1 r
.73225 .20204 m
.73172 .19344 L
s
.73172 .19344 m
.73229 .20169 L
s
.496 .284 1 r
.33659 .20659 m
.33649 .20724 L
s
.559 .267 1 r
.71428 .1398 m
.71716 .18376 L
s
.811 .206 1 r
.38383 .1398 m
.38203 .1853 L
s
.531 .274 1 r
.46122 .20898 m
.46115 .20932 L
s
.702 .231 1 r
.40712 .21203 m
.40704 .21246 L
s
.459 .295 1 r
.30952 .20831 m
.30944 .20846 L
s
.531 .274 1 r
.55299 .19499 m
.55306 .20386 L
s
.55312 .20351 m
.55299 .19499 L
s
.767 .216 1 r
.76951 .18299 m
.77021 .19249 L
s
.77023 .19244 m
.76951 .18299 L
s
.76951 .18299 m
.77097 .20156 L
s
.531 .274 1 r
.55306 .20386 m
.55301 .19494 L
s
.55301 .19494 m
.55312 .20351 L
s
.88 .191 1 r
.62354 .20037 m
.62383 .21009 L
s
.62389 .20974 m
.62354 .20037 L
s
.68 .237 1 r
.6178 .18233 m
.61803 .19159 L
s
.61806 .19154 m
.6178 .18233 L
s
.6178 .18233 m
.61836 .20051 L
s
.383 .317 1 r
.42833 .19291 m
.42806 .20127 L
s
.42813 .20112 m
.42833 .19291 L
s
.88 .191 1 r
.62383 .21009 m
.62356 .20031 L
s
.62356 .20031 m
.62389 .20974 L
s
.56259 .1395 m
.5634 .18616 L
s
.383 .317 1 r
.42806 .20127 m
.42834 .19286 L
s
.42834 .19286 m
.42813 .20112 L
s
.723 .226 1 r
.58589 .21175 m
.58583 .21225 L
s
.477 .289 1 r
.3414 .17958 m
.34087 .1883 L
s
.34089 .18825 m
.3414 .17958 L
s
.3414 .17958 m
.34044 .19667 L
s
.702 .231 1 r
.38488 .18644 m
.38445 .19548 L
s
.38447 .19543 m
.38488 .18644 L
s
.38488 .18644 m
.38409 .20503 L
s
.391 .315 1 r
.7414 .1392 m
.74441 .17972 L
s
.638 .247 1 r
.41086 .1392 m
.40949 .18317 L
s
.375 .32 1 r
.63419 .19143 m
.63447 .19983 L
s
.63452 .19949 m
.63419 .19143 L
s
.63447 .19983 m
.63421 .19139 L
s
.63421 .19139 m
.63452 .19949 L
s
1 .138 .854 r
.62941 .2193 m
.62935 .21966 L
s
.4 .312 1 r
.54725 .17803 m
.54728 .18651 L
s
.5473 .18646 m
.54725 .17803 L
s
.54725 .17803 m
.54739 .19465 L
s
1 .166 .998 r
.58967 .13891 m
.59092 .1875 L
s
.648 .244 1 r
.52593 .1977 m
.52593 .20677 L
s
.52599 .20677 m
.52593 .1977 L
s
.569 .264 1 r
.49312 .1812 m
.493 .19011 L
s
.49303 .19006 m
.49312 .1812 L
s
.49312 .1812 m
.49297 .19887 L
s
.648 .244 1 r
.52593 .20677 m
.52596 .19765 L
s
.52596 .19765 m
.52599 .20677 L
s
.476 .29 1 r
.69903 .179 m
.69948 .18772 L
s
.6995 .18767 m
.69903 .179 L
s
.69903 .179 m
.69999 .19609 L
s
.44 .8 1 r
.35196 .17092 m
.35154 .17812 L
s
.35156 .17808 m
.35196 .17092 L
s
.35196 .17092 m
.35122 .18487 L
s
.916 .184 1 r
.71063 .21529 m
.71058 .21564 L
s
.4 .312 1 r
.72611 .17774 m
.72662 .18622 L
s
.72664 .18617 m
.72611 .17774 L
s
.72611 .17774 m
.72719 .19436 L
s
1 .161 .972 r
.76853 .13861 m
.77253 .18682 L
s
.531 .274 1 r
.4379 .13861 m
.43694 .18105 L
s
.629 .249 1 r
.37414 .19742 m
.37371 .20641 L
s
.37377 .20648 m
.37414 .19742 L
s
.37371 .20641 m
.37416 .19737 L
s
.37416 .19737 m
.37377 .20648 L
s
.569 .264 1 r
.48826 .20955 m
.48819 .20971 L
s
.424 .305 1 r
.56947 .20515 m
.56942 .20549 L
s
.811 .206 1 r
.64493 .18266 m
.64526 .19223 L
s
.64529 .19218 m
.64493 .18266 L
s
.64493 .18266 m
.64567 .20146 L
s
.579 .262 1 r
.61676 .13831 m
.61825 .18113 L
s
.485 .287 1 r
.45534 .19355 m
.45515 .20222 L
s
.45521 .20207 m
.45534 .19355 L
s
.45515 .20222 m
.45537 .1935 L
s
.45537 .1935 m
.45521 .20207 L
s
.513 .279 1 r
.39545 .1786 m
.39506 .18744 L
s
.39508 .18739 m
.39545 .1786 L
s
.39545 .1786 m
.39477 .19589 L
s
.701 .232 1 r
.46495 .13801 m
.46433 .18314 L
s
.788 .211 1 r
.79194 .21204 m
.79191 .21243 L
s
.942 .178 1 r
.64387 .13772 m
.64591 .18477 L
s
.37 .509 1 r
.31993 .2019 m
.31988 .2017 L
s
.845 .199 1 r
.61303 .21309 m
.61297 .21344 L
s
.916 .184 1 r
.70489 .19894 m
.70544 .20875 L
s
.70549 .2084 m
.70489 .19894 L
s
.70544 .20875 m
.70492 .19889 L
s
.70492 .19889 m
.70549 .2084 L
s
.383 .317 1 r
.44471 .20429 m
.44465 .20444 L
s
.618 .252 1 r
.49202 .13742 m
.4918 .18102 L
s
.335 .341 1 r
.49888 .20161 m
.49882 .20195 L
s
.892 .189 1 r
.671 .13712 m
.67346 .18457 L
s
.669 .239 1 r
.51533 .21012 m
.51527 .21032 L
s
.522 .277 1 r
.41761 .2064 m
.41754 .2067 L
s
.523 .277 1 r
.59661 .20572 m
.59655 .20615 L
s
.99 .169 1 r
.67211 .18321 m
.67254 .19318 L
s
.67257 .19312 m
.67211 .18321 L
s
.67211 .18321 m
.67305 .2028 L
s
.477 .289 1 r
.53659 .1909 m
.53661 .19965 L
s
.53667 .19919 m
.53659 .1909 L
s
.53661 .19965 m
.53661 .19085 L
s
.53661 .19085 m
.53667 .19919 L
s
.441 .3 1 r
.51911 .13682 m
.51925 .17851 L
s
.766 .217 1 r
.5202 .18296 m
.52015 .19227 L
s
.52018 .19222 m
.5202 .18296 L
s
.5202 .18296 m
.5202 .20174 L
s
.649 .244 1 r
.33048 .19359 m
.3299 .20281 L
s
.33 .20235 m
.33048 .19359 L
s
.522 .277 1 r
.35757 .1921 m
.35709 .20093 L
s
.35717 .20062 m
.35757 .1921 L
s
.649 .244 1 r
.3299 .20281 m
.3305 .19354 L
s
.3305 .19354 m
.33 .20235 L
s
.522 .277 1 r
.35709 .20093 m
.35759 .19205 L
s
.35759 .19205 m
.35717 .20062 L
s
.618 .252 1 r
.60149 .17867 m
.60168 .18778 L
s
.6017 .18773 m
.60149 .17867 L
s
.60149 .17867 m
.60195 .19655 L
s
.711 .229 1 r
.69814 .13653 m
.70086 .18128 L
s
.383 .566 1 r
.75921 .19768 m
.75917 .19786 L
s
.733 .224 1 r
.69439 .2106 m
.69433 .2108 L
s
.669 .239 1 r
.42245 .1798 m
.42212 .18899 L
s
.42214 .18894 m
.42245 .1798 L
s
.42245 .1798 m
.42189 .19799 L
s
.811 .206 1 r
.57441 .18062 m
.57453 .1902 L
s
.57455 .19014 m
.57441 .18062 L
s
.57441 .18062 m
.57473 .19943 L
s
.66 .241 1 r
.54621 .13623 m
.54674 .17983 L
s
.952 .176 1 r
.40109 .19958 m
.4007 .20936 L
s
.40077 .20935 m
.40109 .19958 L
s
.88 .191 1 r
.6673 .21233 m
.66725 .21268 L
s
.578 .262 1 r
.44954 .17853 m
.4493 .18749 L
s
.44932 .18744 m
.44954 .17853 L
s
.44954 .17853 m
.44914 .19626 L
s
.494 .284 1 r
.47177 .20486 m
.4717 .20517 L
s
.952 .176 1 r
.4007 .20936 m
.40111 .19953 L
s
.40111 .19953 m
.40077 .20935 L
s
.638 .247 1 r
.74861 .20792 m
.74857 .20823 L
s
.669 .239 1 r
.75348 .18014 m
.7541 .1893 L
s
.75413 .18925 m
.75348 .18014 L
s
.75348 .18014 m
.75482 .19838 L
s
.869 .194 1 r
.78635 .1969 m
.78714 .2066 L
s
.78718 .20628 m
.78635 .1969 L
s
.347 .402 1 r
.58018 .19912 m
.58013 .19949 L
s
.869 .194 1 r
.78714 .2066 m
.78638 .19685 L
s
.78638 .19685 m
.78718 .20628 L
s
.442 .299 1 r
.7253 .13593 m
.72814 .17685 L
s
.413 .693 1 r
.39423 .13593 m
.39292 .17187 L
s
.68 .237 1 r
.68859 .19332 m
.68906 .20262 L
s
.68911 .20215 m
.68859 .19332 L
s
.68906 .20262 m
.68862 .19327 L
s
.68862 .19327 m
.68911 .20215 L
s
.503 .282 1 r
.47663 .17757 m
.47647 .1863 L
s
.47649 .18625 m
.47663 .17757 L
s
.47663 .17757 m
.47639 .19491 L
s
.701 .232 1 r
.78062 .1791 m
.78134 .18841 L
s
.78137 .18836 m
.78062 .1791 L
s
.78062 .1791 m
.78213 .19741 L
s
.892 .189 1 r
.36821 .18362 m
.36771 .19321 L
s
.36773 .19315 m
.36821 .18362 L
s
.36821 .18362 m
.36728 .20299 L
s
.978 .171 1 r
.60728 .19811 m
.60753 .20804 L
s
.60759 .20772 m
.60728 .19811 L
s
.60753 .20804 m
.60731 .19805 L
s
.60731 .19805 m
.60759 .20772 L
s
.744 .221 1 r
.57333 .13563 m
.57427 .18078 L
s
.733 .224 1 r
.5095 .19452 m
.50944 .20391 L
s
.50951 .20359 m
.5095 .19452 L
s
.50944 .20391 m
.50952 .19447 L
s
.50952 .19447 m
.50951 .20359 L
s
.811 .206 1 r
.72158 .21041 m
.72153 .21076 L
s
.477 .289 1 r
.53085 .17515 m
.53084 .18391 L
s
.53086 .18387 m
.53085 .17515 L
s
.53085 .17515 m
.53091 .19222 L
s
.629 .249 1 r
.65576 .17747 m
.65611 .18662 L
s
.65614 .18657 m
.65576 .17747 L
s
.65576 .17747 m
.65653 .19539 L
s
.589 .259 1 r
.6509 .20534 m
.65085 .2058 L
s
.711 .229 1 r
.75247 .13533 m
.75597 .1801 L
s
.733 .224 1 r
.42131 .13533 m
.42002 .18164 L
s
.669 .239 1 r
.77582 .20773 m
.77578 .20804 L
s
.559 .267 1 r
.41169 .19124 m
.41136 .20019 L
s
.41144 .19985 m
.41169 .19124 L
s
.503 .282 1 r
.34684 .20399 m
.34675 .20434 L
s
.559 .267 1 r
.41136 .20019 m
.41171 .19119 L
s
.41171 .19119 m
.41144 .19985 L
s
.649 .244 1 r
.56373 .19215 m
.56383 .20137 L
s
.56389 .2009 m
.56373 .19215 L
s
.56383 .20137 m
.56375 .19209 L
s
.56375 .19209 m
.56389 .2009 L
s
.881 .191 1 r
.66154 .19603 m
.66195 .20577 L
s
.66201 .20541 m
.66154 .19603 L
s
.811 .206 1 r
.62868 .17945 m
.62896 .18903 L
s
.62898 .18898 m
.62868 .17945 L
s
.62868 .17945 m
.62932 .19827 L
s
.881 .191 1 r
.66195 .20577 m
.66157 .19598 L
s
.66157 .19598 m
.66201 .20541 L
s
.618 .252 1 r
.60046 .13504 m
.60175 .17865 L
s
.845 .199 1 r
.48238 .19693 m
.48224 .20648 L
s
.48231 .20647 m
.48238 .19693 L
s
.48224 .20648 m
.4824 .19688 L
s
.4824 .19688 m
.48231 .20647 L
s
.424 .305 1 r
.73229 .20169 m
.73225 .20204 L
s
.618 .252 1 r
.4484 .13474 m
.44757 .17836 L
s
.521 .277 1 r
.43878 .19066 m
.43853 .19946 L
s
.4386 .19927 m
.43878 .19066 L
s
.433 .302 1 r
.4659 .18917 m
.46573 .19769 L
s
.46579 .19754 m
.4659 .18917 L
s
.711 .229 1 r
.50374 .17789 m
.50365 .18724 L
s
.50367 .18719 m
.50374 .17789 L
s
.50374 .17789 m
.50365 .19625 L
s
.521 .277 1 r
.43853 .19946 m
.4388 .19061 L
s
.4388 .19061 m
.4386 .19927 L
s
.433 .302 1 r
.46573 .19769 m
.46592 .18912 L
s
.46592 .18912 m
.46579 .19754 L
s
.588 .259 1 r
.67808 .20514 m
.67803 .20549 L
s
.416 .307 1 r
.37876 .17581 m
.37835 .18423 L
s
.37836 .18418 m
.37876 .17581 L
s
.37876 .17581 m
.37801 .19269 L
s
.68 .237 1 r
.74295 .19246 m
.74359 .20173 L
s
.74363 .20138 m
.74295 .19246 L
s
.598 .257 1 r
.62761 .13444 m
.62928 .17845 L
s
.68 .237 1 r
.74359 .20173 m
.74298 .19241 L
s
.74298 .19241 m
.74363 .20138 L
s
.648 .244 1 r
.59087 .19187 m
.59105 .20105 L
s
.59111 .20071 m
.59087 .19187 L
s
.59105 .20105 m
.59089 .19182 L
s
.59089 .19182 m
.59111 .20071 L
s
1 .118 .744 r
.7653 .21913 m
.76521 .21899 L
s
.383 .317 1 r
.42813 .20112 m
.42806 .20127 L
s
.638 .247 1 r
.47551 .13414 m
.47503 .1793 L
s
.531 .274 1 r
.55312 .20351 m
.55306 .20386 L
s
.618 .252 1 r
.558 .1757 m
.55806 .18485 L
s
.55808 .1848 m
.558 .1757 L
s
.558 .1757 m
.55821 .19355 L
s
.551 .269 1 r
.73724 .17499 m
.73781 .18395 L
s
.73784 .1839 m
.73724 .17499 L
s
.73724 .17499 m
.73844 .19249 L
s
.44 .8 1 r
.35154 .17812 m
.35114 .18531 L
s
.35122 .18487 m
.35154 .17812 L
s
.955 .176 1 r
.68301 .17816 m
.68347 .18817 L
s
.6835 .18812 m
.68301 .17816 L
s
.68301 .17816 m
.684 .19749 L
s
.44 .8 1 r
.35114 .18531 m
.35156 .17808 L
s
.35156 .17808 m
.35122 .18487 L
s
.869 .194 1 r
.71589 .19488 m
.71647 .20458 L
s
.71651 .20426 m
.71589 .19488 L
s
.71647 .20458 m
.71592 .19482 L
s
.71592 .19482 m
.71651 .20426 L
s
.702 .231 1 r
.65478 .13384 m
.65683 .17747 L
s
.375 .32 1 r
.63452 .19949 m
.63447 .19983 L
s
.477 .289 1 r
.34087 .1883 m
.34035 .19701 L
s
.34044 .19667 m
.34087 .1883 L
s
.34035 .19701 m
.34089 .18825 L
s
.34089 .18825 m
.34044 .19667 L
s
.68 .237 1 r
.61803 .19159 m
.6183 .20086 L
s
.61836 .20051 m
.61803 .19159 L
s
.845 .199 1 r
.50264 .13354 m
.50256 .17987 L
s
.68 .237 1 r
.6183 .20086 m
.61806 .19154 L
s
.61806 .19154 m
.61836 .20051 L
s
.88 .191 1 r
.62389 .20974 m
.62383 .21009 L
s
.702 .231 1 r
.38445 .19548 m
.38404 .20453 L
s
.38409 .20503 m
.38445 .19548 L
s
.767 .216 1 r
.77021 .19249 m
.77093 .202 L
s
.77097 .20156 m
.77021 .19249 L
s
.4 .312 1 r
.54728 .18651 m
.54734 .19499 L
s
.54739 .19465 m
.54728 .18651 L
s
.702 .231 1 r
.38404 .20453 m
.38447 .19543 L
s
.38447 .19543 m
.38409 .20503 L
s
.767 .216 1 r
.77093 .202 m
.77023 .19244 L
s
.77023 .19244 m
.77097 .20156 L
s
.4 .312 1 r
.54734 .19499 m
.5473 .18646 L
s
.5473 .18646 m
.54739 .19465 L
s
.588 .259 1 r
.68196 .13324 m
.68436 .17649 L
s
.476 .29 1 r
.69948 .18772 m
.69995 .19643 L
s
.69999 .19609 m
.69948 .18772 L
s
.4 .312 1 r
.72662 .18622 m
.72715 .1947 L
s
.72719 .19436 m
.72662 .18622 L
s
.476 .29 1 r
.69995 .19643 m
.6995 .18767 L
s
.6995 .18767 m
.69999 .19609 L
s
.4 .312 1 r
.72715 .1947 m
.72664 .18617 L
s
.72664 .18617 m
.72719 .19436 L
s
.569 .264 1 r
.493 .19011 m
.49291 .19903 L
s
.49297 .19887 m
.493 .19011 L
s
.49291 .19903 m
.49303 .19006 L
s
.49303 .19006 m
.49297 .19887 L
s
.669 .239 1 r
.40582 .17658 m
.40544 .18578 L
s
.40546 .18573 m
.40582 .17658 L
s
.40582 .17658 m
.40516 .19479 L
s
.648 .244 1 r
.52599 .20677 m
.52593 .20677 L
s
.405 .662 1 r
.72086 .16837 m
.72129 .17585 L
s
.72132 .17581 m
.72086 .16837 L
s
.72086 .16837 m
.7218 .18315 L
s
1 .151 .92 r
.52978 .13295 m
.53011 .18159 L
s
.588 .259 1 r
.61231 .17465 m
.61253 .18369 L
s
.61255 .18364 m
.61231 .17465 L
s
.61231 .17465 m
.61283 .19238 L
s
.424 .305 1 r
.48724 .17241 m
.48711 .18098 L
s
.48713 .18093 m
.48724 .17241 L
s
.48724 .17241 m
.48706 .1892 L
s
.608 .254 1 r
.43295 .17554 m
.43266 .18459 L
s
.43268 .18454 m
.43295 .17554 L
s
.43295 .17554 m
.43246 .19344 L
s
.629 .249 1 r
.37377 .20648 m
.37371 .20641 L
s
.494 .284 1 r
.70915 .13265 m
.71186 .17475 L
s
.485 .287 1 r
.45521 .20207 m
.45515 .20222 L
s
.978 .171 1 r
.71027 .17887 m
.71081 .18882 L
s
.71084 .18876 m
.71027 .17887 L
s
.71027 .17887 m
.71144 .19845 L
s
.669 .239 1 r
.76457 .176 m
.76523 .1852 L
s
.76526 .18515 m
.76457 .176 L
s
.76457 .176 m
.76598 .1942 L
s
.513 .279 1 r
.39506 .18744 m
.39469 .19628 L
s
.39477 .19589 m
.39506 .18744 L
s
.579 .262 1 r
.55693 .13235 m
.55761 .17521 L
s
.513 .279 1 r
.39469 .19628 m
.39508 .18739 L
s
.39508 .18739 m
.39477 .19589 L
s
.811 .206 1 r
.64526 .19223 m
.64562 .20182 L
s
.64567 .20146 m
.64526 .19223 L
s
.64562 .20182 m
.64529 .19218 L
s
.64529 .19218 m
.64567 .20146 L
s
.608 .254 1 r
.46008 .17496 m
.45986 .184 L
s
.45989 .18395 m
.46008 .17496 L
s
.46008 .17496 m
.45974 .19285 L
s
.599 .257 1 r
.73637 .13205 m
.7395 .17492 L
s
.722 .227 1 r
.40467 .13205 m
.40316 .17761 L
s
.953 .176 1 r
.58521 .17773 m
.58537 .18763 L
s
.58539 .18758 m
.58521 .17773 L
s
.58521 .17773 m
.58561 .19719 L
s
.4 .312 1 r
.58411 .13175 m
.58509 .17231 L
s
.477 .289 1 r
.53667 .19919 m
.53661 .19965 L
s
.629 .249 1 r
.6667 .17366 m
.66708 .18282 L
s
.66711 .18277 m
.6667 .17366 L
s
.6667 .17366 m
.66753 .1916 L
s
.916 .184 1 r
.70549 .2084 m
.70544 .20875 L
s
.648 .244 1 r
.76359 .13145 m
.76719 .17548 L
s
.608 .254 1 r
.4318 .13145 m
.43074 .1751 L
s
.639 .247 1 r
.6113 .13115 m
.61274 .17479 L
s
.522 .277 1 r
.35717 .20062 m
.35709 .20093 L
s
.531 .274 1 r
.54156 .17214 m
.54158 .18102 L
s
.5416 .18098 m
.54156 .17214 L
s
.54156 .17214 m
.54168 .18957 L
s
.649 .244 1 r
.33 .20235 m
.3299 .20281 L
s
.618 .252 1 r
.36204 .17311 m
.36154 .18223 L
s
.36156 .18218 m
.36204 .17311 L
s
.36204 .17311 m
.36114 .19101 L
s
.805 .208 1 r
.69393 .17313 m
.69442 .18284 L
s
.69445 .18279 m
.69393 .17313 L
s
.69393 .17313 m
.69496 .19177 L
s
.476 .29 1 r
.45895 .13085 m
.45828 .17335 L
s
.766 .217 1 r
.52015 .19227 m
.52013 .20159 L
s
.5202 .20174 m
.52015 .19227 L
s
.618 .252 1 r
.60168 .18778 m
.60189 .1969 L
s
.60195 .19655 m
.60168 .18778 L
s
.766 .217 1 r
.52013 .20159 m
.52018 .19222 L
s
.52018 .19222 m
.5202 .20174 L
s
.618 .252 1 r
.60189 .1969 m
.6017 .18773 L
s
.6017 .18773 m
.60195 .19655 L
s
.99 .169 1 r
.67254 .19318 m
.673 .20316 L
s
.67305 .2028 m
.67254 .19318 L
s
.658 .242 1 r
.51439 .17428 m
.51433 .18344 L
s
.51435 .18339 m
.51439 .17428 L
s
.51439 .17428 m
.51436 .19245 L
s
.99 .169 1 r
.673 .20316 m
.67257 .19312 L
s
.67257 .19312 m
.67305 .2028 L
s
.799 .209 1 r
.6385 .13055 m
.64043 .1769 L
s
.669 .239 1 r
.42212 .18899 m
.42181 .19819 L
s
.42189 .19799 m
.42212 .18899 L
s
.578 .262 1 r
.4493 .18749 m
.44907 .19645 L
s
.44914 .19626 m
.4493 .18749 L
s
.395 .62 1 r
.67744 .16557 m
.67778 .17321 L
s
.6778 .17317 m
.67744 .16557 L
s
.67744 .16557 m
.67819 .18051 L
s
.94 .179 1 r
.63962 .17694 m
.63994 .18677 L
s
.63996 .18671 m
.63962 .17694 L
s
.63962 .17694 m
.64035 .1964 L
s
.669 .239 1 r
.42181 .19819 m
.42214 .18894 L
s
.42214 .18894 m
.42189 .19799 L
s
.578 .262 1 r
.44907 .19645 m
.44932 .18744 L
s
.44932 .18744 m
.44914 .19626 L
s
.441 .3 1 r
.41635 .17096 m
.41602 .17953 L
s
.41604 .17949 m
.41635 .17096 L
s
.41635 .17096 m
.41579 .18792 L
s
.344 .33 1 r
.44352 .16946 m
.44328 .17773 L
s
.4433 .17768 m
.44352 .16946 L
s
.44352 .16946 m
.44312 .1858 L
s
.503 .282 1 r
.74833 .17103 m
.74892 .17984 L
s
.74894 .17979 m
.74833 .17103 L
s
.74833 .17103 m
.74957 .1883 L
s
.608 .254 1 r
.48612 .13025 m
.48579 .17468 L
s
.669 .239 1 r
.7541 .1893 m
.75476 .19846 L
s
.75482 .19838 m
.7541 .1893 L
s
.503 .282 1 r
.47647 .1863 m
.47633 .19503 L
s
.47639 .19491 m
.47647 .1863 L
s
.669 .239 1 r
.75476 .19846 m
.75413 .18925 L
s
.75413 .18925 m
.75482 .19838 L
s
.68 .237 1 r
.68911 .20215 m
.68906 .20262 L
s
.503 .282 1 r
.47633 .19503 m
.47649 .18625 L
s
.47649 .18625 m
.47639 .19491 L
s
.811 .206 1 r
.57453 .1902 m
.57467 .19978 L
s
.57473 .19943 m
.57453 .1902 L
s
.57467 .19978 m
.57455 .19014 L
s
.57455 .19014 m
.57473 .19943 L
s
.469 .292 1 r
.66572 .12995 m
.66777 .17053 L
s
.869 .194 1 r
.78718 .20628 m
.78714 .2066 L
s
.952 .176 1 r
.40077 .20935 m
.4007 .20936 L
s
.701 .232 1 r
.78134 .18841 m
.78209 .19772 L
s
.78213 .19741 m
.78134 .18841 L
s
.723 .226 1 r
.56877 .17253 m
.56887 .18197 L
s
.56889 .18191 m
.56877 .17253 L
s
.56877 .17253 m
.56905 .1909 L
s
.477 .289 1 r
.53084 .18391 m
.53085 .19267 L
s
.53091 .19222 m
.53084 .18391 L
s
.701 .232 1 r
.78209 .19772 m
.78137 .18836 L
s
.78137 .18836 m
.78213 .19741 L
s
.477 .289 1 r
.53085 .19267 m
.53086 .18387 L
s
.53086 .18387 m
.53091 .19222 L
s
.733 .224 1 r
.50951 .20359 m
.50944 .20391 L
s
.559 .267 1 r
.41144 .19985 m
.41136 .20019 L
s
.588 .259 1 r
.51329 .12965 m
.51337 .17292 L
s
.892 .189 1 r
.36771 .19321 m
.36722 .20281 L
s
.36728 .20299 m
.36771 .19321 L
s
.44 .8 1 r
.35122 .18487 m
.35114 .18531 L
s
.892 .189 1 r
.36722 .20281 m
.36773 .19315 L
s
.36773 .19315 m
.36728 .20299 L
s
.649 .244 1 r
.56389 .2009 m
.56383 .20137 L
s
.629 .249 1 r
.65611 .18662 m
.65648 .19578 L
s
.65653 .19539 m
.65611 .18662 L
s
.978 .171 1 r
.60759 .20772 m
.60753 .20804 L
s
.629 .249 1 r
.65648 .19578 m
.65614 .18657 L
s
.65614 .18657 m
.65653 .19539 L
s
.618 .252 1 r
.59597 .17165 m
.59614 .18077 L
s
.59616 .18072 m
.59597 .17165 L
s
.59597 .17165 m
.59639 .18955 L
s
.629 .249 1 r
.69295 .12935 m
.6955 .17224 L
s
.433 .302 1 r
.46579 .19754 m
.46573 .19769 L
s
.701 .232 1 r
.3891 .17427 m
.38867 .18348 L
s
.38869 .18343 m
.3891 .17427 L
s
.3891 .17427 m
.38833 .19273 L
s
.521 .277 1 r
.4386 .19927 m
.43853 .19946 L
s
.416 .307 1 r
.37835 .18423 m
.37795 .19265 L
s
.37801 .19269 m
.37835 .18423 L
s
.834 .201 1 r
.54049 .12905 m
.54097 .17541 L
s
.416 .307 1 r
.37795 .19265 m
.37836 .18418 L
s
.37836 .18418 m
.37801 .19269 L
s
.881 .191 1 r
.66201 .20541 m
.66195 .20577 L
s
.531 .274 1 r
.47068 .17008 m
.4705 .17897 L
s
.47052 .17892 m
.47068 .17008 L
s
.47068 .17008 m
.47041 .18752 L
s
.811 .206 1 r
.62896 .18903 m
.62926 .19862 L
s
.62932 .19827 m
.62896 .18903 L
s
.62926 .19862 m
.62898 .18898 L
s
.62898 .18898 m
.62932 .19827 L
s
.845 .199 1 r
.48231 .20647 m
.48224 .20648 L
s
.398 .631 1 r
.72021 .12875 m
.72267 .16512 L
s
.357 .45 1 r
.55226 .16582 m
.55231 .17385 L
s
.55232 .17381 m
.55226 .16582 L
s
.55226 .16582 m
.55242 .18154 L
s
.68 .237 1 r
.74363 .20138 m
.74359 .20173 L
s
.648 .244 1 r
.59111 .20071 m
.59105 .20105 L
s
.711 .229 1 r
.50365 .18724 m
.50358 .1966 L
s
.50365 .19625 m
.50365 .18724 L
s
.50358 .1966 m
.50367 .18719 L
s
.50367 .18719 m
.50365 .19625 L
s
.669 .239 1 r
.5677 .12845 m
.56855 .17289 L
s
.477 .289 1 r
.34044 .19667 m
.34035 .19701 L
s
.551 .269 1 r
.73781 .18395 m
.73841 .19291 L
s
.73844 .19249 m
.73781 .18395 L
s
.73841 .19291 m
.73784 .1839 L
s
.73784 .1839 m
.73844 .19249 L
s
.618 .252 1 r
.55806 .18485 m
.55815 .19401 L
s
.55821 .19355 m
.55806 .18485 L
s
.799 .209 1 r
.77578 .17275 m
.7765 .18231 L
s
.77653 .18226 m
.77578 .17275 L
s
.77578 .17275 m
.7773 .19156 L
s
.4 .312 1 r
.54739 .19465 m
.54734 .19499 L
s
.711 .229 1 r
.74747 .12815 m
.75091 .17298 L
s
.659 .242 1 r
.41515 .12815 m
.41377 .17413 L
s
.618 .252 1 r
.55815 .19401 m
.55808 .1848 L
s
.55808 .1848 m
.55821 .19355 L
s
.405 .662 1 r
.72129 .17585 m
.72175 .18333 L
s
.7218 .18315 m
.72129 .17585 L
s
.72175 .18333 m
.72132 .17581 L
s
.72132 .17581 m
.7218 .18315 L
s
.648 .244 1 r
.65044 .1707 m
.65077 .1799 L
s
.6508 .17985 m
.65044 .1707 L
s
.65044 .1707 m
.65118 .18876 L
s
.766 .217 1 r
.62323 .17223 m
.62349 .18171 L
s
.62352 .18166 m
.62323 .17223 L
s
.62323 .17223 m
.62384 .19088 L
s
.4 .312 1 r
.72719 .19436 m
.72715 .1947 L
s
.744 .222 1 r
.59493 .12785 m
.59618 .17306 L
s
.869 .194 1 r
.71651 .20426 m
.71647 .20458 L
s
.68 .237 1 r
.61836 .20051 m
.6183 .20086 L
s
.476 .29 1 r
.69999 .19609 m
.69995 .19643 L
s
.702 .231 1 r
.38409 .20503 m
.38404 .20453 L
s
.767 .216 1 r
.77097 .20156 m
.77093 .202 L
s
.777 .214 1 r
.44234 .12755 m
.44138 .17315 L
s
.955 .176 1 r
.68347 .18817 m
.68397 .19819 L
s
.684 .19749 m
.68347 .18817 L
s
.68397 .19819 m
.6835 .18812 L
s
.6835 .18812 m
.684 .19749 L
s
.569 .264 1 r
.49297 .19887 m
.49291 .19903 L
s
.424 .305 1 r
.48711 .18098 m
.487 .18955 L
s
.48706 .1892 m
.48711 .18098 L
s
.701 .232 1 r
.62217 .12725 m
.62383 .17286 L
s
.63 .249 1 r
.37246 .16891 m
.37199 .17811 L
s
.37201 .17806 m
.37246 .16891 L
s
.37246 .16891 m
.37163 .18681 L
s
.424 .305 1 r
.487 .18955 m
.48713 .18093 L
s
.48713 .18093 m
.48706 .1892 L
s
.669 .239 1 r
.40544 .18578 m
.40509 .19498 L
s
.40516 .19479 m
.40544 .18578 L
s
.40509 .19498 m
.40546 .18573 L
s
.40546 .18573 m
.40516 .19479 L
s
.588 .259 1 r
.61253 .18369 m
.61277 .19273 L
s
.61283 .19238 m
.61253 .18369 L
s
.459 .295 1 r
.46954 .12695 m
.46901 .16909 L
s
.588 .259 1 r
.61277 .19273 m
.61255 .18364 L
s
.61255 .18364 m
.61283 .19238 L
s
.608 .254 1 r
.43266 .18459 m
.43238 .19363 L
s
.43246 .19344 m
.43266 .18459 L
s
.513 .279 1 r
.39477 .19589 m
.39469 .19628 L
s
.608 .254 1 r
.43238 .19363 m
.43268 .18454 L
s
.43268 .18454 m
.43246 .19344 L
s
.494 .285 1 r
.7322 .16818 m
.73274 .17691 L
s
.73276 .17687 m
.7322 .16818 L
s
.7322 .16818 m
.73336 .18546 L
s
.658 .242 1 r
.52508 .17046 m
.52505 .17963 L
s
.52508 .17958 m
.52508 .17046 L
s
.52508 .17046 m
.52511 .18865 L
s
.504 .282 1 r
.64943 .12665 m
.65135 .16917 L
s
.669 .239 1 r
.76523 .1852 m
.76593 .1944 L
s
.76598 .1942 m
.76523 .1852 L
s
.76593 .1944 m
.76526 .18515 L
s
.76526 .18515 m
.76598 .1942 L
s
.701 .232 1 r
.49676 .12635 m
.49659 .17119 L
s
.608 .254 1 r
.45986 .184 m
.45967 .19305 L
s
.45974 .19285 m
.45986 .184 L
s
.892 .189 1 r
.49786 .17264 m
.49775 .18236 L
s
.49777 .18231 m
.49786 .17264 L
s
.49786 .17264 m
.49772 .19193 L
s
.569 .264 1 r
.39962 .1689 m
.39924 .17783 L
s
.39926 .17778 m
.39962 .1689 L
s
.39962 .1689 m
.39894 .18661 L
s
.608 .254 1 r
.45967 .19305 m
.45989 .18395 L
s
.45989 .18395 m
.45974 .19285 L
s
.811 .206 1 r
.64567 .20146 m
.64562 .20182 L
s
.978 .171 1 r
.71081 .18882 m
.71139 .19877 L
s
.71144 .19845 m
.71081 .18882 L
s
.71139 .19877 m
.71084 .18876 L
s
.71084 .18876 m
.71144 .19845 L
s
.618 .252 1 r
.6767 .12605 m
.6791 .1705 L
s
.54 .272 1 r
.42683 .16808 m
.42653 .17694 L
s
.42655 .17689 m
.42683 .16808 L
s
.42683 .16808 m
.42631 .18564 L
s
.522 .277 1 r
.52399 .12575 m
.52421 .16828 L
s
.822 .204 1 r
.70508 .1713 m
.70558 .18087 L
s
.70561 .18081 m
.70508 .1713 L
s
.70508 .1713 m
.70618 .19028 L
s
.629 .249 1 r
.66708 .18282 m
.66748 .19198 L
s
.66753 .1916 m
.66708 .18282 L
s
.66748 .19198 m
.66711 .18277 L
s
.66711 .18277 m
.66753 .1916 L
s
.352 .327 1 r
.70399 .12545 m
.70649 .16529 L
s
.395 .62 1 r
.67778 .17321 m
.67815 .18084 L
s
.67819 .18051 m
.67778 .17321 L
s
.953 .176 1 r
.58537 .18763 m
.58555 .19754 L
s
.58561 .19719 m
.58537 .18763 L
s
.503 .282 1 r
.60682 .16794 m
.60701 .17664 L
s
.60703 .17659 m
.60682 .16794 L
s
.60682 .16794 m
.60729 .18535 L
s
.395 .62 1 r
.67815 .18084 m
.6778 .17317 L
s
.6778 .17317 m
.67819 .18051 L
s
.953 .176 1 r
.58555 .19754 m
.58539 .18758 L
s
.58539 .18758 m
.58561 .19719 L
s
.531 .274 1 r
.54158 .18102 m
.54161 .18991 L
s
.54168 .18957 m
.54158 .18102 L
s
.54161 .18991 m
.5416 .18098 L
s
.5416 .18098 m
.54168 .18957 L
s
.68 .237 1 r
.55124 .12514 m
.55186 .1696 L
s
.618 .252 1 r
.60195 .19655 m
.60189 .1969 L
s
.36154 .18223 m
.36106 .19136 L
s
.36114 .19101 m
.36154 .18223 L
s
.344 .33 1 r
.44328 .17773 m
.44306 .18599 L
s
.44312 .1858 m
.44328 .17773 L
s
.618 .252 1 r
.36106 .19136 m
.36156 .18218 L
s
.36156 .18218 m
.36114 .19101 L
s
.344 .33 1 r
.44306 .18599 m
.4433 .17768 L
s
.4433 .17768 m
.44312 .1858 L
s
.744 .222 1 r
.7313 .12484 m
.73453 .17008 L
s
.441 .3 1 r
.41602 .17953 m
.41572 .18811 L
s
.41579 .18792 m
.41602 .17953 L
s
.845 .199 1 r
.75967 .1697 m
.76035 .17938 L
s
.76038 .17933 m
.75967 .1697 L
s
.75967 .1697 m
.76111 .18872 L
s
.441 .3 1 r
.41572 .18811 m
.41604 .17949 L
s
.41604 .17949 m
.41579 .18792 L
s
.658 .242 1 r
.51433 .18344 m
.51429 .19261 L
s
.51436 .19245 m
.51433 .18344 L
s
.578 .262 1 r
.44914 .19626 m
.44907 .19645 L
s
.658 .242 1 r
.51429 .19261 m
.51435 .18339 L
s
.51435 .18339 m
.51436 .19245 L
s
.766 .217 1 r
.5202 .20174 m
.52013 .20159 L
s
.805 .208 1 r
.69442 .18284 m
.69493 .19256 L
s
.69496 .19177 m
.69442 .18284 L
s
.503 .282 1 r
.47639 .19491 m
.47633 .19503 L
s
.74892 .17984 m
.74954 .18865 L
s
.74957 .1883 m
.74892 .17984 L
s
.45 .297 1 r
.68862 .16469 m
.68904 .17335 L
s
.68906 .1733 m
.68862 .16469 L
s
.68862 .16469 m
.68953 .18166 L
s
.608 .254 1 r
.57851 .12454 m
.57949 .16824 L
s
.669 .239 1 r
.42189 .19799 m
.42181 .19819 L
s
.805 .208 1 r
.69493 .19256 m
.69445 .18279 L
s
.69445 .18279 m
.69496 .19177 L
s
.503 .282 1 r
.74954 .18865 m
.74894 .17979 L
s
.74894 .17979 m
.74957 .1883 L
s
.99 .169 1 r
.67305 .2028 m
.673 .20316 L
s
.477 .289 1 r
.53091 .19222 m
.53085 .19267 L
s
.669 .239 1 r
.75482 .19838 m
.75476 .19846 L
s
.734 .224 1 r
.75862 .12424 m
.76223 .16909 L
s
.799 .209 1 r
.42567 .12424 m
.42445 .17025 L
s
.648 .244 1 r
.6614 .16687 m
.66177 .17608 L
s
.6618 .17603 m
.6614 .16687 L
s
.6614 .16687 m
.66221 .18494 L
s
.811 .206 1 r
.57473 .19943 m
.57467 .19978 L
s
.799 .209 1 r
.45403 .16927 m
.45378 .1788 L
s
.4538 .17874 m
.45403 .16927 L
s
.45403 .16927 m
.45363 .18813 L
s
.94 .179 1 r
.63994 .18677 m
.64029 .1966 L
s
.64035 .1964 m
.63994 .18677 L
s
.64029 .1966 m
.63996 .18671 L
s
.63996 .18671 m
.64035 .1964 L
s
.701 .232 1 r
.78213 .19741 m
.78209 .19772 L
s
.589 .259 1 r
.60579 .12394 m
.60715 .16725 L
s
.754 .219 1 r
.63416 .16879 m
.63445 .1782 L
s
.63448 .17814 m
.63416 .16879 L
s
.63416 .16879 m
.63483 .18745 L
s
.629 .249 1 r
.65653 .19539 m
.65648 .19578 L
s
.723 .226 1 r
.56887 .18197 m
.56899 .19141 L
s
.56905 .1909 m
.56887 .18197 L
s
.433 .302 1 r
.45291 .12364 m
.45217 .16541 L
s
.723 .226 1 r
.56899 .19141 m
.56889 .18191 L
s
.56889 .18191 m
.56905 .1909 L
s
.391 .315 1 r
.74323 .16309 m
.74378 .17156 L
s
.74381 .17151 m
.74323 .16309 L
s
.74323 .16309 m
.74441 .17972 L
s
.765 .217 1 r
.48128 .16845 m
.48112 .1779 L
s
.48114 .17785 m
.48128 .16845 L
s
.48128 .16845 m
.48105 .18716 L
s
.416 .307 1 r
.37801 .19269 m
.37795 .19265 L
s
.357 .45 1 r
.55231 .17385 m
.55237 .18188 L
s
.55242 .18154 m
.55231 .17385 L
s
.55237 .18188 m
.55232 .17381 L
s
.55232 .17381 m
.55242 .18154 L
s
.618 .252 1 r
.59614 .18077 m
.59634 .18989 L
s
.59639 .18955 m
.59614 .18077 L
s
.59634 .18989 m
.59616 .18072 L
s
.59616 .18072 m
.59639 .18955 L
s
.892 .189 1 r
.36728 .20299 m
.36722 .20281 L
s
.405 .662 1 r
.7218 .18315 m
.72175 .18333 L
s
.928 .181 1 r
.63309 .12334 m
.635 .17129 L
s
.701 .232 1 r
.38867 .18348 m
.38827 .19269 L
s
.38833 .19273 m
.38867 .18348 L
s
.531 .274 1 r
.4705 .17897 m
.47033 .18786 L
s
.47041 .18752 m
.4705 .17897 L
s
.701 .232 1 r
.38827 .19269 m
.38869 .18343 L
s
.38869 .18343 m
.38833 .19273 L
s
.531 .274 1 r
.47033 .18786 m
.47052 .17892 L
s
.47052 .17892 m
.47041 .18752 L
s
.788 .211 1 r
.48017 .12303 m
.47972 .17098 L
s
.765 .217 1 r
.50855 .16786 m
.50847 .17731 L
s
.50849 .17726 m
.50855 .16786 L
s
.50855 .16786 m
.50848 .18657 L
s
.811 .206 1 r
.62932 .19827 m
.62926 .19862 L
s
1 .106 .673 r
.57968 .17338 m
.57982 .18397 L
s
.57985 .18391 m
.57968 .17338 L
s
.57968 .17338 m
.58007 .19441 L
s
.476 .29 1 r
.6604 .12273 m
.66244 .16452 L
s
.711 .229 1 r
.50365 .19625 m
.50358 .1966 L
s
.551 .269 1 r
.73844 .19249 m
.73841 .19291 L
s
.559 .267 1 r
.71606 .16603 m
.71656 .17489 L
s
.71659 .17484 m
.71606 .16603 L
s
.71606 .16603 m
.71716 .18376 L
s
.618 .252 1 r
.55821 .19355 m
.55815 .19401 L
s
.494 .284 1 r
.50744 .12243 m
.50743 .1646 L
s
.811 .206 1 r
.38285 .16648 m
.38239 .17612 L
s
.38241 .17607 m
.38285 .16648 L
s
.38285 .16648 m
.38203 .1853 L
s
.531 .274 1 r
.4374 .16359 m
.43713 .17249 L
s
.43715 .17244 m
.4374 .16359 L
s
.4374 .16359 m
.43694 .18105 L
s
.638 .247 1 r
.41012 .16513 m
.40976 .17431 L
s
.40978 .17426 m
.41012 .16513 L
s
.41012 .16513 m
.40949 .18317 L
s
.4 .312 1 r
.68773 .12213 m
.69007 .16276 L
s
.648 .244 1 r
.65077 .1799 m
.65113 .18911 L
s
.65118 .18876 m
.65077 .1799 L
s
.65113 .18911 m
.6508 .17985 L
s
.6508 .17985 m
.65118 .18876 L
s
.413 .693 1 r
.39351 .15722 m
.39318 .16464 L
s
.3932 .16459 m
.39351 .15722 L
s
.39351 .15722 m
.39292 .17187 L
s
.799 .209 1 r
.7765 .18231 m
.77726 .19187 L
s
.7773 .19156 m
.7765 .18231 L
s
.77726 .19187 m
.77653 .18226 L
s
.77653 .18226 m
.7773 .19156 L
s
.579 .262 1 r
.6177 .16344 m
.61794 .1725 L
s
.61796 .17245 m
.6177 .16344 L
s
.6177 .16344 m
.61825 .18113 L
s
.424 .305 1 r
.48706 .1892 m
.487 .18955 L
s
.766 .217 1 r
.62349 .18171 m
.62378 .1912 L
s
.62384 .19088 m
.62349 .18171 L
s
.777 .214 1 r
.53473 .12183 m
.53512 .16747 L
s
.766 .217 1 r
.62378 .1912 m
.62352 .18166 L
s
.62352 .18166 m
.62384 .19088 L
s
.88 .191 1 r
.56314 .16698 m
.56322 .17674 L
s
.56325 .17669 m
.56314 .16698 L
s
.56314 .16698 m
.5634 .18616 L
s
.618 .252 1 r
.71508 .12152 m
.71798 .16524 L
s
.955 .176 1 r
.684 .19749 m
.68397 .19819 L
s
1 .156 .946 r
.53585 .16875 m
.53585 .17887 L
s
.53587 .17881 m
.53585 .16875 L
s
.53585 .16875 m
.53595 .18868 L
s
.588 .259 1 r
.61283 .19238 m
.61277 .19273 L
s
.63 .249 1 r
.37199 .17811 m
.37153 .18732 L
s
.37163 .18681 m
.37199 .17811 L
s
.618 .252 1 r
.56204 .12122 m
.56279 .16494 L
s
.669 .239 1 r
.40516 .19479 m
.40509 .19498 L
s
.63 .249 1 r
.37153 .18732 m
.37201 .17806 L
s
.37201 .17806 m
.37163 .18681 L
s
.608 .254 1 r
.43246 .19344 m
.43238 .19363 L
s
.494 .285 1 r
.73274 .17691 m
.73331 .18565 L
s
.73336 .18546 m
.73274 .17691 L
s
.73331 .18565 m
.73276 .17687 L
s
.73276 .17687 m
.73336 .18546 L
s
.425 .305 1 r
.74244 .12092 m
.74552 .16194 L
s
.658 .242 1 r
.52505 .17963 m
.52505 .1888 L
s
.52511 .18865 m
.52505 .17963 L
s
.52505 .1888 m
.52508 .17958 L
s
.52508 .17958 m
.52511 .18865 L
s
.441 .3 1 r
.51926 .16151 m
.51921 .1701 L
s
.51923 .17006 m
.51926 .16151 L
s
.51926 .16151 m
.51925 .17851 L
s
.618 .252 1 r
.49196 .16309 m
.49183 .17223 L
s
.49185 .17218 m
.49196 .16309 L
s
.49196 .16309 m
.4918 .18102 L
s
.395 .62 1 r
.67819 .18051 m
.67815 .18084 L
s
.638 .247 1 r
.58936 .12062 m
.5905 .16473 L
s
.669 .239 1 r
.76598 .1942 m
.76593 .1944 L
s
.701 .232 1 r
.46465 .16474 m
.46444 .17404 L
s
.46446 .17399 m
.46465 .16474 L
s
.46465 .16474 m
.46433 .18314 L
s
.608 .254 1 r
.45974 .19285 m
.45967 .19305 L
s
.569 .264 1 r
.39924 .17783 m
.39887 .18677 L
s
.39894 .18661 m
.39924 .17783 L
s
.39887 .18677 m
.39926 .17778 L
s
.39926 .17778 m
.39894 .18661 L
s
.766 .217 1 r
.43623 .12031 m
.43517 .16597 L
s
.442 .299 1 r
.72703 .15994 m
.72755 .1686 L
s
.72758 .16856 m
.72703 .15994 L
s
.72703 .15994 m
.72814 .17685 L
s
1 .166 .998 r
.59049 .16772 m
.59066 .17769 L
s
.59068 .17763 m
.59049 .16772 L
s
.59049 .16772 m
.59092 .1875 L
s
1 .161 .972 r
.77096 .167 m
.77171 .17709 L
s
.77174 .17703 m
.77096 .167 L
s
.77096 .167 m
.77253 .18682 L
s
.54 .272 1 r
.42653 .17694 m
.42624 .1858 L
s
.42631 .18564 m
.42653 .17694 L
s
.658 .242 1 r
.61669 .12001 m
.61825 .1649 L
s
.54 .272 1 r
.42624 .1858 m
.42655 .17689 L
s
.42655 .17689 m
.42631 .18564 L
s
.892 .189 1 r
.49775 .18236 m
.49765 .19209 L
s
.49772 .19193 m
.49775 .18236 L
s
.49765 .19209 m
.49777 .18231 L
s
.49777 .18231 m
.49772 .19193 L
s
.629 .249 1 r
.66753 .1916 m
.66748 .19198 L
s
.978 .171 1 r
.71144 .19845 m
.71139 .19877 L
s
.503 .282 1 r
.60701 .17664 m
.60723 .18535 L
s
.60729 .18535 m
.60701 .17664 L
s
.833 .201 1 r
.46353 .11971 m
.46283 .1673 L
s
.503 .282 1 r
.60723 .18535 m
.60703 .17659 L
s
.60703 .17659 m
.60729 .18535 L
s
.531 .274 1 r
.54168 .18957 m
.54161 .18991 L
s
.344 .33 1 r
.44312 .1858 m
.44306 .18599 L
s
.942 .178 1 r
.64514 .16535 m
.64549 .17528 L
s
.64551 .17522 m
.64514 .16535 L
s
.64514 .16535 m
.64591 .18477 L
s
.66 .241 1 r
.54659 .16175 m
.54662 .17104 L
s
.54665 .17099 m
.54659 .16175 L
s
.54659 .16175 m
.54674 .17983 L
s
.822 .204 1 r
.70558 .18087 m
.70613 .19044 L
s
.70618 .19028 m
.70558 .18087 L
s
.70613 .19044 m
.70561 .18081 L
s
.70561 .18081 m
.70618 .19028 L
s
1 .07 .462 r
.64405 .11941 m
.64645 .17514 L
s
.711 .229 1 r
.69981 .16288 m
.70029 .17226 L
s
.70032 .1722 m
.69981 .16288 L
s
.69981 .16288 m
.70086 .18128 L
s
.441 .3 1 r
.41579 .18792 m
.41572 .18811 L
s
.618 .252 1 r
.36114 .19101 m
.36106 .19136 L
s
.953 .176 1 r
.58561 .19719 m
.58555 .19754 L
s
.648 .244 1 r
.49084 .1191 m
.49059 .16322 L
s
.503 .282 1 r
.74957 .1883 m
.74954 .18865 L
s
.45 .297 1 r
.68904 .17335 m
.68948 .18201 L
s
.68953 .18166 m
.68904 .17335 L
s
.68948 .18201 m
.68906 .1733 L
s
.68906 .1733 m
.68953 .18166 L
s
.904 .186 1 r
.67141 .1188 m
.6739 .1664 L
s
.658 .242 1 r
.51436 .19245 m
.51429 .19261 L
s
.805 .208 1 r
.69496 .19177 m
.69493 .19256 L
s
.892 .189 1 r
.67253 .16526 m
.67295 .17499 L
s
.67298 .17494 m
.67253 .16526 L
s
.67253 .16526 m
.67346 .18457 L
s
.916 .184 1 r
.51817 .1185 m
.51832 .16571 L
s
.357 .45 1 r
.55242 .18154 m
.55237 .18188 L
s
.845 .199 1 r
.76035 .17938 m
.76107 .18907 L
s
.76111 .18872 m
.76035 .17938 L
s
.76107 .18907 m
.76038 .17933 L
s
.76038 .17933 m
.76111 .18872 L
s
.744 .221 1 r
.57395 .16222 m
.57406 .17167 L
s
.57409 .17162 m
.57395 .16222 L
s
.57395 .16222 m
.57427 .18078 L
s
.618 .252 1 r
.60129 .16072 m
.60147 .16986 L
s
.6015 .16981 m
.60129 .16072 L
s
.60129 .16072 m
.60175 .17865 L
s
.669 .239 1 r
.6988 .11819 m
.70154 .16309 L
s
.648 .244 1 r
.66177 .17608 m
.66216 .18529 L
s
.66221 .18494 m
.66177 .17608 L
s
.391 .315 1 r
.74378 .17156 m
.74437 .18002 L
s
.74441 .17972 m
.74378 .17156 L
s
.648 .244 1 r
.66216 .18529 m
.6618 .17603 L
s
.6618 .17603 m
.66221 .18494 L
s
.711 .229 1 r
.7546 .1617 m
.75524 .17107 L
s
.75527 .17102 m
.7546 .1617 L
s
.7546 .1617 m
.75597 .1801 L
s
.391 .315 1 r
.74437 .18002 m
.74381 .17151 L
s
.74381 .17151 m
.74441 .17972 L
s
.618 .252 1 r
.44798 .16042 m
.44773 .16956 L
s
.44775 .16951 m
.44798 .16042 L
s
.44798 .16042 m
.44757 .17836 L
s
.845 .199 1 r
.54551 .11789 m
.54607 .16434 L
s
.799 .209 1 r
.45378 .1788 m
.45356 .18833 L
s
.45363 .18813 m
.45378 .1788 L
s
.723 .226 1 r
.56905 .1909 m
.56899 .19141 L
s
.799 .209 1 r
.45356 .18833 m
.4538 .17874 L
s
.4538 .17874 m
.45363 .18813 L
s
.754 .219 1 r
.63445 .1782 m
.63477 .18761 L
s
.63483 .18745 m
.63445 .1782 L
s
.618 .252 1 r
.59639 .18955 m
.59634 .18989 L
s
.94 .179 1 r
.64035 .1964 m
.64029 .1966 L
s
.754 .219 1 r
.63477 .18761 m
.63448 .17814 L
s
.63448 .17814 m
.63483 .18745 L
s
.531 .274 1 r
.7262 .11759 m
.72918 .16018 L
s
.47041 .18752 m
.47033 .18786 L
s
.765 .217 1 r
.48112 .1779 m
.48098 .18735 L
s
.48105 .18716 m
.48112 .1779 L
s
.48098 .18735 m
.48114 .17785 L
s
.48114 .17785 m
.48105 .18716 L
s
.598 .257 1 r
.62867 .16054 m
.62893 .16957 L
s
.62896 .16952 m
.62867 .16054 L
s
.62867 .16054 m
.62928 .17845 L
s
.916 .184 1 r
.57287 .11728 m
.57385 .16451 L
s
.733 .224 1 r
.42061 .16299 m
.42027 .1723 L
s
.42029 .17224 m
.42061 .16299 L
s
.42061 .16299 m
.42002 .18164 L
s
.702 .231 1 r
.65604 .15922 m
.6564 .16867 L
s
.65643 .16862 m
.65604 .15922 L
s
.65604 .15922 m
.65683 .17747 L
s
.413 .693 1 r
.39318 .16464 m
.39286 .17205 L
s
.39292 .17187 m
.39318 .16464 L
s
.701 .232 1 r
.38833 .19273 m
.38827 .19269 L
s
.413 .693 1 r
.39286 .17205 m
.3932 .16459 L
s
.3932 .16459 m
.39292 .17187 L
s
.578 .262 1 r
.75362 .11698 m
.75706 .16073 L
s
.559 .267 1 r
.71656 .17489 m
.71709 .18376 L
s
.71716 .18376 m
.71656 .17489 L
s
.71709 .18376 m
.71659 .17484 L
s
.71659 .17484 m
.71716 .18376 L
s
.765 .217 1 r
.50847 .17731 m
.50841 .18677 L
s
.50848 .18657 m
.50847 .17731 L
s
.50841 .18677 m
.50849 .17726 L
s
.50849 .17726 m
.50848 .18657 L
s
.578 .262 1 r
.60025 .11668 m
.60154 .16043 L
s
.588 .259 1 r
.68344 .15871 m
.68386 .16777 L
s
.68389 .16772 m
.68344 .15871 L
s
.68344 .15871 m
.68436 .17649 L
s
.531 .274 1 r
.43713 .17249 m
.43687 .18139 L
s
.43694 .18105 m
.43713 .17249 L
s
.638 .247 1 r
.47529 .16112 m
.47512 .17019 L
s
.47514 .17014 m
.47529 .16112 L
s
.47529 .16112 m
.47503 .1793 L
s
.531 .274 1 r
.43687 .18139 m
.43715 .17244 L
s
.43715 .17244 m
.43694 .18105 L
s
.822 .204 1 r
.44683 .11637 m
.4459 .16322 L
s
.494 .284 1 r
.71081 .15747 m
.7113 .16626 L
s
.71132 .16621 m
.71081 .15747 L
s
.71081 .15747 m
.71186 .17475 L
s
.638 .247 1 r
.40976 .17431 m
.40941 .18348 L
s
.40949 .18317 m
.40976 .17431 L
s
.648 .244 1 r
.65118 .18876 m
.65113 .18911 L
s
.638 .247 1 r
.40941 .18348 m
.40978 .17426 L
s
.40978 .17426 m
.40949 .18317 L
s
.811 .206 1 r
.38239 .17612 m
.38194 .18577 L
s
.38203 .1853 m
.38239 .17612 L
s
.4 .312 1 r
.58475 .15562 m
.58488 .16414 L
s
.5849 .16409 m
.58475 .15562 L
s
.58475 .15562 m
.58509 .17231 L
s
.868 .194 1 r
.62764 .11607 m
.62945 .1633 L
s
.811 .206 1 r
.38194 .18577 m
.38241 .17607 L
s
.38241 .17607 m
.38203 .1853 L
s
.579 .262 1 r
.61794 .1725 m
.6182 .18156 L
s
.61825 .18113 m
.61794 .1725 L
s
1 .106 .673 r
.57982 .18397 m
.58 .19458 L
s
.58007 .19441 m
.57982 .18397 L
s
.579 .262 1 r
.6182 .18156 m
.61796 .17245 L
s
.61796 .17245 m
.61825 .18113 L
s
.799 .209 1 r
.7773 .19156 m
.77726 .19187 L
s
1 .106 .673 r
.58 .19458 m
.57985 .18391 L
s
.57985 .18391 m
.58007 .19441 L
s
.766 .217 1 r
.62384 .19088 m
.62378 .1912 L
s
.579 .262 1 r
.5574 .1575 m
.55746 .16657 L
s
.55748 .16652 m
.5574 .1575 L
s
.5574 .1575 m
.55761 .17521 L
s
.701 .232 1 r
.47418 .11576 m
.47368 .16107 L
s
.845 .199 1 r
.50266 .16082 m
.50256 .17052 L
s
.50258 .17047 m
.50266 .16082 L
s
.50266 .16082 m
.50256 .17987 L
s
.599 .257 1 r
.73827 .15713 m
.73885 .16628 L
s
.73888 .16622 m
.73827 .15713 L
s
.73827 .15713 m
.7395 .17492 L
s
.63 .249 1 r
.37163 .18681 m
.37153 .18732 L
s
.679 .237 1 r
.65505 .11546 m
.65718 .16077 L
s
.494 .285 1 r
.73336 .18546 m
.73331 .18565 L
s
.88 .191 1 r
.56322 .17674 m
.56333 .18651 L
s
.5634 .18616 m
.56322 .17674 L
s
.56333 .18651 m
.56325 .17669 L
s
.56325 .17669 m
.5634 .18616 L
s
.811 .206 1 r
.50155 .11516 m
.50145 .16124 L
s
.441 .3 1 r
.51921 .1701 m
.51919 .1787 L
s
.51925 .17851 m
.51921 .1701 L
s
.51919 .1787 m
.51923 .17006 L
s
.51923 .17006 m
.51925 .17851 L
s
.904 .186 1 r
.68247 .11485 m
.68511 .1621 L
s
.658 .242 1 r
.52511 .18865 m
.52505 .1888 L
s
1 .156 .946 r
.53585 .17887 m
.53587 .189 L
s
.53595 .18868 m
.53585 .17887 L
s
.53587 .189 m
.53587 .17881 L
s
.53587 .17881 m
.53595 .18868 L
s
.569 .264 1 r
.39894 .18661 m
.39887 .18677 L
s
.618 .252 1 r
.49183 .17223 m
.49173 .18137 L
s
.4918 .18102 m
.49183 .17223 L
s
.398 .631 1 r
.72171 .15018 m
.72216 .1578 L
s
.72219 .15776 m
.72171 .15018 L
s
.72171 .15018 m
.72267 .16512 L
s
.618 .252 1 r
.49173 .18137 m
.49185 .17218 L
s
.49185 .17218 m
.4918 .18102 L
s
.442 .299 1 r
.72755 .1686 m
.72811 .17727 L
s
.72814 .17685 m
.72755 .1686 L
s
.608 .254 1 r
.43124 .15719 m
.43094 .16629 L
s
.43096 .16624 m
.43124 .15719 L
s
.43124 .15719 m
.43074 .1751 L
s
.344 .33 1 r
.52893 .11455 m
.5292 .15485 L
s
.442 .299 1 r
.72811 .17727 m
.72758 .16856 L
s
.72758 .16856 m
.72814 .17685 L
s
.701 .232 1 r
.46444 .17404 m
.46425 .18334 L
s
.46433 .18314 m
.46444 .17404 L
s
.469 .292 1 r
.66698 .15352 m
.66735 .16236 L
s
.66737 .16231 m
.66698 .15352 L
s
.66698 .15352 m
.66777 .17053 L
s
.701 .232 1 r
.46425 .18334 m
.46446 .17399 L
s
.46446 .17399 m
.46433 .18314 L
s
.648 .244 1 r
.76578 .15737 m
.76645 .1666 L
s
.76648 .16655 m
.76578 .15737 L
s
.76578 .15737 m
.76719 .17548 L
s
.54 .272 1 r
.42631 .18564 m
.42624 .1858 L
s
.639 .247 1 r
.61221 .15677 m
.61243 .16599 L
s
.61246 .16594 m
.61221 .15677 L
s
.61221 .15677 m
.61274 .17479 L
s
.722 .227 1 r
.40385 .15907 m
.40346 .16842 L
s
.40348 .16837 m
.40385 .15907 L
s
.40385 .15907 m
.40316 .17761 L
s
.476 .29 1 r
.45862 .1561 m
.4584 .16478 L
s
.45842 .16473 m
.45862 .1561 L
s
.45862 .1561 m
.45828 .17335 L
s
.868 .194 1 r
.70991 .11424 m
.71297 .16149 L
s
1 .151 .92 r
.53005 .16156 m
.53003 .17177 L
s
.53006 .17171 m
.53005 .16156 L
s
.53005 .16156 m
.53011 .18159 L
s
.503 .282 1 r
.60729 .18535 m
.60723 .18535 L
s
.834 .201 1 r
.55633 .11394 m
.55705 .16003 L
s
.892 .189 1 r
.49772 .19193 m
.49765 .19209 L
s
.588 .259 1 r
.73737 .11364 m
.74056 .15703 L
s
1 .166 .998 r
.59066 .17769 m
.59086 .18766 L
s
.59092 .1875 m
.59066 .17769 L
s
.59086 .18766 m
.59068 .17763 L
s
.59068 .17763 m
.59092 .1875 L
s
1 .161 .972 r
.77171 .17709 m
.77249 .18717 L
s
.77253 .18682 m
.77171 .17709 L
s
.66 .241 1 r
.54662 .17104 m
.54668 .18034 L
s
.54674 .17983 m
.54662 .17104 L
s
.45 .297 1 r
.68953 .18166 m
.68948 .18201 L
s
1 .161 .972 r
.77249 .18717 m
.77174 .17703 L
s
.77174 .17703 m
.77253 .18682 L
s
.66 .241 1 r
.54668 .18034 m
.54665 .17099 L
s
.54665 .17099 m
.54674 .17983 L
s
.701 .232 1 r
.58374 .11333 m
.58484 .15865 L
s
.822 .204 1 r
.70618 .19028 m
.70613 .19044 L
s
.942 .178 1 r
.64549 .17528 m
.64586 .18521 L
s
.64591 .18477 m
.64549 .17528 L
s
.711 .229 1 r
.70029 .17226 m
.70081 .18164 L
s
.70086 .18128 m
.70029 .17226 L
s
.942 .178 1 r
.64586 .18521 m
.64551 .17522 L
s
.64551 .17522 m
.64591 .18477 L
s
.711 .229 1 r
.70081 .18164 m
.70032 .1722 L
s
.70032 .1722 m
.70086 .18128 L
s
.629 .249 1 r
.6945 .15433 m
.69497 .1636 L
s
.695 .16355 m
.6945 .15433 L
s
.6945 .15433 m
.6955 .17224 L
s
.588 .259 1 r
.5134 .15513 m
.51334 .1642 L
s
.51336 .16415 m
.5134 .15513 L
s
.5134 .15513 m
.51337 .17292 L
s
.608 .254 1 r
.48599 .15668 m
.48585 .16572 L
s
.48587 .16567 m
.48599 .15668 L
s
.48599 .15668 m
.48579 .17468 L
s
.391 .315 1 r
.74441 .17972 m
.74437 .18002 L
s
.81 .206 1 r
.61118 .11272 m
.61272 .1596 L
s
.799 .209 1 r
.63971 .158 m
.64002 .16754 L
s
.64005 .16749 m
.63971 .158 L
s
.63971 .158 m
.64043 .1769 L
s
.712 .229 1 r
.45747 .11242 m
.45675 .15697 L
s
.413 .693 1 r
.39292 .17187 m
.39286 .17205 L
s
.892 .189 1 r
.67295 .17499 m
.6734 .18473 L
s
.67346 .18457 m
.67295 .17499 L
s
.6734 .18473 m
.67298 .17494 L
s
.67298 .17494 m
.67346 .18457 L
s
.845 .199 1 r
.76111 .18872 m
.76107 .18907 L
s
.648 .244 1 r
.66221 .18494 m
.66216 .18529 L
s
.618 .252 1 r
.60147 .16986 m
.60169 .179 L
s
.60175 .17865 m
.60147 .16986 L
s
.60169 .179 m
.6015 .16981 L
s
.6015 .16981 m
.60175 .17865 L
s
.904 .186 1 r
.63862 .11211 m
.64062 .15976 L
s
.744 .221 1 r
.57406 .17167 m
.5742 .18113 L
s
.57427 .18078 m
.57406 .17167 L
s
.5742 .18113 m
.57409 .17162 L
s
.57409 .17162 m
.57427 .18078 L
s
.711 .229 1 r
.75524 .17107 m
.75593 .18045 L
s
.75597 .1801 m
.75524 .17107 L
s
.618 .252 1 r
.44773 .16956 m
.4475 .1787 L
s
.44757 .17836 m
.44773 .16956 L
s
.711 .229 1 r
.75593 .18045 m
.75527 .17102 L
s
.75527 .17102 m
.75597 .1801 L
s
.618 .252 1 r
.4475 .1787 m
.44775 .16951 L
s
.44775 .16951 m
.44757 .17836 L
s
.754 .219 1 r
.48487 .11181 m
.48452 .15791 L
s
.799 .209 1 r
.45363 .18813 m
.45356 .18833 L
s
.754 .219 1 r
.63483 .18745 m
.63477 .18761 L
s
.722 .227 1 r
.66609 .1115 m
.6684 .15723 L
s
.598 .257 1 r
.62893 .16957 m
.62922 .1786 L
s
.62928 .17845 m
.62893 .16957 L
s
.62922 .1786 m
.62896 .16952 L
s
.62896 .16952 m
.62928 .17845 L
s
.765 .217 1 r
.48105 .18716 m
.48098 .18735 L
s
.669 .239 1 r
.56827 .15466 m
.56836 .16393 L
s
.56839 .16388 m
.56827 .15466 L
s
.56827 .15466 m
.56855 .17289 L
s
.522 .277 1 r
.5123 .1112 m
.51235 .15383 L
s
.733 .224 1 r
.42027 .1723 m
.41995 .18161 L
s
.42002 .18164 m
.42027 .1723 L
s
.41995 .18161 m
.42029 .17224 L
s
.42029 .17224 m
.42002 .18164 L
s
.559 .267 1 r
.71716 .18376 m
.71709 .18376 L
s
.834 .201 1 r
.54084 .15639 m
.54086 .16606 L
s
.54088 .166 m
.54084 .15639 L
s
.54084 .15639 m
.54097 .17541 L
s
.702 .231 1 r
.6564 .16867 m
.65679 .17813 L
s
.65683 .17747 m
.6564 .16867 L
s
.65679 .17813 m
.65643 .16862 L
s
.65643 .16862 m
.65683 .17747 L
s
.711 .229 1 r
.69357 .11089 m
.69625 .15584 L
s
.531 .274 1 r
.43694 .18105 m
.43687 .18139 L
s
.711 .229 1 r
.74956 .15455 m
.7502 .16393 L
s
.75023 .16388 m
.74956 .15455 L
s
.74956 .15455 m
.75091 .17298 L
s
.765 .217 1 r
.50848 .18657 m
.50841 .18677 L
s
.588 .259 1 r
.68386 .16777 m
.68431 .17684 L
s
.68436 .17649 m
.68386 .16777 L
s
.494 .284 1 r
.7113 .16626 m
.71181 .17505 L
s
.71186 .17475 m
.7113 .16626 L
s
.722 .227 1 r
.53974 .11058 m
.5402 .15748 L
s
.588 .259 1 r
.68431 .17684 m
.68389 .16772 L
s
.68389 .16772 m
.68436 .17649 L
s
.494 .284 1 r
.71181 .17505 m
.71132 .16621 L
s
.71132 .16621 m
.71186 .17475 L
s
.638 .247 1 r
.47512 .17019 m
.47497 .17927 L
s
.47503 .1793 m
.47512 .17019 L
s
.4 .312 1 r
.58488 .16414 m
.58504 .17266 L
s
.58509 .17231 m
.58488 .16414 L
s
.638 .247 1 r
.47497 .17927 m
.47514 .17014 L
s
.47514 .17014 m
.47503 .1793 L
s
.459 .295 1 r
.46929 .15195 m
.46911 .16059 L
s
.46913 .16055 m
.46929 .15195 L
s
.46929 .15195 m
.46901 .16909 L
s
.638 .247 1 r
.40949 .18317 m
.40941 .18348 L
s
.4 .312 1 r
.58504 .17266 m
.5849 .16409 L
s
.5849 .16409 m
.58509 .17231 L
s
.744 .222 1 r
.59574 .15447 m
.59592 .16394 L
s
.59594 .16389 m
.59574 .15447 L
s
.59574 .15447 m
.59618 .17306 L
s
.579 .262 1 r
.61825 .18113 m
.6182 .18156 L
s
.916 .184 1 r
.72106 .11028 m
.7243 .15756 L
s
.811 .206 1 r
.38203 .1853 m
.38194 .18577 L
s
.504 .282 1 r
.65063 .15179 m
.65095 .1606 L
s
.65097 .16055 m
.65063 .15179 L
s
.65063 .15179 m
.65135 .16917 L
s
.352 .327 1 r
.70553 .14889 m
.70598 .15726 L
s
.706 .15721 m
.70553 .14889 L
s
.70553 .14889 m
.70649 .16529 L
s
.8 .209 1 r
.56719 .10997 m
.56806 .15571 L
s
.659 .242 1 r
.41439 .15577 m
.41404 .16485 L
s
.41406 .1648 m
.41439 .15577 L
s
.41439 .15577 m
.41377 .17413 L
s
.579 .262 1 r
.55746 .16657 m
.55754 .17564 L
s
.55761 .17521 m
.55746 .16657 L
s
.777 .214 1 r
.44184 .1544 m
.44156 .16395 L
s
.44158 .1639 m
.44184 .1544 L
s
.44184 .1544 m
.44138 .17315 L
s
.579 .262 1 r
.55754 .17564 m
.55748 .16652 L
s
.55748 .16652 m
.55761 .17521 L
s
.799 .209 1 r
.74858 .10967 m
.75214 .15579 L
s
.398 .631 1 r
.72216 .1578 m
.72264 .16542 L
s
.72267 .16512 m
.72216 .1578 L
s
.72264 .16542 m
.72219 .15776 L
s
.72219 .15776 m
.72267 .16512 L
s
.599 .257 1 r
.73885 .16628 m
.73947 .17542 L
s
.7395 .17492 m
.73885 .16628 L
s
.73947 .17542 m
.73888 .16622 L
s
.73888 .16622 m
.7395 .17492 L
s
.441 .3 1 r
.51925 .17851 m
.51919 .1787 L
s
.701 .232 1 r
.62322 .15437 m
.62348 .16365 L
s
.62351 .1636 m
.62322 .15437 L
s
.62322 .15437 m
.62383 .17286 L
s
.799 .209 1 r
.59466 .10936 m
.59595 .15588 L
s
.845 .199 1 r
.50256 .17052 m
.50248 .18022 L
s
.50256 .17987 m
.50256 .17052 L
s
.50248 .18022 m
.50258 .17047 L
s
.50258 .17047 m
.50256 .17987 L
s
.522 .277 1 r
.52418 .15082 m
.52415 .15971 L
s
.52417 .15966 m
.52418 .15082 L
s
.52418 .15082 m
.52421 .16828 L
s
.442 .299 1 r
.72814 .17685 m
.72811 .17727 L
s
1 .106 .673 r
.58007 .19441 m
.58 .19458 L
s
.88 .191 1 r
.5634 .18616 m
.56333 .18651 L
s
.701 .232 1 r
.49673 .15279 m
.49661 .16214 L
s
.49664 .16209 m
.49673 .15279 L
s
.49673 .15279 m
.49659 .17119 L
s
.618 .252 1 r
.4918 .18102 m
.49173 .18137 L
s
.658 .242 1 r
.62215 .10875 m
.62379 .15372 L
s
.469 .292 1 r
.66735 .16236 m
.66774 .17119 L
s
.66777 .17053 m
.66735 .16236 L
s
.618 .252 1 r
.67819 .15245 m
.6786 .16154 L
s
.67863 .16149 m
.67819 .15245 L
s
.67819 .15245 m
.6791 .1705 L
s
.469 .292 1 r
.66774 .17119 m
.66737 .16231 L
s
.66737 .16231 m
.66777 .17053 L
s
.608 .254 1 r
.43094 .16629 m
.43066 .1754 L
s
.43074 .1751 m
.43094 .16629 L
s
.476 .29 1 r
.4584 .16478 m
.45821 .17346 L
s
.45828 .17335 m
.4584 .16478 L
s
.608 .254 1 r
.43066 .1754 m
.43096 .16624 L
s
.43096 .16624 m
.43074 .1751 L
s
.476 .29 1 r
.45821 .17346 m
.45842 .16473 L
s
.45842 .16473 m
.45828 .17335 L
s
.701 .232 1 r
.46433 .18314 m
.46425 .18334 L
s
.477 .289 1 r
.46815 .10844 m
.46761 .15033 L
s
.648 .244 1 r
.76645 .1666 m
.76715 .17583 L
s
.76719 .17548 m
.76645 .1666 L
s
1 .156 .946 r
.53595 .18868 m
.53587 .189 L
s
.648 .244 1 r
.76715 .17583 m
.76648 .16655 L
s
.76648 .16655 m
.76719 .17548 L
s
.639 .247 1 r
.61243 .16599 m
.61268 .17522 L
s
.61274 .17479 m
.61243 .16599 L
s
.61268 .17522 m
.61246 .16594 L
s
.61246 .16594 m
.61274 .17479 L
s
.722 .227 1 r
.40346 .16842 m
.40308 .17777 L
s
.40316 .17761 m
.40346 .16842 L
s
.67 .239 1 r
.64965 .10814 m
.65176 .15466 L
s
.722 .227 1 r
.40308 .17777 m
.40348 .16837 L
s
.40348 .16837 m
.40316 .17761 L
s
.68 .237 1 r
.55167 .15132 m
.55172 .16064 L
s
.55174 .16059 m
.55167 .15132 L
s
.55167 .15132 m
.55186 .1696 L
s
.822 .204 1 r
.49561 .10783 m
.49542 .15475 L
s
.66 .241 1 r
.54674 .17983 m
.54668 .18034 L
s
.608 .254 1 r
.57915 .15031 m
.57928 .15943 L
s
.5793 .15938 m
.57915 .15031 L
s
.57915 .15031 m
.57949 .16824 L
s
.744 .222 1 r
.67717 .10753 m
.67964 .15289 L
s
1 .151 .92 r
.53003 .17177 m
.53004 .18199 L
s
.53011 .18159 m
.53003 .17177 L
s
.53004 .18199 m
.53006 .17171 L
s
.53006 .17171 m
.53011 .18159 L
s
.433 .302 1 r
.45253 .14842 m
.45231 .15699 L
s
.45233 .15695 m
.45253 .14842 L
s
.45253 .14842 m
.45217 .16541 L
s
.744 .222 1 r
.73327 .15148 m
.73387 .16095 L
s
.73389 .1609 m
.73327 .15148 L
s
.73327 .15148 m
.73453 .17008 L
s
.551 .269 1 r
.52309 .10722 m
.5233 .14988 L
s
.711 .229 1 r
.70086 .18128 m
.70081 .18164 L
s
1 .166 .998 r
.59092 .1875 m
.59086 .18766 L
s
1 .161 .972 r
.77253 .18682 m
.77249 .18717 L
s
.589 .259 1 r
.60666 .14944 m
.60686 .15852 L
s
.60688 .15847 m
.60666 .14944 L
s
.60666 .14944 m
.60715 .16725 L
s
.608 .254 1 r
.48585 .16572 m
.48573 .17476 L
s
.48579 .17468 m
.48585 .16572 L
s
.588 .259 1 r
.51334 .1642 m
.5133 .17327 L
s
.51337 .17292 m
.51334 .1642 L
s
.942 .178 1 r
.64591 .18477 m
.64586 .18521 L
s
.618 .252 1 r
.70471 .10691 m
.70748 .15074 L
s
.608 .254 1 r
.48573 .17476 m
.48587 .16567 L
s
.48587 .16567 m
.48579 .17468 L
s
.588 .259 1 r
.5133 .17327 m
.51336 .16415 L
s
.51336 .16415 m
.51337 .17292 L
s
.734 .224 1 r
.76081 .15057 m
.76148 .16005 L
s
.76151 .15999 m
.76081 .15057 L
s
.76081 .15057 m
.76223 .16909 L
s
.629 .249 1 r
.69497 .1636 m
.69546 .17286 L
s
.6955 .17224 m
.69497 .1636 L
s
.69546 .17286 m
.695 .16355 L
s
.695 .16355 m
.6955 .17224 L
s
.711 .229 1 r
.55058 .10661 m
.5512 .15159 L
s
.476 .29 1 r
.66167 .14733 m
.66202 .15609 L
s
.66204 .15604 m
.66167 .14733 L
s
.66167 .14733 m
.66244 .16452 L
s
.618 .252 1 r
.60175 .17865 m
.60169 .179 L
s
.799 .209 1 r
.42502 .15138 m
.42469 .16097 L
s
.42471 .16092 m
.42502 .15138 L
s
.42502 .15138 m
.42445 .17025 L
s
.4 .312 1 r
.68917 .14604 m
.68959 .15457 L
s
.68961 .15453 m
.68917 .14604 L
s
.68917 .14604 m
.69007 .16276 L
s
.722 .227 1 r
.73226 .1063 m
.73556 .15206 L
s
.799 .209 1 r
.64002 .16754 m
.64037 .1771 L
s
.64043 .1769 m
.64002 .16754 L
s
.64037 .1771 m
.64005 .16749 L
s
.64005 .16749 m
.64043 .1769 L
s
.618 .252 1 r
.44757 .17836 m
.4475 .1787 L
s
.892 .189 1 r
.67346 .18457 m
.6734 .18473 L
s
.744 .221 1 r
.57427 .18078 m
.5742 .18113 L
s
.869 .194 1 r
.57809 .10599 m
.57915 .15292 L
s
.711 .229 1 r
.75597 .1801 m
.75593 .18045 L
s
.494 .284 1 r
.5075 .14729 m
.50742 .1561 L
s
.50744 .15605 m
.5075 .14729 L
s
.5075 .14729 m
.50743 .1646 L
s
.598 .257 1 r
.62928 .17845 m
.62922 .1786 L
s
.744 .222 1 r
.60562 .10538 m
.60706 .15154 L
s
.702 .231 1 r
.65683 .17747 m
.65679 .17813 L
s
.669 .239 1 r
.56836 .16393 m
.56848 .1732 L
s
.56855 .17289 m
.56836 .16393 L
s
.4 .312 1 r
.58509 .17231 m
.58504 .17266 L
s
.669 .239 1 r
.56848 .1732 m
.56839 .16388 L
s
.56839 .16388 m
.56855 .17289 L
s
.494 .284 1 r
.71186 .17475 m
.71181 .17505 L
s
.733 .224 1 r
.42002 .18164 m
.41995 .18161 L
s
.425 .305 1 r
.74432 .14506 m
.74489 .15368 L
s
.74491 .15363 m
.74432 .14506 L
s
.74432 .14506 m
.74552 .16194 L
s
.588 .259 1 r
.68436 .17649 m
.68431 .17684 L
s
.398 .631 1 r
.72267 .16512 m
.72264 .16542 L
s
.459 .295 1 r
.46911 .16059 m
.46895 .16924 L
s
.46901 .16909 m
.46911 .16059 L
s
.69 .234 1 r
.63316 .10476 m
.63499 .15015 L
s
.459 .295 1 r
.46895 .16924 m
.46913 .16055 L
s
.46913 .16055 m
.46901 .16909 L
s
.834 .201 1 r
.54086 .16606 m
.5409 .17573 L
s
.54097 .17541 m
.54086 .16606 L
s
.5409 .17573 m
.54088 .166 L
s
.54088 .166 m
.54097 .17541 L
s
.711 .229 1 r
.7502 .16393 m
.75086 .17333 L
s
.75091 .17298 m
.7502 .16393 L
s
.75086 .17333 m
.75023 .16388 L
s
.75023 .16388 m
.75091 .17298 L
s
.928 .181 1 r
.63429 .15177 m
.6346 .16161 L
s
.63463 .16155 m
.63429 .15177 L
s
.63429 .15177 m
.635 .17129 L
s
.638 .247 1 r
.47503 .1793 m
.47497 .17927 L
s
.618 .252 1 r
.71685 .14726 m
.71738 .15643 L
s
.7174 .15637 m
.71685 .14726 L
s
.71685 .14726 m
.71798 .16524 L
s
.352 .327 1 r
.70598 .15726 m
.70645 .16563 L
s
.70649 .16529 m
.70598 .15726 L
s
.755 .219 1 r
.47887 .10446 m
.47844 .14985 L
s
.352 .327 1 r
.70645 .16563 m
.706 .15721 L
s
.706 .15721 m
.70649 .16529 L
s
.504 .282 1 r
.65095 .1606 m
.6513 .1694 L
s
.65135 .16917 m
.65095 .1606 L
s
.6513 .1694 m
.65097 .16055 L
s
.65097 .16055 m
.65135 .16917 L
s
.579 .262 1 r
.55761 .17521 m
.55754 .17564 L
s
.618 .252 1 r
.56255 .14696 m
.56263 .15613 L
s
.56265 .15607 m
.56255 .14696 L
s
.56255 .14696 m
.56279 .16494 L
s
.869 .194 1 r
.66072 .10415 m
.66311 .15303 L
s
.744 .222 1 r
.59592 .16394 m
.59612 .17342 L
s
.59618 .17306 m
.59592 .16394 L
s
.59612 .17342 m
.59594 .16389 L
s
.59594 .16389 m
.59618 .17306 L
s
.777 .214 1 r
.53503 .1487 m
.53503 .15826 L
s
.53505 .15821 m
.53503 .1487 L
s
.53503 .1487 m
.53512 .16747 L
s
.659 .242 1 r
.41404 .16485 m
.41371 .17394 L
s
.41377 .17413 m
.41404 .16485 L
s
.41371 .17394 m
.41406 .1648 L
s
.41406 .1648 m
.41377 .17413 L
s
.788 .211 1 r
.47997 .15193 m
.4798 .1613 L
s
.47982 .16125 m
.47997 .15193 L
s
.47997 .15193 m
.47972 .17098 L
s
.599 .257 1 r
.7395 .17492 m
.73947 .17542 L
s
.658 .242 1 r
.50639 .10384 m
.50636 .14885 L
s
.777 .214 1 r
.44156 .16395 m
.4413 .1735 L
s
.44138 .17315 m
.44156 .16395 L
s
.618 .252 1 r
.6883 .10354 m
.69085 .14738 L
s
.777 .214 1 r
.4413 .1735 m
.44158 .1639 L
s
.44158 .1639 m
.44138 .17315 L
s
.638 .247 1 r
.5901 .14663 m
.59026 .15583 L
s
.59028 .15578 m
.5901 .14663 L
s
.5901 .14663 m
.5905 .16473 L
s
.522 .277 1 r
.52415 .15971 m
.52414 .16859 L
s
.52421 .16828 m
.52415 .15971 L
s
.52414 .16859 m
.52417 .15966 L
s
.52417 .15966 m
.52421 .16828 L
s
.701 .232 1 r
.62348 .16365 m
.62376 .17294 L
s
.62383 .17286 m
.62348 .16365 L
s
.469 .292 1 r
.66777 .17053 m
.66774 .17119 L
s
.701 .232 1 r
.62376 .17294 m
.62351 .1636 L
s
.62351 .1636 m
.62383 .17286 L
s
.94 .179 1 r
.53392 .10323 m
.53432 .15134 L
s
.845 .199 1 r
.50256 .17987 m
.50248 .18022 L
s
.589 .259 1 r
.71589 .10292 m
.71882 .14678 L
s
.476 .29 1 r
.45828 .17335 m
.45821 .17346 L
s
.701 .232 1 r
.49661 .16214 m
.49652 .1715 L
s
.49659 .17119 m
.49661 .16214 L
s
.608 .254 1 r
.43074 .1751 m
.43066 .1754 L
s
.701 .232 1 r
.49652 .1715 m
.49664 .16209 L
s
.49664 .16209 m
.49659 .17119 L
s
.618 .252 1 r
.6786 .16154 m
.67904 .17062 L
s
.6791 .1705 m
.6786 .16154 L
s
.711 .229 1 r
.56147 .10261 m
.56225 .14763 L
s
.618 .252 1 r
.67904 .17062 m
.67863 .16149 L
s
.67863 .16149 m
.6791 .1705 L
s
.648 .244 1 r
.76719 .17548 m
.76715 .17583 L
s
.766 .217 1 r
.43568 .14724 m
.43538 .15676 L
s
.4354 .15671 m
.43568 .14724 L
s
.43568 .14724 m
.43517 .16597 L
s
.639 .247 1 r
.61274 .17479 m
.61268 .17522 L
s
.658 .242 1 r
.61768 .14663 m
.61792 .15584 L
s
.61795 .15579 m
.61768 .14663 L
s
.61768 .14663 m
.61825 .1649 L
s
.904 .186 1 r
.7435 .1023 m
.74712 .15003 L
s
.722 .227 1 r
.40316 .17761 m
.40308 .17777 L
s
.628 .249 1 r
.58904 .102 m
.5902 .14663 L
s
.648 .244 1 r
.49076 .14508 m
.49063 .15433 L
s
.49065 .15427 m
.49076 .14508 L
s
.49076 .14508 m
.49059 .16322 L
s
.68 .237 1 r
.55172 .16064 m
.55179 .16996 L
s
.55186 .1696 m
.55172 .16064 L
s
.55179 .16996 m
.55174 .16059 L
s
.55174 .16059 m
.55186 .1696 L
s
.433 .302 1 r
.45231 .15699 m
.4521 .16557 L
s
.45217 .16541 m
.45231 .15699 L
s
.4521 .16557 m
.45233 .15695 L
s
.45233 .15695 m
.45217 .16541 L
s
.608 .254 1 r
.57928 .15943 m
.57943 .16855 L
s
.57949 .16824 m
.57928 .15943 L
s
.57943 .16855 m
.5793 .15938 L
s
.5793 .15938 m
.57949 .16824 L
s
.638 .247 1 r
.61662 .10138 m
.6182 .14679 L
s
.588 .259 1 r
.51337 .17292 m
.5133 .17327 L
s
.589 .259 1 r
.60686 .15852 m
.60709 .1676 L
s
.60715 .16725 m
.60686 .15852 L
s
.629 .249 1 r
.6955 .17224 m
.69546 .17286 L
s
.589 .259 1 r
.60709 .1676 m
.60688 .15847 L
s
.60688 .15847 m
.60715 .16725 L
s
.744 .222 1 r
.73387 .16095 m
.73449 .17043 L
s
.73453 .17008 m
.73387 .16095 L
s
.608 .254 1 r
.48579 .17468 m
.48573 .17476 L
s
1 .151 .92 r
.53011 .18159 m
.53004 .18199 L
s
.744 .222 1 r
.73449 .17043 m
.73389 .1609 L
s
.73389 .1609 m
.73453 .17008 L
s
.531 .274 1 r
.72802 .14266 m
.72857 .15159 L
s
.72859 .15154 m
.72802 .14266 L
s
.72802 .14266 m
.72918 .16018 L
s
.833 .201 1 r
.46318 .14812 m
.46296 .15769 L
s
.46298 .15764 m
.46318 .14812 L
s
.46318 .14812 m
.46283 .1673 L
s
.649 .244 1 r
.64422 .10076 m
.64617 .14502 L
s
.476 .29 1 r
.66202 .15609 m
.66239 .16486 L
s
.66244 .16452 m
.66202 .15609 L
s
.4 .312 1 r
.68959 .15457 m
.69003 .1631 L
s
.69007 .16276 m
.68959 .15457 L
s
.476 .29 1 r
.66239 .16486 m
.66204 .15604 L
s
.66204 .15604 m
.66244 .16452 L
s
.4 .312 1 r
.69003 .1631 m
.68961 .15453 L
s
.68961 .15453 m
.69007 .16276 L
s
.734 .224 1 r
.76148 .16005 m
.76219 .16952 L
s
.76223 .16909 m
.76148 .16005 L
s
.76219 .16952 m
.76151 .15999 L
s
.76151 .15999 m
.76223 .16909 L
s
.669 .239 1 r
.70049 .14479 m
.70097 .15404 L
s
.701 .15398 m
.70049 .14479 L
s
.70049 .14479 m
.70154 .16309 L
s
.712 .229 1 r
.48963 .10046 m
.48937 .1451 L
s
.494 .284 1 r
.50742 .1561 m
.50736 .16491 L
s
.50743 .1646 m
.50742 .1561 L
s
.928 .181 1 r
.67184 .10015 m
.67437 .14828 L
s
.494 .284 1 r
.50736 .16491 m
.50744 .15605 L
s
.50744 .15605 m
.50743 .1646 L
s
.904 .186 1 r
.67296 .14699 m
.67339 .15679 L
s
.67341 .15673 m
.67296 .14699 L
s
.67296 .14699 m
.6739 .1664 L
s
.799 .209 1 r
.64043 .1769 m
.64037 .1771 L
s
.916 .184 1 r
.51833 .1463 m
.51827 .15618 L
s
.5183 .15613 m
.51833 .1463 L
s
.51833 .1463 m
.51832 .16571 L
s
.799 .209 1 r
.42469 .16097 m
.42437 .17057 L
s
.42445 .17025 m
.42469 .16097 L
s
.42437 .17057 m
.42471 .16092 L
s
.42471 .16092 m
.42445 .17025 L
s
.51721 .09984 m
.51734 .14642 L
s
.578 .262 1 r
.75572 .14289 m
.75635 .15191 L
s
.75638 .15186 m
.75572 .14289 L
s
.75572 .14289 m
.75706 .16073 L
s
.845 .199 1 r
.54591 .14524 m
.54594 .15496 L
s
.54597 .15491 m
.54591 .14524 L
s
.54591 .14524 m
.54607 .16434 L
s
.618 .252 1 r
.69947 .09953 m
.70218 .14341 L
s
.578 .262 1 r
.60108 .14259 m
.60126 .15161 L
s
.60129 .15155 m
.60108 .14259 L
s
.60108 .14259 m
.60154 .16043 L
s
.425 .305 1 r
.74489 .15368 m
.74548 .16229 L
s
.74552 .16194 m
.74489 .15368 L
s
.94 .179 1 r
.5448 .09922 m
.54536 .14736 L
s
.425 .305 1 r
.74548 .16229 m
.74491 .15363 L
s
.74491 .15363 m
.74552 .16194 L
s
.669 .239 1 r
.56855 .17289 m
.56848 .1732 L
s
.459 .295 1 r
.46901 .16909 m
.46895 .16924 L
s
.352 .327 1 r
.70649 .16529 m
.70645 .16563 L
s
.559 .267 1 r
.72712 .09891 m
.73017 .14202 L
s
.916 .184 1 r
.57352 .1451 m
.57364 .15498 L
s
.57366 .15492 m
.57352 .1451 L
s
.57352 .1451 m
.57385 .16451 L
s
.344 .33 1 r
.52915 .13842 m
.52913 .14673 L
s
.52915 .14668 m
.52915 .13842 L
s
.52915 .13842 m
.5292 .15485 L
s
.503 .282 1 r
.5724 .0986 m
.57328 .14094 L
s
.711 .229 1 r
.75091 .17298 m
.75086 .17333 L
s
.504 .282 1 r
.65135 .16917 m
.6513 .1694 L
s
.834 .201 1 r
.54097 .17541 m
.5409 .17573 L
s
.618 .252 1 r
.71738 .15643 m
.71793 .16559 L
s
.71798 .16524 m
.71738 .15643 L
s
.71793 .16559 m
.7174 .15637 L
s
.7174 .15637 m
.71798 .16524 L
s
.56263 .15613 m
.56273 .16529 L
s
.56279 .16494 m
.56263 .15613 L
s
.56273 .16529 m
.56265 .15607 L
s
.56265 .15607 m
.56279 .16494 L
s
.928 .181 1 r
.6346 .16161 m
.63494 .17145 L
s
.635 .17129 m
.6346 .16161 L
s
.744 .222 1 r
.59618 .17306 m
.59612 .17342 L
s
.928 .181 1 r
.63494 .17145 m
.63463 .16155 L
s
.63463 .16155 m
.635 .17129 L
s
.734 .224 1 r
.60003 .09798 m
.60141 .14536 L
s
.659 .242 1 r
.41377 .17413 m
.41371 .17394 L
s
.701 .232 1 r
.47396 .14259 m
.47377 .15193 L
s
.47379 .15187 m
.47396 .14259 L
s
.47396 .14259 m
.47368 .16107 L
s
.822 .204 1 r
.44635 .14415 m
.44608 .15376 L
s
.4461 .15371 m
.44635 .14415 L
s
.44635 .14415 m
.4459 .16322 L
s
.788 .211 1 r
.4798 .1613 m
.47965 .17068 L
s
.47972 .17098 m
.4798 .1613 L
s
.777 .214 1 r
.53503 .15826 m
.53505 .16782 L
s
.53512 .16747 m
.53503 .15826 L
s
.788 .211 1 r
.47965 .17068 m
.47982 .16125 L
s
.47982 .16125 m
.47972 .17098 L
s
.777 .214 1 r
.53505 .16782 m
.53505 .15821 L
s
.53505 .15821 m
.53512 .16747 L
s
.522 .277 1 r
.52421 .16828 m
.52414 .16859 L
s
.679 .237 1 r
.65638 .14237 m
.65673 .15163 L
s
.65676 .15158 m
.65638 .14237 L
s
.65638 .14237 m
.65718 .16077 L
s
.777 .214 1 r
.44138 .17315 m
.4413 .1735 L
s
.868 .194 1 r
.62878 .14404 m
.62907 .15377 L
s
.62909 .15371 m
.62878 .14404 L
s
.62878 .14404 m
.62945 .1633 L
s
.62767 .09737 m
.62951 .14552 L
s
.638 .247 1 r
.59026 .15583 m
.59044 .16504 L
s
.5905 .16473 m
.59026 .15583 L
s
.59044 .16504 m
.59028 .15578 L
s
.59028 .15578 m
.5905 .16473 L
s
.701 .232 1 r
.62383 .17286 m
.62376 .17294 L
s
.811 .206 1 r
.50156 .14229 m
.50146 .15194 L
s
.50148 .15189 m
.50156 .14229 L
s
.50156 .14229 m
.50145 .16124 L
s
1 .07 .462 r
.64558 .15305 m
.64595 .16386 L
s
.64598 .1638 m
.64558 .15305 L
s
.64558 .15305 m
.64645 .17514 L
s
.701 .232 1 r
.49659 .17119 m
.49652 .1715 L
s
.822 .204 1 r
.65532 .09675 m
.65755 .14375 L
s
.618 .252 1 r
.6791 .1705 m
.67904 .17062 L
s
.588 .259 1 r
.73932 .13918 m
.7399 .14828 L
s
.73993 .14822 m
.73932 .13918 L
s
.73932 .13918 m
.74056 .15703 L
s
.589 .259 1 r
.50044 .09644 m
.50033 .13957 L
s
.904 .186 1 r
.6841 .14272 m
.68456 .15256 L
s
.68459 .15251 m
.6841 .14272 L
s
.6841 .14272 m
.68511 .1621 L
s
.658 .242 1 r
.61792 .15584 m
.61819 .16506 L
s
.61825 .1649 m
.61792 .15584 L
s
.61819 .16506 m
.61795 .15579 L
s
.61795 .15579 m
.61825 .1649 L
s
.766 .217 1 r
.43538 .15676 m
.43509 .16629 L
s
.43517 .16597 m
.43538 .15676 L
s
1 .156 .946 r
.68299 .09613 m
.68579 .14585 L
s
.766 .217 1 r
.43509 .16629 m
.4354 .15671 L
s
.4354 .15671 m
.43517 .16597 L
s
.433 .302 1 r
.45217 .16541 m
.4521 .16557 L
s
.834 .201 1 r
.55682 .141 m
.55689 .15073 L
s
.55691 .15067 m
.55682 .141 L
s
.55682 .141 m
.55705 .16003 L
s
.416 .307 1 r
.52807 .09582 m
.52833 .1374 L
s
.68 .237 1 r
.55186 .1696 m
.55179 .16996 L
s
.648 .244 1 r
.49063 .15433 m
.49052 .16357 L
s
.49059 .16322 m
.49063 .15433 L
s
.49052 .16357 m
.49065 .15427 L
s
.49065 .15427 m
.49059 .16322 L
s
.608 .254 1 r
.57949 .16824 m
.57943 .16855 L
s
.868 .194 1 r
.71179 .14222 m
.71234 .15196 L
s
.71237 .1519 m
.71179 .14222 L
s
.71179 .14222 m
.71297 .16149 L
s
.88 .191 1 r
.71068 .09551 m
.71376 .14252 L
s
.701 .232 1 r
.58446 .14017 m
.58461 .14951 L
s
.58463 .14946 m
.58446 .14017 L
s
.58446 .14017 m
.58484 .15865 L
s
.589 .259 1 r
.60715 .16725 m
.60709 .1676 L
s
.4 .312 1 r
.69007 .16276 m
.69003 .1631 L
s
.777 .214 1 r
.55571 .0952 m
.55641 .14066 L
s
.476 .29 1 r
.66244 .16452 m
.66239 .16486 L
s
.531 .274 1 r
.72857 .15159 m
.72914 .16052 L
s
.72918 .16018 m
.72857 .15159 L
s
.712 .229 1 r
.45712 .13853 m
.45688 .14799 L
s
.4569 .14793 m
.45712 .13853 L
s
.45712 .13853 m
.45675 .15697 L
s
.531 .274 1 r
.72914 .16052 m
.72859 .15154 L
s
.72859 .15154 m
.72918 .16018 L
s
.744 .222 1 r
.73453 .17008 m
.73449 .17043 L
s
.68 .237 1 r
.73839 .09489 m
.74171 .13957 L
s
.744 .221 1 r
.58338 .09458 m
.58449 .14043 L
s
.734 .224 1 r
.76223 .16909 m
.76219 .16952 L
s
.833 .201 1 r
.46296 .15769 m
.46276 .16727 L
s
.46283 .1673 m
.46296 .15769 L
s
.494 .284 1 r
.50743 .1646 m
.50736 .16491 L
s
.833 .201 1 r
.46276 .16727 m
.46298 .15764 L
s
.46298 .15764 m
.46283 .1673 L
s
.522 .277 1 r
.5124 .13633 m
.51233 .14524 L
s
.51235 .14519 m
.5124 .13633 L
s
.5124 .13633 m
.51235 .15383 L
s
.669 .239 1 r
.70097 .15404 m
.70149 .16329 L
s
.70154 .16309 m
.70097 .15404 L
s
.70149 .16329 m
.701 .15398 L
s
.701 .15398 m
.70154 .16309 L
s
.81 .206 1 r
.61216 .14056 m
.6124 .15014 L
s
.61242 .15008 m
.61216 .14056 L
s
.61216 .14056 m
.61272 .1596 L
s
.68 .237 1 r
.61106 .09396 m
.61254 .13865 L
s
.799 .209 1 r
.42445 .17025 m
.42437 .17057 L
s
.578 .262 1 r
.75635 .15191 m
.75701 .16092 L
s
.75706 .16073 m
.75635 .15191 L
s
.75701 .16092 m
.75638 .15186 L
s
.75638 .15186 m
.75706 .16073 L
s
.425 .305 1 r
.74552 .16194 m
.74548 .16229 L
s
.904 .186 1 r
.67339 .15679 m
.67384 .1666 L
s
.6739 .1664 m
.67339 .15679 L
s
.754 .219 1 r
.48474 .13915 m
.48458 .14861 L
s
.48461 .14856 m
.48474 .13915 L
s
.48474 .13915 m
.48452 .15791 L
s
.904 .186 1 r
.67384 .1666 m
.67341 .15673 L
s
.67341 .15673 m
.6739 .1664 L
s
.916 .184 1 r
.51827 .15618 m
.51824 .16607 L
s
.51832 .16571 m
.51827 .15618 L
s
.578 .262 1 r
.60126 .15161 m
.60147 .16062 L
s
.60154 .16043 m
.60126 .15161 L
s
.916 .184 1 r
.51824 .16607 m
.5183 .15613 L
s
.5183 .15613 m
.51832 .16571 L
s
.578 .262 1 r
.60147 .16062 m
.60129 .15155 L
s
.60129 .15155 m
.60154 .16043 L
s
.722 .227 1 r
.66753 .13862 m
.66792 .148 L
s
.66795 .14795 m
.66753 .13862 L
s
.66753 .13862 m
.6684 .15723 L
s
.467 .292 1 r
.63875 .09334 m
.64052 .13533 L
s
.845 .199 1 r
.54594 .15496 m
.546 .16469 L
s
.54607 .16434 m
.54594 .15496 L
s
.904 .186 1 r
.63988 .14033 m
.6402 .15014 L
s
.64023 .15009 m
.63988 .14033 L
s
.63988 .14033 m
.64062 .15976 L
s
.845 .199 1 r
.546 .16469 m
.54597 .15491 L
s
.54597 .15491 m
.54607 .16434 L
s
.711 .229 1 r
.69522 .13736 m
.69569 .14678 L
s
.69572 .14672 m
.69522 .13736 L
s
.69522 .13736 m
.69625 .15584 L
s
.344 .33 1 r
.52913 .14673 m
.52913 .15503 L
s
.5292 .15485 m
.52913 .14673 L
s
.52913 .15503 m
.52915 .14668 L
s
.52915 .14668 m
.5292 .15485 L
s
.777 .214 1 r
.66646 .09272 m
.66881 .13858 L
s
.618 .252 1 r
.71798 .16524 m
.71793 .16559 L
s
.67 .239 1 r
.51128 .0924 m
.51132 .13789 L
s
.916 .184 1 r
.57364 .15498 m
.57378 .16486 L
s
.57385 .16451 m
.57364 .15498 L
s
.618 .252 1 r
.56279 .16494 m
.56273 .16529 L
s
.916 .184 1 r
.57378 .16486 m
.57366 .15492 L
s
.57366 .15492 m
.57385 .16451 L
s
.578 .262 1 r
.69419 .09209 m
.69683 .13602 L
s
.8 .209 1 r
.56778 .13682 m
.56787 .14648 L
s
.5679 .14643 m
.56778 .13682 L
s
.56778 .13682 m
.56806 .15571 L
s
.477 .289 1 r
.4679 .1331 m
.46771 .14188 L
s
.46773 .14183 m
.4679 .1331 L
s
.4679 .1331 m
.46761 .15033 L
s
.722 .227 1 r
.54008 .13874 m
.54009 .14801 L
s
.54012 .14796 m
.54008 .13874 L
s
.54008 .13874 m
.5402 .15748 L
s
.881 .191 1 r
.53897 .09178 m
.53944 .13843 L
s
.701 .232 1 r
.47377 .15193 m
.47361 .16127 L
s
.47368 .16107 m
.47377 .15193 L
s
.916 .184 1 r
.72304 .13812 m
.72363 .14802 L
s
.72366 .14796 m
.72304 .13812 L
s
.72304 .13812 m
.7243 .15756 L
s
.701 .232 1 r
.47361 .16127 m
.47379 .15187 L
s
.47379 .15187 m
.47368 .16107 L
s
.928 .181 1 r
.635 .17129 m
.63494 .17145 L
s
.777 .214 1 r
.53512 .16747 m
.53505 .16782 L
s
.822 .204 1 r
.44608 .15376 m
.44582 .16338 L
s
.4459 .16322 m
.44608 .15376 L
s
.799 .209 1 r
.75075 .13687 m
.75141 .14649 L
s
.75144 .14643 m
.75075 .13687 L
s
.75075 .13687 m
.75214 .15579 L
s
.822 .204 1 r
.44582 .16338 m
.4461 .15371 L
s
.4461 .15371 m
.4459 .16322 L
s
.834 .201 1 r
.72194 .09147 m
.72516 .13812 L
s
.788 .211 1 r
.47972 .17098 m
.47965 .17068 L
s
.679 .237 1 r
.65673 .15163 m
.65712 .16089 L
s
.65718 .16077 m
.65673 .15163 L
s
.65712 .16089 m
.65676 .15158 L
s
.65676 .15158 m
.65718 .16077 L
s
.638 .247 1 r
.5905 .16473 m
.59044 .16504 L
s
.744 .222 1 r
.56667 .09116 m
.56753 .13665 L
s
.868 .194 1 r
.62907 .15377 m
.62938 .1635 L
s
.62945 .1633 m
.62907 .15377 L
s
.62938 .1635 m
.62909 .15371 L
s
.62909 .15371 m
.62945 .1633 L
s
.799 .209 1 r
.5955 .13691 m
.59568 .14649 L
s
.5957 .14643 m
.5955 .13691 L
s
.5955 .13691 m
.59595 .15588 L
s
.658 .242 1 r
.62319 .13542 m
.62345 .14465 L
s
.62347 .1446 m
.62319 .13542 L
s
.62319 .13542 m
.62379 .15372 L
s
.811 .206 1 r
.50146 .15194 m
.50138 .16159 L
s
.50145 .16124 m
.50146 .15194 L
s
.50138 .16159 m
.50148 .15189 L
s
.50148 .15189 m
.50145 .16124 L
s
.588 .259 1 r
.7399 .14828 m
.74052 .15737 L
s
.74056 .15703 m
.7399 .14828 L
s
.777 .214 1 r
.59439 .09054 m
.59567 .13642 L
s
.588 .259 1 r
.74052 .15737 m
.73993 .14822 L
s
.73993 .14822 m
.74056 .15703 L
s
.551 .269 1 r
.52328 .13225 m
.52324 .14128 L
s
.52327 .14123 m
.52328 .13225 L
s
.52328 .13225 m
.5233 .14988 L
s
.658 .242 1 r
.61825 .1649 m
.61819 .16506 L
s
.766 .217 1 r
.43517 .16597 m
.43509 .16629 L
s
1 .07 .462 r
.64595 .16386 m
.64636 .17469 L
s
.64645 .17514 m
.64595 .16386 L
s
.503 .282 1 r
.62213 .08992 m
.62369 .13231 L
s
1 .07 .462 r
.64636 .17469 m
.64598 .1638 L
s
.64598 .1638 m
.64645 .17514 L
s
.648 .244 1 r
.49059 .16322 m
.49052 .16357 L
s
.904 .186 1 r
.68456 .15256 m
.68506 .16242 L
s
.68511 .1621 m
.68456 .15256 L
s
.68506 .16242 m
.68459 .15251 L
s
.68459 .15251 m
.68511 .1621 L
s
.744 .222 1 r
.6787 .13424 m
.67913 .14374 L
s
.67916 .14369 m
.6787 .13424 L
s
.6787 .13424 m
.67964 .15289 L
s
.618 .252 1 r
.70641 .13271 m
.70691 .1419 L
s
.70694 .14185 m
.70641 .13271 L
s
.70641 .13271 m
.70748 .15074 L
s
.834 .201 1 r
.55689 .15073 m
.55698 .16046 L
s
.55705 .16003 m
.55689 .15073 L
s
.67 .239 1 r
.65098 .13615 m
.65132 .14527 L
s
.65134 .14522 m
.65098 .13615 L
s
.65098 .13615 m
.65176 .15466 L
s
.834 .201 1 r
.55698 .16046 m
.55691 .15067 L
s
.55691 .15067 m
.55705 .16003 L
s
.94 .179 1 r
.64988 .08929 m
.65207 .13713 L
s
.531 .274 1 r
.72918 .16018 m
.72914 .16052 L
s
.701 .232 1 r
.58461 .14951 m
.58478 .15885 L
s
.58484 .15865 m
.58461 .14951 L
s
.822 .204 1 r
.49557 .13565 m
.49544 .14528 L
s
.49547 .14522 m
.49557 .13565 L
s
.49557 .13565 m
.49542 .15475 L
s
.701 .232 1 r
.58478 .15885 m
.58463 .14946 L
s
.58463 .14946 m
.58484 .15865 L
s
.868 .194 1 r
.71234 .15196 m
.71291 .16169 L
s
.71297 .16149 m
.71234 .15196 L
s
.71291 .16169 m
.71237 .1519 L
s
.71237 .1519 m
.71297 .16149 L
s
.711 .229 1 r
.55102 .13309 m
.55106 .14252 L
s
.55109 .14246 m
.55102 .13309 L
s
.55102 .13309 m
.5512 .15159 L
s
.712 .229 1 r
.45688 .14799 m
.45666 .15744 L
s
.45675 .15697 m
.45688 .14799 L
s
.69 .234 1 r
.67765 .08867 m
.68014 .13418 L
s
.712 .229 1 r
.45666 .15744 m
.4569 .14793 L
s
.4569 .14793 m
.45675 .15697 L
s
.522 .277 1 r
.51233 .14524 m
.51229 .15414 L
s
.51235 .15383 m
.51233 .14524 L
s
.51229 .15414 m
.51235 .14519 L
s
.51235 .14519 m
.51235 .15383 L
s
.52217 .08836 m
.52236 .13154 L
s
.669 .239 1 r
.70154 .16309 m
.70149 .16329 L
s
.833 .201 1 r
.46283 .1673 m
.46276 .16727 L
s
.722 .227 1 r
.73428 .13344 m
.73488 .14283 L
s
.73491 .14278 m
.73428 .13344 L
s
.73428 .13344 m
.73556 .15206 L
s
.373 .52 1 r
.70543 .08804 m
.70785 .12581 L
s
.578 .262 1 r
.75706 .16073 m
.75701 .16092 L
s
.81 .206 1 r
.6124 .15014 m
.61266 .15972 L
s
.61272 .1596 m
.6124 .15014 L
s
.61266 .15972 m
.61242 .15008 L
s
.61242 .15008 m
.61272 .1596 L
s
.69 .234 1 r
.54991 .08773 m
.55052 .13325 L
s
.344 .33 1 r
.5292 .15485 m
.52913 .15503 L
s
.578 .262 1 r
.60154 .16043 m
.60147 .16062 L
s
.869 .194 1 r
.57879 .13367 m
.57892 .14345 L
s
.57895 .1434 m
.57879 .13367 L
s
.57879 .13367 m
.57915 .15292 L
s
.766 .217 1 r
.73324 .08742 m
.73658 .13333 L
s
.754 .219 1 r
.48458 .14861 m
.48445 .15807 L
s
.48452 .15791 m
.48458 .14861 L
s
.48445 .15807 m
.48461 .14856 L
s
.48461 .14856 m
.48452 .15791 L
s
.904 .186 1 r
.6739 .1664 m
.67384 .1666 L
s
.722 .227 1 r
.66792 .148 m
.66834 .15738 L
s
.6684 .15723 m
.66792 .148 L
s
.916 .184 1 r
.51832 .16571 m
.51824 .16607 L
s
.733 .224 1 r
.57767 .08711 m
.5787 .13301 L
s
.722 .227 1 r
.66834 .15738 m
.66795 .14795 L
s
.66795 .14795 m
.6684 .15723 L
s
.845 .199 1 r
.54607 .16434 m
.546 .16469 L
s
.744 .222 1 r
.60655 .13279 m
.60676 .14222 L
s
.60679 .14217 m
.60655 .13279 L
s
.60655 .13279 m
.60706 .15154 L
s
.711 .229 1 r
.69569 .14678 m
.6962 .1562 L
s
.69625 .15584 m
.69569 .14678 L
s
.6962 .1562 m
.69572 .14672 L
s
.69572 .14672 m
.69625 .15584 L
s
.904 .186 1 r
.6402 .15014 m
.64056 .15996 L
s
.64062 .15976 m
.6402 .15014 L
s
.69 .234 1 r
.63431 .13168 m
.6346 .141 L
s
.63463 .14094 m
.63431 .13168 L
s
.63431 .13168 m
.63499 .15015 L
s
.904 .186 1 r
.64056 .15996 m
.64023 .15009 L
s
.64023 .15009 m
.64062 .15976 L
s
.755 .219 1 r
.47869 .13115 m
.47852 .14069 L
s
.47854 .14064 m
.47869 .13115 L
s
.47869 .13115 m
.47844 .14985 L
s
.618 .252 1 r
.60545 .08648 m
.60684 .13045 L
s
.68987 .12935 m
.69032 .13854 L
s
.69034 .13849 m
.68987 .12935 L
s
.68987 .12935 m
.69085 .14738 L
s
.477 .289 1 r
.46771 .14188 m
.46754 .15067 L
s
.46761 .15033 m
.46771 .14188 L
s
.46754 .15067 m
.46773 .14183 L
s
.46773 .14183 m
.46761 .15033 L
s
.658 .242 1 r
.50644 .13054 m
.50635 .13977 L
s
.50637 .13972 m
.50644 .13054 L
s
.50644 .13054 m
.50636 .14885 L
s
.916 .184 1 r
.57385 .16451 m
.57378 .16486 L
s
.658 .242 1 r
.63324 .08586 m
.63507 .131 L
s
.722 .227 1 r
.54009 .14801 m
.54013 .15729 L
s
.5402 .15748 m
.54009 .14801 L
s
.701 .232 1 r
.47368 .16107 m
.47361 .16127 L
s
.8 .209 1 r
.56787 .14648 m
.568 .15614 L
s
.56806 .15571 m
.56787 .14648 L
s
.722 .227 1 r
.54013 .15729 m
.54012 .14796 L
s
.54012 .14796 m
.5402 .15748 L
s
.8 .209 1 r
.568 .15614 m
.5679 .14643 L
s
.5679 .14643 m
.56806 .15571 L
s
.589 .259 1 r
.71769 .12885 m
.71822 .13793 L
s
.71825 .13788 m
.71769 .12885 L
s
.71769 .12885 m
.71882 .14678 L
s
.679 .237 1 r
.65718 .16077 m
.65712 .16089 L
s
.744 .222 1 r
.66105 .08523 m
.66334 .13154 L
s
.822 .204 1 r
.4459 .16322 m
.44582 .16338 L
s
.916 .184 1 r
.72363 .14802 m
.72425 .15792 L
s
.7243 .15756 m
.72363 .14802 L
s
.799 .209 1 r
.75141 .14649 m
.7521 .15611 L
s
.75214 .15579 m
.75141 .14649 L
s
.916 .184 1 r
.72425 .15792 m
.72366 .14796 L
s
.72366 .14796 m
.7243 .15756 L
s
.799 .209 1 r
.7521 .15611 m
.75144 .14643 L
s
.75144 .14643 m
.75214 .15579 L
s
.711 .229 1 r
.562 .12912 m
.56208 .13855 L
s
.5621 .13849 m
.562 .12912 L
s
.562 .12912 m
.56225 .14763 L
s
.658 .242 1 r
.62345 .14465 m
.62373 .15388 L
s
.62379 .15372 m
.62345 .14465 L
s
.62373 .15388 m
.62347 .1446 L
s
.62347 .1446 m
.62379 .15372 L
s
.588 .259 1 r
.74056 .15703 m
.74052 .15737 L
s
.868 .194 1 r
.62945 .1633 m
.62938 .1635 L
s
.754 .219 1 r
.68888 .08461 m
.69159 .13092 L
s
.799 .209 1 r
.59568 .14649 m
.59589 .15607 L
s
.59595 .15588 m
.59568 .14649 L
s
.59589 .15607 m
.5957 .14643 L
s
.5957 .14643 m
.59595 .15588 L
s
.811 .206 1 r
.50145 .16124 m
.50138 .16159 L
s
.551 .269 1 r
.52324 .14128 m
.52323 .15031 L
s
.5233 .14988 m
.52324 .14128 L
s
.869 .194 1 r
.66223 .13356 m
.66261 .14316 L
s
.66264 .1431 m
.66223 .13356 L
s
.66223 .13356 m
.66311 .15303 L
s
.551 .269 1 r
.52323 .15031 m
.52327 .14123 L
s
.52327 .14123 m
.5233 .14988 L
s
.712 .229 1 r
.5331 .08429 m
.53346 .12905 L
s
.628 .249 1 r
.58979 .12847 m
.58995 .13763 L
s
.58998 .13758 m
.58979 .12847 L
s
.58979 .12847 m
.5902 .14663 L
s
.94 .179 1 r
.53423 .13172 m
.53422 .14163 L
s
.53425 .14157 m
.53423 .13172 L
s
.53423 .13172 m
.53432 .15134 L
s
.531 .274 1 r
.71672 .08398 m
.71962 .1268 L
s
.734 .224 1 r
.5609 .08367 m
.56168 .12882 L
s
.618 .252 1 r
.70691 .1419 m
.70744 .15109 L
s
.70748 .15074 m
.70691 .1419 L
s
.70744 .15109 m
.70694 .14185 L
s
.70694 .14185 m
.70748 .15074 L
s
.904 .186 1 r
.68511 .1621 m
.68506 .16242 L
s
.67 .239 1 r
.65132 .14527 m
.65168 .15439 L
s
.65176 .15466 m
.65132 .14527 L
s
.904 .186 1 r
.74571 .13057 m
.74637 .1404 L
s
.7464 .14034 m
.74571 .13057 L
s
.74571 .13057 m
.74712 .15003 L
s
.744 .222 1 r
.67913 .14374 m
.67959 .15325 L
s
.67964 .15289 m
.67913 .14374 L
s
.67 .239 1 r
.65168 .15439 m
.65134 .14522 L
s
.65134 .14522 m
.65176 .15466 L
s
.744 .222 1 r
.67959 .15325 m
.67916 .14369 L
s
.67916 .14369 m
.67964 .15289 L
s
.649 .244 1 r
.64543 .12682 m
.64576 .13609 L
s
.64579 .13604 m
.64543 .12682 L
s
.64543 .12682 m
.64617 .14502 L
s
.834 .201 1 r
.55705 .16003 m
.55698 .16046 L
s
.638 .247 1 r
.61763 .12851 m
.61787 .13763 L
s
.61789 .13758 m
.61763 .12851 L
s
.61763 .12851 m
.6182 .14679 L
s
.701 .232 1 r
.58484 .15865 m
.58478 .15885 L
s
.559 .267 1 r
.58872 .08304 m
.58985 .12626 L
s
.712 .229 1 r
.48955 .12663 m
.48941 .1361 L
s
.48943 .13604 m
.48955 .12663 L
s
.48955 .12663 m
.48937 .1451 L
s
.822 .204 1 r
.49544 .14528 m
.49534 .15491 L
s
.49542 .15475 m
.49544 .14528 L
s
.868 .194 1 r
.71297 .16149 m
.71291 .16169 L
s
.822 .204 1 r
.49534 .15491 m
.49547 .14522 L
s
.49547 .14522 m
.49542 .15475 L
s
.522 .277 1 r
.51235 .15383 m
.51229 .15414 L
s
1 .07 .462 r
.64645 .17514 m
.64636 .17469 L
s
.712 .229 1 r
.45675 .15697 m
.45666 .15744 L
s
.711 .229 1 r
.55106 .14252 m
.55113 .15195 L
s
.5512 .15159 m
.55106 .14252 L
s
.55113 .15195 m
.55109 .14246 L
s
.55109 .14246 m
.5512 .15159 L
s
.648 .244 1 r
.61655 .08241 m
.61811 .1268 L
s
.618 .252 1 r
.70113 .12536 m
.70162 .13456 L
s
.70164 .13451 m
.70113 .12536 L
s
.70113 .12536 m
.70218 .14341 L
s
.722 .227 1 r
.73488 .14283 m
.7355 .15222 L
s
.73556 .15206 m
.73488 .14283 L
s
.559 .267 1 r
.72898 .12429 m
.72954 .13333 L
s
.72956 .13328 m
.72898 .12429 L
s
.72898 .12429 m
.73017 .14202 L
s
.503 .282 1 r
.57299 .12352 m
.57309 .13241 L
s
.57312 .13236 m
.57299 .12352 L
s
.57299 .12352 m
.57328 .14094 L
s
.618 .252 1 r
.6444 .08178 m
.64635 .12579 L
s
.722 .227 1 r
.7355 .15222 m
.73491 .14278 L
s
.73491 .14278 m
.73556 .15206 L
s
.81 .206 1 r
.61272 .1596 m
.61266 .15972 L
s
.799 .209 1 r
.51736 .12742 m
.5173 .13702 L
s
.51732 .13697 m
.51736 .12742 L
s
.51736 .12742 m
.51734 .14642 L
s
.68 .237 1 r
.67227 .08115 m
.67465 .12594 L
s
.754 .219 1 r
.48452 .15791 m
.48445 .15807 L
s
.722 .227 1 r
.6684 .15723 m
.66834 .15738 L
s
.928 .181 1 r
.67341 .12869 m
.67385 .13857 L
s
.67388 .13851 m
.67341 .12869 L
s
.67341 .12869 m
.67437 .14828 L
s
.869 .194 1 r
.57892 .14345 m
.57908 .15324 L
s
.57915 .15292 m
.57892 .14345 L
s
.57908 .15324 m
.57895 .1434 L
s
.57895 .1434 m
.57915 .15292 L
s
.711 .229 1 r
.69625 .15584 m
.6962 .1562 L
s
.744 .222 1 r
.60676 .14222 m
.607 .15166 L
s
.60706 .15154 m
.60676 .14222 L
s
.607 .15166 m
.60679 .14217 L
s
.60679 .14217 m
.60706 .15154 L
s
.658 .242 1 r
.70015 .08053 m
.70296 .1257 L
s
.69 .234 1 r
.6346 .141 m
.63493 .15031 L
s
.63499 .15015 m
.6346 .141 L
s
.63493 .15031 m
.63463 .14094 L
s
.63463 .14094 m
.63499 .15015 L
s
.477 .289 1 r
.46761 .15033 m
.46754 .15067 L
s
.904 .186 1 r
.64062 .15976 m
.64056 .15996 L
s
.701 .232 1 r
.54407 .08021 m
.5446 .12656 L
s
.755 .219 1 r
.47852 .14069 m
.47836 .15024 L
s
.47844 .14985 m
.47852 .14069 L
s
.47836 .15024 m
.47854 .14064 L
s
.47854 .14064 m
.47844 .14985 L
s
.618 .252 1 r
.69032 .13854 m
.6908 .14774 L
s
.69085 .14738 m
.69032 .13854 L
s
.94 .179 1 r
.54521 .12773 m
.54523 .13764 L
s
.54526 .13759 m
.54521 .12773 L
s
.54521 .12773 m
.54536 .14736 L
s
.618 .252 1 r
.6908 .14774 m
.69034 .13849 L
s
.69034 .13849 m
.69085 .14738 L
s
.531 .274 1 r
.72805 .0799 m
.73111 .12275 L
s
.658 .242 1 r
.50635 .13977 m
.50629 .14901 L
s
.50636 .14885 m
.50635 .13977 L
s
.50629 .14901 m
.50637 .13972 L
s
.50637 .13972 m
.50636 .14885 L
s
.638 .247 1 r
.57193 .07958 m
.57285 .12438 L
s
.589 .259 1 r
.71822 .13793 m
.71877 .14701 L
s
.71882 .14678 m
.71822 .13793 L
s
.8 .209 1 r
.56806 .15571 m
.568 .15614 L
s
.589 .259 1 r
.50044 .12171 m
.50034 .13087 L
s
.50036 .13082 m
.50044 .12171 L
s
.50044 .12171 m
.50033 .13957 L
s
.71877 .14701 m
.71825 .13788 L
s
.71825 .13788 m
.71882 .14678 L
s
.722 .227 1 r
.5402 .15748 m
.54013 .15729 L
s
.416 .307 1 r
.52829 .12044 m
.52827 .12902 L
s
.52829 .12897 m
.52829 .12044 L
s
.52829 .12044 m
.52833 .1374 L
s
.87 .194 1 r
.5998 .07895 m
.60122 .12687 L
s
.799 .209 1 r
.75214 .15579 m
.7521 .15611 L
s
.734 .224 1 r
.60093 .1265 m
.60112 .1358 L
s
.60115 .13575 m
.60093 .1265 L
s
.60093 .1265 m
.60141 .14536 L
s
.916 .184 1 r
.7243 .15756 m
.72425 .15792 L
s
.658 .242 1 r
.62379 .15372 m
.62373 .15388 L
s
.551 .269 1 r
.5233 .14988 m
.52323 .15031 L
s
.711 .229 1 r
.56208 .13855 m
.56218 .14798 L
s
.56225 .14763 m
.56208 .13855 L
s
.56218 .14798 m
.5621 .13849 L
s
.5621 .13849 m
.56225 .14763 L
s
.788 .212 1 r
.62769 .07832 m
.6295 .12507 L
s
.799 .209 1 r
.59595 .15588 m
.59589 .15607 L
s
.628 .249 1 r
.58995 .13763 m
.59013 .14679 L
s
.5902 .14663 m
.58995 .13763 L
s
.59013 .14679 m
.58998 .13758 L
s
.58998 .13758 m
.5902 .14663 L
s
.869 .194 1 r
.66261 .14316 m
.66303 .15277 L
s
.66311 .15303 m
.66261 .14316 L
s
.868 .194 1 r
.62884 .12611 m
.62912 .1358 L
s
.62915 .13575 m
.62884 .12611 L
s
.62884 .12611 m
.62951 .14552 L
s
.822 .204 1 r
.65671 .12462 m
.65708 .13426 L
s
.65711 .13421 m
.65671 .12462 L
s
.65671 .12462 m
.65755 .14375 L
s
.869 .194 1 r
.66303 .15277 m
.66264 .1431 L
s
.66264 .1431 m
.66311 .15303 L
s
.68 .237 1 r
.6556 .07769 m
.65775 .1225 L
s
.618 .252 1 r
.70748 .15074 m
.70744 .15109 L
s
.94 .179 1 r
.53422 .14163 m
.53424 .15154 L
s
.53432 .15134 m
.53422 .14163 L
s
.53424 .15154 m
.53425 .14157 L
s
.53425 .14157 m
.53432 .15134 L
s
.777 .214 1 r
.5562 .12185 m
.55626 .13149 L
s
.55629 .13143 m
.5562 .12185 L
s
.5562 .12185 m
.55641 .14066 L
s
.67 .239 1 r
.65176 .15466 m
.65168 .15439 L
s
.744 .222 1 r
.67964 .15289 m
.67959 .15325 L
s
.68 .237 1 r
.74041 .1212 m
.74103 .13056 L
s
.74105 .13051 m
.74041 .1212 L
s
.74041 .1212 m
.74171 .13957 L
s
.68353 .07706 m
.68608 .12187 L
s
.638 .247 1 r
.61787 .13763 m
.61813 .14676 L
s
.6182 .14679 m
.61787 .13763 L
s
.649 .244 1 r
.64576 .13609 m
.64611 .14537 L
s
.64617 .14502 m
.64576 .13609 L
s
.638 .247 1 r
.61813 .14676 m
.61789 .13758 L
s
.61789 .13758 m
.6182 .14679 L
s
.649 .244 1 r
.64611 .14537 m
.64579 .13604 L
s
.64579 .13604 m
.64617 .14502 L
s
.88 .191 1 r
.71257 .12319 m
.71312 .13303 L
s
.71315 .13297 m
.71257 .12319 L
s
.71257 .12319 m
.71376 .14252 L
s
.904 .186 1 r
.74637 .1404 m
.74706 .15024 L
s
.74712 .15003 m
.74637 .1404 L
s
.74706 .15024 m
.7464 .14034 L
s
.7464 .14034 m
.74712 .15003 L
s
.467 .292 1 r
.63986 .11809 m
.64015 .12686 L
s
.64018 .12681 m
.63986 .11809 L
s
.63986 .11809 m
.64052 .13533 L
s
.712 .229 1 r
.48941 .1361 m
.48929 .14557 L
s
.48937 .1451 m
.48941 .1361 L
s
1 .081 .525 r
.71147 .07643 m
.71504 .1306 L
s
.711 .229 1 r
.5512 .15159 m
.55113 .15195 L
s
.712 .229 1 r
.48929 .14557 m
.48943 .13604 L
s
.48943 .13604 m
.48937 .1451 L
s
.822 .204 1 r
.49542 .15475 m
.49534 .15491 L
s
.744 .221 1 r
.5841 .12169 m
.58425 .13118 L
s
.58428 .13113 m
.5841 .12169 L
s
.5841 .12169 m
.58449 .14043 L
s
1 .156 .946 r
.68473 .12568 m
.68521 .13581 L
s
.68524 .13575 m
.68473 .12568 L
s
.68473 .12568 m
.68579 .14585 L
s
.68 .237 1 r
.612 .12027 m
.61223 .12964 L
s
.61225 .12958 m
.612 .12027 L
s
.612 .12027 m
.61254 .13865 L
s
.522 .277 1 r
.55509 .07612 m
.55574 .11899 L
s
.618 .252 1 r
.70162 .13456 m
.70213 .14376 L
s
.70218 .14341 m
.70162 .13456 L
s
.70213 .14376 m
.70164 .13451 L
s
.70164 .13451 m
.70218 .14341 L
s
.503 .282 1 r
.57309 .13241 m
.57322 .14129 L
s
.57328 .14094 m
.57309 .13241 L
s
.57322 .14129 m
.57312 .13236 L
s
.57312 .13236 m
.57328 .14094 L
s
.559 .267 1 r
.72954 .13333 m
.73012 .14237 L
s
.73017 .14202 m
.72954 .13333 L
s
.73012 .14237 m
.72956 .13328 L
s
.72956 .13328 m
.73017 .14202 L
s
.722 .227 1 r
.73556 .15206 m
.7355 .15222 L
s
.868 .194 1 r
.583 .07548 m
.58415 .12303 L
s
.881 .191 1 r
.61093 .07485 m
.61252 .1224 L
s
.799 .209 1 r
.5173 .13702 m
.51727 .14662 L
s
.51734 .14642 m
.5173 .13702 L
s
.51727 .14662 m
.51732 .13697 L
s
.51732 .13697 m
.51734 .14642 L
s
.869 .194 1 r
.57915 .15292 m
.57908 .15324 L
s
.578 .262 1 r
.69582 .11811 m
.69629 .12716 L
s
.69631 .12711 m
.69582 .11811 L
s
.69582 .11811 m
.69683 .13602 L
s
.777 .214 1 r
.66792 .11972 m
.66832 .12933 L
s
.66835 .12927 m
.66792 .11972 L
s
.66792 .11972 m
.66881 .13858 L
s
.744 .222 1 r
.60706 .15154 m
.607 .15166 L
s
.928 .181 1 r
.67385 .13857 m
.67431 .14845 L
s
.67437 .14828 m
.67385 .13857 L
s
.69 .234 1 r
.63499 .15015 m
.63493 .15031 L
s
.928 .181 1 r
.67431 .14845 m
.67388 .13851 L
s
.67388 .13851 m
.67437 .14828 L
s
.929 .181 1 r
.63888 .07422 m
.6409 .12178 L
s
.67 .239 1 r
.51137 .11945 m
.5113 .12871 L
s
.51132 .12866 m
.51137 .11945 L
s
.51137 .11945 m
.51132 .13789 L
s
.618 .252 1 r
.69085 .14738 m
.6908 .14774 L
s
.755 .219 1 r
.47844 .14985 m
.47836 .15024 L
s
.467 .292 1 r
.66685 .07359 m
.66904 .11609 L
s
.658 .242 1 r
.50636 .14885 m
.50629 .14901 L
s
.589 .259 1 r
.71882 .14678 m
.71877 .14701 L
s
.416 .307 1 r
.52827 .12902 m
.52827 .13759 L
s
.52833 .1374 m
.52827 .12902 L
s
.52827 .13759 m
.52829 .12897 L
s
.52829 .12897 m
.52833 .1374 L
s
.94 .179 1 r
.54523 .13764 m
.54529 .14757 L
s
.54536 .14736 m
.54523 .13764 L
s
.54529 .14757 m
.54526 .13759 L
s
.54526 .13759 m
.54536 .14736 L
s
.881 .191 1 r
.53932 .11914 m
.53933 .12902 L
s
.53935 .12896 m
.53932 .11914 L
s
.53932 .11914 m
.53944 .13843 L
s
.589 .259 1 r
.50034 .13087 m
.50026 .14003 L
s
.50033 .13957 m
.50034 .13087 L
s
.50026 .14003 m
.50036 .13082 L
s
.50036 .13082 m
.50033 .13957 L
s
.744 .222 1 r
.56725 .11794 m
.56735 .12747 L
s
.56737 .12742 m
.56725 .11794 L
s
.56725 .11794 m
.56753 .13665 L
s
.503 .282 1 r
.62311 .11487 m
.62336 .12377 L
s
.62339 .12371 m
.62311 .11487 L
s
.62311 .11487 m
.62369 .13231 L
s
.658 .242 1 r
.69483 .07295 m
.69757 .11818 L
s
.373 .52 1 r
.70691 .11026 m
.70735 .11821 L
s
.70737 .11816 m
.70691 .11026 L
s
.70691 .11026 m
.70785 .12581 L
s
.834 .201 1 r
.72391 .11898 m
.72449 .12871 L
s
.72453 .12865 m
.72391 .11898 L
s
.72391 .11898 m
.72516 .13812 L
s
.734 .224 1 r
.60112 .1358 m
.60134 .1451 L
s
.60141 .14536 m
.60112 .1358 L
s
.60134 .1451 m
.60115 .13575 L
s
.60115 .13575 m
.60141 .14536 L
s
1 .118 .743 r
.72283 .07232 m
.72652 .12535 L
s
.711 .229 1 r
.56225 .14763 m
.56218 .14798 L
s
.777 .214 1 r
.59522 .11755 m
.5954 .12716 L
s
.59543 .12711 m
.59522 .11755 L
s
.59522 .11755 m
.59567 .13642 L
s
.559 .267 1 r
.56614 .072 m
.56696 .1153 L
s
.628 .249 1 r
.5902 .14663 m
.59013 .14679 L
s
.869 .194 1 r
.66311 .15303 m
.66303 .15277 L
s
.868 .194 1 r
.62912 .1358 m
.62944 .14549 L
s
.62951 .14552 m
.62912 .1358 L
s
.822 .204 1 r
.65708 .13426 m
.65749 .14391 L
s
.65755 .14375 m
.65708 .13426 L
s
.868 .194 1 r
.62944 .14549 m
.62915 .13575 L
s
.62915 .13575 m
.62951 .14552 L
s
.822 .204 1 r
.65749 .14391 m
.65711 .13421 L
s
.65711 .13421 m
.65755 .14375 L
s
.433 .302 1 r
.59412 .07137 m
.59529 .1135 L
s
.522 .277 1 r
.52235 .11393 m
.52231 .12283 L
s
.52233 .12278 m
.52235 .11393 L
s
.52235 .11393 m
.52236 .13154 L
s
.649 .244 1 r
.64617 .14502 m
.64611 .14537 L
s
.94 .179 1 r
.53432 .15134 m
.53424 .15154 L
s
.638 .247 1 r
.6182 .14679 m
.61813 .14676 L
s
.68 .237 1 r
.74103 .13056 m
.74167 .13993 L
s
.74171 .13957 m
.74103 .13056 L
s
.701 .232 1 r
.6221 .07074 m
.62378 .11598 L
s
.68 .237 1 r
.74167 .13993 m
.74105 .13051 L
s
.74105 .13051 m
.74171 .13957 L
s
.777 .214 1 r
.55626 .13149 m
.55635 .14113 L
s
.55641 .14066 m
.55626 .13149 L
s
.467 .292 1 r
.64015 .12686 m
.64047 .13563 L
s
.64052 .13533 m
.64015 .12686 L
s
.777 .214 1 r
.55635 .14113 m
.55629 .13143 L
s
.55629 .13143 m
.55641 .14066 L
s
.467 .292 1 r
.64047 .13563 m
.64018 .12681 L
s
.64018 .12681 m
.64052 .13533 L
s
.712 .229 1 r
.48937 .1451 m
.48929 .14557 L
s
.69 .234 1 r
.6792 .11566 m
.67962 .12499 L
s
.67965 .12494 m
.6792 .11566 L
s
.6792 .11566 m
.68014 .13418 L
s
.904 .186 1 r
.74712 .15003 m
.74706 .15024 L
s
.88 .191 1 r
.71312 .13303 m
.71371 .14287 L
s
.71376 .14252 m
.71312 .13303 L
s
.94 .179 1 r
.65125 .1175 m
.65161 .12747 L
s
.65164 .12741 m
.65125 .1175 L
s
.65125 .1175 m
.65207 .13713 L
s
.88 .191 1 r
.71371 .14287 m
.71315 .13297 L
s
.71315 .13297 m
.71376 .14252 L
s
.904 .186 1 r
.65011 .0701 m
.65233 .11808 L
s
.503 .282 1 r
.57328 .14094 m
.57322 .14129 L
s
.618 .252 1 r
.70218 .14341 m
.70213 .14376 L
s
.744 .221 1 r
.58425 .13118 m
.58442 .14067 L
s
.58449 .14043 m
.58425 .13118 L
s
.68 .237 1 r
.61223 .12964 m
.61248 .139 L
s
.61254 .13865 m
.61223 .12964 L
s
.559 .267 1 r
.73017 .14202 m
.73012 .14237 L
s
.744 .221 1 r
.58442 .14067 m
.58428 .13113 L
s
.58428 .13113 m
.58449 .14043 L
s
.68 .237 1 r
.61248 .139 m
.61225 .12958 L
s
.61225 .12958 m
.61254 .13865 L
s
.733 .224 1 r
.67813 .06947 m
.68068 .1155 L
s
.69 .234 1 r
.55034 .11472 m
.55039 .12406 L
s
.55041 .12401 m
.55034 .11472 L
s
.55034 .11472 m
.55052 .13325 L
s
1 .156 .946 r
.68521 .13581 m
.68573 .14594 L
s
.68579 .14585 m
.68521 .13581 L
s
.68573 .14594 m
.68524 .13575 L
s
.68524 .13575 m
.68579 .14585 L
s
.766 .217 1 r
.73528 .11449 m
.73589 .12406 L
s
.73592 .12401 m
.73528 .11449 L
s
.73528 .11449 m
.73658 .13333 L
s
.618 .252 1 r
.60633 .11237 m
.60654 .12159 L
s
.60657 .12153 m
.60633 .11237 L
s
.60633 .11237 m
.60684 .13045 L
s
.661 1 .672 r
.70617 .06883 m
.7078 .09437 L
s
.733 .224 1 r
.57835 .11429 m
.57848 .12375 L
s
.57851 .12369 m
.57835 .11429 L
s
.57835 .11429 m
.5787 .13301 L
s
.799 .209 1 r
.51734 .14642 m
.51727 .14662 L
s
.578 .262 1 r
.69629 .12716 m
.69678 .13622 L
s
.69683 .13602 m
.69629 .12716 L
s
.69678 .13622 m
.69631 .12711 L
s
.69631 .12711 m
.69683 .13602 L
s
.777 .214 1 r
.66832 .12933 m
.66876 .13893 L
s
.66881 .13858 m
.66832 .12933 L
s
.733 .224 1 r
.57724 .06788 m
.57827 .11353 L
s
.777 .214 1 r
.66876 .13893 m
.66835 .12927 L
s
.66835 .12927 m
.66881 .13858 L
s
.67 .239 1 r
.5113 .12871 m
.51125 .13797 L
s
.51132 .13789 m
.5113 .12871 L
s
.51125 .13797 m
.51132 .12866 L
s
.51132 .12866 m
.51132 .13789 L
s
.928 .181 1 r
.67437 .14828 m
.67431 .14845 L
s
.416 .307 1 r
.52833 .1374 m
.52827 .13759 L
s
.658 .242 1 r
.63439 .11263 m
.63468 .12189 L
s
.63471 .12184 m
.63439 .11263 L
s
.63439 .11263 m
.63507 .131 L
s
.373 .52 1 r
.70735 .11821 m
.70781 .12615 L
s
.70785 .12581 m
.70735 .11821 L
s
.70781 .12615 m
.70737 .11816 L
s
.70737 .11816 m
.70785 .12581 L
s
.589 .259 1 r
.50033 .13957 m
.50026 .14003 L
s
.485 .287 1 r
.60527 .06724 m
.60663 .11018 L
s
.503 .282 1 r
.62336 .12377 m
.62364 .13266 L
s
.62369 .13231 m
.62336 .12377 L
s
.62364 .13266 m
.62339 .12371 L
s
.62339 .12371 m
.62369 .13231 L
s
.531 .274 1 r
.71849 .10919 m
.71902 .11817 L
s
.71905 .11812 m
.71849 .10919 L
s
.71849 .10919 m
.71962 .1268 L
s
.94 .179 1 r
.54536 .14736 m
.54529 .14757 L
s
.733 .224 1 r
.63332 .0666 m
.63522 .11343 L
s
.881 .191 1 r
.53933 .12902 m
.53937 .1389 L
s
.53944 .13843 m
.53933 .12902 L
s
.744 .222 1 r
.56735 .12747 m
.56747 .137 L
s
.56753 .13665 m
.56735 .12747 L
s
.881 .191 1 r
.53937 .1389 m
.53935 .12896 L
s
.53935 .12896 m
.53944 .13843 L
s
.744 .222 1 r
.66248 .11273 m
.66286 .1222 L
s
.66289 .12214 m
.66248 .11273 L
s
.66248 .11273 m
.66334 .13154 L
s
.56747 .137 m
.56737 .12742 L
s
.56737 .12742 m
.56753 .13665 L
s
.712 .229 1 r
.53339 .11053 m
.53338 .12002 L
s
.5334 .11997 m
.53339 .11053 L
s
.53339 .11053 m
.53346 .12905 L
s
.834 .201 1 r
.72449 .12871 m
.72511 .13844 L
s
.72516 .13812 m
.72449 .12871 L
s
.72511 .13844 m
.72453 .12865 L
s
.72453 .12865 m
.72516 .13812 L
s
.734 .224 1 r
.60141 .14536 m
.60134 .1451 L
s
.846 .199 1 r
.66139 .06597 m
.66373 .11281 L
s
.754 .219 1 r
.69055 .11207 m
.69102 .12157 L
s
.69105 .12152 m
.69055 .11207 L
s
.69055 .11207 m
.69159 .13092 L
s
.777 .214 1 r
.5954 .12716 m
.59561 .13677 L
s
.59567 .13642 m
.5954 .12716 L
s
.559 .267 1 r
.58945 .10848 m
.58961 .11754 L
s
.58963 .11749 m
.58945 .10848 L
s
.58945 .10848 m
.58985 .12626 L
s
.777 .214 1 r
.59561 .13677 m
.59543 .12711 L
s
.59543 .12711 m
.59567 .13642 L
s
.734 .224 1 r
.56143 .11017 m
.56151 .11971 L
s
.56153 .11965 m
.56143 .11017 L
s
.56143 .11017 m
.56168 .12882 L
s
.765 .217 1 r
.68947 .06533 m
.69221 .11178 L
s
.822 .204 1 r
.65755 .14375 m
.65749 .14391 L
s
.522 .277 1 r
.52231 .12283 m
.5223 .13173 L
s
.52236 .13154 m
.52231 .12283 L
s
.5223 .13173 m
.52233 .12278 L
s
.52233 .12278 m
.52236 .13154 L
s
.467 .292 1 r
.64052 .13533 m
.64047 .13563 L
s
.868 .194 1 r
.62951 .14552 m
.62944 .14549 L
s
1 .151 .92 r
.71756 .06469 m
.72102 .11544 L
s
.68 .237 1 r
.74171 .13957 m
.74167 .13993 L
s
.648 .244 1 r
.61754 .10854 m
.61778 .11785 L
s
.61781 .11779 m
.61754 .10854 L
s
.61754 .10854 m
.61811 .1268 L
s
.777 .214 1 r
.55641 .14066 m
.55635 .14113 L
s
.618 .252 1 r
.64561 .10769 m
.64594 .11691 L
s
.64597 .11686 m
.64561 .10769 L
s
.64561 .10769 m
.64635 .12579 L
s
.69 .234 1 r
.67962 .12499 m
.68008 .13433 L
s
.68014 .13418 m
.67962 .12499 L
s
.68008 .13433 m
.67965 .12494 L
s
.67965 .12494 m
.68014 .13418 L
s
.744 .221 1 r
.58839 .06373 m
.58959 .10941 L
s
.88 .191 1 r
.71376 .14252 m
.71371 .14287 L
s
.68 .237 1 r
.61254 .13865 m
.61248 .139 L
s
.744 .221 1 r
.58449 .14043 m
.58442 .14067 L
s
.94 .179 1 r
.65161 .12747 m
.65201 .13744 L
s
.65207 .13713 m
.65161 .12747 L
s
.65201 .13744 m
.65164 .12741 L
s
.65164 .12741 m
.65207 .13713 L
s
.68 .237 1 r
.67374 .10752 m
.67416 .1169 L
s
.67418 .11685 m
.67374 .10752 L
s
.67374 .10752 m
.67465 .12594 L
s
.765 .217 1 r
.61648 .06309 m
.61812 .10956 L
s
.69 .234 1 r
.55039 .12406 m
.55045 .1334 L
s
.55052 .13325 m
.55039 .12406 L
s
.55045 .1334 m
.55041 .12401 L
s
.55041 .12401 m
.55052 .13325 L
s
.531 .274 1 r
.72992 .10512 m
.73048 .11411 L
s
.73051 .11406 m
.72992 .10512 L
s
.72992 .10512 m
.73111 .12275 L
s
.618 .252 1 r
.60654 .12159 m
.60678 .1308 L
s
.60684 .13045 m
.60654 .12159 L
s
.60678 .1308 m
.60657 .12153 L
s
.60657 .12153 m
.60684 .13045 L
s
.766 .217 1 r
.73589 .12406 m
.73654 .13364 L
s
.73658 .13333 m
.73589 .12406 L
s
1 .156 .946 r
.68579 .14585 m
.68573 .14594 L
s
.514 .279 1 r
.64458 .06245 m
.64645 .10425 L
s
.766 .217 1 r
.73654 .13364 m
.73592 .12401 L
s
.73592 .12401 m
.73658 .13333 L
s
.373 .52 1 r
.70785 .12581 m
.70781 .12615 L
s
.578 .262 1 r
.69683 .13602 m
.69678 .13622 L
s
.658 .242 1 r
.70189 .10732 m
.70238 .11659 L
s
.70241 .11654 m
.70189 .10732 L
s
.70189 .10732 m
.70296 .1257 L
s
.733 .224 1 r
.57848 .12375 m
.57864 .13321 L
s
.5787 .13301 m
.57848 .12375 L
s
.57864 .13321 m
.57851 .12369 L
s
.57851 .12369 m
.5787 .13301 L
s
.701 .231 1 r
.6727 .06181 m
.67523 .10907 L
s
.777 .214 1 r
.66881 .13858 m
.66876 .13893 L
s
.67 .239 1 r
.51132 .13789 m
.51125 .13797 L
s
.638 .247 1 r
.57254 .10611 m
.57265 .11534 L
s
.57268 .11529 m
.57254 .10611 L
s
.57254 .10611 m
.57285 .12438 L
s
.658 .242 1 r
.63468 .12189 m
.63501 .13115 L
s
.63507 .131 m
.63468 .12189 L
s
.701 .232 1 r
.54446 .10789 m
.54448 .1172 L
s
.54451 .11715 m
.54446 .10789 L
s
.54446 .10789 m
.5446 .12656 L
s
.658 .242 1 r
.63501 .13115 m
.63471 .12184 L
s
.63471 .12184 m
.63507 .131 L
s
.834 .201 1 r
.70084 .06117 m
.70379 .10805 L
s
.503 .282 1 r
.62369 .13231 m
.62364 .13266 L
s
.531 .274 1 r
.71902 .11817 m
.71958 .12715 L
s
.71962 .1268 m
.71902 .11817 L
s
.71958 .12715 m
.71905 .11812 L
s
.71905 .11812 m
.71962 .1268 L
s
.744 .222 1 r
.56753 .13665 m
.56747 .137 L
s
.881 .191 1 r
.53944 .13843 m
.53937 .1389 L
s
.744 .222 1 r
.66286 .1222 m
.66328 .13166 L
s
.66334 .13154 m
.66286 .1222 L
s
.66328 .13166 m
.66289 .12214 L
s
.66289 .12214 m
.66334 .13154 L
s
.712 .229 1 r
.53338 .12002 m
.5334 .12952 L
s
.53346 .12905 m
.53338 .12002 L
s
.5334 .12952 m
.5334 .11997 L
s
.5334 .11997 m
.53346 .12905 L
s
.834 .201 1 r
.72516 .13812 m
.72511 .13844 L
s
.68 .237 1 r
.65694 .10407 m
.6573 .11346 L
s
.65733 .11341 m
.65694 .10407 L
s
.65694 .10407 m
.65775 .1225 L
s
.69 .234 1 r
.59957 .05957 m
.60095 .10567 L
s
.559 .267 1 r
.58961 .11754 m
.58979 .12661 L
s
.58985 .12626 m
.58961 .11754 L
s
.87 .194 1 r
.60072 .10744 m
.60092 .11719 L
s
.60095 .11714 m
.60072 .10744 L
s
.60072 .10744 m
.60122 .12687 L
s
.559 .267 1 r
.58979 .12661 m
.58963 .11749 L
s
.58963 .11749 m
.58985 .12626 L
s
.754 .219 1 r
.69102 .12157 m
.69153 .13108 L
s
.69159 .13092 m
.69102 .12157 L
s
.777 .214 1 r
.59567 .13642 m
.59561 .13677 L
s
.754 .219 1 r
.69153 .13108 m
.69105 .12152 L
s
.69105 .12152 m
.69159 .13092 L
s
.788 .212 1 r
.62884 .10604 m
.62912 .11564 L
s
.62915 .11558 m
.62884 .10604 L
s
.62884 .10604 m
.6295 .12507 L
s
.734 .224 1 r
.56151 .11971 m
.56161 .12925 L
s
.56168 .12882 m
.56151 .11971 L
s
.56161 .12925 m
.56153 .11965 L
s
.56153 .11965 m
.56168 .12882 L
s
.68 .237 1 r
.6851 .10344 m
.68555 .11283 L
s
.68558 .11278 m
.6851 .10344 L
s
.6851 .10344 m
.68608 .12187 L
s
.522 .277 1 r
.52236 .13154 m
.5223 .13173 L
s
.977 .171 1 r
.62772 .05893 m
.62961 .10738 L
s
.522 .277 1 r
.55554 .10139 m
.55559 .11035 L
s
.55562 .1103 m
.55554 .10139 L
s
.55554 .10139 m
.55574 .11899 L
s
.701 .231 1 r
.65589 .05829 m
.65806 .10323 L
s
.648 .244 1 r
.61778 .11785 m
.61805 .12715 L
s
.61811 .1268 m
.61778 .11785 L
s
.61805 .12715 m
.61781 .11779 L
s
.61781 .11779 m
.61811 .1268 L
s
.661 1 .672 r
.70721 .08451 m
.70747 .08924 L
s
.70749 .08921 m
.70721 .08451 L
s
.70721 .08451 m
.7078 .09437 L
s
.618 .252 1 r
.64594 .11691 m
.64629 .12614 L
s
.64635 .12579 m
.64594 .11691 L
s
.64629 .12614 m
.64597 .11686 L
s
.64597 .11686 m
.64635 .12579 L
s
.69 .234 1 r
.68014 .13418 m
.68008 .13433 L
s
.68 .237 1 r
.68407 .05765 m
.68666 .10259 L
s
.811 .206 1 r
.71227 .057 m
.71537 .10351 L
s
.94 .179 1 r
.65207 .13713 m
.65201 .13744 L
s
.69 .234 1 r
.55052 .13325 m
.55045 .1334 L
s
.68 .237 1 r
.67416 .1169 m
.6746 .12629 L
s
.67465 .12594 m
.67416 .1169 L
s
.6746 .12629 m
.67418 .11685 L
s
.67418 .11685 m
.67465 .12594 L
s
.618 .252 1 r
.60684 .13045 m
.60678 .1308 L
s
.531 .274 1 r
.73048 .11411 m
.73107 .1231 L
s
.73111 .12275 m
.73048 .11411 L
s
.73107 .1231 m
.73051 .11406 L
s
.73051 .11406 m
.73111 .12275 L
s
.467 .292 1 r
.66821 .09876 m
.66858 .10752 L
s
.66861 .10747 m
.66821 .09876 L
s
.66821 .09876 m
.66904 .11609 L
s
.766 .217 1 r
.73658 .13333 m
.73654 .13364 L
s
.868 .194 1 r
.58376 .10364 m
.58391 .11343 L
s
.58393 .11337 m
.58376 .10364 L
s
.58376 .10364 m
.58415 .12303 L
s
.658 .242 1 r
.70238 .11659 m
.7029 .12586 L
s
.70296 .1257 m
.70238 .11659 L
s
.733 .224 1 r
.5787 .13301 m
.57864 .13321 L
s
.658 .242 1 r
.7029 .12586 m
.70241 .11654 L
s
.70241 .11654 m
.70296 .1257 L
s
.881 .191 1 r
.61195 .10296 m
.61219 .1128 L
s
.61221 .11274 m
.61195 .10296 L
s
.61195 .10296 m
.61252 .1224 L
s
.799 .209 1 r
.61081 .0554 m
.61238 .10231 L
s
.638 .247 1 r
.57265 .11534 m
.57279 .12457 L
s
.57285 .12438 m
.57265 .11534 L
s
.658 .242 1 r
.63507 .131 m
.63501 .13115 L
s
.638 .247 1 r
.57279 .12457 m
.57268 .11529 L
s
.57268 .11529 m
.57285 .12438 L
s
.929 .181 1 r
.64014 .10219 m
.64048 .11218 L
s
.64051 .11212 m
.64014 .10219 L
s
.64014 .10219 m
.6409 .12178 L
s
.701 .232 1 r
.54448 .1172 m
.54453 .12652 L
s
.5446 .12656 m
.54448 .1172 L
s
.54453 .12652 m
.54451 .11715 L
s
.54451 .11715 m
.5446 .12656 L
s
.711 .229 1 r
.63901 .05475 m
.64096 .1001 L
s
.661 1 .672 r
.70747 .08924 m
.70775 .09396 L
s
.7078 .09437 m
.70747 .08924 L
s
.531 .274 1 r
.71962 .1268 m
.71958 .12715 L
s
.661 1 .672 r
.70775 .09396 m
.70749 .08921 L
s
.70749 .08921 m
.7078 .09437 L
s
.658 .242 1 r
.69652 .09978 m
.697 .10906 L
s
.69703 .10901 m
.69652 .09978 L
s
.69652 .09978 m
.69757 .11818 L
s
.559 .267 1 r
.56669 .09749 m
.56678 .10657 L
s
.56681 .10651 m
.56669 .09749 L
s
.56669 .09749 m
.56696 .1153 L
s
1 .081 .525 r
.71367 .10873 m
.7143 .11965 L
s
.71433 .11959 m
.71367 .10873 L
s
.71367 .10873 m
.71504 .1306 L
s
.433 .302 1 r
.59488 .09636 m
.59504 .10501 L
s
.59507 .10496 m
.59488 .09636 L
s
.59488 .09636 m
.59529 .1135 L
s
.869 .194 1 r
.66723 .05411 m
.66968 .10102 L
s
.712 .229 1 r
.53346 .12905 m
.5334 .12952 L
s
.744 .222 1 r
.66334 .13154 m
.66328 .13166 L
s
.559 .267 1 r
.58985 .12626 m
.58979 .12661 L
s
.777 .214 1 r
.69547 .05346 m
.69835 .10039 L
s
.68 .237 1 r
.6573 .11346 m
.6577 .12285 L
s
.65775 .1225 m
.6573 .11346 L
s
.6577 .12285 m
.65733 .11341 L
s
.65733 .11341 m
.65775 .1225 L
s
.754 .219 1 r
.69159 .13092 m
.69153 .13108 L
s
.734 .224 1 r
.56168 .12882 m
.56161 .12925 L
s
.87 .194 1 r
.60092 .11719 m
.60115 .12696 L
s
.60122 .12687 m
.60092 .11719 L
s
.788 .212 1 r
.62912 .11564 m
.62944 .12523 L
s
.6295 .12507 m
.62912 .11564 L
s
.87 .194 1 r
.60115 .12696 m
.60095 .11714 L
s
.60095 .11714 m
.60122 .12687 L
s
.788 .212 1 r
.62944 .12523 m
.62915 .11558 L
s
.62915 .11558 m
.6295 .12507 L
s
.522 .277 1 r
.55559 .11035 m
.55568 .1193 L
s
.55574 .11899 m
.55559 .11035 L
s
.55568 .1193 m
.55562 .1103 L
s
.55562 .1103 m
.55574 .11899 L
s
.68 .237 1 r
.68555 .11283 m
.68603 .12223 L
s
.68608 .12187 m
.68555 .11283 L
s
.68603 .12223 m
.68558 .11278 L
s
.68558 .11278 m
.68608 .12187 L
s
.701 .232 1 r
.62316 .09741 m
.62343 .10685 L
s
.62346 .1068 m
.62316 .09741 L
s
.62316 .09741 m
.62378 .11598 L
s
.648 .244 1 r
.61811 .1268 m
.61805 .12715 L
s
.618 .252 1 r
.64635 .12579 m
.64629 .12614 L
s
.661 1 .672 r
.7078 .09437 m
.70775 .09396 L
s
.833 .201 1 r
.62208 .0512 m
.62385 .09853 L
s
.733 .224 1 r
.67971 .09672 m
.68015 .10621 L
s
.68018 .10615 m
.67971 .09672 L
s
.67971 .09672 m
.68068 .1155 L
s
1 .164 .985 r
.65035 .05056 m
.65267 .10063 L
s
.531 .274 1 r
.73111 .12275 m
.73107 .1231 L
s
.904 .186 1 r
.6515 .09851 m
.65186 .10839 L
s
.65189 .10833 m
.6515 .09851 L
s
.6515 .09851 m
.65233 .11808 L
s
.68 .237 1 r
.67465 .12594 m
.6746 .12629 L
s
1 .118 .743 r
.72512 .10418 m
.72575 .11463 L
s
.72579 .11457 m
.72512 .10418 L
s
.72512 .10418 m
.72652 .12535 L
s
.467 .292 1 r
.66858 .10752 m
.66898 .11628 L
s
.66904 .11609 m
.66858 .10752 L
s
.66898 .11628 m
.66861 .10747 L
s
.66861 .10747 m
.66904 .11609 L
s
.608 .254 1 r
.67863 .04991 m
.6811 .09413 L
s
.485 .287 1 r
.60614 .09271 m
.60634 .10152 L
s
.60637 .10147 m
.60614 .09271 L
s
.60614 .09271 m
.60663 .11018 L
s
.658 .242 1 r
.70296 .1257 m
.7029 .12586 L
s
.868 .194 1 r
.58391 .11343 m
.58409 .12323 L
s
.58415 .12303 m
.58391 .11343 L
s
.58409 .12323 m
.58393 .11337 L
s
.58393 .11337 m
.58415 .12303 L
s
.733 .224 1 r
.57792 .0948 m
.57805 .10432 L
s
.57808 .10426 m
.57792 .0948 L
s
.57792 .0948 m
.57827 .11353 L
s
.834 .201 1 r
.70693 .04926 m
.70999 .09622 L
s
.638 .247 1 r
.57285 .12438 m
.57279 .12457 L
s
.881 .191 1 r
.61219 .1128 m
.61246 .12264 L
s
.61252 .1224 m
.61219 .1128 L
s
.61246 .12264 m
.61221 .11274 L
s
.61221 .11274 m
.61252 .1224 L
s
.701 .232 1 r
.5446 .12656 m
.54453 .12652 L
s
.559 .267 1 r
.56678 .10657 m
.5669 .11565 L
s
.56696 .1153 m
.56678 .10657 L
s
.433 .302 1 r
.59504 .10501 m
.59523 .11365 L
s
.59529 .1135 m
.59504 .10501 L
s
.559 .267 1 r
.5669 .11565 m
.56681 .10651 L
s
.56681 .10651 m
.56696 .1153 L
s
.433 .302 1 r
.59523 .11365 m
.59507 .10496 L
s
.59507 .10496 m
.59529 .1135 L
s
.929 .181 1 r
.64048 .11218 m
.64085 .12218 L
s
.6409 .12178 m
.64048 .11218 L
s
.658 .242 1 r
.697 .10906 m
.69751 .11834 L
s
.69757 .11818 m
.697 .10906 L
s
.929 .181 1 r
.64085 .12218 m
.64051 .11212 L
s
.64051 .11212 m
.6409 .12178 L
s
.658 .242 1 r
.69751 .11834 m
.69703 .10901 L
s
.69703 .10901 m
.69757 .11818 L
s
.733 .224 1 r
.63453 .09457 m
.63482 .10398 L
s
.63485 .10393 m
.63453 .09457 L
s
.63453 .09457 m
.63522 .11343 L
s
.467 .292 1 r
.6334 .04699 m
.63514 .08928 L
s
.68 .237 1 r
.65775 .1225 m
.6577 .12285 L
s
.846 .199 1 r
.66284 .09354 m
.66324 .10335 L
s
.66327 .1033 m
.66284 .09354 L
s
.66284 .09354 m
.66373 .11281 L
s
1 .081 .525 r
.7143 .11965 m
.71496 .13058 L
s
.71504 .1306 m
.7143 .11965 L
s
.71496 .13058 m
.71433 .11959 L
s
.71433 .11959 m
.71504 .1306 L
s
.522 .277 1 r
.55574 .11899 m
.55568 .1193 L
s
.416 .307 1 r
.66173 .04634 m
.66387 .08902 L
s
.68 .237 1 r
.68608 .12187 m
.68603 .12223 L
s
.765 .217 1 r
.69116 .09283 m
.69164 .1024 L
s
.69167 .10235 m
.69116 .09283 L
s
.69116 .09283 m
.69221 .11178 L
s
.788 .212 1 r
.6295 .12507 m
.62944 .12523 L
s
.87 .194 1 r
.60122 .12687 m
.60115 .12696 L
s
.701 .232 1 r
.62343 .10685 m
.62372 .1163 L
s
.62378 .11598 m
.62343 .10685 L
s
.62372 .1163 m
.62346 .1068 L
s
.62346 .1068 m
.62378 .11598 L
s
.559 .267 1 r
.69007 .04569 m
.69267 .08916 L
s
.514 .279 1 r
.64574 .08678 m
.64606 .09583 L
s
.64609 .09578 m
.64574 .08678 L
s
.64574 .08678 m
.64645 .10425 L
s
.744 .221 1 r
.58916 .09063 m
.58933 .1002 L
s
.58936 .10014 m
.58916 .09063 L
s
.58916 .09063 m
.58959 .10941 L
s
.467 .292 1 r
.66904 .11609 m
.66898 .11628 L
s
.733 .224 1 r
.68015 .10621 m
.68062 .1157 L
s
.68068 .1155 m
.68015 .10621 L
s
.68062 .1157 m
.68018 .10615 L
s
.68018 .10615 m
.68068 .1155 L
s
.765 .217 1 r
.61752 .09061 m
.61777 .10018 L
s
.6178 .10012 m
.61752 .09061 L
s
.61752 .09061 m
.61812 .10956 L
s
.904 .186 1 r
.65186 .10839 m
.65226 .11828 L
s
.65233 .11808 m
.65186 .10839 L
s
1 .151 .92 r
.7197 .09501 m
.7203 .10519 L
s
.72034 .10513 m
.7197 .09501 L
s
.7197 .09501 m
.72102 .11544 L
s
.904 .186 1 r
.65226 .11828 m
.65189 .10833 L
s
.65189 .10833 m
.65233 .11808 L
s
.485 .287 1 r
.60634 .10152 m
.60657 .11033 L
s
.60663 .11018 m
.60634 .10152 L
s
.60657 .11033 m
.60637 .10147 L
s
.60637 .10147 m
.60663 .11018 L
s
1 .118 .743 r
.72575 .11463 m
.72642 .12509 L
s
.72652 .12535 m
.72575 .11463 L
s
.72642 .12509 m
.72579 .11457 L
s
.72579 .11457 m
.72652 .12535 L
s
.868 .194 1 r
.58415 .12303 m
.58409 .12323 L
s
.777 .214 1 r
.64477 .04277 m
.64683 .08859 L
s
.733 .224 1 r
.57805 .10432 m
.57821 .11385 L
s
.57827 .11353 m
.57805 .10432 L
s
.57821 .11385 m
.57808 .10426 L
s
.57808 .10426 m
.57827 .11353 L
s
.433 .302 1 r
.59529 .1135 m
.59523 .11365 L
s
.559 .267 1 r
.56696 .1153 m
.5669 .11565 L
s
.881 .191 1 r
.61252 .1224 m
.61246 .12264 L
s
.579 .262 1 r
.67315 .04212 m
.67553 .08599 L
s
.701 .231 1 r
.67429 .09026 m
.6747 .09953 L
s
.67473 .09948 m
.67429 .09026 L
s
.67429 .09026 m
.67523 .10907 L
s
.834 .201 1 r
.70265 .08881 m
.70318 .09859 L
s
.70321 .09853 m
.70265 .08881 L
s
.70265 .08881 m
.70379 .10805 L
s
.658 .242 1 r
.69757 .11818 m
.69751 .11834 L
s
.929 .181 1 r
.6409 .12178 m
.64085 .12218 L
s
.391 .315 1 r
.70155 .04146 m
.70417 .08261 L
s
.733 .224 1 r
.63482 .10398 m
.63515 .1134 L
s
.63522 .11343 m
.63482 .10398 L
s
.63515 .1134 m
.63485 .10393 L
s
.63485 .10393 m
.63522 .11343 L
s
.69 .234 1 r
.60046 .08702 m
.60066 .09637 L
s
.60068 .09631 m
.60046 .08702 L
s
.60046 .08702 m
.60095 .10567 L
s
.846 .199 1 r
.66324 .10335 m
.66367 .11317 L
s
.66373 .11281 m
.66324 .10335 L
s
.66367 .11317 m
.66327 .1033 L
s
.66327 .1033 m
.66373 .11281 L
s
.701 .231 1 r
.65723 .08466 m
.65761 .09416 L
s
.65764 .09411 m
.65723 .08466 L
s
.65723 .08466 m
.65806 .10323 L
s
.765 .217 1 r
.69164 .1024 m
.69215 .11198 L
s
.69221 .11178 m
.69164 .1024 L
s
.69215 .11198 m
.69167 .10235 L
s
.69167 .10235 m
.69221 .11178 L
s
.701 .232 1 r
.62378 .11598 m
.62372 .1163 L
s
.514 .279 1 r
.64606 .09583 m
.64641 .10488 L
s
.64645 .10425 m
.64606 .09583 L
s
.64641 .10488 m
.64609 .09578 L
s
.64609 .09578 m
.64645 .10425 L
s
.68 .237 1 r
.68566 .0841 m
.68612 .09352 L
s
.68615 .09347 m
.68566 .0841 L
s
.68566 .0841 m
.68666 .10259 L
s
1 .081 .525 r
.71504 .1306 m
.71496 .13058 L
s
.977 .171 1 r
.62891 .0875 m
.62922 .0976 L
s
.62925 .09754 m
.62891 .0875 L
s
.62891 .0875 m
.62961 .10738 L
s
.424 .305 1 r
.65618 .03852 m
.65823 .08086 L
s
.744 .221 1 r
.58933 .1002 m
.58952 .10977 L
s
.58959 .10941 m
.58933 .1002 L
s
.58952 .10977 m
.58936 .10014 L
s
.58936 .10014 m
.58959 .10941 L
s
.811 .206 1 r
.71417 .08439 m
.71473 .09413 L
s
.71476 .09407 m
.71417 .08439 L
s
.71417 .08439 m
.71537 .10351 L
s
.638 .247 1 r
.68462 .03787 m
.68724 .08294 L
s
.733 .224 1 r
.68068 .1155 m
.68062 .1157 L
s
.485 .287 1 r
.60663 .11018 m
.60657 .11033 L
s
.765 .217 1 r
.61777 .10018 m
.61805 .10976 L
s
.61812 .10956 m
.61777 .10018 L
s
.61805 .10976 m
.6178 .10012 L
s
.6178 .10012 m
.61812 .10956 L
s
.904 .186 1 r
.65233 .11808 m
.65226 .11828 L
s
1 .151 .92 r
.7203 .10519 m
.72094 .11537 L
s
.72102 .11544 m
.7203 .10519 L
s
.72094 .11537 m
.72034 .10513 L
s
.72034 .10513 m
.72102 .11544 L
s
.733 .224 1 r
.57827 .11353 m
.57821 .11385 L
s
.711 .229 1 r
.64023 .08145 m
.64055 .09095 L
s
.64058 .0909 m
.64023 .08145 L
s
.64023 .08145 m
.64096 .1001 L
s
.799 .209 1 r
.61181 .08317 m
.61205 .09284 L
s
.61207 .09278 m
.61181 .08317 L
s
.61181 .08317 m
.61238 .10231 L
s
1 .118 .743 r
.72652 .12535 m
.72642 .12509 L
s
.701 .231 1 r
.6747 .09953 m
.67515 .1088 L
s
.67523 .10907 m
.6747 .09953 L
s
.67515 .1088 m
.67473 .09948 L
s
.67473 .09948 m
.67523 .10907 L
s
.834 .201 1 r
.70318 .09859 m
.70374 .10837 L
s
.70379 .10805 m
.70318 .09859 L
s
.70374 .10837 m
.70321 .09853 L
s
.70321 .09853 m
.70379 .10805 L
s
.869 .194 1 r
.66875 .08165 m
.66917 .09156 L
s
.6692 .0915 m
.66875 .08165 L
s
.66875 .08165 m
.66968 .10102 L
s
.608 .254 1 r
.66763 .03426 m
.66998 .07897 L
s
.733 .224 1 r
.63522 .11343 m
.63515 .1134 L
s
.777 .214 1 r
.69725 .08133 m
.69775 .09092 L
s
.69778 .09086 m
.69725 .08133 L
s
.69725 .08133 m
.69835 .10039 L
s
.69 .234 1 r
.60066 .09637 m
.60088 .10571 L
s
.60095 .10567 m
.60066 .09637 L
s
.60088 .10571 m
.60068 .09631 L
s
.60068 .09631 m
.60095 .10567 L
s
.45 .297 1 r
.69613 .03361 m
.69874 .07558 L
s
.846 .199 1 r
.66373 .11281 m
.66367 .11317 L
s
.514 .279 1 r
.64645 .10425 m
.64641 .10488 L
s
.701 .231 1 r
.65761 .09416 m
.65801 .10366 L
s
.65806 .10323 m
.65761 .09416 L
s
.65801 .10366 m
.65764 .09411 L
s
.65764 .09411 m
.65806 .10323 L
s
.765 .217 1 r
.69221 .11178 m
.69215 .11198 L
s
.68 .237 1 r
.68612 .09352 m
.68661 .10294 L
s
.68666 .10259 m
.68612 .09352 L
s
.68661 .10294 m
.68615 .09347 L
s
.68615 .09347 m
.68666 .10259 L
s
.977 .171 1 r
.62922 .0976 m
.62955 .1077 L
s
.62961 .10738 m
.62922 .0976 L
s
.744 .221 1 r
.58959 .10941 m
.58952 .10977 L
s
.977 .171 1 r
.62955 .1077 m
.62925 .09754 L
s
.62925 .09754 m
.62961 .10738 L
s
.608 .254 1 r
.68015 .07598 m
.68059 .08521 L
s
.68061 .08515 m
.68015 .07598 L
s
.68015 .07598 m
.6811 .09413 L
s
.833 .201 1 r
.6232 .07922 m
.62348 .08898 L
s
.6235 .08892 m
.6232 .07922 L
s
.6232 .07922 m
.62385 .09853 L
s
.811 .206 1 r
.71473 .09413 m
.71532 .10387 L
s
.71537 .10351 m
.71473 .09413 L
s
.71532 .10387 m
.71476 .09407 L
s
.71476 .09407 m
.71537 .10351 L
s
.765 .217 1 r
.61812 .10956 m
.61805 .10976 L
s
.559 .267 1 r
.67913 .02999 m
.68159 .07355 L
s
.834 .201 1 r
.7088 .07695 m
.70935 .08674 L
s
.70938 .08668 m
.7088 .07695 L
s
.7088 .07695 m
.70999 .09622 L
s
1 .164 .985 r
.65181 .08043 m
.65218 .09051 L
s
.65222 .09045 m
.65181 .08043 L
s
.65181 .08043 m
.65267 .10063 L
s
1 .151 .92 r
.72102 .11544 m
.72094 .11537 L
s
.711 .229 1 r
.64055 .09095 m
.6409 .10046 L
s
.64096 .1001 m
.64055 .09095 L
s
.467 .292 1 r
.63449 .07192 m
.63478 .08075 L
s
.6348 .0807 m
.63449 .07192 L
s
.63449 .07192 m
.63514 .08928 L
s
.711 .229 1 r
.6409 .10046 m
.64058 .0909 L
s
.64058 .0909 m
.64096 .1001 L
s
.799 .209 1 r
.61205 .09284 m
.61231 .10251 L
s
.61238 .10231 m
.61205 .09284 L
s
.61231 .10251 m
.61207 .09278 L
s
.61207 .09278 m
.61238 .10231 L
s
.701 .231 1 r
.67523 .10907 m
.67515 .1088 L
s
.834 .201 1 r
.70379 .10805 m
.70374 .10837 L
s
.416 .307 1 r
.66307 .07185 m
.66342 .08042 L
s
.66345 .08037 m
.66307 .07185 L
s
.66307 .07185 m
.66387 .08902 L
s
.869 .194 1 r
.66917 .09156 m
.66963 .10146 L
s
.66968 .10102 m
.66917 .09156 L
s
.66963 .10146 m
.6692 .0915 L
s
.6692 .0915 m
.66968 .10102 L
s
.559 .267 1 r
.69166 .07128 m
.69213 .08039 L
s
.69215 .08034 m
.69166 .07128 L
s
.69166 .07128 m
.69267 .08916 L
s
.69 .234 1 r
.60095 .10567 m
.60088 .10571 L
s
.777 .214 1 r
.69775 .09092 m
.69829 .10051 L
s
.69835 .10039 m
.69775 .09092 L
s
.69829 .10051 m
.69778 .09086 L
s
.69778 .09086 m
.69835 .10039 L
s
.701 .231 1 r
.65806 .10323 m
.65801 .10366 L
s
.68 .237 1 r
.68666 .10259 m
.68661 .10294 L
s
.744 .222 1 r
.69068 .02569 m
.69349 .07241 L
s
.608 .254 1 r
.68059 .08521 m
.68105 .09444 L
s
.6811 .09413 m
.68059 .08521 L
s
.977 .171 1 r
.62961 .10738 m
.62955 .1077 L
s
.608 .254 1 r
.68105 .09444 m
.68061 .08515 L
s
.68061 .08515 m
.6811 .09413 L
s
.833 .201 1 r
.62348 .08898 m
.62378 .09873 L
s
.62385 .09853 m
.62348 .08898 L
s
.62378 .09873 m
.6235 .08892 L
s
.6235 .08892 m
.62385 .09853 L
s
.811 .206 1 r
.71537 .10351 m
.71532 .10387 L
s
.391 .315 1 r
.70316 .06572 m
.70362 .07432 L
s
.70365 .07427 m
.70316 .06572 L
s
.70316 .06572 m
.70417 .08261 L
s
.579 .262 1 r
.67462 .06798 m
.67503 .07714 L
s
.67506 .07709 m
.67462 .06798 L
s
.67462 .06798 m
.67553 .08599 L
s
.777 .214 1 r
.64605 .06963 m
.6464 .07935 L
s
.64643 .07929 m
.64605 .06963 L
s
.64605 .06963 m
.64683 .08859 L
s
.467 .292 1 r
.63478 .08075 m
.63509 .08959 L
s
.63514 .08928 m
.63478 .08075 L
s
.63509 .08959 m
.6348 .0807 L
s
.6348 .0807 m
.63514 .08928 L
s
.711 .229 1 r
.64096 .1001 m
.6409 .10046 L
s
.834 .201 1 r
.70935 .08674 m
.70994 .09653 L
s
.70999 .09622 m
.70935 .08674 L
s
.70994 .09653 m
.70938 .08668 L
s
.70938 .08668 m
.70999 .09622 L
s
.799 .209 1 r
.61238 .10231 m
.61231 .10251 L
s
1 .164 .985 r
.65218 .09051 m
.6526 .1006 L
s
.65267 .10063 m
.65218 .09051 L
s
.6526 .1006 m
.65222 .09045 L
s
.65222 .09045 m
.65267 .10063 L
s
.416 .307 1 r
.66342 .08042 m
.6638 .08898 L
s
.66387 .08902 m
.66342 .08042 L
s
.6638 .08898 m
.66345 .08037 L
s
.66345 .08037 m
.66387 .08902 L
s
.559 .267 1 r
.69213 .08039 m
.69262 .08951 L
s
.69267 .08916 m
.69213 .08039 L
s
.869 .194 1 r
.66968 .10102 m
.66963 .10146 L
s
.559 .267 1 r
.69262 .08951 m
.69215 .08034 L
s
.69215 .08034 m
.69267 .08916 L
s
.424 .305 1 r
.65746 .06367 m
.6578 .07233 L
s
.65783 .07227 m
.65746 .06367 L
s
.65746 .06367 m
.65823 .08086 L
s
.777 .214 1 r
.69835 .10039 m
.69829 .10051 L
s
.638 .247 1 r
.68624 .06456 m
.68669 .07385 L
s
.68672 .07379 m
.68624 .06456 L
s
.68624 .06456 m
.68724 .08294 L
s
.608 .254 1 r
.6811 .09413 m
.68105 .09444 L
s
.391 .315 1 r
.70362 .07432 m
.70412 .08292 L
s
.70417 .08261 m
.70362 .07432 L
s
.70412 .08292 m
.70365 .07427 L
s
.70365 .07427 m
.70417 .08261 L
s
.833 .201 1 r
.62385 .09853 m
.62378 .09873 L
s
.579 .262 1 r
.67503 .07714 m
.67548 .0863 L
s
.67553 .08599 m
.67503 .07714 L
s
.67548 .0863 m
.67506 .07709 L
s
.67506 .07709 m
.67553 .08599 L
s
.467 .292 1 r
.63514 .08928 m
.63509 .08959 L
s
.777 .214 1 r
.6464 .07935 m
.64678 .08907 L
s
.64683 .08859 m
.6464 .07935 L
s
.64678 .08907 m
.64643 .07929 L
s
.64643 .07929 m
.64683 .08859 L
s
.416 .307 1 r
.66387 .08902 m
.6638 .08898 L
s
.834 .201 1 r
.70999 .09622 m
.70994 .09653 L
s
.45 .297 1 r
.69773 .05831 m
.6982 .06712 L
s
.69822 .06707 m
.69773 .05831 L
s
.69773 .05831 m
.69874 .07558 L
s
.608 .254 1 r
.66909 .06074 m
.66949 .06995 L
s
.66952 .0699 m
.66909 .06074 L
s
.66909 .06074 m
.66998 .07897 L
s
1 .164 .985 r
.65267 .10063 m
.6526 .1006 L
s
.559 .267 1 r
.69267 .08916 m
.69262 .08951 L
s
.424 .305 1 r
.6578 .07233 m
.65818 .08097 L
s
.65823 .08086 m
.6578 .07233 L
s
.65818 .08097 m
.65783 .07227 L
s
.65783 .07227 m
.65823 .08086 L
s
.638 .247 1 r
.68669 .07385 m
.68718 .08314 L
s
.68724 .08294 m
.68669 .07385 L
s
.391 .315 1 r
.70417 .08261 m
.70412 .08292 L
s
.638 .247 1 r
.68718 .08314 m
.68672 .07379 L
s
.68672 .07379 m
.68724 .08294 L
s
.559 .267 1 r
.68065 .05563 m
.68108 .06476 L
s
.68111 .06471 m
.68065 .05563 L
s
.68065 .05563 m
.68159 .07355 L
s
.579 .262 1 r
.67553 .08599 m
.67548 .0863 L
s
.777 .214 1 r
.64683 .08859 m
.64678 .08907 L
s
.45 .297 1 r
.6982 .06712 m
.69869 .07593 L
s
.69874 .07558 m
.6982 .06712 L
s
.69869 .07593 m
.69822 .06707 L
s
.69822 .06707 m
.69874 .07558 L
s
.608 .254 1 r
.66949 .06995 m
.66992 .07917 L
s
.66998 .07897 m
.66949 .06995 L
s
.66992 .07917 m
.66952 .0699 L
s
.66952 .0699 m
.66998 .07897 L
s
.424 .305 1 r
.65823 .08086 m
.65818 .08097 L
s
.638 .247 1 r
.68724 .08294 m
.68718 .08314 L
s
.744 .222 1 r
.69242 .05344 m
.69291 .06298 L
s
.69294 .06293 m
.69242 .05344 L
s
.69242 .05344 m
.69349 .07241 L
s
.559 .267 1 r
.68108 .06476 m
.68154 .0739 L
s
.68159 .07355 m
.68108 .06476 L
s
.68154 .0739 m
.68111 .06471 L
s
.68111 .06471 m
.68159 .07355 L
s
.45 .297 1 r
.69874 .07558 m
.69869 .07593 L
s
.608 .254 1 r
.66998 .07897 m
.66992 .07917 L
s
.744 .222 1 r
.69291 .06298 m
.69343 .07254 L
s
.69349 .07241 m
.69291 .06298 L
s
.69343 .07254 m
.69294 .06293 L
s
.69294 .06293 m
.69349 .07241 L
s
.559 .267 1 r
.68159 .07355 m
.68154 .0739 L
s
.744 .222 1 r
.69349 .07241 m
.69343 .07254 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{288, 189.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000_B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00`@3oool00`2n>?l0oooo0?ooo`1L0?ooo`00_P3oool0102?A?l0oooo
0?ooo`2n>?mN0?ooo`00^`3oool0102K@Ol0oooo0?ooo`2?A?l20?ooo`030;hho`1cC?l0oooo05`0
oooo002h0?ooo`0406a>o`3oool0oooo09]1o`80oooo00D0SdCo0:<oo`3oool0_SSo07=<o`1M0?oo
o`00]@3oool01036=_l0oooo0?ooo`1/C_l20?ooo`0:09]1o`2D@ol0oooo08m4o`2S?ol0oooo0;hh
o`1cC?l0oooo06A@oe/0oooo002b0?ooo`0407M:o`3oool0oooo0<Hfo`80oooo00d0K4ko06Y>o`3o
ool0Vd7o09A3o`3oool0SdCo0:<oo`3oool0_SSo07=<o`3oool0I53o05/0oooo002_0?ooo`040=Dc
o`3oool0oooo07M:o`80oooo0140aSKo0?lYo03oool0K4ko06Y>o`3oool0Vd7o09A3o`3oool0SdCo
0:<oo`3oool0SdCo0;hho`3oool0I53o0=Dco`1J0?ooo`00[03oool0103<=Ol0oooo0?ooo`3E<ol2
0?ooo`0<07M:o`2f>_l0oooo0<Hfo`3o:O`0oooo06a>o`1ZC_l0oooo09]1o`2D@ol0oooo0P2?A?l0
1P3oool0_SSo0;hho`3oool0I53o0=DcoeX0oooo002Y0?ooo`040;0ko`3oool0oooo0<`eo`80oooo
00l0eC?o0?ooo`3j:ol0Md[o0;Hjo`3oool0aSKo0?lYo03oool0K4ko06Y>o`3oool0gS7o09]1o`3o
ool00P2?A?l0203oool0_SSo0;hho`1cC?l0I53o0=Dco`3oool0ccCoF03oool00:T0oooo0180/3_o
0?ooo`3oool0c3Go0?ooo`33=ol0eC?o0?ooo`3j:ol0Md[o0;Hjo`3oool0aSKo0?lYo03oool0/c_o
06a>o`3oool209]1o`040?ooo`2?A?l0SdCo0:<oo`80_SSo00D0Ldco0=Dco`1TD?l0oooo0<ldo`1H
0?ooo`00YP3oool04P2n>?l0oooo0?ooo`2`>ol0oooo07a9o`3<=Ol0oooo0<<go`3E<ol0oooo0?X[
o`1gB_l0]S[o0?ooo`23Aol0aSKo0?ooo`80K4ko00X0oooo09]1o`2K@Ol0U4?o09]1o`2?A?l0Xcoo
08m4o`2n>?l0Ldco0P1TD?l00`3oool0ccCo0?lVj`1G0?ooo`00X`3oool0102k>Ol0oooo0?ooo`2n
>?l20?ooo`0<0;0ko`3oool0O4Wo0<`eo`3oool0`cOo0=Dco`3oool0nR_o07M:o`2f>_l0oooo0P36
=_l0103oool0K4ko06a>o`1ZC_l209]1o`0709A3o`2K@Ol0SdCo0:<oo`33=ol0_SSo07=<o`0206A@
o`030?ooo`3?=?l0obK[05L0oooo002P0?ooo`0408m4o`3oool0oooo0;/io`80oooo00l0_SSo0?oo
o`1^COl0/3_o0?ooo`1lBOl0c3Go0?ooo`33=ol0eC?o0?ooo`3j:ol0Md[o0;Hjo`3oool00P36=_l0
103oool0K4ko06a>o`1ZC_l209]1o`0709A3o`2k>Ol0SdCo0:<oo`2?A?l0_SSo07=<o`0206A@o`04
0=Dco`3?=?l0obK[0?lN_UH0oooo002M0?ooo`0408E6o`3oool0oooo08m4o`80oooo0180^cWo0?oo
o`3N<Ol0_SSo0?ooo`1^COl0/3_o0?ooo`1lBOl0c3Go0?ooo`33=ol0eC?o0?ooo`3j:ol0Md[o0>d^
o`2f>_l20<Hfo`070?lYo02c>ol0K4ko06Y>o`1gB_l0Vd7o09A3o`0209]1o`040:<oo`2?A?l0SdCo
07=<o`80I53o00@0eC?o0<ldo`3o9^/0oajnEP3oool009/0oooo00<0/c_o0?ooo`25A_l00P3oool0
5@2?A?l0oooo0:<oo`2k>Ol0oooo0=hao`2n>?l0oooo06i=o`2`>ol0oooo07a9o`3<=Ol0oooo0<<g
o`3E<ol0oooo0?X[o`1gB_l0kBko0;Hjo`020<Hfo`070?lYo02c>ol0K4ko06Y>o`3N<Ol0Vd7o09A3
o`0209]1o`0<0:<oo`2?A?l0SdCo0<Hfo`3E<ol0I53o0=Dco`3oool0ccCo0?lN_P3oool0QdKoE03o
ool009P0oooo02<0]S[o0?ooo`3oool0/c_o0?ooo`25A_l0oooo0;/io`2?A?l0oooo0:<oo`2k>Ol0
oooo0=hao`2n>?l0oooo06i=o`2`>ol0oooo07a9o`3<=Ol0oooo0<<go`3E<ol0oooo0?X[o`1gB_l0
kBko0;Hjo`23Aol0aSKo0?lYo02c>ol0f3;o06Y>o`020=hao`0:09A3o`2K@Ol0Vd7o0:<oo`33=ol0
SdCo0<Hfo`3E<ol0I53o0=Dco`80ccCo00<0oajn0?ooo`27A_l0E03oool009D0oooo00@0QDKo0?oo
o`3oool0]S[o0P3oool0802c>ol0/3_o08E6o`3oool0^cWo08m4o`3oool0Xcoo0;/io`3oool0gS7o
08m4o`2n>?l0KTgo0;0ko`3oool0O4Wo0<`eo`3oool0`cOo0=Dco`3oool0nR_o07M:o`3];_l0]S[o
08=7o`36=_l0obWl0;<ko`2n>?l0JTko0P3N<Ol02P2c>ol0Vd7o09]1o`2^??l0`cOo08m4o`36=_l0
eC?o0:Wo[03E<ol20<ldo`040?lN_P3oool0QdKo0<@goe<0oooo002B0?ooo`040:/mo`3oool0oooo
08E6o`80oooo00/0]S[o0>4`o`3oool0/c_o0;0ko`25A_l0oooo0;/io`2?A?l0oooo0:<oo`020;/i
o`0F0=hao`2n>?l0_SSo06i=o`2`>ol0oooo07a9o`3<=Ol0oooo0<<go`3E<ol0oooo0?X[o`2k>Ol0
kBko0;Hjo`23Aol0iboo0?lYo02c>ol0_SSo0=Pbo`80gS7o00X0/c_o0;/io`2K@Ol0[Sco0<<go`2X
?Ol0aSKo0=Dco`1OQOl0eC?o0P3?=?l0103o9^/0oooo08M6o`34=omC0?ooo`00S`3oool0102F@_l0
oooo0?ooo`2[?Ol20?ooo`0>08E6o`1ZC_l0oooo0;Hjo`3Q<?l0oooo0;<ko`2`>ol0QDKo0<Hfo`2k
>Ol0_SSo08m4o`2S?ol20;/io`0R0=hao`2n>?l0_SSo06i=o`2`>ol0oooo07a9o`3<=Ol0oooo0<<g
o`3E<ol0oooo0?X[o`2k>Ol0kBko0;Hjo`23Aol0l2go0?lYo02c>ol0_SSo0=Pbo`1gB_l0gS7o0;<k
o`2k>Ol0Vd7o0:hlo`33=ol0Td?o0<Hfo`3E<ol0GhGo0=Dco`80ccCo00H0obK[0?ooo`27A_l0a3Oo
0?ooo`2^??mA0?ooo`00S03oool0102f>_l0oooo0?ooo`2F@_l20?ooo`0A0:/mo`3oool0c3Go08E6
o`1ZC_l0oooo0;Hjo`3Q<?l0oooo0;<ko`2`>ol0oooo08E6o`2k>Ol0_SSo08m4o`2S?ol00P2k>Ol0
8P3N<Ol0_SSo0;hho`1^COl0/3_o0?ooo`1lBOl0c3Go0>4`o`33=ol0eC?o0?ooo`3j:ol0^cWo07M:
o`2f>_l0PdOo0?0]o`3o:O`0/c_o0;hho`3H<_l0Md[o0=hao`2c>ol0^cWo0?lWlP2^??l0`cOo09=3
o`36=_l0eC?o05n5o`3o58H20<ldo`060?lVj`3o7[h0QdKo0<@go`3oool0[ScoD@3oool008T0oooo
00@0`CSo0?ooo`3oool0]S[o0P3oool0502F@_l0oooo0:Pmo`2[?Ol0oooo0<`eo`25A_l0JTko0?oo
o`2f>_l0hC3o0?ooo`2c>ol0/3_o0?ooo`25A_l0^cWo0;hho`2?A?l0Xcoo0P2k>Ol0103N<Ol0_SSo
0;hho`1^COl20;0ko`0L07a9o`3<=Ol0hC3o0<<go`2c>ol0oooo0?X[o`2k>Ol0Md[o0>d^o`23Aol0
l2go0>L_o`2c>ol0_SSo0=Pbo`1gB_l0kBko0;<ko`2k>Ol0obOb0:hlo`33=ol0Td?o0:Pmo`3E<ol0
GhGo0>4`o`80ccCo00L0obK[0?lN_P27A_l0QdKo0?ooo`2^??l0iboo0500oooo00270?ooo`0307Y9
o`3oool0`CSo0080oooo01L0]S[o0?ooo`3B=?l0UT;o0?ooo`2X?Ol0Zcgo0?ooo`3<=Ol0QDKo06Y>
o`3oool0]S[o0>4`o`3oool0/c_o0;0ko`3oool0QDKo0;/io`2n>?l0SdCo0:<oo`020;/io`070=ha
o`2n>?l0_SSo06i=o`2`>ol0gS7o07a9o`020>4`o`0M0<<go`2c>ol0oooo0?X[o`2k>Ol0Md[o0>d^
o`2N@?l0l2go0>L_o`2^??l0gS7o0=Pbo`1gB_l0kBko0;<ko`2k>Ol0obOb0:hlo`33=ol0Td?o0:Pm
o`3E<ol0WT3o05n5o`3o58H0QdKo0?lVj`3o7[h00P27A_l00`3oool0[Sco0>L_o`1@0?ooo`00Q03o
ool08P2f>_l0oooo0?ooo`1jBOl0oooo0<4ho`3oool0`CSo0;Hjo`3oool0dSCo09I2o`3oool0Z3go
0:/mo`3oool0c3Go08E6o`1ZC_l0oooo0;Hjo`3Q<?l0oooo0;<ko`2`>ol0oooo08E6o`2k>Ol0_SSo
08m4o`2S?ol0gS7o0;/io`3N<Ol20;hho`0406i=o`3N<Ol0gS7o07a9o`80hC3o00@0`cOo0;<ko`3o
ool0bCKo0P2k>Ol03`3];_l0WT3o0?0]o`3W;ol0[Sco0=hao`3H<_l0Md[o0>d^o`2^??l0^cWo0?lW
lP2^??l0`cOo09=3o`020:Pmo`80GhGo00@0oaB608M6o`3o9^/0oajn0P27A_l01034=ol0[Sco0>L_
o`3<=Om?0?ooo`00P@3oool0103B=?l0oooo0?ooo`2f>_l20?ooo`0O07Y9o`2c>ol0`CSo0?ooo`31
>?l0]S[o0?ooo`3B=?l0UT;o0?ooo`2X?Ol0Zcgo0?ooo`3<=Ol0QDKo06Y>o`1HE?l0]S[o0>4`o`3o
ool0/c_o0;0ko`3oool0QDKo0;/io`3oool0SdCo0:<oo`3N<Ol0^cWo0=hao`0208m4o`0406i=o`3N
<Ol0gS7o09i0o`80hC3o01D0YCko0;<ko`3N<Ol0bCKo0;/io`3W;ol0kBko09i0o`2[?Ol0iboo0:hl
o`3N<Ol0f3;o07M:o`3];_l0[Sco0;/io`3o9o80[Sco0<4ho`2f>_l00P2X?Ol205n5o`040?lDQP27
A_l0obK[0?lN_P80QdKo00@0a3Oo0:hlo`3W;ol0c3GoC`3oool007h0oooo00@0a3Oo0?ooo`3oool0
dSCo0P3oool09@2f>_l0eC?o0?ooo`1jBOl0/c_o0<4ho`3oool0`CSo0;Hjo`2U?_l0dSCo09I2o`3o
ool0Z3go0:/mo`3oool0c3Go08E6o`1ZC_l0F5Co0;Hjo`3Q<?l0oooo0;<ko`2`>ol0oooo08E6o`2k
>Ol0oooo0;hho`2S?ol0gS7o0;/io`3N<Ol0X3oo08m4o`36=_l00P3N<Ol0602N@?l0[Sco0>4`o`2U
?_l0P4So0=hao`39=_l0Z3go0>L_o`3];_l0WT3o0:/mo`3W;ol0[Sco0=hao`2n>?l0aSKo0>d^o`2^
??l0/3_o0?lWlP2^??l0`CSo09=3o`80Z3go0P1OQOl0303o58H0QdKo08M6o`3o7[h0SdCo08M6o`34
=ol0[Sco0>L_o`3<=Ol0oooo09=3odd0oooo001k0?ooo`040<`eo`3oool0oooo0<@go`80oooo0440
dSCo0?ooo`1^COl0]S[o0=Dco`3oool0NTWo0;<ko`31>?l0bCKo0<4ho`2f>_l0YCko0=8do`2F@_l0
oooo0:Pmo`2[?Ol0oooo0<`eo`25A_l0JTko05QDo`2f>_l0hC3o0?ooo`2c>ol0/3_o0?ooo`36=_l0
^cWo0?ooo`2n>?l0Xcoo0=hao`2k>Ol0gS7o0:0oo`2?A?l0aSKo09=3o`3N<Ol0WT3o0:hlo`3Q<?l0
YCko0818o`3N<Ol0bCKo0:Pmo`3W;ol0kBko09i0o`2[?Ol0l2go0:hlo`3N<Ol0_SSo0<Hfo`3];_l0
[Sco0;0ko`3W;ol0[Sco0<4ho`0209=3o`0@0:Pmo`2N@?l0GhGo0?lDQP2F@_l0QdKo0?lN_P2?A?l0
QdKo0<@go`2^??l0iboo0<`eo`3oool0Td?o0;/iod`0oooo001i0?ooo`030:Pmo`3oool0c3Go0080
oooo02h0a3Oo0?ooo`36=_l0dSCo0?ooo`1^COl0]S[o0=Dco`3oool0NTWo0;<ko`31>?l0bCKo0<4h
o`2f>_l0YCko0=8do`2F@_l0oooo0:Pmo`2[?Ol0oooo0<`eo`25A_l0JTko05QDo`2f>_l0hC3o0?oo
o`2c>ol0/3_o0?ooo`36=_l0^cWo0?ooo`2n>?l0P4So0=hao`2k>Ol0_SSo0:<oo`2?A?l0aSKo0;/i
o`3N<Ol0WT3o0P2^??l04@2U?_l0P4So0=hao`39=_l0Z3go0>L_o`1gB_l0WT3o0:/mo`3`;Ol0dSCo
0=hao`2n>?l0aSKo0>L_o`2^??l0/3_o0080obOb01<0`CSo09=3o`2C@ol0Z3go09i0o`1OQOl0oaB6
09I2o`27A_l0oajn08m4o`2h>_l0a3Oo0:hlo`1/C_l0iboo0?ooo`2C@ol0^cWo04`0oooo001f0?oo
o`0c0;Pjo`3oool0oooo0:Pmo`3oool0c3Go0?ooo`2K@Ol0a3Oo0?ooo`36=_l0dSCo0?ooo`1^COl0
]S[o0=Dco`3oool0NTWo0;<ko`31>?l0bCKo0<4ho`2f>_l0YCko0=8do`2F@_l0oooo0:Pmo`2[?Ol0
oooo0<`eo`25A_l0JTko05QDo`2f>_l0hC3o0=Dco`3`;Ol0/3_o0?ooo`36=_l0^cWo0?ooo`2n>?l0
P4So0?ooo`2k>Ol0_SSo0:<oo`2P?ol0aSKo0080^cWo00D0WT3o0:hlo`2^??l0Xcoo0818o`020=ha
o`0=0:Pmo`3W;ol0Md[o0:Hno`21B?l0l2go0=8do`1iB_l0_SSo0<Hfo`3W;ol0kBko0;0ko`020?lW
lP030<4ho`2f>_l0Td?o0080WT3o00T0gS7o0?lDQP3o58H0jRoo0=Dco`2?A?l0_SSo0<@go`2^??l0
0P3W;ol0103oool0Td?o0;/io`2U?_m;0?ooo`00L`3oool0101Y/Ol0oooo0?ooo`2h>_l20?ooo`0`
0:Pmo`2k>Ol0c3Go0?ooo`2K@Ol0a3Oo0?ooo`36=_l0dSCo0?ooo`1^COl0]S[o0=Dco`3oool0NTWo
0;<ko`31>?l0bCKo0<4ho`2f>_l0YCko0=8do`2F@_l0f3;o0:Pmo`2[?Ol0oooo0<`eo`2=A?l0JTko
05QDo`3`;Ol0hC3o0;Pjo`3`;Ol0/3_o0?ooo`36=_l0]S[o0?ooo`2n>?l0P4So0?ooo`2k>Ol0_SSo
0:<oo`2P?ol0aSKo0P2k>Ol01@2n>?l0ccCo0:hlo`2S?ol0P4So0080gS7o00`0/3_o0>L_o`1gB_l0
YSko0858o`3`;Ol0dSCo07U:o`3N<Ol0aSKo0>L_o`3];_l20;0ko`040?lWlP2N@?l0]S[o09=3o`80
WT3o00T0gS7o0>4`o`2F@_l0IJ7o0=Dco`2?A?l0^3[o0<@go`2^??l00P3W;ol0103<=Ol0Td?o0;/i
o`2U?_m;0?ooo`00L@3oool00`3?=?l0oooo06Vao`020?ooo`0j0;Pjo`3oool0Xcoo0:Pmo`2k>Ol0
c3Go0?ooo`2K@Ol0a3Oo08M6o`36=_l0dSCo0?ooo`1^COl0]S[o0=Dco`2c>ol0NTWo0;<ko`31>?l0
bCKo0<4ho`2f>_l0YCko0=8do`2F@_l0f3;o0:Pmo`2[?Ol0oooo0<`eo`2=A?l0JTko05QDo`3`;Ol0
hC3o0;Pjo`3`;Ol0]S[o0?ooo`36=_l0]S[o0?ooo`2n>?l0P4So0?ooo`3N<Ol0_SSo0:<oo`2P?ol0
aSKo09i0o`2k>Ol0_SSo0:<oo`2^??l0Xcoo0:Pmo`80gS7o0180/3_o0<`eo`3W;ol0YSko0858o`3`
;Ol0dSCo07U:o`3N<Ol0aSKo0>L_o`3];_l0_SSo09I2o`3o9o80WT3o0;Hjo`2C@ol209i0o`0607i8
o`3Q<?l0UT;o06FQo`3E<ol0SdCo0P2h>_l0202^??l0iboo0>L_o`3<=Ol0Td?o0;/io`2U?_l0obWh
BP3oool00740oooo03/0ccCo0?ooo`1Y/Ol0oooo0953o`2h>_l0oooo0:<oo`2X?Ol0^cWo0<`eo`2:
AOl0Vd7o0<@go`27A_l0aSKo0=8do`3oool0KTgo0;Hjo`3E<ol0/c_o07Y9o`2c>ol0`CSo0<Tfo`31
>?l0]S[o0:Dno`3B=?l0UT;o0=Pbo`2X?Ol0QDKo0?ooo`3<=Ol0SDCo0?ooo`1HE?l0l2go0?ooo`2h
>_l0l2go0;Hjo`1KLol0aSKo0;Hjo`3oool0c3Go0818o`3oool0gS7o0;hho`3oool0X3oo0<`eo`2N
@?l0^cWo0;hho`020<ldo`0D0:<oo`2X?Ol0VD7o0=hao`2`>ol0c3Go0>L_o`2V?_l0PDSo0:/mo`3B
=?l0ND[o0=hao`2h>_l0i33o0>d^o`2n>?l0iboo0?lWlP2N@?l20;Hjo`80WT3o00H0OTSo0>4`o`2F
@_l0IJ7o0>X_o`2?A?l20;Pjo`080:hlo`1/C_l0iboo0<`eo`2C@ol0^cWo0:Dno`3o:OQ:0?ooo`00
KP3oool0602Q?ol0oooo0?ooo`3?=?l0/c_o06Vao`3oool0TD?o0;Pjo`3oool0Xcoo0:Pmo`2k>Ol0
c3Go08Y5o`2K@Ol0a3Oo08M6o`36=_l0dSCo06i=o`3<=Ol0]S[o0=Dco`80NTWo02@0/c_o0<4ho`39
=_l0`CSo0;Hjo`2U?_l0dSCo0<ldo`3H<_l0Z3go08E6o`3oool0c3Go08e4o`2X?Ol0F5Co0?0]o`3o
ool0^3[o0?0]o`2f>_l0Fg?o0=Dco`2f>_l0oooo0<`eo`3Z;ol0oooo0=hao`2c>ol0oooo0:0oo`3<
=Ol0WT3o0;/io`2n>?l20<ldo`0D0:<oo`2X?Ol0VD7o0=hao`2`>ol0c3Go0>L_o`2V?_l0PDSo0:/m
o`3B=?l0ND[o0=hao`2h>_l0iboo0>d^o`2n>?l0iboo0?lWlP2N@?l20;Hjo`80WT3o0180OTSo0=ha
o`2F@_l0IJ7o0>X_o`27A_l0_SSo0;Pjo`2F@_l0K4ko0>L_o`3<=Ol0Td?o0=Pbo`2k>Ol0obWh0?oo
o`3<=Om80?ooo`00J`3oool05`2N@?l0oooo0?ooo`2Q?ol0JTko0?ooo`3?=?l0/c_o06Vao`3oool0
TD?o0;Pjo`3oool0Z3go071<o`2k>Ol0c3Go08Y5o`2K@Ol0a3Oo08M6o`36=_l0dSCo0080KTgo02P0
]S[o0=Dco`1jBOl0NTWo0;<ko`31>?l0bCKo0<4ho`1/C_l0YCko0=8do`3?=?l0f3;o0:Pmo`25A_l0
Z3go0>X_o`2=A?l0Z3go05QDo`3`;Ol0oooo0;Pjo`3`;Ol0]S[o0:hlo`3E<ol0]S[o0?ooo`3<=Ol0
jRoo0?ooo`3N<Ol0/c_o0?ooo`2S?ol0c3Go09i0o`2C@ol0_SSo0P3?=?l20:Pmo`0?09U1o`3N<Ol0
/3_o0;0ko`3W;ol0oa5f0:Dno`2[?Ol0[Cco07U:o`3N<Ol0^3[o0>L_o`3];_l0_SSo0080iboo0180
WT3o0;Hjo`2f>_l0Zcgo09i0o`1nB?l0gS7o09i0o`1UXOl0jRoo08M6o`3oool0^3[o09I2o`1/C_l0
iboo0<`eo`2C@ol20;/io`030?lYn03oool0c3Go04P0oooo001X0?ooo`0J073<o`3oool0oooo09i0
o`3oool0i33o0:4oo`1ZC_l0oooo0<ldo`2c>ol0JK7o08=7o`2A@ol0^3[o0?ooo`2X?Ol0L4co0;/i
o`3<=Ol0RTGo09]1o`34=ol0QdKo0<Hfo`3B=?l206i=o`0X0;Hjo`3E<ol0/c_o07E;o`2c>ol0Xcoo
0<Tfo`31>?l0K4ko0:Dno`3B=?l0ccCo0=Pbo`1nB?l0QDKo09I2o`3Z;ol0QDKo0:Pmo`1HE?l0l2go
0?ooo`2h>_l0f3;o0;Hjo`2^??l0eC?o09i0o`3oool0c3Go0>X_o`3oool0gS7o0;<ko`3oool0Xcoo
0<`eo`2N@?l0Td?o0;hho`80ccCo0`2X?Ol02`3N<Ol0kBko0?0]o`3W;ol0oa5f0:Dno`2[?Ol0[Cco
07U:o`3N<Ol0^3[o0080iboo00@0_SSo0>L_o`3W;ol0IToo0P2f>_l03`2[?Ol0FU?o07i8o`3N<Ol0
WT3o06FQo`3Z;ol0QdKo0;hho`2h>_l0UT;o06a>o`2f>_l0c3Go09=3o`020;/io`040:Dno`3o:OP0
c3Go0;<kodL0oooo001V0?ooo`0B07Y9o`3oool0L<co0?ooo`25A_l0WT3o0?ooo`3T<?l0XCoo06Y>
o`3oool0ccCo0;<ko`1Y/Ol0PdOo0953o`2h>_l0oooo0P2X?Ol0@P2k>Ol0c3Go08Y5o`2K@Ol0a3Oo
08M6o`36=_l0dSCo06i=o`3<=Ol0]S[o0=Dco`2c>ol0MD_o0;<ko`20B?l0bCKo0<4ho`1/C_l0YCko
0;<ko`3?=?l0f3;o07i8o`3oool0UT;o0>X_o`25A_l0Z3go0?lVj`36=_l0NTWo0;Pjo`3H<_l0oooo
0:hlo`3E<ol0WT3o0:Hno`3<=Ol0jRoo0?ooo`2K@Ol0/c_o0?ooo`2S?ol0c3Go09i0o`2C@ol0UT;o
0:<oo`3?=?l0Z3go0;<ko`3?=?l0gS7o0>d^o`3`;Ol0iboo0?lAMP2U?_l0PDSo0:dlo`2U?_l0ND[o
0;Pjo`80iboo00@0WT3o09I2o`3W;ol0IToo0P2f>_l0202[?Ol0FU?o07i8o`3N<Ol0WT3o06FQo`3Z
;ol0QdKo0P2n>?l01@2F@_l0K4ko0;Hjo`3<=Ol0Td?o0080^cWo00@0YCko0?lYn03<=Ol0/c_oA`3o
ool006<0oooo00h0YSko0?ooo`3oool0NTWo0818o`1`c?l0oooo08E6o`2N@?l0oooo0>@`o`2Q?ol0
JTko0<ldo`80/c_o00D0JK7o08=7o`2A@ol0^3[o0:<oo`020:Pmo`120;/io`3<=Ol0RTGo09]1o`34
=ol0QDKo0<Hfo`3B=?l0KTgo0<`eo`1iB_l0eC?o0;<ko`1eBol0/c_o0:<oo`39=_l0Vd7o06a>o`2U
?_l0/c_o0<ldo`3H<_l0OTSo0?ooo`2F@_l0jRoo08E6o`2X?Ol0obK[0<Hfo`1jBOl0eC?o0=Pbo`3o
ool0[Sco0=Dco`2N@?l0YSko0:/mo`3Z;ol0oooo09]1o`1VCol0oooo0:<oo`2n>?l0WT3o09=3o`2F
@_l0Xcoo0<ldo`2X?Ol0/c_o0<ldo`3N<Ol0kBko0?0]o`3W;ol0oa5f0:Dno`21B?l0[Cco0:Dno`1i
B_l0N4[o0P3W;ol03P2N@?l0UT;o0>L_o`1VCol0XCoo07U:o`2[?Ol0FU?o07i8o`3N<Ol0WT3o06FQ
o`1VCol0QdKo0P2n>?l0302I@Ol0K4ko0;Hjo`2f>_l0Td?o0=Pbo`2k>Ol0YCko0?lYn03<=Ol0/c_o
0=haodH0oooo001N0?ooo`0307E;o`3oool0GX;o0080oooo00h0YSko0?ooo`1nB?l0NTWo0818o`1`
c?l0oooo08E6o`2N@?l0GGco0>@`o`2Q?ol0JTko0<ldo`80/c_o01D0JK7o0953o`3c;Ol0^3[o0:<o
o`2X?Ol0L4co0;/io`3<=Ol0RTGo09]1o`34=ol0QdKo0<Hfo`3B=?l0KTgo0<`eo`1iB_l0eC?o0;<k
o`1eBol00P2S?ol07`39=_l0Vd7o06a>o`2U?_l0/c_o05EGo`3H<_l0OTSo0?ooo`2F@_l0jRoo08E6
o`2X?Ol0obK[0<Hfo`1jBOl0eC?o0=Pbo`3oool0[Sco09A3o`2N@?l0hC3o0:/mo`3Z;ol0oooo09]1
o`1VCol0oooo0:<oo`2n>?l00P2N@?l06`2F@_l0Xcoo0:<oo`2X?Ol0/c_o0<ldo`3N<Ol0kBko0?0]
o`3<=Ol0oa5f0:Dno`21B?l0/c_o0>4`o`1iB_l0N4[o0>@`o`3W;ol0WT3o09I2o`1cC?l0IToo0:4o
o`2f>_l0Zcgo05YCo`0207i8o`0409i0o`1UXOl0IToo075<o`80_SSo00<0VD7o06A@o`20B?l00P2f
>_l01`3oool0^cWo0:Dno`3o:OP0c3Go0;<ko`3N<Ol0AP3oool005/0oooo00h0^cWo0?ooo`3oool0
MD_o0?ooo`1NP_l0oooo05MPo`2V?_l0oooo07i8o`1jBOl0P4So073<o`80QDKo00H0WT3o05elo`2Q
?ol0XCoo06Y>o`3?=?l20;<ko`0;06Vao`2A@ol0TD?o0;Pjo`2S?ol0Z3go071<o`2k>Ol0c3Go08Y5
o`2K@Ol00P27A_l02036=_l0WT3o09=3o`3<=Ol0ND[o0=Dco`2c>ol0MD_o0P2S?ol02039=_l0Vd7o
06a>o`2N@?l0/c_o05EGo`3H<_l0`cOo0P2F@_l05@1`C?l0QDKo0:Pmo`3o9^/0aSKo07Y9o`3E<ol0
Z3go0?ooo`2^??l0U4?o0?ooo`3Q<?l0Zcgo0;hho`3oool0Vd7o06I?o`3oool0ob[o0;hho`0209i0
o`80UT;o00`0Xcoo09A3o`2c>ol0ccCo09U1o`3];_l0l2go0<`eo`3o4GH0UT;o0858o`2c>ol20:Dn
o`0507Q:o`3T<?l0iboo09i0o`2F@_l00P1cC?l0102Q?ol0]S[o0;Hjo`3B=?l207i8o`0908m4o`1W
ZOl0IToo075<o`1nB?l0_SSo09U1o`1TD?l0P4So0080]S[o00T0f3;o0;/io`2U?_l0obWh0?ooo`3<
=Ol0gS7o0?ooo`39=_l0A03oool005P0oooo00@0WT3o0?ooo`3oool0^cWo0P3oool02`1eBol0`CSo
05j2o`3oool0Ef3o0:Hno`3oool0OTSo07Y9o`20B?l0L<co0080QDKo00H0WT3o05elo`2Q?ol0XCoo
06Y>o`3?=?l20;<ko`0;06Vao`2A@ol0TD?o0;Pjo`2S?ol0Z3go071<o`2k>Ol0c3Go08Y5o`2K@Ol0
0P27A_l02`36=_l0WT3o09=3o`3<=Ol0ND[o08M6o`2c>ol0QdKo0:<oo`20B?l0bCKo0080Vd7o00D0
WT3o0;<ko`1EEol0f3;o0<<go`0209I2o`0E071<o`3oool0Z3go0?lVj`3o9o80NTWo0=Dco`2X?Ol0
oooo05]co`2D@ol0oooo0>4`o`2[?Ol0_SSo0?ooo`3o6j`0IToo0?ooo`3o:_l0_SSo0080WT3o00L0
P4So0=Pbo`2S?ol0U4?o0;<ko`3?=?l0VD7o0080kBko00D0c3Go0?lAMP2U?_l0YCko0;<ko`020:Dn
o`0F07Q:o`3T<?l0i33o09i0o`2F@_l0[Sco07=<o`2Q?ol0ND[o0;Hjo`3B=?l0nR_o07i8o`2?A?l0
IjWo06I?o`1aC?l0OTSo0;hho`2I@Ol0I53o0818o`80]S[o0P3H<_l0202U?_l0obWh0<`eo`3<=Ol0
gS7o0?ooo`39=_l0kBko@`3oool005H0oooo00<0UT;o0?ooo`2N@?l00P3oool03P2k>Ol0oooo0<`e
o`1eBol0`CSo05j2o`3oool0Ef3o0:Hno`1ce_l0NTWo07M:o`20B?l0L<co0P25A_l01P2N@?l0GGco
0:4oo`2Q?ol0JTko0<ldo`80/c_o0140PdOo0953o`2A@ol0^3[o0:<oo`2?A?l0L4co0;/io`2[?Ol0
RTGo09]1o`27A_l0QDKo05QDo`2N@?l0Td?o0<`eo`0209]1o`0`0;<ko`27A_l0Xcoo0818o`33=ol0
Vd7o06a>o`2N@?l0i33o05EGo`3H<_l0`cOo06k5o`2X?Ol0L4co0?ooo`2X?Ol0obK[0?lWlP1jBOl0
eC?o0:Pmo`3oool0Fg?o09A3o`3oool0hC3o0;Tio`2n>?l0ccCo0?lK[03c;Ol0oooo0?lZo`2N@?l0
UT;o09i0o`20B?l0UT;o0:<oo`2D@ol0a3Oo0?lSfP2I@Ol0`CSo06i=o`3<=Ol0oa5f0P2U?_l0102c
>ol0YCko0:Dno`2Q?ol20>@`o`0I06FNo`2F@_l0[Sco07=<o`3>=Ol0ND[o0;Hjo`3B=?l0nR_o07i8
o`2?A?l0IjWo06I?o`1aC?l0OTSo08e4o`2I@Ol0I53o0818o`3Z;ol0]S[o0=Pbo`2[?Ol0YCko0?lY
n0020<`eo`040;<ko`3oool0bCKo0>d^od<0oooo001C0?ooo`0F09U1o`3oool0oooo09I2o`3oool0
WT3o0?ooo`2c>ol0^cWo0?ooo`3<=Ol0MD_o0<4ho`1NP_l0bCKo05MPo`2V?_l0LmKo07Y9o`1gB_l0
P4So073<o`80QDKo00H0WT3o0>@`o`2Q?ol0XCoo06Y>o`3?=?l20;<ko`0A08=7o`2A@ol0TD?o0:/m
o`2S?ol0SdCo071<o`2k>Ol0Zcgo08Y5o`2K@Ol0QdKo08E6o`1HE?l0WT3o09=3o`3<=Ol00P2K@Ol0
9P2c>ol0QdKo0:<oo`20B?l0`cOo0>4`o`1/C_l0WT3o0>@`o`1EEol0f3;o0<<go`1^aOl0Z3go071<
o`3oool0Z3go0?lVj`3o9o80NTWo08M6o`2X?Ol0oooo05]co`2N@?l0oooo0>4`o`2i>Ol0_SSo0<ld
o`3o6j`0lbgo0?ooo`3o:_l0WT3o09I2o`2N@?l0P4So0P2F@_l03P2D@ol0a3Oo0?lSfP2I@Ol0`CSo
06i=o`3`;Ol0lBgo09I2o`2U?_l0/c_o0>4`o`2U?_l0XCoo0P3T<?l0301UW_l0m2go0;/io`1cC?l0
cSGo07U:o`2f>_l0dSCo0?X[o`2S?ol0SdCo06NYo`80IToo00L0OTSo08e4o`2=A?l0I53o0818o`3Z
;ol0]S[o0080f3;o00T0Zcgo0?lYn03o:OP0c3Go0;<ko`3oool0bCKo0>d^o`2S?ol0@P3oool00540
oooo00<0/c_o0?ooo`2I@Ol00P3oool0302F@_l0a3Oo09i0o`3oool0/c_o0;/io`3oool0c3Go07E;
o`31>?l0GX;o0<Tfo`80YSko00D0LmKo07Y9o`1gB_l0P4So073<o`0208E6o`0609i0o`3T<?l0XCoo
0:4oo`1ZC_l0ccCo0P2c>ol0B@23Aol0TD?o0?<]o`2[?Ol0Xcoo08m4o`1`C?l0QDKo0:/mo`2:AOl0
Vd7o07M:o`25A_l0F5Co0?lYn02C@ol0c3Go09]1o`27A_l0/c_o08M6o`1nB?l0P4So0<<go`3Q<?l0
K4ko0953o`3T<?l0EEOo0;Hjo`33=ol0^cWo0:Pmo`34=ol0oooo0:Pmo`3o9^/0obOb07Y9o`27A_l0
IToo0?ooo`1KLol0WT3o0?ooo`3Q<?l0^CWo0:/mo`3?=?l0oa^/0?<]o`3oool0ob[o09i0o`2F@_l0
WT3o0818o`3H<_l0UT;o0:hlo`34=ol0ob?J0<ldo`31>?l0KTgo0?0]o`3a;Ol0UT;o0:Dno`2Q?ol0
_SSo0:Dno`2Q?ol00P3T<?l0302F@_l0m2go0:hlo`1cC?l0cSGo07U:o`2f>_l0dSCo0?X[o`2S?ol0
SdCo06NYo`80IToo00X0OTSo08e4o`2=A?l0[Sco0818o`3Z;ol0Zcgo06:@o`3H<_l0Zcgo0P3o:OP0
1P3<=Ol0/c_o0=hao`39=_l0kBko0:<ood80oooo001>0?ooo`0D0;<ko`3oool0oooo0;<ko`3oool0
VD7o0?ooo`25A_l0UT;o0<@go`2N@?l0oooo0;<ko`2k>Ol0QdKo07E;o`2A@ol0`CSo05j2o`39=_l2
0:Hno`0507i8o`1jBOl0Md[o0818o`2:AOl00P25A_l01P2N@?l0i33o0:4oo`2Q?ol0JTko0<ldo`80
/c_o04H0PdOo0953o`3c;Ol0Zcgo0;<ko`2?A?l0L4co08E6o`2[?Ol0RTGo09]1o`1gB_l0QDKo05QD
o`1RDOl0Td?o0<`eo`2K@Ol0QdKo06i=o`27A_l0OTSo0818o`33=ol0hC3o06a>o`2A@ol0i33o05EG
o`2f>_l0`cOo0;/io`2X?Ol0a3Oo0?ooo`2X?Ol0NTWo0?lWlP1jBOl0QdKo06I?o`3m:ol0QdKo09i0
o`3oool0hC3o0;Tio`2[?Ol0ccCo0?lK[03c;Ol0oooo0?lZo`2N@?l0UT;o09i0o`3j:ol0f3;o09I2
o`2^??l0a3Oo0>4`o`3?=?l0`CSo0>4`o`3`;Ol0ccCo09I2o`2U?_l0XCoo0P3Q<?l01@2Q?ol0oB_o
09I2o`2F@_l0m2go0080[Sco00P0cSGo07U:o`2f>_l0dSCo0?X[o`2S?ol0gS7o0<ldo`80IToo00X0
OTSo0818o`2=A?l0[Sco0818o`3Z;ol0Zcgo06:@o`3H<_l0Zcgo0P3o:OP01`3<=Ol0/c_o0=hao`39
=_l0kBko0:<oo`3K<_l0@@3oool004/0oooo00@0Z3go0?ooo`3oool0/c_o0P3oool20;<ko`0>09U1
o`3oool0QDKo09I2o`34=ol0WT3o0<@go`2k>Ol0oooo08M6o`1eBol0TD?o0<4ho`1NP_l205MPo`0>
0:Hno`1nB?l0NTWo07M:o`20B?l0QDKo0?ooo`25A_l0WT3o0>@`o`20B?l0XCoo06Y>o`2A@ol20;<k
o`0608=7o`1JDol0lbgo0:/mo`2c>ol0SdCo0P25A_l01@2[?Ol0HU7o09]1o`2K@Ol0QDKo0080HU7o
00l0Td?o07a9o`2K@Ol0QdKo06i=o`2?A?l0OTSo0818o`3H<_l0hC3o06a>o`2A@ol0i33o05EGo`2f
>_l00P2k>Ol08`2X?Ol0a3Oo05n5o`2U?_l0NTWo0?ooo`1jBOl0QdKo06I?o`3m:ol0QdKo09i0o`3o
ool0YSko0;Tio`2[?Ol0ccCo0?lK[03c;Ol0^CWo0:Dno`2N@?l0UT;o09i0o`3j:ol0ccCo09I2o`2^
??l0a3Oo0>4`o`3?=?l0Ge7o0>4`o`3`;Ol0ccCo0080UT;o00D0XCoo0>4`o`3Q<?l0XCoo0?d[o`02
09I2o`0P0?@]o`2^??l0[Sco0<heo`1iB_l0]S[o0=8do`3j:ol0Xcoo0=hao`3?=?l0f3;o06I?o`1/
C_l0P4So08e4o`2^??l0Xcoo0>X_o`2[?Ol0HY3o0?lN_P2[?Ol0a3Oo0:/mo`3<=Ol0/c_o0=hao`2h
>_l0bCKo0:<oo`3K<_m10?ooo`00B@3oool00`2F@_l0oooo0:Pmo`020?ooo`030;<ko`3oool0S4Co
0080/c_o00L0VD7o0?ooo`25A_l0UT;o0<@go`2N@?l0a3Oo0080^cWo00H0QdKo07E;o`2A@ol0`CSo
05j2o`1GH?l20:Hno`0407i8o`1jBOl0Md[o0818o`<0QDKo00l0GGco0>@`o`20B?l0XCoo05EGo`2A
@ol0/c_o0:<oo`23Aol0FU?o0?<]o`2[?Ol0/c_o08m4o`25A_l00P2[?Ol0101RDOl0Vd7o07M:o`25
A_l2069Ao`0:09=3o`1lBOl0VD7o08M6o`1^COl0_SSo07i8o`20B?l0f3;o0>4`o`80TD?o00P0Fg;o
05EGo`2f>_l0^cWo06k5o`2[?Ol0a3Oo0<<go`80YCko01L0oooo07Y9o`1GH?l0IToo06i=o`27A_l0
WT3o0?ooo`2V?_l0K4ko0?ooo`3?=?l0oa^/0?<]o`2i>Ol0YCko08E6o`3oool0WT3o0?X[o`3?=?l0
f3;o0:hlo`020>4`o`050<ldo`1ODOl0hC3o0?0]o`3?=?l00P2F@_l01@2Q?ol0hC3o0>4`o`3Q<?l0
oB_o0080UT;o01`0m2go0:hlo`2^??l0^cWo07U:o`2f>_l0jRoo0?X[o`2S?ol0gS7o0<ldo`3H<_l0
IToo06a>o`20B?l0ccCo0:hlo`2S?ol0oooo0:/mo`1RT?l0eC?o0:/mo`34=ol0Zcgo08m4o`2c>ol0
gS7o0P39=_l0102S?ol0fc;o0?ooo`3o9o8o0?ooo`00AP3oool02`2c>ol0oooo0?ooo`2F@_l0oooo
0:Pmo`3oool0iboo0;<ko`3oool0S4Co0080/c_o00L0VD7o07M:o`2F@_l0oooo0<@go`2N@?l0a3Oo
0080^cWo00`0c3Go07E;o`2A@ol0`CSo05j2o`1GH?l0YSko07?Fo`1nB?l0NTWo07M:o`20B?l308E6
o`0?05elo`3T<?l0P4So0:4oo`1EEol0TD?o0;<ko`33=ol0SdCo05YCo`3c;Ol0ND[o0;<ko`2?A?l0
QDKo0080Zcgo0100HU7o07U:o`1gB_l0QDKo069Ao`3o:OP0/c_o07a9o`2I@Ol0QdKo06i=o`2n>?l0
OTSo0:Hno`3H<_l0hC3o0P2A@ol01P2f>_l0EEOo066=o`2k>Ol0K/Go0:/mo`80a3Oo0P2U?_l05`3o
ool0NTWo05MPo`3oool0KTgo08M6o`1EEol0oooo0:Hno`1/C_l0oooo0<ldo`1HI_l0lbgo0;Tio`2U
?_l0QDKo0?ooo`2F@_l0nR_o0<ldo`3H<_l0[Sco0080hC3o00D0ccCo05mAo`3Q<?l0KTgo0<ldo`02
09I2o`0L08e4o`3Q<?l0hC3o0>4`o`3m:ol0YSko09I2o`3d;Ol0^cWo0:hlo`2k>Ol0/3_o0;Hjo`3Z
;ol0nR_o09A3o`3N<Ol0ccCo0=Pbo`2n>?l0K4ko0818o`1cC?l0[Sco0:<oo`3Z;ol0Zcgo06:@o`80
oajn00D0a3Oo0:/mo`2?A?l0/c_o0=hao`020<Tfo`040>d^o`3K<_l0oooo0?lWlSl0oooo00140?oo
o`0309i0o`3oool0/c_o0080oooo0140UT;o0?ooo`2X?Ol0oooo0>L_o`2c>ol0oooo08a4o`2c>ol0
VD7o0?ooo`1gB_l0UT;o0?ooo`34=ol0WT3o0;<ko`020;/io`0<0<`eo`1eBol0TD?o0<4ho`1NP_l0
Ef3o0:Hno`1ce_l0OTSo07_bo`1gB_l0P4So0`25A_l08P1MO?l0i33o0818o`2Q?ol0EEOo0953o`2c
>ol0`cOo08m4o`1JDol0lbgo07U:o`2c>ol0GGco08E6o`1cC?l0Vd7o069Ao`1iB_l0Md[o0:Dno`1R
DOl0obWh0;<ko`1lBOl0VD7o08M6o`2?A?l0_SSo07i8o`2V?_l0f3;o0>4`o`2A@ol20;Hjo`0705EG
o`1QSOl0^cWo06k5o`2[?Ol0a3Oo0<<go`020:Dno`0=07U:o`2h>_l0Ef3o0?ooo`1^COl0QdKo05EG
o`3?=?l0YSko06a>o`3oool0Zcgo0857o`020;Tio`080:Dno`25A_l0oooo09I2o`3j:ol0ccCo0=Pb
o`2^??l20>4`o`080?lSfP1jBOl0hC3o06i=o`3?=?l0[Sco09I2o`2=A?l30>4`o`090?d[o`2c>ol0
UT;o05YCo`2k>Ol0[Sco0;/io`2`>ol0YCko0080jRoo00/0Xcoo0=hao`3?=?l0f3;o0?X[o`1/C_l0
P4So0<ldo`2^??l0Xcoo0>X_o`020;Hjo`040?lN_P3a;Ol0a3Oo0:/mo`80SdCo00P0gS7o0<Tfo`39
=_l0kBko0:<oo`3oool0obOb0<`eoch0oooo00110?ooo`0A0?0]o`3oool0oooo09i0o`3oool0/c_o
0?ooo`1PR_l0UT;o0?ooo`2X?Ol0oooo0>L_o`2c>ol0^cWo0;<ko`20B?l00P2I@Ol0=P1gB_l0UT;o
0=<co`34=ol0WT3o0;<ko`2k>Ol0/c_o0<`eo`1eBol0TD?o0<4ho`39=_l0Ef3o0>L_o`1ce_l0OTSo
07_bo`1gB_l0RTGo08E6o`1MO?l0HiKo06FQo`1cC?l0P4So0:4oo`1EEol0TD?o0;<ko`33=ol0SdCo
05YCo`3c;Ol0ND[o0;<ko`1MO?l0QDKo07=<o`2K@Ol0Xcko07U:o`1gB_l0YCko07=<o`3o:OP0/c_o
0;Hjo`2I@Ol0QdKo08m4o`2n>?l0OTSo0:Hno`80f3;o00X0TD?o0;Hjo`2f>_l0eC?o066=o`2c>ol0
K/Go0:/mo`3oool0`cOo0P2U?_l03@1iB_l0^3[o0:Pmo`3oool0KTgo05IDo`1EEol0QdKo0:hlo`1/
C_l0oooo0:/mo`21Aol00P2i>Ol0201VCol0QDKo0?ooo`2F@_l0nR_o06A@o`3H<_l0[Sco0P3Q<?l0
203o8mX0NTWo0;<ko`1^COl0a3Oo0;hho`2F@_l0SDCo0`3Q<?l02@2^??l0YSko09I2o`1JDol0^cWo
0<Hfo`2k>Ol0/3_o0;Hjo`020>X_o`80Xcoo00D0ccCo0=Pbo`2n>?l0_SSo0818o`020<ldo`050:<o
o`3Z;ol0]S[o0;Hjo`3o7[h00P3a;Ol0102[?Ol0SdCo08m4o`3N<Ol20<Tfo`060>d^o`2S?ol0oooo
0?lWlP3<=Ol0QdKo?@3oool003l0oooo00<0PdOo0?ooo`3`;Ol00P3oool03P2N@?l0QdKo0;<ko`3o
ool0H8[o09I2o`3oool0Z3go0;/io`2c>ol0oooo0;/io`2c>ol0P4So0P2I@Ol0F`25A_l0UT;o0=<c
o`34=ol0WT3o0;<ko`2k>Ol0QdKo0<`eo`1eBol0TD?o0<4ho`39=_l0Ef3o0;Pjo`1ce_l0[Sco07_b
o`1gB_l0IIko08E6o`1MO?l0HiKo06FQo`1cC?l0P4So06>Fo`1EEol0TD?o0:<oo`33=ol0SdCo05YC
o`3c;Ol0ND[o0;<ko`1MO?l0VD7o07=<o`2K@Ol0K4ko07U:o`1gB_l0YCko07=<o`3o:OP0/c_o075<
o`2I@Ol0QdKo08m4o`2n>?l0SdCo0:Hno`2[?Ol0hC3o0953o`2f>_l0Fg;o0=Dco`3oool0/c_o06k5
o`2[?Ol0oooo0<<go`2N@?l0YCko0:Hno`2h>_l0Z3go0?ooo`1^COl0EUCo0?ooo`27A_l0[Sco07M:
o`3oool0Zcgo0857o`2N@?l0^CWo06I?o`2?A?l0oooo09I2o`31>?l0I53o0=Pbo`2^??l00P3Q<?l0
1@3o8mX0NTWo0;<ko`3Q<?l0a3Oo0080_SSo00D0SDCo0;hho`2N@?l0hC3o0:hlo`020:Hno`0605YC
o`2k>Ol0aSKo0;/io`2`>ol0]S[o0P3Z;ol20:<oo`050<ldo`3H<_l0_SSo0;hho`20B?l00P3?=?l0
101nB?l0jRoo0>X_o`2f>_l20?lN_P0=0?4]o`36=_l0aSKo08m4o`2D@ol0QdKo0<Tfo`3];_l0Xcoo
0=/bo`3o9o80c3Go08M6o`0m0?ooo`00?03oool0502F@_l0oooo0?ooo`23Aol0oooo0?0]o`3oool0
c3Go09i0o`27A_l0/c_o0?ooo`1PR_l0UT;o0:Pmo`34=ol0^cWo0;<ko`3oool0^cWo0P2c>ol209U1
o`0<08E6o`2F@_l0dc?o0<@go`2N@?l0/c_o0;/io`27A_l0c3Go07M:o`2A@ol0`CSo0P39=_l01@2h
>_l0/c_o0:hlo`1kl_l0Md[o0080RTGo00/0GGco06>Fo`1UXOl0Ldco0818o`1SU_l0EEOo05YCo`2S
?ol0`cOo08m4o`020<<go`1007U:o`2c>ol0GGco09U1o`1cC?l0Vd7o0:<no`1iB_l0Xcoo0:Dno`1c
C?l0obWh0;<ko`2f>_l0VD7o0;0ko`2?A?l0_SSo08m4o`2V?_l0[Sco0>4`o`2c>ol0]S[o05]bo`3E
<ol0Zcgo0;<ko`36=_l0Ge7o0?ooo`33=ol0WT3o0:Dno`2V?_l0^3[o0:Pmo`3oool0KTgo05IDo`3o
ool0QdKo0:hlo`1gB_l0oooo0:/mo`21Aol0WT3o0;Tio`1VCol0SdCo0?ooo`2F@_l0`CSo06A@o`3H
<_l0[Sco05EGo`2l>Ol0ob?J07Y9o`2c>ol0hC3o0<@go`80_SSo00D0SDCo0;hho`2N@?l0hC3o0:hl
o`020:Hno`0H08m4o`2k>Ol0aSKo06a>o`2`>ol0YCko0;Hjo`3Z;ol0U4?o0:<oo`3?=?l0f3;o0?X[
o`2n>?l0hC3o07=<o`3?=?l0OTSo06I?o`3Z;ol0]S[o0;hho`3o7[h0lBgo0P36=_l02`2?A?l0U4?o
08M6o`39=_l0kBko0:<oo`3K<_l0obOb0<`eo`27A_l0^cWo03`0oooo000j0?ooo`0308M6o`3oool0
UT;o0080oooo00/0PdOo0=Dco`3`;Ol0oooo0<`eo`2N@?l0QdKo0;<ko`1lBOl0UT;o0?ooo`020:Pm
o`040;/io`2c>ol0Zcgo08a4o`80/c_o01/0VD7o0:/mo`25A_l0UT;o0:hlo`34=ol0WT3o0;<ko`2`
>ol0QdKo0<`eo`1gB_l0TD?o0<4ho`39=_l0aSKo0;Pjo`2c>ol0[Sco0:/mo`3K<_l0RTGo07W/o`1M
O?l0HU3o06FQo`1cC?l00P1SU_l01@1EEol0FU?o0:<oo`33=ol0SdCo0080`cOo00D0ND[o05YCo`2N
@?l0VD7o07=<o`020:<no`0507U:o`2S?ol0YCko07=<o`3o:OP00P2f>_l01@2I@Ol0/3_o08m4o`2n
>?l0SdCo0080[Sco02/0hC3o0;<ko`2f>_l0Fg;o0=Dco`2[?Ol0/c_o0<Hfo`1ODOl0Fg?o0<<go`2N
@?l0oooo0:Hno`2h>_l0Z3go07U:o`3m:ol0EUCo0?ooo`27A_l0[Sco07M:o`3oool0UT;o0857o`2N
@?l0PDSo0:/mo`2?A?l0oooo05elo`31>?l0I53o0<ldo`2^??l0EEOo0;`io`3o8mX0NTWo0;<ko`3Q
<?l0a3Oo0080_SSo00D0]S[o0;hho`2N@?l0_SSo0:hlo`020:Hno`0H08m4o`2k>Ol0aSKo06a>o`2`
>ol0YCko0;Hjo`36=_l0U4?o0:<oo`3?=?l0f3;o0?X[o`2n>?l0hC3o07=<o`3?=?l0OTSo06I?o`3Z
;ol0]S[o0;hho`3o7[h0lBgo0P36=_l02`3o9o80U4?o08M6o`2h>_l0kBko0:<oo`3K<_l0hC3o0?lW
lP27A_l0^cWo03`0oooo000g0?ooo`0C06Q?o`3oool0oooo08M6o`3oool0UT;o0?ooo`23Aol0oooo
0=Dco`3`;Ol0oooo0<`eo`2N@?l0/c_o0?ooo`1lBOl0UT;o0<`eo`020:Pmo`040>L_o`2c>ol0Zcgo
08a4o`80/c_o00D0VD7o07M:o`25A_l0UT;o0:hlo`020<@go`80/c_o01T0QdKo0<`eo`1gB_l0TD?o
05MPo`39=_l0iboo0;Pjo`2c>ol0[Sco0:/mo`1UW_l0RTGo07W/o`1MO?l0HU3o06FQo`1cC?l0HiKo
0;/io`2[?Ol0FU?o07Y9o`33=ol0SdCo0080`cOo00D0ND[o05YCo`2N@?l0VD7o07=<o`020:<no`05
05n5o`2S?ol0WT3o07=<o`3o:OP00P2f>_l01@2I@Ol0/3_o08Y5o`2n>?l0SdCo0080[Sco04`0hC3o
0;<ko`1gB_l0Fg;o0=Dco`2[?Ol0/c_o0<Hfo`1ODOl0hC3o05n5o`2N@?l0oooo0:Hno`2h>_l0Z3go
0=Pbo`3m:ol0UT;o0?ooo`27A_l0WT3o07M:o`3oool0UT;o0:hlo`2N@?l0PDSo0:/mo`2?A?l0oooo
05elo`31>?l0SdCo0<ldo`2C@ol0EEOo0;`io`3E<ol0F6?o0;<ko`3Q<?l0I53o0:hlo`2n>?l0]S[o
0;hho`34=ol0_SSo0:hlo`2c>ol0YSko08m4o`2k>Ol0/c_o06a>o`3o9nh0YCko0;Hjo`36=_l0U4?o
05aBo`3?=?l0bCKo0?ooo`2n>?l0hC3o07=<o`3?=?l0OTSo06I?o`1LDol0]S[o0;hho`3E<ol0lBgo
0P36=_l01`2f>_l0U4?o08M6o`2h>_l0kBko0:<oo`3K<_l00P3o9o800`27A_l0^cWo0<Hfo`0k0?oo
o`00=03oool0103];_l0oooo0?ooo`1XCol20?ooo`0@08M6o`2?A?l0UT;o0?ooo`23Aol0oooo0=Dc
o`3`;Ol0YCko09i0o`3oool0/c_o0?lVj01PR_l0UT;o0<`eo`80Z3go00d0iboo0;<ko`2[?Ol0S4Co
0;<ko`20B?l0VD7o07M:o`25A_l0X3oo0:hlo`34=ol0YSko0080/c_o00D0QdKo0>4`o`1gB_l0TD?o
05MPo`020<Tfo`040;Pjo`2c>ol0[Sco0=/bo`80IIko00D0NNco05elo`1RD?l0IJ7o07=<o`0206>F
o`0C0:/mo`1JDol0NTWo0<<go`2?A?l0`cOo06>Fo`1gB_l0FU?o09i0o`2I@Ol0aSKo0:<no`1/C_l0
GhGo0:<oo`2N@?l0Ldco0?lYn0020;Hjo`0507Y9o`2`>ol0RTGo0;hho`3?=?l00P2^??l0A03<=Ol0
/c_o07M:o`1KL_l0eC?o0:/mo`2c>ol0aSKo0=Pbo`3Q<?l0GhGo06I?o`3oool0YSko0:hlo`2X?Ol0
f3;o0?d[o`2F@_l0oooo08M6o`2N@?l0QdKo0?ooo`2F@_l0[Sco0?ooo`21B?l0Zcgo08m4o`3oool0
GGco0?d[o`2?A?l0ccCo09=3o`1ZC_l0_3Wo0=Dco`1HHol0S4Co0>4`o`1TD?l0[Sco0;hho`2f>_l0
ccCo09i0o`2n>?l0[Sco0;<ko`2V?_l0SdCo0>L_o`36=_l0K4ko0?lWkP2U?_l0]S[o0<Hfo`2D@ol0
G5;o0<ldo`39=_l0nR_o0;hho`3Q<?l0Ldco0P3T<?l01P1VCol0G5?o062:o`2n>?l0eC?o05aBo`80
aSKo0P2f>_l01@27A_l0^3[o0=hao`2S?ol0fc;o0080obOb00D0c3Go0;/io`36=_l0oooo0=hao`0i
0?ooo`00<P3oool00`1eBol0oooo0>d^o`020?ooo`0>06Q?o`3oool0QdKo0?ooo`2?A?l0UT;o07M:
o`23Aol0oooo0=Dco`3`;Ol0YCko09i0o`36=_l20;<ko`03062:o`2F@_l0c3Go0080Z3go00@0iboo
0;<ko`2k>Ol0S4Co0`2c>ol0101gB_l0QDKo0=<co`2^??l30<@go`0;0;<ko`27A_l0O4Wo07M:o`2[
?Ol0Ef3o0<Hfo`3W;ol0^3[o0;<ko`2^??l00P3K<_l01@1`C?l0NNco071<o`1RD?l0IJ7o0080oabc
0280^cWo0:/mo`2C@ol0NTWo0<<go`1UW_l0`cOo06>Fo`1gB_l0FU?o09i0o`2I@Ol0aSKo0:<no`1/
C_l0GhGo0:<oo`2N@?l0Ldco0?lYn02f>_l0LDco07Y9o`2`>ol0RTGo0;hho`3?=?l0[Sco0:/mo`3<
=Ol0/c_o07M:o`1KL_l0obKX0P2c>ol02036=_l0f3;o0>4`o`1OQOl0IToo0=Pbo`2V?_l0[Sco0P3H
<_l08@3m:ol0UT;o0?ooo`27A_l0WT3o08M6o`3oool0UT;o0:hlo`3oool0WT3o0:/mo`2f>_l0oooo
06I?o`3m:ol0SdCo0<ldo`2C@ol0JTko0:Dno`3E<ol0F6?o08a4o`3Q<?l0I53o0:hlo`3];_l0]S[o
0<ldo`2N@?l0_SSo0:hlo`020;<ko`0<08m4o`3W;ol0aSKo0<Hfo`3o9nh0YCko0;Hjo`36=_l0U4?o
05aBo`3?=?l0bCKo0P3j:ol02@3Q<?l0Ldco0>@`o`3T<?l0IToo05aCo`2F@_l0_SSo0=Dco`0205aB
o`050<Hfo`2f>_l0]S[o0<`eo`2h>_l00P3N<Ol0203K<_l0obOb0<`eo`3<=Ol0QdKo0<Hfo`3oool0
gS7o>@3oool002l0oooo01H0MD_o0?ooo`3oool0MD_o0?ooo`3];_l0oooo0953o`1XCol0oooo08M6
o`2[?Ol0SdCo09I2o`1gB_l0PdOo0?ooo`3`;Ol0EEOo0:Dno`2N@?l0QdKo0P2c>ol07P1PR_l0UT;o
0<`eo`2X?Ol0^cWo0>L_o`2c>ol0^cWo08a4o`3N<Ol0/c_o0:/mo`1gB_l0JTko0=<co`2^??l0YSko
0<@go`2`>ol0/c_o07?Ho`1lBOl0Md[o0?ooo`1EEol0aSKo0>L_o`2h>_l0/c_o0:hlo`80fc;o00D0
L4co0;0ko`1`C?l0HU3o0>d^o`020?lL/`0=0;/io`2[?Ol0Td?o07Y9o`33=ol0IIko0<<go`1SU_l0
Md[o05YCo`2N@?l0VD7o0<Hfo`020:<no`0M05n5o`3E<ol0WT3o07=<o`27A_l0]S[o075<o`1jBOl0
K4ko08Y5o`2n>?l0ccCo0:hlo`2[?Ol0c3Go09I2o`1gB_l0hC3o0?lVj02c>ol0WT3o0<Hfo`3H<_l0
hC3o0;/io`1VCol0f3;o07U:o`2^??l00P3H<_l07P3m:ol0UT;o0?ooo`3?=?l0WT3o08M6o`2V?_l0
UT;o0:hlo`3oool0WT3o0:/mo`2f>_l0oooo06I?o`3m:ol0SdCo06A@o`2C@ol0JTko0:Dno`3E<ol0
F6?o08a4o`2c>ol0YSko0:hlo`3];_l0]S[o0<ldo`80WT3o00D0[Sco0;<ko`2c>ol0l2go0>L_o`02
0<Hfo`080?lWkP2U?_l0]S[o0<Hfo`2D@ol0jRoo05aBo`39=_l20?X[o`0@0>4`o`1cC?l0i33o0>@`
o`1/^ol0G5?o09I2o`1PR_l0eC?o0?ooo`1LD_l0aSKo09=3o`2f>_l0c3Go0;Pjo`80gS7o00T0fc;o
0?lWlP3o9o80c3Go08M6o`36=_l0oooo0=hao`1MO_l0>03oool002d0oooo0340RTGo0?ooo`1eBol0
oooo0953o`1eBol0oooo0>d^o`3oool0TD?o06Q?o`2X?Ol0QdKo0:/mo`2F@_l0oooo07M:o`23Aol0
FU?o0?0]o`1EEol0c3Go09i0o`27A_l0/c_o0?lVj01PR_l0UT;o07M:o`2X?Ol0^cWo0>L_o`2[?Ol0
^cWo08a4o`3N<Ol0/c_o0:/mo`1gB_l0X3oo0=<co`2^??l0YSko0<@go`2`>ol0/c_o0>4`o`1lBOl0
Md[o0080EEOo00D0aSKo0>L_o`2`>ol0/c_o0:hlo`020=/bo`05071<o`2`>ol0L4co069@o`3o:OP0
0P3o7;<0;02k>Ol0Zcgo09=3o`1jBOl0`cOo06FNo`23Aol0HiKo07M:o`1JDol0WT3o09U1o`36=_l0
I53o06a>o`3E<ol0^cWo09i0o`2k>Ol0QdKo0818o`1aC?l0NTWo06a>o`2:AOl0_SSo0<ldo`3<=Ol0
Zcgo0<`eo`2F@_l0Md[o0>4`o`3o9^P0Zcgo09i0o`36=_l0f3;o0>4`o`2k>Ol0IToo0=Pbo`1iB_l0
[Sco0P3H<_l08@3m:ol0UT;o0?ooo`3?=?l0WT3o08M6o`2V?_l0PdOo0:hlo`3oool0WT3o0:/mo`2f
>_l0jRoo06I?o`3m:ol0SdCo06A@o`2I@Ol0JTko0<Hfo`2l>Ol0]S[o08a4o`2c>ol0YSko0:hlo`3]
;_l0EU[o0<ldo`34=ol0WT3o08m4o`020;<ko`0<0?0]o`3W;ol0/c_o0<Hfo`3o9nh0YCko0;Hjo`2n
>?l0U4?o0>X_o`1LD_l0jRoo0P3j:ol03`34=ol0]S[o0<Hfo`3T<?l0K;_o0:Dno`2F@_l0H8[o0=Dc
o`27A_l0G5;o0=/bo`2C@ol0]S[o0<`eo`020;Pjo`0:0=hao`3H<_l0oB_o0?lWlP3<=Ol0QdKo0;/i
o`3oool0gS7o05enocP0oooo000X0?ooo`0f05QDo`3oool0oooo06a>o`3oool0RTGo0?ooo`1eBol0
oooo0953o`1eBol0oooo0>d^o`3oool0J4oo0?ooo`2X?Ol0QdKo0:/mo`2F@_l0/c_o07M:o`23Aol0
eC?o0?0]o`1EEol0c3Go09i0o`27A_l0/c_o07a9o`1PR_l0UT;o07M:o`34=ol0^cWo0>L_o`2[?Ol0
^cWo0;hho`3N<Ol0P4So0:/mo`1gB_l0X3oo0=<co`2^??l0YSko09U1o`2`>ol0/c_o0>4`o`1lBOl0
Zcgo0P1EEol07@36=_l0iboo0;0ko`2c>ol0Zcgo0=/bo`2?A?l0L4co0;0ko`1`C?l0HU3o0?lYn03o
7;<0acKo0;/io`2[?Ol0Td?o07Y9o`1PDOl0SdCo08=7o`1SU_l0OTSo05YCo`2N@?l0L4co0<Hfo`1T
D?l0K4ko0080eC?o01H0WT3o0;/io`27A_l0QdKo075<o`2`>ol0K4ko08Y5o`3o7;L0ccCo0<`eo`2[
?Ol0c3Go09I2o`1gB_l0hC3o0?lVj02[?Ol0WT3o0<Hfo`3H<_l0hC3o0P2k>Ol00`3H<_l0ND[o06a=
o`020=Pbo`0C0?lGV@2F@_l0oooo0<ldo`2N@?l0QdKo0:<oo`23Aol0[Sco0?ooo`2N@?l0Td?o0;Hj
o`3Z;ol0IToo0?d[o`3Q<?l0I53o09U1o`020<Hfo`0<0;`io`2f>_l0a3Oo0;<ko`2V?_l0[Sco0>d^
o`1FF_l0ccCo05]co`2N@?l0SdCo0P2c>ol02P3`;Ol0iboo0>4`o`36=_l0ccCo0:Dno`2f>_l0_SSo
0=Dco`3Q<?l20>X_o`0N09i0o`3j:ol0a3Oo0;Hjo`36=_l0i33o06bko`2U?_l0UT;o0;hho`25A_l0
QdKo0?lK[`3K<_l0Td?o0?lWlP3<=Ol0[Sco066=o`3N<Ol0f3;o0?d[o`3o9o80c3Go08M6o`2k>Ol0
oooo0=hao`1MO_l0TD?o=`3oool002H0oooo00<0X3oo0?ooo`1HE?l00P3oool04P1/C_l0YCko08Y5
o`3oool0MD_o0?ooo`2A@ol0MD_o0:<oo`3];_l0oooo06Q?o`3oool0Z3go08M6o`2[?Ol0UT;o0;<k
o`80PdOo00X0eC?o0?0]o`1EEol0c3Go09i0o`27A_l0/c_o07a9o`1PR_l0QDKo0P34=ol04P2k>Ol0
iboo0:/mo`2k>Ol0_SSo0=hao`20B?l0Zcgo0<Tfo`2P?ol0dc?o0=/bo`2V?_l0VD7o0;0ko`2c>ol0
hC3o07a9o`80Zcgo01h0[Cco0<Hfo`3W;ol0/3_o0;<ko`2[?Ol0fc;o08m4o`1`C?l0/3_o071<o`3]
;_l0obWh0?lL/`37=_l0^cWo09A2o`2C@ol0NTWo061Ao`2?A?l0PdOo07i8o`1cC?l0FU?o09i0o`1`
C?l0aSKo06A@o`1/C_l20=Dco`0F09i0o`2k>Ol0jRoo0818o`1aC?l0/3_o06a>o`2:AOl0oabg0<ld
o`3<=Ol0Zcgo0>X_o`2F@_l0ccCo0>4`o`3o9^P0Zcgo09i0o`34=ol0f3;o0>4`o`80^cWo00<0f3;o
07U:o`1/COl00P3H<_l04`3o5iT0ccCo0=8do`3?=?l0WT3o0?ooo`2S?ol0PdOo05mAo`3oool0WT3o
09=3o`2f>_l0jRoo06I?o`2=A?l0hC3o08m4o`2I@Ol00P36=_l05`2l>Ol0]S[o08a4o`2c>ol0YSko
0?<]o`3j:ol0EU[o08m4o`34=ol0WT3o08m4o`3W;ol0WT3o0?0]o`3Q<?l0/c_o0<Hfo`3?=?l0_SSo
0;Hjo`2n>?l0eC?o00<0jRoo01h0WT3o0?X[o`34=ol0]S[o0<Hfo`3T<?l0QdKo0:Dno`2F@_l0_SSo
08E6o`27A_l0oa^_0=/bo`2C@ol0obOb0<`eo`2^??l0HHgo0=hao`3H<_l0oB_o0>4`o`3<=Ol0QdKo
0;/io`36=_l0gS7o05eno`2A@olg0?ooo`008`3oool04@2K@Ol0oooo0?ooo`2P?ol0oooo05QDo`3o
ool0QDKo06a>o`2U?_l0RTGo0?ooo`1eBol0oooo0953o`1eBol0kBko0080oooo0100J4oo05]Co`2X
?Ol0QdKo08m4o`2F@_l0/c_o08=7o`2<A?l0F6Co0?0]o`2U?_l0c3Go0;0ko`27A_l0HU7o0P1lBOl0
103<=Ol0a3Oo0<@go`2k>Ol20:/mo`0?0;/io`3];_l0gS7o0=/bo`2[?Ol0JTko0:0oo`3C<ol0fc;o
09A3o`2I@Ol0/3_o07?Ho`3Q<?l0O4Wo0080Zcgo01H0[Cco0<Hfo`20B?l0/3_o0;<ko`2[?Ol0fc;o
08m4o`1`C?l0/3_o071<o`3];_l0obWh0?lL/`37=_l0^cWo09A2o`2C@ol0c3Go061Ao`2?A?l0PdOo
0P1nB?l01P1JDol0f3;o071<o`1MO?l0I53o0?lYn080eC?o01H0UT;o0;/io`3Z;ol0P4So0:Dno`2`
>ol0K4ko0?lWkP3o7;L0YSko0<`eo`2[?Ol0jRoo09I2o`3?=?l0hC3o0:Dno`2[?Ol0WT3o0<@go`3H
<_l0Fg?o0P2k>Ol04@3H<_l0obWh06a=o`3oool0ND[o0?lGV@3?=?l0dSCo0<ldo`2N@?l0oooo0:<o
o`23Aol0Ge7o0?ooo`36=_l0Td?o0080jRoo00D0Xcoo08e4o`3Q<?l0SdCo09U1o`020<Hfo`090;`i
o`2f>_l0S4Co08a4o`2V?_l0lbgo0?X[o`3];_l0SdCo0080a3Oo00D0SdCo0>L_o`2N@?l0l2go0>4`
o`020;<ko`0=0<ldo`2n>?l0]S[o0;hho`3E<ol0jRoo0<ldo`3Z;ol0WT3o0:hlo`34=ol0]S[o0<Hf
o`0208M6o`0H0:Dno`2F@_l0[Sco08E6o`27A_l0oooo0=/bo`2C@ol0obOb0<`eo`2^??l0HHgo0>4`
o`3H<_l0oB_o0>4`o`3<=Ol0QdKo0;/io`36=_l0gS7o05eno`2A@ol0`CSo=P3oool00240oooo00<0
PDSo0?ooo`2K@Ol00P3oool03@2P?ol0UT;o05QDo`3oool0K4ko0?ooo`2U?_l0RTGo08=7o`1eBol0
oooo07E;o`3oool00P3];_l00`2S?ol0J4oo05]Co`0208M6o`0:08m4o`2F@_l0Md[o08=7o`2<A?l0
eC?o0?0]o`2U?_l0c3Go0<Hfo`80QdKo00H0O4Wo05ioo`3<=Ol0Md[o07=<o`2k>Ol20:/mo`0_0;/i
o`3];_l0gS7o0=/bo`2[?Ol0JTko0:0oo`36=_l0fc;o09A3o`2I@Ol0/3_o07?Ho`3Q<?l0WT3o0:/m
o`2U?_l0[Cco0<Hfo`20B?l0/3_o0:<oo`2[?Ol0c3Go08m4o`3?=?l0/3_o071<o`3];_l0obWh0?lL
/`37=_l0^cWo09A2o`2C@ol0c3Go0:hlo`2?A?l0PdOo09Koa`1nB?l0FU?o0=Pbo`2N@?l0GGco06A@
o`3o:OP00P3E<ol05P2F@_l0^cWo0>X_o`20B?l0YCko0;0ko`1/C_l0obO^0?lL]`2n>?l0c3Go0;/i
o`3Z;ol0UT;o0<ldo`3Q<?l0YCko0:/mo`3c;Ol0a3Oo0=Pbo`1KLol20;/io`0H0=Pbo`3o:OP0K4go
0?ooo`1iB_l0oaNI0<ldo`2N@?l0Ldco09i0o`3oool0Xcoo0:hlo`1ODOl0oooo0<Hfo`2C@ol0obWh
0>X_o`2S?ol0SDCo0>4`o`2?A?l0VD7o0P36=_l02@2U?_l0]S[o0<@go`2<A?l0YSko0?<]o`3j:ol0
kBko08m4o`020<@go`050<ldo`3W;ol0WT3o0?0]o`3Q<?l00P2c>ol02@3?=?l0_SSo0;Hjo`2f>_l0
eC?o0>X_o`3?=?l0jRoo09i0o`020:hlo`0D0;Hjo`36=_l0QdKo08M6o`2U?_l0UT;o0;hho`25A_l0
QdKo0?lK[`3K<_l0Td?o0?lWlP3o7/40[Sco066=o`3Q<?l0f3;o0?d[o`3Q<?l20>X_o`070;/io`36
=_l0X?ng0=hao`1MO_l0`CSo0:/mo`0e0?ooo`007P3oool0402[?Ol0oooo0?ooo`21B?l0oooo09]1
o`3oool0X3oo0?ooo`2F@_l0F5Co0?ooo`1/C_l0oooo0:Dno`2:AOl207E;o`030?ooo`1eBol0GhGo
0080kBko01L0TD?o06Q?o`1KDol0QdKo0:/mo`2?A?l0UT;o07M:o`27A_l0FU?o0=Dco`3`;Ol0YCko
0<`eo`36=_l0dSCo0?lVj01lBOl0QDKo0<`eo`1gB_l0Ldco0;/io`020:/mo`0W0;hho`3];_l0gS7o
0=/bo`2U?_l0JTko0:0oo`2f>_l0fc;o09A3o`2I@Ol0l2go07?Ho`3Q<?l0Ldco0:/mo`2U?_l0[Cco
0>L_o`20B?l0/3_o0:<oo`2[?Ol0c3Go08m4o`3?=?l0/3_o071<o`3];_l0obWh0:0oo`37=_l0TD?o
09A2o`2C@ol0c3Go0:hlo`2?A?l0PdOo0080OTSo03P0QdKo0=Pbo`2N@?l0GGco06A@o`3o:OP0eC?o
0;/io`2F@_l0L<[o0>X_o`20B?l0YCko0;0ko`1/C_l0obO^0?lL]`2n>?l0c3Go0;/io`3Z;ol0UT;o
0<ldo`36=_l0YCko0:/mo`3c;Ol0a3Oo0=Pbo`1KLol0eC?o0;/io`3H<_l0obWh0>X_o`3oool0ND[o
0?lGV@3?=?l0WT3o07=<o`1VCol0oooo0:<oo`2^??l0bCKo0?ooo`36=_l0J4oo08m4o`3Z;ol0Xcoo
08e4o`3Q<?l0SdCo0?lZoP80aSKo00T0YCko0;Hjo`34=ol0S4Co0>@`o`3c;Ol0nR_o0>d^o`3?=?l0
0P34=ol0103?=?l0iboo0;Hjo`2N@?l20>4`o`030;<ko`1ND_l0_SSo0080]S[o00D0eC?o0>X_o`3Z
;ol0ccCo09i0o`020:hlo`060;Hjo`36=_l0QdKo08M6o`2U?_l0UT;o0P2n>?l01@27A_l0oa^_0?lK
[`2C@ol0obOb0080oak100X0Zcgo0>4`o`3o9N@0oB_o0>4`o`3Z;ol0]S[o0;/io`36=_l0gS7o0P1M
O_l00`31>?l0Zcgo0?ooo`0d0?ooo`00703oool00`2f>_l0oooo0:/mo`020?ooo`0;0858o`3oool0
Vd7o0?ooo`2P?ol0oooo09I2o`1HE?l0JTko06a>o`3oool00P2:AOl207E;o`030953o`1eBol0GhGo
0080kBko00h0TD?o06Q?o`2X?Ol0QdKo0:/mo`2?A?l0QDKo07M:o`27A_l0FU?o0=Dco`1EEol0YCko
0<`eo`80dSCo00H0obKX07a9o`25A_l0c3Go05QSo`1cC?l30:/mo`0>0;hho`3];_l0gS7o0=/bo`39
=_l0JTko0:0oo`2f>_l0fc;o08Y5o`2I@Ol0/3_o07?Ho`3Q<?l209i0o`1A0:Dno`2]??l0iboo0818
o`2`>ol0Xcoo071<o`3<=Ol0SdCo0<ldo`2`>ol0PdOo0>d^o`3o:OP0X3oo0<Lfo`2A@ol0U4;o05MP
o`3<=Ol0[Sco08m4o`23Aol0OTSo07=<o`27A_l0f3;o09i0o`1MO?l0QdKo0?lYn03E<ol0^cWo09I2
o`1`b_l0jRoo0>4`o`2U?_l0^cWo06a>o`3o9nh0oabg0:Hno`3<=Ol0^cWo0>X_o`2F@_l0ccCo0<Hf
o`2U?_l0i33o0?<]o`2K@Ol0f3;o0>X_o`3E<ol0^cWo0=Pbo`3o:OP0jRoo0<ldo`1iB_l0SdCo0<ld
o`2N@?l0Ldco06I?o`3oool0Xcoo0:hlo`39=_l0oooo0<Hfo`1XCol0SdCo0>X_o`2S?ol0f3;o0;/i
o`2?A?l0ob[n0080aSKo01L0YCko0=Dco`34=ol0S4Co0>@`o`3c;Ol0]S[o0>d^o`3?=?l0Fg?o0<@g
o`3?=?l0iboo06m=o`2N@?l0l2go0>4`o`2c>ol0GU;o0;hho`27A_l0]S[o06a>o`020>X_o`060<ld
o`3Z;ol0bCKo0:hlo`2F@_l0aSKo0P27A_l01@1aC?l0UT;o0;hho`2n>?l0^cWo0080oa^_00D0HU7o
0?lWlP3o9o80oak10:/mo`020>4`o`070?d[o`3Q<?l0jRoo0;Hjo`2k>Ol0aSKo0=hao`0205eno`03
0<4ho`2[?Ol0eC?o03@0oooo000I0?ooo`080<4ho`3oool0oooo0;Hjo`3oool0Zcgo0?ooo`21B?l2
0?ooo`0909]1o`1cC?l0X3oo0?ooo`1HE?l0oooo06Y>o`1/C_l0^cWo0080RTGo0P1eBol01@2A@ol0
MD_o05n5o`3];_l0QDKo0080TD?o00h0Z3go07U:o`2[?Ol0SdCo0;<ko`1gB_l0QdKo05YCo`3E<ol0
EEOo0:Dno`2`>ol0dSCo069Ao`80obKX00@0QDKo0<`eo`1HHol0^3[o0P2[?Ol03`1SV?l0_SSo0>d^
o`31>?l0fc;o0<Tfo`1ZC_l0aSKo0;Hjo`3K<_l0RTGo09U1o`2`>ol0obSe0>4`o`0209i0o`040:Dn
o`2]??l0iboo0818o`80Xcoo01/0L4co0<`eo`2U?_l0ccCo0;0ko`23Aol0kBko0:/mo`2P?ol0kBko
0953o`2D@_l0Ef3o0<`eo`2^??l0SdCo09i0o`1nB?l0Ldco08M6o`3H<_l0WT3o05elo`27A_l0obWh
05aCo`2k>Ol00P1`b_l0;P3Z;ol0hC3o0:Dno`2k>Ol0K4ko0?lWkP2n>?l0YSko08m4o`2k>Ol0c3Go
09I2o`3?=?l0aSKo0:Dno`3T<?l0lbgo09]1o`3H<_l0jRoo0=Dco`2c>ol0f3;o0?lYn03Z;ol0ccCo
05YCo`2?A?l0oooo09i0o`2V?_l0IToo0?ooo`2V?_l0[Sco0<Tfo`3oool0aSKo06Q?o`2?A?l0jRoo
0:<oo`3H<_l0^cWo0>4`o`3o:_h20;hho`0G0:Dno`3E<ol0a3Oo0<@go`3T<?l0hC3o0;Hjo`3];_l0
ccCo05]co`34=ol0ccCo0;/io`2f>_l0WT3o0?0]o`3Q<?l0oajn05iBo`3H<_l0QdKo0;Hjo`1/C_l0
0P3Z;ol01P3?=?l0jRoo0<Tfo`2^??l0UT;o0;Hjo`80QdKo0100LDco0<@go`2^??l0_SSo0;/io`1l
BOl0oa^_069Ao`3<=Ol0obOb0?lN`@2[?Ol0X3oo0>4`o`3o9N@0hC3o0P3Z;ol00`2f>_l0aSKo0=ha
o`0205eno`030953o`2[?Ol0eC?o03@0oooo000G0?ooo`0E0=Dco`3oool0`CSo0?ooo`2I@Ol0]S[o
0?ooo`2[?Ol0oooo0858o`3oool0X3oo09]1o`1cC?l0X3oo0?ooo`1HE?l0oooo06Y>o`1/C_l0YCko
0080RTGo01d0MD_o0953o`2A@ol0MD_o0:<oo`3];_l0QDKo0953o`1KDol0Z3go07U:o`2[?Ol0SdCo
0;<ko`1gB_l0UT;o05YCo`1HI?l0EEOo0:Dno`2`>ol0dSCo069Ao`3o9^P0GWoo08E6o`3<=Ol0F6?o
0;Pjo`020:/mo`0E06>Ho`2n>?l0kBko0<4ho`3K<_l0bCKo06Y>o`36=_l0]S[o0=/bo`2:AOl0Z3go
0;0ko`3o:?D0gS7o09i0o`3Z;ol0YCko061Ao`3W;ol0P4So0080Xcoo04/0L4co0<`eo`2U?_l0ccCo
0;0ko`23Aol0kBko0:/mo`2P?ol0EU[o0953o`2D@_l0Ef3o07cdo`2^??l0SdCo0;<ko`1IJOl0Ldco
08M6o`2?A?l0WT3o09I2o`27A_l0obWh05aCo`2k>Ol0L<[o08M6o`3Z;ol0hC3o0<Tfo`2k>Ol0K4ko
0?lWkP2n>?l0YSko08m4o`2k>Ol0c3Go09I2o`2f>_l0aSKo0:Dno`3T<?l0lbgo09]1o`3H<_l0jRoo
0=Dco`2c>ol0f3;o0?lYn03Z;ol0]S[o05YCo`2?A?l0oooo09i0o`2V?_l0IToo0?ooo`2V?_l0[Sco
0<Tfo`3c;Ol0FU?o0;<ko`2?A?l0obWh0:<oo`3H<_l0^cWo0>4`o`3o:_h00P2n>?l03@1JDol0eC?o
0<@go`34=ol0i33o0>4`o`2f>_l0kBko0<ldo`1KLol0^cWo0<ldo`2k>Ol00P2f>_l09P3`;Ol0hC3o
0;Hjo`3o7[h0f3;o08M6o`2A@ol0K4ko0>4`o`2n>?l0ccCo0>X_o`39=_l0NTWo09I2o`2f>_l0QdKo
0?lWkP1aC?l0a3Oo0:hlo`2n>?l0^cWo07a9o`3o6jl0HU7o0<`eo`3o9o80oak10:/mo`2P?ol0hC3o
0?lUi03Q<?l0YCko0>X_o`2f>_l0aSKo0P3N<Ol01@1MO_l0TD?o0:/mo`3E<ol0ob?J03<0oooo000G
0?ooo`050=Dco`3oool0`CSo0?ooo`2f>_l00P3oool02`2[?Ol0oooo0858o`3oool0Vd7o0?ooo`1c
C?l0X3oo07WYo`1HE?l0oooo0080K4ko00@0YCko08Y5o`2:AOl0MD_o0P2A@ol0201eBol0Xcoo0>d^
o`25A_l0TD?o05]Co`2X?Ol0ND[o0P2[?Ol0402c>ol0Md[o08a4o`1JDol0KTgo05EGo`2K@Ol0/3_o
0<Hfo`1RDOl0obKX05ioo`25A_l0c3Go05QSo`2h>_l20:/mo`0m06>Ho`2n>?l0kBko0<4ho`2U?_l0
bCKo0:Dno`36=_l0]S[o0<<go`2:AOl0l2go0;0ko`3o:?D0gS7o07=<o`3Z;ol0YCko061Ao`3W;ol0
G7Wo0:<oo`1X[_l0L4co0<`eo`2U?_l0ccCo0<@go`23Aol0ccCo0:/mo`2P?ol0kBko0953o`1ZC_l0
K4ko07cdo`2^??l0WT3o0;<ko`1IJOl0Ldco08M6o`2?A?l0WT3o09I2o`27A_l0obWh05aCo`2k>Ol0
O4Wo08M6o`3Z;ol0hC3o0<ldo`2k>Ol0UT;o07M:o`2n>?l0YSko08m4o`020<`eo`0S09I2o`2f>_l0
aSKo0:Dno`3T<?l0OTSo09]1o`3H<_l0jRoo0=Dco`2c>ol0f3;o0?lXm@3Z;ol0]S[o05YCo`27A_l0
oooo09i0o`2V?_l0TD?o0?ooo`2V?_l0MD_o0<Tfo`3c;Ol0FU?o0;<ko`3?=?l0obWh09I2o`3H<_l0
^cWo0>4`o`3o:_h00P2n>?l03@1JDol0eC?o0<@go`34=ol0i33o0>4`o`2f>_l0nR_o0<ldo`1KLol0
^cWo0<ldo`2k>Ol00P2f>_l01P3`;Ol0hC3o0?lN_P3o7[h0f3;o08M6o`80TD?o00D0hC3o0;hho`2n
>?l0jRoo0<Tfo`0207Y9o`0P0;Hjo`27A_l0ccCo075<o`34=ol0[Sco0;hho`2k>Ol0O4Wo0?lK[`2?
A?l0c3Go0>d^o`3o7/40Zcgo0:0oo`1]`?l0obGT0>4`o`2U?_l0jRoo0;Hjo`3m:ol0obO_0=hao`1M
O_l0TD?o0<4ho`3oool0eC?o0?ooo`31>?la0?ooo`005`3oool0603E<ol0oooo0<4ho`3oool0]S[o
0?ooo`27A_l0Zcgo0?ooo`21B?l0oooo09]1o`3oool0Ldco0:0oo`2F@_l0F5Co0?ooo`1/C_l0GU;o
0:Dno`2:AOl0PdOo07E;o`80TD?o00X0GhGo0:<oo`2F@_l0Xcoo0953o`1KDol0Z3go08E6o`2[?Ol0
QDKo0P2c>ol04`2<A?l0FU?o06i=o`1^COl0Vd7o0;0ko`36=_l0HU7o0?lVj01NOol0QDKo0<<go`1H
Hol0^3[o0:/mo`25A_l0HiSo0;hho`3E<ol00P31>?l01039=_l0YCko0<Hfo`2f>_l20<<go`0@0?0]
o`2`>ol0obSe0=hao`1cC?l0jRoo07CJo`1PDOl0iboo05aio`2S?ol0J:ko071<o`3<=Ol0YCko0<ld
o`80a3Oo02l0ccCo0:/mo`3];_l0kBko0953o`1ZC_l0K4ko07cdo`2^??l0WT3o0;<ko`1IJOl0Ldco
0<ldo`2?A?l0WT3o09I2o`27A_l0oafj05aCo`2k>Ol0O4Wo08M6o`2?A?l0hC3o0<Tfo`2k>Ol0UT;o
07M:o`25A_l0YSko08m4o`3<=Ol0ROoV0=Pbo`2f>_l0f3;o0:Dno`3T<?l0OTSo09]1o`1VCol0jRoo
0:0oo`2c>ol0f3;o0?lXm@020>X_o`0D0:/mo`27A_l0oooo0=8do`2V?_l0TD?o0?ooo`2V?_l0MD_o
0<Tfo`3c;Ol0FU?o0;<ko`3?=?l0obWh09I2o`3H<_l0NTWo0>4`o`3H<_l20;hho`0=05YCo`3E<ol0
aSKo0<@go`25A_l0hC3o0?lZoP3j:ol0ob?J06a>o`2k>Ol0obGT0;/io`020;Hjo`060?0]o`3Q<?l0
oajn0?lN_P3H<_l0QdKo0P2A@ol01@3Q<?l0_SSo0;hho`3Z;ol0bCKo0080NTWo0200]S[o08M6o`3?
=?l0ccCo0<@go`2^??l0S4Co0;/io`1lBOl0L4co08m4o`3<=Ol0kBko0?lN`@2[?Ol0X3oo06g0o`3o
9N@0hC3o0:Dno`2^??l0]S[o0?d[o`3o9nl0gS7o0<ldo`2A@ol0`CSo0:/mo`3E<ol0oooo0<4hoc40
oooo000F0?ooo`080=Dco`3oool0oooo0<4ho`3oool0]S[o0?ooo`2[?Ol20?ooo`040858o`2P?ol0
Vd7o0?ooo`80X3oo00L0UT;o05QDo`1ZC_l0K4ko05iBo`2U?_l0RTGo0080PdOo0P2A@ol00`1OQOl0
Xcoo0:<oo`020:<oo`0905]Co`2X?Ol0VD7o0:/mo`25A_l0/c_o09I2o`2<A?l0Vd7o0080KTgo00D0
Vd7o0;0ko`2S?ol0HU7o08Y5o`0205ioo`070<<go`1HHol0obSe0:/mo`25A_l0HiSo0;hho`020=8d
o`0@0:Dno`39=_l0iboo0<Hfo`2f>_l0`cOo0:Pmo`3`;Ol0/3_o0?lXm@3N<Ol0UT;o0>X_o`1df_l0
H57o0>L_o`80^cWo02h0J:ko071<o`2X?Ol0YCko0<ldo`34=ol0hC3o0<ldo`2[?Ol0QdKo0>d^o`2S
?ol0JTko06a>o`1lm?l0[Sco09i0o`2c>ol0FFWo07=<o`2n>?l0SdCo09i0o`2F@_l0Vd7o0?lM^P1L
Dol0[Sco07a9o`27A_l0SdCo0>4`o`39=_l0^cWo09I2o`2OokP0QDKo0:Hno`2k>Ol0c3Go08WoiP3H
<_l0]S[o0=Pbo`2U?_l0i33o0P1nB?l04@1VCol0jRoo0:0oo`2c>ol0Ldco0?lXm@3oool0]S[o0:/m
o`27A_l0oooo0=8do`2V?_l0TD?o0?ooo`2V?_l0MD_o0080lbgo00d0c3Go0;<ko`3?=?l0obWh09I2
o`3Q<?l0NTWo0>4`o`3H<_l0WT3o07a9o`1JDol0ccCo0080a3Oo00d0QDKo0>4`o`2f>_l0nR_o0?lS
fP1/C_l0lbgo0?lUi03Z;ol0Kdgo0;Hjo`36=_l0hC3o0080oajn00d0f3;o08M6o`1VCol0TD?o0>4`
o`3oool0_SSo0=Pbo`39=_l0YCko07Y9o`3g;?l0QdKo0080ccCo01d0a3Oo0:hlo`2<A?l0^cWo07a9
o`1`C?l0SdCo0<`eo`3];_l0Zcgo07=<o`2P?ol0KL3o0:hlo`3Q<?l0YCko0:hlo`2n>?l0oB_o0?lW
k`2^??l0ccCo0953o`31>?l0Zcgo0=Dco`3o8mX0`CSo0>X_o`0`0?ooo`005P3oool07P3E<ol0oooo
0:<oo`31>?l0oooo0;Hjo`3oool0Zcgo0?ooo`25A_l0PDSo0:0oo`2K@Ol0oooo0:0oo`1gB_l0UT;o
05QDo`1ZC_l0QDKo05iBo`2U?_l0RTGo08=7o`2h>_l0Xcoo0953o`1OQOl0PdOo08E6o`80Xcoo01H0
Fe?o0:Pmo`2I@Ol0/c_o08E6o`2c>ol0UT;o08a4o`2K@Ol0KTgo0818o`2K@Ol0/3_o0:<oo`2C@ol0
RTGo05ioo`2A@ol0`cOo07U:o`3E<ol0Zcgo0P25A_l0202k>Ol0dSCo0<`eo`2U?_l0bCKo0>L_o`36
=_l0obKX0P33=ol0503`;Ol0Td?o0?lXm@3N<Ol0UT;o0>X_o`1df_l0H57o0>L_o`2k>Ol0gS7o06R^
o`2c>ol0Z3go0:Dno`1GGOl0a3Oo0>4`o`3?=?l0Zcgo0P3];_l02@2S?ol0K/;o06a>o`2?A?l0iboo
09i0o`2c>ol0FFWo0<ldo`0208m4o`0905QDo`2F@_l0Vd7o0?lM^P1jBOl0[Sco07a9o`27A_l0SdCo
0080bCKo02l0^cWo09I2o`2OokP0QDKo0:Hno`2k>Ol0c3Go08WoiP3H<_l0_SSo0=Pbo`2U?_l0ccCo
09U1o`2K@Ol0IToo0?lWlP2P?ol0/c_o07=<o`3o:?D0oooo0;Hjo`2[?Ol0QdKo0?ooo`3B=?l0_SSo
0953o`36=_l0YSko09U1o`2c>ol0lbgo0<`eo`2c>ol0ccCo08m4o`2F@_l0hC3o07Y9o`3Q<?l0f3;o
09i0o`1lBOl0aSKo0<ldo`020<@go`0L08E6o`3o4h80]S[o0?X[o`3o8mX0K4ko0?<]o`3o9N@0jRoo
06m=o`2f>_l0aSKo0818o`2f>_l0oajn0=Pbo`2X?Ol0IToo0953o`3B=?l0oooo0;hho`3H<_l0S4Co
0:Dno`1jBOl0mbco08m4o`80ccCo00T0lbgo0:hlo`2<A?l0S4Co0=Pbo`1`C?l0SdCo0<`eo`3];_l0
0P2[?Ol04`2P?ol0SdCo0:hlo`1^COl0YCko0:hlo`2n>?l0oB_o0?lWk`2^??l0ccCo0953o`31>?l0
Zcgo0=Dco`3o8mX0`CSo0>X_o`3F<ol0;`3oool001H0oooo00<0eC?o0?ooo`31>?l00P3oool0102f
>_l0oooo0:/mo`3oool20858o`070:0oo`2K@Ol0Ldco0:0oo`1ijOl0UT;o09]1o`0208E6o`0K0;/i
o`2U?_l0RTGo08=7o`2h>_l0Xcoo0;/io`1OQOl0PdOo08E6o`2S?ol0Z3go05]Co`25A_l0VD7o0;<k
o`25A_l0/c_o09I2o`2<A?l0QDKo06i=o`20B?l0Vd7o0;0ko`2S?ol0Td?o0080RTGo00<0TD?o0<<g
o`1iB_l00P3o:?D01@25A_l0Td?o0;/io`3B=?l0c3Go0080YCko00h0iboo0<Hfo`2<A?l0S4Co0:Pm
o`3`;Ol0Td?o0?lXm@3N<Ol0UT;o0>X_o`1df_l0gS7o0:Pmo`80^cWo01@0ccCo0;<ko`2X?Ol0YCko
05MMo`34=ol0hC3o0<ldo`27A_l0kBko061Ao`2S?ol0K/;o06a>o`3N<Ol0iboo09i0o`2c>ol0FFWo
0<ldo`80SdCo00T0F5Co09I2o`2K@Ol0oafj07Y9o`2^??l0O4Wo08M6o`2N@?l00P39=_l0;`2:AOl0
UT;o09oo^025A_l0YSko0;/io`21B?l0hC3o0=Pbo`2n>?l0f3;o0=8do`3?=?l0VD7o09]1o`2?A?l0
obOb0<ldo`2c>ol0Ldco0?lXm@3Q<?l0]S[o0:/mo`36=_l0IToo0=8do`2n>?l0TD?o0<Hfo`2V?_l0
VD7o0;<ko`3c;Ol0c3Go0;<ko`2S?ol0SdCo06R^o`3Q<?l0NTWo0;/io`3H<_l0WT3o07a9o`36=_l0
ccCo0080a3Oo02@0hC3o0?lCPP2f>_l0nR_o0?lSfP1/C_l0lbgo0?lUi03Z;ol0Kdgo0?<]o`36=_l0
P4So0;Hjo`3o7[h0f3;o0:Pmo`1VCol0TD?o0=8do`3oool0lbgo0=Pbo`2<A?l0YCko0:<oo`3g;?l0
SdCo0?lWkP3?=?l0lbgo0:hlo`1ODOl0S4Co0=Pbo`1`C?l208m4o`050>d^o`2S?ol0Zcgo07=<o`2?
A?l00P2^??l03`20B?l0[Sco0;hho`2A@ol0obO_0:hlo`3?=?l0_SSo0<4ho`2[?Ol0eC?o0?lSfP31
>?l0jRoo0=Hco`0_0?ooo`005P3oool04P3E<ol0oooo0<4ho`31>?l0VD7o0;Hjo`3oool0Zcgo05eB
o`21B?l0oooo0;/io`2K@Ol0Ldco0:0oo`1ijOl0UT;o09]1o`<0QDKo00L0YCko08Y5o`2[?Ol0TD?o
0:<oo`2k>Ol0GhGo0080QDKo01d0RTGo05eBo`1MD_l0QDKo09U1o`2c>ol0QDKo0<<go`2F@_l0S4Co
08E6o`2K@Ol0O?Ko09]1o`2k>Ol0Xcoo09=3o`2:AOl0X3oo0953o`33=ol0`CSo0?lXm@2c>ol0QDKo
08a4o`2k>Ol0eC?o09=3o`020:Dno`0S0>L_o`2A@ol0S4Co08a4o`2X?Ol0l2go09=3o`3o:?D0MD_o
09I2o`1`C?l0X3oo0=hao`2X?Ol0GhSo0=hao`3?=?l0/c_o0:Pmo`2?A?l0Eego06I?o`3Q<?l0ccCo
08M6o`3];_l0H57o0:<oo`1^`_l0K4ko0=hao`3W;ol0YSko0;<ko`36=_l00P3?=?l205QDo`0:08M6
o`2K@Ol0oafj07Y9o`2^??l0O4Wo08M6o`2N@?l0bCKo0<ldo`80RTGo0140PDSo08E6o`2P?ol0^cWo
0858o`3Q<?l0f3;o0;hho`3H<_l0dSCo0<ldo`2I@Ol0Vd7o08m4o`3o9o80ccCo0;<ko`020;hho`1;
05MMo`3?=?l0Zcgo0<Hfo`1VCol0dSCo0;hho`3o9o80aSKo0:Hno`2I@Ol0/c_o0?<]o`3<=Ol0WT3o
0:<oo`2?A?l0J:ko0>4`o`2I@Ol0^cWo0=Dco`2N@?l0F6?o0<Hfo`3?=?l0Zcgo0<@go`3Q<?l0oa>2
0?lZoP2f>_l0ob?J06a>o`3c;Ol0obGT0>X_o`1_COl0lbgo0<Hfo`20B?l0]S[o0?lN_P3H<_l0Z3go
06I?o`2n>?l0dSCo0?ooo`3?=?l0f3;o08a4o`2U?_l0UT;o0?L/o`2?A?l0obO^0<ldo`3c;Ol0aSKo
05mAo`2<A?l0f3;o08M6o`2F@_l0SdCo0<Hfo`2S?ol0Zcgo07=<o`2?A?l0f3;o0:hlo`1^COl0[Sco
0080_SSo00`0obO_0:<oo`3?=?l0f3;o0<4ho`2[?Ol0eC?o0?lSfP31>?l0jRoo0=Hco`3?=?l^0?oo
o`005P3oool06P3E<ol0oooo0<4ho`31>?l0VD7o0;Hjo`3oool0Zcgo08E6o`21B?l0oooo0;/io`2K
@Ol0Ldco0;<ko`1ijOl0UT;o09]1o`1ZC_l0GU;o08E6o`2S?ol0RTGo0:/mo`2A@ol0WT3o0P1VCol0
7P2F@_l0QDKo08Y5o`1MD_l0[Sco08E6o`2I@Ol0O4Wo08E6o`3o9N@0UT;o09]1o`25A_l0Vd7o0818
o`2K@Ol0^cWo0:<oo`1`C?l0RTGo0:0oo`2A@ol0`cOo0<4ho`3o:?D0/c_o08E6o`2<A?l0^cWo0=Dc
o`80c3Go00T0YCko0>L_o`2A@ol0obKX06:Bo`2X?Ol0l2go09=3o`3o:?D00P1eBol09`1`C?l0X3oo
0=hao`2X?Ol0GhSo0=hao`3?=?l0/c_o0:Pmo`2?A?l0W47o06I?o`3Q<?l0ccCo08M6o`1FF_l0H57o
0:<oo`1^`_l0K4ko0=hao`3W;ol0YSko0;<ko`36=_l0ccCo0;hho`1HE?l0UT;o08M6o`2K@Ol0oafj
07Y9o`2F@_l0O4Wo08M6o`2N@?l0bCKo0<ldo`0208Y5o`0A0858o`25A_l0X3oo0;/io`21B?l0hC3o
09I2o`2n>?l0f3;o0=8do`3?=?l0VD7o09]1o`2?A?l0obOb0<ldo`2c>ol00P2n>?l0:@1GGOl0ccCo
0:/mo`36=_l0ccCo0=8do`2n>?l0obOb0<Hfo`2V?_l0VD7o0;<ko`1cC?l0c3Go09i0o`2S?ol0ccCo
09i0o`3c;Ol0VD7o0;/io`3E<ol0K4go05QSo`36=_l0hC3o0<Hfo`34=ol0hC3o0?lCPP1KLol0]S[o
0?lSfP3B=?l0lbgo0;/io`3Z;ol0Kdgo0?<]o`1iB_l0NTWo0080]S[o00H0Kdgo0:Pmo`1VCol0_SSo
0=8do`2U?_l20<ldo`0L08a4o`2U?_l0UT;o0?L/o`2?A?l0obO^0:<oo`3c;Ol0aSKo05mAo`1eBol0
f3;o08M6o`2F@_l0SdCo0<Hfo`2S?ol0P4So07=<o`2?A?l0f3;o0:hlo`1^COl0P4So0?<]o`2n>?l0
obO_0:<oo`80ccCo00P0`CSo0:/mo`3E<ol0ob?J0;<ko`31>?l0eS?o0<ldobh0oooo000F0?ooo`04
0=Dco`3oool0`CSo0<4ho`80]S[o00/0UT;o0:/mo`25A_l0Md[o09U1o`2k>Ol0/c_o07=<o`2c>ol0
NNWo0>L_o`0206Y>o`0705iBo`25A_l0Xcoo08Y5o`2[?Ol0TD?o09i0o`0206I?o`0309I2o`25A_l0
Z3go0080GE;o00X0QDKo09U1o`1lBOl0Zcgo0?lUi02F@_l0Vd7o08E6o`2K@Ol0P4So0P2k>Ol09`2S
?ol0L4co0;<ko`2P?ol0TD?o07U:o`31>?l0eC?o0;<ko`31>?l0S4Co0;/io`1hB_l0c3Go0=hao`2U
?_l0iboo0953o`3o9^P0HY;o0:Pmo`2`>ol0Td?o0?lXm@1eBol0U4?o071<o`2P?ol0gS7o0:Pmo`1O
R?l0gS7o0<ldo`2c>ol0Z3go08m4o`2L@Ol0IToo0>4`o`0208a4o`0H05IJo`1PDOl0IIko06k2o`1/
C_l0gS7o0>L_o`2V?_l0/c_o0<Hfo`3?=?l0_SSo05QDo`2F@_l0QdKo09]1o`3o7KX0S4Co09I2o`1l
BOl0J4oo09i0o`1JDol0ccCo0P2:AOl04@21B?l0P4So0:0oo`25A_l0PDSo0>4`o`2F@_l0QdKo0=Pb
o`3B=?l0lbgo09U1o`2K@Ol0SdCo0?lWlP3?=?l0/c_o0080_SSo01X0Eego0<ldo`2F@_l0aSKo0<ld
o`2N@?l0_SSo0?ooo`36=_l0_SSo09U1o`2c>ol0Ldco0<`eo`2N@?l0Xcoo0<ldo`2N@?l0lbgo09U1
o`1jBOl0eC?o06a=o`1HHol0aSKo0>4`o`80aSKo01D0hC3o0?lCPP3o:_h0]S[o0<ldo`3B=?l0jRoo
0;/io`2n>?l0VD7o09i0o`1iB_l0NTWo0<@go`2f>_l0Kdgo0?lTg@1VCol0_SSo0>d^o`2U?_l00P3?
=?l0803g;?l0YCko09I2o`2F@_l0SdCo0?lWkP2S?ol0lbgo0<Hfo`1ODOl0MD_o0=Pbo`27A_l0UT;o
0:Pmo`36=_l0Xcoo0818o`3o:OP0SdCo0=Pbo`21B?l0KTgo0818o`3c;Ol0_SSo0953o`2S?ol0[Sco
0<ldo`3H<_l0Zcgo0P3E<ol20<4ho`030=Hco`3?=?l0/3_o02d0oooo000E0?ooo`80eC?o00<0oooo
0<4ho`3oool00P2f>_l02@2F@_l0Zcgo08E6o`1gB_l0RTGo0;/io`2c>ol0Ldco07i8o`020>L_o`0D
06Y>o`27A_l0GU;o0;/io`2I@Ol0RTGo0;Pjo`2A@ol0WT3o06I?o`2V?_l0UT;o08E6o`2X?Ol0hC3o
0:hlo`25A_l0a3Oo07a9o`2[?Ol20?lUi00309]1o`25A_l0U4?o0080P4So0180^cWo0:<oo`1`C?l0
/c_o0:0oo`2A@ol0ND[o0<4ho`3E<ol0/c_o09=3o`2<A?l0^cWo07Q:o`3<=Ol0gS7o0:Dno`3W;ol2
0?lVj00P06:Bo`2F@_l0/3_o09=3o`3o:?D0MD_o09A3o`1`C?l0X3oo0=hao`2X?Ol0GhSo0=hao`3?
=?l0/c_o0>4`o`2?A?l0W47o06I?o`3Q<?l0S4Co0:<oo`1FF_l0QdKo06FNo`2S?ol0SdCo0=hao`1l
BOl0YSko0;<ko`36=_l20<ldo`0]05QDo`2F@_l0QdKo09]1o`3o9N@0S4Co09I2o`1lBOl0J4oo09i0
o`1JDol0ccCo05n5o`2:AOl0PDSo0818o`2P?ol0QDKo0858o`3Q<?l0UT;o08M6o`3H<_l0dSCo0?<]
o`2I@Ol0f3;o08m4o`1cC?l0ccCo0;<ko`2n>?l0oooo05MMo`3?=?l0UT;o0<Hfo`3?=?l0WT3o07=<
o`3oool0aSKo0;hho`2^??l0oooo0080Ldco00`0WT3o0?ooo`3?=?l0WT3o0?<]o`2I@Ol0NTWo0=Dc
o`1/COl0F6?o07a9o`3Q<?l20<Hfo`0E0>4`o`2N@?l0ob[n0?lZoP3?=?l0dSCo0?<]o`2k>Ol0_SSo
09U1o`3c;Ol0ND[o07Y9o`34=ol0]S[o06m=o`3o9=d0WT3o0;hho`3];_l0YCko0080ccCo00H0mbco
0:Dno`2S?ol0UT;o0=Pbo`3o9nh20:<oo`0P0<Hfo`1ODOl0MD_o0=Pbo`27A_l0UT;o0:Pmo`36=_l0
Xcoo0818o`3B=?l0SdCo0=Pbo`21B?l0hC3o0818o`3c;Ol0SdCo0953o`2S?ol0[Sco0<ldo`3H<_l0
YCko0>L_o`3E<ol0ob?J0<4ho`3Z;ol0ccCo0;0ko`3H<_l/0?ooo`005@3oool20=Dco`090:<oo`31
>?l0oooo0;Hjo`3oool0UT;o0?ooo`25A_l0Md[o0080X3oo01l0/c_o07=<o`1gB_l0iboo05mAo`1Z
C_l0QdKo05iBo`2k>Ol0VD7o08Y5o`2h>_l0TD?o0;/io`1VCol0YSko09I2o`2U?_l0Z3go0>4`o`2P
?ol0QDKo0<@go`1lBOl0Zcgo0?lUi02I@Ol0Vd7o08E6o`2D@ol0Eego0080^cWo00`0eC?o071<o`2c
>ol0X3oo0:<oo`1iB_l0`CSo09i0o`2c>ol0Td?o08a4o`2:AOl209=3o`030=hao`2U?_l0_SSo0080
obKX00l0bCKo09I2o`2`>ol0Td?o07Y9o`3W;ol0U4?o071<o`2P?ol0gS7o0:Pmo`1OR?l0HU7o0<ld
o`2c>ol00P3Q<?l00`2L@Ol0IToo07=<o`0208a4o`0<05IJo`27A_l0IIko0>@`o`2?A?l0gS7o07a9
o`2V?_l0obWh0<Hfo`1cC?l0_SSo0P2F@_l0>@27A_l0IIko0?lUi02<A?l0UT;o09i0o`1XCol0QDKo
05YCo`3?=?l0GhGo08Y5o`21B?l0P4So08E6o`1PRol0PDSo0>4`o`1lBOl0QdKo0=Pbo`2f>_l0lbgo
09U1o`3H<_l0eC?o07=<o`3?=?l0dSCo0;hho`3oool0Eego0<ldo`2F@_l0oooo0<ldo`2N@?l0Ldco
0?ooo`36=_l0_SSo0:hlo`3oool0/c_o07=<o`1gB_l0oooo0<ldo`2N@?l0lbgo0;Hjo`1jBOl0dSCo
06a=o`2V?_l0O4Wo0>4`o`020<Hfo`060:hlo`2N@?l0ob[n0?lZoP3?=?l0dSCo0P3c;Ol01P2n>?l0
VD7o0?<]o`3c;Ol0NTWo0<@go`80Ldco00P0obCM09i0o`2n>?l0kBko0:Dno`3c;Ol0ccCo0?L/o`80
Xcoo00L0UT;o0=Pbo`3o9nh0a3Oo0:<oo`36=_l0Ge7o0080MD_o01`0ccCo09I2o`2X?Ol0UT;o0:<o
o`20B?l0dSCo0818o`3H<_l0PDSo0>4`o`20B?l0lbgo08m4o`1VCol0Xcoo0:hlo`25A_l0f3;o0:Dn
o`3W;ol0eC?o0?lSfP31>?l0jRoo0=Hco`2`>ol0f3;o;03oool001D0oooo00d0eC?o0?ooo`2S?ol0
`CSo0;<ko`2I@Ol0oooo09I2o`1MD_l0QDKo0?ooo`2P?ol0oooo0080S4Co00L0Md[o0>L_o`2K@Ol0
JTko08M6o`1ND_l0^cWo0080a3Oo00T0^3[o0953o`2k>Ol0/c_o0:Hno`2F@_l0Xcoo0:Pmo`3Q<?l0
0P2`>ol02@34=ol0O4Wo0<<go`3o9N@0KL3o09]1o`2h>_l0U4?o05MMo`020;/io`0<0=Dco`1`C?l0
hC3o0:0oo`34=ol0ND[o0<4ho`2N@?l0`CSo09=3o`2<A?l0RTGo0P2C@ol0103N<Ol0LDco0;hho`2A
@ol20<Tfo`0B09I2o`2`>ol0^cWo07Y9o`3W;ol0U4?o0:/mo`2P?ol0gS7o0>h^o`3E<ol0HU7o0<ld
o`2c>ol0hC3o07U:o`2L@Ol0UT;o0P2[?Ol03@2S?ol0EU[o08M6o`1UW_l0i33o08m4o`3N<Ol0O4Wo
0:Hno`3o:OP0aSKo07=<o`2n>?l00P2F@_l0@@27A_l0IIko0?lUi02<A?l0UT;o09i0o`1XCol0QDKo
05YCo`3?=?l0K4ko08Y5o`21B?l0P4So08E6o`1PRol0]S[o0>4`o`1lBOl0QdKo0=Pbo`2f>_l0lbgo
09U1o`3H<_l0eC?o08m4o`3?=?l0dSCo0;<ko`1MO?l0Eego08Y5o`2F@_l0oooo0<ldo`3N<Ol0Ldco
0?ooo`3o9o80_SSo0:hlo`3oool0/c_o07=<o`1gB_l0oooo0<ldo`2N@?l0lbgo0;Hjo`1jBOl0dSCo
0;<ko`2V?_l0O4Wo09i0o`2[?Ol0aSKo0:hlo`2N@?l0Fg?o0?lZoP1iB_l0dSCo0080lbgo00H0c3Go
09U1o`3c;Ol0lbgo08m4o`34=ol207=<o`080?lTg@2N@?l0_SSo0>d^o`2U?_l0lbgo0<ldo`3g;?l2
0:<oo`0;07=<o`3H<_l0obO^0<@go`2S?ol0aSKo06Y>o`2^??l0MD_o0<ldo`2F@_l00P2X?Ol01`2F
@_l0P4So0=8do`20B?l0f3;o0858o`3Q<?l00P3c;Ol0402?A?l0IToo0:<oo`2^??l0QDKo0=Pbo`2U
?_l0iboo0;hho`3o8mX0`CSo0>X_o`3F<ol0/3_o0=Pbo`2f>_l[0?ooo`005@3oool03`3E<ol0oooo
0:<oo`3oool0/c_o09U1o`3oool0QdKo05eBo`25A_l0oooo0:0oo`2K@Ol0S4Co0?ooo`0207M:o`1B
09]1o`1HHol0QdKo05iBo`2S?ol0a3Oo0:Hno`2h>_l0X3oo0;/io`2c>ol0QDKo09I2o`2S?ol0Z3go
0>4`o`2`>ol0Td?o0<@go`1lBOl0`cOo0?lUi02I@Ol0Vd7o0;<ko`2D@ol0Eego0;/io`2[?Ol0eC?o
071<o`3Q<?l0X3oo0<@go`1iB_l0VD7o09i0o`31>?l0Td?o0;0ko`2:AOl0N4[o05QDo`3N<Ol0LDco
0;hho`2^??l0bCKo0<@go`2F@_l0/3_o0;/io`1aC?l0iboo09A3o`2[?Ol0X3oo0=hao`3^;_l0eC?o
069Ao`3?=?l0K4go0>4`o`1iB_l0W47o09I2o`2[?Ol0ob[o0:<oo`2N@?l0QdKo0:<oo`3T<?l0SdCo
05UYo`1lBOl0YSko0?lYn01LM_l0Ldco0;hho`80UT;o05<0H8_o08m4o`3o9N@0S4Co09I2o`2N@?l0
UT;o08E6o`1JDol0WT3o06a>o`2:AOl0PDSo06Y>o`25A_l0H8_o0;Hjo`3Q<?l0O4Wo08M6o`3H<_l0
]S[o0=Dco`2I@Ol0f3;o0=Dco`34=ol0ccCo0=8do`2c>ol0GGco0>4`o`2:AOl0oao50?X[o`3?=?l0
gS7o0:/mo`3oool0obOb0=Dco`2^??l0oooo0;<ko`2n>?l0Md[o0?<]o`2S?ol0WT3o0;<ko`2f>_l0
VD7o0=8do`2c>ol0YSko05QSo`2N@?l0Zcgo0<Hfo`2^??l0WT3o05]co`3o:_h0ND[o0=8do`3Z;ol0
lbgo0<`eo`2I@Ol0WT3o0?<]o`2?A?l0a3Oo09]1o`1cC?l0obCM09i0o`2n>?l0kBko0:Dno`3c;Ol0
S4Co0?L/o`020:<oo`0?07E;o`3H<_l0iboo0<@go`3oool0aSKo06Y>o`2^??l0MD_o0<ldo`2^??l0
SdCo0:Pmo`2F@_l0P4So0080dSCo01H0f3;o0858o`3Q<?l0ccCo0?<]o`2?A?l0IToo08m4o`2^??l0
QDKo0;hho`2U?_l0iboo0;hho`3o8mX0`CSo0>X_o`3F<ol0ccCo0=Pbo`2f>_l0`CSo:P3oool001L0
oooo00H0Xcoo0?ooo`2c>ol0oooo0:Pmo`27A_l208E6o`030?ooo`2:AOl0/c_o0080S4Co00L0Md[o
0:<oo`2K@Ol0F6?o08M6o`2X?Ol0Xcoo0080a3Oo01P0^3[o0:0oo`2k>Ol0/c_o08E6o`2n>?l0Xcoo
0:Pmo`2^??l0/3_o09=3o`34=ol0RTGo0<<go`3o9N@0VD7o09]1o`2c>ol0U4?o0:0oo`2k>Ol0Zcgo
0=Dco`2N@?l207i8o`1/0<@go`1iB_l0VD7o0:Pmo`31>?l0Td?o0;0ko`2:AOl0N4[o05QDo`3N<Ol0
LDco0;hho`1VCol0bCKo0<@go`2F@_l0/3_o0;/io`1aC?l0iboo09A3o`2[?Ol0X3oo0=hao`3^;_l0
eC?o069Ao`3?=?l0K4go0>4`o`1iB_l0W47o09I2o`2[?Ol0ob[o0:<oo`2N@?l0QdKo0:<oo`3T<?l0
Vd7o05UYo`1lBOl0HY;o0?lYn01LM_l0Ldco0;hho`2F@_l0SdCo062;o`2?A?l0HY?o08a4o`1JKOl0
WT3o09I2o`25A_l0J:ko09i0o`1/C_l0RTGo0858o`1ZC_l0Ge7o062;o`2f>_l0hC3o07a9o`27A_l0
Vd7o0;Hjo`3E<ol0VD7o09A3o`3E<ol0a3Oo0<ldo`3B=?l0/c_o09I2o`3Q<?l0RTGo0?lOa@3j:ol0
ccCo0=hao`2[?Ol0Xcoo0?lWlP3E<ol0P4So0?ooo`2c>ol0_SSo07M:o`3c;Ol0Xcoo0;Hjo`2c>ol0
]S[o09U1o`3B=?l0/c_o0:Hno`1HHol0WT3o0P2[?Ol04P2^??l0WT3o05]co`3o:_h0ND[o0=Pbo`3Z
;ol0lbgo0<`eo`1RDOl0WT3o0?<]o`2?A?l0a3Oo09]1o`1cC?l0obCM09i0o`80_SSo00@0ob;C0?<]
o`2<A?l0S4Co0P2S?ol04P1eBol0f3;o0>L_o`34=ol0ccCo0<Hfo`1ZC_l0[Sco0;hho`3?=?l0[Sco
08m4o`2X?Ol0UT;o0<ldo`3m:ol0dSCo0818o`<0hC3o0180lbgo08m4o`1VCol0SdCo0:hlo`25A_l0
_SSo0<ldo`3W;ol0_SSo0>4`o`31>?l0jRoo0=Hco`3?=?l0f3;o0;Hjo`31>?lZ0?ooo`006@3oool0
3`2c>ol0oooo0:Pmo`3oool0QDKo0?ooo`2I@Ol0RTGo0;<ko`2S?ol0S4Co07M:o`2S?ol0Vd7o09I2
o`020:Pmo`070:<oo`2I@Ol0EU[o0;Pjo`2P?ol0^cWo0:Hno`0208E6o`0B0:<oo`2X?Ol0[Sco0:0o
o`23Aol0a3Oo08Y5o`33=ol0Zcgo09U1o`2h>_l0/c_o09A3o`2U?_l0^cWo0:/mo`3E<ol0S4Co0P1n
B?l0H034=ol0RTGo09U1o`2X?Ol0`CSo09=3o`3o9=d0RTGo08M6o`1HE?l0FU?o075<o`2n>?l0[Sco
0<Tfo`34=ol0UT;o0;hho`2k>Ol0WT3o0>L_o`1TD?l0Zcgo0:0oo`1GGOl0kRko0=Dco`1RDOl0`cOo
06a=o`1HI?l0ND[o09A3o`2F@_l0Ldco0?lZo`2S?ol0WT3o08M6o`2S?ol0i33o09]1o`1IJOl0O4Wo
06:Bo`3o:OP0G7Ko07=<o`2`>ol0UT;o08m4o`1PRol0^cWo06:Co`2<A?l0FVgo09i0o`2F@_l0QDKo
06R^o`2N@?l0K4ko08Y5o`29on@0JTko05mAo`1PRol0]S[o0;<ko`1lBOl0JTko09]1o`1lBOl0eC?o
09U1o`2D@ol0eC?o0<@go`3?=?l0nR_o0;<ko`2F@_l0hC3o0<ldo`3o7lD0[Sco06I?o`3N<Ol0Zcgo
07i8o`3o9o80eC?o0818o`3oool0/c_o0;hho`80lbgo02H0Xcoo0;Hjo`2c>ol0oooo09U1o`3c;Ol0
/c_o0:Hno`1HHol0WT3o0858o`2[?Ol0Ldco09i0o`1KLol0_SSo09i0o`3H<_l0jRoo0?<]o`3<=Ol0
HU7o09i0o`3c;Ol0SdCo0:4oo`2K@Ol0`CSo061Ao`2n>?l0SdCo0;hho`3o8]<0lbgo0?lWlP2<A?l0
Ef3o0:<oo`80MD_o01H0iboo0<@go`3?=?l0IIko06Y>o`2^??l0_SSo0<ldo`2^??l0SdCo0=8do`2F
@_l0ccCo0?d[o`3B=?l0P4So0>4`o`1LDol0hC3o0<ldo`36=_l0IToo0P2?A?l03P25A_l0_SSo0<ld
o`3W;ol0_SSo0>4`o`2c>ol0jRoo0=Hco`3?=?l0/3_o0?ooo`2f>_l0nR_o:@3oool001T0oooo00H0
/c_o0?ooo`2X?Ol0oooo08E6o`3oool209U1o`0;0;<ko`2S?ol0OTSo07M:o`2S?ol0Vd7o08M6o`2X
?Ol0H8_o0:<oo`2I@Ol00P2[?Ol03P1HE?l0^cWo0:Hno`1nB?l0_SSo0:<oo`2f>_l0[Sco0:0oo`23
Aol0a3Oo08Y5o`33=ol0QDKo0P2I@Ol09@2c>ol0Eego0:Dno`2I@Ol0Zcgo0=Dco`2<A?l0hC3o0:<o
o`34=ol0[Sco09U1o`2X?Ol0`CSo0;0ko`3o9=d0RTGo08M6o`1MD_l0FU?o075<o`2V?_l0[Sco05ID
o`34=ol0GE;o0;hho`2k>Ol0WT3o0>L_o`1TD?l0Zcgo0:0oo`1GGOl0S4Co0=Dco`3Q<?l00P33=ol0
501HI?l0ND[o09A3o`2F@_l0Ldco0?lZo`2S?ol0WT3o08M6o`2S?ol0i33o09]1o`1IJOl0O4Wo06a>
o`36=_l0G7Ko05]co`2`>ol0obO^0`2?A?l05`1RTol0S4Co05Y]o`2h>_l0UT;o08E6o`1X[_l0_SSo
06a>o`2:AOl0K4ko06Y>o`1ODOl0H8_o0;Hjo`2c>ol0O4Wo06Y>o`2K@Ol0O4Wo0=Dco`2c>ol0U4?o
0080a3Oo0180ccCo0?X[o`2c>ol0UT;o0>4`o`3?=?l0oao50:hlo`1VCol0gS7o0:/mo`1nB?l0jRoo
0=Dco`20B?l0ND[o0<4ho`2n>?l20?<]o`0B0:<oo`2f>_l0IToo0?ooo`2I@Ol0lbgo0;<ko`3?=?l0
F6?o09I2o`21B?l0Zcgo07=<o`3o9nh0Fg?o0;hho`2N@?l0f3;o0P3Z;ol05`3<=Ol0HU7o09i0o`1W
ZOl0SdCo0:4oo`2K@Ol0`CSo061Ao`2n>?l0SdCo0;hho`3o8]<0lbgo0?lWlP2<A?l0Ef3o0:<oo`1c
C?l0MD_o0>L_o`34=ol0ccCo0080IIko01H0[Sco0;hho`2`>ol0[Sco08m4o`3B=?l0Fg?o0<ldo`3m
:ol0obWh0818o`3Q<?l0G5?o0>4`o`3?=?l0aSKo0:Pmo`1giOl0SdCo0<4ho`2n>?l0ccCo0P2n>?l0
2P3Q<?l0/c_o0>X_o`3F<ol0ccCo0;0ko`3H<_l0]S[o0<4ho`2]??lX0?ooo`006`3oool02@2X?Ol0
oooo05eBo`3oool0VD7o0?ooo`2c>ol0Xcoo07i8o`0207=<o`0609]1o`27A_l0Z3go0:Pmo`2S?ol0
YSko0P2[?Ol0201HE?l0^cWo0:Hno`1nB?l0YCko0:<oo`2f>_l0[Sco0`3Q<?l0@02:AOl0`cOo08E6
o`31>?l0^3[o0;<ko`1GGOl0YCko09U1o`2[?Ol0eC?o08a4o`3Q<?l0Xcoo0<@go`2^??l0VD7o0;/i
o`31>?l0/3_o0?lTg@2K@Ol0QdKo05eBo`1JDol0LDco0:Hno`2^??l0EUCo0<@go`1MD_l0_SSo0;/i
o`2N@?l0iboo06A@o`2[?Ol0QDKo0>L_o`2<A?l0eC?o0>4`o`33=ol0YSko05QTo`2?A?l0U4?o09I2
o`2N@?l0ob[o0;<ko`2N@?l0QdKo0:<oo`3T<?l0Vd7o05QDo`1lBOl0K4ko0<Hfo`1LM_l0Fg?o0;0k
o`3o9nh308m4o`0G0;/io`1iB_l0hC3o0>4`o`2F@_l0ND[o0;hho`2C@ol0K4ko08Y5o`1/C_l0Xcoo
05mAo`2?A?l0FFWo0;<ko`1lBOl0JTko0=hao`1lBOl0eC?o0;<ko`2D@ol00P34=ol04P3?=?l0nR_o
0?ooo`2F@_l0hC3o0<ldo`3o7lD0[Sco06I?o`3Z;ol0Zcgo07i8o`3Z;ol0eC?o0818o`1iB_l0`CSo
0;hho`80lbgo0180[Sco0;Hjo`1VCol0oooo0;Hjo`3c;Ol0YSko0<ldo`2V?_l0UT;o0858o`1VCol0
Ldco0?lWkP36=_l0Fg?o09i0o`3H<_l20>X_o`0705YCo`2f>_l0WT3o06NYo`2k>Ol0XCoo09]1o`02
0<4ho`0=0;hho`2?A?l0iboo0?lRd`2n>?l0obOb0;/io`1GH?l0/c_o07=<o`1eBol0P4So0<@go`02
0<ldo`0306FNo`2^??l0_SSo0080/3_o00D0SdCo0=8do`2^??l0ccCo0?d[o`020?lYn00:0>4`o`1L
Dol0]S[o0<ldo`36=_l0Z3go07OUo`2?A?l0TD?o0;hho`80ccCo00/0OTSo0>4`o`2c>ol0obGT0=Hc
o`3?=?l0/3_o0=Pbo`2f>_l0`CSo0:dlo`0X0?ooo`007@3oool01`1MD_l0oooo09U1o`3oool0/c_o
0?ooo`1nB?l00P1cC?l0303oool0QdKo08M6o`2C@ol0Xcoo0:Hno`2[?Ol0WT3o05QDo`25A_l0YSko
07i8o`80YCko03<0]S[o0:hlo`2C@ol0hC3o0:Pmo`2:AOl0`cOo08E6o`31>?l0^3[o0;<ko`1GGOl0
X3oo09U1o`2[?Ol0WT3o08a4o`3Q<?l0Xcoo08Y5o`2^??l0VD7o0;/io`31>?l0/3_o0?lTg@3T<?l0
QdKo066@o`1JDol0a3Oo0:Hno`1VCol0EUCo0<@go`1MD_l0_SSo0;/io`2N@?l0_SSo06A@o`2[?Ol0
QDKo0:0oo`2<A?l0eC?o0;Hjo`33=ol0YSko05QTo`2?A?l00P2F@_l01P2N@?l0ob[o0;<ko`2N@?l0
L4co0:<oo`80Vd7o00P0F5Co07a9o`1/C_l0aSKo07M:o`1KLol0/3_o0?lWkP80SdCo0P2k>Ol01@1i
B_l0hC3o0>4`o`2F@_l0ND[o0080_SSo00l0K4ko08m4o`1/C_l0Xcoo05mAo`2?A?l0FFWo0;Hjo`1l
BOl0JTko0=hao`3?=?l0eC?o0;<ko`2?A?l00P34=ol01`2^??l0nR_o06bko`2F@_l0hC3o0<ldo`3o
ool00P2^??l01@3Z;ol0oooo07i8o`3Z;ol0XCoo0080ND[o01l0`CSo09I2o`3c;Ol0lbgo0:hlo`2f
>_l0IToo0?ooo`2f>_l0lbgo0:Hno`2f>_l0YSko09I2o`21B?l0IToo0;Tio`3o9nh0aSKo05]co`2N
@?l0VD7o0:Dno`3Z;ol0FU?o0;Hjo`2N@?l0IjWo0;/io`2Q?ol0Vd7o0080`CSo00H0_SSo08m4o`3W
;ol0ob;C0;hho`3o9o8209]1o`0:0;<ko`1cC?l0P4So0818o`2n>?l0Zcgo0<ldo`1UW_l0dSCo0;hh
o`80/3_o00D0SdCo0=8do`2^??l0ccCo0?d[o`020?lYn00I0>4`o`1LDol0]S[o0?<]o`36=_l0Z3go
07OUo`2D@ol0TD?o0<4ho`2c>ol0ccCo0;hho`3Q<?l0/c_o0?lUi01jBOl0ccCo0;0ko`3H<_l0]S[o
0<4ho`3j:ol0oooo0;<ko`0V0?ooo`007`3oool02031>?l0Vd7o0;<ko`3oool0OTSo0?ooo`1cC?l0
oooo0P27A_l20:Pmo`0c0:Hno`1FF_l0X3oo0=Pbo`25A_l0YSko0;hho`2U?_l0QDKo0;Hjo`2^??l0
Td?o0>4`o`2X?Ol0RTGo0<`eo`25A_l0`CSo0;Pjo`2i>Ol0Eego0:0oo`2I@Ol0Zcgo09i0o`2<A?l0
^cWo0:<oo`2:AOl0[Sco0:<oo`2k>Ol0dSCo0;0ko`3o9=d0i33o08M6o`1QT?l0FU?o0<4ho`2V?_l0
i33o05IDo`34=ol0GE;o0;hho`1nB?l0WT3o0;hho`1TD?l0S4Co0080QDKo00L0S4Co0=Dco`3Q<?l0
hC3o0:Hno`2F@_l0SdCo0080UT;o00H0WT3o0?lZo`2c>ol0WT3o071<o`2S?ol209]1o`0805QDo`1l
BOl0K4ko0<Hfo`1gB_l0Fg?o0?lRd`3o9nh208m4o`80^cWo00D0ccCo0>4`o`3Q<?l0UT;o07U:o`02
0;hho`0?06a>o`2?A?l0QdKo0:<oo`1ODOl0SdCo08M6o`2f>_l0O4Wo05EGo`3N<Ol0ccCo0=Dco`2c
>ol0SdCo0080a3Oo00L0[Sco0?X[o`1/^ol0UT;o0:/mo`3?=?l0dSCo0080[Sco00T0jRoo0?ooo`1n
B?l0jRoo0:4oo`2c>ol0ND[o0<4ho`2F@_l00P3c;Ol08`2^??l0f3;o05elo`3oool0]S[o0?<]o`2V
?_l0]S[o0:Hno`2F@_l0PDSo06I?o`2i>Ol0obO^0<Hfo`1KLol0_SSo09U1o`2U?_l0jRoo0=Pbo`2f
>_l0/3_o06NYo`2k>Ol0/c_o09]1o`1^COl0`CSo0;hho`2?A?l0iboo0?lRd`2n>?l0obOb0080Vd7o
00X0/c_o07=<o`20B?l0]S[o0;hho`2[?Ol0ccCo0<4ho`3B=?l0_SSo0P2`>ol01@3E<ol0dSCo0:hl
o`2^??l0oB_o0080obWh00h0hC3o05mAo`2f>_l0lbgo0<Hfo`2X?Ol0lbgo0?l?J@2A@ol0`CSo0;<k
o`3?=?l0_SSo07i8o`80/c_o00T0NTWo0<ldo`2`>ol0f3;o0;Hjo`31>?l0nR_o0:dlo`2c>ol09P3o
ool001l0oooo01T0`CSo09]1o`2c>ol0oooo07i8o`2S?ol0Ge7o0?ooo`27A_l0H8_o0:Pmo`3oool0
YSko08=7o`2P?ol0f3;o08E6o`2V?_l0_SSo0:Dno`25A_l0]S[o0>4`o`2C@ol0PdOo0080Z3go02<0
o`0008E6o`2k>Ol0^3[o0;Tio`1GGOl0[Sco09U1o`2S?ol0WT3o08a4o`2k>Ol0VD7o08Y5o`2^??l0
]S[o0;/io`3B=?l0/3_o0?lTg@3T<?l0QdKo066@o`36=_l0`CSo0:Hno`3T<?l0EUCo0;hho`1MD_l0
_SSo07i8o`1JDol0_SSo06A@o`0208a4o`0@0:0oo`2<A?l0WT3o0>4`o`2k>Ol0YSko09I2o`2?A?l0
U4?o0=Pbo`2N@?l0X3oo0;<ko`36=_l0L4co09=3o`80Vd7o00X0F5Co0<`eo`1/C_l0aSKo07M:o`3o
8mX0ob;C0?lWkP1gB_l0SdCo0P2k>Ol01@3?=?l0hC3o0;Pjo`3`;Ol0ND[o0080_SSo01P0obOb08m4
o`1/C_l0Xcoo0;Tio`2?A?l0IjKo0;Hjo`1lBOl0EEOo0=hao`3?=?l0eC?o0;<ko`2?A?l0TD?o08m4
o`2^??l0QDKo0<<go`1MO?l0Zcgo0:Hno`3B=?l20:hlo`090>X_o`3oool0OTSo0:Dno`2Q?ol0oooo
07U:o`27A_l0UT;o0080Td?o02<0[Sco0=Pbo`1MO?l0oooo0;Hjo`36=_l0YSko0;Hjo`2V?_l0^3[o
0858o`2U?_l0^CWo0?lWkP36=_l0jRoo0;hho`2I@Ol0YCko08M6o`3H<_l0]S[o0;0ko`1WZOl0^cWo
0;<ko`3H<_l0SdCo0<4ho`1JDol0SdCo0;/io`3W;ol0UT;o0?lWlP0209]1o`0A0;<ko`1cC?l0P4So
0:hlo`2n>?l0Zcgo0:Dno`3oool0dSCo0;Hjo`2P?ol0/3_o0=Dco`3B=?l0JDoo0:hlo`3m:ol00P3o
:OP03`1ODOl0_SSo0;Hjo`3c;Ol0OTSo0:Pmo`1^COl0o`mY09A3o`31>?l0/c_o0:/mo`2n>?l0OTSo
06]>o`020?lUi00907Y9o`2`>ol0f3;o0;Hjo`31>?l0nR_o0:dlo`2c>ol0aSKo02D0oooo000O0?oo
o`0`0<4ho`2K@Ol0oooo08a4o`1nB?l0Xcoo05mAo`2F@_l0QdKo062;o`2X?Ol0L4co0:Hno`23Aol0
X3oo0=Pbo`2I@Ol0YSko0;hho`39=_l0obO_0;Hjo`3Q<?l0Td?o0<@go`2X?Ol0c3Go0?l00025A_l0
^cWo0;Pjo`2i>Ol0Eego0953o`2I@Ol0Xcoo09i0o`3<=Ol0^cWo09U1o`2:AOl0[Sco0;Hjo`2<A?l0
dSCo0;0ko`3o9=d0i33o0P2S?ol00`34=ol0`CSo0:Hno`020>@`o`0U0;hho`1MD_l0Xcoo07i8o`1J
Dol0_SSo09i0o`2<A?l0iboo0:0oo`2<A?l0]S[o0>4`o`2k>Ol0YSko09I2o`2?A?l0U4?o0=Pbo`2X
?Ol0X3oo0;<ko`36=_l0[Cco09=3o`2K@Ol0S4Co05QDo`3<=Ol0K4ko0<Hfo`1gB_l0ob?J0?lRd`3o
9nh0Md[o06bko`020;/io`0b0<ldo`3Q<?l0^3[o0?0]o`2I@Ol0_SSo09=3o`3o9o80SdCo06a>o`2S
?ol0^CWo08m4o`1WY_l0]S[o07a9o`1EEol0gS7o0<ldo`3E<ol0PdOo08m4o`2A@ol0SdCo0:Hno`25
A_l0`cOo05elo`2[?Ol0YSko0?lVj`3j:ol0[Sco0;hho`3oool0Xcoo0:Dno`1gB_l0oooo07U:o`27
A_l0YSko06i=o`2C@ol0ccCo0=Pbo`1MO?l0oooo0;Hjo`36=_l20;Hjo`0L0:Hno`2h>_l0gS7o0:Dn
o`2i>Ol0obO^0<Hfo`1KLol0_SSo08m4o`2U?_l0QdKo0=Pbo`2f>_l0/3_o0;hho`1WZOl0/c_o0=Pb
o`2?A?l0`CSo05YCo`2[?Ol0^cWo0>L_o`2F@_l0obOb0;/io`80Vd7o0100Ldco0818o`2^??l0_SSo
0:/mo`2U?_l0`CSo0=8do`2f>_l0X3oo0;0ko`3E<ol0obKX06U?o`2^??l0mbco0`3o:OP0101ODOl0
]S[o0?<]o`1nB?l206i=o`0=0?l?J@2D@ol0`CSo0;<ko`2[?Ol0EUCo07i8o`1[C_l0obCN0?lUi01j
BOl0lbgo0=Pbo`020;Hjo`050?X[o`2]??l0/c_o0<Hfo`3`;Ol0903oool00200oooo0P2K@Ol06P2<
A?l0oooo0:<oo`1ODOl0UT;o05IDo`1PRol0Td?o071<o`2V?_l0PdOo0:0oo`3H<_l0VD7o0<Hfo`2n
>?l0bCKo0?lWk`2f>_l0hC3o09=3o`2I@Ol0Z3go0<`eo`3o0000`CSo0P2A@ol06@2i>Ol0eC?o0953
o`2N@?l0Xcoo09i0o`3<=Ol0^cWo09U1o`2:AOl0Xcoo0;Hjo`2<A?l0dSCo0;0ko`2K@Ol0i33o0:Hn
o`2S?ol0a3Oo0<4ho`2f>_l0i33o07?Fo`2n>?l00P2S?ol08P1JKOl0FU?o0;hho`2N@?l0S4Co0>L_
o`2P?ol0a3Oo0;Hjo`3H<_l0^cWo0:Hno`2F@_l0SdCo06a>o`3H<_l0Z3go0:0oo`2c>ol0aSKo0:dl
o`2C@ol0Vd7o08a4o`2C@ol0c3Go06a>o`3W;ol0Md[o0?lSfP3o8]<0obO^07M:o`1/^ol20;/io`0b
0<ldo`3Q<?l0^3[o0?0]o`2I@Ol0_SSo09=3o`3o9o80K4ko08M6o`2S?ol0^CWo08m4o`1WY_l0]S[o
0858o`1EEol0_SSo0<ldo`3E<ol0PdOo0;Hjo`2A@ol0SdCo0:Hno`30ok80`cOo05elo`2?A?l0YSko
0?lVj`3j:ol0[Sco0;hho`3oool0Xcoo0:Dno`1gB_l0oooo0;<ko`27A_l0YSko06i=o`2C@ol0ccCo
0=Pbo`2?A?l0jRoo0:hlo`36=_l20;Hjo`0C0<ldo`2h>_l0gS7o0:Dno`2i>Ol0gS7o0?lK[`1KLol0
_SSo08m4o`2U?_l0QdKo0=Pbo`36=_l0/3_o0;hho`1WZOl0/c_o0=Pbo`0208m4o`0706a>o`2[?Ol0
^cWo0>L_o`2F@_l0obOb0;/io`0209]1o`0G0:/mo`20B?l0]S[o0:hlo`2[?Ol0YCko0<4ho`3B=?l0
]S[o0:0oo`3];_l0eC?o0?lVj01YCol0Fg?o0?L/o`2V?_l0[Sco0?lYn01ODOl0_SSo0?<]o`1nB?l0
0P1^COl0503o3fT0U4?o0:Pmo`2c>ol0Zcgo05IDo`2A@ol0Jdko0?lTgP3o9N@0NTWo0?<]o`3H<_l0
l2go0;Hjo`3j:ol0[Cco0;<ko`36=_l0l2go903oool00280oooo00d0S4Co0?ooo`2S?ol0oooo09I2
o`1FE?l0H8_o09=3o`1`C?l0IIko08E6o`2P?ol0QDKo0080VD7o00/0_SSo0<Tfo`3o9nl0Md[o0>4`
o`2C@ol0VD7o0818o`3<=Ol0o`000<4ho`020953o`0A0;Tio`2^??l0TD?o09i0o`2S?ol0WT3o0<`e
o`2k>Ol0l2go08Y5o`2S?ol0]S[o0>@`o`3B=?l0gS7o09]1o`3T<?l00P2S?ol01P34=ol0`CSo0;Hj
o`3T<?l0LmKo0;hho`80Xcoo00P0FVgo05YCo`2n>?l0WT3o0;hho`3W;ol0X3oo0<@go`80]S[o01P0
^cWo0:/mo`2F@_l0SdCo06a>o`3H<_l0Z3go0:0oo`2?A?l0aSKo0:dlo`2C@ol0X3oo08a4o`2C@ol0
c3Go06a>o`3W;ol0F6?o0?lSfP3o8]<0obO^07M:o`1/^ol20;/io`0M0<ldo`2c>ol0^3[o0?0]o`2I
@Ol0_SSo09=3o`3o9o80K4ko08M6o`2S?ol0^CWo08M6o`1WY_l0]S[o0858o`1VCol0_SSo0<ldo`2^
??l0PdOo0;Hjo`2A@ol0RdGo0:Hno`30ok80`cOo0:Pmo`2?A?l00P3o9^/03`3j:ol0JkSo0;hho`3o
ool0Xcoo09i0o`1gB_l0oooo0;<ko`27A_l0YSko06i=o`1nB?l0ccCo06A@o`020>X_o`0C0:hlo`3o
9o80]S[o0;Hjo`3?=?l0^3[o0=hao`2U?_l0IToo0=hao`3o6jl0jRoo0;hho`2?A?l0Vd7o08M6o`3H
<_l0aSKo0;0ko`020;hho`0R0<`eo`3H<_l0KTgo08m4o`1/C_l0Zcgo0;/io`1VCol0UT;o0:Pmo`2k
>Ol0_SSo09]1o`2[?Ol0Ldco0;Hjo`2^??l0QdKo0:Dno`31>?l0/3_o0;Hjo`2P?ol0kBko0=Dco`3o
9^P0JDoo05]co`3g;?l0YSko0:hlo`3o:OP0Ge7o0;hho`80lbgo0P1^COl05@3o3fT0U4?o0:Pmo`1J
Kol0Zcgo05IDo`2A@ol0QDKo0?lTgP2U?_l0WT3o0?<]o`1XCol0l2go0;Hjo`31>?l0[Cco0;<ko`36
=_l0l2go05afo`0S0?ooo`00903oool0<02S?ol0oooo09I2o`3oool0H8_o0?ooo`1`C?l0oooo09i0
o`2P?ol0QDKo0?lVj02P?ol0_SSo08E6o`3o9nl0Vd7o0>4`o`34=ol0VD7o0818o`3<=Ol0o`000<4h
o`2k>Ol0eC?o0;Tio`2^??l0TD?o09A3o`2S?ol0`CSo0<`eo`2k>Ol0Xcoo0?0]o`2S?ol0]S[o0;0k
o`3B=?l0gS7o09]1o`3T<?l0Xcoo0<Hfo`34=ol0`CSo0;Hjo`80i33o00H0_SSo0:<oo`2S?ol0^cWo
05YCo`1iB_l20;hho`0S0>L_o`2P?ol0a3Oo09i0o`3H<_l0^cWo0:/mo`2F@_l0bCKo06a>o`2<A?l0
Z3go0:0oo`2?A?l0aSKo0:dlo`2C@ol0X3oo08a4o`2C@ol0c3Go09I2o`3W;ol0F6?o0?lSfP3o8]<0
f3;o09I2o`1/^ol0^cWo07U:o`3?=?l0/c_o0;Pjo`3`;Ol00P2I@Ol05`2C@ol0obOb06a>o`27A_l0
eC?o0;Tio`27A_l0IjKo0;Hjo`21B?l0IToo0;hho`3?=?l0[Sco05EGo`2f>_l0TD?o08]5o`2V?_l0
`?nb0<<go`2X?Ol0SdCo0080obK[00l0nR_o06i=o`3Z;ol0Fe?o0:<oo`2N@?l0UT;o0?ooo`2c>ol0
FFWo0:Hno`2?A?l0OTSo0<ldo`1TD?l00P3Z;ol04@2^??l0obOb0;Hjo`2f>_l0ccCo09I2o`3N<Ol0
YCko06I?o`3N<Ol0oa^_0>X_o`1KLol0SdCo09]1o`27A_l0f3;o0080aSKo0P2n>?l04`3<=Ol0f3;o
06i=o`2?A?l0K4ko0:/mo`2k>Ol0aSKo06I?o`2X?Ol0^cWo0?<]o`2K@Ol0Zcgo07=<o`2f>_l0[Sco
08M6o`2U?_l00P31>?l09`2`>ol0X3oo0>d^o`2?A?l0obKX06U?o`1KLol0mbco0:Hno`2^??l0]S[o
0=Pbo`2n>?l0lbgo07i8o`2[?Ol0KTgo0?l?J@2D@ol0Z3go0?lReP2[?Ol0EUCo0953o`25A_l0obCN
0:Dno`2N@?l0lbgo06Q?o`3`;Ol0JTko0<4ho`3j:ol0`CSo0;<ko`3`;Ol0G7Ko0:hlo`0R0?ooo`00
903oool06@2S?ol0oooo09I2o`3oool0aSKo0?ooo`1`C?l0oooo09i0o`3oool0QDKo0?lVj02C@ol0
_SSo08E6o`3o9nl0WT3o0>4`o`34=ol0VD7o0:/mo`3<=Ol0o`000<4ho`2k>Ol00P3E<ol01`2^??l0
TD?o0:Pmo`2S?ol0`CSo0<`eo`2X?Ol00P3`;Ol0302S?ol0]S[o0>@`o`3B=?l0gS7o09]1o`2^??l0
Xcoo0<Hfo`34=ol0Vd7o0;Hjo`80c3Go00H0_SSo0:<oo`2S?ol0^cWo0;0ko`1iB_l20;hho`0S0>L_
o`2F@_l0a3Oo09i0o`3H<_l0^cWo0:/mo`2F@_l0bCKo0>X_o`2<A?l0Z3go07M:o`2?A?l0JTko0:dl
o`2C@ol0X3oo0:hlo`2C@ol0c3Go09I2o`3W;ol0F6?o0?lSfP3o8]<0f3;o09I2o`1/^ol0^cWo07U:
o`3m:ol0/c_o0;Pjo`3H<_l00P2n>?l05`2C@ol0obOb0<Hfo`27A_l0eC?o05MPo`27A_l0IjKo05EG
o`21B?l0IToo0;hho`3?=?l0[Sco05EGo`2f>_l0TD?o08]5o`1ZC_l0`?nb0<<go`2X?Ol0SdCo0080
obK[00l0nR_o06i=o`3Z;ol0Fe?o0:<oo`2N@?l0UT;o0?ooo`2c>ol0FFWo0:Hno`2?A?l0OTSo0?lW
lP2f>_l00P3Z;ol03`2^??l0obOb0<Tfo`39=_l0ccCo09I2o`3N<Ol0WT3o06I?o`1ND_l0oa^_07M:
o`1KLol0Q?oc09]1o`0208M6o`80aSKo0P2n>?l02`3<=Ol0]S[o06i=o`27A_l0K4ko07i8o`2k>Ol0
aSKo06I?o`2X?Ol0^cWo0080lbgo00X0Zcgo07=<o`2f>_l0[Sco08M6o`2?A?l0QdKo0<4ho`2`>ol0
[Sco0P3];_l00`3o9^P0Zcgo05]co`020<Hfo`0:0:hlo`2f>_l0f3;o0;hho`3K<_l0EEOo0:/mo`1^
COl0o`mY09A3o`80Z3go0180/S_o05MNo`2A@ol0QDKo0?lTgP2U?_l0WT3o0?<]o`1XCol0l2go06Y>
o`31>?l0nR_o0:dlo`2c>ol0l2go05afo`2^??lR0?ooo`009P3oool0202F@_l0aSKo0<Hfo`3oool0
L4co08=7o`2N@?l0oooo0P3o9^P03@2C@ol0_SSo08E6o`3o9nl0`CSo0>4`o`34=ol0VD7o0:/mo`3<
=Ol0o`000<4ho`2K@Ol00P3E<ol05@2^??l0TD?o0<@go`34=ol0`CSo0<`eo`2X?Ol0l2go0<Tfo`2S
?ol0SdCo0>@`o`2D@ol0gS7o09]1o`2^??l0YSko0<Hfo`34=ol0Vd7o0;Hjo`020<`eo`0[08E6o`2S
?ol0Xcoo0;/io`2N@?l0ND[o09i0o`2K@Ol0iboo09I2o`34=ol0/c_o0=Pbo`36=_l0Zcgo09I2o`39
=_l0jRoo08a4o`2X?Ol0Md[o07U:o`1ZC_l0[Cco09i0o`2P?ol0[Sco09=3o`3<=Ol0UT;o0>L_o`1H
Hol0ob?J08m4o`3H<_l0UT;o08m4o`20B?l0ND[o0?d[o`2c>ol0^3[o0=Pbo`020;hho`0G09=3o`2^
??l0aSKo08M6o`3E<ol0Ef3o08M6o`1WY_l0EEOo07=<o`1VCol0_SSo0<ldo`2^??l0EEOo0;Hjo`1g
B_l0RdGo06Y>o`30ok80`cOo0:Pmo`3j:ol00P3o9^/04`2?A?l0KTgo0>X_o`3Q<?l0XCoo09i0o`2F
@_l0Ldco0;<ko`1IJOl0iboo08m4o`1nB?l0obOb0;Hjo`2?A?l0jRoo0;hho`3o9o800P39=_l01`3?
=?l0UT;o0:hlo`2N@?l0YCko05iBo`3o6jl00P3Z;ol01P3oool0Vd7o07E;o`27A_l0Zcgo0<Hfo`80
_SSo00/0c3Go0;Hjo`1^COl0YCko06a>o`1nB?l0^cWo0<Hfo`1VCol0QdKo0;/io`020?<]o`090<`e
o`1cC?l0]S[o0>X_o`27A_l0SdCo08M6o`31>?l0/3_o0080[Sco00@0kBko08m4o`2[?Ol0f3;o0P36
=_l07`2^??l0]S[o0=Pbo`3N<Ol0fc;o05EGo`2[?Ol0`CSo0?<]o`37=_l0bCKo0:Pmo`3o8]H0/S_o
0953o`25A_l0obCN0:Dno`2N@?l0eC?o08m4o`3`;Ol0JTko0953o`3j:ol0[Cco0;<ko`36=_l0G7Ko
0:hlo`23Aol08@3oool002L0oooo00L0aSKo0?ooo`2F@_l0UT;o08=7o`25A_l0oooo0080obKX00d0
Td?o069Ao`25A_l0obO_0<4ho`3B=?l0a3Oo09U1o`2[?Ol0Z3go0?l00031>?l0Vd7o0080eC?o00<0
[Sco09A3o`34=ol00P31>?l0403<=Ol0Z3go0?0]o`39=_l0Xcoo08m4o`3T<?l0U4?o0=hao`3E<ol0
[Sco0:Hno`36=_l0a3Oo09]1o`2<A?l20<`eo`0[08E6o`2S?ol0[Cco0;/io`2N@?l0ND[o09i0o`2K
@Ol0iboo09I2o`34=ol0/c_o0=Pbo`36=_l0Zcgo0:Dno`39=_l0jRoo08a4o`2X?Ol0Md[o07U:o`1Z
C_l0[Cco09i0o`2P?ol0[Sco09=3o`2^??l0UT;o07i8o`1HHol0ob?J08m4o`3H<_l0UT;o08m4o`20
B?l0Ge7o0?d[o`2c>ol0Xcoo0=Pbo`020;hho`0e09i0o`2^??l0aSKo08M6o`3E<ol0Ef3o07Y9o`1W
Y_l0_SSo07=<o`2^??l0_SSo0<ldo`2c>ol0UT;o0;Hjo`1gB_l0VD7o06Y>o`20B?l0K;_o0:Pmo`3j
:ol0[Sco0?lVj`2?A?l0KTgo0>X_o`3Q<?l0XCoo0?lVj`2F@_l0Ldco0<`eo`3c;Ol0iboo08m4o`1^
COl0obOb0;Hjo`2?A?l0jRoo0;hho`3o9o80_SSo0<Tfo`1JDol0UT;o0:hlo`2N@?l0YCko0;0ko`3o
6jl00P3Z;ol01@2^??l0W47o07E;o`27A_l0Zcgo0080aSKo0P2n>?l01P2f>_l0KTgo0:Dno`2U?_l0
OTSo0?<]o`80aSKo00L0QdKo05QSo`3c;Ol0lbgo0<`eo`3?=?l0]S[o0080jRoo00@0SdCo08M6o`1J
Dol0/3_o0P2^??l0103];_l0SdCo0:/mo`3H<_l30<Hfo`0O0;Hjo`3H<_l0gS7o0=/bo`1EEol0Zcgo
0<4ho`3c;Ol0acKo0<Tfo`2X?Ol0ob;F0;8ko`2A@ol0QDKo0;Hjo`1jBOl0WT3o0=Dco`2?A?l0l2go
06Y>o`2A@ol0nR_o0:dlo`2c>ol0aSKo0?0]o`2^??l0PdOo0:Pmo`0P0?ooo`009`3oool01P36=_l0
oooo09I2o`3oool0PdOo08E6o`80RTGo00X0aSKo0:0oo`2:AOl0QDKo09]1o`31>?l0dSCo0<@go`1K
Lol0Zcgo0P2X?Ol01P31>?l0Vd7o0;Pjo`1MD_l0[Sco09A3o`80a3Oo03h0`CSo0;/io`2X?Ol0Xcoo
0<Tfo`1GGOl0SdCo0;0ko`2D@ol0gS7o0=Dco`2^??l0Xcoo0<Hfo`1nB?l0Vd7o08a4o`3<=Ol0ccCo
08E6o`2S?ol0[Cco0;/io`2N@?l0ND[o06Y>o`2K@Ol0YCko09I2o`34=ol0/c_o0953o`36=_l0Zcgo
0:Dno`39=_l0jRoo08a4o`31>?l0Md[o07U:o`1ZC_l0[Cco09i0o`3<=Ol0[Sco09=3o`2^??l0^cWo
07i8o`1HHol0ob?J08m4o`3H<_l0UT;o08m4o`20B?l0Ge7o0?d[o`2c>ol0Xcoo0?lUi080_SSo03D0
WT3o0:hlo`36=_l0QdKo0=Dco`36=_l0NTWo06NVo`2n>?l0Ldco0:hlo`2n>?l0ccCo0;<ko`2F@_l0
]S[o07M:o`2I@Ol0jRoo0818o`1FF_l0ND[o0?X[o`2^??l0obK[08m4o`1^COl0jRoo0>4`o`2Q?ol0
obK[09I2o`1cC?l0c3Go0?<]o`3W;ol0oooo06i=o`3o9o80]S[o0;<ko`3Z;ol0_SSo0953o`2n>?l0
bCKo05YCo`1`C?l0[Sco0818o`2U?_l0/3_o08a4o`020>X_o`060:hlo`2L@Ol0MD_o06Y>o`2[?Ol0
bCKo0`2n>?l03`3?=?l0KTgo06i=o`2U?_l0OTSo0?<]o`36=_l0hC3o08M6o`1HHol0_SSo0?<]o`3<
=Ol0ccCo0;Hjo`020>X_o`040?<]o`27A_l0FU?o09I2o`80[Sco00D0ccCo0;Tio`2[?Ol0f3;o08e4
o`020<Hfo`030<ldo`3H<_l0gS7o0080SdCo00X0Zcgo0<4ho`3c;Ol0acKo0<Tfo`2?A?l0ob;F0;8k
o`1GG_l0QDKo0P2f>_l02P2N@?l0eC?o08m4o`3`;Ol0JTko0953o`36=_l0[Cco0;<ko`36=_l205af
o`0308=7o`2X?Ol0oooo01l0oooo000Y0?ooo`0809I2o`3oool0PdOo0?ooo`2:AOl0oooo0<Hfo`2P
?ol208Y5o`0609]1o`2N@?l0_SSo0<@go`1KLol0Zcgo0P2X?Ol00`2k>Ol0Vd7o0;Pjo`020=Dco`0Y
09A3o`2X?Ol0`CSo0<4ho`2k>Ol0Z3go08=7o`39=_l0Eego08m4o`2`>ol0U4?o0=hao`3E<ol0[Sco
0:<oo`36=_l0OTSo09]1o`2f>_l0c3Go0<ldo`25A_l0Xcoo0:dlo`2`>ol0WT3o07U:o`1ZC_l0Vd7o
0:Dno`2F@_l0X3oo0;<ko`2A@ol0aSKo0<`eo`2U?_l0]S[o0>X_o`2<A?l00P31>?l05P1iB_l0JTko
0818o`2N@?l0c3Go0:hlo`39=_l0[Sco0;/io`1nB?l0aSKo06I?o`2?A?l0f3;o09I2o`2?A?l0Ldco
05mAo`3m:ol0[Sco0:<oo`3o9N@20;hho`0O09i0o`2D@ol0aSKo08M6o`3E<ol0aSKo07Y9o`1cC?l0
_SSo08m4o`2^??l0_SSo0<ldo`2c>ol0OTSo0;Hjo`20B?l0VD7o0>X_o`20B?l0EU[o07U:o`3j:ol0
[Sco0=8do`2f>_l0KTgo0?ooo`3Q<?l0ccCo0?lVj`0207=<o`0;0<`eo`3c;Ol0iboo0?ooo`1^COl0
obOb0;Hjo`2^??l0SdCo0;hho`2A@ol00P2n>?l0602[?Ol0L4co0:Dno`20B?l0YCko0;0ko`2<A?l0
Md[o0>X_o`2^??l0W47o07E;o`1ZC_l0Zcgo0<Tfo`3Z;ol0NTWo0;hho`3?=?l0P4So08M6o`2U?_l0
QdKo0?<]o`80aSKo00`0hC3o05QSo`2n>?l0lbgo0<`eo`3?=?l0]S[o0?lOa@3Z;ol0lbgo08M6o`1J
Dol209I2o`060:hlo`3?=?l0^CWo0:/mo`3H<_l0SDCo0P36=_l06`3?=?l0f3;o0=hao`3N<Ol0SdCo
0:/mo`31>?l0WT3o0<Lfo`39=_l0SdCo0?lReP2b>ol0Eeko0?lVj`1EEol0]S[o07Y9o`3E<ol0SdCo
0;Hjo`3H<_l0TD?o0<Hfo`1/C_l0/c_o0<Hfo`0205afo`0308=7o`2X?Ol0WT3o01l0oooo000[0?oo
o`0G08=7o`3oool0RTGo0?ooo`36=_l0_SSo08Y5o`3oool0Vd7o09i0o`2n>?l0a3Oo05]co`2[?Ol0
`CSo0:Pmo`2k>Ol0Vd7o075<o`3E<ol0]S[o09A3o`2X?Ol00P31>?l0602k>Ol0Z3go08=7o`39=_l0
Eego08m4o`3E<ol0U4?o0<4ho`3E<ol0[Sco0:<oo`1eBol0OTSo09]1o`2f>_l0c3Go0<ldo`25A_l0
/c_o0:dlo`2`>ol0WT3o05mAo`80JTko00/0YCko09I2o`2P?ol0/C_o0953o`36=_l0c3Go0:Dno`2f
>_l0jRoo0:hlo`020<4ho`1407U:o`2c>ol0P4So0953o`3<=Ol0[Sco0<Tfo`2^??l0^cWo07i8o`36
=_l0IToo08m4o`3H<_l0jRoo08m4o`1cC?l0Ge7o0?d[o`2^??l0Fe?o0?lUi02n>?l0QDKo09i0o`2D
@ol0aSKo0<`eo`3E<ol0aSKo07Y9o`1cC?l0_SSo07U:o`2^??l0_SSo0;Hjo`2c>ol0OTSo0;Hjo`20
B?l0VD7o0>X_o`20B?l0EU[o07U:o`3j:ol0[Sco0=8do`2f>_l0Ldco05MPo`3Q<?l0ccCo0?lVj`3o
ool0Ldco0<`eo`3c;Ol0QdKo0?ooo`2?A?l0aSKo0?lYn02^??l0SdCo09I2o`2A@ol20;hho`0H0:/m
o`1`C?l0YCko0818o`2U?_l0/3_o0<Hfo`1gB_l0jRoo0:hlo`2U?_l0MD_o06Y>o`3B=?l0bCKo0>X_
o`1jBOl0_SSo0<ldo`20B?l0QdKo0:Dno`27A_l0lbgo0P36=_l0303Q<?l0YSko0;hho`21B?l0c3Go
0<ldo`36=_l0oao50>X_o`3c;Ol0f3;o05YCo`80UT;o02T0[Sco0<ldo`2i>Ol0ODWo0=Pbo`2=A?l0
[Sco0<Hfo`3?=?l0gS7o0>L_o`3N<Ol0SdCo0:/mo`31>?l0WT3o075<o`39=_l0SdCo05Y_o`1hj?l0
oa1^0?lVj`1EEol0]S[o07Y9o`3E<ol0SdCo0;Hjo`3H<_l0TD?o0<Hfo`1/C_l0`CSo0<Hfo`3`;Ol0
G7Ko0:hlo`2X?Ol0WT3o08e4o`0N0?ooo`00:`3oool07`23Aol0oooo0?lYn03oool0aSKo0;hho`2:
AOl0K4ko09]1o`3B=?l0_SSo08Y5o`1KLol0Zcgo0<4ho`1gB_l0^cWo09]1o`1aC?l0eC?o0;Hjo`2D
@ol0^cWo0<4ho`1lBOl0^cWo0:Pmo`23Aol0RTGo05MMo`2?A?l00P3E<ol02`31>?l0eC?o08E6o`2S
?ol0MD_o07i8o`3T<?l0]S[o0:<oo`3?=?l0WT3o0080/c_o0100/3_o09i0o`1nB?l0OTSo09]1o`2U
?_l0JkSo0:0oo`2a>ol0TD?o0<Hfo`3<=Ol0[Sco0;Hjo`3Z;ol0[Sco0P31>?l0A01iB_l0/c_o0818
o`2A@ol0c3Go0>@`o`39=_l0[Sco0;/io`1nB?l0aSKo06I?o`2?A?l0f3;o0>X_o`2?A?l0Ldco05mA
o`3m:ol0[Sco05]Co`3o9N@0_SSo08E6o`20B?l0U4?o0<Hfo`3<=Ol0eC?o0<Hfo`1jBOl0Ldco0;hh
o`1iB_l0[Sco0;hho`2f>_l0OTSo09I2o`2f>_l0P4So08M6o`3Z;ol0P4So05IJo`1iB_l0L4co0:hl
o`3B=?l0]S[o07=<o`1MOol0hC3o0<ldo`3o9^/0oooo07=<o`2K@Ol0lbgo08M6o`2]??l0SdCo0<Hf
o`3o:OP0[Sco0;<ko`2F@_l0^cWo0P2n>?l0402[?Ol0obGX0:Dno`20B?l0WT3o0;0ko`36=_l0Md[o
0>X_o`2^??l0YCko07=<o`1ZC_l0dSCo0<Tfo`3Z;ol207Y9o`060<ldo`20B?l0QdKo0=Dco`27A_l0
WT3o0P36=_l00`3Q<?l0YSko0;hho`020858o`0;0<ldo`36=_l0oao50>X_o`3c;Ol0f3;o0;hho`34
=ol0UT;o0<Tfo`3?=?l00P2i>Ol00`3H<_l0SDCo0:hlo`020<ldo`0Q0=hao`3W;ol0gS7o08m4o`36
=_l0`CSo09i0o`1aC?l0bCKo08m4o`1JKol0N>So09U1o`3o9^/0EEOo05Y_o`1jBOl0Ef3o08m4o`2f
>_l0f3;o09i0o`36=_l0K4ko0<4ho`36=_l0l2go05afo`2^??l0PdOo09i0o`2=A?l0YSko01d0oooo
000]0?ooo`0^0?lYn02]??l0aSKo0;hho`1RDOl0WT3o09]1o`3B=?l0_SSo07i8o`1KLol0Zcgo0<4h
o`1gB_l0^cWo0<Hfo`1aC?l0GE;o0;Hjo`2D@ol0^cWo0<4ho`1lBOl0^cWo0<Hfo`23Aol0RTGo05MM
o`1ODOl0eC?o09U1o`31>?l0eC?o08E6o`2:AOl0MD_o07i8o`2c>ol0]S[o0:<oo`3?=?l0WT3o0;<k
o`2P?ol0/3_o09i0o`80OTSo0100Vd7o0:Dno`2h>_l0^3[o0;4ko`2A@ol0UT;o0<`eo`2^??l0]S[o
0>X_o`2^??l0a3Oo0<4ho`3o9^P0/c_o0P2A@ol01@3<=Ol0i33o0<Tfo`2^??l0^cWo0080aSKo02@0
IToo08m4o`3H<_l0jRoo09i0o`1cC?l0Xcoo05IJo`2^??l0Fe?o0?lUi01nB?l0QDKo0818o`2D@ol0
aSKo0<`eo`2D@ol0aSKo07Y9o`1cC?l0_SSo07U:o`2^??l0L4co0;Hjo`1nB?l0UT;o0;hho`20B?l0
QdKo0>X_o`20B?l0EU[o07M:o`1`C?l20:hlo`0C0;Hjo`1cC?l0GGoo0>4`o`3?=?l0GX;o0?ooo`1J
Dol0Vd7o0?<]o`27A_l0[Cco08m4o`36=_l0obWh0:hlo`2c>ol0UT;o0;/io`020;hho`070:/mo`3o
9NP0YCko0818o`2N@?l0/3_o0<Hfo`0207M:o`070:hlo`2U?_l0Ldco06Y>o`3B=?l0Z3go0>X_o`02
07Y9o`0306A@o`20B?l0QdKo0080eC?o00/0WT3o0:<oo`2N@?l0hC3o0:Hno`2n>?l0YCko0858o`2n
>?l0aSKo0?lOa@020?<]o`060=Pbo`2n>?l0a3Oo09I2o`39=_l0ccCo0P2i>Ol00`1mBOl0SDCo0:hl
o`020<ldo`070=hao`3W;ol0[Cco08m4o`36=_l0HY3o09i0o`02075<o`0;06I?o`1JKol0N>So09U1
o`3o9^/0EEOo05Y_o`31>?l0Ef3o07I;o`2f>_l00P3H<_l02`36=_l0K4ko0<4ho`2f>_l0l2go05af
o`2^??l0PdOo09i0o`2=A?l0YSko01d0oooo000]0?ooo`030?lYn02]??l0oooo0080_SSo0P2N@?l0
4`3B=?l0c3Go07i8o`1gB_l0Zcgo0<4ho`2K@Ol0^cWo0<Hfo`1aC?l0TD?o0;Hjo`3Q<?l0^cWo0<4h
o`1lBOl0^cWo0<Hfo`2C@ol00P2:AOl02@1ODOl0eC?o09U1o`31>?l0Ldco08E6o`2:AOl0MD_o0:/m
o`020>@`o`0I0:<oo`3?=?l0WT3o0;<ko`2P?ol0/3_o0;hho`1nB?l0I53o09]1o`2F@_l0^3[o0<Hf
o`2a>ol0TD?o09I2o`3<=Ol0[Sco0;Hjo`3<=Ol0[Sco0<@go`31>?l0obKX0;<ko`020953o`050<`e
o`3T<?l0dSCo0:hlo`2k>Ol00P36=_l0901VCol0SdCo0>X_o`3Z;ol0WT3o07=<o`2S?ol0EU[o0=Dc
o`1KDol0obGT07i8o`1iB_l0P4So09A3o`3o:O`0c3Go09A3o`36=_l0oB_o07=<o`2?A?l0ND[o0:hl
o`1`C?l0Ge7o07i8o`2F@_l0_SSo0<<go`27A_l0jRoo0818o`2n>?l0Md[o09I2o`80[Sco00P0QDKo
07=<o`1MOol0Fe?o0<ldo`1iB_l0oooo05YCo`80Vd7o0P2]??l0402?A?l0HY3o0?lYn02S?_l0/c_o
07U:o`2k>Ol0Fg?o0>4`o`2[?Ol0obGX0:hlo`20B?l0WT3o07E;o`36=_l207M:o`0606I?o`2U?_l0
Ldco06Y>o`3B=?l0Z3go0P3Z;ol0101jBOl0I53o0:hlo`27A_l20=Dco`0C09i0o`2S?ol0WT3o0>4`
o`2V?_l0aSKo0:Dno`21B?l0_SSo0<Hfo`3o7lD0lbgo0<Tfo`3H<_l0_SSo0<@go`2^??l0bCKo0?lW
kP020;Tio`0W07e9o`3H<_l0[Sco0<ldo`3H<_l0gS7o0>L_o`2]??l0QDKo0<Hfo`1RT?l0Xcoo09I2
o`1aC?l0Ldco06I?o`1gB_l0VD7o0?lVj`1EEol0FVoo0<4ho`36=_l0MT_o0;Hjo`3N<Ol0f3;o09i0
o`3m:ol0`CSo0;Hjo`3`;Ol0H57o0:hlo`23Aol0Z3go08e4o`2V?_l0GGko01`0oooo000]0?ooo`0b
0?lYn02]??l0[Cco0;hho`3oool0WT3o0?ooo`3B=?l0c3Go07i8o`1gB_l0Zcgo0<4ho`2f>_l0^cWo
0<Hfo`1aC?l0Zcgo0;Hjo`3Q<?l0^cWo0<4ho`1lBOl0TD?o0<Hfo`2C@ol0RTGo09]1o`1ODOl0eC?o
09U1o`31>?l0Ldco08E6o`33=ol0MD_o0:/mo`3T<?l0iboo0:<oo`3?=?l0WT3o0;<ko`2P?ol0/3_o
0;hho`1ODOl0I53o09]1o`2F@_l20;Pjo`0<0;4ko`3Q<?l0UT;o0>4`o`2^??l0]S[o0<`eo`2?A?l0
a3Oo0<4ho`3o9^P0/c_o0P2A@ol02@2n>?l0i33o0=8do`2^??l0^cWo0<Hfo`2f>_l0IToo08m4o`02
0>X_o`0@09i0o`1cC?l0Xcoo0:hlo`3E<ol0Fe?o0?lUi01nB?l0ND[o0818o`2D@ol0obWl0<`eo`1/
__l0aSKo0?d[o`80SdCo00h0ND[o06:Co`1`C?l0Ge7o07Y9o`2F@_l0_SSo0<<go`27A_l0jRoo0818
o`2n>?l0Md[o09I2o`80[Sco00X0QDKo05eoo`1MOol0Fe?o0<`eo`1iB_l0oooo05YCo`2F@_l0Vd7o
0P2]??l0402?A?l0HY3o0?lYn02S?_l0/c_o07U:o`2k>Ol0Fg?o0<4ho`2N@?l0obGX0:hlo`20B?l0
WT3o07E;o`2^??l207M:o`0306I?o`36=_l0Ldco0080JTko01@0Z3go0:4oo`1jBOl0KTgo06A@o`2^
??l0QdKo0>L_o`3E<ol0aSKo0:<oo`2N@?l0ccCo0:Hno`36=_l0YCko0:/mo`2n>?l0UT;o0?lOa@80
lbgo0300f3;o0;hho`34=ol0[Sco0<Tfo`3o9nh0ccCo06A@o`1mBOl0f3;o0:hlo`3?=?l0f3;o07Q:
o`3W;ol0[Cco08E6o`36=_l0HY3o0:<oo`2F@_l0LDco07=<o`1VCol0Md[o09U1o`3o9^/0K4ko05Y_
o`31>?l0aSKo07I;o`1LD_l0gS7o0=Pbo`2N@?l0oB_o0<4ho`2f>_l0c3Go061Ao`2^??l0PdOo0:Pm
o`2N@?l0YSko05eno`36=_lK0?ooo`00<03oool0302n>?l0oooo09i0o`3oool0dSCo08Y5o`1nB?l0
Md[o0:/mo`31>?l0]S[o0:/mo`80aSKo0140Zcgo0;Hjo`3Q<?l0^cWo0;Pjo`1lBOl0TD?o0<Hfo`2S
?ol0RTGo09]1o`1ODOl0eC?o09U1o`31>?l0Ldco08E6o`020<<go`0A0:/mo`3T<?l0iboo0:<oo`1`
C?l0WT3o0;<ko`2P?ol0QDKo0;hho`2k>Ol0I53o0=Dco`2F@_l0ccCo0<Hfo`2a>ol00P1jBOl02@3Q
<?l0[Sco0=Dco`3<=Ol0SdCo0<@go`31>?l0obKX0;hho`020953o`0B0;hho`3T<?l0dSCo0:hlo`2P
?ol0aSKo0;Hjo`1VCol0FW3o0>X_o`27A_l0WT3o0?lWlP2S?ol0[Sco0=Dco`2n>?l0f3;o0P1iB_l0
1`20B?l0hC3o0?lYo02D@ol0K;ko0<Hfo`3m:ol00P2?A?l06P1iB_l0HY?o08m4o`1ODOl0NTWo09I2
o`2n>?l0`cOo07Y9o`3Z;ol0P4So0;hho`2U?_l0UT;o0:hlo`3:=_l0QDKo0?ooo`1MOol0GE;o0<`e
o`1iB_l0IToo05YCo`2F@_l0Vd7o0P2]??l01`3Q<?l0Ldco0<ldo`2S?_l0/c_o07U:o`2[?Ol00P31
>?l03@2N@?l0obGX0:hlo`3o5iD0P4So05EGo`2^??l0OTSo0858o`1VCol0aSKo0:hlo`2f>_l00P1Z
C_l02`2Q?ol0NTWo06i=o`1^COl0[Sco0;0ko`2n>?l0eC?o0<Hfo`2S?ol0WT3o0080ccCo00/0aSKo
0:Dno`2[?Ol0_SSo09I2o`3o7lD0UT;o0?<]o`39=_l0_SSo0<@go`020:hlo`070?lWkP3?=?l0I53o
0818o`3H<_l0FU?o0<ldo`020=Pbo`0R0>L_o`2]??l0QDKo07Y9o`1RT?l0Xcoo09I2o`3Z;ol0Ldco
06I?o`1gB_l0VD7o0?l@KP1/C_l0dSCo0<4ho`36=_l0jRoo05aBo`3N<Ol0jRoo09i0o`3Q<?l0`CSo
0;Hjo`3<=Ol0H57o0:hlo`23Aol0Z3go09i0o`2V?_l0GGko0<Hfoa/0oooo000`0?ooo`0>0;hho`3o
ool0K4ko09i0o`3B=?l0RTGo07i8o`1`C?l0Zcgo0?lTh@2f>_l0Zcgo0<Hfo`2A@ol20:Pmo`0R0>4`
o`2k>Ol0^3[o07E;o`2A@ol0aSKo0:<oo`2P?ol0Vd7o05mAo`2c>ol0VD7o0953o`1cC?l0^cWo0<<g
o`2I@Ol0Zcgo0;<ko`3W;ol0hC3o071<o`2N@?l0L4co0:0oo`25A_l0_SSo0;/io`1TD?l0eC?o09I2
o`3?=?l0aSKo09i0o`80NTWo01d0hC3o0:hlo`2c>ol0c3Go08m4o`34=ol0]S[o0?lVj02n>?l0TD?o
0>@`o`2n>?l0N4[o0=8do`2^??l0X3oo0;hho`2f>_l0YCko05Y`o`3Z;ol0QdKo09i0o`3o9o80Xcoo
0:hlo`3E<ol0_SSo0=Pbo`0207U:o`0S0818o`3Q<?l0obWl09A3o`1/__l0eC?o0?d[o`2?A?l0[Sco
07U:o`3T<?l0SdCo0<`eo`1jBOl0UT;o0:Pmo`33=ol0NTWo0>X_o`3<=Ol0_SSo0:Dno`2F@_l0[Sco
0<Xfo`3j:ol0IToo05MPo`1MD_l0c3Go07U:o`1VCol0QDKo09I2o`2[?Ol00P2]??l01`3Q<?l0Ldco
0<ldo`2S?_l0[Sco0=hao`2[?Ol00P31>?l03@2N@?l0obGX0:hlo`3o5iD0P4So05EGo`2^??l0OTSo
0858o`2^??l0aSKo0:hlo`2[?Ol00P1ZC_l0601ODOl0NTWo0;0ko`1^COl0[Sco0;0ko`2n>?l0eC?o
0<Hfo`3o:OP0WT3o0;<ko`3?=?l0aSKo0:Dno`2[?Ol0L4co09I2o`2A@ol0UT;o0?<]o`39=_l0jRoo
0<@go`80[Sco00X0obO^0<ldo`1TD?l0P4So0=Pbo`1JDol0eC?o0<ldo`3H<_l0N4[o0P2]??l02P1j
BOl0HY3o0:<oo`2F@_l0jRoo05aBo`1VCol0Md[o09U1o`3o46h206a>o`0D0<4ho`36=_l0jRoo07E;
o`3N<Ol0jRoo0=Dco`3Q<?l0oB_o0;Hjo`3<=Ol0H57o0=hao`23Aol0Z3go09i0o`2=A?l0GGko0<Hf
o`3o7lDJ0?ooo`00<`3oool02`2N@?l0dSCo08Y5o`1nB?l0L4co0:/mo`3o9>40Vd7o06a>o`36=_l0
TD?o0080Z3go00X0hC3o0:0oo`2h>_l0MD_o0953o`36=_l0Xcoo0:0oo`2K@Ol0Z3go0P2[?Ol07`2A
@ol0Ldco0>X_o`33=ol0VD7o0:/mo`2c>ol0iboo0>4`o`1`C?l0WT3o071<o`1jBOl0QDKo0;hho`2k
>Ol0FVgo0=Dco`2F@_l0ccCo0<Hfo`2N@?l0hC3o0;/io`3Q<?l0P4So0;<ko`1VCol0SdCo0<@go`2f
>_l00P3o9^P0>02A@ol0i33o0;hho`1hB_l0dSCo07U:o`2P?ol0_SSo0;Hjo`2U?_l0K4ko08m4o`27
A_l0WT3o0?lWlP1iB_l0[Sco0=Dco`2n>?l0f3;o07U:o`39=_l0FU?o0>4`o`2c>ol0QDKo06bno`3E
<ol0oB_o08m4o`2^??l0ND[o0>@`o`2?A?l0K4ko07Y9o`2F@_l0Z3go0<<go`1jBOl0jRoo0<`eo`2n
>?l0YCko09I2o`3E<ol0bSKo0?X[o`1VCol0Ef3o05eBo`3<=Ol0ND[o06I?o`25A_l0UT;o0`2[?Ol0
1`3Q<?l0Ldco0<ldo`2F@_l0[Sco0=hao`2[?Ol00P31>?l0302N@?l0jRoo0>X_o`1ZC_l0P4So05EG
o`2^??l0OTSo0<`eo`2^??l0aSKo0:hlo`80Zcgo0140JTko05mAo`1jBOl0UT;o06i=o`2F@_l0/3_o
0;hho`2S?ol0aSKo0?lYn02V?_l0/c_o0<ldo`20B?l0YCko0:/mo`02071<o`0<0953o`2F@_l0/c_o
0<Tfo`3Z;ol0aSKo09I2o`2^??l0aSKo0<ldo`1TD?l0P4So0P31>?l03`3E<ol0ccCo0=Pbo`1hB_l0
J4oo08E6o`1jBOl0HY3o07a9o`2F@_l0jRoo05aBo`2k>Ol0Md[o05IDo`020?l@KP0F06a>o`31>?l0
aSKo0>X_o`1eBol0gS7o0>X_o`3E<ol0hC3o0?d[o`2P?ol0c3Go061Ao`3N<Ol0i33o0:Pmo`2N@?l0
SDCo0:Hno`36=_l0oao50;PioaT0oooo000c0?ooo`1^09i0o`3oool0RTGo0?ooo`1`C?l0F6Co0?lT
h@2K@Ol0Zcgo0<Hfo`2A@ol0Zcgo08M6o`3Q<?l0X3oo0;Pjo`1aC?l0TD?o0=8do`2S?ol0X3oo09]1
o`3B=?l0Zcgo0=hao`2A@ol0OTSo0;/io`33=ol0VD7o0:/mo`2S?ol0iboo0>4`o`1`C?l0UT;o071<
o`1jBOl0QDKo0;hho`2k>Ol0FVgo0=Dco`2F@_l0ccCo0<Hfo`2N@?l0hC3o0;/io`3Q<?l0eC?o0;<k
o`1VCol0SdCo09I2o`2f>_l0hC3o0;hho`2h>_l0i33o0?<]o`1hB_l0dSCo07U:o`2N@?l0_SSo0;Hj
o`2U?_l0K4ko08m4o`27A_l0lbgo0?lWlP1iB_l0[Sco0=Dco`2n>?l0`cOo07U:o`39=_l0FU?o0>4`
o`2c>ol0QDKo06bno`3E<ol0Ge7o08E6o`2^??l0ND[o0>@`o`2?A?l0K4ko07Y9o`2F@_l0Z3go07i8
o`1jBOl0jRoo0<`eo`2f>_l0YCko09I2o`3E<ol0bSKo0?X[o`2[?Ol0Ef3o05eBo`1/^ol206I?o`06
08E6o`2n>?l0Zcgo08E6o`2[?Ol0hC3o0P1cC?l01`2F@_l0[Sco0=hao`2[?Ol0PdOo0<4ho`3Q<?l0
0P3Z;ol20?lGU@0705EGo`1UW_l0_SSo0858o`2^??l0aSKo0:hlo`020:/mo`070=/bo`1ODOl0Zcgo
0;0ko`1^COl0UT;o0;0ko`020;hho`0W0:<oo`3o:OP0YSko0;<ko`3?=?l0P4So09U1o`2[?Ol0Z3go
071<o`2f>_l0UT;o0;<ko`3E<ol0jRoo0<Hfo`2F@_l0[Sco0<Hfo`21B?l0bCKo0818o`31>?l0WT3o
0=Dco`3?=?l0jRoo0<Hfo`1XCol0fc;o07Y9o`1RT?l0O4Wo09I2o`3Z;ol0G5;o0;/io`1gB_l0EUCo
0080oa1^01H0K4ko0<4ho`36=_l0jRoo07E;o`3N<Ol0jRoo0=Dco`2`>ol0oB_o0:/mo`3<=Ol0H57o
0=hao`3T<?l0Z3go09i0o`2=A?l0YSko05eno`3o7lD0^3Wo6@3oool003D0oooo01D0RTGo0?ooo`1`
C?l0PdOo0?lTh@1XCol0Zcgo09]1o`2A@ol0Zcgo08M6o`3Q<?l0X3oo0;Pjo`1aC?l0TD?o0=8do`2S
?ol0MD_o09]1o`3B=?l00P2[?Ol20953o`0@0;/io`2^??l0VD7o0:/mo`2S?ol0iboo0>4`o`1`C?l0
UT;o0;Hjo`1jBOl0QDKo08m4o`2k>Ol0FVgo0=Dco`80ccCo01`0[Sco09i0o`3Q<?l0^cWo0>4`o`3E
<ol0]S[o06I?o`2?A?l0UT;o0>L_o`3Q<?l0_SSo0;Pjo`3T<?l0lbgo07Q:o`3B=?l0ND[o09i0o`2n
>?l0]S[o0:Dno`1/C_l0SdCo08M6o`3c;Ol0obOb0P2^??l0403H<_l0_SSo0<<go`1RDOl0bCKo05YC
o`1/C_l0/c_o08E6o`2[?Ol0eC?o05mAo`25A_l0[Sco06I?o`3T<?l206a>o`0A07Y9o`2F@_l0Z3go
07i8o`1jBOl0jRoo0<`eo`2f>_l0YCko09I2o`3E<ol0ccCo0?X[o`2[?Ol0Ef3o08m4o`2K@Ol00P1V
Col03`25A_l0_SSo0;<ko`25A_l0Zcgo09M2o`27A_l0Ldco09I2o`2S?_l0gS7o0?lWkP23Aol0`CSo
0>4`o`020>X_o`80oaNE0100VD7o0<Xfo`2n>?l0PDSo0:hlo`2F@_l0[Sco0;Hjo`2[?Ol0fc;o08a4
o`2[?Ol0/3_o0:hlo`2F@_l0QDKo0P2n>?l05P2S?ol0obWh0:Hno`2c>ol0dSCo0818o`2I@Ol0HiKo
0:Pmo`1`C?l0]S[o09I2o`2c>ol0eC?o0>X_o`36=_l0UT;o0:4oo`36=_l0PDSo0<Tfo`20B?l20<4h
o`080=Dco`3?=?l0jRoo0<Hfo`1XCol0fc;o0<Hfo`2k>Ol207a9o`070>X_o`1LD_l0^cWo0;Tio`1F
E?l0aSKo0?l@KP020=8do`0;0<Hfo`3Z;ol0MD_o0:Hno`3Z;ol0eC?o0;0ko`3m:ol0Zcgo0:0oo`2Q
?ol00P3N<Ol0202n>?l0WT3o08e4o`2V?_l0GGko0?lOa@2h>Ol0QDKo603oool003D0oooo00H0RTGo
0?ooo`1`C?l0PdOo0?lTh@1XCol20:/mo`0?0953o`2X?Ol0QdKo05eBo`2P?ol0^3[o075<o`3E<ol0
dSCo0:<oo`1eBol0Z3go0=8do`2c>ol0gS7o0080TD?o0100^cWo0:hlo`2I@Ol0ND[o0:<oo`1GGOl0
hC3o0=/bo`2F@_l0]S[o07Y9o`2^??l0SdCo0=Pbo`1JKOl0eC?o0P3?=?l0702^??l0WT3o0>4`o`2k
>Ol0SdCo0=Dco`2f>_l0IToo09A3o`2F@_l0iboo0>4`o`2n>?l0^3[o0>@`o`3c;Ol0ccCo0:Dno`3?
=?l0WT3o0;hho`2?A?l0YCko06a>o`2?A?l0QdKo0?<]o`3o9o820:hlo`0N0=Pbo`1XCol0`cOo069A
o`39=_l0OTSo06a>o`1HHol0QDKo0:/mo`2D@ol0IToo08E6o`2^??l0IToo0>@`o`1/C_l0c3Go05IJ
o`2F@_l0^cWo07i8o`1jBOl0YSko0<`eo`2f>_l0f3;o09I2o`3E<ol0ccCo0P3j:ol00`1GH?l0SdCo
09]1o`0206I?o`0?07Y9o`2n>?l0/c_o08E6o`2[?Ol0Ud;o08M6o`1cC?l0`CSo0:<no`3N<Ol0obO^
08=7o`2n>?l0hC3o0080jRoo0P3o5iD0302I@Ol0bSKo0;hho`3<=Ol0[Sco09I2o`34=ol0]S[o0:/m
o`3K<_l0S4Co0:/mo`80/3_o00P0UT;o08E6o`2n>?l0_SSo0:<oo`2K@Ol0YSko0;<ko`80dSCo02H0
VD7o06>Fo`2X?Ol0YSko0;Hjo`2U?_l0/c_o0=Dco`3o7KX0aSKo09I2o`2Q?ol0obWh0858o`39=_l0
`CSo0?0]o`31>?l0WT3o0<ldo`3Z;ol0aSKo0=8do`3K<_l0aSKo0;/io`2f>_l0O4Wo0>X_o`1nB?l0
^cWo0;Tio`1ZC_l0aSKo0?l@KP33=ol0dSCo0<4ho`80jRoo01<0YSko0>X_o`3E<ol0/3_o0;Hjo`2[
?Ol0X3oo0:4oo`34=ol0gS7o0>@`o`1TD?l0SDCo0:Hno`1MO_l0aSKo0;Pio`25A_l0NTWo01L0oooo
000g0?ooo`08071<o`23Aol0obCQ06Q?o`1/C_l0Vd7o0953o`2X?Ol205eBo`040:0oo`3<=Ol0a3Oo
0=Dco`80dSCo0240MD_o0:Pmo`3B=?l0/c_o0=hao`1nB?l0TD?o0>X_o`2^??l0VD7o07U:o`2^??l0
Eego0>4`o`3K<_l0f3;o0;Hjo`1jBOl0[Sco08m4o`3H<_l0FVgo0=Dco`3?=?l0QDKo0:hlo`2N@?l0
hC3o0;/io`2?A?l0P4So0;Hjo`2k>Ol00P3Z;ol04@3W;ol0hC3o07=<o`2h>_l0]S[o0?<]o`3?=?l0
YCko0<ldo`2N@?l0_SSo08m4o`3Z;ol0K4ko08m4o`27A_l0lbgo0080ND[o01l0G7Wo0=Pbo`1XCol0
`cOo069Ao`39=_l0OTSo05]eo`1HHol0QDKo0:/mo`2D@ol0IToo08E6o`2^??l0IToo0>@`o`1/C_l0
c3Go05IJo`2F@_l0^cWo0:/mo`1jBOl0YSko0?lUi02f>_l0f3;o09I2o`3E<ol0ccCo0080Zcgo03L0
aSKo08m4o`2K@Ol0IToo08M6o`1jBOl0_SSo0;<ko`25A_l0IToo09M2o`27A_l0EUco0<4ho`2S?_l0
YCko0?lWkP23Aol0aSKo0>4`o`3Z;ol0fc;o06Y>o`3o5iD0VD7o0<Xfo`2n>?l0c3Go0858o`2F@_l0
a3Oo0;Hjo`1/C_l0fc;o08a4o`2[?Ol0UT;o0;0ko`2^??l0QDKo0>L_o`25A_l0Xcoo09]1o`2[?Ol0
/c_o0?lZoP3B=?l0SdCo08=7o`2X?Ol0YSko0;Hjo`2U?_l0/c_o0080eC?o03<0oafj09I2o`2Q?ol0
obWh09U1o`39=_l0`CSo0?0]o`31>?l0WT3o0<ldo`3Z;ol0aSKo0=8do`3K<_l0aSKo0;/io`2f>_l0
O4Wo0:Hno`1nB?l0^cWo0;Tio`1ZC_l0aSKo0858o`33=ol0dSCo0<4ho`3Z;ol0MD_o0:Hno`3h;?l0
eC?o0;0ko`2f>_l0kBko0:0oo`2Q?ol0a3Oo0=hao`3T<?l0_SSo08e4o`2V?_l0GGko0<Hfo`2h>Ol0
QDKo07Y9o`2f>_l05P3oool003P0oooo00@0PdOo0?lTh@1XCol0oooo0P2K@Ol01`2X?Ol0GE;o05eB
o`2P?ol0c3Go0<@go`3E<ol00P3B=?l04P2A@ol0Z3go0=8do`2X?Ol0gS7o07i8o`2A@ol0jRoo0:hl
o`25A_l0ND[o0:hlo`1GGOl0hC3o0=/bo`3H<_l0]S[o0<`eo`80[Sco00T0f3;o05YCo`20B?l0ccCo
08E6o`2^??l0Z3go0>4`o`2[?Ol00P2?A?l0=P2f>_l0^cWo0>X_o`1LM_l0iboo0>4`o`1cC?l0aSKo
0;Hjo`3c;Ol0ccCo0:Dno`3?=?l0WT3o0;<ko`2?A?l0jRoo06a>o`3c;Ol0QdKo0?<]o`1iB_l0K4ko
05aio`3H<_l0J4oo0?lWlP1RDOl0bCKo07i8o`1KMOl0F6?o08E6o`2[?Ol0U4?o071<o`25A_l0G5?o
06I?o`1ODOl0[Sco0<`eo`1FF_l0WT3o0;/io`2[?Ol0NTWo0:Hno`3o9N@0a3Oo0=Pbo`2F@_l0SdCo
0<ldo`80Zcgo00L0aSKo08m4o`2K@Ol0oooo08M6o`1jBOl0JkKo0080/c_o03P0IToo07M:o`27A_l0
EUco0<4ho`2S?_l0YCko0?lWkP23Aol0aSKo0?lXm@3Z;ol0fc;o06Y>o`3o5iD0VD7o0<Xfo`2n>?l0
^CWo0858o`3o:O`0a3Oo0;Hjo`1/C_l0fc;o08a4o`1VCol0UT;o0;0ko`2^??l0/c_o0>L_o`25A_l0
YSko09]1o`2[?Ol0/c_o0?lZoP3B=?l0SdCo08=7o`2X?Ol0YSko0?d[o`2U?_l0SdCo0<4ho`3E<ol0
oafj0:Dno`2Q?ol0obWh09U1o`39=_l0`CSo0?0]o`80WT3o02T0Kdgo0>X_o`36=_l0dSCo0=/bo`36
=_l0^cWo0;Hjo`3H<_l0YSko07i8o`2k>Ol0^CWo06Y>o`36=_l0PDSo0<<go`39=_l0`CSo0>4`o`3F
<ol0YSko0?P/o`1VCol0/3_o0;Hjo`3];_l0fc;o0:4oo`34=ol0]S[o0>@`o`2n>?l0U4?o0:Hno`1M
O_l0aSKo0?lOa@25A_l0NTWo0;Hjo`0F0?ooo`00>P3oool02`1XCol0oooo09]1o`2K@Ol0Z3go06i=
o`1MD_l0^3[o0<`eo`34=ol0eC?o0080dSCo01d0TD?o0:Pmo`3B=?l0Z3go0=hao`1nB?l0TD?o0:<o
o`2^??l0QDKo07U:o`2X?Ol0Eego0<4ho`3K<_l0f3;o0;Hjo`3<=Ol0[Sco05mAo`3H<_l0FU?o0818
o`2k>Ol0QDKo0:hlo`2X?Ol0hC3o0:/mo`0208m4o`0f0;Hjo`2k>Ol0jRoo05afo`3W;ol0hC3o0;/i
o`36=_l0]S[o0?<]o`3?=?l0_SSo0<ldo`2N@?l0/c_o0;0ko`3Z;ol0K4ko0?<]o`27A_l0WT3o08Y5
o`1/C_l0obK[07U:o`2F@_l0obOb069Ao`39=_l0OTSo05]eo`1HHol0G5;o0:/mo`1VCol0L4co08E6
o`1LDol0aSKo05mAo`2^??l0c3Go0;Hjo`2N@?l0^cWo0:/mo`1jBOl0ccCo0?lUi034=ol0f3;o06i=
o`2?A?l0W47o0P2[?Ol04@36=_l0WT3o09]1o`1cC?l0QdKo09U1o`2f>_l0G7Ko0?ooo`1VCol0Md[o
05Y_o`1FG?l0`CSo09I2o`2U?_l0Ef3o0080aSKo01L0obSe0>X_o`3K<_l0]S[o0?lGU@3o6J40bSKo
07=<o`3<=Ol0PDSo0?lYo034=ol0]S[o0<Hfo`1/C_l0S4Co06I?o`2F@_l0Eego0:hlo`2c>ol0iboo
08E6o`020:Hno`070:/mo`3o:OP0ob[n0=8do`2?A?l0PdOo0:Pmo`020:Hno`070:Dno`2?A?l0`CSo
0=Dco`3o7KX0YCko0?lRd`020?lYn00809U1o`31>?l0l2go09i0o`3N<Ol0Kdgo05ioo`36=_l20=8d
o`0A0<Hfo`2k>Ol0]S[o0=Pbo`2V?_l0OTSo0<ldo`2i>Ol0JTko08m4o`3o8<`0`cOo0<Tfo`1gB_l0
hC3o0=Hco`2V?_l00P3h;?l04P2h>_l0]S[o0>d^o`3K<_l0TD?o0<@go`2f>_l0SdCo0;hho`2D@ol0
nR_o0=Pbo`36=_l0oao50;Pio`1jBOl0]S[o0=DcoaD0oooo000l0?ooo`0F0:Dno`2K@Ol0Z3go06i=
o`2C@ol0^3[o0<`eo`34=ol0eC?o06^fo`3B=?l0TD?o0:Pmo`3B=?l0Z3go0?<]o`1nB?l0TD?o0:<o
o`1eBol0QDKo07U:o`80Z3go0100`CSo0=/bo`3o9nh0]S[o0<`eo`2^??l0Ge7o0=Pbo`1JDol0P4So
0;/io`25A_l0_SSo0:Pmo`3T<?l0Zcgo0P2?A?l01@20B?l0^cWo09A3o`1LM_l0iboo0080^cWo0480
aSKo0;Hjo`2F@_l0ccCo0;hho`3?=?l0^cWo0;<ko`2`>ol0jRoo0<ldo`3c;Ol0EEOo09i0o`2:AOl0
K4ko0?lVj`1iB_l0UT;o0?lWlP3W;ol0obGT0=hao`1KMOl0F6?o05aBo`2[?Ol0IToo071<o`2[?Ol0
G5?o0<Hfo`1jBOl0[Sco0<`eo`2f>_l0WT3o09A3o`2[?Ol0Ef3o0<ldo`3o9N@0a3Oo0=Pbo`1^COl0
WT3o09a1o`2k>Ol0IToo0<Hfo`2N@?l0Vd7o07=<o`27A_l0VD7o0;Hjo`1LM_l0oooo08E6o`1gB_l0
FVoo0:Hno`1ZC_l0UT;o0>4`o`1GH?l20<Hfo`080?lXm@27A_l0fc;o0=hao`1ZC_l0oaVQ0<Xfo`1c
C?l20<`eo`0d0?lYo02F@_l0]S[o0<Hfo`1/C_l0P4So06I?o`2F@_l0Eego0:hlo`2c>ol0iboo08E6
o`2?A?l0YSko0:/mo`3o:OP0ob[n07Y9o`2?A?l0PdOo0:Pmo`1/COl0YSko0?d[o`2?A?l0`CSo09i0
o`3o7KX0YCko0?lRd`2G@_l0obWh09U1o`31>?l0l2go09i0o`3N<Ol0FVgo05ioo`3N<Ol0hC3o0=8d
o`1OR?l0^cWo0;Hjo`3H<_l0a3Oo07i8o`3?=?l0^CWo06Y>o`80SdCo01/0`cOo0<Tfo`1gB_l0hC3o
0=Hco`36=_l0`CSo0?P/o`2h>_l0]S[o0>d^o`3K<_l0TD?o0<@go`2f>_l0c3Go0;hho`2D@ol0nR_o
0=Pbo`36=_l0oao50;Pio`25A_l0]S[o0=Dco`2<A?l0503oool003`0oooo01X0YCko09]1o`2X?Ol0
KTgo09=3o`2h>_l0c3Go0;<ko`3E<ol0JkKo0=8do`1/C_l0Z3go08E6o`2X?Ol0lbgo07i8o`3g;?l0
Xcoo07E;o`25A_l0F5Co0:Pmo`2k>Ol0`CSo0=/bo`80obO^00`0c3Go0>L_o`1ODOl0f3;o05YCo`25
A_l0^cWo08E6o`2n>?l0Z3go0>@`o`2[?Ol208m4o`050818o`2k>Ol0Z3go05afo`3W;ol00P2k>Ol0
3036=_l0]S[o09I2o`2c>ol0_SSo0<ldo`2k>Ol0/c_o0;0ko`3Z;ol0ccCo0?<]o`80EEOo03@0RTGo
06a>o`3o9^/0/c_o09I2o`3o9o80iboo0?lUi03N<Ol0FgGo06a>o`1LD_l0QDKo06I?o`1`C?l0Zcgo
0?lPb@36=_l0NTWo0:hlo`3<=Ol0]S[o09i0o`2D@ol0Zcgo05MPo`3?=?l0U4?o0<@go`3H<_l0KTgo
09i0o`2L@Ol0^cWo06I?o`36=_l0WT3o0:hlo`1cC?l0QdKo09U1o`2f>_l0L]?o0?ooo`25A_l0Md[o
05Y_o`2V?_l0JTko09I2o`3Q<?l0NTWo0P36=_l00`3o:?D0QdKo0<ldo`020=hao`030?lIX@3o9o80
Ldco0080c3Go0180obWl09I2o`3];_l0aSKo07=<o`20B?l0F5Co09I2o`3o7[d0Eego0;<ko`36=_l0
MD_o0=hao`2V?_l0mbco0?lYn03o:_h207Y9o`0m08=7o`2X?Ol0K4go0:Hno`3m:ol0RTGo0<4ho`2N
@?l0oafj0:Dno`3o8]<0Ud;o0?lYn02I@Ol0lbgo0?0]o`2N@?l0gS7o05Y]o`3o8<T0gS7o0>4`o`3B
=?l0Eego05n8o`2f>_l0f3;o0<@go`1LNOl0ccCo09A3o`1JKol0RTGo08m4o`33=ol0bCKo07M:o`2?
A?l0eS?o0<Hfo`31>?l0n2co06I?o`2h>_l0kBko0=/bo`2A@ol0H57o0;Hjo`3<=Ol0SdCo09A3o`3j
:ol0f3;o0<Hfo`3o7lD0^3Wo08E6o`1jBOl0eC?o08a4o`0D0?ooo`00?03oool0D02U?_l0Vd7o0?oo
o`1^COl0Td?o0;Pjo`3<=Ol0/c_o07i8o`1[]_l0dSCo06a>o`2X?Ol0QDKo0<ldo`3c;Ol0OTSo0?L/
o`1JDol0MD_o08E6o`1HE?l0Z3go0;/io`31>?l0fc;o0?lWkP2n>?l0c3Go0>L_o`1ODOl0iboo05YC
o`25A_l0^cWo09i0o`2n>?l0a3Oo0>@`o`2[?Ol0SdCo07i8o`20B?l0^cWo0:Pmo`1lBOl0TD?o0;/i
o`33=ol0aSKo06Y>o`2F@_l0/c_o0;hho`3?=?l0^cWo09I2o`2`>ol0jRoo0<ldo`3c;Ol0PdOo09i0
o`2:AOl0^cWo0?lVj`2c>ol0UT;o0?lWlP3W;ol0obGT0=hao`1cC?l0K4ko0<ldo`25A_l0FU?o071<
o`2[?Ol0ob390P36=_l09P2^??l0c3Go0;Hjo`1lBOl0U4?o0:/mo`1GH?l0ccCo09A3o`34=ol0SdCo
05]co`2N@?l0EU[o0;/io`1VCol0obWh09i0o`2^??l0YCko08a4o`2I@Ol0]S[o07;Co`3oool0QDKo
05aio`1JKol0YSko08m4o`31>?l0hC3o07Y9o`3o:O/0aSKo0;hho`1SU_l0ccCo0P3N<Ol0C@3o6J40
obOb0<Hfo`2i>Ol0c3Go0?lYo02F@_l0kBko0<Hfo`1cC?l0P4So05QDo`2F@_l0TD?o05MMo`2=A?l0
aSKo07E;o`3N<Ol0YSko0?L/o`3o:OP0ob[n0<Tfo`1jBOl0f3;o0:Pmo`1/COl0]S[o0?d[o`2:AOl0
`CSo09i0o`3H<_l0IToo0?lRd`2G@_l0YCko0;/io`3c;Ol0TD?o09i0o`3N<Ol0FVgo069Ao`3N<Ol0
hC3o05j1o`1GGOl0GhSo0:4oo`3H<_l0a3Oo05aio`3?=?l0U4?o05Y_o`2:AOl0SdCo0?lUi039=_l0
Md[o08m4o`3Q<?l0aSKo0<4ho`3Q<?l0Xcoo0;Pjo`3];_l0fc;o0953o`1PDOl0]S[o0<`eo`2?A?l0
U4?o0080nR_o00L0aSKo0?lOa@2h>Ol0QDKo07Y9o`3E<ol0S4Co01@0oooo000m0?ooo`0709]1o`3o
ool0KTgo09I2o`2h>_l0]S[o0;<ko`030:<oo`0406a>o`1EEol0QDKo0<ldo`80lbgo00D0mbco0:<o
o`1eBol0[Sco05QDo`020;/io`0c0<4ho`1gB_l0obO^0;hho`3<=Ol0iboo0<Tfo`3W;ol0FU?o0>4`
o`2k>Ol0WT3o0;hho`34=ol0i33o0=hao`2?A?l0OTSo0818o`2k>Ol0Z3go07a9o`2A@ol0UT;o0<<g
o`36=_l0JTko0;0ko`2c>ol0_SSo0953o`2k>Ol0UT;o0;0ko`3Z;ol0ccCo08=7o`3?=?l0WT3o08Y5
o`2k>Ol0obK[0;<ko`2F@_l0obOb0>L_o`3o9N@0gS7o07=<o`1/C_l0ccCo0080QDKo01H0L4co0:/m
o`3o8<T0aSKo07Y9o`2^??l0dSCo0;Hjo`1lBOl0U4?o08M6o`1TD?l0SdCo09A3o`34=ol0SdCo05]c
o`2N@?l0EU[o0;/io`2U?_l0obWh0P2^??l04`2U?_l0S4Co08E6o`2f>_l0L]?o0?ooo`25A_l0G7Wo
06A@o`2V?_l0SdCo0<4ho`3Q<?l0NTWo0?lYn`36=_l0_SSo06>Fo`3?=?l00P3N<Ol0203o6J40obOb
0<Hfo`2i>Ol0c3Go0<Tfo`3?=?l0kBko0P36=_l00`1cC?l0F5Co0:/mo`020?lN_@0B08e4o`36=_l0
MD_o0=hao`1FFOl0mbco09a0o`3o:_h0bCKo07Y9o`3H<_l0Z3go06a=o`2f>_l0oB_o08Y5o`1iB_l0
WT3o0P3H<_l08`3o8]<0Ud;o0:Dno`2k>Ol0lbgo0953o`2?A?l0gS7o05Y]o`3o8<T0gS7o0>4`o`1N
POl0Eego07=<o`2Q?ol0f3;o0<@go`1LNOl0EUCo09A3o`1JKol0RTGo07E;o`3o9N@0/c_o07M:o`2?
A?l0hC3o0<Hfo`31>?l0hC3o0:<oo`2h>_l0jRoo0080fc;o00D0H57o09I2o`3<=Ol0SdCo0>X_o`02
0?X[o`070=Pbo`3o7lD0^3Wo08E6o`1jBOl0]S[o08a4o`0D0?ooo`00?`3oool01@1^COl0UT;o0;Pj
o`2f>_l0/c_o00<0Xcoo00@0bCKo05EGo`25A_l0KTgo0P3c;Ol01@3g;?l0QDKo07E;o`2^??l0F5Co
0080^cWo01T0`CSo07M:o`3o9nh0_SSo0<`eo`2^??l0Xcoo0>L_o`2k>Ol0hC3o0;/io`2N@?l0YCko
0<@go`3T<?l0gS7o05afo`1nB?l0P4So08Y5o`2X?Ol0O4Wo0953o`2X?Ol0`cOo0080/c_o0400/3_o
0;<ko`2n>?l0TD?o0?L/o`2F@_l0/3_o0=8do`3?=?l0PdOo0<ldo`2N@?l0RTGo0;/io`3o9^/0/c_o
09I2o`3o9o80iboo0:0oo`3N<Ol0Ldco06a>o`3?=?l0lbgo05YCo`1`C?l0obO^0?lPb@1JKol0NTWo
0:hlo`3B=?l0[Sco07a9o`2D@ol0QdKo06A@o`2?A?l0fc;o0<@go`2?A?l0Fg?o08m4o`1FF_l0^cWo
0:Dno`3o:OP0[Sco0?ooo`2U?_l0S4Co08E6o`2f>_l0VD7o0;<ko`1jBOl0]S[o06A@o`2V?_l0SdCo
0<4ho`3Q<?l0NTWo0P3o:O/0302n>?l0[Sco08=7o`2f>_l0gS7o0?lIX@3o9o80aSKo0;Tio`2S?ol0
bCKo0<ldo`80kBko00H0aSKo07=<o`2k>Ol0Zcgo0?lN_@3W;ol208e4o`0K06a>o`3N<Ol0gS7o0?L/
o`2L@?l0Z3go0<Tfo`2f>_l0f3;o07i8o`1/COl0]S[o0:hlo`27A_l0ND[o0:0oo`1PDOl0f3;o0?lR
d`3?=?l0YCko0;/io`3c;Ol0TD?o08m4o`3N<Ol0FVgo0080ob390100hC3o05j1o`1GGOl0Ldco0:4o
o`1RDOl0a3Oo0:dlo`1FE?l0aSKo0>@`o`2:AOl0MD_o0?lUi02c>ol0ccCo0P2?A?l01@20B?l0`CSo
0>4`o`2S?ol0YSko0080jRoo00l0UT;o061Ao`2F@_l0c3Go08m4o`3Z;ol0_SSo0?X[o`3H<_l0oao5
0;Pio`25A_l0NTWo0;Hjo`2<A?l0503oool00400oooo00T0UT;o0?ooo`2f>_l0/c_o0:<oo`25A_l0
Xcoo0<Tfo`1EEol00P1^COl20?<]o`0P0?L/o`2S?ol0Xcoo0:hlo`1HE?l0IToo0;/io`1GH?l0Xcoo
09]1o`2n>?l0WT3o0:hlo`2S?ol0iboo0;/io`3Q<?l0fc;o09i0o`2U?_l0a3Oo0>@`o`3N<Ol0G7Ko
07i8o`20B?l0RTGo0:Pmo`1lBOl0TD?o0:Pmo`33=ol20;<ko`0k0;0ko`2c>ol0KTgo0953o`3g;?l0
UT;o09i0o`3B=?l0UT;o0?0]o`3?=?l0WT3o0:dlo`2k>Ol0UT;o0;<ko`2`>ol0Md[o0>L_o`2P?ol0
gS7o07=<o`3W;ol0ccCo0?<]o`1JDol0f3;o0?lWkP3o8<T0FVoo07Y9o`1JDol0dSCo0:hlo`2U?_l0
U4?o08M6o`1TD?l0SdCo0=/bo`34=ol0K4go0<Tfo`2?A?l0EEOo0;/io`2U?_l0obWh0:hlo`3oool0
YCko0:hlo`25A_l0WT3o09U1o`2c>ol0NTWo0;Hjo`1TD?l00P2?A?l00`31>?l0IToo09]1o`020?lY
n`070:/mo`2^??l0PdOo0;Hjo`3N<Ol0QdKo0?lWlP020<Hfo`0:0:<oo`39=_l0ccCo08m4o`3==Ol0
aSKo07=<o`2k>Ol0Zcgo0?lN_@80iboo00d0SDCo06a>o`2?A?l0gS7o05IIo`1lBOl0Z3go0<Tfo`2f
>_l0f3;o07i8o`3?=?l0]S[o0080[Sco00H0ND[o0:0oo`1PDOl0f3;o06I?o`3?=?l20:Dno`050:Hn
o`1RTol0SdCo0>@`o`2?A?l00P3o8<T05`3Q<?l0IJ3o05MMo`1cC?l0XCoo069Ao`2D@ol0[Cco05ID
o`36=_l0/C_o08Y5o`1eBol0obGT0;<ko`3?=?l0^cWo0>4`o`20B?l0GhSo0>4`o`2S?ol0YSko0080
jRoo00l0UT;o0;4ko`2F@_l0P4So0;Hjo`3Z;ol0_SSo0?X[o`3H<_l0UT;o05QVo`25A_l0NTWo0;Hj
o`3E<ol0503oool00400oooo00@0UT;o0?ooo`2f>_l0oooo0`2S?ol06039=_l0EEOo05EGo`1^COl0
/c_o0?<]o`3g;?l0Xcoo0;<ko`2^??l0]S[o06I?o`2k>Ol0Ef3o0:<oo`2K@Ol0_SSo09i0o`39=_l0
Xcoo0>L_o`2k>Ol0hC3o0=/bo`80WT3o01H0a3Oo09I2o`3N<Ol0G7Ko07i8o`33=ol0RTGo06I?o`1l
BOl0TD?o0:Pmo`2S?ol0/c_o09I2o`2`>ol0/c_o06i=o`25A_l0mbco09I2o`2N@?l0dSCo0P3`;Ol0
203?=?l0WT3o0:dlo`2k>Ol0UT;o0;<ko`2`>ol0^cWo0P2P?ol0@03N<Ol0Ldco0>L_o`3?=?l0lbgo
05YCo`3H<_l0obO^0?lPb@1JKol0]S[o05YCo`3B=?l0[Sco0:Dno`2D@ol0_SSo06A@o`2k>Ol0fc;o
0<@go`1/COl0bCKo08m4o`1EEol0^cWo0:Dno`2?A?l0gS7o0?ooo`2U?_l0[Sco08E6o`2N@?l0VD7o
0;<ko`1jBOl0]S[o0;/io`2`>ol0SdCo06Y>o`1VCol0Vd7o07i8o`3o:O/0Zcgo0:hlo`23Aol0]S[o
0:<oo`2n>?l0dSCo09U1o`2i>Ol0Ycko0:<oo`3?=?l0SdCo0<deo`2V?_l0Ldco0;/io`2[?Ol20?lN
_@0W0>L_o`2=A?l0K4ko08m4o`3N<Ol0lbgo07a9o`2X?Ol0bCKo0;Hjo`3H<_l0OTSo0<ldo`2f>_l0
UT;o0:hlo`27A_l0X3oo061Ao`34=ol0JTko0<ldo`1SD?l0^cWo0:Hno`1RTol0GU;o0>@`o`2?A?l0
Z3go0?lPb@1RDOl0IJ3o05MMo`1cC?l0F5Co08E6o`2D@ol0[Cco0080EUCo00l0aSKo08Y5o`1eBol0
ob3<0?lJZ03?=?l0^cWo0>4`o`20B?l0GhSo0>4`o`2S?ol0YSko0;Hjo`3Z;ol00`2F@_l03@20B?l0
]S[o0>X_o`2n>?l0f3;o07M:o`2F@_l0F6Ko0<`eo`1jBOl0]S[o0=Dco`2<A?l04`3oool00480oooo
00@0]S[o0?ooo`2F@_l0QDKo0`2S?ol206i=o`0307M:o`3c;Ol0UT;o0080Xcoo00l0[Sco09=3o`1V
Col0Xcoo05MPo`2S?ol0Vd7o0;0ko`2N@?l0bCKo0:<oo`3W;ol0^cWo0>4`o`3K<_l00P2N@?l03`34
=ol0UT;o0=hao`1LM_l0OTSo0<<go`2k>Ol0IToo07a9o`2S?ol0Z3go0:<oo`2c>ol0UT;o0;0ko`02
0<Tfo`0908E6o`3g;?l0]S[o09i0o`31>?l0l2go0:Hno`3?=?l0`CSo0080[Cco00@0UT;o0;<ko`2`
>ol0RTGo0P2P?ol0=`2S?ol0IToo0>L_o`3E<ol0lbgo0<ldo`3H<_l0obO^0=Dco`2n>?l0]S[o0;<k
o`3<=Ol0Z3go0:Dno`2D@ol0_SSo08m4o`2k>Ol0fc;o0<@go`1/COl0bCKo08m4o`1EEol0^cWo0?lY
n`2?A?l0gS7o0<ldo`2U?_l0[Sco07U:o`2N@?l0oooo0;<ko`2:AOl0]S[o0;/io`2`>ol0SdCo06Y>
o`1EEol0Vd7o07i8o`3o:O/0Zcgo0:hlo`3m:ol0]S[o0:<oo`2n>?l0dSCo09U1o`2[?Ol00P2S?ol0
0`3o:OP0SdCo0<deo`020:Hno`0:0;/io`1cC?l0oajm0?lN_@3W;ol0ob3806a>o`2?A?l0lbgo0=Dc
o`80O4Wo00l0bCKo0;Hjo`2f>_l0Xcko0<ldo`2G@_l0UT;o0:hlo`27A_l0U4;o061Ao`34=ol0JTko
0<ldo`1SD?l00P2k>Ol07`1RTol0GU;o0>@`o`2?A?l0Z3go0?lPb@1TD?l0IJ3o07a9o`1cC?l0F5Co
08E6o`2D@ol0[Cco06FQo`2h>_l0aSKo0;4ko`1eBol0ob3<0?lJZ03?=?l0^cWo0>4`o`20B?l0GhSo
0?lUi02S?ol0YSko0;Hjo`3Z;ol00P2F@_l03P2I@Ol0P4So0;Hjo`2h>_l0_SSo0=Pbo`2k>Ol0UT;o
05QVo`3<=Ol0obWl0;Hjo`3E<ol0S4Co4`3oool004@0oooo00D0UT;o08E6o`2S?ol0Xcoo0;<ko`02
06i=o`0607M:o`3c;Ol0UT;o08E6o`2c>ol0[Sco0P2f>_l02@2S?ol0Ef3o0;/io`2K@Ol0/3_o0:/m
o`39=_l0Xcoo0:Hno`020;/io`0?0=/bo`2V?_l0WT3o05]Co`2F@_l0U4?o05afo`2<A?l0`cOo0;/i
o`1VCol0c3Go0:<oo`2?A?l0Xcoo0080UT;o02T0/3_o0<Tfo`3B=?l0QDKo0?L/o`2f>_l0WT3o0<4h
o`3`;Ol0YSko0<ldo`31>?l0[Cco0:Pmo`2F@_l0X3oo0;0ko`2:AOl0/3_o0=Pbo`2S?ol0IToo0>L_
o`3E<ol0lbgo0<ldo`3H<_l0obO^0=Dco`2n>?l0]S[o0;<ko`3<=Ol0Z3go0:Dno`2D@ol0_SSo08m4
o`2k>Ol0fc;o0<@go`020<Tfo`80EEOo00h0^cWo0?lYn`2=A?l0gS7o0<ldo`1cC?l0[Sco07U:o`1N
D_l0oooo0;<ko`2:AOl0]S[o0;/io`80/3_o00<0JTko05EGo`2K@Ol00P1nB?l02@3?=?l0[Sco0?d[
o`2f>_l0gS7o0;hho`1/COl0VD7o0:/mo`020:<oo`030?lYn03K<_l0cCGo0080YSko00d0^cWo07=<
o`3o7[d0oajm0>L_o`3o8<P0obCN08m4o`3c;Ol0eC?o0:hlo`1lBOl0bCKo0080]S[o03d0Xcko0<ld
o`2G@_l0UT;o0:<oo`27A_l0U4;o0=Pbo`34=ol0JTko0<ldo`34=ol0aSKo0:Hno`2X?Ol0GU;o0>@`
o`2?A?l0Z3go0?lPb@1TD?l0HU7o07a9o`1cC?l0F5Co08E6o`2S?ol0[Cco06FQo`2h>_l0aSKo0;4k
o`3Q<?l0ob3<0?lJZ027A_l0^cWo08M6o`36=_l0iboo0?lUi01/C_l0YSko0;Hjo`2D@ol0WT3o09I2
o`2a>ol0ccCo0;Hjo`2h>_l0UT;o0=Pbo`2k>Ol0Ge7o05QVo`3<=Ol0obWl0;Hjo`3E<ol0S4Co01<0
oooo00150?ooo`0F08E6o`3oool0Xcoo0:<oo`1^COl0nR_o07M:o`3c;Ol0UT;o08E6o`2c>ol0PdOo
0;Hjo`2`>ol0Xcoo0;Pjo`2k>Ol0Zcgo0;0ko`2[?Ol0bCKo0:<oo`80`CSo00T0Td?o0=/bo`2V?_l0
WT3o05]Co`2F@_l0Md[o08=7o`2c>ol00P33=ol05`1VCol0c3Go0:<oo`2?A?l0Xcoo0<<go`2F@_l0
L4co0<Tfo`3B=?l0QDKo0?L/o`2f>_l0dSCo0<4ho`2F@_l0YSko0<ldo`31>?l0iboo0:Pmo`2F@_l0
X3oo0080RTGo01L0/3_o0=Pbo`2S?ol0IToo0>L_o`3E<ol0lbgo0<ldo`3H<_l0obWh0=Dco`2n>?l0
]S[o0;<ko`3<=Ol0Z3go0:Dno`3?=?l0_SSo08m4o`2k>Ol0fc;o0<@go`020<Tfo`80EEOo01<0^cWo
0?lYn`2=A?l0gS7o0<ldo`1cC?l0c3Go07U:o`1ND_l0aSKo0;<ko`2:AOl0YSko0;/io`20B?l0/3_o
0;hho`1EEol0FU?o0080OTSo01P0ccCo0:hlo`3m:ol0PDOo0=hao`2n>?l0K4go0<Hfo`2[?Ol0gS7o
0:<oo`3o:OP0fc;o0<deo`1OR?l0YSko09]1o`2:AOl0TD?o0;Tio`3W;ol0ob380?lTgP3H<_l20?<]
o`030=Dco`1lBOl0]S[o0080]S[o02P0Xcko0?<]o`2G@_l0UT;o0:<oo`2?A?l0U4;o0=Pbo`34=ol0
JTko0<@go`2?A?l0aSKo0818o`2X?Ol0H8So05iBo`1eBol0Z3go069Ao`1TD?l0HU7o07a9o`1nB?l0
obCQ08E6o`2S?ol0[Cco06>Fo`2h>_l0oB_o0;4ko`3B=?l0ob3<0?lJZ027A_l0mbco08M6o`36=_l0
iboo0P3o9N@03P2I@Ol0]S[o09A3o`2N@?l0/c_o0;4ko`2I@Ol0]S[o0;Pjo`2F@_l0f3;o0;/io`1O
DOl0oooo0P3<=Ol00`2f>_l0eC?o08a4o`0C0?ooo`00A@3oool03025A_l0oooo08e4o`2c>ol0KTgo
0?X[o`34=ol0JTko09I2o`23Aol0/c_o08=7o`80]S[o01H0Xcoo07Y9o`2k>Ol0Zcgo0;0ko`2[?Ol0
bCKo09I2o`31>?l0EU[o09=3o`3K<_l0YSko0:<oo`1KDol0UT;o07M:o`23Aol0/c_o07i8o`2k>Ol0
Ldco0P3<=Ol03`2?A?l0Xcoo0<<go`2F@_l0L4co0<Tfo`3B=?l0QDKo0;Pjo`2f>_l0dSCo0<4ho`1e
Bol0YSko0953o`020<4ho`0L0:Pmo`3<=Ol0X3oo08Y5o`2k>Ol0/3_o0=Pbo`3o8M00QdKo07U:o`3E
<ol0lbgo0<ldo`2k>Ol0obWh0=Dco`2n>?l0obWh0;<ko`3o9o80Z3go0:Dno`3?=?l0[Sco08m4o`25
A_l0fc;o0<@go`80bCKo02l0_SSo0;<ko`2U?_l0obWk08e4o`3N<Ol0ccCo07=<o`3<=Ol0^CWo05iB
o`36=_l0VD7o08Y5o`2V?_l0^cWo0818o`2`>ol0_SSo0=Dco`1JDol0FF[o0=Pbo`3?=?l0Z3go0?d[
o`21Aol0gS7o0:<oo`1/COl0aSKo0:/mo`2W?_l0Xcoo0?lYn03K<_l0SdCo05n8o`2V?_l0Vd7o08Y5
o`2A@ol0^CWo0?d[o`3o8<P0obCN0=Pbo`020?<]o`0?0=Dco`2^??l0]S[o07a9o`1`b_l0Xcko0?<]
o`3<=Ol0UT;o0:<oo`2?A?l0U4;o0=Pbo`1HI_l0JTko0080a3Oo00h0aSKo0818o`2X?Ol0H8So05iB
o`1eBol0Z3go069Ao`1TD?l0HU7o07a9o`1nB?l0obCQ08E6o`80Xcoo0240HiKo0;Pjo`3m:ol0i33o
0=8do`3o8<`0oaZX08M6o`3g;?l0SdCo0<Hfo`3W;ol0OTSo0?lUi02I@Ol0SdCo09A3o`2N@?l0/c_o
0;4ko`2I@Ol0QDKo0;Pjo`2F@_l0acKo0;/io`1ODOl0eC?o0?ooo`3<=Ol0obWl0=Dco`2<A?l04`3o
ool004L0oooo0280SDCo0;<ko`3oool0nR_o0<@go`1ZC_l0UT;o08=7o`2c>ol0PdOo09=3o`2`>ol0
Xcoo0;Pjo`2k>Ol0Zcgo0;0ko`1nB?l0bCKo09I2o`31>?l0EU[o09=3o`1^COl0YSko0:<oo`1KDol0
`cOo07M:o`23Aol0/c_o07i8o`2k>Ol0Ldco0P3<=Ol00`2?A?l0Xcoo0<<go`020;hho`0O0;0ko`3B
=?l0/3_o0;Pjo`2n>?l0dSCo0<4ho`1eBol0Ge7o0953o`2C@ol0iboo0:Pmo`3<=Ol0iboo08Y5o`2k
>Ol0/3_o0=Pbo`3o8M00QdKo07U:o`3E<ol0/c_o0<ldo`2k>Ol0obWh0=Dco`2n>?l0obWh0;<ko`02
0:Pmo`090:/mo`3?=?l0[Sco0:hlo`25A_l0fc;o05QWo`39=_l0c3Go0080/c_o00<0YCko0?lYn`2=
A?l00P3?=?l00`1gB_l0c3Go0;Tio`020<Hfo`0I09U1o`3Z;ol0YSko071<o`20B?l0/3_o0;hho`3E
<ol0aSKo05UZo`33=ol0ccCo0:Pmo`3m:ol0PDOo0=Dco`2S?ol0lbgo0<Hfo`23Aol0Ycko0:<oo`2?
A?l0fc;o08m4o`0205n8o`0809]1o`2:AOl0FU?o0;Tio`3m:ol0ob380?lTgP3H<_l20?<]o`0:0=Dc
o`2^??l0]S[o07a9o`1`b_l0OTSo0?<]o`3<=Ol0HHgo0:<oo`80SdCo02h0f3;o05QVo`1KLol0O?Co
0<@go`2?A?l0P4So0:Pmo`1PR?l0I53o07E;o`1HE?l0XCoo06A@o`1RDOl0O4Wo07i8o`3o9>40QDKo
05IJo`2S?ol0HiKo0;Pjo`3m:ol0i33o0=8do`3Q<?l0oaZX08M6o`3g;?l0SdCo0<Hfo`3W;ol0OTSo
0?lUi02I@Ol0SdCo08M6o`2N@?l0/c_o08Y5o`2I@Ol0ccCo0;Pjo`2F@_l0acKo0P3oool01P3E<ol0
oooo0<`eo`3o:O`0oooo08a4oa<0oooo00180?ooo`0<0;<ko`3oool0nR_o0<@go`1ZC_l0Xcoo08=7
o`2`>ol0PdOo09=3o`2`>ol0_SSo0P2h>_l04`2[?Ol0/3_o07i8o`1nB?l0UT;o0:Hno`1FF_l0S4Co
06i=o`2F@_l0Xcoo05eBo`33=ol0fc;o08=7o`2<A?l0OTSo0;/io`1cC?l00P3<=Ol00`2?A?l0^3[o
0<<go`020;hho`0N0;0ko`3B=?l0/3_o0;Pjo`2n>?l0dSCo06R^o`1eBol0Ge7o0953o`2C@ol0iboo
0<ldo`3<=Ol0iboo05MPo`2k>Ol0/3_o09]1o`3o8M00QdKo07U:o`3E<ol0/c_o08Y5o`2k>Ol0QdKo
0=Dco`2n>?l0obWh0`2X?Ol02@2[?Ol0ccCo0:hlo`2^??l0QDKo0=/bo`1HIol0bCKo0<`eo`020;<k
o`080:Dno`2?A?l0Jdko0?ooo`3?=?l0Md[o0<`eo`2i>Ol20<Hfo`0909U1o`3Z;ol0WT3o071<o`2<
A?l0NTWo0;hho`3E<ol0aSKo0080`cOo00T0SdCo0:Pmo`1MD_l0obWh0=hao`2S?ol0lbgo0<Hfo`23
Aol00P2W?_l0102?A?l0PDSo0=hao`1OR?l20;/io`0`08Y5o`1JDol0^CWo066@o`3m:ol0obCN0=Pb
o`2n>?l0Ldco0=Dco`2^??l0lbgo07E;o`2]??l0OTSo0?<]o`3<=Ol0HHgo0:<oo`1XCol0SdCo0=Pb
o`1GGOl0Fg?o07cdo`34=ol0SdCo0=Pbo`2X?Ol0H8So06A@o`2A@ol0F5Co0:4oo`1TD?l0HU7o07a9
o`1jBOl0obCQ06a>o`1FF_l0Xcoo06>Fo`2h>_l0oB_o0>@`o`3m:ol0hC3o0P3o6ZP04@3g;?l0SdCo
09A3o`3W;ol0OTSo07M:o`2I@Ol0SdCo08M6o`2N@?l0/c_o08Y5o`3oool0ccCo08E6o`2F@_l0acKo
0080oooo00@0eC?o0?ooo`3oool0obWl5@3oool004P0oooo00<0/c_o0?ooo`3j:ol00P1iB_l03P2S
?ol0`CSo0;0ko`23Aol0MD_o0;0ko`2n>?l0^3[o0:0oo`2[?Ol0_SSo07i8o`3Z;ol0UT;o0P2?A?l0
=P2<A?l0YCko09I2o`2S?ol0GE;o0<<go`3K<_l0PdOo08a4o`1nB?l0VD7o07=<o`2K@Ol0c3Go0:Dn
o`2h>_l0SdCo0;hho`36=_l0/3_o0=8do`2`>ol0kBko0;hho`3B=?l0PdOo0<Hfo`1ODOl0[Cco09=3
o`3W;ol0ccCo0<`eo`3W;ol0Ef3o0;/io`2`>ol0Vd7o0?lQd027A_l0ND[o07a9o`2c>ol0RTGo06R/
o`27A_l0eC?o0;0ko`3o:OP0Z3go0?lWlP23Aol0Zcgo08m4o`80[Sco00D0QDKo0=/bo`3o:O/0Z3go
0<`eo`020;<ko`0309]1o`2?A?l0Jdko0080ccCo00<0Md[o09I2o`2i>Ol00P36=_l02@3H<_l0jRoo
09i0o`3o9>40S4Co07Y9o`1iB_l0eC?o0<Hfo`020<<go`0908m4o`1IJOl0GE;o0?lYn03N<Ol0Xcoo
0?<]o`2S?ol0PdOo0080Ycko00<0SdCo0858o`3N<Ol00P2c>ol0A02k>Ol0MT_o05YCo`3I<_l0HI3o
0?d[o`2l>Ol0f3;o0;hho`1cC?l0lbgo0:hlo`3c;Ol0MD_o0:dlo`1nB?l0IZ?o0<`eo`23Aol0N>So
06Q?o`2?A?l0_SSo0:Hno`1KLol0Ef3o0?lOa`2?A?l0f3;o0:Pmo`2d>ol0I53o0953o`1JKol0XCoo
05elo`1RDOl0O4Wo07Y9o`3o9>40K4ko05IJo`1TD?l0HiKo05]co`3m:ol0i33o0?d[o`3Q<?l0mbco
0=Tbo`3g;?l0SdCo09A3o`3W;ol0OTSo07M:o`3`;Ol0SdCo08M6o`3oool0/c_o08Y5o`3oool0ccCo
08E6o`3oool0acKo0P3oool0103E<ol0oooo0?ooo`3o:O`E0?ooo`00BP3oool01@3j:ol0ND[o0?oo
o`2S?ol0`CSo0080/3_o03d0MD_o0;Hjo`2n>?l0NTWo0:0oo`2[?Ol0_SSo0818o`3Z;ol0UT;o08m4
o`2P?ol0S4Co0:Dno`2F@_l0Xcoo05eBo`33=ol0fc;o08=7o`2I@Ol0OTSo09U1o`20B?l0Vd7o0<`e
o`2U?_l0^3[o08m4o`2n>?l0aSKo0;0ko`3H<_l0/3_o0>d^o`2n>?l0dSCo08=7o`36=_l0PdOo0:dl
o`2C@ol0iboo0<ldo`2U?_l0iboo05MPo`2k>Ol0nR_o09]1o`3o8M00QdKo0:4oo`1lBOl0aSKo08Y5
o`1X[?l0QdKo0=Dco`2`>ol0obWh0080Z3go00X0PdOo0:/mo`2?A?l0`CSo0:hlo`25A_l0oB_o0?lY
n`2X?Ol0XCoo0P2c>ol0202K@Ol0IToo0<ldo`3?=?l0jRoo0=/bo`2F@_l0obKX0P36=_l02@3H<_l0
jRoo09i0o`3o9>40S4Co07Y9o`1iB_l0eC?o0<Hfo`020<<go`0408m4o`1IJOl0WT3o0?lYn080gS7o
00<0lbgo0:<oo`2k>Ol00P2W?_l00`2?A?l0obO^0=hao`020;<ko`0A0;/io`1fBol0IZCo0=Tbo`1Q
T?l0oB_o0;`io`1/C_l0_SSo07=<o`3c;Ol0dc?o0?<]o`1eBol0[Cco07i8o`1VXol00P23Aol0;01l
BOl0J4oo08E6o`2n>?l0YSko05MMo`1GH?l0oao707=<o`3H<_l0[Sco0;@ko`1TD?l0TD?o0?lWkP2Q
?ol0GGco0;hho`1lBOl0NTWo0?lTh@1/C_l0EU[o0?lXm@3Q<?l0P4So0?d[o`3T<?l0oB_o07I;o`3g
;?l0fC;o0?L/o`2?A?l0U4?o0=Pbo`3oool0Md[o0?0]o`2?A?l0QdKo0?ooo`2c>ol0RTGo103oool2
0<LfoaX0oooo001:0?ooo`050?X[o`1iB_l0oooo0:<oo`31>?l00P2`>ol02P1eBol0]S[o0;hho`1/
COl0X3oo0;Pjo`2n>?l0P4So0>X_o`2S?ol208m4o`1108a4o`2U?_l0UT;o0<`eo`1MD_l0jRoo0=/b
o`3H<_l0VD7o0818o`2I@Ol0P4So09]1o`3<=Ol0YCko07i8o`2?A?l0dSCo0<Hfo`2`>ol0f3;o09=3
o`3];_l0_SSo0;0ko`23Aol0aSKo08=7o`2]??l0Td?o08=7o`3?=?l0YCko0953o`1GH?l0^cWo0?X[
o`1FF_l0a3Oo08M6o`2Q?ol0I53o0<Hfo`2A@ol0J:co08M6o`1lBOl0/3_o0?lQd01RDOl0obOb08=7
o`2<A?l0oB_o0<4ho`2^??l0Z3go0?d[o`3o:O/0Z3go0:4oo`2c>ol0[Sco09]1o`1VCol00P3?=?l0
103Z;ol0fc;o09I2o`3o9^P20<Hfo`090=Pbo`3o8<`0WT3o0?lTh@2<A?l0P4So07U:o`1ND_l0aSKo
0080`cOo00h0f3;o06Y>o`2N@?l0obWh0=Dco`3N<Ol0lbgo0:<oo`2k>Ol0gS7o0;Pjo`2?A?l0obO^
0=hao`80/c_o00D0^cWo07I;o`1VY?l0fC;o0?lYn00209A2o`0306a>o`2n>?l0fc;o00<0lbgo02X0
MD_o0:dlo`2<A?l0GhSo06JSo`23Aol0O4Wo06Q?o`25A_l0_SSo0:Hno`1GGOl0Ef3o0?lOa`1cC?l0
f3;o0:hlo`2d>ol0QdKo0953o`3o9nh0HHgo0?ooo`2n>?l0O4Wo07Y9o`3[;_l0lbgo05IJo`3o:?D0
hC3o0818o`1KLol0i33o0?d[o`1fBol0mbco0=Tbo`2S?ol0]S[o09A3o`3H<_l20?ooo`030?0]o`3o
ool0QdKo02<0oooo001=0?ooo`1A0:<oo`20B?l0/3_o0;0ko`25A_l0]S[o0;hho`3E<ol0X3oo0;Pj
o`2n>?l0X3oo0>X_o`2S?ol0SdCo0:0oo`2<A?l0bCKo09I2o`3<=Ol0UT;o0>X_o`3K<_l0f3;o09U1
o`20B?l0Z3go0818o`2K@Ol0aSKo0:Dno`1nB?l0SdCo0=8do`36=_l0/3_o0=Pbo`2C@ol0kBko0?0]
o`2`>ol0PdOo0<Hfo`23Aol0[Cco09U1o`23Aol0HU7o0:Dno`2A@ol0Ef3o08Y5o`3j:ol0EU[o0<@g
o`3o8<T0XCoo06A@o`36=_l0TD?o06R/o`2K@Ol0O4Wo06^io`3o8M00HU7o0?lWlP3K<_l0S4Co0?d[
o`31>?l0[Sco0:Pmo`3m:ol0obWk0>L_o`2Q?ol0/c_o0:hlo`20B?l0IToo0080ccCo01l0jRoo0=/b
o`2U?_l0obKX0?ooo`2A@ol0f3;o0?lPc01IJ_l0obCQ0=hao`20B?l0Xcko05iBo`3F<ol0aSKo0<<g
o`3H<_l0JTko09i0o`3o:OP0eC?o0=hao`34=ol0HU7o0;/io`3N<Ol0^3[o08m4o`3o9nh0gS7o00<0
/c_o02H0IjKo0:<oo`39=_l0obWh066<o`2D@_l0mbco0;hho`3K<_l0ccCo0?<]o`3C<ol0F5Co0:dl
o`2<A?l0GhSo06JSo`23Aol0O4Wo06Q?o`25A_l0H8[o0:Hno`1GGOl0Ef3o0?lOa`1cC?l0K4ko0:hl
o`2d>ol0QdKo0953o`3o9nh0HHgo075<o`2n>?l0oB_o07Y9o`80jbko00@0FgGo0?lXm@3Q<?l0P4So
0P2^??l0203m:ol0MT_o0?lWkP3oool0Xcoo0;Hjo`3oool0f3;o0P3oool00`3`;Ol0oooo0?ooo`0S
0?ooo`00C@3oool0;`2S?ol0P4So0?ooo`2`>ol0QDKo0;Hjo`2n>?l0eC?o08M6o`2h>_l0_SSo0:0o
o`3Z;ol0Xcoo0:/mo`2P?ol0S4Co0<Tfo`23Aol0c3Go09I2o`3Z;ol0fc;o0=Pbo`1eBol0P4So0:Pm
o`20B?l0Vd7o0<Hfo`2F@_l0OTSo08m4o`1cC?l0aSKo0;0ko`2k>Ol0Td?o0>d^o`3`;Ol0/3_o08=7
o`20B?l0PdOo0:dlo`2I@Ol0I53o0080HU7o0200TD?o0:/mo`2:AOl0nR_o05IJo`34=ol0ob390:4o
o`1TD?l0aSKo0953o`31>?l0Vd7o05aCo`3d;Ol0ob7@069Ao`3o9o80fc;o08a4o`3m:ol0obK[0:hl
o`2X?Ol0Zcgo0?lYn`1cC?l0XCoo0;hho`2^??l0P4So08M6o`80ccCo01/0Zcgo0=/bo`2U?_l0obKX
0?ooo`2A@ol0SdCo0?lPc01IJ_l0obCQ0=hao`20B?l0Xcko0<@go`3F<ol0aSKo0<<go`3H<_l0JTko
09i0o`1VCol0eC?o0=hao`34=ol0HU7o0;/io`3N<Ol00P2h>_l09@3o9nh0hC3o0;<ko`3?=?l0/c_o
06NVo`2S?ol0bCKo0?lYn01QS?l0U4;o0?L/o`2n>?l0fc;o0<ldo`3c;Ol0dc?o05QDo`2]??l0S4Co
05n8o`1VXol0PdOo07a9o`1cC?l0QDKo062:o`2F@_l0S4Co05MPo`3o7lL0Ldco06a>o`1TVol0]3_o
08M6o`1bdol00P3o9nh03`1aC?l0_SSo0?d[o`3K<_l0EeCo0>/^o`1KMOl0obSe0>4`o`20B?l0oooo
0:hlo`3m:ol0oooo0?lWkP020?ooo`030;Hjo`3oool0f3;o0080oooo00<0l2go0?ooo`3oool08`3o
ool004h0oooo0500P4So0?ooo`2`>ol0Md[o0;Hjo`1MD_l0eC?o08M6o`2h>_l0YCko0:0oo`2:AOl0
Xcoo0:/mo`2P?ol0Zcgo0<Tfo`23Aol0c3Go05aCo`3Z;ol0fc;o0=Pbo`1eBol0P4So0:Pmo`20B?l0
^cWo0<Hfo`2F@_l0OTSo05MPo`1cC?l0VD7o0;0ko`2k>Ol0Td?o0>d^o`3`;Ol0aSKo08=7o`20B?l0
PdOo0<Hfo`2I@Ol0I53o07E;o`2f>_l0TD?o0:/mo`2:AOl0gS7o05IJo`34=ol0ob3907i8o`2?A?l0
jRoo0953o`31>?l0Vd7o05aCo`3d;Ol0ob7@069Ao`3o9o80fc;o08M6o`3m:ol0obK[0:hlo`3o7;<0
Zcgo0?lYn`1cC?l0XCoo0;hho`3?=?l0P4So08M6o`80ccCo00l0Zcgo0=/bo`2U?_l0obKX0<<go`2N
@?l0SdCo0?lPc034=ol0I53o0:hlo`2<A?l0Xcko0<@go`3F<ol00P36=_l0103H<_l0JTko05YCo`3N
<Ol20=Dco`0Q0<@go`1RDOl0UT;o0=hao`2K@Ol0^3[o0?lWkP3Q<?l0]S[o0<ldo`2c>ol0^cWo0:<o
o`39=_l0obWh066<o`1NPOl0mbco08m4o`3K<_l0ccCo0>4`o`3C<ol0F5Co0?lXm@2<A?l0GhSo06JS
o`3j:ol0O4Wo07=<o`25A_l0H8[o0080UT;o00X0KTgo0?lOa`2N@?l0K4ko06BKo`2A@ol0QdKo06^i
o`1JDol0obO^0P1aC?l03@3m:ol0fc;o05MDo`3[;_l0lbgo0?lXm@3Q<?l0P4So0?ooo`2^??l0kRko
0?ooo`3o9nh00P3oool00`2f>_l0oooo0?ooo`0X0?ooo`00D03oool05P2`>ol0Md[o0;Hjo`1MD_l0
K4go08M6o`2h>_l0YCko06Y>o`2:AOl0gS7o0:/mo`2P?ol0Zcgo0<Tfo`23Aol0c3Go05aCo`3Z;ol0
/c_o0=Pbo`1eBol20818o`1V0<4ho`2k>Ol0TD?o09I2o`1nB?l0Ef3o07M:o`2I@Ol0UT;o0;/io`2C
@ol0KTgo0?0]o`36=_l0UT;o0818o`23Aol0aSKo0;<ko`1TD?l0MD_o0;Hjo`2A@ol0Zcgo0<<go`3N
<Ol0EU[o075<o`3o8<T0OTSo08m4o`3Z;ol0TD?o0<4ho`2K@Ol0G5?o0?@]o`2?A?l0HU7o0?lWlP3K
<_l0QdKo0?d[o`3o9^/0[Sco0?lL/`2[?Ol0F6Ko07=<o`2Q?ol0_SSo0<ldo`36=_l0QdKo0>L_o`2^
??l0Zcgo0;0ko`3c;Ol0WT3o0<<go`2N@?l0SdCo06I?o`34=ol0I53o0:hlo`2<A?l0Xcko0<@go`3F
<ol0KTgo0<Hfo`2f>_l0Zcgo05YCo`3N<Ol0c3Go0=Dco`1RT?l0aSKo09I2o`3N<Ol0Vd7o0;Pjo`3H
<_l0hC3o0;Hjo`3?=?l0^cWo09i0o`2S?ol0bCKo0?lYn01QS?l0GX7o0?L/o`2?A?l0fc;o0<ldo`3Q
<?l0mbco0P34=ol03`2^??l0XCoo06JSo`3j:ol0O4Wo07=<o`1df_l0hC3o0>X_o`2F@_l0KTgo0:hl
o`2N@?l0K4ko06BKo`020953o`0=06^io`1JDol0obO^0?ooo`1aC?l0oB_o0=/bo`1GE?l0oooo0?<]
o`1KMOl0hC3o0818o`020?ooo`030>h^o`3oool0obO^02d0oooo001A0?ooo`0<07M:o`3oool0GE;o
07M:o`27A_l0L4co0:Dno`1ZC_l0RTGo0=hao`2[?Ol0a3Oo0P2[?Ol02P23Aol0c3Go05aCo`3Z;ol0
/c_o0;Pjo`1eBol0dSCo0818o`31>?l20;/io`0=09I2o`1nB?l0`CSo07M:o`2I@Ol0UT;o0;/io`2f
>_l0KTgo071<o`36=_l0UT;o0818o`020<Hfo`0F0;<ko`1TD?l0[Cco0;Hjo`3N<Ol0Zcgo0<<go`3N
<Ol0/c_o075<o`3o8<T0OTSo08m4o`3Z;ol0aSKo0<4ho`3Z;ol0dSCo0?@]o`2?A?l0lbgo09i0o`80
QdKo00D0ccCo0?lVj`3?=?l0oabc0?lRe`0207=<o`040:4oo`3Q<?l0ccCo0<Hfo`80iboo00X0[Sco
0>/^o`2`>ol0lbgo09i0o`33=ol0WT3o05YCo`1VCol0a3Oo0P2^??l08`2<A?l0QdKo0<@go`3==Ol0
KTgo0<Hfo`2f>_l0Zcgo08m4o`3N<Ol0c3Go0=Dco`3H<_l0aSKo09I2o`1eBol0Vd7o0;Pjo`3H<_l0
YSko0;Hjo`3?=?l0^cWo09i0o`2S?ol0^CWo0?lYn02<A?l0GX7o0?L/o`2?A?l0EEOo0<ldo`3Q<?l0
mbco0080a3Oo00D0[Sco0:4oo`2?A?l0nR_o0?lSfP020<ldo`070>4`o`3Z;ol0UT;o08a4o`2^??l0
WT3o07a9o`030953o`0:06^io`1JDol0FVoo0?ooo`1aC?l0ccCo0=/bo`1GE?l0oooo0?<]ocD0oooo
001C0?ooo`0U05eBo`1gB_l0QdKo071<o`2k>Ol0JTko08Y5o`2?A?l0Zcgo0<@go`2C@ol0Zcgo08=7
o`2X?Ol0Vd7o0=/bo`2X?Ol0^3[o07E;o`3B=?l0VD7o0<4ho`2<A?l0TD?o09I2o`1nB?l0`CSo07M:
o`2D@ol0UT;o0;/io`2f>_l0^cWo071<o`1HE?l0UT;o0818o`020<Hfo`0;0;<ko`1TD?l0[Cco0;Hj
o`3N<Ol0Zcgo0<<go`3N<Ol0/c_o07i8o`2U?_l00P2?A?l0403Z;ol0aSKo0<4ho`3Z;ol0dSCo0?@]
o`2?A?l0lbgo09i0o`27A_l0YSko0<ldo`3o9^/0ccCo0?lL/`3o8]L207=<o`040:4oo`3Q<?l0ccCo
0<Hfo`80iboo00@0[Sco0>/^o`2`>ol0lbgo0P33=ol0102N@?l0FU?o0?d[o`34=ol20:hlo`0:08a4
o`27A_l0a3Oo0<deo`1^COl0YCko0;Hjo`2[?Ol0SdCo0=hao`80c3Go00X0f3;o0<Hfo`1JKol0MD_o
05QSo`2K@Ol0f3;o0:Hno`2:AOl0ccCo0P2k>Ol01@2S?ol0^CWo0?lYn03o:OP0GX7o0080oB_o00<0
EUco08m4o`3Q<?l00P3g;?l01034=ol0[Sco0:4oo`2?A?l20?X[o`0?0?lSfP3?=?l0hC3o0>X_o`1n
B?l0S4Co06i=o`2N@?l0O4Wo0953o`3oool0TD?o06^io`3oool0FVoo0080oooo00<0ccCo0?ooo`3o
ool0=`3oool005@0oooo0340Md[o0?ooo`1`C?l0^cWo06Y>o`1GH?l0SdCo09]1o`34=ol0Td?o0:/m
o`2P?ol0Z3go09]1o`3K<_l0Z3go0;Pjo`1eBol0dSCo09U1o`31>?l0S4Co0953o`2N@?l0OTSo0<4h
o`1gB_l0U4?o09I2o`2k>Ol0]S[o0;/io`1`C?l0EEOo09I2o`2`>ol0aSKo0=8do`2c>ol0UT;o0:dl
o`3K<_l0gS7o05QSo`33=ol0gS7o0;<ko`1nB?l0YCko0080SdCo0140jRoo0<Hfo`3?=?l0jRoo0=8d
o`3d;Ol0GE;o0?<]o`1gB_l0QdKo0:Hno`3?=?l0obK[0<ldo`3o7;<0ob;G0=hao`0207=<o`030>4`
o`3B=?l0aSKo00<0iboo00<0jbko0:Pmo`3c;Ol00`33=ol00`1ODOl0oB_o0<@go`020:hlo`040=ha
o`27A_l0X3oo0<deo`80KTgo0300Jdko0:/mo`2?A?l0gS7o0<Lfo`3<=Ol0f3;o0<Hfo`1JKol0/c_o
05QSo`2K@Ol0gS7o0:Hno`2:AOl0ccCo07M:o`2k>Ol0WT3o0;Tio`2N@?l0S4Co0<Hfo`1RDOl0oB_o
05ILo`2?A?l0hC3o0;<ko`3g;?l0a3Oo0?lXm@2Q?ol0SdCo08M6o`3j:ol0ob?J0<ldo`3Q<?l0jRoo
07i8o`2<A?l0KTgo069Ao`1lBOl0TD?o0?ooo`2A@ol50?ooo`030<ldo`3oool0oooo03L0oooo001F
0?ooo`07071<o`2k>Ol0JTko0;hho`2?A?l0Vd7o0<@go`020:/mo`0V09=3o`2X?Ol0Vd7o0=/bo`2n
>?l0^3[o07E;o`3B=?l0VD7o0<4ho`2i>Ol0TD?o09i0o`2K@Ol0`CSo07M:o`1lBOl0UT;o071<o`2f
>_l0^cWo071<o`1EEol0UT;o0;0ko`36=_l0dSCo0;<ko`2F@_l0[Cco0=/bo`3N<Ol0F6?o0<<go`3N
<Ol0/c_o07i8o`2V?_l208m4o`0A0>d^o`36=_l0ccCo0>X_o`3B=?l0m2go05eBo`3c;Ol0Md[o08a4
o`2V?_l0ccCo0:<oo`3?=?l0f3;o0?lRe`3N<Ol00P1cC?l0103Q<?l0dSCo0<Tfo`2[?Ol20>L_o`04
0>/^o`2X?Ol0lbgo0:hlo`80`cOo00<0Ge7o0?d[o`2X?Ol00P2^??l0103N<Ol0Vd7o0:0oo`3o9nl2
0:Dno`0^06]>o`1KL_l0SdCo0:Dno`37=_l0c3Go0=Pbo`2f>_l0SdCo0;<ko`1HHol0/c_o0=hao`3j
:ol0RTGo0=Hco`1gB_l0^cWo09i0o`2U?_l0WT3o08a4o`36=_l0HU7o0?d[o`1FG?l0SdCo0?lOa@2c
>ol0mbco0<@go`3o:?D0XCoo08m4o`27A_l0nR_o0?lSfP3?=?l0hC3o0>X_o`1nB?l0oooo06i=o`1R
DOl0oooo0953od40oooo001F0?ooo`07071<o`1nB?l0oooo0;hho`1TD?l0Vd7o0<@go`020:/mo`0>
09=3o`3T<?l0Vd7o0=/bo`2n>?l0^3[o07E;o`2[?Ol0VD7o0<4ho`2i>Ol0QDKo09i0o`2K@Ol20<4h
o`0807a9o`1ZC_l0L4co06A@o`2k>Ol0Vd7o05EGo`2c>ol20;0ko`0A0=8do`2c>ol0UT;o0:<oo`3K
<_l0/c_o05QSo`33=ol0OTSo0;hho`1nB?l0YSko08m4o`1EEol0kBko09]1o`3?=?l00P3B=?l04P3d
;Ol0GE;o0?<]o`3N<Ol0S4Co0:Hno`3?=?l0Xcoo06U?o`3H<_l0i33o0=hao`3W;ol0Ldco069Ao`3B
=?l0bCKo0<ldo`80iboo00@0KTgo0:Pmo`39=_l0oooo0P33=ol02@1ODOl0oB_o0:Pmo`3T<?l0Zcgo
0=hao`2K@Ol0X3oo0?lWk`020:Dno`0Y0=0do`1KL_l0YSko0:Dno`37=_l0fc;o0=Pbo`2f>_l0SdCo
0;<ko`1HHol0/c_o0=hao`3j:ol0YSko0=Hco`1gB_l0YSko09i0o`2U?_l0SDCo08a4o`36=_l0HU7o
0?d[o`3g;?l0YCko0?lOa@2c>ol0Ldco0<@go`3o:?D0IToo08m4o`27A_l0G5;o0?lSfP3?=?l0MD_o
0>X_o`1nB?l00P3oool00`1RDOl0oooo0953o`110?ooo`00E`3oool05P1nB?l0oooo0;hho`2n>?l0
Vd7o0<@go`2[?Ol0X3oo09=3o`3T<?l0Vd7o0=/bo`2n>?l0EU[o0:Pmo`2[?Ol0VD7o07Y9o`2i>Ol0
QDKo09i0o`2K@Ol20<4ho`0Q07a9o`1ZC_l0TD?o06A@o`2k>Ol0Vd7o0?lYo02c>ol0/3_o0:<oo`3B
=?l0^cWo09I2o`2S?ol0fc;o0;<ko`2^??l0U4;o07i8o`2n>?l0WT3o0:Hno`2?A?l0EEOo0>d^o`2K
@Ol0ccCo0=8do`2<A?l0m2go0:4oo`2f>_l0gS7o0080S4Co0300QTKo0:<oo`1YCol0_SSo0>@`o`3N
<Ol0iboo0:<oo`1RDOl0SdCo0<Tfo`3?=?l0kRko0>L_o`1^COl0IToo0<Tfo`3oool0bCKo0<<go`1O
DOl0oB_o0:Pmo`3Q<?l0Zcgo0=hao`2K@Ol0i33o0?lWk`2:AOl0YCko0=0do`3Q<?l0YSko0:Dno`37
=_l0O4Wo0=/bo`2f>_l0SdCo0;<ko`36=_l0/c_o0=hao`3j:ol0YSko0=Hco`1gB_l20:Hno`0F0:Dn
o`2=A?l0hC3o0<Hfo`1RDOl0oB_o0?L/o`2U?_l0oao50;<ko`1cC?l0dSCo0?lXm@1VCol0Q4Oo08M6
o`1LD_l0ob?J0<ldo`1eBol0jRoo07i8odH0oooo001I0?ooo`0505MPo`1TD?l0Vd7o0:dlo`2[?Ol0
0P2P?ol0103T<?l0Vd7o08M6o`2n>?l20:Pmo`070:/mo`2I@Ol0NTWo0:Dno`25A_l0^cWo09]1o`02
0<4ho`0W0:Pmo`1ZC_l0TD?o06A@o`2k>Ol0Vd7o0?lYo02c>ol0PdOo0:<oo`3B=?l0^cWo07i8o`2S
?ol0_SSo0;<ko`2^??l0U4;o07i8o`2n>?l0WT3o0:Hno`1jBOl0EEOo0>d^o`2K@Ol0_SSo0=8do`2<
A?l0ccCo0:4oo`2f>_l0gS7o07=<o`2V?_l0QTKo0<4ho`1eBol0_SSo0080i33o0340iboo0:<oo`1`
C?l0SdCo0<Tfo`3?=?l0kRko08E6o`1^COl0IToo0:Pmo`1lBOl0bCKo0;/io`1VCol0ob;C0;Hjo`3Q
<?l0Zcgo08E6o`1JDol0i33o0?lWk`2:AOl0YCko0=0do`3Q<?l0YSko0<Hfo`37=_l0O4Wo0=/bo`2f
>_l0SdCo0<@go`36=_l0UT;o0;<ko`3j:ol0YSko0;Tio`20B?l0S4Co0:Hno`3j:ol0SDCo0>4`o`36
=_l0HU7o0080mbco00X0YCko0?lOa@2c>ol0Ldco0=8do`3o:?D0oooo08A7o`3oool0G5;oB`3oool0
05X0oooo00@0I53o0?ooo`2]??l0[Cco0P2P?ol0103T<?l0Td?o08M6o`39=_l20:Pmo`090:/mo`1g
B_l0NTWo0:Dno`1iB_l0^cWo09]1o`36=_l0`CSo0080Z3go02X0TD?o06A@o`20B?l0Vd7o0?lYo02c
>ol0PdOo0:<oo`25A_l0^cWo07i8o`2K@Ol0_SSo0;<ko`2^??l0YSko07i8o`27A_l0WT3o0:Hno`1j
BOl0YCko07Y9o`2N@?l0_SSo0:/mo`2<A?l0ccCo0:4oo`3<=Ol0gS7o07=<o`2V?_l0Zcgo0<4ho`1e
Bol0_SSo0>h^o`3N<Ol0iboo0:<oo`1`C?l208m4o`0B0<ldo`3^;_l0QDKo0;0ko`1ZC_l0Z3go07a9
o`39=_l0^cWo06I?o`3o8]<0]S[o0>4`o`3T<?l0QDKo05YCo`3T<?l0J4oo0P2:AOl06P3@=?l0hC3o
0;0ko`36=_l0[Sco07a9o`3K<_l0Kdgo0:hlo`34=ol0aSKo09I2o`2c>ol0Md[o08E6o`2i>Ol0P4So
08a4o`2V?_l0nR_o0>@`o`3Q<?l0UT;o0<ldo`3oool0mbco0P2F@_l01P3L<_l0oooo0=8do`3B=?l0
oooo08A7odd0oooo001L0?ooo`050:dlo`1MD_l0X3oo0:0oo`3T<?l00P2]??l06039=_l0EU[o09I2
o`2[?Ol0Md[o0;hho`2U?_l0ND[o0;/io`2K@Ol0aSKo0<4ho`2X?Ol0Zcgo0953o`2<A?l0P4So09=3
o`3o:O`0[Sco08=7o`2S?ol0QDKo07Y9o`80OTSo0380_SSo0;<ko`2^??l0YSko07i8o`27A_l0WT3o
0<ldo`1jBOl0YCko06NYo`2N@?l0_SSo0:/mo`2<A?l0Vd7o0:4oo`3<=Ol0gS7o07=<o`2V?_l0Zcgo
0<4ho`1eBol0c3Go0>h^o`3N<Ol0RTGo0:<oo`1`C?l0Md[o08m4o`3?=?l0Md[o08a4o`2`>ol0JTko
0:Pmo`1lBOl0[Sco0;/io`1VCol0ob;C0;Hjo`1_COl0i33o0;Hjo`1JDol0i33o0>4`o`80RTGo00/0
d3Co0>4`o`2`>ol0aSKo0:hlo`1lBOl0fc;o06m=o`2^??l0a3Oo0<Hfo`0209I2o`0@07M:o`25A_l0
^CWo0818o`2<A?l0ob[o0?X[o`3T<?l0hC3o09I2o`3?=?l0oooo0?L/o`2F@_l0oooo0=`bo`80oooo
00<0dSCo0?ooo`3oool0C@3oool005`0oooo05<0Md[o05eBo`2P?ol0X3oo0>@`o`2]??l0SdCo0<Tf
o`2I@Ol0UT;o09U1o`1gB_l0_SSo0:Dno`3Z;ol0^cWo09i0o`36=_l0P4So0:Pmo`2[?Ol0TD?o08a4
o`20B?l0U4;o0?lYo02^??l0PdOo08M6o`25A_l0NTWo0=hao`2K@Ol0_SSo0<ldo`2^??l0YSko0<4h
o`27A_l0WT3o0<ldo`3N<Ol0YCko06NYo`2N@?l0TD?o0:/mo`1lBOl0Vd7o09U1o`3<=Ol0X3oo07=<
o`2V?_l0Zcgo0?L/o`36=_l0c3Go0>h^o`3N<Ol0RTGo09i0o`1jBOl0Md[o0<Hfo`3?=?l0Md[o08a4
o`2`>ol0JTko0?ooo`1lBOl0[Sco0<`eo`1RTol0U4?o0?lXm02^??l0i33o0;Hjo`3Q<?l0ccCo0>4`
o`0208Y5o`0;05j1o`3Q<?l0/3_o0;Hjo`2^??l0oooo07a9o`2U?_l0[Sco066=o`36=_l00P2F@_l0
403E<ol0QDKo0;hho`3oool0S4Co0?lZo`3j:ol0i33o0>D`o`2F@_l0ccCo0?ooo`3g;?l0UT;o0?oo
o`3L<_l20?ooo`030=8do`3oool0oooo04d0oooo001M0?ooo`0J05eBo`2N@?l0X3oo0:/mo`2]??l0
SdCo0<Tfo`2I@Ol0UT;o09U1o`3H<_l0_SSo0:Dno`3Z;ol0^cWo09i0o`36=_l0P4So0<@go`2[?Ol0
TD?o08a4o`2U?_l0U4;o09i0o`2^??l208M6o`130;/io`1jBOl0gS7o09]1o`2n>?l0ccCo08a4o`2V
?_l0`CSo08M6o`1lBOl0ccCo0=hao`2U?_l0_SSo0;0ko`2A@ol0Zcgo07a9o`2K@Ol0VD7o0<`eo`2P
?ol0Ldco0<@go`2[?Ol0mbco0<Hfo`3<=Ol0kRko0818o`3o9^/0WT3o07Y9o`1gB_l0aSKo0:/mo`27
A_l0S4Co0<Hfo`2[?Ol0oooo07a9o`2^??l0c3Go06:Co`2D@ol0obSd0:hlo`3T<?l0]S[o0>4`o`3?
=?l0hC3o05]bo`3?=?l0IjKo09=3o`2`>ol0]S[o0:hlo`3o7KX0O4Wo0:Dno`2^??l0S4Co08m4o`02
09I2o`050=Dco`3o:_h0_SSo0?ooo`2<A?l00P3o:_l0103T<?l0iC3o0?ooo`3?=?mG0?ooo`00GP3o
ool0202N@?l0oooo0:/mo`2C@ol0SdCo0<Tfo`2I@Ol0aSKo0P2I@Ol0CP2n>?l0YCko0>X_o`2F@_l0
WT3o06Y>o`20B?l0a3Oo0:/mo`2n>?l0S4Co0:Dno`2D@_l0WT3o0:hlo`27A_l0[Sco0;/io`23Aol0
gS7o09]1o`2N@?l0ccCo08a4o`3?=?l0`CSo08M6o`1lBOl0ccCo0=hao`2n>?l0fc;o0;0ko`2A@ol0
Zcgo07a9o`1aC?l0VD7o0:Pmo`2P?ol0UT;o0<@go`2?A?l0mbco0<Hfo`3<=Ol0kRko0818o`3o9^/0
WT3o07Y9o`3c;Ol0aSKo0:/mo`27A_l0S4Co0<Hfo`2[?Ol0/3_o07a9o`3Q<?l0c3Go0;Hjo`3I<_l0
obSd0:hlo`3Q<?l0]S[o0>4`o`3m:ol0hC3o05]bo`36=_l0IjKo09=3o`1nB?l0]S[o0:hlo`80oafj
00T0YCko07=<o`2<A?l0SdCo0:Pmo`3oool0eC?o0?lZoP2n>?l00P3oool20?lZo`040?ooo`3U<?l0
oooo0<ldoeL0oooo001N0?ooo`80WT3o02<0Zcgo09=3o`2?A?l0Z3go09U1o`36=_l0Ldco0=Pbo`2n
>?l0Xcoo0>X_o`2F@_l0WT3o06Y>o`20B?l0K4ko0:/mo`2n>?l0VD7o0:Dno`2C@ol0WT3o0:hlo`27
A_l0[Sco0;/io`23Aol0gS7o08Y5o`2N@?l0RTGo08a4o`3?=?l0`CSo071<o`0207a9o`0?0=hao`2n
>?l0fc;o0;0ko`2A@ol0GE;o07a9o`1aC?l0Xcoo0:Pmo`2P?ol0UT;o0<@go`2?A?l0mbco0080aSKo
01T0obK[07WZo`3o9^/0Ef3o07Y9o`3c;Ol0aSKo0:/mo`27A_l0Ldco0<Hfo`2[?Ol0/3_o0:Hno`3Q
<?l0SdCo0;Hjo`3I<_l0obSd0:hlo`3Q<?l0Xcoo0>4`o`3m:ol0hC3o0080aSKo00D0IjKo09=3o`1n
B?l0EUWo0:hlo`020?lM^P080:Dno`1cC?l0S4Co08m4o`2X?Ol0oooo0=Dco`3o:_h40?ooo`030?lZ
o`3oool0oooo05T0oooo001P0?ooo`0;0:/mo`2C@ol0oooo0:Pmo`2D@ol0aSKo07=<o`3H<_l0_SSo
0:<oo`1iB_l00P2F@_l0301ZC_l0ND[o06a>o`2U?_l0_SSo09U1o`2U?_l0a3Oo09i0o`2h>_l0iboo
0:hlo`80PdOo01l0gS7o08Y5o`2N@?l0RTGo08Ooj@3?=?l0`CSo071<o`2[?Ol0O4Wo0=hao`2n>?l0
fc;o0;0ko`1nB?l0GE;o07a9o`1IJOl0Xcoo0:Pmo`2<A?l0UT;o0;Hjo`2?A?l0VD7o0<Hfo`3<=Ol0
obK[0818o`3o9^/0Ef3o0080lbgo00`0aSKo0;Hjo`27A_l0Ldco09I2o`2[?Ol0/3_o0:Hno`3Q<?l0
SdCo0;Hjo`3I<_l20:hlo`050>4`o`2S?ol0gS7o0?d[o`1VCol00P36=_l02`3?=?l0]S[o05j1o`1F
FOl0YSko0?ooo`3o7KX0IToo0?ooo`2<A?l0oooo0080Z3go00<0oooo0?lZoP3oool00`3oool00`3o
:_l0oooo0?ooo`1I0?ooo`00H@3oool0602C@ol0oooo0:Pmo`2D@ol0aSKo07=<o`3H<_l0Vd7o0:<o
o`1iB_l0QdKo09i0o`2U?_l0ND[o0:<oo`2U?_l0QDKo09U1o`2U?_l0a3Oo0953o`2h>_l0iboo0:hl
o`80PdOo00T0gS7o08Y5o`1FF_l0RTGo08Ooj@3?=?l0`CSo071<o`2[?Ol00P2k>Ol0502D@ol0fc;o
0;0ko`1nB?l0/c_o07a9o`1IJOl0Xcoo0:Pmo`2<A?l0`CSo0;Hjo`2`>ol0VD7o07U:o`3<=Ol0obK[
0818o`3o9^/0/c_o0P3c;Ol03036=_l0]S[o08M6o`2S?ol0UT;o0?ooo`2`>ol0YSko0:hlo`2?A?l0
]S[o0=Tbo`80[Sco00D0Kdgo0:<oo`3N<Ol0oB_o05eoo`020<Hfo`0<0<ldo`2f>_l0GX7o0?ooo`2V
?_l0oooo0?lM^P1VCol0oooo08a4o`3oool0Z3goH`3oool006<0oooo0240Xcoo09A3o`36=_l0Ldco
0=Pbo`2K@Ol0gS7o07U:o`2k>Ol0WT3o0:Dno`1iB_l0Xcoo0:Dno`25A_l0VD7o0;/io`34=ol0TD?o
0;Pjo`3W;ol0[Sco0;/io`23Aol0F6?o05QDo`1FF_l0Vd7o09i0o`3?=?l0H8Wo0:hlo`2[?Ol00P2k
>Ol08P2D@ol0fc;o0;0ko`1nB?l0/c_o09i0o`1IJOl0Xcoo0:/mo`2<A?l0`CSo0;Hjo`2`>ol0HHgo
07U:o`3<=Ol0obK[0818o`1iB_l0/c_o0=Dco`3c;Ol0SdCo0;Hjo`27A_l0Xcoo09I2o`3oool0/3_o
08a4o`2^??l0PDSo0;Hjo`2i>Ol20?lVj00906m=o`3N<Ol0gS7o0;hho`1MOol0oooo0<Hfo`3?=?l0
]S[o0080oooo00<0YSko0?ooo`3o7KX0J03oool006<0oooo00@0Xcoo09A3o`3<=Ol0Ldco0P2F@_l0
4`3N<Ol0ND[o0;/io`2N@?l0YCko07E;o`2S?ol0XCoo08E6o`2I@Ol0^cWo0<@go`2A@ol0bCKo0>L_
o`2^??l0^cWo0<Hfo`25A_l00P1HE?l01P2K@Ol0WT3o0<ldo`2[?Ol0[Sco0:/mo`80_SSo00`0U4?o
0=/bo`27A_l0PdOo0;<ko`2N@?l0FFWo0:<oo`2[?Ol0Td?o0<4ho`2K@Ol20;0ko`0:07U:o`3<=Ol0
Z3go0818o`27A_l0/c_o0=Dco`3c;Ol0SdCo0;hho`80Xcoo00P0^cWo0?ooo`2`>ol0S4Co0:hlo`21
B?l0WT3o0;Tio`80obKX00P0QdKo0=hao`3N<Ol0_SSo05eoo`3oool0aSKo0<ldofh0oooo001T0?oo
o`0309A3o`3<=Ol0oooo0080UT;o01/0gS7o0?lVj02k>Ol0PdOo0:Dno`1eBol0Xcoo05QWo`25A_l0
^3[o0;/io`2X?Ol0UT;o0<Tfo`3W;ol0WT3o0;/io`36=_l0QDKo05QDo`2c>ol0Vd7o09i0o`2V?_l0
Zcgo0:hlo`2;AOl00P2n>?l0602D@ol0fc;o08M6o`23Aol0/c_o09i0o`1IJOl0XCoo0:/mo`2C@ol0
`CSo09]1o`2I@Ol0HHgo07U:o`3W;ol0Z3go0818o`27A_l0/c_o0=Dco`36=_l0obCQ0;hho`80Xcoo
00d0^cWo0>4`o`1cC?l0S4Co07=<o`2?A?l0WT3o0:hlo`3oool0obKX08M6o`3N<Ol0c3Go00@0oooo
00<0ccCo0?ooo`3oool0K03oool006D0oooo03/0c3Go0?ooo`2F@_l0O4Wo0=hao`3o9^P0^cWo08=7
o`2I@Ol0MD_o0:<oo`1HIol0QDKo0;Pjo`1cC?l0Z3go09I2o`39=_l0iboo09i0o`1NOol0aSKo08E6
o`1ZC_l0/c_o09]1o`2N@?l0YSko0:/mo`2^??l0RdGo0;/io`1QT?l0U4?o05aCo`27A_l0PdOo0;Hj
o`2N@?l0J4oo0:4oo`2[?Ol0Td?o05iBo`2K@Ol0VD7o08m4o`1TD?l0iboo0:Pmo`2[?Ol0QdKo0<Hf
o`3E<ol0aSKo0?lTh@2n>?l0Xcoo09]1o`020;/io`0;07=<o`2f>_l0Ldco08m4o`2N@?l0[Sco0?oo
o`3o9^P0QdKo0?ooo`3<=Ol0L`3oool006D0oooo00L0c3Go0?ooo`2F@_l0O4Wo0=hao`3o9^P0WT3o
0080PdOo03`0MD_o0:dlo`1HIol0OTSo0;Pjo`1cC?l0Xcoo09I2o`39=_l0iboo09i0o`1NOol0aSKo
08E6o`1ZC_l0/c_o09]1o`2N@?l0HY?o0:/mo`1nB?l0RdGo0;/io`31>?l0VD7o05aCo`27A_l0PdOo
0;Hjo`2N@?l0J4oo0:4oo`2f>_l0WT3o05iBo`25A_l0VD7o08m4o`1TD?l0iboo0:Pmo`2[?Ol0QdKo
0<Hfo`3E<ol0aSKo0?lTh@2k>Ol0Xcoo09]1o`2k>Ol0hC3o07=<o`2f>_l0oooo08m4o`3oool0[Sco
0?ooo`3o9^P20?ooo`030<`eo`3oool0oooo0740oooo001X0?ooo`0X07a9o`1HE?l0obKX09i0o`2c
>ol0VD7o07E;o`2]??l0UT;o07i8o`1RDOl0Ldco0:<oo`2F@_l0bCKo08a4o`2k>Ol0Zcgo0;hho`25
A_l0Ldco0;<ko`23Aol0WT3o06:Co`2`>ol0OTSo08]5o`2^??l0`CSo09U1o`1nB?l0QdKo0:hlo`2f
>_l0WT3o06Q?o`2U?_l0]S[o09i0o`80QDKo01@0VD7o08m4o`2c>ol0EEOo0:Pmo`2[?Ol0Fg?o0<Hf
o`3E<ol0U4?o0?lTh@2k>Ol0LDco09]1o`3oool0hC3o0?ooo`2f>_l0oooo08m4ogX0oooo001Y0?oo
o`0F05QDo`3o9^P0WT3o0;<ko`2I@Ol0OTSo0:dlo`2F@_l0U4?o069Ao`1cC?l0WT3o09I2o`2D@ol0
obWh0;/io`2[?Ol0_SSo08E6o`1cC?l0/c_o08=7o`80O4Wo00l0/3_o07i8o`2n>?l0[Sco0<4ho`2I
@Ol0OTSo08E6o`2^??l0]S[o0;hho`1VYOl0YCko0;Hjo`2N@?l00P25A_l03@2I@Ol0SdCo0;<ko`1Q
SOl0G5?o0:/mo`1KLol0aSKo0=Dco`2D@ol0obCQ0;/io`1aC?l00P3oool00`3Q<?l0oooo0;Hjo`1l
0?ooo`00J`3oool0502N@?l0Ge7o09U1o`1nB?l0[Cco09I2o`2D@ol0HU7o07=<o`2N@?l0S4Co09A3
o`3`;Ol0^cWo0:/mo`2n>?l0Zcgo07=<o`1FF_l0PdOo0P1lBOl03`2`>ol0OTSo0;hho`2^??l0`CSo
05ioo`1nB?l0QDKo0:hlo`2f>_l0_SSo06JUo`2U?_l0UT;o0;Hjo`0208E6o`0406A@o`2?A?l0/c_o
066=o`80G5?o00D0Fg?o0<Hfo`1OQOl0oooo0=Dco`040?ooo`030>4`o`3oool0oooo07`0oooo001[
0?ooo`0<09i0o`1ODOl0Ldco07i8o`1cC?l0PDSo09A3o`1RDOl0P4So09i0o`2<A?l0aSKo0P3o:OP0
7@2[?Ol0_SSo0:/mo`2c>ol0EU[o07=<o`2I@Ol0O4Wo0;0ko`1PDOl0_SSo0:/mo`31>?l0GWoo05eB
o`25A_l0[Sco05QWo`2n>?l0GE;o05QSo`2F@_l0]S[o08E6o`3E<ol0I53o0:<oo`2c>ol0HHgo00H0
oooo00<0eC?o0?ooo`3oool0P@3oool006d0oooo02P0Ldco0?ooo`1cC?l0PDSo09A3o`1/C_l0P4So
08E6o`2<A?l0aSKo0?lYn01RDOl0Zcgo09]1o`2[?Ol0/c_o0:0oo`1cC?l0VD7o07a9o`2`>ol0H57o
0;hho`2[?Ol0ND[o0:/mo`1MD_l0QDKo0:hlo`2N@?l0QdKo05eBo`1HHol0oooo0;Hjo`25A_l0eC?o
0?ooo`2S?ol0/c_oR`3oool006l0oooo01h0Ldco08m4o`2D@ol0K4ko0818o`25A_l0obSe0<Hfo`3o
:OP0HU7o0:/mo`2K@Ol0Ldco0;<ko`2P?ol0FU?o09U1o`1lBOl0FFWo05n5o`1ZC_l0Zcgo07U:o`2[
?Ol0GE;o08E6o`2c>ol0WT3o08M6o`1MD_l20?ooo`050;Hjo`3oool0eC?o0?ooo`2S?ol0S03oool0
06l0oooo01h0Ldco08m4o`25A_l0K4ko0:<oo`25A_l0obSe0<Hfo`3`;Ol0HU7o08m4o`2K@Ol0Ldco
0;<ko`2P?ol0FU?o09U1o`1lBOl0FFWo05n5o`1ZC_l0`cOo0?ooo`2[?Ol0GE;o09I2o`2c>ol0WT3o
0?ooo`1MD_l20?ooo`030;Hjo`3oool0eC?o08h0oooo001`0?ooo`0308m4o`25A_l0oooo0080^cWo
00d0obSe0<Hfo`33=ol0Vd7o08m4o`3E<ol0Ldco09i0o`2P?ol0UT;o09U1o`2N@?l0^cWo0080GhGo
00L0`cOo0?ooo`2[?Ol0oooo09I2o`2c>ol0WT3o09D0oooo001a0?ooo`80QDKo0P2k>Ol03@3o:?D0
aSKo0<<go`2K@Ol0SdCo0=Dco`1lBOl0WT3o0:0oo`2F@_l0VD7o09i0o`2k>Ol00P3oool01`33=ol0
oooo0:/mo`3oool0UT;o0?ooo`2N@?l0U@3oool007<0oooo00l0Xcoo08m4o`3o:?D0Td?o0<<go`2K
@Ol0S4Co0=Dco`1lBOl0WT3o05n5o`2F@_l0QDKo09i0o`2k>Ol0103oool00`2[?Ol0oooo0?ooo`2G
0?ooo`00L`3oool03`2S?ol0SdCo0?lXm@2C@ol0Ef3o09]1o`2<A?l0eC?o07a9o`2N@?l0GhGo0?oo
o`25A_l0oooo0;/io`2N0?ooo`00M@3oool01`2?A?l0oooo09i0o`3oool0S4Co0?ooo`1lBOl0Y03o
ool007D0oooo00D0SdCo09i0o`2N@?l0oooo08a4o`2V0?ooo`00MP3oool209i0ojP0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo001O0?ooo`900000_`3oool00640oooo00=000000?ooo`3oool0_03o
ool005<0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00A000000?ooo`3oool0oooo0d00
00050?ooo`03@000003oool0oooo00T0oooo0T0000030?ooo`9000000P3oool3@00000<0oooo0T00
00020?ooo`=000003P3oool2@00000<0oooo0T0000020?ooo`=000000`3oool2@00000<0oooo0T00
00020?ooo`=000000P3oool2@00005h0oooo001D0?ooo`03@000003oool0oooo00<0oooo00E00000
0?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00L0oooo00=000000?ooo`3oool0403o
ool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0
oooo@00000020?ooo`04@000003oool0oooo@00000l0oooo0T0000020?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool00P3oool01T000000oooo0?oood000000oooo@0000080oooo00A0
00000?ooo`3ooom000001@3oool00d000000oooo0?ooo`1K0?ooo`00E03oool00d000000oooo0?oo
o`030?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`080?ooo`03@000
003oool0oooo00l0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000020?ooo`05
@000003oool0oooo0?oood0000000P3oool014000000oooo0?oood00000>0?ooo`05@000003oool0
oooo@000003oool00d0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3o
ool014000000oooo0?oood0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool0
G03oool005@0oooo0T0000030?ooo`900000103oool3@00000X0oooo00=000000?ooo`3oool03`3o
ool00d000000oooo0?ooo`030?ooo`9000000`3oool00d000000oooo0?ooo`020?ooo`9000000P3o
ool4@00000/0oooo0T0000020?ooo`03@000003ooom00000009000000P3oool3@00000030?oood00
00100000009000000`3oool2@0000080oooo140000020?ooo`900000G@3oool005@0oooo00A00000
0?ooo`3ooom000004`3oool00d000000oooo@000000@0?ooo`03@000003ooom0000000P0oooo00=0
00000?ooo`3oool09@3oool00d000000oooo0?ooo`1/0?ooo`00D`3oool5@0000080oooo00=00000
0?ooo`3oool03`3oool00d000000oooo0?ooo`0?0?ooo`=000001`3oool2@00009H0oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {188.688, 0}} -> {-0.0447462, 0.137829, 
  0.00363509, 0.00363509}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
%%ImageSize: 200 20 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00238095 0.952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00238095 0.97619 0.097619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0874126 0.00192308 0.0480769 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .00192 translate
.96154 .09616 scale
33 string
11 2 8 [11 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFF5E6F5FFCCC2FFB399FFC280FFFF66A3FF704CFFD733FFFF19A3FF0000
FFFFFFFFF5E6F5FFCCC2FFB399FFC280FFFF66A3FF704CFFD733FFFF19A3FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{200, 20},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400038000052000`400?l00000o`00003ob03oool0
0<P0oooo000L0?oooa00ooGV403eol`?0<;o/a00VOo24020ool@06JSoa00L4co3`3G<ol@0?lIXa00
o`003P3oool001`0oooo403omNH@0?Goc0l0`_nc402Iol8@083ooa00IZ?o401`C?l?0=Lcoa00oaVS
403o000>0?ooo`00703oool@0?oeiQ00mOo<3`32ok<@09Wo`Q00P?oo401VXol@071<o`l0ec?o403o
6J<@0?l000h0oooo000L0?oooa00ooGV403eol`?0<;o/a00VOo24020ool@06JSoa00L4co3`3G<ol@
0?lIXa00o`003P3oool001`0oooo403omNH@0?Goc0l0`_nc402Iol8@083ooa00IZ?o401`C?l?0=Lc
oa00oaVS403o000>0?ooo`00703oool@0?oeiQ00mOo<3`32ok<@09Wo`Q00P?oo401VXol@071<o`l0
ec?o403o6J<@0?l000h0oooo000L0?oooa00ooGV403eol`?0<;o/a00VOo24020ool@06JSoa00L4co
3`3G<ol@0?lIXa00o`003P3oool001`0oooo403omNH@0?Goc0l0`_nc402Iol8@083ooa00IZ?o401`
C?l?0=Lcoa00oaVS403o000>0?ooo`00703oool@0?oeiQ00mOo<3`32ok<@09Wo`Q00P?oo401VXol@
071<o`l0ec?o403o6J<@0?l000h0oooo000L0?oooa00ooGV403eol`?0<;o/a00VOo24020ool@06JS
oa00L4co3`3G<ol@0?lIXa00o`003P3oool001`0oooo403omNH@0?Goc0l0`_nc402Iol8@083ooa00
IZ?o401`C?l?0=Lcoa00oaVS403o000>0?ooo`00703oool@0?oeiQ00mOo<3`32ok<@09Wo`Q00P?oo
401VXol@071<o`l0ec?o403o6J<@0?l000h0oooo000L0?oooa00ooGV403eol`?0<;o/a00VOo24020
ool@06JSoa00L4co3`3G<ol@0?lIXa00o`003P3oool001`0oooo403omNH@0?Goc0l0`_nc402Iol8@
083ooa00IZ?o401`C?l?0=Lcoa00oaVS403o000>0?ooo`00703oool@0?oeiQ00mOo<3`32ok<@09Wo
`Q00P?oo401VXol@071<o`l0ec?o403o6J<@0?l000h0oooo000L0?oooa00ooGV403eol`?0<;o/a00
VOo24020ool@06JSoa00L4co3`3G<ol@0?lIXa00o`003P3oool001`0oooo403omNH@0?Goc0l0`_nc
402Iol8@083ooa00IZ?o401`C?l?0=Lcoa00oaVS403o000>0?ooo`00703oool@0?oeiQ00mOo<3`32
ok<@09Wo`Q00P?oo401VXol@071<o`l0ec?o403o6J<@0?l000h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 199}, {19, 0}} -> {-0.0498739, -0.00250052, 
  0.00552637, 0.00552637}, {{9, 189.938}, {18.5, 
  0.4375}} -> {-0.79998, -0.0975889, 0.0633363, 0.115157}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function VectorMag3D",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Since each of the vector lengths corresponds to light reflection strength, \
a comparison between the vector distribution and color bar reveals that a \
light reflection strength of the wall is not uniform but somewhat random \
nature. Reader may suppose that this sample concrete wall has several cracks. \
In order to confirm this, we compute a distribution of vector magnitudes in \
Fig. 2 by a following ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]vectorMag3D\[CloseCurlyDoubleQuote]. A \
parameter \[OpenCurlyDoubleQuote]vectorData3D\[CloseCurlyDoubleQuote] refers \
to the three-dimensional vector data.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
vectorMag3D=Compile[{{vectorData3D,_Real,3}},
\tModule[{mag={{0.}},max=0.,min=0.,i=0,j=0,dim={0}},
\t\tdim=Dimensions[vectorData3D];
\t\tmag=Sqrt[Table[vectorData3D[[1,i,j]]^2+
\t\t\tvectorData3D[[2,i,j]]^2+
\t\t\tvectorData3D[[3,i,j]]^2,
\t\t\t{i,dim[[2]]},{j,dim[[3]]}]];
\t\tmin=Min[mag];max=Max[mag-min];
\t\tIf[max=!=0.,Return[(mag-min)/max],
\t\t\tPrint[\"Zero vectors !\"];
\t\tReturn[mag]]]];\
\>", "Input",
  CellLabel->"In[27]:=",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Using this function, we compute the magnitude of the characteristic \
vectors in Fig. 1.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["vectMag=vectorMag3D[sample];", "Input",
  CellLabel->"In[28]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After that, we construct an image data of the vector magnitude \
distribution.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
vectMagG=ListDensityPlot[vectMag,
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->\"Vector magnitude\",
\tDisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[29]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Before simply plotting the vector magnitude image, we classify the vector \
magnitude distribution into 5 levels by their magnitude, and then we \
construct the classified image data. Figure 3 shows the classified vector \
magnitude distributions.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
nx=5;
vectMagCG=ListDensityPlot[1. Round[nx vectMag]/nx,
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"Classified``\",nx],
\tColorFunction->hueColor,DisplayFunction->Identity];
Show[GraphicsArray[{vectMagG,vectMagCG}],
\tPlotLabel->\"Fig.3. Vector magnitude distribution\",
\tImageSize->{400,200}];
Show[GraphicsArray[{colorBar5}],ImageSize->{400,20}]; \
\>", "Input",
  CellLabel->"In[30]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -110 0 ]
[.5 .48869 110 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -171 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vector) show
147.000000 12.812500 moveto
(magnitude) show
207.000000 12.812500 moveto
(distribution) show
279.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -50 0 ]
[.5 1.0125 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vector) show
105.000000 12.812500 moveto
(magnitude) show
159.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CBC3C7B7C4BBC2C0B7C0BEC7BFB6ABB0B1B9B9BDB4ADB4A8
D0ACB0B9B9B1BDBDB7C4D1BDBFC8C4C2BDC1C192C4B9C4B7
BDA8BDCCBFC0C6BAB4C8A08CC0C2B5A08EB2BFC4BFC2CAB6
95C6C5BCC1C9C9CFC8BECBBFC4BFB5C6C7C5C4C6BDC6C2A8
B8BEC4C8C4C1B8C8BBD0C6C2C6C7C3C2C9CBCBD1B4BCC8B8
B1C5BEBDBBC4C6C1
B8C1C2AFC9C5C2C0CFC4D5C8BCC5BAB2BCB4C2B8BCB8C246
D3BAAFB7ADB4BEBFB2B8DBC1C8B9AEB5CFC2C6CFB6C2BBBD
BDBFA7B4CF8AB8CDADD3AFA0BBB7AFCDBEA5C084ABBFB0BB
C2B1BECCD0B9BCC8C2C6BDC4C2B2B7BCC1CBD0BBCDB1C9C2
BEC2B1BFC9BFCCC2BECBD1CDCFC5B0C7C4C8C2B2CEB1CAD0
A0BACBCBC7B8B5CB
C0C0BDB9BDA9B4C7C6C9C4B8BDB5B8BAC0C4B7BDBBC6C0A7
BBB9B5ACBBB6B9B6CBAEC9C1B9C69EC7C7CBCFC6BAACC4C4
B8B2C8C4C4BEC9BCC7AEA79FB6A7B7C2B8BACFB7B0A7C4C0
BBC0C0C2C6D3BEC8C8BCB2C6CBC0C4C6C7C7CBC5C1CFC9AD
B0C0CEBDC3BCC6C6C0C2CDCBB2C3B5BCC7BCD3CFC4B5D5C7
B0C2BCC7C0C9B3C4
B6B5C7B2AEAAB4BABDB4C9ABC6BFBDB9CBC0C0C4C4C0C2BE
A1B2C2B6BFBABAA4B7D3D8C2C6C0C7BFC2A7BCAFC1CBBBB2
BABC91BEB3C5CBC7C9B48F79BBABB9C7A3B4B8A9B0D0BDB7
CBC2C0C6C6B3CAC6BCB2A9CCBDA7CEC4CAC0C0C8BEDAC4B6
BDB9C9C9BEC4C9C1BDD0C4C9C7D3B2C2B9C4BFB7E1C4E3C4
B7CDBCA7BDA7C2BC
C4C0B9C9B8BABFBBB3D6CFB3B0B6B8B5C2C0C0C2B7B2C0CB
C1C2C295B4B8A7BCC0C3CBB7B5C7B4BCC6C6C6B8B79DB4A9
C2B2C8D0B9BFBBA6C9AD8C86B4AAB8D4A2B3BFB2C436B7BA
C2C7B2BAB9ACB9BDBFB2B5C2B4C4C9C9C0B7CACBB8C4BABA
D1C7D1C9C8C2C6B8C6B9BBC0CDAFCEC2C4C9C6D2B8A1C4AE
CDBCBEB5BBB7AEB0
B1C5BEB8D1CBBCC0BACAC5CBB6BBC6BAC7C0C6B5BCBCBADE
9587A9A980A7B5BABDC0D2C4CEC9B9CDCDBCAEB4A1BFD5AE
C0BAB2BEB0C8BDBBBDCA8989A7C6A0B8BCB6B9BDBBCAC0C2
B4ABB3C2B9C7BFC8C2C0C4BFC6C0D0C2C4C0C2A7C0B4BCBC
B4C4C3A9C3C8CCC0C9C2CCCAD1C2C7C6D3BCCDABB4C6BBB2
C7C1C3B9BDBEC4BE
C1AFB8C1B9BBBAC086ABB0C9C6C1B9BCBFC0A0C7B9D0ACD3
C4B1C4BAABBBA99FC8A7D9C4C9C7B3C6C2BFCDD0C2AACBBD
C0C7C4CBB4B0A7C8C5BB838AB9BA9CB4B7ABBBCF5DABD2B8
BBC0C2C2BEB4ABC2C9BBC4BFC0C2BEC0C4C9B6CAD0BAABB6
C5BCC4CEC4C6B7C4C6CFC8C8BFC6C0BFC9D3D1CCCFC4CCBA
C4B9C2C6C8C0CBC2
C098BACDC0B4C9C9B0CBBEC7C7C8C3C2C7BCBEB2A9B5B2BD
ADB9A3C4B5B5B7B4AFB8CBC9C4CAB0BDC6C2C4C9BEC0CDC6
BAC1C4DDA2BABFC9C7C4A08ACEABC0B69EA7BBC0C9BED1A7
BBC9CFBEBFB5B4C2C4C4BEC7C4B4AEC3C6C2C8C0BDABB4C8
D1D5CEC8C2BC9EC8CDC8CCCCCEC6C8C1CD93B8BEB6B0C0C4
C8C0B5B0C2C6BFD0
ADA7BDA7C0C9B4ABA7B4ADD1C7C1BBAEAFC6B8C4ACB9BDB5
B895BAC9B2BFC3B8AEA1B8C4C5BBC2C0D0C9CDC5BFCBBCCB
C3C1B6B4A9CACFC4C2B99AABA2B5B3C0A9ADC0C9ABADC4C0
B8B1AEBCB8C7BCC0BEABB9C4C7A7BFBBCCBDBDBDB8C6C8B3
CCCCCBBEC9C6CDD1BFCDC6ACC2B3B7CFC1CABFBBC2D4B4C4
C6C4C7C0CBC8CAA5
C3BBBBBEBDB9B5BDBFCBC4BEC6C7BFC0BFBBB5B9BBB6C2B6
ADBCC0C3BDBFC6B6A771BFB8C4C0D3C9D6D5CBB9C4CCC6C7
B5B2D0AACBC7C1BBB6AD90878EC3B0B9C3A9CDCFC2B5C4C8
C2C6BFBBC7C4B9ABC4C4B3B3C4B7B0CFB8BBC3C4B5B8AFB7
A9C6C3D6B5C7CBBBBBCDCBC7CFC4CBC4D2C5BCBABEC6C6C9
BED0C4BFBFBDBCC9
C7C0C4BBB3B3BEBCC1B4BDBEC5BCC4BEBDC3CEC0B8CAC2B1
BDC0BEC4BEBCBCBEA1B9A7BEC2C0C6B4C7BEB0C7CDC3BDC1
CEC9C2C6C8C6C4C4CDB0859599B99CB7ABAEBBB6B5AFA2C2
BEB6B4D1AEC2B5B4B2E2B7BBB1B3CFC1C7C7B2D1D8C4CBCD
C2BDBFB3D0C0C4CFC9C0C6CBC0C4CDC4B4CDD1CBC6B3C2B7
C2CDC1D556BCD876
C4BEBBB7C8C0C1B2B4CE88CCC1C0BFC1C2A7BDCDBDB6C4CF
C3C3BDB7B7BEB3BEC2C4CD7FC7C9D4AAC3B6C9BBCDD6C6B7
BFBBB3B0B9C8C6BDBFAB2C4387C4AEBEA7BEB7B2C2C6BBA4
B1ADB9CAABBACCBDCBC6C2CBB4B9CCBACEBFBDD9C0BDA4B1
B7C0ADC4C0BDC5EAD3C9C2C0C7B7BDC6BCB9C3C7C9BEB7C5
B2C7BFCEC4C4B9C0
BEC7B6B3B3BBB9C1C0C9C2C8C6C7B8B9C1C3C3B5B5BBD9C7
B8CBB7B9C0C0B9BAC7C0D6C49BB2CBC6C9CAC4CDB9BE8BFA
BECAC2B5C3C6C2B6B24CAEB1E2C7C2C2C7C2C7C2ABADB3BF
B5C0C0C2C4C2B9BDB6C4CCB4BBC5C4C4C1C5C1D5D7C7C1BF
BCC6C2C8BEB7C0C9BCC6CAC6C1C5C3BBC0B9CBC9C8BFC3C5
C7BDC1C0EAC4E1C7
CEBDB7C0C1B8C9BDB7C0B9C0C4BEC7C4BABAC3BDC3C0BBBF
C7C3B8C6BCBDC8B6BFC5D6C1CAAFA4C9C8BCC2C6BDC0C9B4
BDBFBBBBBBBBBDB5A5BCA7B785B7C7BCCFADB6C0B1C0A9B9
BFB9C2C6C3CBBFB1B1C3CABCB0A5CFC2CAC6BDBAB8A2BBBF
C2B7C6CBC3C4C3CABBCCBECAC0C4CDC2C7C1BFC7CCCCC7BF
B7C4B5BEBFC6B9B5
BABEADA4B9B8C1BDA9AEABC0B6C2C0BCBFC5C7C0C2C9BEC4
82B8C6C6C4C0BBB6CBBAB8B4CBC4C09AC8CDC7C9C3B9B3BB
C0C0B7D0C0C2BBB9B2E2D6E1C6B4B5C29AA7B4C7BDC4C0AD
C0C6D6CBBDC9BBBDC0C9BBC4A9C2C6BCC8CAB5B3B9B9A4C6
CECEC6C8AFBBC6CABDCAC1C3CDC6CFC4C2D3CDC8D0D6D7C7
BCB7A0C6B9C6B9C8
B7B885B8C8C0BDACB5C1BFB7BBC3B6C8C6BCC3C9BFBCC7C4
BFB8C4BCBEBFC2BAC2C2C2CEC7BBC4C8B9D0C9D0C7B2CFC6
C9D1CDCAC8B5AFBDCFBEC6B5B6BDB7B3B5A9D0CDCBB6C4CD
C0D8BDC8BBBCBEA6C6CCB7B6B0C0B8BEC2CEBBB9BDB5BFC6
C2BFC2C6B9CAB5D1C8C8C8BBBFC8C6C2B7BDBEB1A9B6B4C4
DDC4D3BEC8CAD0BB
C0B7AABFBCB1C0C0CCC2C0C8C0C0C2D2CEC6C7C9BDC2BCCD
C6BEB2BBBFC3C7BCC4BEC6B7C9BECFB8BACED1B8CDC6D0D9
CFBAC0B5C9C0C3D8D1C8C8ADBCC4ADC69C98BFBFC8C2A0C9
B3CCC4A5C3C1BBADCEB5C4BF9EBBC2BCC0C4B5B7AFB5BFBB
C5C8E4D2D4C8BFB6C0A7C4C6D0CBEDAFC29EC5BBC6B9BFCA
BFBFCED3CBC9C8CF
B9B2B9B7BCB8C0B6C9C6C6C9BABEC4BABABEBAC2C1BDBDCF
C4BAADBDB8C0C4C0C4ADC6B9BEC0AECBB4A4AEB699BABFAA
CED9CEC2C6D0D2A9A9C2C6B4C5A2B7BDBDB5BDBDB9BBB3BD
C0C2BBB7CBBACFC8BEC2C2B2ADBBC1B8C3BABCB5C4BDC2C0
B8C8BFC4BBBFBBC9CBCFC2CFCCBEBDB9BFB0CFCFC4C2C0C6
BEC6C8C2CBC9BCC8
BDC59EBD9AC7BFABBDC5C9C2C4B4B7BCB9C792C6C4BFC0C5
CBAFB6C2B5BBBFC8BAB9BCAFC0C6D9C6C1E1D6A4BDC2ADBE
C6B3B2C4CABFB8CABFBBBCC2C9B7B7B0ABB7B2C0B1ADBF8E
B9CAB5C2C6C6C2B1C4C4CBB790C2C7BDC0C6A7B9B9C4C0C4
CACFD2D2BFC8B7D1BCB2BDBAC9C7B7C2B5C9CFAECFB4C4C2
BFC2BDCCBBC8C2BD
B9B9C1B5B7B2B4BEC6C4C0C2C5C6C2B8BBC9CECCBEC1B4C4
C3ABAEC7BFC9DDA6BDC6B4BB96C4B4BADE95F0B8B7BD9CAB
A9B1B1C0C6CECEABC5BBB5BBAFCDB7BBC1B5BEC0C0CAB7C4
C6B6B5CCBFAEAEC1BDC7D0C09CB9BEBEB6B9B0B5BFADB7BB
B5B3BED0D0CECEA9BAC7C0CDBAB4B8CDBFD4CCB9C8BBCED9
BDC6D2B0B4C5BFCC
C8B9B2B0BFC2D9DDC6B6B4C2BCC6C1C4B8C2C5C3BFC8C2BD
CECFC8BEC1C2BCB4B4C9CDBDBBB69DADBCACB49B8A9EA281
96C0C0CEC8D2C2C0BBB6A7A3BBC2B6C4CCABAFC2CBB7C6C7
B2B9B9C1CACCC9C8A4B2C4B9ADC2BFB9C5B9B2AEA9ADB1B9
A6C0C0B5BFBFBDC9C8A7C7CFD1C5C438B4CFBEC5AFCEC2A9
CDC0D0CCC5CDCFC0
B5C2B3C1B6B4A585CBC4A7A9BDA1D8B8C1BFECCFC7BFC0BF
BBBEB5BBBABFCFC19EC4C0C6C7CCC2BAC0ABB0C6E1C2B1C4
B1C2A4959996B1C8C6B7B8C2B2C4BEB4CDADC0B0B1B9C0B5
C8B4BFBFD5C4B4A3C0B9BDBAADBAB9B2C4D0C4B1C8C2C6B2
C7C9C6D6C2C8BBBFCCC8D2C8CAC8C2B9B7BDB3BDB7BCCEE1
D0BAC690ADCBB2C6
BDBEB8B9B8B9BCC4D8BDCEBCB7C5FFB7BBCDA8C4BDBEBAAD
C0C4BDBDC7D0B9A6ABB7C6CCC9C2C3C2B5C2B2ACC1B9CDB8
C1C1A8B9CACFD1B6B087C2C468AFB9B6A2AED6C2BDB7B7BF
C3BCE2C2C2C8B4D1D9BBC8C6A0BDC0BBC1B8AAC4C2C2C2BC
C5C3B8C0D3CDC2B9CAC8D1CDC0C8C0CBCFBFBDC4BFB7ABCA
BFBAB9B5BDC8C9B7
CBC7C3B0C4CBBDB1B6CDC4C9C1CDC3BFBEC4C0BBBD9EAAC2
CBBDAFC6C4C3B799E1C4C3BFC7CBC4BBC2C1BFB9A4CDB7C6
C4C6B7B8CBB5D4C97BC0ADAFC6C0BDB1B7A5D2C2A9C2D0A5
B3DAB8C0C3B0C2C2A9B9C6BBA5BBC6B9CCC8C4C0C5D4C2BD
C4C7C6C2D1BFA6A9C2CCC2CFC7CFD2C2CCC9C4BEC8B5C6CE
CEC489BDBFC4C8C4
B7ADB9B0BFBBB8C0C7C5BD95C9B9C6BBC5AABFC6BECBBDB2
C2B7C6CBDBBBADAFB2C3C2B8BD9BB2C8BCBACDD49FB6C4BC
BBC8CEB8B9C9C0B583BABFC6B3B9BFC0B9B8C6C4D0BDC0B0
D8B8C9E1D0CACED0BFCACEB8AFA4C2BFD4BBB9C6B4B5B7BD
AFC6BDC2CCC2CECEADCDCACEBFC3BFB69AC9B3BCC4CEB6C0
99A6C6CAB1AEBCB8
C4C4A5AFB3A5B6C9BCC2BCBBC7CBC2C1BBBDC9C0C7B9BDBA
BEC0BFC1ABD0B7BCBCBCC9BEC1ABB4C9D0C7BBDBB8BFB5B6
BDC6C2B2AEB990B54AC2CAD9BFBDB3A7C8B6CDAEB0BEB9D9
C4B6C2A5BDCAD2D0C2C6C0C9B6C3C7C0D9C2C2CBA5C6C3BB
BFBAB7CBCDB3C2DDD9ACC6BFCFC8CAD0D0B6C4BAABB5B7BE
C2B8BEC0C6BFCBC4
D6BDC8C2B9B4BFCFC8D1C1C5C7BACBBEBBC9C0BCC6BAB9B6
BAC8C3C0B9C6ABBFAFBEC8B5C6B6CFC0BFBED1DECAC0CE9E
AFB2BAA2ADB5B1D0CFC8A5CEBBACBDB2AC858FAECEB5B1AD
C6CFC6C6CAB9C2D0C8BAC6C0B5C6CCC4BDABBFC2BDB8B7AE
BBBDC7BAC2C6DBD1B2B0BDC8CEC8D4C0D2C4CAADCBD3BBCD
B2ABBDB9C4BBC6BA
C9C3BEC0B2AED2BCC8C7C0BBCFB1BBB3BEBDC2C0CEB8C9D2
C7CBC2C9C0BEB8BBCABED1C4C6BCC9D5D2C9D8D8C5B8BEB1
B0D0A5B1D396BFB2B8C2BEBEBB92B8C9BAACB8BEC8C4B9E7
C4BDC5C2C4C6C8C6C6B4C8B7B3C2C8B9BDB9A6C4C6CBC6B3
C6CFC0C4C4AFC0CBC5CDC9D9BCC6CDBBCAC8C7ABB9C3C4D4
BBA9C9C4B5BFC9C5
C2B9AEC8BEC2C6CBC2BDC1B1C5BBC2B5C8BCC9BED1C0C4C4
CBC9CFBB9DC3C1BFAAC4C6D5BFC0C2C5A8C0AEA1B1B9BEE1
C2B9A9BB91BACDB2C4AFCAC7ABC0E1A9C2B4BBBBC6C9B4CA
BBB5BDCAC8C4D2C4A4BDC6C2B1C1E7B3CAD2B9C4C2C0C2BC
A2C0CAC0A9C9B5C8C8CBBAD5CED4BDAFC2C6B5C8D3C497A7
B6D1AEB1C4ABC0C2
B9B9B4B1A9BCBED3BFBFBBB6BFAABFBBC6C6C9B0C0C6C9C7
C1BFB0BDCBCDCDC8A0B6C4B8C6CAC1ABC0C4B1A2AFAAAABD
BCB4ADB9B9C7C6CAB7C2B4C7DBBDCCB58ABFC6CCC0C2CAC4
C9B7B9C4BAD6C4CCBFC6D2D9BBC8B6B9C0ACB8B0CD9ECABB
B5BBBAD7ACB9C0CEBBC0B3C2CCD4ABCCCC81D0C0C8BCC6AB
BEC9C9BBBFC4CECC
C6C2BFBCC9C2A4B5B4C7BEBFCBB4C1C1C7BDC0B2C0C7CFC0
BEBCC0C1C7CBCFD1ACBBB6BAAEC2B8C2CBC6C7A4B5ABB3B7
C0C79AADBBABC0BDC8BCABBBBEC5B5B3B9B7C9C1BDC2C0C0
C9C2C4C4CF7ACCABCBCBD6B7B5C2CA9CBFD2B7BDBFC0C4CE
D4C8BCC6CBBCCEBDC6CEC6C0C2B3ABBFC6CED0D2CDB0AFB9
BABFB7C2CCD0D6C8
BBC1B0B9B8BFC0C2C0C4BAA5C5B7BDC7BDC9C7A8C5A3C9C2
B6C6D0C4BBC0BCBB9CCCA7B8CBCBB2B4C9B1C7CDBFC9B9C4
BFC0D1AABDADB0DDAFA5ADB7BFC2B7C8BBA9B8C2C9C2C8CB
CFC9D9CBCBC8C9D1C0BDCBBBB9C6C4C6D7C4BCB5C4A7B5AF
CDC4B8C6B8D0BDD2C2CEC8BEDAD0C4B8B8C4E9C4B5BBC8A4
C0BFD7B4CECDBBCE
B1B7CBC6B4C6C7C6C6ACACC2BCB4C7BFC1BDC9BDC3CDCDBD
C0C2C7BBC4C2C6BDA5B1C6C4BAC0BACBCEBEA7C4BDB8D4D0
B9C9CFB0B5AFD6B7C6A5B9C0DAB9B6CEBFA7B9C4B878C6D6
CCDDC0B3B6ABD0B1CCD3D0BBBBCAB3A3C0C4ADB1BCC0AFA7
AEBDB0CAA7C6AEC4C4B9C6C4C0C0C6BFC3BDD0C8CACCB1D6
C2C4C2D0C2BBC9DD
C0B0ADC1C1C3B5C7B7B1B1C8CCBDC6C2B4C3C4B5C7BCC1C2
C7C0C1CDCABFC2BEB9C4C4B1B6C6C2B9C2B3C4A9A5B8B7BF
B6CB8FC4BFBFADBBB7B3C0B4C0B8C2BFA6B0C7BBC7C6DED6
CAB6BBBBAFBFADC6DDBDBBCCBDC2CAC0C8BFADC4C2C4BBCE
C8C2CFC7CABDC6A7CFCED3CAC0BDC6C4BFC8CFADD2CCB9CC
D0CBCABBCEBDCBC8
BFAAB6C4C2B4C4D1B2B9C4C4C7C0C6B6B7C0BBBBBCC2C2B9
C8CDBAC78CBCC0BAABB7C6C6BFBFC4B9C0C8BCC4BFC2BFB8
C0C2A5B49DADB3A4BDC89AB3BDBEB0BFCAA35FBBBF9A76BD
C6B7CAC0AFCBBFACD6B7ABC6BFBBAFB5C2BDC8BFD0D5BAC6
BDD1C6C6C4DDC2A0CAD0C2CCBBC6B1C8C4BEC0E2CC9CB7D0
C0AD9DB6C8B4C4CD
C0C3C5ACBAB6C0B8BABBBECBC6C0CDC2B9BEC9B8BCC7C0CB
B9B0BFD6B8BCB8B7B9BDCBC7C0C8B7CBC0C8CAC4BEC9CEB7
BAB8C0CFC7C6A5C2D29BAFBFB9C0BFBBADC0BAC0DFAFB5C8
BBCAC4C8D0C4C9BEB1BFBDC6B5BFBBC6B0C4BDBAC8BBC59E
C6CFC4C2D0D2C3B9BDC2D3D3C4C5C4BFB3C0C8B5C6BFD2B7
C4C2B5C6BEBED0B9
B9B6A7C2BED3C8B1C1AEC6CAB6BBBCB2A8BDCBCBCBBAC0B4
BEBEC9C4C0D5C6B7BFC9CFBEBFC6C6C4BB94CCB4C4C9B2BD
BEBAB6C1A3C5C3CD9E96BABCBFC0ABC8A0B5B7B9B7B5BDD9
CBB0BEBED7CDB3C6C4BDB9CBC0BFC0C1C9C3B0BEC0C2BBDD
C8B5C4C0C0A9A9C8BFABC4CECFD4D8D2C89DCABEC6ADCAD9
D0C8E1E1C2CACDC0
BBC5C5B6C0BACDB2ABBCC0C3B9C2C2BEC7C3BBC2CEC0C4C8
C6CCB0BACAC8B9B1B9B6B8C2B1BBC8C8C8C0CCB2C7CFB4C4
B2C6CCB3A2B4B4BF8FABA9A9B5C8C4B3BFB3A2B7C2BDC6AB
B9B7B9CEB9D6CDCDC4BBC2C1B3ACCFC1AFBFC2CFBEA2B9BF
C8C0BFCAD8BDC0C4C8C8C9C0C2CCCBC8BFCDC6A4C4EBBDC6
C8C9C0CFA273B4C6
B2B7DAB8C2CBC2C0CEC4B4C4C8C4B9BBCBC4C7C1B9CAB6BE
C4BDB8B4C2C8B5C6BEBCC8BBCCBFBDC4B1C1BFB5C8B9BECE
ABBBC8C6A4D0BBC69DBBA5B2B8C0BFADB7A9B8C8CEBBCCB1
D2C4BBC2C4B9C6C0C2DCCBC1BBC9B4B9ABB1D6A9CCE4D4D6
C0B9BACED2B3BBBABBB5D1C4C8CCC0C9BCCFC9D2CEADB6AE
C4B2D1C2BBBBC9C0
C0C7C6B4B7C4B2BFBBC1BDCBBCC6C9C6C6C0CDC5C5C6BCC2
C6C2B9CBB6BFC2AFD2B9CCB8BFB3C9A7C0C3CAC6C8C0BDBF
B3B5CDC49EBFCAC9B8C4AF96ABACA6B9AFB9D2D09EAFBFBF
AFB5C0C7BDB9BFCAC2C2C6CEC8BDCBCDBFBBBAD4C6CBAFB0
B9CACECCC4CEA0CED4C6D0D4C8C8D6B9C4B3B968C6C8BFBB
B7C9C9C2C8C2CBB9
B7B9B1BFBBAAB9C8C5BBBBD0BFBBADC4BDC2B8B6B4BFCFCE
CAD7C4C9BEBFB0C6BDBEC4C2C2BAC9AEC1B3BBC9BCBABABE
B1C3B4C0D8C0BBB54DBBBDAD96B4B9ADB086C4B7B994C4CA
CCCAB3ABC6C2CACCC8C0C6B5C087D2BBC4C4BDB1CEB5C6B7
CBCDCFC4D0BEC8BECFC2CEB3CAC4C6BDACBED3CAB3B7AFC0
C6A7C8B9BC98D1B0
C3ABBCCCBEC8DAD0C6BEC6C4C8BBBEB8CAC4C2CFB8C5B9CC
C4B5BFB5C2C7C6BDC3C8C8C2C0B9BCCFB2B1BF85BDB5C4D0
C4CFD5D4C0C6C2B7C4B7B1C4C28398A4A8A89EC3C6A1BFCF
C5BFC7C5C7C4CAC4C6B1CBB8B8B6BFD6BBC2B3BDCAC2CAD2
D3C2D6D8D2C8BBD8CCD2D1C6D2C8ABBBB7A9AFD0D6DED9CE
A7C9DAC2D4C8C4CB
B0B1BEBDADAEBFB5B2CFC0BCBEC6C2BBB3B3C7C4C4C0C0CB
C4BEC3BBB6B4C0BBBFD0C8CEC0CCBABCB4A9C2C9BFCDC9D0
CFC6DDD2B4C2C6C0CEC4B5BFB1A075BB9EB4C4D3BEBEBDB2
CBC9CBC9A8BFBDBABED6C8C5BD9DC9CBBBC0CEC0CCEDABC4
C8C8CEA5CAD4CAC4BFCAC4C9C6D6CBCCD0BEC8E2CF97ACC3
CBC2C8CDB9ABC0B4
BCBFC1AB9ECEB6C4BBBFB9BBC7ADCDBEAEC6BECDBFB9CABC
C2CDCDB7BEC4B8C6BABDC6C0C6C6C6A5BCABB5D5CDD1ABDA
DCEACDB4C9B8B0C4B7BBC0C0C6C2B9A390B6BEA3D29EAEBD
B1C9CACEC8B9C6C87BC2DAB1C8A9D2BBC4BDB3B6D6C0B9BF
C6C4C8A7DDAFC6CFD0C8BDC2C1BEBDB3B9E1CAB5C7C1C2C8
CAC2DBCBA9A7BBD1
C0CDC1BAADC6C8C4CBB9B4C0C4C0BBB2C6B9C2CDCFCCBFC7
BFB5ADACBEC9C5AEBBACC9C2D0CFC7BCB0C0BFCBBCA9BDC9
DBCECCB8C6C6CAB7D1BDC6C2BBB0AD98A59EB0B6B6B0BCA2
CAC9C4C9B9B4CACAB3D2C6BCB3C2BFBD96C0C6C6BFBDCAC2
B8BCD3D0A4CEC6C6D1BBADB0C4A5D0C4BFC9C4CC93C69EA4
ACA9C4B6C5B8CDD8
BAC2C0D0A994BBB7BCC6BFC2B4BDC8BFC3CBC6BCC2CAC8C0
C9BEAF93AFBFB0CBCAAFCCBBD0CEBEBCA3C0BFD4D6E0BBCE
CAAFB0B6C9C0C0C6B9C6BAC4C0ADC2A8A7B0B99DB9B7A5C2
CAADC0B5C69ECEC2CBCA9AC9B1D4CDBFC0BBABBFAFBAC0B4
CCBDC9C4CEC6B8D2C0D9B7C4ADBFCCD0D2BFB7B5B7CABFBD
F0C6BFC4B3BFC7CF
BEC9BCB3C9D0CBB2BBBBCBB2CDC0D0C6BDBBC0CFB2BCB2BE
C6B3AE9E94CAC3BBBDC9C4B6C2C4B5C2B7B5C2C4C2CCA788
8F9193D0B5CDC5B9BDCFD7A0C0B7BBC1B5AACDC7C4AEC7C6
D3C9CEC4DFC4CDB5D7CCC2D6B3C6CAD4D2BBCBA5C8B8C8CD
EBB1DBC4DAD0C4C6CED9CCBEB1C8CAA0C2B3C898C0BDB8C3
CDBFC9CFCDC6D7D5
C8BBC4BFB2B6B4C4C9C8C6C2C4C0D0C0CBC7CDC0C2C9B4C8
B1C2C0C4D7B8BDB8BEC9CBCAC2AEB5C4B7CAC6937F969EA9
7DB1BFC8CAD4BDBDCDBFC7C2C1B0C2BBBFC099B6AFB1A5AE
BCCBC7A8CBCDCFBEC8C0C6CDBECDA5C4BBC0CDBDC4CCCABF
BFC2ECCFC0C0C6BCD2C9C2B7C6C4B9B0A5C0B7CAC0AFBCCB
C9C0BECDBAB6D2BB
B2BDC5B9B6C6CBC6C1BBC1C3BBB5C2C4C2C4CEC4BDBAB8CB
C6B7BDC8C8A4B5BDC2C2C9CEC7C1C4C2C9B2C9C6B6969FB9
BDBDB7BFC4B9CCC6BCB8B1BDC5BDC4C0A9BBCBD0BBA2C2C8
BDC0CAB9AFC2C2BCCBC9C4D0B4BABFA4B5B3B1CACEC9CEC6
C4BBB1CAD0C6C8C9E1C9B9BBCEBFD0BFBDCEB9D4BDD2B9B8
BCC0C2B5CCCDC9CE
C2C4B8BAB0B2C5B4B0C6B2B5AECEB5BBBEBABDAAC6BAC4CC
C6B7BEC9B9B5C2BDC4C8C4CCCDB4C8B1BABCB1B3B59BC1CE
B1B9C8B0B6C2BFC2D7BDBAB6BAB3BEB5B9B3DD90D2CCB5CA
C0ADE1C4B6BCB9B1C6D9C4CAC0B5C2CAD2BBC0D9C0C0D4A5
B3C4ADCACAC4CED0B9CCC0C8C2CCCEC0A7A1CAC4C0C2B7C4
C0C9D4D1BFB8B9C4
BDC5C486948AB1A2CAC3B6BEC0A8B5C0A8B5CCBFB5CBBBBA
CBC4CABFCEC2CEC2C4AEC7C7D9D1BBCBCFB2C6D7C8A9CCB9
BBD2D4C6C0C6C6CBC2C0CBBFB9AFB7BBCAAFB7B1BB9DB8CD
C2D9C2BBD0C8D0BDB7C6C6B2C0A7C4B0CBA8B6C3C8C6BFC4
CAC4C6C4B2C8B7B7CCC8BBB7C6CBC9C8C4BDB2D5C6C0E3C0
D7B79EC2D4B9B9D6
A7B9ADBAC2D3BAC6C6C0C2BEC2BFC1A8AFC2B9BAC8B8B8D0
C0C6B6D0B6CDC2C6AFBDC6C4C7B6C2C2B9B5C0B8A9ABBCAE
BCC2C2B9CCBBD0C8BFD2BFCCB7C4B1C4B1A7B8BBC4A4B9D0
B5D8BBDDC0B9CBBDC1C2C7CAC29EC1CFADC3AFBFBFC2C9CF
BDD6C2B9ADB7C0C0CAB1BDD6CEC6B9B8BBBCCDC0A5C9CAC0
C4D1DACFB3C6D6D6
C4C6C0BCC9CEB8C2D2BEABB8B8AEC1BDCDC2C4C6C2B8A5BD
CAC6BFC6C6BCCBC4BBB7C4CABBC2C6C8C2B5C8C9BB80D0A2
ADBEC2BDC6C4BFC2B9CEA7C0A9CCAFBFC2AFBBAFC0CCA2D0
C0C4C2A9B6ABBFC9C7D4D2C8C4CCBDB4C4B6BFC2C2BFD4BF
CBB9C6BBB5C6C4C9C1D8CBD8CCD2B5C6B9C6C8B9C6CBAEB6
E0DECECFCEC0C6C3
C2CBC4CBBDB5BCC7D0BDC5BEBCB8BAC7AFBBCDB4C0BDC6B9
BBC0A9C4C4C2CECAB1C6C0C6AAB3E7CECACFD7DFE1C6C8AF
CCC8CED7C0B4BDC2B5C6C9BBBDB8B6A7BBB1AFC2DAC0A2A7
A0B7C6BABDC6C6CAB7A9BFC8C2BDCDC1ADC2C2BBC4C2C2B9
C4C8C6C6BEC0CAE6BFD2CABDCAAFC6CEBFC1C2B8E4C8BCA9
80B9C8C6C0C2D4C8
BDBCC0B6A9B5C4D1D2B5B4B7C6C6C7C4D8DBCFAFCCBBB7C4
C2BCCEC6B7BFAFC0BDCAC6CFCFC2CBEABFCFAFCED0BBB3CA
A9AEDAC0B8B2C8B9CBB698C8B3BDCACAA9BCBABDC7B8BBB3
D3B7C6BBC0BFB5BBBDC2C2C0AFAED2B4A7ADC2BFBFABB5BF
D2D4BDC6B5BEB2C0AFD824CDBAB8D2C8CAA2C2B9B6A5C9B0
C2CFD9C4D0D1C8C4
BCBAC5C4C6B5D0B2C2BECDCBBAC0BFAFBFCDB4B5C1C5C5BC
C4C7B9BDBEB5C2BBD2C8CCCAC0F6BFB3C4C2BBA2D9B7D8C7
8FCDB9BAC2B7BEC8B6BAC0BAD3AFC6B5B9B5C09E6F9EABCC
E6CDB9B3BFBFD9C4D6DAC0B3B7B1ABBDB8BBB3C2BDC0C6C9
C2C2B8C2BDC4CAC4C4C4A2CACCC0A7C8C0D2C4B3D9BCE1DF
C6DDC2CFCFCFC6E1
B8CDC0B7B2CBD2BAC0C2ABCDC6C2B4BEC9BDADBEB8C2B8BF
C1BDBBC4C4C4D0CBCEC8C5C6B4AEB5BFC4C2A4D6BF92C0B4
ACCAB6C4BCCBC9D9B5B4C6C2C6A7C4BEB4B4B0B4C1C4D89F
94ADC0BAB4C0B9C4BCBCCCC5C4BBC0BDBDADB3C8A4ABCCC2
C9BAD2C6C8BCDBD6D0ACCAC2C0BDBBBBD2C9BAA9B2B8D0AA
BFD6CED2C4D6CDB9
ABCFC4BDB2C7BDC0C0B5C8D1C7BBBBB5C2BDC8B4ADC0B2C1
C5C5BBC7BDBFCCC2C8C0BFD2D2BAA9B7CE8EC89CB7ABCFD1
B5D0B0B4BCDDC2BCA3C0AFB3C2BDBBB9B5AFC4C8C6B6C0C7
BBC4B1BFBEB4BBB7BE93C8CAC2D0BDC4BBC1BDCAC2C6BDC2
CDCBD6CAABD4C6B9C7C1B2BBCBBCC4D8C6D5DDD0BBB5CBCD
DED8C8C2D0A5B2CA
BAB2B2AEB4C0B8C4C2CCAFCFC0C8C6BBC2BBABB5C6C5C6C0
C2CFBBB3BCCDCFBBB3BFD2CBC0BDC6B5C0B9B9B8D7C6CBC8
CCC0B7C0D5BDC8CCB3BBC2BDC4BEC4D8BDAF939ED3B5BBC8
D0B7BFC0C4BFC0C2CAD1A2CEC8BDC0C2B7CED8C6BFCCD0C7
AEAFBBC4B3CBBFCDC0A3D2B0BDD9D8CCC8C4CCBDBBC6C2B6
92BDC0B9D4CBA1FF
D08DBFC9B7BDC6BFB4C2B6B6C2BCC2BEB9B4C8CCC4A5C6BA
C0C2C9BE9CC6C2C4C6C6C4D2B5CA90C0BECFCDD2CCA5C275
CCC8BFB9B3C6C8D9CAC2C2B9B2C0BBB8B6B0BDC4BBBDC6BF
CAB2BABFCBBCC7D8D1C9B2D8BBBFB3C2B9B2ACA9B1CEBDC2
CFD9D0C6CAC2C4B5B5BDCEB5C8C9D7B1CAC4D6CE7FBCC2C0
CCB5B7CFBBC2C79B
C4CBC8BBBDB7C4C6C4B6A7B2BEB3BFC2CFB4CEB3C0BBCFC4
BBBBC6C6A3BAC6C8C4C6CAD9BFD4BBD3BBBBD2C4C2ADC6C7
B5CCCEADBCCFD4ABBBBFB2ADB6B0B7B14DB1B5C2CBB2B2B0
BFB7BDE5A5C0B6BAAEBFC2BDC4C2C5C8C5B9C8AEBDAFABA4
BFB4BFC8ADC8C6CDD2B8C0D3CCC6C0D0ADD2B9B5C8CEB39A
C2D6C2B4D8A2BBAB
BCC1BFB3B4C0B7CCCACEC8C8C4C4C2CCD3BAB5B5CFBFC0C0
C4BBBECDC4BFBDC4CAB7D0C8B4BCB9BDB3C8C0BB9CBD88CF
B9CABCC9C4B1C0B5BCA0BABABCB6C2B599B7D4A4C2CBBCA2
B6DDB0C2D6A7B7B2B2D7C8A4CCD6ADD192BFB8C6BBCEB7BB
C0D1F4C4B8BECDD0BDD2AEBCC6C7C2CFD6B5D9A1CACCC9C4
ABC6D5D4C643B1CF
D3BEB0E3B7C9BCC4C0C9C6C2C2C9C0C0C6C7BFB1C8C6CDC9
B7BEC1CEBDBFC8CABDBBCAC2C4D3B1B9B9D0B5BFCCB9C7C9
ABC8C4B2CBC4BBB99DA1ADC2C6B7B9B0A9ABB2C6C4C0CEAC
D8C0C9CBCFBAD7CAD0BED7D8CACBCDC0CDBDC6D6C0B3C4CC
C6C6BEC4C6CDDDC0BAAEC0B8CFA9C8C3B4CCBDC8C0D0BBB9
B2BBC6B25F7BC7C4
BBBCB5BDBFC9B3B2BBCBB7BBCDBAB9D4D3C7AFB7B7CFC3C0
C4BFBEC2CBB9C9D2B9BCD2CABEA0C7CBB8CCC2C6CFC8C9A5
B4CEC0C0AFBFC2BDB7B9B1BBBBB5AFC0CDA0BFB9C8BDC2D0
C2BCD3A9C2D7AFB5D2D0BBD2BDA1C7C5AEAEB9BBC2BBC8D9
D2C8D3B6C5B4C8C2C0B6B3B2BBD0C0C9C7A5C2CFD5BCA9AF
B8D4B6B6BFB2BDC0
B5BFC7BDB7C1C3B7C5D2C3D4C9BEC7CDCDBFBFC4BCC6B6C4
B9C2BBBBC7BCB0CAC6CFC6C5D0B7D2B5BFC9A2C0B0B4C9C1
B1A792BBADA4B5BBBBC2BD92C7CEB7B0B4B0C2C8B3C6CAB1
B3BCD2D5B2BDC4B7C6BBC9C6BDB3AFADE3C2BB9ACCABC3D7
C49CC7C7BBC0C6B7A7B9B4BAC8D5B0BACA7AC1D3B7B7CCBE
B7BDBBCFCAB7C2B1
B4ABC5ADC4C6A5C6C8C1C2CFC9BDCBC9BEABCFC5BBBABCC2
C2C2B8B4C6B6B9BFB8BFC8CACDB9C7C3BBD8C2C5B6CDD3BB
BBBFCECABDB8BDC6B9C4C8C9C0BBBFD5C0AFABB2C6C8B9C0
B9CDC7B9AFC2BFCFD0C4BACAC6B5B9DDABB7B7C7D5C8B4C6
C7C0C8C4CACEBAC6C8CAD3BED8BDAFC4C6CDD6E1C8D6C4D5
B2A8C7C4C0C8C2C2
C0C5C3C1B4BBB5C8C2AFB6C0C0C1BCBFC1CBBDC8A3C2C7C5
B5D0C1B6C4C0C4BEBBC0C3D2CAC4A9C0B1C0B5BFAEC3B6C2
B8B4BCCDC2AFCFB1B5BDC1BDD0A9C6CBC284B8B6ACB7A0CB
BEB9B9A4C8C6BBCCBBD6ABBFC2C0ADADA4C4BEC1C8B997C6
CCA0ABCCCFC2D7C0C4CFB7D0CAD2C2E7C2B4BDCBCBCDB7C4
D2B4C0C8CCB9CBBE
B9D6C9BDB7C5C6C2CCBABDB7A7B9C4B7C9B6BFBBBDB1BBC1
C7C5C4CBC6C8C6BCACB8B5BECDC093C899BDC0C3C5CDB0B6
C6C2BAA9A0B5BBBF9CC3C1C0B9C4C2B8B9C4BAD2C4A7D2CC
C6BDB5CABDC6C8C2D4D2C4C6C4BFB9B7C4BDB9BBC3B4AFBA
9EB1C2C0BEC4D1D4CA81D6D0C9C2C3CCD0A0B59EA9BCBDBE
BDC2B8D0B9C4CCDA
B7C9B8B8C6BCBFC1B7C2BDBCA9BDB2B9ACBDB4D0C4D0AFB4
C0CDBDB9C3BFB2BDBDB2CBCBB7C5B9CBD8BFD7D0D9C2A7BA
C2B6B8B9AFB9B1BBBDC4B6C2C9C2C0C3C9C0A1AFC9C9ABD1
BEBBBBBDD6D4BDBDC6CBB2CEC0BBBAC87BBBB9BBC8E1C9D1
BBC4C2C9BDD0BEDFB3B3C6AD9AC6C6C6BBC8CABDB7C0CECE
BBB7C2BBC0C4DBC2
B0C5B9BFA8BFC2BDBDB5BFB7C5B9CAB3C7C4C6B8C2C6CDC9
BBCFC4C2C4D1C6BDB3C2BFC0C7CDC1B9C7BFBFADB1D09E7E
D0A9B6AFC8AFC4C9C5C7C0B8BEBDCCB6C4C6BFBFB8C6C2C4
BFBDB3B9B4CAC2C8ADD3C4B8C5BEBEAFC6BBB9C9CEBCCBC8
C2C4CAC0C0BBB9D2BFC2BDC4CA85C8D1B869BABFC2CEC981
B2A7B5C2CEC2B3D2
C3ABC4B0CBB6C6C4D0C4BBB3C0B8C0B9C7BABAB4C6B4C9BA
C0BCBDC9C9C1D2CCBED3D1C9BFBDC6CDBDC8CFCBA3CDACB0
AFAEACB9ADC7A9D0C6BCC0BDC4CCCBD5D3C2ACBAB5C6BDB2
C2C29DC2C4BCC6D1C2CEC0C0C3BED0C4BEBEC2C8C6D2C4CA
B1B5C6D1C1CDBEB3B7CAC2C8CBCBC3C7CBC0D4D0CEBCCAC8
AFFAB8C2CFC0C7B4
C8B5B7B9BDC5C7C3BEC4BEB9BDA7B8BCC1B0A7B7CFB7BFC0
B4C4A4BDC8B2C1C8B4C1C8CDC0BED4BBB9C0BABB85BEBDB0
ADBFDBC4BBC6C0ADB2B6B7C0D4CAB8C4AD98A6BBB0BDA9CC
C2B3C4A9C8B1BAE3BBD4B6A2B1BBE5C4CED6BFD2B3B7C2D0
B5B4C6D5DBCDC9C3BDCDCACAE1CDCDBDBFCACAB5C9C8CCAF
C8B3C2C6C9C2CACA
B4B5B1CBC5C3BFB7C0C4BABDBDC9ADB6B7BBB6B4B3B9BBC6
C7B8B2C9B89EC4B6BDC9CAC4C2CCC4B8B4C4CDADB1CAB8B6
C2CBC8CDC9C6BFA4B5C6D9D0BDB8CAA7A7A993A5B8B3C2AB
CEC6CAD0B5B7A4C0D9A8BEC4C8BDC2C6B4C3C9C9C6BDB2BB
B6C9AFA3C6C0C2D0C2BBC0D6C4C8CBC9C2B5D6B5ACBCC8D0
BBCAC6C0C6BFD0C2
B4C7B2BEBEDDC9B9CABBC0C0C2BFC7C6BDBBC5C3B0C5BDD2
C2C3C7C1CFC0BEC4BBC1C3CDC4C1CDB0BDCCBFBEB4A9CCC0
ADB2BEB6AEB5B3A1CBC9CAB787B1BFCCB3B3B4BCAFB9C4C8
C8B9C2B1BCB6C7CFB8C2BFD9C9BDBCD6BAC4ABC8BFD6CAE0
C8C6CBD3CBD0C9CAC4D6CEC4D5BEDDD0D3C6E0BCCDBAC8B2
88B4C5BFC0C6D7BC
ACBCB9C2C0C0CDC0BFBDC9BDBDCBCDB5BDC1BDC0C9C6C5BF
C6B1CBD4C5CBC7C7C0C6C7D2BDC8C3D2BFBBB3C4CAC8B2C4
DFD4C2BDC4AFC2D1CAC6CC90BBC8C2B7BBB9AFC0C6BFC2C2
B3C2C2C0C297BFD6C2CDB4D7B49EC0C6CBCAD0C8CAC0C0C0
D2C6B9BFD2BFB3B7B9BFC7CABFCBD9D6D2D2D6A9C4B5C1BC
BBDBCAC0CECCCBC0
B4ACA8BDB1BBADBCC3BFB4B7C7C3C4B9B8BFB5C2C6CBB4C9
D6B2B5B3C1CDBFCFC4BECAC0CCC6D4ADB9B7CFC6B7D1D6C3
B7D6D6C0D4BAABBBC2D4C0BDB9C0D0C4B8B7B4B8C7C4CBB3
D2C3C7DBC2B9CDCBD6CFCDCBC0BDBAB0D1DFBBD0B9BDB9B9
C2C6C1D3D4BFBCB6C8DFCDC7D1D2A8C4CABFD8CACBC7C6CE
D08BB4BFCFC1C2BD
B4B0C6B9B9C5C2C2C2C6C9C8D0C8CCC4C1B5BEC9C0CACBAE
C3B9C3B0CBCBB49FBBD7C1D3BFD382C6C092CFBAABD0D8B1
B5BDCBA9B5CCA7B3BCCFB2B9BEBAC8B6BEADB5B7C4C6BDB9
B3CDCDBEC7CF96CCB7BFC2B5AFA9B3B9C1B7B5C0B7CCB9BF
C8BEA7BAC9D4C4D6BBBDC3C9D0CEB0C2C0CCADC0D2EF88C5
C7CBC6B6C4CFCAB8
C5BEBEC7C3ACC6C7B8BECBB8C4BDC6C6B9C9C2B2AD79BDBF
BDCBBBC5C1C3B5C0B9BCD0BCBFCBC2C8C0A3DACBB8B9C9D5
8CC4C9BBC2ABA9B7AF9AB7B9CAB8B9BEBEB6A0BBC7C0C0BE
BED8B9CCCE98D2AFA4BFB1D4BBB7C7BBC7C7C0BFC4C2BFC2
D0CAC0CFC9C6C2D6D4C8CECEC4CDCFC6CCBFD2CCC4CCDAC7
BEC9C8BACFC6C9C4
B2B4B0C0BB9EBCC1B7BCACB4C4C2B7B0B7C0C8CABBA9C8C6
CCC8C6D096B7ADC0CFC7C9C7B9C7CCC8AFBBD2B8CCB9A4A6
ABB5C2A4B9C2BBB4BBCEBFC4AFC6BFA9B9B994C0AFD6B9D2
C0C2D8ADCEB3D0B5A9BAB690C8BFB0B1BFB5AEADB9D4BFD2
CEB9C6CACACCD0CEB9C4C2B1BBC4A4CDC2DAC6C2B6B8EFB1
C4BCB6E1D9C2C3BB
B9C2C8BFC7BFCDCBC7C9C1C7BFBFB9BBB6A0BDBCC0BFB2C5
C7B7CCC6C3C6B7B9BFCBD2C1BACDBBD4C5BFC2A8C4ACC2BF
A7BCB5D2C9BDC4BFBCC4B9BFBDABC6BFB9B9B0B4DDD2B9CD
C0B9CBC0BBCCD1BFA41CC8C7CFB5C4CCBEB2C9C0C4C8B5CA
CCC8C6C6C4C2BDCFC4D9D7C49CC0C9BDD2C6C4B7A9BD9ECF
CEC4EDD4B7A7C0C6
B6BBC6B3C8BCC2D9C1BDC1CBB4C0B7C9C6C0B6B4B3C1C3BC
D0CAC3B7C8C3BCBACAC0CFC0C3C1DDC9CBC2CACAD6CCC4B9
C9C4BCB4AEC7C7B9A4B5A9C4D6AFC2C1BDB7A3CCB4EBA8BD
C0B8B8C9D0C8E8CB9AC1C2A9C2C5B0BBB5BFC2C2CBBEC0DB
C0C2B7C2C8C4D2A9ABC9C2C4C2B1C8C5C4D1CDBFB2D6BCC9
C2D5B0CAB5CDCCAF
A9BABEB8B8C6C3C6BDBBB2C8BEDBC6B6C6C8C4BFBDC4B2C7
B8C6C5C7BBC9BDC2C7C0CAD3C6D1BBC7BEBEB1AFC0B1C8AB
AFD6C0BDC9B9C3C6BFCAC2D2B5C4C0DABBB1D4BAE0AEBBB7
C2D0AED2C6E1CFB9C0AAE4CBB4C0C2CBC7C6BDDFB7BFBBC0
CDCA91C7D1B7B5C1C9C9B3C4ACC3C7B9CFCEBDB1C4CF79B2
B9C0C7B1BDADB1BD
A7C8BEACC2C7BCCCCDB7C5C7CBC2BAA7BDBCA7BFBDC4BCBC
D1C0B7BBC2B9B7BEC0B4C6CDBEC6B5DEC4C2C6D0C6ABC4CC
C0D6C6D0C6D2B1B0BBC2C0B1C2D0BAC8C4B8B8BDA4C9BDCF
A7C5D6E7CDC3BDC4C6C8BDC6C2BAAD89B2CAC3A5C8BDBFCB
C8C0C6D9DFDBCCD2BDCECACECCBDC8BFCCC4A9A9D2C4C1C4
AAA6DBC0D2C2C4B9
B5B4BECDBAC8B6BAD2B5B8D2B3BCBAB6B4B2BBC7C7C7BCC1
C7BDB1BBC4C2BDC8CBC2BCC2C8CCDBD9C8BEC0CFC9C4CBBD
CBBDCBC2C2C0D1D3ADC4A5C0C9C6B2BAB4BCB9B3B0BBBDC3
BFADD4C6C0B7BBCCC6BBC1B6B7A5C4B9B9B4AEBDC0C2C4D4
CCCEC4BFCBD8CEB9C2C6D4C6CBD2CFC8C4B9B7A9C5BEBFBE
D4CAB5B9C8D3BCC2
AEC4C2C4BFC9BEC9C6D2B4BAC7B9BBCBB6BBBCBBC6BDB2BC
C8C8B7C3BDB7AEBFA7BBD3C4B9C8B5C3B9B0CBC0D6C6C1A6
CAD4BBC4C8C1C9C7C6CDBBC8C0A4B8D48CA1A2B7C0B1CEC8
C8CEB9CCB0C4C9B2B7C8C8BBCDB9C2B6BDB5C6C4D6BDCACA
C0CABDCAD2C4C6A9C9C7C5BBBAC6CAD3CDC8C2BCC8D4DCC0
BBC2C0BBB0B9C7BD
A9B5C1C6C5BABCC0C2B4C0BFC3BFBFBFB5B9C2C4C2C0B3D8
CBC1A1C9C8B4CBCAB8C8C2C6B6C2CDC3B2C4B3AAC9C1B3BB
BDC7C3B4BAC4B6A0D4B0ADC6C8C4C4B9A0ADB3B9C6C0C5C0
C0BCC7A1C9C8C5BABBC9B7C7BCB6BDCACEBBB6C4C0BCC0C4
C6C2B9B7B6B4BBC1D7C0B2C9E1C8C4C2C8B4B5BBC6A9BDCC
DDD0D8CCC6C2CABB
B4C1BFC9CFB4B9C5C1BCBDBFC5AFBFC2B4C6BDC7C49FABB5
B7BEC8C0B4CBBBC7B9ACC8BBBFD1C8CFB9B4C3C7C1BCC2C2
C2B7CDCBC9CEA9C0D5BFCDC6C2B1BFB1B5BFAECBC7C6B5BA
C6DDCABCE6C6B3C2D5D2C4C4BAAEC3ACB890C0EEC0ADB7CC
C2CDBBC5C9CDC8CBD8A9B6D0C2C9CDCEBBCFC7CFC9CBC4C3
B8C0BEE3D1CBD3CA
BEACC0C2C8C8BBC2D7CDB7BBB9B9BFB7B8C2C5C4CDD5C0BF
A9C4C6C0CBB7B5C6B7BFD0CBC0BBBCC0B9CFB2B4C6EDBDB9
BBBDBDCDB5BDB5BFCCBFBAC8B3B7B3BFC2C2B7C2BBC1BBBD
C8C2BBBFADC4BDC4D9B1C6D3CFCDC7BDC4CBD5CBD1B5BFBB
CCC2B4BFC9C3C9CCCCCFD2C8CDD4C4CCB7C7B19F9EC0C0D6
C1C4CABFA9C4A2B7
ACCCBFB3C2BEA9BEC2A9B5C4B8B9C7C0B5C5B2C7B2BBBDC9
C8BEAEB5C4B5C2BCA9B7DFBEAEC497B9B5C9DDDCB7CDBBB8
B8C6A6B8C9CBC0B8BABCB3CAB5B7C4C0C4ADBBC4AFC4D5B9
9CB6CD99D7C6C9C6BDD2B1D1AFD0C2CACFBEBEC2C48BBDB4
B2CBBDC0D0CCC2E7CAA4CCCCCAC9CFCBC8C8BFAABBBBA887
C4C8CBAEB0A1C2B4
C5C4C2C9C3C1C9C9C7BDB4BFAEC4C5B7CBCCC2BFC7AEBEB4
CFBBA9B8BFB9BFCBBDC2BCB2B8C9C9D2BEC9BAC2C2A3A7BA
C8D0D2C9BED0CABEBBB1C6CAB9B4C2C6B5BBA7ABC2C8C0CD
BCCBCBB9ADD1CCD4CBD1C9C6CFC6C5AAD9CBA7B4C4BCA3A1
BBCFDBCECBC0B6CB80CACFBDB6C5CDB6D0ACA6C37DB5D9D0
BC8EC2CBC0C48CD7
BEBEBCC3C9C1BDC4B4B8B5BCBEBBC7B9B0BEC6C1A9D0C3C4
C4B9C2C4CDC9CDC2B2A5B6C0BBC7BEB493CBD7CBBAC4C7C9
D4C4C1B5C4CABBABCAB7C9CFADC4B9C2C6B2B0C4BEB8C2A6
B8B5B9B7C8D0C9C3D0D9B7CABDB2C4D0B8BEC2CFCBB89CB4
C4C2C4CEC8C0C8D0AEC2ABB1CCCCC2C96298B2D6A490D8C2
B5A9BB9BBBB5C4C3
B4C0B9C9D0B7A4B9C8B9D7BABBBFBDACBAB4B6C4B2CBB7BE
C7C6BAC7C6C0B7C6D5B3CAB9B0D0C4B2D86EC5B5C8BCD1D8
BFD0BBC9AED8B3CAC6C8DCB1C9BDBDBFB9AAC2C5ADAED2C9
BDC5C9BDBEBDC4D2D8B8B2CBD5C5D0CCACAAC6BCB7BCD8C5
C6B1ADADBEB6C2CDB5BEB6C1C1E1C2BDADC7AC9CA6ABA9C8
C0B5AEDAC9F1CAFD
C2C2BBBDBDBEBDC5C0CFC6B4C8BDC1BBAEAEBEC6C4C3CBC4
BDD2CDC7C7BCC4CAC0B1D0CAC7CBACD6AEB1CDAFD4C8C1CF
D5DDC4A9BECFB19EB4C0C5C3BDCEC0C3C3BFA9BCB6C4C2CC
C4C1CBB0C5D8CABDC8B8ABBBA8C2C8C2C0C2D6BDBBCAC1CE
C0C4CBC6BDCDB7BCB7C9CBC7B4BBB8C0C0BAB3B087C0A9B9
A7C8C4C3C8C6C899
B5BEC8ABBAC6C7C6C8CEBFB9C9ADBDC7B5AFBCB6C4C2C9C0
C4BFB2A7D3CCB6BDC2BDCCBCB9C9C2C89CBDCBB6C0C4CABD
C8EACFD7A3D3B5B6B5BBD2BFD0B8BFDFBFB5ADB0C4BBC4AD
B4CAB4DFD1C9D8B9C0C6D2DDC0ABC6C6C9BDC6C2CBD1C2D0
C1CDCAC2C0C2B5C6C8CDBFBBCFC8CAB7B3C1B9B7C6CEB9C8
C0BFCECAC2BBBDCA
BCAEC1BC9CB9C6ABD0C2BFB0C8C2BBACB7CAD5C0C09EC6C6
C0B2A7CA00B1B6C0BBB7C8CCD0CDBBBDBF90B9A5C2C2C2A9
8CBFC2BBAFD0D0C6BDCAC8C4D0C0B2ACC6C6ABBFCACCD4C2
C6C9BDB476C9BBC8B3C6C2B4BABFB4C3D2C6D4BFB8CCC0D9
BBCCE1A4BFBBC9BBC7C9CACAB0CFB5C8BDB7AFB7BDD8A4C5
B4A4CCD2B1ABD1D7
CAB5C2C4C8BFCCC6CBC2D2C7B6A5BEBABBC8BFC5CDC4B7B8
B4C2BEC6A3BEBFB2B8B4BABCCBC4D9BFD2C8B7A0BBB9C6C4
DEC4D1B5C1D3B0D1A9C8AEABC2C0C2BBC6BFA6B2C8C2C6B1
B4BEBA66ABBFADD8B4BDC0B4D3C7CFCDD6B5CAB8CAC0BDCE
B7BFB0C1BFC2D2C3CCD2B7C6D0B3ACB4B3C2B7B5D0BFBBBA
C0C8BBC6BDD3BBA2
C0C0C8B5CCC6C0D1BDB9B7C0C2C0BAB6BCC1B7BEB8C2B6B2
C4A7BCBCC6C2BBBBD0ABCABDD2CBD2B9B9CCD8C8E2B6A6A3
C6B7B7C6CAC1CDB6D9CBCCB9BFC6B5C0CBC8A5AFC1C2B7C6
B1BBC2CFD6CECABEC6C2E1C1BABDCDCBBEC0B5B0C1B3D4BD
C7CDC0C2D6E2C7ADBFB9D0BBCDB99DAFD0CBB4ADEEB4C7BD
ACC9BFD8C7BBA3BA
BDC2C8BBABAEBFD4CECEC6C4BEC8CBC6B7B8BBC8C0B7C7C0
B4C0C2BFC4CAB9C2B7CABFA9C6C8D1B8BFC0BEB7AFC2C0C4
B0ADB0CAE1C4A5B5C2DFBFC0C8B7AECDCAB2ABC8B8B1CBC2
B5CFC8CBC7C3C5C1BFC0DAC5C2CBA1C7BDC9CFBFC3C4C2D2
CDB2C6BBCCCE96B9B1ADC5DBBFAFCFC4CEC8ECDBB8DDC7B2
BFC0B5C3CCBBCDC0
BCB6B3B8BEC2B9B9B0C4B1C5C6BCBCCDC2BDB9CAB5CCC6C0
C2C8B6BCC0BDA9BEBEB0CBBFACB7B4BECACCCAF1DCDABFC7
CAB1B9CEC2CAC0CBBBC2DEC9DAC0B5C5C8BDBBBBADCFC0B9
C8BEC0C8CDB5C0BDB3CCCFC2B1BFA9C0C1C3CCB3B1ACB9C3
BFBFDDD4BD98D1B7B2B4C8CAC8D6B6CDACB8AABFB1C5C8CA
CDC6CEB5C4BAC2B1
BCABC6A3B8B6C8BFC0B6A9CFC5B4C3C7C2C0C5C7C1C7C9CF
B8C4C4ABB9B3C4CCB0C0BDB9B8C8C2B7CABFC8CEA8C3CBAB
B5CECCB4C4C9AEC6BBB9AFBBC7D0C0ADCCB5A2BBC9BABCBC
BCCCAFD2D0C9C8BDD4CBCBBD9EC1B3BF9CC6A5C9CBB8BBB9
BEBEF8A6A0BE88C6B9C0BAD4DABBB3BDCACCB69BDFC4BBA7
C2CFB7C1CEC4CDB9
C9CABDC8B5BDBEB5B5B9C0BDC0C0BF9FB9C8C6C8BECACAC4
C0C6BFBDB5BDB5A4C6ADCAC7C4C2BAD3C0D3CCC0B3ADCEBD
C8C2C2A8C3CEBFD0BBBAA5D0B7BEAD7FC7C0A5BBD6D4D2C9
B7AE98D9BBC8BEBEBBCADFAEBBC3B6B7C9C4B6B8C4C6B5D4
CCCCBDAED2C4BFC8A1B2CBCAC6B0C0C0C6C8C8BBCBADD0C4
D0DDD4C1C9CEB8B5
C2AAC6C2BCC2C2A1C0B1A3C3C0CBBDBCCBC5AD9EBFB1B8C6
B8CEC0BBA5B0C7C2B8B6AED2D0DBA5A3C3C4BBB8BDC7C9C1
C2BAC7CBD6E6C2C4B49BDBB8D5D3B6BFC8AFB7ABDFBAABBC
CAADBFC8BFB0B5C6CEBDB6AEB5C8CEDFB6DAB2B9D8A7D0C3
B8C7DDAAD3C5CAB4D3C2C6C4CBB7BACCBFB5C8BFC0C4C0CD
B2B8C093C4C6D3AF
BDC2CDC0C6C2C0BDBFC0BDCEC8BBC5CFB7ACCDBFBEBDBABC
B9ABCAB7C0C0BFC8BAB9BFCACDB6B8C1B0B5CFBBB3ACCBC4
CFD3D0CBD2D4BFBBAFD4AFC4C0BCCBC2CCC2BFC8CDB2C0B2
C1A4B7CC9FBDB9A8C5BCDBA7D2C2B6C2C4B8CAC8C2C4BFB2
AFA5C0B8BBB4CDC6CDAEAABBC4A5B699C5B7B7B5C7CDB4B8
CBBBC2C9ADACC17B
B4BAADB5B7C6BFC7CBBBC4C9C2C4ADCBC2ADABC9C2C1C7C7
BAC2C9BDC9CDAEADB2C7C6CDCABECBC1C6C3D0B7ADD4C2B6
C9ABCF89C8B6C8A2C2C0C8B7C0CCC7C4C2ABC1DBBED7C6CA
B9C4A5BEBA76B7C3C7DFE0C2BABED9C8CCBBC3C4B8D6C8A6
BDCDC6C8C8BAB9DDC491B3C8B0BDB48FB999BFC9C2C4C4CB
C2D3CDCCB5C4B2A8
B5BAD9B2B7B7C0BCB8C7C6C9BBCAC2B4B7C9B9C5B9CCC7C4
B5B0CDD997C8C2BEBEA7C9BFC1C9C7D0C6B5CFB7AEC9C9CC
CFCBC1B9C7B2ABD6C8BEBACDC8CCC8BEB0B8AFBBC8C2C6BD
BBB2CD80C6A0ABD0D4D0CCB8CBC8C4B3C0CABDBDB9BFAD90
CAB5C6C3BBC6A5AECECD9FB9CCBDCAADB0C1C7CACEC6C0BD
C3C9BFCBCDD3BFAB
B1BEC0C2C4C4C9B4C0C0C4C4BCB2B2BBB9B7C4BDA9B7B5C6
BABFC1B79BB2BDC0C6BCCBBDBCD0BACFC3CFB4D1BFACD1C7
CDCBC0C0C8BEBBC3D1C2C8B3C2CFB3C0CAC6B2C4BFC6BDCB
CBC5AEBFBB96BEC6C2CEBFB8CABDBEB2B6C5C2AEBDBDAEB7
E1B9ADC1C4D2BFA4CAA7A9B6C8D0C8BFDAECD1AEC0B3ADC0
C2BFC0B0D2C0BEAB
ABB6C49CB4BAA6BCC5C6C1B0CFC8C6CBA7BFA9BBCABAB2B2
B6C3C6B9BBCBB6BEBDA9B3C2C2CCB4B1CDC6C0C0BBCED1B8
B2D8C9C9C7A2D4A7C2ECB9C4CAB3C4C2ABBFCBB7AEC7CDC8
D8C0C4C0B49ECCC4C6B895E8C2C8B6ADD2BDBDC6BCCBC899
AEB4C0BDCFBEDFC1A0C0BFC2C8BCBCC0BBB9C9B4CBC5D3C4
C4C9BFACCFA0BAC6
B6B9C4B9C9C6BDB3BBC3C0A4CBB4C4D3A9A5B7B2B0BEC6BD
D8C2C2C2B2C2BAC0C1B9C7B2B7D4CFC7B6B3C29EBFB3C4C4
FE30A493C2C6BEBAB1C6D2CCB7BFB2C8C6A9C6B9CCBEADBB
B9C8BEBCBF9FB68ED3B7A9C4C4AEC4B79FC4C6BDC8BBBBC0
C6C0CAAFB9BEC9C7B7A390ABC4D8C6ADBBB0C6CBBCC2BDBD
BDCCD0DACAB7B2A5
BEBABDC6C2C6B6BFC0CDC9CCBEB9C8B8AB8777B89FD1C2C0
C6BCC3D6ADCDB2B5BFD9C8C6D2C4D1C6B9BAB2C2CABFB8A9
AF92C9B7ADD6C1BDCDC4BFC5B2C9C2D7CDB49DAFBDBDC5BD
CECAC4C099B89DA2B1BFB3DFD2CD8FA6C9B0C0CECCBDB0B4
C8B39DD8BBC089C0A8B0AED3A2AEA4BDDAC0B4B3C8C4AFC4
D1C9C8C6C6C0C0A8
BEB5B9B7B2CDB7C5C0C8C6C8B4BFB9BBC5B0C0C4B6C0B5B6
C3D6BBBBC0B0BFD4BDA7C2C4BA9DD0C2C6ADB3C2CDD3C0C0
BDC6C6ABBCB6C4C0B4DFAAC6B09FB4C8BDB2B3C8B7C8C6C0
BCCBCAB0C4B88DAECAACCEBEBDAFB5CEC4BFB9CDBBB5A5C9
D4B1BEBDC9C0C8BCB689B9BEBDCCB1C884B8C8C4BFC8C8C4
C2CA99B9CBBEBCA7
ADBAB6BBBDC6B3A2BDBEBABBA1C7B0C2BEC7C0CEC2BCC6C9
CDBBB6BCB6CBC1BDBDCABBB3C8C4B7B5BFA4B4C4B4B7C3B5
C1C8C6DADDCFC2BABECAD8A7B0A8BBDAC9BCC8B5B4C9CCD1
C4AD98D5C9C4BCAEC6B4D2C5B4CBB6BF9ED6BBB2A6AEC8D5
B7BEADA7C19D99C0B3B9BCC2AA91B9BAC4C8BBBCC7C8C5C9
CDD4C4ECAEB6A19D
B1B4ADB5C3C0C0C2B4B8B0BFA4A7C8C2C8B9C6B3BFCDC8B0
CEBFC2BEC2CDC0C0C6C1B4B7C1B5BBC9D4BFC6B2C0C3C8CA
CCBFC0C2D8B2B6D0B7C8C7BFBAD2C0B6CCBDC5B7C0A5B6BF
C2C6B2BAD2C6B9A4B0D2C6EAADCDB4B8AEC1B79386B3B4C6
BFC2CEA5B5BAA8BDADC4C3BDB5C2CBB9B9CDCBD1C7D8C5C9
C9CAB8C8B6BEDCB0
B3B0B7BEAEAEBFBBBCC6C6ADB8ADC4C0BFBFC2C8C6A1BCC6
B9AEC4C8C0B3BAC5C4BEBDD4D8D9D8C2B5C2C2B6BAA7B0C4
C2CEAFC8C4D4B8B3CFD2C0C0A4AEC0C1CCB5A4B9BECAC0BB
CAC0C0C5D6C4D2ADCDC4CBAFC2C699BE87D2C6ADA4B7BBB6
C1BFB4BFAEA7B6B7ABB8C2B4C8CFB4BDCAC8CEB3CEB251BD
BBC2C9C2BCC9C8C6
C2ABB3B8C5C8BEA0C8B5C4B9C0B5B2BFBFBCBFC5B9ABE9B3
BEBD71BAC2BDBCB6B3AED0CBDED5C2B2C2BDBDC7BFB4D4BD
CFD9E6CDA0BFB7C6CBD2BCC6CDD0BAB496A0B3A7BFC4C8C4
C8D2CAA8B5BFC6B8BED3A496BBBDA9A09699BA809BC6BCBE
C5BFDABBC1C39998A1BDC4C6B9BBCBC5D3C4C2D4C7BEB5B7
BFABB6C4C9C6B4C8
B3ABBCA9B7B3BABED6D0C6ABB3BBB7C39CBEBAA99DC4ACC7
B7BBA6BCC2BFC7B0C3DDC9B78667A7BDC8C6B9B9C8C3B5C1
C9C9BCC6CFCDAB99B0A7CABBC1CAC8B8C4BDC4C4CDABB9C6
C6CFC5C99EB6BBC2CAB0ABADBAC2B8CEB0A8C08583B0CCD5
9FC0ABBBAECDB6C2B8C699C3C3BFDEBBC6B5B7C0C0B2D0C0
ADD4BBBAD3C0DFA0
ACB9B4BAA9B8B9C2C4C6C5A7B5C2B8ADB3BEB2B8B9CDCDB4
ADBFB9C0B9A5A7BDCAB1BB92C4CBCFB4D4B5D4ACC2B4CDDD
B9B6C0B7B7C5C8B6CBC2C0CACCC4C2CBC8B4ADA9B9C4B8CD
B9C1C0B4D2B4C3C9C6B89BC8BCACBEC2B0C79197B1C8BDC2
B7B7CAC2B8BFC4BACDC4B8B6CDBFB7B7CEB6E6C6BDC9BAC2
C8C6C8DBD0C0B3C2
BBC4B1ABB8D9D1BCC2BAC2B8A9CCB6C2B6CBC2C0BDC4B9AF
BFB3BFCCBCB2BEBFB59C9C83B5BDD2B9C4BBB3CBC2CBCEC8
9CC2D6D0C4BDCAD1B9D1CEC8C8DECDB3BBC4A7BBD3C0CBC4
BFB9BFC2A0DAA9B1CEE97BD69FCBB6BAB8B2A89EDFC9C29A
AFB5BFD4AED4DABAC0B6C5DBCBCAE4B0B9BE9FAFC0B2BDD2
BDCCD0A4CC94C5BC
B9B8BBC997AEBABCBDB9D6B2B0BEAEB0CEC2BCC5C2B1BFC8
C4CAC7BABECBC2CEC6A6ACCBC8B7BEC6B0C9B6CDC7BFC4B5
BED0CAC6CBCBC0C6BBCED1C2B4D58ABFD4B198B1C7CEC0BD
C39EB3C6C2BFCEC0ABAE9AD9C0E0BAB7A3D7C4A787C0CA9C
CCBDE2D6B6C6B7D5ADC4C4C0BCC9BDC0ADCECAA3A6BEBEBB
BFD0B3BFC2C6C2B0
B8BEC6C2C8ADAEBCBEC4C4A1B3B4C3C4C6C6C7C4B6C8C4C3
B0D8C4B9ADC69EC6CFC0B7B7C4C2BBB3B9C0BDCDC0C7BBC8
CCA6CEC4CED1CECFA0BFC3AE77A7B2BAC8ACC4C6C0CEB4BB
C0AABA9ED4CEBBC0D2B7C39399A4B3B39E89A7A0B3D2C4C8
BBE5A2B4B5C4B1A5AEB2D4ADCEB0B9C5C8C2DACEC4D2BDB9
B7C4C6BEB4BDB8B5
B8C3C1B6C4C4A7B3C2BEB6BCA5BFB7B5C2B2B9B9B3BCC2C0
C2AEC4C0C0BBA5B4C796CEB4CAC8B9BACCC8C0C1CBCFC6D0
A3F6C9C4C2B2CCBCC9E6AEDAA4CFA9B6C4B6BCB8C6B4C4B8
C5C9B5A8B3BBC89A9EB6B488B2C0C8ABB0ABB89EA6D8ABB1
C0B1CAA4CFB5BBBF9CBBAEC3B3B7BDB9B7BDC4C2C0C2C8BD
C2C7C3CEC0C6C0B5
C0BDD6C4C7B4BBB3B3CAABB3B5B7ADB9C2C0A1BCC2B2C6D6
C0C2BFBDBDB8AFB9C1ADB9A7C8CEC6C1C0BBC3C3C2C4C4CC
C2A8C0BBD4CCA4BDBCB9C4B9B6C5C2CAC8BFB4B1C5C5C1C9
BAABC8B2A8BFDFC0C8B2BFABD3C68AB7BDB7C2BBB1B3B998
D8C0C6C0B5C4A9C59CCCCFC3D2CDD2CDCFBCB1B3BCBBC3BD
C4C4CCBEBDB5B5C2
BBADC2B6B8B2C6C8ADB8BEA2ABB4B9B7BDB4ABBDC7CDA9B5
C0C4B0C4B8B2C0BBC0C0B2CBB4B0C8A1C5C261BDC4BFBEA6
C6D7C1D2D4BAA9DFC3B3BCCBB4CCBDC3C5BFABB4BBAFC8C4
BCBFB9C2CDA4C7CDC6C6C3A2C9D1B6ADC1BAA6C3CDA4BFB6
BFB0B6A2CFB7ABC8C2BDCBC6BBCCDDA5B3A0B4A1B9AFC6CB
C8B9ADC8C4B6C2D0
BBBBBCB8BEC2CBC0BFC1BDB2A5B0B0BCB5BAB8C0A6B698B1
BDC8B8C8BBB5A9B7C2C0CBB9DAC2C008C6C8BA97B7C6C5CE
B2B5CDB8AFCE989CB6C0C2CAC0C99EB5BDBAB883B7F1D3C1
CEB9AEC6C0BDC4CCD6A2BBBBDBCECEC5BAC8BFA99B928CCB
9EB9D4ABD0ACD6BFA4D0D4DBCCB0BBC2B6BFBDBABFB1BDBD
C5B7C6CBA6C2C4B7
BBB5BDAEBDB5BBBEC0B9C0B4ADBABBB2B3B9C1C1B9BAC6A9
C2C4D4C2C5FEB8D2B5B2C4CFB9C4B8BDC9C9BFACC6C2C8B3
CEC6B5D1B1C2AFB6B7C8C9CFC0BEC6C6BBAFB2BAC6AFBEAD
C4BCC4D5BBC2C9BDB6C8C3C4AFC6B8C4B0A791A7C8BBC0B2
C5BAD4C4D7AFB3D6C8CBB9A3A9B5CC9EBBB6C4A7C4C4C2C8
B7C0C4BBB9B4C0BF
BBB9A7C0B7B8BFD6BDC2BFC8A0B6C7B0ADB8C4C4B9BDA7C4
B8BAAEBAC480ACC2C8B2BCC2C6D3BEC0B3C0B3C4BFC2D9C6
CDBEC6B3C8B3C4C2A9C2E1B9B3BBBBABCBBCC6C6BAB4CFC9
BDCDD2CABDC9B3D6AFBDB9CDCADAD0C2B2BDB6C1BBC4ABC6
B2CFCDC6D2D6CECCC2BBB4A0C0CABCB7B4C8BBBEC4D9CAC6
BDC7ADC6C9C6CBC6
C8D8CDCDBBADBCB0BAB3C1B1A7BCB4BFC6C4B7BFBFA4BDA9
C84CBFBBCBBAB5C2C0C6C2CFC8C0C2C0B8C3C2C2BCC9C1C9
BABCBCBDA0CAC4BFC0B8C8C0B8CBBCC0CDC2ADA4ACB8B8BC
BCD08FB8C7B9C6B3C0C6B4D1D4C2C6B99E9EAEB2AFC28CC4
B4BEBDD6A2B2B5BBB4CAC2CDD6C8D4BE8AB5C1C5D3BBC2BF
C4A0B9AAD1C0B4C4
BFB6BAC4B5CDA0C6B8B3C6AE96A1C2BABDC2BFABADC6C4B6
CBBCC0C09EC2A49CA0ACCBC2B2C2CEC2C4B3BBCBC2C6B9C8
C9BAA1C4CAD3A1B6C0C2AFC2BAC8C1BBD5C17DB2D4D4CFC0
CAC4BDD2CDC8CBBDB8C9ACB0B4C5B6B9AEA2BBCF93B6A4C2
CACAAAB9A3CDB7BFD1CDD8C8C4DBCCC6D1C2B9D2B9C2B890
C8CBCBC4D5D1BAC2
B4BEBCB7B7C6BEBEA7BABEB68B95B8B8C8ADB9C6C0D4BBB4
BEC0CFBCB4B5BABEBAC1C8C4C9C2B8BEC4C6C8CDB5D2CFAD
C9AEC6CAD6BDBDB3B9B3CEB8C6DADCC1CCAAB7B5CBD3D9BF
D0C2CCCDC6ADAECBAFAEC4B9BBBFCDA7B0ADCDC7A6B8ADCC
CFB3B7D2C3C7BDCFC9C7D8C2C4B4C9BFBBCAA29AC1B6BEC2
CBD9D1CCC0C8B9C0
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -35 0 ]
[.5 1.0125 35 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Classified) show
123.000000 12.812500 moveto
(5) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
D733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFF5FFCC
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF66A3FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF99FFC2D733FF\
66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FFD733FF\
66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFF5FFCCD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FF
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF
D733FF66A3FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FF99FFC266A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FF
66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FF\
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF99FFC2D733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FF\
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FF\
D733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF99FFC2D733FFD733FF99FFC2
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF99FFC2D733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFF5FFCCF5FFCC66A3FF\
D733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF
66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFFF0000
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFF5FFCC66A3FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF66A3FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFFF000066A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FF66A3FFD733FF66A3FFD733FF66A3FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FF66A3FFFF0000D733FFD733FFD733FF66A3FF66A3FF
66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FF66A3FFD733FF66A3FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFF5FFCCD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FF66A3FFD733FF\
66A3FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FF
66A3FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFFF0000D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF99FFC2\
66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF99FFC2D733FF66A3FF66A3FFD733FF\
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFF5FFCCD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FF66A3FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF\
66A3FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FF66A3FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFFF0000
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF\
D733FFFF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF99FFC2D733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF66A3FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF99FFC2D733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FF66A3FF
66A3FFD733FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FF99FFC2D733FFD733FF66A3FF99FFC2D733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFFF0000D733FFD733FF
D733FFD733FFD733FFD733FF66A3FF99FFC2D733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF\
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF\
66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF99FFC2D733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF99FFC2D733FFD733FF66A3FF66A3FF\
D733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FF66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
66A3FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
66A3FF99FFC2D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFFF000066A3FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFFF0000D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF99FFC2D733FFD733FF66A3FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FFD733FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FF66A3FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FF66A3FF66A3FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FF
D733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
FF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
FF000066A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF99FFC266A3FF66A3FF66A3FF
99FFC266A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FF66A3FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF\
D733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF\
D733FFFF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFFF0000D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFF5FFCCD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
FF0000D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF99FFC266A3FF66A3FFD733FF
FF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFFF0000
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF99FFC2
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF99FFC2D733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FF\
66A3FFD733FF66A3FF99FFC266A3FFD733FFD733FFD733FF66A3FF66A3FF66A3FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FF\
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFF5FFCC66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF\
D733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FF66A3FF99FFC299FFC2D733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF
66A3FF66A3FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF99FFC2D733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FF99FFC2D733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FF99FFC2
D733FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FF99FFC2D733FFD733FFD733FFD733FFD733FF66A3FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF
66A3FF66A3FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFFF0000D733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FF66A3FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFFF000066A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF99FFC2D733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF\
D733FF66A3FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFFF000066A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFF5FFCCD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FFFF0000D733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFFF000066A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFFF0000D733FF66A3FFD733FFD733FF66A3FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF99FFC266A3FF
D733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
66A3FFD733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FF66A3FFD733FF66A3FFD733FFFF0000D733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFFF0000D733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFFF0000D733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FF99FFC2D733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FF\
D733FFD733FFD733FF99FFC266A3FF66A3FFD733FF66A3FF66A3FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FF66A3FFD733FF99FFC2D733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFFF0000D733FFFF0000
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FF66A3FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFFF0000D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FF66A3FF66A3FFD733FFFFFFFF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF99FFC2D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF
D733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF66A3FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FF99FFC266A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FF66A3FFD733FFD733FFD733FF66A3FFFF0000D733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
66A3FF66A3FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFFF000066A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FF99FFC2D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FF
D733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF\
66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FF99FFC2
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF99FFC2D733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF\
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFFF0000D733FF66A3FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFFF0000D733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFFF0000D733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
FF0000F5FFCC66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF\
66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FF\
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FF99FFC2D733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF
66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
D733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FFD733FF66A3FF\
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF\
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFFF000066A3FFD733FF66A3FF66A3FF
66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFFF000066A3FF\
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF\
D733FF66A3FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF99FFC2D733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFFF0000D733FF
D733FFD733FF99FFC2D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
D733FF66A3FF66A3FF66A3FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF\
99FFC266A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FF66A3FF66A3FF66A3FFD733FFD733FF
66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
66A3FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFFF000099FFC2D733FF66A3FF\
D733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FF66A3FF
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
D733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF99FFC2\
66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
66A3FFD733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FF66A3FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
66A3FFFF0000D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FF66A3FF\
D733FFD733FF66A3FF66A3FF66A3FFD733FF66A3FF66A3FFD733FF66A3FF66A3FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FF66A3FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF\
66A3FFD733FF66A3FFD733FFD733FF99FFC2D733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FF66A3FFD733FF66A3FFD733FF66A3FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFFFFFFFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
66A3FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF\
D733FF66A3FFD733FFD733FFD733FFD733FF66A3FFD733FFFF0000D733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FF
66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFFF0000D733FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF\
D733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
D733FFD733FF66A3FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF
66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FF66A3FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FF66A3FF
D733FFF5FFCCD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FF66A3FF66A3FF66A3FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FF66A3FF66A3FF\
66A3FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FF66A3FFD733FF66A3FF66A3FF66A3FF66A3FFD733FFD733FF66A3FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF99FFC266A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF\
D733FFD733FFD733FF66A3FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FF66A3FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FF66A3FF\
66A3FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF66A3FF
D733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FF66A3FFD733FFD733FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FF66A3FF66A3FFD733FFD733FFD733FF\
D733FFD733FF66A3FF66A3FF66A3FFD733FFD733FF66A3FFD733FF66A3FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF\
D733FFD733FFD733FFD733FFD733FF66A3FF66A3FFD733FFD733FFD733FFD733FF
D733FFD733FFD733FFD733FFD733FFD733FFD733FFD733FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{400, 190.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`009@3oool00`3;bl/0`l?30<O7a`020;Ng]`070<C4
a02k^k/0`/;20<30`02g]kL0`<300;jn_P020<O7a`050;no_`2f][H0Zj^[0;2`/02a/K400P2i^KT2
0;fm_@070;Bd]02][Jd0];Bd0:RXZ03@d=00[:b/0;2`/0030;Vi^@060;6a/@2m_Kd0_Kfm0;Ng]`34
a<@0dM7A0P2m_Kd01@2o_kl0b<S80<C4a032`/80_Kfm0080`L710P2BTY801`34a<@0^KVi0<C4a02g
]kL0_Kfm0:RXZ02m_Kd00P3<c<`01`2o_kl0`<300<K6aP2j^[X0];Bd0<S8b02PX:000P2<S8`01`30
`<00`/;20;Fe]@2PX:00SXj>0;:b/P2o_kl00P34a<@01`2o_kl0`/;20<[:bP2f][H0UIFE0<K6aP35
aLD00P2l_;`01`31`L40bLW90<W9b@3?cll0b<S80;jn_P3;bl/00P2o_kl01`34a<@0_kno0;Fe]@36
a/H0alO70<G5a@34a<@00P36a/H01`2m_Kd0a/K60<;2`P2XZ:P0^;Rh0;jn_P34a<@00P38b<P01`34
a<@0`L710;Rh^038b<P0^k^k0=3@d036a/H00P32`/801@36a/H0alO70<?3``32`/80bLW90080bl_;
0P3AdM401`2d];@0_;bl0<S8b02h^;P0/K6a0<G5a@2n_[h00P2m_Kd0102k^k/0a<C40<K6aP31`L4T
0?oooa00ec?o0`1VXol50=Lco`0406JSo`3G<ol0IZ?o0=Lco`80IZ?o0`3G<ol00`1VXol0ec?o0=Lc
o`0<0=Lco`80IZ?o1@3G<ol00`1VXol0ec?o0=Lco`070=Lco`<0IZ?o0`3G<ol306JSo`L0ec?o00<0
IZ?o0=Lco`3G<ol05`3G<ol00`1VXol0ec?o0=Lco`0I0=Lco`0306JSo`3G<ol0ec?o00H0ec?o9`3o
ool002D0oooo00<0^;Rh0<71`@32`/800P2_[jl01`39bLT0aLG50<;2`P30`<00clo?0<C4a03EeMD0
0P38b<P01`2l_;`0aLG50;Zj^P2b/[80_;bl0;Bd]032`/800P2h^;P01`2l_;`0^;Rh0<;2`P16ATH0
dm?C0;Zj^P2_[jl00P2g]kL01`2][Jd0];Bd0;jn_P2o_kl0/[:b0;Rh^03Kfm/00P31`L401`38b<P0
^KVi0:j^[P2e]KD0clo?0<;2`P36a/H00P3?cll00`2f][H0`/;20;^k^`020;fm_@0;0;no_`2WYjL0
];Bd0;Bd]03?cll0RXZ:0;Rh^03=cLd0[Jf]0=?Cd`2_[jl00P2PX:001`2k^k/0]kNg0:n_[`3=cLd0
_[jn0:FUY@30`<000P24Q8@01`2[Zj/0_kno0;2`/02k^k/0`/;20;6a/@2n_[h00P3<c<`01`3@d=00
^KVi0;bl_038b<P0`/;20<K6aP2m_Kd00P34a<@01`32`/80/[:b0;Ng]`2l_;`0`L710<_;b`3@d=00
0P2k^k/01`3=cLd0/K6a0<W9b@32`/80_[jn0<;2`P2a/K400P2o_kl01`39bLT0_kno0<c<c032`/80
_[jn0<_;b`3AdM400P3=cLd01`3?cll0aLG50;2`/037alL0a<C40<S8b032`/800P2b/[801P3>c/h0
/K6a0<[:bP3@d=00X:2P0;Zj^P<0bl_;00@0alO70;Rh^02e]KD0bl_;903oool30=Lco`80IZ?o303G
<ol00`1VXol0ec?o0=Lco`060=Lco`040?Goc03G<ol0ec?o06JSo`80ec?o00D0IZ?o0=Lco`3G<ol0
ec?o06JSo`060=Lco`0306JSo`3G<ol0ec?o00X0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`020=Lc
o`0306JSo`3G<ol0IZ?o0080IZ?o0P3G<ol01@1VXol0ec?o0=Lco`1VXol0ec?o00<0IZ?o00D0ec?o
06JSo`3G<ol0ec?o06JSo`0=0=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol00P3G
<ol00`1VXol0ec?o0=Lco`0;0=Lco`0306JSo`3G<ol0ec?o0080ec?o0P1VXol01@3G<ol0IZ?o0=Lc
o`3G<ol0IZ?o00P0ec?o9`3oool002D0oooo0P30`<002P2m_Kd0^KVi0;Vi^@2m_Kd0ZJVY0;Bd]037
alL0a/K60<W9b@34a<@20;Rh^0070;fm_@2e]KD0^;Rh0;Zj^P30`<00a<C40;Ng]`020;fm_@070;^k
^`36a/H0`<300:NWY`2k^k/0^KVi0;Fe]@020:b/[0070;^k^`2f][H0^KVi0;Jf]P3;bl/0[Zj^0<W9
b@020<71`@030;Vi^@36a/H0WYjN0080alO700H0bl_;0<o?c`36a/H0a/K60;Zj^P2/[:`20<C4a003
0;Rh^02b/[80b<S800<0a<C400H0_[jn0<W9b@2l_;`0alO70:j^[P2WYjL209nOW`070;Jf]P2WYjL0
]kNg0<;2`P2h^;P0^[Zj0<o?c`020;Ng]`050;2`/02WYjL0a<C40<30`02k^k/00P30`<020<;2`P03
0<K6aP3Cdm<0_[jn0080b<S800P0_;bl0;:b/P36a/H0a/K60<_;b`30`<00a<C40<K6aP80alO700X0
bl_;0<G5a@35aLD0`L710<o?c`39bLT0[Jf]0;2`/030`<00c/k>0P2m_Kd01`33`l<0_;bl0<K6aP36
a/H0`<300<;2`P3=cLd00P3;bl/01`2b/[80`l?30;Fe]@2l_;`0alO70;bl_03Cdm<00P3?cll01`34
a<@0]KFe0=GEe@37alL0/;2`0<;2`P2l_;`00P37alL01030`<00bLW90;>c/`34a<@T0?ooo`H0ec?o
00<0IZ?o0=Lco`3G<ol04@3G<ol0101VXol0ec?o0=Lco`3G<ol206JSo`D0ec?o00<0IZ?o0=Lco`3G
<ol00`3G<ol00`1VXol0ec?o0=Lco`050=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol0203G<ol406JS
o`030=Lco`1VXol0ec?o00H0ec?o0P1VXol=0=Lco`0306JSo`3G<ol0ec?o00`0ec?o0P1VXol=0=Lc
o`0306JSo`3G<ol0ec?o00X0ec?o00<0IZ?o0=Lco`3G<ol01P3G<olW0?ooo`009@3oool00`2f][H0
]KFe0<O7a`020;:b/P070:j^[P2ZZZX0];Bd0;Zj^P2m_Kd0];Bd0<W9b@020:^[Z`050<K6aP2o_kl0
_Kfm0;Vi^@3;bl/00P30`<030<C4a0060<30`032`/80_[jn0:6QX@2b/[80`/;20P2f][H01`2o_kl0
^[Zj0;Zj^P2TY:@0]kNg0=?Cd`3Hf=P00P32`/801`36a/H0`<300<O7a`2o_kl0`/;20:NWY`2l_;`0
0P2_[jl01`31`L40bl_;0;^k^`2b/[80^[Zj0;bl_02ATI400P2n_[h01`2c/k<0aLG50<_;b`37alL0
bLW90;Bd]02?Shl00P1iNGT01`2k^k/0Zj^[0;Vi^@37alL0Xj>S0;Bd]02h^;P00P2YZJT01`2`/;00
d=3@0;fm_@2g]kL0bl_;0<;2`P30`<000`36a/H01P2c/k<0b/[:0<K6aP2l_;`0/[:b0:VYZ@80c<c<
00D0_Kfm0:NWY`3>c/h0a<C40<[:bP020<30`080b<S800H0_[jn0=[JfP34a<@0][Jf0;fm_@2i^KT3
0<W9b@070;jn_P34a<@0bLW90<71`@2m_Kd0d=3@0<C4a0020<W9b@070<O7a`3Cdm<0/[:b0<;2`P2i
^KT0a<C40;no_`020;Ng]`070>7Qh@34a<@0hn?S0<C4a02g]kL0cLg=0;bl_0020:NWY`040;fm_@2W
YjL0`/;20;bl_2@0oooo0`3G<ol406JSo`D0ec?o0P1VXol=0=Lco`80IZ?o1P3G<ol00`1VXol0ec?o
0=Lco`080=Lco`0406JSo`3G<ol0IZ?o06JSo`<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o203G<ol01@1V
Xol0VOo209Wo`P3G<ol0IZ?o0080ec?o00<0IZ?o0=Lco`3G<ol00`1VXol=0=Lco`80IZ?o0`3G<ol0
0`1VXol0ec?o0=Lco`0I0=Lco`0306JSo`3G<ol0ec?o00/0ec?o0P1VXol0103G<ol0IZ?o0=Lco`3G
<olW0?ooo`009@3oool00`2f][H0]KFe0<O7a`020;:b/P070:j^[P2ZZZX0];Bd0;Zj^P2m_Kd0];Bd
0<W9b@020:^[Z`050<K6aP2o_kl0_Kfm0;Vi^@3;bl/00P30`<030<C4a0060<30`032`/80_[jn0:6Q
X@2b/[80`/;20P2f][H01`2o_kl0^[Zj0;Zj^P2TY:@0]kNg0=?Cd`3Hf=P00P32`/801`36a/H0`<30
0<O7a`2o_kl0`/;20:NWY`2l_;`00P2_[jl01`31`L40bl_;0;^k^`2b/[80^[Zj0;bl_02ATI400P2n
_[h01`2c/k<0aLG50<_;b`37alL0bLW90;Bd]02?Shl00P1iNGT01`2k^k/0Zj^[0;Vi^@37alL0Xj>S
0;Bd]02h^;P00P2YZJT01`2`/;00d=3@0;fm_@2g]kL0bl_;0<;2`P30`<000`36a/H01P2c/k<0b/[:
0<K6aP2l_;`0/[:b0:VYZ@80c<c<00D0_Kfm0:NWY`3>c/h0a<C40<[:bP020<30`080b<S800H0_[jn
0=[JfP34a<@0][Jf0;fm_@2i^KT30<W9b@070;jn_P34a<@0bLW90<71`@2m_Kd0d=3@0<C4a0020<W9
b@070<O7a`3Cdm<0/[:b0<;2`P2i^KT0a<C40;no_`020;Ng]`070>7Qh@34a<@0hn?S0<C4a02g]kL0
cLg=0;bl_0020:NWY`040;fm_@2WYjL0`/;20;bl_2@0oooo0`3G<ol406JSo`D0ec?o0P1VXol=0=Lc
o`80IZ?o1P3G<ol00`1VXol0ec?o0=Lco`080=Lco`0406JSo`3G<ol0IZ?o06JSo`<0ec?o00@0IZ?o
0=Lco`3G<ol0IZ?o203G<ol01@1VXol0VOo209Wo`P3G<ol0IZ?o0080ec?o00<0IZ?o0=Lco`3G<ol0
0`1VXol=0=Lco`80IZ?o0`3G<ol00`1VXol0ec?o0=Lco`0I0=Lco`0306JSo`3G<ol0ec?o00/0ec?o
0P1VXol0103G<ol0IZ?o0=Lco`3G<olW0?ooo`009@3oool00`34a<@0`<300;Vi^@020<W9b@070;Rh
^02j^[X0_kno0;^k^`2c/k<0e]KF0<o?c`020;>c/`050;2`/02f][H0^;Rh0;Fe]@32`/800P30`<02
0<;2`P050;Ng]`2b/[80`<300<_;b`31`L400P32`/8209FEU@070;Bd]02h^;P0YjNW0;bl_030`<00
`l?30<_;b`020;Ng]`040;Fe]@37alL0];Bd0;bl_0<0a/K60P2h^;P01`2g]kL0WIfM0;Bd]02YZJT0
`/;20;:b/P38b<P00P3@d=001`2i^KT0_kno0;^k^`2VYZH0bLW90:f][@2<S8`00P26QXH01`2d];@0
ZZZZ0;Rh^03De=@0XZ:R0;>c/`2o_kl00P2b/[801`34a<@0=SHf0;Ng]`2j^[X0`/;20<O7a`2b/[80
0P2j^[X01`2i^KT0[:b/0;Vi^@2m_Kd0_kno0;:b/P2e]KD00P32`/801`2d];@0a<C40<W9b@39bLT0
`<300;Ng]`3:b/X00P3;bl/01`2h^;P0a<C40;Zj^P2j^[X0dM7A0<O7a`3AdM400P39bLT01`38b<P0
`/;20<K6aP2h^;P0a/K60;Vi^@2k^k/00P30`<001`3=cLd0[jn_0<k>cP32`/80a<C40<W9b@36a/H0
0P3Bd]801`2h^;P0XJ6Q0<C4a02^[Zh0cLg=0;bl_02n_[h00P2e]KD0102k^k/0]kNg0:j^[P2`/;0T
0?ooo`h0ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol00`1VXol0ec?o0=Lco`030=Lco`80IZ?o0P3G<ol0
0`1VXol0ec?o0=Lco`0>0=Lco`0506JSo`3G<ol0IZ?o0=Lco`1VXol01P3G<ol00`1VXol0ec?o06JS
o`0306JSo`050=Lco`1VXol0ec?o0=Lco`1VXol00P3G<ol206JSo`030=Lco`3eol`0ec?o00<0ec?o
00D0IZ?o0=Lco`3G<ol0ec?o06JSo`030=Lco`0306JSo`3G<ol0ec?o01d0ec?o00<0IZ?o0=Lco`3G
<ol01P3G<ol00`1VXol0ec?o06JSo`070=Lco`80IZ?o9`3oool002D0oooo00<0/K6a0<G5a@2n_[h0
0P2h^;P01`3AdM40bl_;0;bl_030`<00^[Zj0<[:bP35aLD00P3;bl/01`2f][H0^k^k0<K6aP2j^[X0
alO70<30`036a/H00P2e]KD20;bl_0040;Zj^P3Ng]h0UIFE08N7Q`<0ZJVY00L0P8200:NWY`2e]KD0
^[Zj0;fm_@30`<00d];B0080a<C400<0c/k>0<W9b@2i^KT00P3=cLd02`2l_;`0[Zj^0;Bd]02d];@0
XJ6Q0;no_`3EeMD0[Zj^0<30`02j^[X0/[:b0080_[jn00H0/;2`0<S8b02m_Kd0^k^k0;fm_@3:b/X3
08V9R@070:NWY`36a/H0X:2P0;Rh^02l_;`0][Jf0;Vi^@020;fm_@070;^k^`3:b/X0`<300<;2`P2d
];@0Zj^[0;>c/`020<;2`P070;Vi^@37alL0_kno0<S8b032`/80`<300<C4a0020;no_`070<K6aP30
`<00d=3@0<;2`P34a<@0`<300<;2`P020:NWY`070<30`02d];@0_;bl0;bl_02d];@0a<C40<?3``02
0:VYZ@070<?3``38b<P0c<c<0<30`039bLT0`/;20<c<c0020<[:bP070=7Ad@32`/80alO70<K6aP3C
dm<0_;bl0<g=c@020:^[Z`070;Bd]036a/H0^k^k0;:b/P37alL0`L710<?3``020;Vi^@040;fm_@2n
_[h0a<C40;jn_R@0oooo00<0IZ?o0=Lco`3G<ol0603G<ol706JSo`d0ec?o00@0IZ?o0=Lco`3G<ol0
IZ?o0P3G<ol0101VXol0ec?o0=Lco`1VXol20=Lco`0306JSo`3G<ol0ec?o00<0ec?o101VXol00`3G
<ol0IZ?o0=Lco`0:0=Lco`0306JSo`3G<ol0ec?o0140ec?o0P1VXol70=Lco`80IZ?o403G<ol206JS
o`<0ec?o00<0IZ?o0=Lco`3G<ol01`3G<olW0?ooo`009@3oool00`31`L40[jn_0;Rh^0020<71`@07
0;Vi^@2k^k/0^[Zj0<30`026QXH0Zj^[0;2`/0020<W9b@070<K6aP31`L40^KVi0;bl_02o_kl0`<30
0:2PX0020<O7a`070;Vi^@3@d=00[:b/0=?Cd`34a<@0/K6a0<C4a0020;Zj^P070:^[Z`2k^k/0ZJVY
09nOW`38b<P0YjNW0=WIf@020<C4a0070<W9b@37alL0/k>c0<K6aP32`/80_kno0<g=c@020=3@d007
0<;2`P2ZZZX0bl_;0;fm_@30`<00alO70<C4a0020<_;b`070;Bd]02`/;00YjNW0<S8b035aLD0^k^k
08>3P`0208Z:RP070;Vi^@2j^[X0W9bL0;Bd]02g]kL0Zj^[0;^k^`020<o?c`0605eMG@2[Zj/0d];B
0;Rh^02k^k/0`<300`32`/801`2n_[h0];Bd0:^[Z`32`/80bLW90;^k^`34a<@00P2o_kl01`30`<00
`/;20;jn_P30`<00a<C40<W9b@2f][H00P3:b/X01`3@d=00^[Zj0:^[Z`2f][H0aLG50;bl_034a<@0
0P3>c/h01P34a<@0a/K60;Ng]`34a<@0a/K60<o?c`<0b<S800L0_kno0<K6aP30`<00_kno0<W9b@3C
dm<0dM7A0080c<c<00L0clo?0<C4a03<c<`0^[Zj0<C4a02i^KT0`/;20080a/K600@0b<S80<30`03;
bl/0`/;2903oool00`3G<ol0IZ?o0=Lco`060=Lco`<0IZ?o203G<ol00`1VXol0ec?o0=Lco`020=Lc
o`0406JSo`3G<ol0ec?o06JSo`<0ec?o00H0IZ?o0=Lco`1VXol0IZ?o0=Lco`1VXol=0=Lco`0306JS
o`3G<ol0ec?o00H0ec?o0P1VXol30=Lco`<0IZ?o0P3G<ol0101VXol0ec?o0=Lco`1VXol30=Lco`03
09Wo`P1VXol0ec?o00P0ec?o00<0IZ?o0=Lco`3G<ol03`3G<ol00`1VXol0ec?o0=Lco`0S0=LcobL0
oooo000U0?ooo`030<30`02HV9P0^[Zj0080cLg=00L0`<300;Bd]039bLT0bLW90;2`/03;bl/0_[jn
00<0alO700H0b<S80<?3``32`/80alO70;bl_02n_[h20;:b/P070:VYZ@2e]KD0/[:b0;fm_@2][Jd0
^KVi0:>SX`020<C4a080]KFe00D0]kNg0;Bd]02_[jl0^;Rh0<_;b`020<W9b@070<C4a03:b/X0/;2`
0;fm_@36a/H0`/;20<C4a0020<W9b@070;jn_P30`<00cLg=0<K6aP2j^[X0`L710<C4a0020=gMg@07
0::RXP2j^[X0_kno0<W9b@37alL0a<C40:2PX00208Z:RP070<k>cP2[Zj/0`<300;Jf]P2NWYh0YjNW
0;^k^`020<30`0070<W9b@2n_[h0dM7A0:NWY`2k^k/0bLW90<o?c`020;jn_P040;no_`2e]KD0];Bd
0<;2`P80a<C400X0_[jn0<O7a`37alL0a<C40;Bd]02^[Zh0`l?30<K6aP32`/80b<S80P30`<001`2m
_Kd0Zj^[0;Bd]038b<P0dM7A0=GEe@3>c/h00P38b<P01P32`/80_;bl09jNWP38b<P0cLg=0<S8b0<0
c<c<00L0c/k>0<K6aP38b<P0`L710<g=c@2CTi<0^;Rh0080_[jn00L0][Jf0;2`/030`<00a<C40<S8
b030`<00]KFe0080/;2`00@0`/;20<K6aP2o_kl0d=3@903oool00`3G<ol0IZ?o0=Lco`060=Lco`03
06JSo`3G<ol0ec?o00T0ec?o0`1VXol01P3G<ol0IZ?o0=Lco`1VXol0ec?o06JSo`H0ec?o00<0IZ?o
0=Lco`3G<ol0103G<ol00`1VXol0ec?o0=Lco`0=0=Lco`0306JSo`3G<ol0ec?o00<0ec?o0`1VXol0
103G<ol0IZ?o0=Lco`3G<ol206JSo`H0ec?o00<0IZ?o0=Lco`3G<ol03P3G<ol00`1VXol0ec?o0=Lc
o`050=Lco`0306JSo`3G<ol0ec?o00L0ec?o00<0IZ?o0=Lco`3G<ol02@3G<ol00`1VXol0ec?o0=Lc
o`020=Lco`0306JSo`3G<ol0ec?o00<0ec?o0P1VXol40=LcobL0oooo000U0?ooo`030:f][@2WYjL0
_Kfm0080YjNW00L0`<300<W9b@2d];@0Zj^[0:NWY`2d];@0[Jf]0080dM7A00L0alO70<71`@2k^k/0
[Zj^0:n_[`36a/H0^;Rh0080a<C400L0[:b/0;Vi^@2m_Kd0]KFe0;Rh^02EUID0^[Zj0080bLW900L0
/[:b0;no_`33`l<0^;Rh0:j^[P2QXJ40^;Rh0080a<C400L0aLG50;^k^`32`/80`<300=3@d039bLT0
cLg=0080aLG500L0_kno0<_;b`2l_;`0bl_;0<?3``31`L40][Jf0080];Bd00L0ZJVY0<[:bP3?cll0
a<C40<;2`P2i^KT0VYZJ0080Zj^[00L0XZ:R0;Fe]@2c/k<0`<300:VYZ@2][Jd0`<300080bLW900L0
Zj^[0:f][@34a<@0`<300;Rh^02a/K40[Zj^0080_;bl00L0^;Rh0<O7a`2l_;`0`<300;jn_P2[Zj/0
^KVi0080a<C400D0alO70:NWY`2o_kl0^k^k0<c<c0040;fm_@040;Rh^036a/H0b<S80;>c/`80c<c<
00X0bl_;0;jn_P2n_[h0bLW90<K6aP3=cLd0dM7A0;no_`3=cLd0a/K60P2/[:`01`32`/80/k>c0;Ng
]`3?cll0`L710<[:bP2o_kl00P2k^k/01`32`/80e=CD0;Bd]034a<@0a/K60<C4a037alL00P30`<00
103;bl/0b<S80<[:bP2UYJDT0?ooo`80IZ?o00<0ec?o06JSo`1VXol00`3G<ol206JSo`030=Lco`1V
Xol0ec?o00@0ec?o0P1VXol40=Lco`0306JSo`3G<ol0ec?o0080ec?o00D0IZ?o0=Lco`3G<ol0ec?o
06JSo`030=Lco`80IZ?o5@3G<ol00`1VXol0ec?o0=Lco`030=Lco`@0IZ?o0`3G<ol206JSo`<0ec?o
0P1VXol30=Lco`80IZ?o1`3G<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0ec?o01D0ec?o
0P1VXolE0=Lco`0306JSo`3oool0oooo02D0oooo000U0?ooo`030<?3``2k^k/0^k^k0080_[jn00L0
_Kfm0;Vi^@2e]KD0_Kfm0;no_`3;bl/0a<C40080_[jn00L0a/K60<O7a`2o_kl0`<300;no_`2k^k/0
]KFe0080^KVi00L0^k^k0;Jf]P32`/80][Jf0:f][@2l_;`0`<300080`l?300L0_Kfm0;no_`36a/H0
][Jf0:NWY`1aLG40_kno0080^;Rh00L0a<C40<30`03Cdm<0bLW90=KFeP3EeMD0bl_;0080^KVi00L0
a<C40<c<c036a/H0alO70;Fe]@2b/[80d=3@0080ZZZZ00L0bl_;0<O7a`31`L40^k^k0;Jf]P2][Jd0
T92@0080QhN700L0SXj>0<?3``2`/;00^KVi0<?3``2YZJT0cLg=0080clo?00L0`/;20;Fe]@34a<@0
b<S80<;2`P36a/H0_kno0080^k^k00@0alO70<C4a02i^KT0Zj^[0P34a<@30;>c/`070<C4a02g]kL0
/;2`0<o?c`2h^;P0^k^k0<?3``020<C4a0070;Fe]@2h^;P0[jn_0;Ng]`2YZJT0a/K60<?3``020=KF
eP030;Fe]@37alL0bl_;0080^k^k00/0cLg=0<_;b`37alL0alO70<o?c`34a<@0bl_;0<C4a03Bd]80
aLG50;bl_0020;Zj^P070;jn_P36a/H0a/K60<W9b@2n_[h0d=3@0<C4a0030;no_`030;fm_@2l_;`0
bLW902@0oooo6`3G<ol00`1VXol0ec?o0=Lco`060=Lco`0306JSo`2Iol80ec?o0100ec?o00@0IZ?o
0=Lco`1VXol0IZ?o1@3G<ol506JSo`050=Lco`1VXol0ec?o0=Lco`1VXol03`3G<ol00`1VXol0ec?o
0=Lco`050=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`1VXol08`3G<olW0?ooo`009@3o
ool00`37alL0`<300<C4a0020;^k^`80/k>c00D0_[jn0;bl_031`L40];Bd0;fm_@020;jn_P070<G5
a@2l_;`0a<C40;jn_P2m_Kd0`l?30<k>cP020<30`0070;Rh^03:b/X0`/;20;6a/@2m_Kd0`<300;jn
_P020<C4a0070;jn_P2l_;`0_;bl0;jn_P2QXJ40^KVi0:NWY`020;jn_P070<;2`P30`<00a/K60;Bd
]037alL0_[jn0;2`/0020<O7a`070<g=c@33`l<0_Kfm0<71`@3>c/h0bLW90<;2`P020<K6aP070<S8
b036a/H0a<C40<C4a03=cLd0/;2`08F5Q@0209FEU@0709VIV@2i^KT0W9bL0;Ng]`2[Zj/0[Zj^0;^k
^`020;Jf]P070;Fe]@2_[jl0XZ:R0<;2`P2n_[h0][Jf0;Bd]0020=7Ad@070:j^[P32`/80]KFe0;Bd
]02b/[80h^;R0;Ng]`020;^k^`040;6a/@2c/k<0clo?0<71`@80alO700X0/[:b0=7Ad@3AdM40f=SH
0<C4a03;bl/0cLg=0<;2`P2m_Kd0_kno0P2c/k<01`3@d=00`<300<C4a03?cll0bLW90<30`036a/H0
0P3;bl/01`30`<00a<C40<g=c@34a<@0];Bd0<g=c@3AdM400P3;bl/01`36a/H0/k>c0<;2`P2g]kL0
`/;20<g=c@31`L400P3EeMD0101FEUH0_;bl0=SHf01fMWHT0?oooaX0ec?o00<0IZ?o0=Lco`3G<ol0
1`3G<ol00`1VXol0ec?o06JSo`080=Lco`0306JSo`3G<ol0ec?o00h0ec?o1@1VXol00`3G<ol0IZ?o
0=Lco`0206JSo`@0ec?o0P1VXol60=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol0103G<ol00`1VXol0
ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o02@0ec?o00@0VOo20=Lco`3G<ol0VOo29`3oool002D0
oooo00<0a<C40;jn_P2k^k/00P2g]kL01`38b<P0`<300<71`@2b/[80];Bd0<k>cP28R8P00P3<c<`0
1`31`L40`<300;no_`31`L40`/;20:NWY`2m_Kd00P3=cLd0102m_Kd0][Jf0<C4a03?cll20<?3``0:
0;fm_@2g]kL0]kNg0;Ng]`2n_[h0/k>c0;jn_P32`/80a<C40<g=c@80Ogmo00L0alO70<W9b@3De=@0
ZZZZ0<?3``2f][H0bLW90080^k^k00L0cLg=0=KFeP36a/H0]kNg0;no_`2k^k/0/k>c0080/;2`00L0
^KVi0<S8b036a/H0_Kfm0;no_`2[Zj/0;2`/0080@d=300L0QhN70<C4a02^[Zh0_[jn0:NWY`2n_[h0
]kNg0080/[:b00L0`/;20<K6aP2k^k/0Y:BT0;6a/@2][Jd0^KVi0080b/[:00L0Zj^[0;Zj^P3<c<`0
_Kfm0<_;b`36a/H0`/;20080bl_;00L0];Bd0;Vi^@3<c<`0^[Zj0<k>cP2o_kl0_Kfm0080fMWI00L0
`<300;fm_@2TY:@0/K6a0;Ng]`30`<00[Jf]0080a<C400L0`<300;fm_@35aLD0j^[Z0=?Cd`39bLT0
`/;20080`<3000L0alO70;Ng]`2m_Kd0a/K60;bl_02i^KT0`l?30080alO700L0bLW90;jn_P2g]kL0
aLG50;:b/P37alL0_kno0080c/k>0P34a<@00`2i^KT0`<300?ooo`0S0?ooo`P0ec?o00@0IZ?o0=Lc
o`3G<ol0IZ?o1`3G<ol00`1VXol0ec?o0=Lco`0A0=Lco`80VOo20`3G<ol00`1VXol0ec?o0=Lco`0:
0=Lco`80IZ?o1@3G<ol02@1VXol0mOo<0?Goc03eol`0IZ?o0=Lco`1VXol0ec?o06JSo`020=Lco`80
IZ?o0`3G<ol306JSo`<0ec?o00<0IZ?o0=Lco`3G<ol04@3G<ol206JSo`80ec?o00<0IZ?o0=Lco`3G
<ol00`3G<ol00`3o0000ec?o0=Lco`0@0=Lco`0306JSo`3G<ol0ec?o00H0ec?o9`3oool002D0oooo
00<0a<C40;jn_P2k^k/00P2g]kL01`38b<P0`<300<71`@2b/[80];Bd0<k>cP28R8P00P3<c<`01`31
`L40`<300;no_`31`L40`/;20:NWY`2m_Kd00P3=cLd0102m_Kd0][Jf0<C4a03?cll20<?3``0:0;fm
_@2g]kL0]kNg0;Ng]`2n_[h0/k>c0;jn_P32`/80a<C40<g=c@80Ogmo00L0alO70<W9b@3De=@0ZZZZ
0<?3``2f][H0bLW90080^k^k00L0cLg=0=KFeP36a/H0]kNg0;no_`2k^k/0/k>c0080/;2`00L0^KVi
0<S8b036a/H0_Kfm0;no_`2[Zj/0;2`/0080@d=300L0QhN70<C4a02^[Zh0_[jn0:NWY`2n_[h0]kNg
0080/[:b00L0`/;20<K6aP2k^k/0Y:BT0;6a/@2][Jd0^KVi0080b/[:00L0Zj^[0;Zj^P3<c<`0_Kfm
0<_;b`36a/H0`/;20080bl_;00L0];Bd0;Vi^@3<c<`0^[Zj0<k>cP2o_kl0_Kfm0080fMWI00L0`<30
0;fm_@2TY:@0/K6a0;Ng]`30`<00[Jf]0080a<C400L0`<300;fm_@35aLD0j^[Z0=?Cd`39bLT0`/;2
0080`<3000L0alO70;Ng]`2m_Kd0a/K60;bl_02i^KT0`l?30080alO700L0bLW90;jn_P2g]kL0aLG5
0;:b/P37alL0_kno0080c/k>0P34a<@00`2i^KT0`<300?ooo`0S0?ooo`P0ec?o00@0IZ?o0=Lco`3G
<ol0IZ?o1`3G<ol00`1VXol0ec?o0=Lco`0A0=Lco`80VOo20`3G<ol00`1VXol0ec?o0=Lco`0:0=Lc
o`80IZ?o1@3G<ol02@1VXol0mOo<0?Goc03eol`0IZ?o0=Lco`1VXol0ec?o06JSo`020=Lco`80IZ?o
0`3G<ol306JSo`<0ec?o00<0IZ?o0=Lco`3G<ol04@3G<ol206JSo`80ec?o00<0IZ?o0=Lco`3G<ol0
0`3G<ol00`3o0000ec?o0=Lco`0@0=Lco`0306JSo`3G<ol0ec?o00H0ec?o9`3oool002D0oooo00<0
_[jn0<O7a`2f][H00`2c/k<01P2k^k/0^KVi0<71`@30`<00bLW90<;2`P80b<S800D0a/K60<O7a`2h
^;P0^KVi0<71`@020<?3``<0]KFe00H0^k^k0=WIf@37alL0^;Rh0<_;b`2g]kL20;Vi^@80`<3000D0
^KVi0;Zj^P37alL0`<300=KFeP020<C4a00709^KV`2b/[80bl_;0<K6aP39bLT0b/[:0<C4a0020<g=
c@070;Vi^@2n_[h0Rh^;0?[jnP2n_[h0b/[:0<;2`P020;Fe]@070<?3``36a/H0`/;20;Jf]P2b/[80
C4a<0:j^[P020;6a/@070>;RhP37alL0`/;20<;2`P37alL0`/;20<O7a`020<;2`P050:^[Z`2][Jd0
/k>c0;no_`2e]KD00P30`<020<;2`P070<C4a032`/80^KVi0;fm_@2f][H0a<C40<c<c0020;Bd]007
0;^k^`35aLD0a<C40<C4a031`L40aLG50<71`@020=GEe@070=OGe`37alL0`L710;no_`2l_;`0a/K6
0<;2`P020<S8b0070;jn_P2g]kL0`<300<W9b@2l_;`0a/K60<[:bP020<K6aP070<71`@35aLD0`l?3
0;^k^`30`<00^KVi0<_;b`020<W9b@070<S8b02o_kl0`l?30<G5a@37alL0_Kfm0<71`@020<30`004
0>[ZjP34a<@0hN7Q0<O7ab@0oooo:@3G<ol206JSo`T0ec?o00<0IZ?o0?l0003G<ol0203G<ol00`1V
Xol0mOo<06JSo`0206JSo`T0ec?o0P1VXolm0=Lco`040?l0003G<ol0ec?o0=LcobL0oooo000U0?oo
o`030<k>cP2m_Kd0]kNg0080`<3000L0`L710;Rh^039bLT0_Kfm0;Ng]`30`<00^KVi0080`<3000@0
a<C40;jn_P37alL0a<C40P2j^[X02P33`l<0_Kfm0;fm_@33`l<0`<300;^k^`2o_kl0alO70<?3``2h
^;P20<K6aP070;bl_02m_Kd0b<S80;Jf]P2o_kl0aLG50=KFeP020<71`@070<[:bP2_[jl0Y:BT0<W9
b@38b<P0_;bl0<;2`P020<K6aP060;fm_@30`<00bLW90;Bd]02m_Kd0_kno1@2k^k/01@2m_Kd0]KFe
0:FUY@2l_;`0YjNW0080]kNg00L0QHF50;Ng]`37alL0_;bl0<o?c`2][Jd0][Jf0080`<3000L0/K6a
0<30`02YZJT0^KVi0;no_`2i^KT0`/;20080a/K600<0`l?30<_;b`2o_kl00P2a/K402`33`l<0b/[:
0;bl_02l_;`0/;2`0:FUY@3?cll0`/;20<[:bP36a/H0_Kfm0080^[Zj00L0^;Rh0::RXP2k^k/0_kno
0<;2`P2g]kL0a/K60080bl_;00L0`l?30<C4a033`l<0b/[:0;^k^`3<c<`0_[jn0080b/[:00L0`<30
0<C4a03=cLd0`/;20<O7a`31`L40_kno0080alO70P3<c<`01@37alL0_kno0;Ng]`34a<@0]KFe0080
_[jn00@0_kno0<K6aP2i^KT0]KFe903ooolZ0=Lco`80IZ?o4`3G<ol00`1VXol0ec?o06JSo`020=Lc
o`0306JSo`3G<ol0ec?o0080ec?o00L0IZ?o0=Lco`3G<ol0ec?o06JSo`3G<ol0IZ?o00T0ec?o0P1V
Xol40=Lco`80IZ?o203G<ol00`1VXol0ec?o0=Lco`0T0=LcobL0oooo000U0?ooo`030;Zj^P2n_[h0
[Jf]0080Y:BT00L0^KVi0;Rh^031`L40_Kfm0:VYZ@2^[Zh0Zj^[0080`<3000L0][Jf0<;2`P30`<00
_;bl0;no_`35aLD0alO70080`<3000H0`/;20<W9b@2n_[h0a<C408:2PP2h^;P30<K6aP070<C4a030
`<00^k^k0;Jf]P3;bl/0^[Zj0;Rh^0020;Bd]0070<_;b`34a<@0`<3009ZJVP38b<P0cLg=0<O7a`02
0<W9b@040<?3``2i^KT0/k>c0;^k^`80`<3000X0]kNg0=3@d03@d=00`<300<;2`P2k^k/0^KVi0;:b
/P3Rh^80e]KF0P3QhN401`36a/H0];Bd0;Fe]@32`/80VYZJ0:NWY`2d];@00P37alL01`2m_Kd0a<C4
0<30`02][Jd0`<300<K6aP3Fe]H00P3;bl/01`2m_Kd0bLW90;^k^`2m_Kd0`<300<W9b@2k^k/00P34
a<@01`2YZJT0`/;20<K6aP2l_;`0b<S80<[:bP2e]KD00P2c/k<20;Vi^@050:BTY036a/H0c/k>0<k>
cP36a/H00P38b<P01`2_[jl0^k^k0<K6aP3:b/X0_Kfm0<[:bP31`L400P33`l<01`3=cLd0a/K60<o?
c`34a<@0`/;20=?Cd`3=cLd00P38b<P01`3@d=00e]KF0=OGe`37alL0_;bl0;Ng]`2PX:000P36a/H0
102i^KT0a/K60;Vi^@38b<PT0?ooo`80ec?o0`1VXol40=Lco`<0IZ?o3`3G<ol00`1VXol0ec?o0=Lc
o`0>0=Lco`0306JSo`3G<ol0ec?o0100ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol206JSo`H0ec?o00<0
IZ?o0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`080=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0
IZ?o0=Lco`3G<ol05@3G<ol00`1VXol0ec?o0=Lco`040=LcobL0oooo000U0?ooo`030;Ng]`2h^;P0
QHF50080^;Rh00L0b<S80<30`02m_Kd0[:b/0;Fe]@31`L40_kno0080]kNg00L0^k^k0<?3``2f][H0
b<S80<K6aP2l_;`0`l?30080bLW900L0_kno0;bl_037alL0a<C40;no_`2h^;P0a<C40080_;bl00@0
_[jn0;no_`32`/80^[Zj0`32`/820<k>cP070<O7a`2k^k/0a<C40<S8b02i^KT0d=3@0<W9b@020=3@
d0070<O7a`2b/[80clo?0<K6aP39bLT0dM7A0<g=c@020<[:bP070<S8b02e]KD0[jn_0;fm_@3?cll0
_[jn0<K6aP020;Fe]@070;Jf]P2m_Kd0]kNg0;>c/`2e]KD0ZJVY0=3@d0020<g=c@070<_;b`2f][H0
a<C40<g=c@30`<00f=SH0;fm_@020<S8b0070;^k^`2l_;`0_[jn0:JVYP36a/H0c<c<0;Ng]`020;Jf
]P070;2`/030`<00^;Rh0;jn_P32`/80c/k>0;^k^`020;Vi^@070;fm_@2e]KD0_kno0<K6aP32`/80
_kno0<;2`P020<K6aP040;Vi^@3:b/X0]KFe0=7Ad@<0b<S80P2k^k/01`2o_kl0b<S80<K6aP32`/80
]kNg0;fm_@2n_[h00P2a/K401`2YZJT0][Jf0;Bd]034a<@0gMgM0<C4a03Cdm<00P2n_[h01038b<P0
b/[:0=3@d02k^k/T0?ooo`80ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`0X0=Lc
o`0306JSo`3G<ol0ec?o00L0ec?o00<0IZ?o0=Lco`3G<ol02@3G<ol00`1VXol0ec?o0=Lco`0=0=Lc
o`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol07`3G<ol306JSo``0ec?o9`3oool002D0
oooo00<0`<300;Ng]`2ZZZX00P2o_kl01`2l_;`0/K6a0<30`030`<00c<c<0<;2`P30`<000P38b<P2
0<30`0050<;2`P3Bd]80c/k>0<K6aP37alL00P39bLT01`2m_Kd0`/;20;bl_03=cLd0a/K60;jn_P2b
/[800P2k^k/01`2o_kl0`l?30<O7a`2l_;`0a<C40;jn_P36a/H00P2g]kL01`39bLT0_[jn0<o?c`2h
^;P0^[Zj0<k>cP3AdM400P2h^;P01`3=cLd0a/K60=3@d03IfMT0clo?0;Zj^P30`<000P2e]KD01@39
bLT0`<300<?3``3Hf=P0dM7A0080b<S80P2][Jd01P2l_;`0a<C40:f][@36a/H0W9bL09RHV0<0_kno
00L0b<S80<;2`P2PX:00bLW90;>c/`3<c<`0a<C40080YJFU00L0`l?30<71`@2k^k/0[Jf]0<k>cP2e
]KD0a<C40080_kno00L0WYjN0;^k^`32`/80_;bl0<30`034a<@0]KFe0080]kNg00L0[jn_0;Fe]@2o
_kl0^k^k0<G5a@38b<P0i>CT0080d];B00L0e=CD0<S8b02o_kl0][Jf0<30`02WYjL0a<C40080a/K6
00L0d=3@0<_;b`3]kNd0[jn_0<;2`P2NWYh0aLG50080^k^k00@0a/K60;Vi^@2o_kl0b/[:0P2o_kl0
1`3>c/h0dm?C0=?Cd`3;bl/0bLW90<S8b03?cll0903oool20=Lco`0506JSo`3G<ol0ec?o0=Lco`1V
Xol05P3G<ol00`1VXol0ec?o0=Lco`0R0=Lco`80IZ?o0P3G<ol0101VXol0ec?o06JSo`1VXol50=Lc
o`0306JSo`3G<ol0ec?o0080ec?o0P1VXol30=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lc
o`3G<ol01P3G<ol00`1VXol0ec?o0=Lco`0;0=Lco`0306JSo`3G<ol0ec?o00<0ec?o00@0o`0006JS
o`3G<ol0IZ?o403G<olW0?ooo`009@3oool00`2i^KT0/[:b0;Vi^@020;Ng]`050;bl_02h^;P0`<30
0;Jf]P39bLT00P36a/H20<W9b@030;Zj^P2n_[h0a<C40080^[Zj00D0_[jn0;Zj^P32`/80`/;20<71
`@020;fm_@040<o?c`34a<@0^[Zj0:f][@80_Kfm00L0^;Rh0<30`034a<@0`<300<C4a02][Jd0a/K6
0080^KVi00L0_[jn0<30`02^[Zh0bl_;0;Bd]02TY:@0[Zj^0080][Jf00L0VIVI0;Zj^P2o_kl0ZZZZ
0<k>cP3IfMT0c/k>0080`/;200<0a/K60=3@d03Bd]800P2YZJT01`32`/80a/K60;Bd]02d];@0aLG5
0::RXP2g]kL00P2m_Kd02`2e]KD0_Kfm0;fm_@2m_Kd0^KVi0;^k^`2c/k<0_Kfm0<30`032`/80^k^k
0080]kNg00D0bl_;0;Zj^P3?cll0b<S80;jn_P020<;2`P80/[:b00L0[Jf]0;^k^`31`L40^;Rh0<?3
``2j^[X0_;bl0080]KFe00L0a<C40;fm_@32`/80`<300;Rh^038b<P0_kno0080a<C400L0^k^k0;no
_`2k^k/0bLW90<_;b`3?cll0`/;20080clo?00H0c<c<0;jn_P2m_Kd0^KVi0;no_`2`/;030<o?c`07
0<C4a032`/80`<300<K6aP2n_[h0a/K60<S8b0020<;2`P040<_;b`39bLT0_;bl0<S8b2@0oooo00<0
ec?o06JSo`3G<ol06P3G<ol00`1VXol0ec?o0=Lco`050=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0
IZ?o0=Lco`3G<ol00P1VXol20=Lco`0406JSo`3G<ol0ec?o06JSo`P0ec?o0P1VXol50=Lco`0306JS
o`3G<ol0ec?o01D0ec?o0`1VXolO0=Lco`0306JSo`3G<ol0ec?o00h0ec?o9`3oool002D0oooo00<0
_Kfm0<G5a@2NWYh00P2m_Kd01`2JVYX0alO70;no_`2[Zj/0_Kfm0<G5a@39bLT00P32`/801`34a<@0
];Bd0;Ng]`2l_;`0^KVi0<O7a`2BTY800P36a/H01`34a<@0_kno0<30`035aLD0bl_;0:n_[`2f][H0
0P32`/801`2e]KD0^k^k0;no_`38b<P0^[Zj0;Vi^@2l_;`00P2_[jl01`30`<00a/K60=WIf@36a/H0
`L710>7Qh@3Fe]H00P2TY:@01`2m_Kd0`/;20:f][@2n_[h0a/K60;>c/`2b/[800P34a<@01`3:b/X0
_kno0;Rh^03:b/X0_kno0;^k^`2l_;`00P32`/801`39bLT0]kNg0;Ng]`2`/;00Zj^[0;Ng]`2b/[80
0P30`<001`2a/K40[Jf]0;no_`2>SXh0^KVi0<[:bP2e]KD00P32`/820<K6aP050<;2`P2a/K40a<C4
0<C4a03;bl/00P2g]kL01`2@T900`/;20<O7a`2m_Kd0`<300<K6aP2WYjL00`2i^KT01@34a<@0`<30
0<C4a03:b/X0clo?00<0d];B00L0_kno0<S8b02g]kL0dM7A0;bl_02b/[80_Kfm0080^[Zj00L0bLW9
0<O7a`2g]kL0`/;20;Fe]@39bLT0clo?0080[Zj^00L0clo?0;Bd]034a<@0`/;20;no_`32`/80_Kfm
0080c<c<00@0^k^k0<S8b032`/80_Kfm903oool20=Lco`0406JSo`3G<ol0ec?o06JSo`80ec?o00<0
IZ?o0=Lco`3G<ol02@3G<ol00`1VXol0ec?o0=Lco`050=Lco`0306JSo`3G<ol0ec?o00P0ec?o0P1V
Xol70=Lco`80IZ?o0P3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o00h0ec?o0P1VXol0103G<ol0IZ?o
0=Lco`3G<ol206JSo`030=Lco`1VXol0ec?o00L0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0
ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o00h0ec?o00<0IZ?o0=Lco`3G<ol0203G<ol206JSo`d0
ec?o9`3oool002D0oooo0P2i^KT02P31`L40]KFe0;Fe]@2g]kL0/[:b0;Bd]02n_[h0a/K60<C4a030
`<020<;2`P070<G5a@36a/H0`/;20;Rh^02k^k/0bLW90<k>cP020<c<c0070;jn_P31`L40];Bd0<C4
a033`l<0Zj^[0:j^[P020<O7a`070;no_`39bLT0gMgM0:JVYP2m_Kd0a/K60;Bd]0020;^k^`0709JF
UP34a<@0];Bd0;Zj^P3Ng]h0UIFE0?3`l0020;Rh^0050;Ng]`2m_Kd0W9bL0:^[Z`2YZJT00P2a/K42
0<30`0070<K6aP3>c/h0c/k>0:^[Z`35aLD0^k^k0;Fe]@020;^k^`070:n_[`3=cLd0]kNg0;^k^`31
`L40]KFe0;jn_P030<30`0060<[:bP2g]kL0a<C40<K6aP2f][H0]KFe0P3<c<`01`2o_kl0[Zj^0:j^
[P31`L40_Kfm0<O7a`3@d=000P30`<001`2LW9`0^KVi0;jn_P2n_[h0][Jf0;Vi^@2`/;000P2e]KD0
1`2o_kl0[Jf]0;Ng]`2k^k/0]KFe0;>c/`2n_[h00`3@d=020<k>cP040:VYZ@2j^[X0alO70<30`080
cLg=00L0^[Zj0;Bd]02h^;P0cLg=0;no_`3De=@0c<c<0080^KVi00L0b<S80;^k^`3>c/h0fMWI0;fm
_@36a/H0d];B0080/;2`00@0];Bd0<G5a@2o_kl0c<c<903oool60=Lco`0306JSo`3G<ol0ec?o01<0
ec?o0P1VXol50=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol00`1VXol0
o`000=Lco`030=Lco`D0IZ?o1@3G<ol00`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o0100
ec?o0P1VXol60=Lco`0306JSo`3G<ol0ec?o00<0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`0:0=Lc
o`0306JSo`3G<ol0ec?o01<0ec?o0P1VXol40=LcobL0oooo000U0?ooo`80^KVi00X0`L710;Fe]@2e
]KD0]kNg0;:b/P2d];@0_[jn0<K6aP34a<@0`<300P32`/801`35aLD0a/K60<;2`P2h^;P0^k^k0<W9
b@3>c/h00P3<c<`01`2n_[h0`L710;Bd]034a<@0`l?30:^[Z`2^[Zh00P37alL01`2o_kl0bLW90=gM
g@2VYZH0_Kfm0<K6aP2d];@00P2k^k/01`2FUYH0a<C40;Bd]02j^[X0g]kN09FEU@3`l?000P2h^;P0
1@2g]kL0_Kfm09bLW02[Zj/0ZJVY0080/K6a0P30`<001`36a/H0c/k>0<k>cP2[Zj/0aLG50;^k^`2e
]KD00P2k^k/01`2_[jl0cLg=0;Ng]`2k^k/0`L710;Fe]@2n_[h00`30`<001P3:b/X0]kNg0<C4a036
a/H0][Jf0;Fe]@80c<c<00L0_kno0:j^[P2^[Zh0`L710;fm_@37alL0d=3@0080`<3000L0W9bL0;Vi
^@2n_[h0_[jn0;Jf]P2i^KT0/;2`0080]KFe00L0_kno0:f][@2g]kL0^k^k0;Fe]@2c/k<0_[jn00<0
d=3@0P3>c/h0102YZJT0^[Zj0<O7a`30`<020<g=c@070;Zj^P2d];@0^;Rh0<g=c@2o_kl0e=CD0<c<
c0020;Vi^@070<S8b02k^k/0c/k>0=WIf@2m_Kd0a/K60=;BdP020;2`/0040;Bd]035aLD0_kno0<c<
c2@0oooo1P3G<ol00`1VXol0ec?o0=Lco`0C0=Lco`80IZ?o1@3G<ol00`1VXol0ec?o0=Lco`030=Lc
o`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0?l0003G<ol00`3G<ol506JSo`D0ec?o00<0IZ?o0=Lc
o`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`0@0=Lco`80IZ?o1P3G<ol00`1VXol0ec?o0=Lco`030=Lc
o`0506JSo`3G<ol0ec?o0=Lco`1VXol02P3G<ol00`1VXol0ec?o0=Lco`0C0=Lco`80IZ?o103G<olW
0?ooo`009@3oool00`38b<P0^KVi0;:b/P020;2`/0070;no_`32`/80fMWI0=gMg@36a/H0][Jf0;Bd
]0020<;2`P070;bl_036a/H0`L710<C4a02h^;P0`/;20<G5a@020<?3``070;no_`38b<P0`/;20;fm
_@3>c/h0clo?0<S8b0020;jn_P030<71`@32`/80_;bl0080];Bd00/0bLW90<g=c@2m_Kd0_Kfm0;^k
^`2f][H0WIfM0:f][@2l_;`0[:b/0;Bd]00209^KV`0508Z:RP2NWYh0XZ:R0861P@2FUYH00P30`<02
0<k>cP070<S8b03Bd]80`/;20<30`02k^k/0][Jf0:NWY`020:>SX`070;^k^`32`/80][Jf0<C4a03<
c<`0Zj^[0:n_[`020<;2`P050<_;b`2g]kL0a/K60<O7a`2b/[800P2i^KT20<71`@070<[:bP3<c<`0
bLW90<S8b02TY:@0/[:b0<C4a0020;Vi^@070:f][@32`/80_kno0;Vi^@35aLD0^KVi0;:b/P020:j^
[P050:VYZ@2][Jd0/K6a0;Vi^@2VYZH00P30`<020;Fe]@80_kno00D0_Kfm0<W9b@38b<P0YjNW0<O7
a`020<o?c`070=7Ad@35aLD0a<C403Ph>02d];@0clo?0;jn_P020<G5a@070:n_[`3>c/h0`/;20:VY
Z@3=cLd0`<300=3@d0020<c<c0040<G5a@3=cLd0clo?0<30`2@0oooo0P3G<ol306JSobH0ec?o0P1V
Xol00`3G<ol0IZ?o0=Lco`0706JSo`X0ec?o0`1VXol50=Lco`80IZ?o1P3G<ol00`1VXol0ec?o0=Lc
o`060=Lco`80IZ?o0`3G<ol00`1VXol0ec?o0=Lco`030=Lco`H0IZ?o00<0ec?o06JSo`3G<ol0203G
<ol00`1VXol0ec?o0=Lco`040=Lco`030?Goc03G<ol0ec?o00<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o
2@3G<olW0?ooo`009@3oool00`2e]KD0`/;20;>c/`020<71`@070;Jf]P2d];@0YJFU08F5Q@3;bl/0
a<C40:NWY`020:VYZ@070;fm_@2QXJ40f=SH0;Rh^031`L40_kno0>c/k0020<o?c`070<O7a`2o_kl0
`<300;no_`2k^k/0_[jn0;Fe]@020;^k^`070;Zj^P2o_kl0clo?0<71`@2NWYh0a<C40<30`0020<K6
aP070<O7a`3<c<`0`/;20;Zj^P30`<00Zj^[0;2`/0020<K6aP070>7Qh@32`/80/K6a0<C4a02a/K40
`/;20:BTY00209FEU@0709VIV@2FUYH0/K6a0<S8b036a/H0]kNg0;Rh^0020<;2`P070;:b/P34a<@0
_[jn0;Bd]03=cLd0[Jf]0<30`0020;2`/0060;6a/@2i^KT0`<300;Fe]@38b<P0];Bd0`2o_kl01`3E
eMD0a<C40;Bd]02SXj<0`<300;Vi^@2m_Kd00P2j^[X01`2][Jd0^[Zj0;Vi^@2b/[80a<C40=3@d034
a<@00P2a/K401`38b<P0`/;20<K6aP2b/[80alO70<W9b@36a/H00P3Fe]H01`32`/80b<S80;^k^`2o
_kl0c<c<0<S8b03Bd]800P38b<P01`3:b/X0b<S80<;2`P2i^KT0]kNg0;fm_@2c/k<00P2m_Kd01`2g
]kL0_;bl0<k>cP3QhN40d=3@0;Zj^P36a/H00P2@T900102][Jd0bl_;0;:b/P36a/HT0?ooo`L0ec?o
0P1VXol20=Lco`<0IZ?o00<0ec?o06JSo`3G<ol00`3G<ol00`3o0000ec?o0=Lco`0=0=Lco`0306JS
o`3G<ol0ec?o00L0ec?o0P1VXol40=Lco`0406JSo`3G<ol0IZ?o0=Lco`H0IZ?o1P3G<ol00`1VXol0
ec?o0=Lco`020=Lco`0306JSo`3G<ol0IZ?o0080IZ?o2`3G<ol00`1VXol0ec?o0=Lco`030=Lco`04
06JSo`3G<ol0ec?o06JSo`<0ec?o0P1VXol30=Lco`0306JSo`3G<ol0ec?o01`0ec?o0`1VXol00`3G
<ol0IZ?o0=Lco`0W0?ooo`009@3oool00`2m_Kd0_[jn0;Rh^0020;Vi^@070;Rh^02i^KT0_;bl0<C4
a03Hf=P0_Kfm0<k>cP020;bl_0070;Ng]`35aLD0oooo0;Ng]`2k^k/0cLg=0:RXZ0020<C4a0060;fm
_@2n_[h0^[Zj0:f][@30`<00a<C40`2m_Kd01`37alL0d=3@0;Vi^@2VYZH0Zj^[0;Ng]`36a/H00P3<
c<`01`39bLT0`/;20<?3``32`/80]KFe0<;2`P2b/[800P2/[:`01031`L40^KVi0<g=c@2h^;P20<71
`@0:0:RXZ02i^KT0^KVi0<[:bP3?cll0dM7A0;Jf]P2`/;00QhN70<;2`P80a<C400L0J6QX0:n_[`2i
^KT0][Jf0::RXP2^[Zh0e]KF0080`/;200L0_Kfm0;Ng]`2g]kL0_kno0<?3``2l_;`0h^;R00<0`/;2
00H0b<S80;Bd]03AdM40fMWI0;^k^`38b<P20<K6aP070:2PX02m_Kd0`<300;^k^`31`L40^;Rh0:ZZ
ZP020<C4a0<0`/;200@0_;bl0<G5a@33`l<0^;Rh0P30`<001`3Cdm<0cLg=0<;2`P2i^KT0b/[:0<S8
b03AdM400P3=cLd01`30`<00b<S80<30`03;bl/0clo?0;no_`2m_Kd00P34a<@01`2o_kl0]kNg0:^[
Z`3:b/X0_kno0;Zj^P2i^KT00P2e]KD0102m_Kd0b<S80<W9b@2g]kLT0?oooa00ec?o00D0o`000=Lc
o`3G<ol0ec?o06JSo`050=Lco`0306JSo`3G<ol0ec?o00H0ec?o0P1VXol:0=Lco`<0IZ?o1P3G<ol0
0`1VXol0ec?o0=Lco`040=Lco`80IZ?o0`3G<ol0102Iol80IZ?o0=Lco`3G<ol206JSoaD0ec?o00<0
IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`0M0=Lco`0306JSo`3G<ol0ec?o00P0ec?o9`3o
ool002D0oooo00<0bl_;0<O7a`33`l<00P2`/;001`34a<@0bl_;0;fm_@2a/K40][Jf0<g=c@34a<@0
0P39bLT01`31`L40cLg=0<?3``2o_kl0_[jn0<C4a030`<000P2k^k/01`2m_Kd0WYjN0:ZZZP32`/80
bl_;0;fm_@2_[jl00P36a/H01`34a<@0`l?30;Ng]`2IVIT0hN7Q0<C4a033`l<00P2o_kl01`37alL0
bl_;0<C4a02k^k/0`/;20<71`@2o_kl00P2i^KT01`2TY:@0cLg=0;Ng]`36a/H0a<C40<K6aP2g]kL0
0P2h^;P01`3;bl/0]KFe0=CDe039bLT0Ng]k0<30`02][Jd00P2_[jl01`36a/H0`<300;fm_@2a/K40
]kNg0:FUY@3Bd]800P32`/801`2YZJT0`/;20=3@d02UYJD0/k>c0=[JfP2h^;P00P30`<001`33`l<0
/;2`0<;2`P32`/80ZJVY0;Vi^@36a/H00P2k^k/01`2UYJD0^k^k0<K6aP2i^KT0c<c<0<S8b034a<@0
0P30`<001`35aLD0e=CD0<;2`P2m_Kd0a<C40<O7a`36a/H00P32`/801`3AdM40_kno0:JVYP2YZJT0
`/;20<c<c032`/800P3?cll01`37alL0clo?0=;BdP32`/80c<c<0<W9b@34a<@00P2n_[h00`38b<P0
]KFe0<K6aP020<k>cP080<C4a029RHT0_Kfm0;fm_@2o_kl0a<C40<S8b034a<@T0?ooo`<0ec?o0P1V
Xol30=Lco`0306JSo`3G<ol0ec?o00d0ec?o0P1VXol30=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0
IZ?o0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`0:0=Lco`0309Wo`P3G<ol0IZ?o0080IZ?o0`3G
<ol00`1VXol0ec?o06JSo`030=Lco`0406JSo`3G<ol0ec?o06JSo`H0ec?o00@0IZ?o0=Lco`3G<ol0
IZ?o103G<ol00`1VXol0ec?o0=Lco`0A0=Lco`80IZ?o503G<ol00`1VXol0ec?o0=Lco`040=LcobL0
oooo000U0?ooo`030;Ng]`2][Jd0^KVi0080/;2`00L0_kno0;^k^`2h^;P0`<300<O7a`35aLD0_Kfm
0080UIFE00L0bLW90;Vi^@36a/H0^k^k0<G5a@2ZZZX0_kno0080a/K600L0_[jn0<_;b`2m_Kd0/[:b
0<;2`P2g]kL0a/K60080bl_;00L0fm_K0;^k^`2][Jd0[jn_0;:b/P33`l<0`/;20080^;Rh00L0_Kfm
09^KV`2b/[80b<S80;bl_02j^[X0cLg=0080e=CD00L0WinO0;Jf]P34a<@0_;bl0;^k^`38b<P0c/k>
0080^;Rh00L0^KVi0<W9b@30`<00]KFe08>3P`2j^[X0_kno0080a/K600L0/k>c0;Vi^@2o_kl0`<30
0;Vi^@2h^;P0a/K60080a<C400L0d=3@0;fm_@30`<00/;2`0=SHf02h^;P0bLW90080hN7Q00L0d=3@
0<[:bP3>c/h0d=3@0;no_`3:b/X0c/k>0080^;Rh00L0[jn_0:BTY032`/80_kno0=CDe02k^k/0^KVi
0080a/K600L0];Bd0;Fe]@2g]kL0_Kfm0:n_[`36a/H0_Kfm0080`/;200L0c<c<0<;2`P3>c/h0c/k>
0:f][@3=cLd0b/[:0080c/k>00L0_kno0<?3``2o_kl0][Jf09ZJVP39bLT0/k>c0080_;bl00L0a<C4
0<k>cP2f][H0`<3009VIV@2VYZH0a/K60080b/[:00@0/K6a0:j^[P2l_;`0^;Rh903oool00`3G<ol0
IZ?o0=Lco`0206JSo`L0ec?o0P1VXol50=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lco`3G
<ol01@3G<ol306JSo`D0ec?o0P1VXol60=Lco`0306JSo`3G<ol0ec?o00X0ec?o00<0IZ?o0=Lco`3G
<ol03P3G<ol00`1VXol0ec?o0=Lco`0<0=Lco`80IZ?o2`3G<ol00`1VXol0ec?o0=Lco`060=Lco`03
06JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol206JSo`<0ec?o0P1VXol20=LcobL0
oooo000U0?ooo`80a<C400X0YJFU0:n_[`2_[jl0/k>c0:FUY@2f][H0bLW90;bl_032`/80_;bl0P2k
^k/01`37alL0bl_;0<;2`P31`L40^k^k0;fm_@39bLT00P30`<001`37alL0^KVi0;fm_@2j^[X0_[jn
0<30`02o_kl00P31`L400`2[Zj/0d=3@0;Ng]`030;bl_00:0<W9b@2n_[h0_[jn0<71`@2[Zj/0];Bd
0<W9b@3@d=00alO70;^k^`80fm_K00L0^;Rh0;no_`2e]KD0][Jf0;fm_@36a/H0`/;20080/[:b00L0
[Zj^0;Vi^@2@T900]KFe04Y:BP32`/80b/[:0080fMWI00L0_kno0;fm_@2c/k<0YjNW0<S8b02f][H0
cLg=0080[Zj^00L0/;2`0;jn_P2i^KT0fMWI0<C4a02f][H0`/;20080YJFU00L0_Kfm0<[:bP3Bd]80
d=3@0<;2`P36a/H0`<300080bLW900D0][Jf0<?3``37alL0`<300=WIf@020<;2`P80bl_;00L0YJFU
0<K6aP33`l<0^k^k0;no_`2j^[X0]kNg0080bl_;00L0cLg=0;>c/`32`/80gMgM0=WIf@2/[:`0a/K6
0080_kno00<0clo?0<S8b03:b/X00P3@d=002`2f][H0a<C40;Zj^P2j^[X0Zj^[0;Fe]@2g]kL0_[jn
0<;2`P2h^;P0_[jn0080`<3000@0a/K60;no_`3;bl/0a<C4903oool20=Lco`<0IZ?o00<0ec?o06JS
o`3G<ol0603G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JSo`3G<ol0ec?o00`0ec?o0`1VXol0103G
<ol0IZ?o0=Lco`3eol`70=Lco`0406JSo`3G<ol0ec?o0=Lco`<0IZ?o1P3G<ol206JSoa80ec?o00<0
IZ?o0=Lco`3G<ol02`3G<ol00`1VXol0ec?o0=Lco`0:0=Lco`0306JSo`3G<ol0ec?o00X0ec?o9`3o
ool002D0oooo00<0e]KF0;fm_@38b<P00P32`/801`2i^KT0];Bd0;no_`3?cll0b<S80=7Ad@31`L40
0P35aLD01`37alL0^[Zj0<_;b`2n_[h0^k^k0<W9b@30`<000P2l_;`01`36a/H0^[Zj0;Vi^@2f][H0
^[Zj0<S8b033`l<00P30`<001`2i^KT0a/K60:^[Z`2o_kl0[jn_0;jn_P38b<P00P2e]KD01`36a/H0
][Jf0<o?c`30`<00_kno0;jn_P3AdM400P3Ng]h01`3:b/X0`<300<k>cP2NWYh0[jn_0;:b/P2j^[X0
0P2RXZ801`2][Jd0]KFe0;6a/@3@d=00clo?0<S8b02UYJD00P3>c/h01`2k^k/0[:b/0;fm_@2b/[80
[:b/08F5Q@2?Shl00P2^[Zh01P3>c/h0]KFe0;6a/@2][Jd0a/K60<o?c`<0a/K600L0b/[:0;Vi^@32
`/80d=3@0<S8b02j^[X0a/K60080`<3000L0]KFe0<K6aP3<c<`0a<C40;fm_@2[Zj/0_kno0080`/;2
00L0_Kfm0;Rh^02g]kL0[Zj^0;^k^`2m_Kd0alO70080^[Zj00L0`/;20<K6aP3Kfm/0dM7A0;:b/P2`
/;00_Kfm0080b<S800L0c/k>0<S8b03De=@0`<300=;BdP34a<@0b/[:0080[Jf]00L0bl_;0=?Cd`2k
^k/0cLg=0;:b/P2[Zj/0_Kfm0080^KVi00@0a<C40;^k^`36a/H0^[Zj903ooolR0=Lco`0306JSo`3G
<ol0IZ?o0100ec?o0`1VXol01P3G<ol0IZ?o06JSo`1VXol0ec?o06JSo`<0ec?o00H0IZ?o0=Lco`3G
<ol0ec?o06JSo`3G<ol606JSo`80ec?o0P1VXolC0=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o
0=Lco`3G<ol01`3G<ol206JSo`X0ec?o0P1VXol40=Lco`80IZ?o1`3G<olW0?ooo`009@3oool00`39
bLT0`l?30;jn_P020<30`0070;:b/P2^[Zh0d];B0;bl_038b<P0alO70<30`0020;^k^`070<o?c`2a
/K40^k^k0;>c/`2n_[h0_Kfm0<;2`P020<30`0070<k>cP2h^;P0bLW90=;BdP37alL0bl_;0<;2`P02
0<W9b@070<30`02n_[h0^;Rh0;^k^`3:b/X0_[jn0=7Ad@020<C4a0060<K6aP2l_;`0bLW90=GEe@3B
d]80bLW90`3Hf=P01`35aLD0^;Rh0;jn_P2a/K40/;2`0=3@d02UYJD00P2a/K401P3Cdm<0UYJF0;no
_`2b/[80^;Rh0<;2`P<0_[jn00L0^k^k09:BTP2h^;P0bLW90;Zj^P2/[:`0^;Rh0080_[jn00L0b<S8
0<C4a02i^KT0inOW0<C4a02m_Kd0aLG50080`/;200<0a<C40<K6aP38b<P00P36a/H02`2d];@0b<S8
0;Ng]`2g]kL0/k>c0<;2`P38b<P0^KVi0;fm_@2i^KT0YZJV0080a<C400L0a/K60<_;b`36a/H0/k>c
0<K6aP3?cll0`<3000<0a<C400H0[jn_0<30`03;bl/0aLG50<g=c@39bLT20=WIf@070;bl_036a/H0
cLg=0;^k^`3:b/X0b<S80<O7a`020:^[Z`070;Vi^@33`l<0a<C40=CDe02k^k/0ZJVY0<W9b@020<C4
a0040;Fe]@2o_kl0bLW90<G5aB@0oooo1@3G<ol206JSo`P0ec?o00<0IZ?o0=Lco`3G<ol08`3G<ol2
06JSo`080=Lco`1VXol0IZ?o06JSo`3G<ol0IZ?o0=Lco`1VXol60=Lco`0506JSo`3G<ol0ec?o0=Lc
o`1VXol01P3G<ol00`3o0000ec?o0=Lco`0B0=Lco`0306JSo`3G<ol0ec?o00X0ec?o00<0IZ?o0=Lc
o`3G<ol0303G<ol206JSo`D0ec?o00<0IZ?o0=Lco`3G<ol01@3G<olW0?ooo`009@3oool00`39bLT0
`l?30;jn_P020<30`0070;:b/P2^[Zh0d];B0;bl_038b<P0alO70<30`0020;^k^`070<o?c`2a/K40
^k^k0;>c/`2n_[h0_Kfm0<;2`P020<30`0070<k>cP2h^;P0bLW90=;BdP37alL0bl_;0<;2`P020<W9
b@070<30`02n_[h0^;Rh0;^k^`3:b/X0_[jn0=7Ad@020<C4a0060<K6aP2l_;`0bLW90=GEe@3Bd]80
bLW90`3Hf=P01`35aLD0^;Rh0;jn_P2a/K40/;2`0=3@d02UYJD00P2a/K401P3Cdm<0UYJF0;no_`2b
/[80^;Rh0<;2`P<0_[jn00L0^k^k09:BTP2h^;P0bLW90;Zj^P2/[:`0^;Rh0080_[jn00L0b<S80<C4
a02i^KT0inOW0<C4a02m_Kd0aLG50080`/;200<0a<C40<K6aP38b<P00P36a/H02`2d];@0b<S80;Ng
]`2g]kL0/k>c0<;2`P38b<P0^KVi0;fm_@2i^KT0YZJV0080a<C400L0a/K60<_;b`36a/H0/k>c0<K6
aP3?cll0`<3000<0a<C400H0[jn_0<30`03;bl/0aLG50<g=c@39bLT20=WIf@070;bl_036a/H0cLg=
0;^k^`3:b/X0b<S80<O7a`020:^[Z`070;Vi^@33`l<0a<C40=CDe02k^k/0ZJVY0<W9b@020<C4a004
0;Fe]@2o_kl0bLW90<G5aB@0oooo1@3G<ol206JSo`P0ec?o00<0IZ?o0=Lco`3G<ol08`3G<ol206JS
o`080=Lco`1VXol0IZ?o06JSo`3G<ol0IZ?o0=Lco`1VXol60=Lco`0506JSo`3G<ol0ec?o0=Lco`1V
Xol01P3G<ol00`3o0000ec?o0=Lco`0B0=Lco`0306JSo`3G<ol0ec?o00X0ec?o00<0IZ?o0=Lco`3G
<ol0303G<ol206JSo`D0ec?o00<0IZ?o0=Lco`3G<ol01@3G<olW0?ooo`009@3oool00`32`/80^KVi
0:j^[P020<S8b0070;jn_P32`/80a/K60<_;b`32`/80_Kfm0<71`@020;6a/@070<G5a@2k^k/0`/;2
0;Fe]@38b<P0_;bl0<W9b@020;jn_P070=7Ad@30`<00a<C40<C4a03;bl/0bLW90<o?c`020;^k^`07
09fMW@33`l<0`L710;no_`2ZZZX0a<C40<K6aP020=GEe@070;no_`30`<00`/;20<G5a@2XZ:P0`<30
0:j^[P020:6QX@070;6a/@2i^KT0_[jn0>7Qh@32`/80^KVi0:VYZ@020;^k^`07096AT@2j^[X0cLg=
0;:b/P34a<@0[jn_0<[:bP020<O7a`060:^[Z`30`<00hN7Q0:VYZ@32`/80];Bd0`2k^k/01`36a/H0
bLW90;Bd]03:b/X0^k^k0;Fe]@2m_Kd00P3:b/X01`38b<P0a<C40=;BdP34a<@0Y:BT0;fm_@36a/H0
0P32`/801`2a/K40`L710>OWi`2c/k<0b/[:0=;BdP2i^KT00P34a<@01`32`/80`<300<;2`P2l_;`0
XZ:R0<30`03:b/X00P30`<000`2YZJT0bLW90;Fe]@020<S8b00;0<_;b`2j^[X0eMGE0=GEe@3>c/h0
e=CD0;fm_@2_[jl0`/;20<K6aP2e]KD00P38b<P01`3Cdm<0a<C409NGU`2WYjL0][Jf0=7Ad@2^[Zh0
0P2a/K401034a<@0Zj^[0<30`032`/8T0?ooo`80ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol206JSoa80
ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`080=Lco`0306JSo`3G<ol0IZ?o00<0IZ?o1@3G<ol0101V
Xol0ec?o0=Lco`1VXol20=Lco`0306JSo`3G<ol0IZ?o00<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o4P3G
<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0o`0000X0ec?o00<0IZ?o0=Lco`3G<ol00P3G
<ol00`1VXol0ec?o0=Lco`090=Lco`0306JSo`3G<ol0ec?o00D0ec?o0P1VXol20=Lco`<0IZ?o00@0
ec?o06JSo`3G<ol0ec?o9`3oool002D0oooo0P2i^KT01`2d];@0/K6a0;6a/@2YZJT0_;bl0;jn_P3C
dm<00P2o_kl01`2k^k/0][Jf0;Jf]P2o_kl0ZZZZ0;no_`2k^k/00P36a/H02P39bLT0/;2`0;2`/030
`<00a/K60<W9b@37alL0`L710;no_`2`/;020;fm_@070<_;b`3=cLd0cLg=0<S8b02PX:00][Jf0<C4
a0020;Rh^0070<K6aP3:b/X0`L710:^[Z`30`<00a<C40;6a/@020::RXP070:n_[`2ZZZX0ZZZZ0;fm
_@2l_;`0];Bd0:f][@030;Vi^@060<O7a`36a/H0b/[:0;Ng]`32`/80];Bd0P37alL01`3Kfm/0_Kfm
0<c<c02e]KD0RXZ:0;no_`36a/H00P3<c<`01`30`<00`/;20<[:bP34a<@0bLW90;Ng]`2i^KT00P34
a<@01`2j^[X0e]KF0<C4a03<c<`0_kno0<K6aP3Bd]800P3IfMT01`2k^k/0b<S80;Jf]P2i^KT0`<30
0:b/[02h^;P00P2`/;001`3=cLd0WYjN0<[:bP2k^k/0]KFe0;^k^`2j^[X00P3GemL01`2/[:`0^KVi
0<30`03>c/h0^k^k0<30`02c/k<00P32`/800`3<c<`0e=CD0:^[Z`020<c<c0090861P@3@d=00`<30
0<30`038b<P0_;bl0<K6aP2[Zj/0_[jn0080bLW90P2k^k/0102o_kl0a<C40<k>cP3<c<`T0?ooo`<0
ec?o0`1VXol90=Lco`0306JSo`3G<ol0ec?o00<0ec?o0P1VXol60=Lco`0306JSo`3G<ol0ec?o00@0
ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lco`0606JSo`<0ec?o00<0IZ?o0=Lco`3G
<ol03@3G<ol00`1VXol0ec?o0=Lco`0I0=Lco`0606JSo`3G<ol0IZ?o06JSo`3G<ol0IZ?o1`3G<ol0
0`1VXol0ec?o0=Lco`080=Lco`0406JSo`3G<ol0ec?o06JSo`H0ec?o00<0IZ?o0=Lco`3G<ol01`3G
<olW0?ooo`009@3oool00`36a/H0`/;20;no_`020;bl_0070<W9b@32`/80Y:BT0;Fe]@2d];@0alO7
0;jn_P020;no_`070<_;b`2d];@0`L710<71`@37alL0_Kfm0<30`0020;:b/P070<30`037alL0clo?
0<30`02n_[h0_;bl0<30`0020<71`@070<O7a`3;bl/0clo?0=7Ad@2/[:`0^k^k0;Jf]P020;Zj^P07
0:j^[P32`/80^;Rh0<;2`P3;bl/0a/K60<O7a`020:BTY0070;Fe]@2[Zj/0/k>c0;Ng]`30`<00alO7
09ZJVP020:f][@070;^k^`2[Zj/0`<300;fm_@38b<P0_;bl0:^[Z`020;^k^`070;jn_P35aLD0]KFe
0;>c/`2i^KT0]kNg0<W9b@020<71`@060;fm_@32`/80`<300<30`039bLT0`/;20`34a<@0103?cll0
NWYj0<c<c02[Zj/20<_;b`0:0=KFeP2g]kL0]kNg0;Fe]@32`/80b/[:09bLW02o_kl0d];B0;Ng]`80
_Kfm00L0_kno0<30`034a<@0c/k>0=CDe038b<P0_;bl0080a/K600L0bl_;0;bl_03>c/h0_Kfm0<K6
aP3>c/h0a/K60080`<3000L0`/;20;>c/`2[Zj/0_kno0<K6aP3>c/h0d=3@0080d];B00L0cLg=0;2`
/02_[jl0^KVi0;Zj^P2o_kl0]kNg0080`/;200@0c<c<0=3@d03Fe]H0b<S8903oool70=Lco`0306JS
o`3G<ol0ec?o00/0ec?o0P1VXol=0=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol0
103G<ol206JSo`030=Lco`1VXol0ec?o00<0ec?o0`1VXol00`3G<ol0IZ?o0=Lco`030=Lco`0306JS
o`3G<ol0ec?o01<0ec?o00<0VOo20=Lco`1VXol0203G<ol00`1VXol0ec?o0=Lco`0G0=Lco`0306JS
o`3G<ol0ec?o00D0ec?o0P1VXol:0=LcobL0oooo000U0?ooo`030;^k^`31`L40/;2`0080^KVi00L0
^;Rh0;no_`30`<00`/;20<30`034a<@0^[Zj0080YJFU00L0aLG50;Ng]`2m_Kd0alO70;fm_@39bLT0
alO70080Z:RX00L0aLG50:>SX`39bLT0`/;20;Jf]P36a/H0d=3@0080a<C400L0^k^k0<30`02l_;`0
^k^k09bLW03<c<`0YjNW0080^;Rh0P3;bl/01@2b/[80];Bd0<W9b@2a/K40alO70080cLg=00L0_kno
0<W9b@2i^KT0a<C40;no_`30`<00dM7A0080ZZZZ00L0_Kfm0:f][@2`/;00gMgM0:n_[`2UYJD0[Jf]
0080]kNg00L0_kno0<;2`P2g]kL0b<S80;^k^`2YZJT0^;Rh0080`/;200L0bLW90<;2`P38b<P0bl_;
0<o?c`39bLT0fMWI00<0bl_;00H0b<S80<W9b@3AdM40`<300;fm_@3;bl/20;^k^`070;Vi^@36a/H0
a<C40<K6aP3GemL0a<C40;bl_0020;Fe]@070<C4a02WYjL0]KFe0:n_[`3=cLd0a<C40;Rh^0020<K6
aP070;Rh^03@d=00_Kfm0=;BdP32`/80c/k>0<S8b0020;jn_P030=[JfP3@d=00a<C40080^;Rh00/0
a<C40>WYj@34a<@0a<C40;Fe]@2k^k/0b<S80:BTY030`<00_kno0=OGe`020;Bd]0040<k>cP3=cLd0
^k^k0<k>cR@0oooo0P3G<ol00`1VXol0ec?o0=Lco`070=Lco`80IZ?o1`3G<ol206JSo`030=Lco`1V
Xol0ec?o00X0ec?o00<0IZ?o0=Lco`1VXol0103G<ol0101VXol0ec?o0=Lco`1VXol:0=Lco`80IZ?o
00@0ec?o06JSo`1VXol0ec?o0`1VXol70=Lco`0306JSo`3G<ol0ec?o01d0ec?o00<0IZ?o0=Lco`1V
Xol0503G<ol00`3o0000ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o00L0ec?o9`3oool002D0oooo
00<0/K6a0;Ng]`3;bl/00P36a/H00`2d];@0a/K60<O7a`020<K6aP80[:b/0P32`/801`2l_;`0];Bd
0<O7a`2o_kl0`L710;fm_@39bLT00P2m_Kd01`33`l<0cLg=0<g=c@2m_Kd0`<300<;2`P37alL00P2k
^k/01`34a<@0`/;20<K6aP2m_Kd0YJFU0;6a/@36a/H00P34a<@01`2j^[X0`<300;Zj^P3;bl/0c/k>
0;jn_P2WYjL00P34a<@01`2m_Kd0^;Rh0=CDe03@d=00^KVi0<W9b@3?cll00P2`/;001`2e]KD0[jn_
0=KFeP2g]kL0a/K60:FUY@2i^KT00P30`<001`3Jf]X0^KVi0;Jf]P3>c/h0_kno0:NWY`2i^KT00P34
a<@01`2h^;P0N7Qh0<K6aP3Fe]H0c<c<0=gMg@30`<000P2c/k<01`2f][H0Zj^[0=3@d02a/K40c<c<
0=?Cd`3@d=000`2k^k/01P3:b/X0/k>c0:>SX`30`<00a<C40:f][@80/K6a00L0_;bl0<30`02_[jl0
YjNW0:j^[P2m_Kd0/;2`0080b/[:00<0YjNW0<K6aP2^[Zh00P34a<@0102i^KT0a/K60<C4a034a<@2
0<30`0050<K6aP2o_kl0`l?30;fm_@3@d=000P38b<P01`3:b/X0c<c<0;6a/@3Fe]H0`/;20<C4a032
`/800P3@d=001032`/80^k^k0<W9b@3MgMdT0?ooo`0306JSo`3G<ol0ec?o00L0ec?o0P1VXolH0=Lc
o`80IZ?o2@3G<ol00`1VXol0ec?o0=Lco`070=Lco`80IZ?o00<0ec?o06JSo`3G<ol00P3G<ol00`1V
Xol0ec?o0=Lco`060=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0VOo20=Lco`3G<ol01P3G<ol00`1V
Xol0ec?o06JSo`080=Lco`0306JSo`3G<ol0ec?o00<0IZ?o0P3G<ol306JSo`070=Lco`1VXol0ec?o
0=Lco`1VXol0ec?o06JSo`0A0=Lco`0306JSo`3G<ol0ec?o00P0ec?o9`3oool002D0oooo00<0`<30
0;2`/02][Jd00`31`L401033`l<0]KFe0<O7a`2g]kL20;6a/@80b<S800L0c<c<0;fm_@36a/H0`/;2
0;Bd]033`l<0a<C40080]KFe00L0alO70;bl_031`L40`/;20<O7a`30`<00`L710080cLg=00D0b/[:
0;no_`32`/80_[jn0;Vi^@020<C4a080/K6a00L0][Jf0<K6aP32`/80^KVi0<;2`P2c/k<0a<C40080
ZJVY00L0YJFU0;Rh^02g]kL0_kno0;Jf]P3;bl/0Shn?0080a<C40P2o_kl01@2][Jd0^k^k0;Ng]`2c
/k<0`<300080];Bd00L0`<300;Rh^032`/80_kno0:JVYP2`/;00alO70080^k^k00H0alO70<K6aP3N
g]h0e]KF0<[:bP2f][H30;^k^`070:n_[`2o_kl0[Jf]0<K6aP3MgMd0_Kfm0;^k^`020<c<c0070;fm
_@32`/80b/[:0<30`038b<P0_kno0:f][@020<C4a0070<;2`P34a<@0^k^k0<k>cP38b<P0`/;20<o?
c`020<O7a`070<[:bP2m_Kd0a/K60:NWY`3?cll0c/k>0=?Cd`020<[:bP070<30`02m_Kd0a/K60<C4
a02o_kl0b<S80<o?c`020:f][@070=;BdP3<c<`0^KVi0<c<c03@d=00bl_;0<[:bP020;^k^`040<k>
cP2m_Kd0bl_;0<S8b2@0oooo00<0ec?o06JSo`1VXol01`3G<ol206JSoa/0ec?o0P1VXol70=Lco`<0
IZ?o1@3G<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0ec?o00P0ec?o0P1VXol<0=Lco`03
06JSo`3G<ol0IZ?o00`0ec?o00<0IZ?o0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`0:0=Lco`80
IZ?o3@3G<olW0?ooo`009@3oool00`2o_kl0ZZZZ0;Jf]P020<C4a0060<;2`P2d];@0a<C40=7Ad@2b
/[80^KVi0`34a<@01P37alL0`<300<K6aP2f][H0]kNg0<30`0<0^k^k00L0_;bl0<;2`P32`/80^KVi
0<S8b03=cLd0^[Zj0080alO700H0S8b<0;bl_030`<00^[Zj0:^[Z`2g]kL30<K6aP80_kno00D0a<C4
0;Vi^@30`<00b<S80;bl_0020<C4a0070;no_`32`/80_kno0;Rh^030`<00`/;20:FUY@020;Bd]007
09fMW@2][Jd0/k>c0:BTY02m_Kd0b<S809ZJVP020;>c/`070;fm_@2n_[h0/;2`0;no_`3:b/X0Xj>S
05mOG`020;^k^`070;no_`2JVYX0MWIf0;fm_@36a/H0]kNg0<[:bP020<30`0070:n_[`3;bl/0_kno
0:b/[03Fe]H0]kNg0:^[Z`020<K6aP070;no_`2k^k/0[jn_0;Fe]@32`/80_Kfm0<S8b0020;no_`06
0=3@d03EeMD0^[Zj0<K6aP2m_Kd0dM7A0`36a/H01`34a<@0gMgM0<;2`P2PX:00b/[:0=3@d032`/80
0P3<c<`01`2k^k/0a/K60;6a/@38b<P0a<C40;jn_P30`<000P3Rh^801`3<c<`0W9bL0;Ng]`3@d=00
`<300:f][@2MWId00P2f][H01038b<P0];Bd0<C4a03=cLdT0?ooo`030=Lco`1VXol0ec?o00H0ec?o
00<0IZ?o0=Lco`3G<ol0503G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o01<0ec?o00<0IZ?o0=Lco`3G
<ol00P1VXol01@3G<ol0IZ?o0=Lco`3G<ol0IZ?o00@0ec?o00D0IZ?o0=Lco`3G<ol0IZ?o09Wo`P03
0=Lco`0306JSo`2Iol80ec?o00D0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o0P3G<ol00`1VXol0ec?o0=Lc
o`020=Lco`0306JSo`3G<ol0ec?o0100ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lc
o`050=Lco`0406JSo`3G<ol0ec?o0=Lco`80IZ?o1P3G<olW0?ooo`009@3oool00`30`<00`l?30<G5
a@020:b/[0070;Zj^P2f][H0`<300;Rh^02j^[X0^k^k0;jn_P020<_;b`070<K6aP30`<00cLg=0<;2
`P2i^KT0_[jn0<W9b@020;Rh^0070;bl_037alL0`<300<_;b`2i^KT0/;2`0;no_`020=KFeP070;Rh
^02l_;`0^;Rh0;Ng]`2i^KT0_Kfm0<_;b`020<O7a`070<30`038b<P0]kNg0<_;b`30`<00b<S80<[:
bP020<C4a0070;jn_P39bLT0c/k>0;Ng]`2j^[X0^;Rh0<30`0020<o?c`070<O7a`36a/H0YJFU0<;2
`P3Bd]80Vi^K0:n_[`020;no_`070;Vi^@30`<00_kno0;^k^`2][Jd0`<300;Zj^P020<30`0070=oO
g`2_[jl0]KFe0<S8b02k^k/0b/[:0<C4a0020<S8b0070=3@d034a<@0bLW90;jn_P2a/K40_kno0;fm
_@020<K6aP070;Fe]@2o_kl0^k^k0<K6aP2`/;00a<C40;fm_@020;Zj^P070<S8b02k^k/0aLG509jN
WP36a/H0clo?0<C4a0020<;2`P060=3@d03Bd]80`l?30;Vi^@2m_Kd0`/;20`3Cdm<01`34a<@0aLG5
0<C4a02o_kl0/k>c0<30`038b<P00P2e]KD01`36a/H0_kno0=;BdP2g]kL0a<C40<;2`P2e]KD00P36
a/H20;jn_P030=3@d02i^KT0oooo02<0oooo0`3G<ol206JSoaL0ec?o00<0IZ?o0=Lco`3G<ol07P3G
<ol00`1VXol0ec?o0=Lco`0206JSo`H0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lc
o`090=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lc
o`0R0=LcobL0oooo000U0?ooo`030<30`033`l<0aLG50080[:b/00L0^[Zj0;Jf]P30`<00^;Rh0;Zj
^P2k^k/0_[jn0080bl_;00L0a/K60<30`03=cLd0`/;20;Vi^@2n_[h0bLW90080^;Rh00L0_;bl0<O7
a`30`<00bl_;0;Vi^@2`/;00_kno0080e]KF00L0^;Rh0;bl_02h^;P0]kNg0;Vi^@2m_Kd0bl_;0080
alO700L0`<300<S8b02g]kL0bl_;0<30`038b<P0b/[:0080a<C400L0_[jn0<W9b@3>c/h0]kNg0;Zj
^P2h^;P0`<300080clo?00L0alO70<K6aP2UYJD0`/;20=;BdP2KVi/0[jn_0080_kno00L0^KVi0<30
`02o_kl0^k^k0:f][@30`<00^[Zj0080`<3000L0gmoO0:n_[`2e]KD0b<S80;^k^`3:b/X0a<C40080
b<S800L0d=3@0<C4a039bLT0_[jn0;6a/@2o_kl0_Kfm0080a/K600L0]KFe0;no_`2k^k/0a/K60;2`
/034a<@0_Kfm0080^[Zj00L0b<S80;^k^`35aLD0WYjN0<K6aP3?cll0a<C40080`/;200H0d=3@0=;B
dP33`l<0^KVi0;fm_@32`/830=?Cd`070<C4a035aLD0a<C40;no_`2c/k<0`<300<S8b0020;Fe]@07
0<K6aP2o_kl0d];B0;Ng]`34a<@0`/;20;Fe]@020<K6aP80_[jn00<0d=3@0;Vi^@3oool08`3oool3
0=Lco`80IZ?o5`3G<ol00`1VXol0ec?o0=Lco`0N0=Lco`0306JSo`3G<ol0ec?o0080IZ?o1P3G<ol0
0`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o00T0ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol0
0`1VXol0ec?o0=Lco`050=Lco`0306JSo`3G<ol0ec?o0280ec?o9`3oool002D0oooo00<0^KVi0;Jf
]P2WYjL00P32`/801`2n_[h0dm?C0<S8b02a/K40`L710:j^[P36a/H00P3:b/X01P2f][H0^k^k0;bl
_02b/[80Z:RX0;fm_@@0bl_;00<0^[Zj0<30`02d];@00P2n_[h02P39bLT0a<C40<C4a030`<00eMGE
0<K6aP2g]kL0_kno0<W9b@3?cll20;jn_P070;no_`36a/H0a/K60<C4a02k^k/0U9BD0<c<c0020;Bd
]0070<C4a039bLT0/[:b0;fm_@2n_[h0^[Zj0;Jf]P020<71`@070:>SX`35aLD0`l?30<g=c@2NWYh0
UYJF0;Zj^P020;bl_0070;no_`30`<00Zj^[0<S8b02PX:00]KFe0;Ng]`020;Vi^@060;Ng]`2e]KD0
_Kfm0=WIf@3;bl/0/;2`0`2n_[h01`3GemL0cLg=0;>c/`36a/H0a<C40;fm_@2i^KT00P3;bl/01`30
`<00_kno0<30`031`L40bLW90<?3``2`/;000P2n_[h01`30`<00`/;20;^k^`3MgMd0b<S80;Fe]@34
a<@00`30`<020:VYZ@040<S8b02o_kl0Zj^[0<C4a080c/k>00L0clo?0=CDe03Hf=P0d];B0<S8b02M
WId0b/[:0080_[jn00H0a/K60:f][@3:b/X0fMWI0=3@d038b<P30>7Qh@040<;2`P3:b/X0cLg=0<30
`2@0oooo0P3G<ol00`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0IZ?o00H0ec?o0P1VXolK0=Lc
o`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol0101VXol0ec?o0=Lco`3G<ol2
06JSo`D0ec?o00<0IZ?o0=Lco`1VXol02@3G<ol00`1VXol0ec?o0=Lco`0@0=Lco`0306JSo`3G<ol0
ec?o00X0ec?o0P1VXol20=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol0
0`1VXol0ec?o0=Lco`090=LcobL0oooo000U0?ooo`030;^k^`35aLD0aLG50080][Jf00L0`<300;Zj
^P3=cLd0/[:b0:^[Z`2l_;`0`<300080`l?300L0^KVi0<;2`P32`/80_[jn0<O7a`33`l<0^k^k0080
`/;200L0c/k>0<30`034a<@0b<S80<K6aP3<c<`0/;2`0080^[Zj00L0b/[:0<S8b02i^KT0/K6a0;Vi
^@2f][H0^;Rh0080`/;200<0/K6a0;^k^`38b<P00P38b<P02`30`<00c<c<0;:b/P2b/[80alO70<o?
c`2d];@0a<C40;:b/P36a/H0c<c<0080/k>c00H0XZ:R0;Bd]02d];@0_kno08n?S`2[Zj/30:VYZ@07
0;Fe]@38b<P0a<C40;>c/`2o_kl0/k>c0::RXP020;Ng]`070<;2`P2m_Kd0a/K60:^[Z`2i^KT0]kNg
0;Vi^@020<k>cP070;Vi^@3Fe]H0cLg=0<g=c@34a<@0^k^k0<;2`P020<71`@070;>c/`2/[:`0clo?
0<71`@2_[jl0_kno0<;2`P020<o?c`070;jn_P2RXZ80^KVi0;no_`38b<P0`<300;no_`020<[:bP04
0=SHf02m_Kd0`<300<C4a080b<S800X0bLW90<30`030`<00`/;20<c<c03;bl/0b<S80;no_`3=cLd0
a/K60P2TY:@01`34a<@0jn_[0;fm_@36a/H0b<S80<W9b@30`<000P3?cll0102RXZ80Lg=c0;Bd]036
a/HT0?ooo`P0ec?o0P1VXolC0=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol00`3G
<ol00`1VXol0ec?o0=Lco`040=Lco`80IZ?o103G<ol00`1VXol0ec?o0=Lco`020=Lco`0406JSo`3G
<ol0ec?o0=Lco`D0IZ?o1P3G<ol00`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o00d0ec?o
00@0IZ?o0=Lco`3G<ol0IZ?o1@3G<ol00`1VXol0ec?o0=Lco`0E0=Lco`80IZ?o00<0ec?o0?l0003G
<ol01P3G<ol0101VXol0VOo20=Lco`3G<olW0?ooo`009@3oool00`2b/[80]kNg0=[JfP020;Rh^007
0<;2`P3;bl/0`/;20<30`03>c/h0a<C40;Bd]0020<C4a0070<S8b034a<@0^KVi0;^k^`3;bl/0a<C4
0<O7a`020<71`@070;Vi^@3:b/X0][Jf0;jn_P34a<@0_Kfm0;Rh^0020;Bd]0070<;2`P38b<P0]KFe
0<K6aP2n_[h0_;bl0<S8b0020;^k^`070<c<c02o_kl0_Kfm0<C4a02a/K40`L710;no_`020;Fe]@07
0<S8b02i^KT0_[jn0<k>cP2[Zj/0^k^k0<S8b0020<K6aP070:BTY03@d=00^k^k0<K6aP2MWId0^k^k
0:FUY@020;:b/P070;Rh^030`<00_kno0:f][@2g]kL0ZJVY0;Rh^0020<S8b0070<k>cP2k^k/0c<c<
0;6a/@3Bd]80a<C40;^k^`020<;2`P070<C4a02i^KT0a/K60<30`032`/80g=cL0<_;b`020<71`@07
0;^k^`39bLT0];Bd0;Vi^@2[Zj/0/K6a0=KFeP020:VYZ@070<c<c03Ti>@0e=CD0=KFeP30`<00^KVi
0;Zj^P020<k>cP070=;BdP2c/k<0^k^k0;Zj^P2k^k/0]KFe0=7Ad@020<C4a0070<S8b03<c<`0`<30
0<W9b@2l_;`0clo?0<W9b@020=;BdP070<k>cP2][Jd0][Jf0:j^[P34a<@0/[:b0=7Ad@020<;2`P80
^k^k00<0bLW90<30`03oool08`3oool00`1VXol0ec?o0=Lco`0Z0=Lco`0306JSo`3G<ol0ec?o00H0
ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol01P1VXol0ec?o0=Lco`3G<ol0IZ?o0=Lco`<0IZ?o0`3G<ol0
0`1VXol0ec?o06JSo`060=Lco`0306JSo`3G<ol0ec?o0100ec?o0P1VXol00`3G<ol0IZ?o06JSo`0L
0=Lco`0506JSo`3G<ol0IZ?o0=Lco`1VXol01`3G<olW0?ooo`009@3oool00`30`<00alO70<K6aP02
0;Bd]0070;Ng]`34a<@0/[:b0;no_`2k^k/0`L710;fm_@020<_;b`030;bl_036a/H0bLW90080a/K6
00<0`<300<g=c@35aLD00P35aLD01P36a/H0_;bl0<;2`P36a/H0`/;20;Vi^@80bl_;00L0][Jf0;no
_`32`/80[jn_0=;BdP2i^KT0c<c<0080^;Rh00L0_kno0;>c/`39bLT0YjNW0<30`033`l<0b/[:0080
a/K600L0b<S80<30`02m_Kd0_kno0;>c/`2e]KD0cLg=0080a<C400L0WYjN0;no_`3:b/X0bLW90;Rh
^034a<@0[jn_0080UYJF00L0Zj^[0:b/[02VYZH0^KVi0:n_[`2i^KT0d];B0080d=3@00L0WYjN0:n_
[`2o_kl0_kno0:n_[`2e]KD0`<300080alO700@0_Kfm0;Vi^@2o_kl0b/[:0P32`/802P36a/H0c/k>
0<k>cP38b<P0_Kfm0<_;b`3=cLd0_kno0;^k^`2j^[X20=CDe0070<K6aP3;bl/0[jn_0;2`/02i^KT0
b/[:0<k>cP020<c<c0070<C4a03>c/h0X:2P0<k>cP3De=@0a/K60=3@d0020=CDe080b<S800D0e]KF
0;Vi^@34a<@0/k>c0;Vi^@0206QXJ0050<K6aP38b<P0_kno0;^k^`2g]kL00P39bLT20<;2`P040<S8
b032`/80bl_;0;Vi^B@0oooo1`3G<ol00`1VXol0ec?o0=Lco`0I0=Lco`0306JSo`3G<ol0ec?o00H0
ec?o00<0IZ?o0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`030=Lco`H0IZ?o00<0ec?o06JSo`3G
<ol00`3G<ol206JSo`80ec?o00<0IZ?o0=Lco`3G<ol05P3G<ol206JSo`L0ec?o00<0IZ?o0=Lco`3G
<ol02`3G<ol209Wo`Pd0ec?o9`3oool002D0oooo00<0]kNg0;Vi^@2a/K400P2o_kl01@2k^k/0ZZZZ
0;Vi^@38b<P0aLG50080^k^k0P3@d=001`2o_kl0^k^k0:f][@34a<@0_Kfm0<;2`P2h^;P00P2f][H0
1`2d];@0_kno0<o?c`3>c/h0b/[:0=OGe`34a<@00P39bLT01`2n_[h0_kno0;2`/036a/H0_Kfm0;jn
_P34a<@00`32`/801P2j^[X0bLW90:j^[P31`L40/k>c0;^k^`80bLW900L0_;bl0;Zj^P2j^[X0_[jn
0;6a/@33`l<0];Bd0080`<3000L0f=SH0<30`02k^k/0]KFe04e=C@2k^k/0_Kfm0080[Jf]00L0UYJF
0;Bd]02i^KT0[Jf]0;2`/026QXH0a<C40080]kNg00L0^KVi09BDU034a<@0b/[:0<c<c03:b/X0/k>c
0080Zj^[00L0a/K60<;2`P3:b/X0c<c<0<S8b030`<00a/K60080]KFe00@0`<3008N7Q`3Bd]80^k^k
0P34a<@02P2m_Kd0/K6a0;6a/@3>c/h0]KFe0<K6aP2g]kL0bl_;0<g=c@3?cll20<C4a0070=3@d02n
_[h0b<S80;jn_P3?cll0`/;20<k>cP020;>c/`070<[:bP34a<@0a/K60;fm_@2/[:`0_[jn0=?Cd`02
0<[:bP070;>c/`2g]kL0[jn_0<30`036a/H0YjNW0<S8b0020;Vi^@040;bl_02HV9P0dM7A0;2`/2@0
oooo0P3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o00T0ec?o00<0IZ?o0=Lco`3G<ol03`3G<ol00`1V
Xol0ec?o0=Lco`070=Lco`0306JSo`3G<ol0ec?o00L0ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol00`2I
ol80ec?o0=Lco`0306JSo`80ec?o0`1VXol40=Lco`0306JSo`3G<ol0ec?o00<0ec?o0P1VXol:0=Lc
o`0306JSo`3G<ol0ec?o00<0ec?o0P1VXolF0=Lco`0306JSo`3G<ol0ec?o00@0ec?o00@0IZ?o0=Lc
o`3G<ol0IZ?o103G<ol00`1VXol0ec?o06JSo`0W0?ooo`009@3oool00`33`l<0Zj^[0;bl_0020<c<
c0070;jn_P38b<P0f][J0=3@d036a/H0_[jn0<K6aP020<C4a0070<S8b02k^k/0_[jn0;Rh^03:b/X0
a<C40<;2`P020<o?c`070;Rh^035aLD0^KVi0<c<c034a<@0]KFe0;no_`020;Fe]@050<;2`P37alL0
a/K60;fm_@33`l<00P38b<P20<;2`P070<30`02i^KT0_;bl0<o?c`2b/[80/K6a0;no_`0208F5Q@07
0;fm_@2e]KD0a<C40=3@d034a<@0clo?0=GEe@020=CDe0070<30`036a/H0`/;20;Ng]`34a<@0]kNg
0;6a/@020<C4a0040<;2`P23Ph<0V9RH0:BTY080Z:RX00X0WYjN0<?3``33`l<0a/K60:6QX@2o_kl0
clo?0<G5a@2o_kl0alO70P35aLD01`37alL0a<C40<[:bP34a<@0a/K60;6a/@3;bl/00`2h^;P01P2f
][H0_kno0=KFeP2k^k/0`/;20;>c/`80_Kfm00L0b/[:0<;2`P3:b/X0d];B0=?Cd`32`/80e]KF0080
f=SH00L0d];B0<S8b02k^k/0f=SH0<c<c03Bd]80dM7A0080a/K600L0d];B0<S8b02[Zj/0^k^k0;Ng
]`2YZJT0[jn_0080d=3@00L0e]KF0=kNgP3IfMT0c/k>0:NWY`39bLT0f][J0080`/;200@0e=CD0<S8
b034a<@0bl_;903oool00`3G<ol0IZ?o0=Lco`0Z0=Lco`80IZ?o00<0ec?o06JSo`1VXol03`3G<ol0
101VXol0ec?o0=Lco`3G<ol606JSo`<0ec?o00<0IZ?o0=Lco`3G<ol02P3G<ol00`1VXol0ec?o0=Lc
o`0N0=Lco`0306JSo`3G<ol0ec?o0080IZ?o1P3G<ol00`1VXol0ec?o0=Lco`060=LcobL0oooo000U
0?ooo`030;2`/02a/K40_[jn0080_Kfm00L0[Jf]0:j^[P2o_kl0]KFe0;:b/P3?cll0`<300080_;bl
00@0_[jn0<K6aP32`/80^k^k0P2c/k<01037alL0a<C40<C4a034a<@20<30`0040<_;b`34a<@0_[jn
0<?3``80^k^k00L0][Jf0;Bd]030`<00^k^k0;no_`3@d=00b<S80080c/k>00L0`<300<c<c02j^[X0
_;bl0;Bd]02YZJT0`/;20080bLW900L0_kno0<g=c@39bLT0d=3@0<o?c`36a/H0gMgM0080d];B00L0
];Bd0<;2`P36a/H0`<300<k>cP34a<@0]KFe0080_kno00L0/K6a0:2PX01eMGD0^k^k09jNWP2d];@0
a<C40080dm?C0P2n_[h01@2m_Kd0/[:b0<_;b`39bLT0bl_;0080bLW900L0Z:RX0;no_`2m_Kd0^[Zj
0;jn_P3Fe]H0b<S80080aLG500L0_Kfm09fMW@39bLT0bl_;0;^k^`30`<00c/k>0080`<3000@0c<c<
0>g]k@2[Zj/0a<C40P38b<P02P3>c/h0YJFU0:FUY@3:b/X0e=CD0<[:bP34a<@0_kno0<[:bP34a<@2
0<W9b@070<K6aP3Fe]H0bl_;0<c<c03@d=00_[jn0<S8b0020>;RhP070<o?c`2GUiL0[:b/0<?3``3;
bl/0`/;20<S8b0020<g=c@040;Vi^@2[Zj/0`<300;Bd]2@0oooo0P1VXol30=Lco`80IZ?o0P3G<ol0
0`1VXol0ec?o0=Lco`0R0=Lco`0306JSo`3G<ol0ec?o01<0ec?o0P1VXol00`2Iol80ec?o06JSo`07
0=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol00`1VXol0ec?o0=Lco`06
0=Lco`030?l0001VXol0ec?o00<0ec?o0P1VXolC0=Lco`80IZ?o1`3G<ol00`1VXol0ec?o0=Lco`0W
0?ooo`009@3oool00`2l_;`0_kno0<71`@020:^[Z`0709jNWP3>c/h0][Jf0<C4a02k^k/0_kno0;Vi
^@020;^k^`070<O7a`2][Jd0cLg=0;jn_P2^[Zh0a/K60;jn_P020<g=c@050;no_`2i^KT0b/[:0;bl
_032`/800P3=cLd20;Ng]`070;jn_P34a<@0^;Rh0<K6aP2j^[X0_Kfm0<K6aP020<30`0<0a/K600@0
YJFU0;bl_02[Zj/0]KFe0P3EeMD01`3=cLd0dM7A0:^[Z`3Jf]X0g=cL0>[ZjP3=cLd00P2d];@01P39
bLT0^;Rh0;2`/034a<@0]kNg0;^k^`<0`<3000L0a/K60<;2`P2i^KT0Xj>S092@T02f][H0_[jn0080
Xj>S00L0d];B09jNWP2^[Zh0_Kfm0;6a/@39bLT0b/[:0080c/k>00L0b<S80;Vi^@36a/H0b<S807]k
N`32`/80f][J0080/K6a00L0b<S80:VYZ@3Bd]80^k^k0<C4a02m_Kd0/k>c0080][Jf00L0e]KF0<30
`02i^KT0_kno0<K6aP34a<@0b<S80080YjNW00L0gMgM0:n_[`36a/H0clo?0=3@d038b<P0_Kfm0080
`/;200L0`L710;jn_P2m_Kd0/k>c0;Vi^@3QhN40b/[:0080]KFe00L0alO70<71`@32`/80b<S80<[:
bP32`/80fm_K0080bl_;00@0ZJVY0:NWY`2k^k/0dM7A903oool30=Lco`<0IZ?o2@3G<ol0101VXol0
ec?o0=Lco`1VXolI0=Lco`0306JSo`3G<ol0IZ?o00D0ec?o00@0IZ?o0=Lco`3G<ol0o`001@3G<ol0
0`1VXol0ec?o0=Lco`070=Lco`80IZ?o0P3G<ol206JSo`050=Lco`1VXol0IZ?o0=Lco`1VXol0203G
<ol00`2Iol80ec?o0=Lco`0206JSo`030=Lco`1VXol0ec?o00d0ec?o0P1VXol00`3G<ol0IZ?o0=Lc
o`0H0=Lco`80IZ?o0P3G<olW0?ooo`009@3oool00`2l_;`0_kno0<71`@020:^[Z`0709jNWP3>c/h0
][Jf0<C4a02k^k/0_kno0;Vi^@020;^k^`070<O7a`2][Jd0cLg=0;jn_P2^[Zh0a/K60;jn_P020<g=
c@050;no_`2i^KT0b/[:0;bl_032`/800P3=cLd20;Ng]`070;jn_P34a<@0^;Rh0<K6aP2j^[X0_Kfm
0<K6aP020<30`0<0a/K600@0YJFU0;bl_02[Zj/0]KFe0P3EeMD01`3=cLd0dM7A0:^[Z`3Jf]X0g=cL
0>[ZjP3=cLd00P2d];@01P39bLT0^;Rh0;2`/034a<@0]kNg0;^k^`<0`<3000L0a/K60<;2`P2i^KT0
Xj>S092@T02f][H0_[jn0080Xj>S00L0d];B09jNWP2^[Zh0_Kfm0;6a/@39bLT0b/[:0080c/k>00L0
b<S80;Vi^@36a/H0b<S807]kN`32`/80f][J0080/K6a00L0b<S80:VYZ@3Bd]80^k^k0<C4a02m_Kd0
/k>c0080][Jf00L0e]KF0<30`02i^KT0_kno0<K6aP34a<@0b<S80080YjNW00L0gMgM0:n_[`36a/H0
clo?0=3@d038b<P0_Kfm0080`/;200L0`L710;jn_P2m_Kd0/k>c0;Vi^@3QhN40b/[:0080]KFe00L0
alO70<71`@32`/80b<S80<[:bP32`/80fm_K0080bl_;00@0ZJVY0:NWY`2k^k/0dM7A903oool30=Lc
o`<0IZ?o2@3G<ol0101VXol0ec?o0=Lco`1VXolI0=Lco`0306JSo`3G<ol0IZ?o00D0ec?o00@0IZ?o
0=Lco`3G<ol0o`001@3G<ol00`1VXol0ec?o0=Lco`070=Lco`80IZ?o0P3G<ol206JSo`050=Lco`1V
Xol0IZ?o0=Lco`1VXol0203G<ol00`2Iol80ec?o0=Lco`0206JSo`030=Lco`1VXol0ec?o00d0ec?o
0P1VXol00`3G<ol0IZ?o0=Lco`0H0=Lco`80IZ?o0P3G<olW0?ooo`009@3oool00`30`<00cLg=0<71
`@020;Zj^P070:f][@36a/H0b<S80<C4a03;bl/0^KVi0;Bd]0020<30`0070<C4a030`<00^k^k0;:b
/P36a/H0^KVi0<;2`P020<g=c@070<o?c`3<c<`0_kno0<O7a`2o_kl0]KFe0:f][@020:b/[0070;jn
_P39bLT0aLG50:j^[P2k^k/0[:b/0<W9b@020<;2`P070=3@d03?cll0alO70;bl_02`/;00`<300;no
_`020<_;b`070;bl_02YZJT0_Kfm0<W9b@3Kfm/0c/k>0<c<c0020;Rh^080a/K600D0b/[:0;Ng]`3A
dM40_Kfm0<K6aP020<;2`P070;^k^`2`/;00[Jf]09RHV02UYJD0WYjN0;2`/0030;Jf]P060;2`/02l
_;`0XZ:R0<[:bP39bLT0a<C40P39bLT01`2i^KT0];Bd0<[:bP3:b/X0/k>c0=;BdP36a/H00P2l_;`0
1P2c/k<0`/;20;no_`2m_Kd0UYJF0<30`0<0a/K600L0_kno0;fm_@3:b/X0`/;20;Rh^02l_;`0dm?C
0080d=3@00L0Y:BT0<k>cP36a/H0a/K60=7Ad@2k^k/0[Jf]0080/;2`00L0a<C40:FUY@3@d=00a<C4
0;no_`39bLT0a<C40080c<c<00L0Ti>C0<K6aP2NWYh0Y:BT0:b/[02YZJT0a<C40080][Jf00@0aLG5
0;Rh^03=cLd0f=SH903oool50=Lco`0306JSo`3G<ol0ec?o00T0ec?o00<0IZ?o0=Lco`3G<ol02@3G
<ol306JSo`<0ec?o00<0IZ?o0=Lco`1VXol01`3G<ol00`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G
<ol0ec?o00l0ec?o1P1VXol30=Lco`0306JSo`3G<ol0IZ?o0180ec?o00<0IZ?o0=Lco`3G<ol02`3G
<ol00`1VXol0ec?o0=Lco`030=Lco`<0IZ?o00<0ec?o06JSo`3G<ol01P3G<ol00`1VXol0ec?o06JS
o`0306JSo`L0ec?o9`3oool002D0oooo00<0^[Zj0<;2`P30`<000P3@d=001`2YZJT0U9BD0;^k^`2g
]kL0_;bl0<K6aP2o_kl00P32`/801`2d];@0_Kfm0<S8b02o_kl0`l?30<_;b`36a/H00P2l_;`01`32
`/80b/[:0<S8b030`<00bLW90;jn_P2_[jl00P2CTi<01`2_[jl0_kno0;2`/03;bl/0b/[:0:n_[`3<
c<`00P2k^k/01`3@d=00c/k>0;jn_P2l_;`0Xj>S0<30`02o_kl00P3De=@01`3Fe]H0h>3P0;^k^`3>
c/h0b/[:0:n_[`2`/;000P2f][H01`39bLT0`<300<30`036a/H0^KVi0<K6aP2j^[X00P34a<@01`30
`<00[Jf]0<;2`P2XZ:P0YjNW0;2`/02i^KT00P2MWId01`2i^KT0]kNg0:FUY@32`/80b/[:0:f][@30
`<000P2e]KD01`36a/H0WYjN0<k>cP32`/80bl_;0<[:bP2JVYX00P39bLT01`2a/K40e=CD0<g=c@2o
_kl0`<300;^k^`2[Zj/00P2o_kl01`2_[jl0^[Zj0<30`02d];@0c<c<0;fm_@39bLT00P34a<@01`3>
c/h0a/K60;Rh^03Bd]80`<300=WIf@2g]kL00P34a<@01`2][Jd0_kno0<c<c03@d=00d];B0;no_`2g
]kL00P2e]KD01`2g]kL0b/[:0;no_`2m_Kd0l?3`0<K6aP2o_kl00P34a<@0102c/k<0_kno0<O7a`3?
cllT0?ooo`D0ec?o0P1VXolF0=Lco`@0IZ?o00D0ec?o06JSo`3G<ol0ec?o06JSo`070=Lco`0306JS
o`3G<ol0ec?o00L0ec?o0P1VXol<0=Lco`0306JSo`3G<ol0IZ?o0080IZ?o00<0ec?o06JSo`1VXol0
0P3G<ol0101VXol0ec?o0=Lco`1VXol40=Lco`0306JSo`3G<ol0ec?o0080ec?o00@0IZ?o0=Lco`3G
<ol0IZ?o1@3G<ol0101VXol0ec?o0=Lco`1VXolA0=Lco`0306JSo`3G<ol0ec?o00X0ec?o00<0o`00
0=Lco`3G<ol01P3G<olW0?ooo`009@3oool00`2n_[h0bLW90;bl_0020;>c/`040<W9b@3@d=00bl_;
0;:b/P80^k^k00X0bl_;0;:b/P2b/[80cLg=0<30`03@d=00a/K60;fm_@2k^k/0`<300P3?cll01`2b
/[80_;bl0;:b/P2n_[h0a/K60;>c/`2^[Zh00P2NWYh01`2DU9@0b/[:0<?3``2k^k/0_Kfm0<W9b@34
a<@00P2f][H01`32`/80a<C40;Fe]@32`/80]kNg0;Fe]@32`/800P34a<@01`32`/80c<c<0:NWY`28
R8P0Shn?096AT@2CTi<00P3@d=001`2e]KD0cLg=0<G5a@2i^KT0_Kfm0<o?c`3GemL00P2PX:001`30
`<00]kNg0;^k^`31`L40]KFe0:ZZZP3=cLd00P37alL01`34a<@0[Zj^0<O7a`36a/H0dm?C0<W9b@3>
c/h00P34a<@01`3Ogml0a<C40<g=c@2e]KD0emOG0<c<c032`/800P3Fe]H01`2c/k<0a/K60<[:bP3D
e=@0d];B0;^k^`3;bl/00P2UYJD01`38b<P0^;Rh0<S8b03=cLd0jn_[0;6a/@3Kfm/00P34a<@01`3J
f]X0d=3@0<C4a036a/H0c/k>0=WIf@3<c<`00P2n_[h01`2a/K40b<S80<[:bP2PX:00`/;20;>c/`38
b<P00P2HV9P01`30`<00_Kfm0;Rh^033`l<0cLg=0;no_`39bLT00P3?cll0103=cLd0a/K60=OGe`3E
eMDT0?ooo`P0ec?o00@0IZ?o0=Lco`3G<ol0ec?o0P1VXol90=Lco`0306JSo`3G<ol0IZ?o00<0ec?o
101VXolC0=Lco`D0IZ?o2@3G<ol206JSo`D0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol00`1VXol0ec?o
0=Lco`0E0=Lco`80IZ?o103G<ol00`3o0000IZ?o0=Lco`0;0=Lco`0406JSo`3G<ol0ec?o06JSo`<0
ec?o0P1VXol=0=LcobL0oooo000U0?ooo`030<S8b02k^k/0a<C40080_kno00L0/[:b0;Jf]P2d];@0
a<C40<W9b@38b<P0a/K60080`/;200L0a<C40<30`03@d=00`<300<_;b`37alL0cLg=0080`<3000L0
`/;20<W9b@2d];@0b<S80;6a/@32`/80`<300080a<C400L0emOG0;Rh^02m_Kd0^;Rh0;jn_P39bLT0
bl_;0080b/[:00L0`/;20:j^[P2e]KD0a<C40;Ng]`3:b/X0a/K60080Ti>C00L0Ogmo09JFUP2NWYh0
ZJVY07emO@2a/K40_kno0080b<S800L0b/[:0=CDe02m_Kd0_Kfm0<g=c@2o_kl0alO70080`/;200L0
`L710;2`/032`/80^k^k0;no_`30`<00VIVI0080][Jf00L0[jn_0;6a/@2UYJD0[Zj^0;bl_03;bl/0
alO70080Z:RX00L0bl_;0<g=c@3?cll0_[jn0<S8b030`<00a/K60080cLg=00L0_[jn0<g=c@2UYJD0
a<C40;^k^`30`<00cLg=0080_Kfm00<0a<C40<c<c03:b/X00P2o_kl01032`/80k>c/0<o?c`3?cll2
0<30`0050<K6aP2l_;`0d];B0<W9b@32`/800P2g]kL01`36a/H0a<C40;Vi^@2`/;00YJFU0<30`02g
]kL00P3:b/X01`30`<00[jn_0;bl_03;bl/0bLW90<30`02n_[h00P3=cLd0102j^[X0][Jf0=;BdP2k
^k/T0?ooo`D0ec?o00<0IZ?o0=Lco`3G<ol04`3G<ol00`1VXol0ec?o0=Lco`0<0=Lco`0306JSo`3G
<ol0ec?o00<0ec?o0P1VXol01P2Iol80IZ?o06JSo`1VXol0VOo206JSo`d0ec?o00<0IZ?o0=Lco`3G
<ol00P3G<ol00`1VXol0ec?o0=Lco`0406JSo`<0ec?o0P1VXol;0=Lco`0306JSo`3G<ol0ec?o00X0
ec?o00<0o`000=Lco`3G<ol0303G<ol206JSo`D0ec?o00<0IZ?o0=Lco`3G<ol02@3G<olW0?ooo`00
9@3oool00`2b/[80_Kfm0<G5a@020;Vi^@070;Jf]P36a/H0bl_;0<K6aP31`L40^k^k0<71`@020<?3
``070;^k^`2e]KD0`/;20<C4a032`/80a<C40<k>cP020<C4a0070;fm_@2j^[X0^;Rh0<_;b`36a/H0
]kNg0;fm_@030<S8b0030:BTY02e]KD0_Kfm0080`/;200X0bLW90<k>cP3>c/h0alO70<71`@34a<@0
`/;20<W9b@2b/[80bLW90P36a/H0102f][H0UYJF09nOW`2i^KT20;fm_@0:0;Ng]`2o_kl0_kno0<C4
a02i^KT0c<c<0<K6aP2l_;`0^;Rh0;6a/@80_Kfm00L0aLG50;fm_@34a<@0`<300:VYZ@2k^k/0bl_;
0080d=3@00L0^k^k0::RXP32`/80b<S80;fm_@30`<00b/[:0080^KVi00L0[jn_0<;2`P32`/80_;bl
0<_;b`39bLT0a<C40080d=3@00L0];Bd0;Zj^P2o_kl0Y:BT0;Fe]@2c/k<0/K6a0080b/[:00L0c/k>
0<W9b@3>c/h0a/K60<C4a02k^k/0/K6a0080b/[:00L0d=3@0<K6aP38b<P0bLW90>7Qh@39bLT0^KVi
0080^k^k00L0c/k>0;no_`3@d=00_kno0;fm_@3>c/h0^KVi0080e=CD00L0_Kfm0=;BdP2i^KT0^;Rh
0;bl_030`<00`/;20080]KFe00@0c<c<0<g=c@39bLT0c/k>903oool00`1VXol0ec?o0=Lco`0N0=Lc
o`0306JSo`3G<ol0ec?o00X0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol206JSo``0ec?o00<0IZ?o0=Lc
o`3G<ol0103G<ol00`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lc
o`3G<ol02@3G<ol0101VXol0ec?o0=Lco`1VXol80=Lco`0306JSo`3G<ol0ec?o01l0ec?o9`3oool0
02D0oooo00<0`/;20<C4a02h^;P00P2j^[X01`2`/;00/[:b0<G5a@2d];@0/;2`0<K6aP2b/[800P2e
]KD01`2^[Zh0c/k>0;Fe]@2k^k/0_[jn0;Zj^P2m_Kd00P2ZZZX01`36a/H0^[Zj0<C4a03<c<`0a/K6
0;Ng]`2n_[h00P39bLT01`2i^KT0]KFe0<;2`P2m_Kd0a<C40<S8b034a<@00P3<c<`01`3=cLd0];Bd
0<S8b02a/K40^[Zj0;bl_02a/K400P2c/k<01`2e]KD0Vi^K0<71`@3>c/h0/K6a0;Vi^@38b<P00P2`
/;001`2f][H0`/;20;no_`32`/80emOG0;fm_@2j^[X00P2f][H01`2j^[X0/k>c0;jn_P2e]KD0^KVi
0;>c/`3MgMd00P2@T9001`3Bd]80c<c<0;Fe]@3:b/X0`<300:f][@3QhN400P34a<@01`2f][H0_;bl
0;Vi^@2a/K40a/K60=WIf@34a<@00P3:b/X01`30`<00]KFe0<;2`P3:b/X0d];B0;^k^`30`<000P3I
fMT20<30`0050=CDe02UYJD0/k>c0<C4a02][Jd00`3:b/X01P34a<@0c/k>0=3@d02i^KT0c<c<0<30
`080b<S800L0`/;20<c<c03>c/h0`<300:NWY`2QXJ40b/[:0080a<C400L0`<300<;2`P2g]kL0a<C4
0<30`039bLT0e=CD0080dM7A00@0_kno0;Rh^02i^KT0a<C4903oool50=Lco`80IZ?o0P3G<ol00`1V
Xol0ec?o06JSo`020=Lco`0306JSo`3G<ol0ec?o00@0ec?o0P1VXolE0=Lco`0406JSo`3G<ol0ec?o
06JSo`<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o0P3G<ol206JSoa00ec?o0P1VXol50=Lco`0306JSo`3G
<ol0ec?o00@0ec?o00<0IZ?o0=Lco`3G<ol03`3G<ol0101VXol0ec?o0=Lco`1VXol?0=Lco`80IZ?o
403G<olW0?ooo`009@3oool00`2m_Kd0aLG50<C4a00208J6QP0709BDU02:RXX0/K6a0::RXP3:b/X0
`l?30;Jf]P020;jn_P070<30`02XZ:P0]KFe0<30`02XZ:P0]KFe0<c<c0020;no_`070;Fe]@3;bl/0
^k^k0;Zj^P3;bl/0a<C40<[:bP020;no_`060<k>cP32`/80c/k>0<;2`P34a<@0[Zj^0`37alL01`3I
fMT0dM7A0;^k^`3;bl/0clo?0;:b/P36a/H00P3GemL01`38b<P0ZJVY0<c<c02i^KT0^k^k0=;BdP3D
e=@00P36a/H01`30`<00a/K60<K6aP3;bl/0`/;20<30`03;bl/00P2o_kl01`2i^KT0[jn_0;Ng]`2k
^k/0b/[:0:n_[`2g]kL00P2a/K401`2k^k/0WIfM0;Rh^03=cLd0`/;20=WIf@32`/800P2k^k/01@3@
d=00b<S80=3@d02m_Kd0]kNg0080a/K60P2b/[801`30`<00YjNW0<C4a02`/;00bl_;0:RXZ02f][H0
0P33`l<01`38b<P0a/K60;no_`34a<@0b/[:0<C4a036a/H00P34a<@01`2b/[80b<S80;Ng]`2g]kL0
c<c<0<S8b02k^k/00P2g]kL01`36a/H0bl_;0<W9b@38b<P0a<C40;fm_@2b/[800P3EeMD01`36a/H0
`<300>?Sh`30`<00emOG0;Ng]`2NWYh00P32`/80103De=@0^KVi0;Vi^@3Fe]HT0?ooo`<0ec?o1P1V
Xol60=Lco`0406JSo`3G<ol0ec?o06JSoa80ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol00`1VXol0ec?o
0=Lco`020=Lco`0306JSo`3G<ol0ec?o00l0ec?o00H0IZ?o0=Lco`3G<ol0ec?o06JSo`3G<ol206JS
o`030=Lco`1VXol0ec?o00d0ec?o0P1VXol01P3G<ol0IZ?o0=Lco`1VXol0ec?o06JSo``0ec?o00<0
IZ?o0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`060=Lco`0306JSo`3G<ol0ec?o00@0ec?o9`3o
ool002D0oooo00<0YjNW0;Vi^@2][Jd00P2j^[X00`32`/80dm?C0;Zj^P020<K6aP0;0<30`032`/80
_[jn0;jn_P32`/80_kno0<71`@2XZ:P0[jn_0<;2`P2i^KT00P2j^[X01`38b<P0^;Rh0;Rh^03@d=00
`<300<K6aP2f][H00P3@d=001`2f][H0cLg=0<;2`P36a/H0[jn_0;fm_@36a/H00P34a<@01`37alL0
][Jf0<;2`P32`/80^KVi0;Fe]@30`<000P2h^;P01@2YZJT0Zj^[0;bl_02^[Zh0_;bl0080`/;20P2i
^KT01`3<c<`0^k^k0=3@d038b<P0_kno0=;BdP2o_kl00P3<c<`01`2g]kL0a<C40;6a/@34a<@0/K6a
0:NWY`2h^;P00P2k^k/01`34a<@0Y:BT0;Vi^@3@d=00]KFe0=SHf02k^k/00P3MgMd01`30`<00^KVi
0<_;b`2m_Kd0`L710<;2`P37alL00P3:b/X01`32`/80WYjN0<71`@3?cll0[Jf]0<?3``2_[jl00`2o
_kl01P32`/80bLW90<o?c`2m_Kd0e]KF0<;2`P80^KVi00L0[Jf]0;Ng]`30`<00`<300<[:bP2a/K40
_Kfm0080e]KF00L0c/k>0<K6aP2i^KT0^;Rh0;^k^`2l_;`0cLg=0080`<3000L0YJFU0<W9b@3:b/X0
`<300<C4a03AdM40f][J0080clo?00@0/k>c0<K6aP3Fe]H0e]KF903oool00`1VXol0ec?o06JSo`0>
0=Lco`80IZ?o4@3G<ol00`1VXol0ec?o0=Lco`0;0=Lco`80IZ?o00<0ec?o06JSo`3G<ol03`3G<ol0
101VXol0ec?o06JSo`1VXol40=Lco`0306JSo`3G<ol0ec?o00l0ec?o00H0IZ?o0=Lco`3G<ol0IZ?o
0=Lco`1VXol;0=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol02P3G<ol00`1VXol0
ec?o0=Lco`0:0=LcobL0oooo000U0?ooo`030:NWY`2i^KT0[Jf]0080^[Zj00<0`/;20=?Cd`2j^[X0
0P36a/H02`30`<00`/;20;jn_P2n_[h0`/;20;no_`31`L40Z:RX0:n_[`32`/80^KVi0080^[Zj00L0
b<S80;Rh^02h^;P0d=3@0<30`036a/H0][Jf0080d=3@00L0][Jf0<g=c@32`/80a/K60:n_[`2m_Kd0
a/K60080a<C400L0alO70;Jf]P32`/80`/;20;Vi^@2e]KD0`<300080^;Rh00D0ZJVY0:^[Z`2l_;`0
[Zj^0;bl_0020<;2`P80^KVi00L0c<c<0;^k^`3@d=00b<S80;no_`3Bd]80_kno0080c<c<00L0]kNg
0<C4a02a/K40a<C40;6a/@2WYjL0^;Rh0080^k^k00L0a<C40:BTY02i^KT0d=3@0;Fe]@3Hf=P0^k^k
0080gMgM00L0`<300;Vi^@3;bl/0_Kfm0<71`@32`/80alO70080b/[:00L0`/;209jNWP31`L40clo?
0:f][@33`l<0[jn_00<0_kno00H0`/;20<W9b@3?cll0_Kfm0=KFeP32`/820;Vi^@070:f][@2g]kL0
`<300<30`03:b/X0/K6a0;fm_@020=KFeP070<k>cP36a/H0^KVi0;Rh^02k^k/0_;bl0<g=c@020<30
`0070:FUY@39bLT0b/[:0<30`034a<@0dM7A0=[JfP020<o?c`040;>c/`36a/H0e]KF0=KFeR@0oooo
00<0IZ?o0=Lco`1VXol03P3G<ol206JSoa40ec?o00<0IZ?o0=Lco`3G<ol02`3G<ol206JSo`030=Lc
o`1VXol0ec?o00l0ec?o00@0IZ?o0=Lco`1VXol0IZ?o103G<ol00`1VXol0ec?o0=Lco`0?0=Lco`06
06JSo`3G<ol0ec?o06JSo`3G<ol0IZ?o2`3G<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0
ec?o00X0ec?o00<0IZ?o0=Lco`3G<ol02P3G<olW0?ooo`009@3oool00`34a<@0a/K60<30`0020;bl
_0070<W9b@3>c/h0^;Rh0<;2`P3Bd]80_[jn0:^[Z`030;Rh^0060:j^[P31`L40_Kfm0<g=c@32`/80
a<C40P36a/H01`32`/80^;Rh0:FUY@2m_Kd0b/[:0<K6aP2o_kl00`36a/H01P2l_;`0bl_;0<C4a02k
^k/0]kNg0<C4a080b/[:00L0^k^k0<;2`P36a/H0b<S80<;2`P2e]KD0b<S80080bLW900L0^k^k0820
P03@d=00XZ:R0:f][@2n_[h0`/;20080_Kfm00L0a/K60<C4a02o_kl0`/;20;Vi^@3>c/h0YjNW0080
`<3000L0ZJVY0<c<c02_[jl0_kno0<;2`P2_[jl0^k^k0080[jn_00L0`<300<c<c02RXZ80d=3@0<30
`034a<@0`/;20080ZJVY00L0][Jf0:^[Z`2o_kl0bLW90<O7a`3De=@0d];B0080b<S800L0a<C40<c<
c02m_Kd0];Bd0<C4a02f][H0_kno00<0`/;200H0_kno0=CDe02o_kl0bl_;0;Vi^@36a/H20;^k^`07
0;Fe]@36a/H0a<C40<W9b@31`L40f=SH0<_;b`020=SHf0070<c<c03Bd]80]KFe0<K6aP2i^KT0a/K6
0<S8b0020;Vi^@070<K6aP3;bl/0[Zj^0;Jf]P3Ph>00g]kN0<k>cP020<o?c`040<k>cP30`<00a/K6
0<?3`b@0oooo2`3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o00T0ec?o00<0IZ?o0=Lco`3G<ol05`3G
<ol0101VXol0ec?o06JSo`1VXol:0=Lco`0606JSo`3G<ol0ec?o06JSo`3G<ol0IZ?o0P3G<ol0101V
Xol0ec?o06JSo`1VXol20=Lco`0306JSo`3G<ol0ec?o0080ec?o0P1VXol00`3G<ol0IZ?o0=Lco`0/
0=Lco`0306JSo`3G<ol0ec?o00P0ec?o9`3oool002D0oooo00<0`/;20<_;b`34a<@00P3;bl/01`2m
_Kd0]KFe0;bl_037alL0d=3@0;fm_@35aLD00P2n_[h01`2l_;`0^;Rh0;Zj^P37alL0[jn_0;^k^`3=
cLd00P2d];@01`30`<00_Kfm0<K6aP2i^KT0^k^k0<30`02YZJT00`34a<@01P32`/80c/k>0<[:bP2a
/K40a/K60<30`080a/K600L0ZZZZ0;>c/`3WinL0c/k>0<[:bP3?cll0emOG0080gmoO00L0hN7Q0<K6
aP38b<P0[jn_0<c<c038b<P0c/k>0080emOG00L0`<300;Bd]02m_Kd0`/;20;Fe]@36a/H0bLW90080
^k^k00L0_Kfm0;Rh^02f][H0YjNW0;^k^`2a/K40[jn_0080`/;200L0f][J0<30`02RXZ80YjNW0:2P
X02g]kL0a/K60080^[Zj00L0_Kfm0<K6aP36a/H0b/[:0;Ng]`2YZJT0_kno0080b<S800D0`/;20;fm
_@3=cLd0`L710:f][@020<;2`P80^k^k00H0a<C40<;2`P32`/80^KVi0<C4a038b<P30<K6aP070;jn
_P30`<00b/[:0>KViP2o_kl0d];B0<[:bP020;fm_@070<[:bP2_[jl0a/K60<k>cP2o_kl0`L710<;2
`P020;Rh^0070>CTi038b<P0_;bl0:VYZ@20P800^KVi0<S8b0020<K6aP040<30`032`/80e=CD0<S8
b2@0oooo4P3G<ol00`1VXol0ec?o0=Lco`080=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lc
o`3G<ol00P3G<ol00`1VXol0ec?o0?l000090=Lco`0306JSo`3G<ol0ec?o00l0ec?o00@0IZ?o0=Lc
o`1VXol0IZ?o103G<ol306JSo`T0ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lco`0>
0=Lco`030?l0003G<ol0ec?o00@0ec?o00<0IZ?o0=Lco`3G<ol0203G<ol206JSo`P0ec?o9`3oool0
02D0oooo00<0_Kfm0;bl_030`<000P2f][H01`2YZJT0]KFe0<C4a03AdM40d];B0;Fe]@2d];@00P2g
]kL20<K6aP050<O7a`34a<@0f=SH0=_Kf`3?cll00P2_[jl01`3<c<`0^k^k0;Ng]`34a<@0`/;20;bl
_03>c/h00P36a/H01`2g]kL0_kno0:n_[`30`<00_Kfm0<[:bP36a/H00`3?cll01P32`/80bl_;0>[Z
jP2o_kl0clo?0:n_[`80c/k>00L0d=3@0;^k^`2c/k<0b/[:0:VYZ@2^[Zh0f][J0080`<3000L0^;Rh
0;:b/P38b<P0^KVi0<_;b`2f][H0V9RH0080b<S800L0/k>c0;fm_@3:b/X0b/[:0:VYZ@2l_;`0^[Zj
0080_Kfm00L0alO70;Rh^02k^k/0/k>c0=?Cd`2g]kL0a/K60080^k^k00D0`<300;no_`2e]KD0^k^k
0;fm_@020<;2`P80`<3000L0[jn_0:j^[P3Bd]80];Bd0:NWY`2][Jd0`/;200<0_kno00H0Zj^[0;Fe
]@2o_kl0d];B0=CDe02m_Kd20<K6aP070;Fe]@2n_[h0/[:b0<30`02_[jl0f=SH02@T90020<g=c@07
0;Zj^P2h^;P0d];B0<S8b03:b/X0XZ:R0<;2`P020;Vi^@070;Jf]P2UYJD0bLW90;2`/032`/80clo?
0=WIf@020<C4a0040=3@d03AdM40b<S80<C4a2@0oooo1@3G<ol00`1VXol0ec?o0=Lco`0=0=Lco`80
IZ?o2`3G<ol00`1VXol0ec?o0=Lco`070=Lco`040?l0003G<ol0ec?o06JSo`H0ec?o0P1VXol40=Lc
o`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol0103G<ol00`1VXol0ec?o0=Lco`0D0=Lc
o`80IZ?o0P3G<ol206JSo`@0ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol01@1VXol0ec?o06JSo`3G<ol0
mOo<00L0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol00`1VXol0ec?o06JSo`090=LcobL0oooo000U0?oo
o`030;bl_02j^[X0aLG50080a<C400L0a/K60;Fe]@3@d=00/[:b0<;2`P2n_[h0cLg=0080bl_;00L0
^[Zj0<30`02o_kl0[jn_0;no_`3=cLd0];Bd0080]KFe00L0`L710<G5a@35aLD0_;bl0<C4a037alL0
^KVi0080_Kfm00L0_[jn0;Fe]@32`/80^k^k0=;BdP38b<P0c<c<0080b/[:00L0`<300?KfmP2o_kl0
/k>c0<C4a032`/80^k^k0080XZ:R00L0fMWI0;Ng]`3Hf=P0alO708n?S`3=cLd0^KVi0080^[Zj00L0
`/;20;Ng]`2n_[h0b<S80;Jf]P2j^[X0`<300080^[Zj00L0dm?C0:n_[`36a/H0]KFe0;Vi^@2e]KD0
`<300080WYjN00L0Kfm_09jNWP2[Zj/0c<c<0>KViP3=cLd0^KVi0080/k>c0P2o_kl01@3IfMT0a<C4
0=KFeP3Jf]X0`<300080/k>c00L0]kNg0;6a/@2[Zj/0_Kfm0;Rh^02k^k/0/k>c0080`/;200@0_Kfm
0<30`036a/H0bLW90P32`/801P2h^;P0`/;20<;2`P2m_Kd0a<C40<[:bP<0a<C400X0XZ:R0<[:bP3:
b/X0c<c<0<30`02WYjL0b<S80<30`03Bd]80a<C40P2c/k<01`3IfMT0_;bl0>7Qh@3Ogml0a/K60=gM
g@32`/80103?cll00`36a/H0hN7Q0?ooo`0S0?ooo`P0ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol00`1V
Xol0ec?o0=Lco`0F0=Lco`030?l0003G<ol0ec?o00<0ec?o0P1VXol40=Lco`0306JSo`3G<ol0ec?o
00`0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol206JSo`0509Wo`P1VXol0IZ?o0=Lco`3o00003P3G<ol2
06JSoaD0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol00`1VXol0ec?o0=Lco`0A0=LcobL0oooo000U0?oo
o`030;Rh^03=cLd0`<300080]kNg00L0/[:b0<_;b`3Bd]80^[Zj0<30`032`/80Zj^[0080cLg=00L0
a/K60<;2`P2d];@0_[jn0<W9b@2m_Kd0[Jf]0080_[jn00L0^;Rh0<;2`P2h^;P0_kno0<71`@2m_Kd0
^k^k00@0a<C400D0d=3@0<_;b`3>c/h0b<S80<G5a@020<K6aP070;Bd]02^[Zh0]KFe0;no_`34a<@0
`/;20:BTY0020=KFeP070;no_`2BTY80`<300;Bd]02/[:`0b/[:0;Jf]P020<C4a0070;bl_03;bl/0
bLW90=WIf@2e]KD0];Bd0<K6aP020<;2`P040<K6aP2WYjL0a<C40;jn_P80];Bd00X0/;2`0;Bd]02d
];@0`L710<C4a03Hf=P0WinO09BDU02][Jd0`<300P2j^[X0102d];@0`<300;Vi^@34a<@20;bl_006
0<c<c035aLD0aLG50<C4a02k^k/0`<300P2m_Kd02`2][Jd0/k>c0<S8b038b<P0Y:BT0:^[Z`3<c<`0
`/;20<W9b@2j^[X0d];B0080a/K600L0b<S80;bl_03Kfm/0e]KF0=3@d02/[:`0b/[:0080`/;200L0
`<300;fm_@2k^k/0^k^k0=;BdP39bLT0^[Zj0080ZJVY00L0/[:b0;Rh^03@d=00ZZZZ0;no_`3Fe]H0
c/k>0080d];B00@0a<C40=KFeP3=cLd0^KVi903oool50=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0
IZ?o0=Lco`3G<ol01P3G<ol00`1VXol0ec?o0=Lco`0C0=Lco`0306JSo`3G<ol0ec?o0080ec?o00D0
IZ?o0=Lco`3G<ol0ec?o06JSo`020=Lco`0306JSo`3G<ol0ec?o00`0ec?o00<0IZ?o0=Lco`3G<ol0
0P3G<ol00`1VXol0ec?o0=Lco`030=Lco`<0IZ?o4@3G<ol0101VXol0ec?o0=Lco`3G<ol206JSo``0
ec?o00<0IZ?o0=Lco`3G<ol0203G<ol306JSo`80ec?o00<0IZ?o0=Lco`3G<ol01`3G<olW0?ooo`00
9@3oool00`2[Zj/0clo?0<C4a0020;fm_@030;:b/P37alL0_Kfm0080`<3000D0]KFe0<S8b03AdM40
dM7A0<O7a`020;^k^`040;Fe]@32`/80_Kfm0<S8b080];Bd00@0[Jf]0<30`02b/[80`L710P35aLD0
2P2k^k/0alO70<O7a`2m_Kd0_kno0<c<c032`/80b<S80<30`02o_kl30=;BdP060;Zj^P2YZJT0]kNg
0<k>cP2>SXh0b<S80P2LW9`01`2g]kL0Zj^[0<o?c`3AdM40]KFe0=3@d02`/;000P2d];@01`2l_;`0
gMgM0<;2`P2l_;`0Xj>S0<30`02_[jl00P2c/k<01`32`/80_Kfm0;^k^`2i^KT0]KFe0:n_[`34a<@0
0P38b<P01`36a/H0][Jf0<30`037alL0^k^k0<C4a02a/K400P2o_kl01`2n_[h0];Bd0;^k^`2g]kL0
_[jn09>CT`38b<P00P3:b/X01`32`/80d=3@0;fm_@34a<@0^k^k0<71`@2m_Kd00P3:b/X01`32`/80
a/K60;fm_@32`/80cLg=0<_;b`3Fe]H00P3:b/X01`2[Zj/0e=CD0<K6aP2i^KT0alO70<71`@2b/[80
0P2k^k/01`3;bl/0_;bl0<C4a03Hf=P0a/K60=GEe@3MgMd00P3@d=001`2k^k/0]KFe0<_;b`3=cLd0
g]kN0=SHf038b<P00P32`/80103@d=00YJFU0;:b/P3:b/XT0?ooo`0306JSo`3G<ol0ec?o0080ec?o
00<0IZ?o0=Lco`3G<ol03`3G<ol00`1VXol0ec?o06JSo`0A0=Lco`0506JSo`3G<ol0ec?o06JSo`3G
<ol00P1VXol00`3G<ol0IZ?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lco`1V
Xol01`3G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lco`3G
<ol04`3G<ol00`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0ec?o01<0ec?o0P1VXol00`3G<ol0
oooo0?ooo`0U0?ooo`009@3oool00`2j^[X0/[:b0;:b/P020:j^[P070;Bd]030`<00^;Rh0<C4a032
`/80c<c<0:n_[`020<o?c`070<30`038b<P0a/K60;^k^`32`/80^k^k0:^[Z`020;Fe]@070<K6aP35
aLD0a/K60<30`032`/80clo?0;^k^`020;>c/`070;bl_03=cLd0clo?0;^k^`2c/k<0_kno0=;BdP02
0<_;b`050<30`02m_Kd0a/K60;Fe]@30`<000P2i^KT20;Rh^0070=OGe`36a/H0bl_;0<S8b03<c<`0
`<300;Ng]`020<30`0070=GEe@2m_Kd0b<S80<c<c02c/k<0^k^k0<;2`P020;fm_@070<C4a02n_[h0
a<C40=SHf02m_Kd0[jn_09>CT`0209jNWP070=?Cd`2e]KD0^k^k0<S8b03@d=00]kNg0;no_`020<30
`0070<C4a02o_kl0`<300<;2`P3:b/X0dM7A0::RXP020<k>cP070<S8b02m_Kd0`<300<;2`P2g]kL0
c/k>0=SHf0020<K6aP070;no_`3<c<`0d=3@0<O7a`2^[Zh0[jn_0;^k^`020<C4a0070;>c/`3;bl/0
_kno0<g=c@30`<00Xj>S0=;BdP020;2`/0070;fm_@3IfMT0f=SH0<c<c038b<P0a<C40<c<c0020;fm
_@070;^k^`36a/H0`/;20;Jf]P2BTY80_Kfm0<30`0020;Vi^@030=CDe03;bl/0XJ6Q02D0oooo00<0
ec?o06JSo`1VXol00P1VXol60=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol0<P3G
<ol406JSo`l0ec?o00<0IZ?o0=Lco`3G<ol03@3G<ol206JSo`P0ec?o00@0IZ?o0=Lco`1VXol0IZ?o
3@3G<ol00`1VXol0ec?o0=Lco`040=Lco`0306JSo`3o0000oooo02H0oooo000U0?ooo`030=3@d02=
SHd0_kno0080bLW900H0]kNg0;fm_@36a/H0_kno0;Bd]032`/830;Jf]P070<;2`P2l_;`0`/;20;jn
_P2i^KT0];Bd0<S8b0020<c<c0070<C4a02UYJD0a/K60;Zj^P30`<00`/;20<W9b@020;jn_P0409bL
W036a/H0`/;20<C4a080a/K600X0a<C40=;BdP3Bd]80]KFe0<[:bP2@T900`<300;jn_P3?cll0cLg=
0P3Bd]801`3<c<`0YJFU0<;2`P1eMGD0c<c<0<S8b02o_kl00P2i^KT01@2c/k<0a/K60<S8b03IfMT0
b/[:0080`/;20P2i^KT01`2b/[80`<300;^k^`2h^;P0][Jf0;2`/02m_Kd00P34a<@01`2k^k/0_Kfm
0<K6aP2o_kl0b/[:0;:b/P2j^[X00P2o_kl01`3;bl/0_;bl0<O7a`3Hf=P0dM7A0<W9b@2b/[800P3H
f=P01`2k^k/0_kno0;>c/`32`/80^KVi0;:b/P2/[:`00P2YZJT01`2a/K40c/k>0;fm_@32`/80clo?
0=WIf@3@d=000P36a/H00`3:b/X0`/;20<C4a0020;Fe]@0;0;fm_@3>c/h0]KFe0;Fe]@38b<P0bLW9
0=OGe`2a/K40b/[:0<C4a03Fe]H00P3>c/h01`1oOgl0_;bl0<;2`P30`<00c<c<0;Fe]@2g]kL00P3?
cll0102k^k/0`/;20<O7a`2KVi/T0?ooo`030=Lco`1VXol0ec?o01D0ec?o00<0IZ?o0=Lco`3G<ol0
1@3G<ol00`1VXol0ec?o0=Lco`080=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lco`2Iol80
3P3G<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol0
1`3G<ol00`1VXol0ec?o0=Lco`050=Lco`D0IZ?o503G<ol00`1VXol0ec?o0=Lco`030=Lco`0309Wo
`P3G<ol0ec?o00T0ec?o00<0IZ?o0?ooo`3oool09@3oool002D0oooo00<0d=3@08f=S@2o_kl00P39
bLT01P2g]kL0_Kfm0<K6aP2o_kl0];Bd0<;2`P<0][Jf00L0`/;20;bl_032`/80_[jn0;Vi^@2d];@0
b<S80080c<c<00L0a<C40:FUY@36a/H0^[Zj0<30`032`/80bLW90080_[jn00@0W9bL0<K6aP32`/80
a<C40P36a/H02P34a<@0d];B0=;BdP2e]KD0b/[:092@T030`<00_[jn0<o?c`3=cLd20=;BdP070<c<
c02UYJD0`/;207EeM@3<c<`0b<S80;no_`020;Vi^@050;>c/`36a/H0b<S80=WIf@3:b/X00P32`/82
0;Vi^@070;:b/P30`<00^k^k0;Rh^02f][H0/;2`0;fm_@020<C4a0070;^k^`2m_Kd0a/K60;no_`3:
b/X0/[:b0;Zj^P020;no_`070<_;b`2l_;`0alO70=SHf03AdM40bLW90;:b/P020=SHf0070;^k^`2o
_kl0/k>c0<;2`P2i^KT0/[:b0:b/[0020:VYZ@070;6a/@3>c/h0_Kfm0<;2`P3?cll0fMWI0=3@d002
0<K6aP030<[:bP32`/80a<C40080]KFe00/0_Kfm0<k>cP2e]KD0]KFe0<S8b039bLT0emOG0;6a/@3:
b/X0a<C40=KFeP020<k>cP0707moO`2l_;`0`/;20<30`03<c<`0]KFe0;Ng]`020<o?c`040;^k^`32
`/80alO709^KVb@0oooo00<0ec?o06JSo`3G<ol05@3G<ol00`1VXol0ec?o0=Lco`050=Lco`0306JS
o`3G<ol0ec?o00P0ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o09Wo`P0>0=Lco`0306JS
o`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JS
o`3G<ol0ec?o00D0ec?o1@1VXolD0=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0VOo20=Lco`3G<ol0
2@3G<ol00`1VXol0oooo0?ooo`0U0?ooo`009@3oool00`34a<@0bl_;0<S8b0020;^k^`070;fm_@2g
]kL0a<C40<K6aP34a<@0][Jf0:NWY`020;:b/P070;jn_P2c/k<0_kno0<;2`P3?cll0];Bd0<k>cP02
0;>c/`040<30`02k^k/0clo?0<C4a080^k^k0`36a/H01`2SXj<0^[Zj0<K6aP38b<P0a<C40<K6aP3:
b/X00P3IfMT0102o_kl0e=CD0;^k^`3Cdm<20;^k^`0:0=;BdP34a<@0a<C40<;2`P2][Jd0a/K60<O7
a`2e]KD0c<c<0<k>cP80[Jf]00L0_;bl0<o?c`3De=@0Zj^[0;^k^`2o_kl0/[:b0080[Jf]00L0][Jf
0;2`/02g]kL0/K6a04e=C@2a/K40]KFe0080`/;200L0bl_;0;:b/P2b/[80/;2`0;no_`2g]kL0_Kfm
0080iNGU00L0YJFU0<30`02f][H0^[Zj0:j^[P2o_kl0`/;20080_Kfm00L0a<C40<;2`P35aLD0b<S8
0<G5a@2i^KT0b<S80080[Zj^00L0_Kfm0:n_[`2[Zj/0Y:BT0;no_`2d];@0_kno0080b<S800L0[Jf]
0<S8b036a/H0cLg=0=;BdP2h^;P0`<300080dm?C00L0c<c<0<K6aP30`<00d=3@0:f][@3Bd]80^KVi
0080]KFe00L0b<S80<k>cP2c/k<0VYZJ0<;2`P3Fe]H0`/;20080];Bd00@0f=SH0::RXP2k^k/0Zj^[
903oool;0=Lco`<0IZ?o4P3G<ol00`1VXol0ec?o0=Lco`0@0=Lco`0306JSo`3G<ol0ec?o00<0ec?o
0P1VXol30=Lco`0306JSo`3G<ol0ec?o00<0IZ?o00H0ec?o06JSo`3G<ol0IZ?o09Wo`P1VXol40=Lc
o`<0IZ?o1@3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o00/0ec?o0P1VXol0103G<ol0IZ?o06JSo`1V
Xol50=Lco`0306JSo`3G<ol0ec?o00X0ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lc
o`040=Lco`0306JSo`3G<ol0IZ?o02L0oooo000U0?ooo`030;bl_031`L40_kno0080/k>c00H0];Bd
0<30`02g]kL0c<c<0<[:bP3>c/h30<S8b080a<C400@0`/;20<c<c03Cdm<0^[Zj0`2e]KD01`3?cll0
_kno0<30`030`<00a<C40;^k^`2n_[h00P3=cLd01`34a<@0_kno0;fm_@34a<@0b/[:0;Ng]`3@d=00
0P38b<P01`2d];@0_;bl0;Vi^@2m_Kd0/k>c0<S8b030`<000P2k^k/01`2LW9`0_Kfm08R8R03?cll0
^KVi0<[:bP2l_;`00P39bLT01P34a<@0/K6a0<30`02e]KD0_;bl0:2PX0<0^[Zj00L0_;bl0;Jf]P32
`/80]KFe09VIV@2g]kL0e=CD0080Y:BT00L0`/;20<_;b`2l_;`0XZ:R0;Jf]P3MgMd0/;2`0080`/;2
00<0e]KF0:NWY`2g]kL00P2b/[802`3GemL0b<S80:BTY02TY:@0c<c<0=KFeP2][Jd0dM7A09:BTP2o
_kl0^;Rh0080a/K600L0^k^k0<k>cP2g]kL0^k^k0<30`03AdM40m?Cd0080a<C400L0^;Rh0;jn_P3=
cLd0d=3@0;fm_@3Bd]80[Zj^0080_;bl00L0a/K60<O7a`32`/80clo?0=KFeP2e]KD0fMWI0080XJ6Q
00L0b/[:0<c<c039bLT0a<C40:^[Z`36a/H0eMGE0080e=CD00@0a/K604=3@`2a/K40clo?903ooolb
0=Lco`0306JSo`3G<ol0IZ?o00L0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`070=Lco`0306JSo`3G
<ol0ec?o0080IZ?o0`3G<ol0101VXol0ec?o0=Lco`1VXol30=Lco`0406JSo`3G<ol0IZ?o06JSo`80
ec?o0P1VXol20=Lco`0306JSo`3G<ol0IZ?o00X0ec?o00<0o`000=Lco`3G<ol01P3G<ol00`1VXol0
ec?o0=Lco`070=Lco`80IZ?o103G<ol00`1VXol0ec?o0=Lco`030=Lco`030?Goc01VXol0ec?o02L0
oooo000U0?ooo`030=?Cd`2n_[h0/;2`0080hn?S00L0]kNg0<W9b@2l_;`0a<C40<30`039bLT0a/K6
00<0`/;200H0bLW90<30`030`<00a/K60<O7a`2o_kl20;6a/@070<S8b036a/H0cLg=0<W9b@2g]kL0
_[jn0<71`@020<k>cP070;fm_@2o_kl0b<S80<[:bP2m_Kd0^k^k0<[:bP020<;2`P030<C4a03Cdm<0
/K6a0080^KVi00/0d=3@0;Fe]@2o_kl0_kno0<c<c02i^KT0alO70<W9b@2[Zj/0b<S80<C4a0020;:b
/P070<_;b`34a<@0^k^k0;Vi^@2MWId0XJ6Q0:f][@020<;2`P070<K6aP2g]kL0^KVi0;2`/02YZJT0
Zj^[0;:b/P020<K6aP070<C4a030`<00c/k>0:b/[03Hf=P0`<300<W9b@020<_;b`070<o?c`2j^[X0
emOG0<[:bP3@d=00_[jn0=OGe`020=SHf0070<[:bP3;bl/0cLg=0<30`03=cLd0_Kfm0<K6aP020=KF
eP040<30`02c/k<0a<C40<c<c080a/K600X0_[jn0<C4a034a<@0a/K60<g=c@3MgMd0`<300;Zj^P2^
[Zh0`<300P2h^;P01`3?cll0ZJVY0<S8b033`l<0];Bd0<c<c02m_Kd00P38b<P01`30`<00d=3@0;^k
^`2i^KT0/[:b0;^k^`36a/H00P2b/[80101OGel0Ng]k0<O7a`34a<@T0?ooo`80ec?o00<0IZ?o0=Lc
o`3G<ol0403G<ol206JSoa@0ec?o00<0IZ?o0=Lco`3G<ol0203G<ol00`1VXol0ec?o0=Lco`0206JS
o`@0ec?o0`1VXol50=Lco`@0IZ?o1@3G<ol00`1VXol0ec?o0=Lco`0S0=Lco`0306JSo`3G<ol0ec?o
0080ec?o00<0IZ?o0=Lco`3G<ol02@3G<ol00`1VXol0ec?o0=Lco`0206JSo`80VOo20P3G<olW0?oo
o`009@3oool00`2k^k/0_;bl0;Fe]@020;fm_@070;no_`39bLT0/k>c0;:b/P2k^k/0bl_;0;Ng]`02
0;^k^`070<g=c@2j^[X0^KVi0=CDe03Cdm<0alO70:n_[`030;Ng]`060<o?c`33`l<0`<300<C4a02o
_kl0_[jn0P32`/801`3;bl/0^KVi0<W9b@3Bd]80^KVi0;bl_03Bd]800P3:b/X01`2n_[h0X:2P0<O7
a`3;bl/0^;Rh0<c<c032`/800P36a/H01P3?cll0b<S80<W9b@2UYJD0];Bd0<k>cP<0`<3000L0[jn_
0;no_`32`/80_Kfm0;Ng]`2i^KT0/K6a00<0^k^k00H0]KFe0:n_[`30`<00cLg=0:2PX02o_kl20;Vi
^@070<S8b02m_Kd0`/;20=3@d032`/80_;bl0=?Cd`020:VYZ@070<;2`P3GemL0[jn_0;Fe]@3Bd]80
d=3@0;^k^`020=;BdP040;fm_@2QXJ40alO70<G5a@80[Zj^00X0^KVi0;^k^`2k^k/0`/;20;^k^`38
b<P0fMWI0=;BdP38b<P0dm?C0P2f][H01`35aLD0];Bd0<S8b032`/80`<300;Jf]P2c/k<00P2b/[80
1`2k^k/0d=3@0<30`039bLT0alO70:FUY@32`/800P3?cll01P3EeMD0_;bl0:VYZ@2_[jl0^;Rh0=CD
e0<0][Jf00@0_kno0;:b/P2m_Kd0`<30903oool80=Lco`0306JSo`3G<ol0ec?o00T0ec?o00<0IZ?o
0=Lco`3G<ol04`3G<ol00`1VXol0ec?o0=Lco`080=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o
0=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`020=Lco`0406JSo`3G<ol0ec?o06JSo`X0ec?o0P1V
Xol20=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lco`3G<ol00P1VXolC0=Lco`80IZ?o1@3G
<ol00`1VXol0ec?o0=Lco`030=Lco`80IZ?o1P3G<ol00`1VXol0ec?o0=Lco`0W0?ooo`009@3oool0
0`2e]KD0_kno0<O7a`020;fm_@070;Ng]`31`L40`l?30;Ng]`35aLD0d];B0<?3``020=CDe0030<W9
b@2n_[h0alO70080cLg=0P2o_kl20<C4a0060;bl_036a/H0][Jf0<C4a02i^KT0`/;20`2k^k/01`37
alL0_;bl0;2`/03:b/X0a/K60<o?c`36a/H00P35aLD01`3@d=00]kNg0=;BdP2e]KD0_kno0<W9b@2R
XZ800P30`<001`2`/;00];Bd0<W9b@31`L40/K6a0:NWY`2BTY800P2k^k/00`2][Jd0Y:BT0;Fe]@02
0;^k^`0;0<;2`P2m_Kd0TY:B09:BTP37alL0c/k>0;Ng]`2`/;00];Bd0;2`/032`/800P38b<P01`2c
/k<0a/K60<[:bP2a/K40/k>c0;bl_03Bd]800P3EeMD01`2b/[80_Kfm0<C4a02g]kL0a/K60;^k^`39
bLT00P36a/H01`2m_Kd0/k>c0:n_[`2][Jd0hn?S0<;2`P2k^k/00P2JVYX01P3<c<`0Zj^[0<?3``3G
emL0a<C409bLW0<0alO700L0^k^k0<30`036a/H0]kNg0:NWY`2i^KT0];Bd0080^[Zj00L0b<S80=GE
e@2`/;00^[Zj0<[:bP1jNWX0`L710080dm?C0P2g]kL01@3<c<`0_[jn0;Ng]`2m_Kd0^k^k0080clo?
00@0b/[:0;Ng]`32`/80/K6a903ooolR0=Lco`0306JSo`3G<ol0ec?o00X0ec?o00@0IZ?o0=Lco`3G
<ol0IZ?o0`3G<ol306JSo`80ec?o0P1VXol50=Lco`80IZ?o0`3G<ol00`1VXol0ec?o06JSo`060=Lc
o`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol0203G<ol206JSo`<0ec?o0P1VXol00`3G
<ol0IZ?o0=Lco`020=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol0101V
Xol0ec?o0=Lco`2Iol8?0=Lco`0306JSo`3oool0oooo02D0oooo000U0?ooo`030;Bd]02[Zj/0aLG5
0080[Jf]00L0a<C40<K6aP2UYJD0a/K60<S8b031`L40`/;20080clo?00L0bLW90;fm_@3;bl/0bLW9
0;jn_P2[Zj/0clo?0080aLG500<0^k^k0;Zj^P2l_;`00`32`/802P2h^;P0];Bd0;Bd]036a/H0][Jf
0;Vi^@2o_kl0^;Rh0;no_`38b<P20<[:bP070<g=c@2i^KT0alO70<?3``2k^k/0f=SH0<;2`P020<G5
a@030;Jf]P3=cLd0dm?C0080^k^k00/0_kno0<k>cP3:b/X0b/[:0;fm_@2h^;P0_Kfm0<K6aP2i^KT0
a<C40<S8b0020<W9b@070<30`02k^k/0_kno0=GEe@30`<00[jn_0:^[Z`020;:b/P070<K6aP38b<P0
^KVi0<30`02i^KT0cLg=0<O7a`020;Vi^@070:n_[`32`/80_kno0<o?c`3@d=00a<C40;Zj^P020<[:
bP050<K6aP2e]KD0^KVi0=gMg@2[Zj/00P2g]kL20<O7a`070=GEe@38b<P0];Bd0<K6aP37alL0`<30
0<S8b0020<C4a0070<[:bP3>c/h0^[Zj0<K6aP38b<P0b/[:0=?Cd`020;jn_P070=SHf02m_Kd0[jn_
0<C4a036a/H0cLg=0=KFeP020>7Qh@070<S8b03Fe]H0a<C40=GEe@2b/[80Z:RX0<O7a`020<C4a004
0<30`038b<P0`/;20<;2`R@0oooo00<0ec?o06JSo`3G<ol00P1VXol20=Lco`0306JSo`3G<ol0ec?o
00T0ec?o00<0IZ?o0=Lco`3G<ol0<`3G<ol406JSo`T0ec?o00<0IZ?o0=Lco`3G<ol02P3G<ol00`1V
Xol0ec?o0=Lco`0F0=Lco`0306JSo`3G<ol0ec?o00P0ec?o0P1VXol70=LcobL0oooo000U0?ooo`03
0<30`035aLD0`l?30080`L7100L0];Bd0;^k^`2e]KD0b<S80<;2`P2_[jl0][Jf00<0`<3000H0`L71
0;bl_02o_kl0`L710<_;b`2m_Kd20<S8b0070:>SX`32`/80alO70<G5a@2e]KD0d=3@0<71`@020;Jf
]P070<C4a030`<00a<C40;jn_P2k^k/0`<300<?3``020=;BdP070<[:bP34a<@0ZJVY0<30`02a/K40
`<300;Fe]@020;no_`070:j^[P33`l<0][Jf0<;2`P2h^;P0];Bd0;bl_0020<g=c@070<;2`P2_[jl0
clo?0;6a/@2e]KD0_Kfm0<71`@020;fm_@070=3@d02YZJT0a/K60<_;b`32`/80Q8B40;Rh^0020;Jf
]P050:b/[02g]kL0X:2P0<_;b`2n_[h00P2i^KT20:BTY0070<S8b036a/H0^k^k0<c<c02k^k/0e]KF
0:^[Z`020;no_`070<;2`P30`<00[Jf]0:f][@2TY:@0a<C40;jn_P020<71`@070<S8b02i^KT0UiNG
0<K6aP3<c<`0X:2P0:^[Z`020<c<c0070<o?c`32`/80emOG0<30`034a<@0clo?0;Ng]`020=3@d007
0<[:bP3Bd]80`/;20>OWi`32`/80];Bd0;fm_@030<_;b`060<g=c@2g]kL0a<C40=;BdP2d];@0`<30
0P38b<P0103<c<`0^KVi0<_;b`2n_[hT0?ooo`X0ec?o00<0IZ?o0=Lco`3G<ol02P3G<ol00`1VXol0
ec?o0=Lco`0A0=Lco`0306JSo`3G<ol0IZ?o00@0ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol00`1VXol0
ec?o06JSo`060=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol00`3G<ol00`1VXol0ec?o06JSo`040=Lc
o`80IZ?o1P3G<ol00`1VXol0ec?o0=Lco`020=Lco`<0IZ?o1P3G<ol00`1VXol0ec?o0=Lco`0206JS
o`h0ec?o00<0o`000=Lco`3G<ol0403G<olW0?ooo`009@3oool00`2i^KT0e]KF0<W9b@020;fm_@07
0;Ng]`35aLD0a/K60<;2`P3<c<`0^[Zj0;fm_@020;Ng]`070:NWY`2i^KT0a<C40;Ng]`39bLT0][Jf
0;no_`020;^k^`070;fm_@2a/K40^k^k0<71`@37alL0aLG50<C4a0020<_;b`070<K6aP38b<P0a/K6
0;bl_02/[:`0^;Rh0;Fe]@020;jn_P070<g=c@30`<00Ti>C0<S8b02IVIT0_Kfm0<30`0020<?3``07
0<G5a@3=cLd0/;2`0;Jf]P36a/H0`/;20;Zj^P020:VYZ@070:2PX02e]KD0^k^k0;no_`2LW9`0`l?3
0<71`@020<30`0070;Vi^@34a<@0`/;20;Rh^02i^KT0a<C40;Zj^P020=;BdP070<C4a02WYjL0d];B
0<c<c036a/H0_Kfm0;Fe]@020<[:bP070;fm_@36a/H0b<S80<;2`P3De=@0d];B0<C4a0020<K6aP07
0<C4a02o_kl0^KVi0;Ng]`34a<@0_Kfm0;Vi^@020;^k^`070<?3``2d];@0[jn_0;Zj^P2NWYh0/K6a
0<;2`P020<30`0070;jn_P34a<@0dM7A0=CDe03:b/X0PH610=KFeP020=3@d0070<W9b@32`/80`l?3
0<c<c03@d=00X:2P0;Fe]@0209jNWP070:VYZ@2l_;`0_Kfm0;jn_P2m_Kd0`/;20;Rh^0020=3@d004
0;Vi^@34a<@0c<c<0=[JfR@0oooo3P3G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JSo`3G<ol0ec?o
00T0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol00`1VXol0ec?o06JSo`060=Lco`0306JSo`3G<ol0ec?o
0080ec?o0`1VXol30=Lco`0306JSo`3G<ol0ec?o00`0ec?o00<0IZ?o0=Lco`3G<ol06@3G<ol0101V
Xol0ec?o06JSo`1VXol80=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`1VXol00P1VXol<
0=LcobL0oooo000U0?ooo`030;Vi^@3Fe]H0bLW90080_Kfm00L0]kNg0<G5a@36a/H0`/;20<c<c02j
^[X0_Kfm0080]kNg00L0YjNW0;Vi^@34a<@0]kNg0<W9b@2f][H0_kno0080^k^k00L0_Kfm0;6a/@2k
^k/0`L710<O7a`35aLD0a<C40080bl_;00L0a/K60<S8b036a/H0_;bl0:b/[02h^;P0]KFe0080_[jn
00L0cLg=0<30`02CTi<0b<S809VIV@2m_Kd0`<300080`l?300L0aLG50<g=c@2`/;00][Jf0<K6aP32
`/80^[Zj0080ZJVY00L0X:2P0;Fe]@2k^k/0_kno09bLW033`l<0`L710080`<3000L0^KVi0<C4a032
`/80^;Rh0;Vi^@34a<@0^[Zj0080d];B00L0a<C40:NWY`3Bd]80c<c<0<K6aP2m_Kd0]KFe0080b/[:
00L0_Kfm0<K6aP38b<P0`/;20=CDe03Bd]80a<C40080a/K600L0a<C40;no_`2i^KT0]kNg0<C4a02m
_Kd0^KVi0080^k^k00L0`l?30;Bd]02_[jl0^[Zj09jNWP2a/K40`/;20080`<3000L0_[jn0<C4a03A
dM40e=CD0<[:bP21PH40e]KF0080d=3@00L0bLW90<;2`P33`l<0c<c<0=3@d02PX:00]KFe0080WYjN
00L0ZJVY0;bl_02m_Kd0_[jn0;fm_@32`/80^;Rh0080d=3@00@0^KVi0<C4a03<c<`0f][J903oool>
0=Lco`0306JSo`3G<ol0ec?o00L0ec?o00<0IZ?o0=Lco`3G<ol02@3G<ol00`1VXol0ec?o0=Lco`04
0=Lco`0306JSo`3G<ol0IZ?o00H0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol306JSo`<0ec?o00<0IZ?o
0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`0I0=Lco`0406JSo`3G<ol0IZ?o06JSo`P0ec?o00<0
IZ?o0=Lco`3G<ol01P3G<ol00`1VXol0ec?o06JSo`0206JSo``0ec?o9`3oool002D0oooo00<0]kNg
0<W9b@2h^;P00P2h^;P01`36a/H0_;bl0;no_`31`L40]kNg0<;2`P2m_Kd00P2l_;`01`2YZJT0_Kfm
0;:b/P2i^KT0[:b/0;fm_@2d];@00P3@d=001`34a<@0d=3@0:n_[`2d];@0`<300<g=c@2m_Kd00P2i
^KT00`33`l<0_kno0;:b/P020;fm_@0;0;:b/P3;bl/0bl_;0<_;b`2g]kL0aLG50;Vi^@3;bl/0f=SH
0;no_`3GemL00P3@d=001`3IfMT0`/;20:NWY`2j^[X0`/;20;Jf]P2h^;P00P2i^KT01`2_[jl0^KVi
0;6a/@2k^k/0_Kfm0<C4a02f][H00P32`/801`39bLT0`/;20<30`033`l<0bLW90<30`02QXJ400P2_
[jl20<W9b@030:^[Z`3AdM40_[jn0080^k^k0P2m_Kd01`3Fe]H0e=CD0;fm_@2m_Kd0a/K60<_;b`2b
/[800P3>c/h01`30`<00^k^k0;Zj^P38b<P0Ng]k0;^k^`2i^KT00P2k^k/01`38b<P0hN7Q0<W9b@3A
dM40^k^k0<C4a032`/800P39bLT0102m_Kd0d=3@0;jn_P3Ogml20;>c/`040<K6aP2][Jd0[Jf]09ZJ
VP<0a/K600<0^k^k0<S8b03:b/X00P2m_Kd01`2g]kL0`<300<k>cP3>c/h0^k^k0;Ng]`32`/800P2k
^k/01030`<00a<C40=_Kf`32`/8T0?ooo`h0ec?o00D0IZ?o0=Lco`1VXol0ec?o06JSo`060=Lco`03
06JSo`3G<ol0ec?o00H0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o3P3G<ol00`1VXol0ec?o0=Lco`040=Lc
o`0306JSo`3G<ol0IZ?o00`0ec?o0`1VXol20=Lco`0306JSo`3G<ol0ec?o00X0ec?o00<0IZ?o0=Lc
o`3G<ol0103G<ol00`2Iol80ec?o0=Lco`0B0=Lco`<0IZ?o5@3G<olW0?ooo`009@3oool00`2`/;00
aLG50;Vi^@020;no_`030:RXZ02o_kl0`/;20080_Kfm00/0]KFe0;no_`2g]kL0]kNg0<G5a@2i^KT0
b/[:0;>c/`37alL0a<C40<K6aP020;Rh^0070<;2`P36a/H0cLg=0<W9b@2k^k/0clo?0<C4a0020<;2
`P070<C4a03AdM40a/K60;fm_@2c/k<0`/;20;no_`020<30`0050<O7a`3=cLd0`L710;Vi^@37alL0
0P2o_kl20:f][@070;6a/@3@d=00WYjN07inOP3@d=00ZJVY0;Jf]P020:n_[`070<S8b02_[jl0a<C4
0<W9b@35aLD0alO70<30`0020;Rh^0060;jn_P2m_Kd0c<c<0;Jf]P34a<@0a/K60`2o_kl01`2h^;P0
a/K60<;2`P34a<@0_kno0;fm_@2c/k<00P2i^KT01`2d];@0b/[:0<;2`P38b<P0[Jf]0=?Cd`34a<@0
0P2h^;P01`35aLD0_[jn0;jn_P2_[jl0a/K60;^k^`2i^KT00P39bLT01`3>c/h0_;bl0<_;b`38b<P0
`/;20<C4a03:b/X00`30`<001P2k^k/0^KVi0=;BdP2o_kl0`/;20;fm_@80a<C400L0b/[:08F5Q@38
b<P0dM7A0;Rh^01YJFT0^[Zj0080_kno00L0`/;20<k>cP39bLT0PH610;:b/P2WYjL0]KFe0080`/;2
00@0c/k>0<;2`P2c/k<0d];B903oool00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0ec?o02P0
ec?o0`1VXol01P3G<ol0IZ?o09Wo`P3G<ol0IZ?o0=Lco`80IZ?o00<0ec?o06JSo`3G<ol0703G<ol0
0`1VXol0ec?o0=Lco`050=Lco`0306JSo`3G<ol0ec?o01H0ec?o00D0IZ?o0=Lco`3G<ol0ec?o09Wo
`P060=Lco`<0IZ?o1`3G<olW0?ooo`009@3oool00`33`l<0Zj^[0<C4a0020;2`/0070<_;b`2f][H0
a/K60<C4a03@d=00a<C40;^k^`020;>c/`050<30`02h^;P0`<300;Vi^@37alL00P2j^[X20;Bd]007
0<K6aP2d];@0bLW90;Zj^P30`<00_;bl0;fm_@030<W9b@060<71`@3Bd]80c<c<0;jn_P3Cdm<0dM7A
0P39bLT01`2o_kl0_Kfm0<K6aP3=cLd0_Kfm0<S8b03?cll00P3;bl/01`2SXj<0cLg=0:b/[02`/;00
[jn_0:j^[P2/[:`00P2i^KT01`2][Jd0alO70:VYZ@3@d=00a/K60;bl_030`<000P2m_Kd01`34a<@0
c<c<0<_;b`3EeMD0dm?C0<;2`P2/[:`00P2j^[X0102e]KD0a/K60;fm_@2b/[820<;2`P0909fMW@32
`/80`/;20<C4a02l_;`0a/K60=7Ad@32`/80c/k>00<0`<3000@0`l?30;jn_P3@d=00a<C40P2n_[h0
2P32`/80b<S80<S8b036a/H0d];B0<C4a03:b/X0/K6a0;Fe]@36a/H20=7Ad@070<71`@3=cLd0_[jn
0;>c/`2g]kL0b/[:0<;2`P020<S8b080bl_;00D0`l?30<O7a`3;bl/0`<300=CDe0020=3@d0070<k>
cP2l_;`0b/[:0<S8b02_[jl0n_[j0;Rh^0020<;2`P040<o?c`30`<00alO70;Bd]2@0oooo00<0ec?o
06JSo`3G<ol00P1VXol]0=Lco`0306JSo`3G<ol0IZ?o00@0IZ?o0P3G<ol00`1VXol0ec?o06JSo`0<
0=Lco`0306JSo`3G<ol0ec?o00<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o603G<ol00`1VXol0ec?o0=Lc
o`0H0=Lco`0306JSo`3o0000ec?o00H0ec?o9`3oool002D0oooo00<0b<S80;Fe]@2g]kL00P2i^KT0
1`2m_Kd0aLG50<O7a`33`l<0_[jn0<C4a02n_[h00P2i^KT01`2m_Kd0YjNW0;Rh^02l_;`0`L710;2`
/02WYjL00P2g]kL01`3?cll0]kNg0;no_`30`<00];Bd0<C4a02TY:@00P2m_Kd01`38b<P0/[:b0<71
`@38b<P0];Bd0<71`@38b<P00P3=cLd01`30`<00_[jn0=CDe02k^k/0^KVi0<30`02j^[X00P2k^k/0
1`25QHD0_[jn0;fm_@2`/;00[Jf]0;no_`3Kfm/00P34a<@01`2k^k/0a/K60<30`02][Jd0/[:b0;Jf
]P2g]kL00P30`<001`3De=@0b/[:0;Rh^034a<@0[Jf]09RHV02VYZH00P2k^k/01`2`/;00_Kfm0:VY
Z@3<c<`0`/;20;>c/`34a<@00P2YZJT01`38b<P0/K6a0;Zj^P3Shn<0^k^k0=CDe02f][H00P2RXZ80
1`2a/K40^k^k0>GUi@34a<@0c/k>0=KFeP2o_kl00P3Bd]801`2c/k<0]kNg0<;2`P3@d=00]KFe0;Bd
]036a/H00P3EeMD01P3Kfm/0cLg=0<W9b@33`l<0_Kfm0<g=c@<0b/[:00D0hN7Q0<g=c@3=cLd0_Kfm
0;no_`020<[:bP80]KFe00L0bLW90<S8b03<c<`0[jn_0<S8b02c/k<0`/;20080a/K600@0bLW90<;2
`P3:b/X0b/[:903oool?0=Lco`0406JSo`3G<ol0ec?o0=Lco`80IZ?o203G<ol01@1VXol0ec?o0=Lc
o`3G<ol0IZ?o0100ec?o00<0IZ?o0=Lco`3G<ol00P1VXol70=Lco`80IZ?o203G<ol306JSo`80ec?o
00<0IZ?o0=Lco`1VXol0103G<ol206JSo`030=Lco`1VXol0ec?o00@0ec?o0`1VXolV0=Lco`0306JS
o`3G<ol0ec?o00L0ec?o9`3oool002D0oooo00<0];Bd0;Fe]@2a/K400P3;bl/01`35aLD0`l?30;no
_`2g]kL0`<300<C4a02j^[X00`2m_Kd01P39bLT0[Jf]0;Jf]P2g]kL0^k^k0;Jf]P80];Bd00L0/k>c
0;Vi^@2k^k/0a/K60<O7a`2h^;P0/[:b0080bLW900L0^;Rh09jNWP34a<@0][Jf0;fm_@39bLT0b/[:
0080a<C400L0`/;20<c<c034a<@0^;Rh0;Bd]034a<@0cLg=0080[Jf]00L0/K6a0<[:bP2h^;P0][Jf
0<;2`P3;bl/0b<S80080cLg=00L0bLW90<K6aP2o_kl0Y:BT0;Fe]@36a/H0fMWI0080d=3@00<0_Kfm
0;Rh^03:b/X00P2WYjL02`2YZJT0Ti>C0:FUY@2UYJD0^;Rh0;>c/`32`/80Zj^[0<k>cP36a/H0b/[:
0080d=3@00L0]KFe0;Ng]`2TY:@0`<300=WIf@2XZ:P0_[jn0080a<C400H0b<S80;fm_@32`/80a/K6
0;Bd]033`l<30<W9b@070<K6aP2m_Kd0/[:b0;^k^`2f][H0bLW90:n_[`020:>SX`070<K6aP30`<00
`/;20=3@d032`/80^k^k0<30`0020=KFeP070<C4a038b<P0bl_;0<W9b@32`/80]KFe0=KFeP020;Fe
]@070:b/[02l_;`0b<S80=3@d02k^k/0b/[:0<K6aP020<30`0040<K6aP2o_kl0d=3@0<;2`R@0oooo
0P3G<ol00`1VXol0ec?o0=Lco`0;0=Lco`0306JSo`3G<ol0ec?o00X0ec?o00D0IZ?o0=Lco`3G<ol0
ec?o06JSo`0>0=Lco`<0IZ?o2`3G<ol00`1VXol0ec?o0=Lco`060=Lco`H0IZ?o0`3G<ol00`1VXol0
ec?o0=Lco`050=Lco`0406JSo`3G<ol0ec?o06JSo`h0ec?o00@0IZ?o0=Lco`3G<ol0ec?o0`1VXolB
0=Lco`0306JSo`3G<ol0ec?o00X0ec?o9`3oool002D0oooo00<0];Bd0<O7a`2b/[800`2n_[h01@3M
gMd0bLW90;Vi^@3:b/X0^k^k00<0`<3000L0`/;20;no_`37alL0a/K60;fm_@2k^k/0aLG50080`l?3
00L0/;2`0<G5a@2m_Kd0d];B0<;2`P33`l<0alO70080`L7100L0clo?0<30`02n_[h0a<C40;^k^`31
`L40`l?30080cLg=00L0a<C40<71`@3=cLd0/;2`0;fm_@3<c<`0_kno0080_[jn00L0];Bd0:VYZ@3<
c<`0`<300:f][@2b/[80_[jn0080][Jf00L0[Zj^0;Fe]@2c/k<0XJ6Q0<_;b`39bLT0b/[:0080]kNg
00@0QhN70;6a/@2o_kl0c<c<0P2c/k<01P2d];@0_;bl0;bl_02_[jl0^KVi0<C4a080b<S800/0^KVi
0<;2`P2a/K40/K6a0;bl_02f][H0alO70<o?c`2h^;P0`/;20;no_`020=WIf@070<W9b@2m_Kd0_;bl
0=KFeP2j^[X0a<C40:^[Z`020<S8b0070;no_`3Fe]H0b/[:0>3Ph038b<P0a/K60<_;b`020=?Cd`07
0<_;b`3@d=00bLW90<[:bP34a<@0e]KF0<k>cP020<C4a0070=GEe@2n_[h0gMgM0=3@d03Cdm<0a/K6
0>3Ph0020;bl_0070<g=c@2j^[X0b<S80;:b/P28R8P0];Bd0<G5a@020;no_`040<30`036a/H0emOG
0;bl_2@0oooo0P3G<ol00`1VXol0ec?o0=Lco`0B0=Lco`0306JSo`3G<ol0ec?o0180ec?o00<0IZ?o
0=Lco`3G<ol0103G<ol00`1VXol0ec?o0=Lco`0206JSo`<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o1@3G
<ol206JSo`L0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol206JSo`l0ec?o00<0IZ?o0=Lco`3G<ol07P3G
<ol206JSo`P0ec?o9`3oool002D0oooo00<0[:b/0;bl_02i^KT00P32`/820<30`0050<g=c@30`<00
_kno0;fm_@39bLT00`2m_Kd01P3;bl/0cLg=0;Fe]@2m_Kd0`L710;fm_@80`<3000L0bLW90<K6aP35
aLD0_kno0<K6aP2a/K40bl_;0080e=CD00L0aLG50<_;b`37alL0alO70<30`036a/H0alO70080d];B
00L0_Kfm0<S8b033`l<0d];B0;no_`2k^k/0/k>c0080a<C400L0b/[:0<S8b02b/[80a<C40=oOg`3D
e=@0`/;20080_Kfm00L0a<C40:n_[`32`/80dM7A0<[:bP36a/H0c<c<0080T92@00L0^k^k0<S8b032
`/80]kNg0;^k^`2i^KT0[jn_0080`<3000D0a/K60;no_`32`/80`/;20;>c/`020<;2`P80`<3000L0
`/;209NGU`2o_kl0e]KF0<;2`P3=cLd0];Bd0080emOG00L0];Bd09jNWP30`<00a/K60<_;b`3:b/X0
d=3@0080b<S800L0b/[:0<30`030`<00`<300=;BdP36a/H0^KVi0080_kno00L0d];B0;no_`2c/k<0
]kNg0;Vi^@2o_kl0alO70080b/[:00@0_kno0<_;b`3IfMT0e]KF0P3Bd]802P3Fe]H0ZJVY0:VYZ@34
a<@0]KFe0<71`@2l_;`0^k^k0=_Kf`3:b/X20<30`0040<k>cP3<c<`0bl_;0<30`2@0oooo00<0IZ?o
0=Lco`3G<ol06@3G<ol00`1VXol0ec?o0=Lco`0E0=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o
0=Lco`3G<ol00`3G<ol206JSo`H0ec?o00<0IZ?o0=Lco`3G<ol02P3G<ol00`1VXol0ec?o0=Lco`06
0=Lco`0306JSo`3G<ol0ec?o01h0ec?o0P1VXol=0=LcobL0oooo000U0?ooo`030;Bd]02/[:`0Z:RX
0080_Kfm00L0/K6a0;^k^`2][Jd0_;bl0<?3``2o_kl0];Bd0080]kNg00L0alO70<?3``34a<@0^KVi
0;Rh^02o_kl0]KFe0080`/;200L0a/K60<_;b`2d];@0bLW90=KFeP2b/[80]KFe0080/k>c00L0`L71
0<g=c@2o_kl0clo?0<C4a02n_[h0b/[:0080`<3000L0c<c<0<K6aP3De=@0[Jf]0;Vi^@2g]kL0clo?
0080a/K600D0]kNg0=7Ad@3Fe]H0`l?30;Ng]`020=KFeP80`<3000L0e=CD0;Zj^P2[Zj/0^k^k0<;2
`P3De=@0`<300080_Kfm00L0^KVi0<30`03@d=00a<C40;Rh^02g]kL0];Bd0080^;Rh00L0alO70<C4
a03;bl/0/k>c0=;BdP33`l<0alO70080fm_K00L0`/;20;Vi^@3=cLd0bl_;0=KFeP3?cll0cLg=0080
bl_;00L0`<300;fm_@2j^[X0/;2`0=7Ad@3Ogml0^k^k0080d=3@00L0^KVi0;fm_@2i^KT0^KVi0<;2
`P36a/H0`L710080dm?C00L0e=CD0;no_`2l_;`0][Jf0<S8b03Ogml0cLg=0080alO700L0dM7A0=;B
dP2XZ:P0a<C40<[:bP2o_kl0f=SH0080b/[:00L0bl_;0<O7a`36a/H0c/k>0=3@d02;Rh/0];Bd0080
_kno00@0clo?0<71`@32`/80_Kfm903oool00`3G<ol0IZ?o06JSo`020=Lco`0306JSo`3G<ol0IZ?o
01@0ec?o00<0IZ?o0=Lco`3G<ol03@3G<ol00`1VXol0ec?o0=Lco`0>0=Lco`0306JSo`3G<ol0ec?o
0280ec?o00<0IZ?o0=Lco`3G<ol05`3G<ol00`1VXol0ec?o0=Lco`090=Lco`0306JSo`3G<ol0ec?o
00D0ec?o9`3oool002D0oooo00<0];Bd0:b/[02XZ:P00P2m_Kd01`2a/K40^k^k0:f][@2l_;`0`l?3
0;no_`2d];@00P2g]kL01`37alL0`l?30<C4a02i^KT0^;Rh0;no_`2e]KD00P32`/801`36a/H0bl_;
0;Bd]039bLT0e]KF0;:b/P2e]KD00P2c/k<01`31`L40cLg=0;no_`3?cll0a<C40;jn_P3:b/X00P30
`<001`3<c<`0a/K60=CDe02][Jd0^KVi0;Ng]`3?cll00P36a/H01@2g]kL0dM7A0=KFeP33`l<0]kNg
0080e]KF0P30`<001`3De=@0^[Zj0:^[Z`2k^k/0`/;20=CDe030`<000P2m_Kd01`2i^KT0`<300=3@
d034a<@0^;Rh0;Ng]`2d];@00P2h^;P01`37alL0a<C40<_;b`2c/k<0d];B0<?3``37alL00P3Kfm/0
1`32`/80^KVi0<g=c@3;bl/0e]KF0<o?c`3=cLd00P3;bl/01`30`<00_Kfm0;Zj^P2`/;00dM7A0=oO
g`2k^k/00P3@d=001`2i^KT0_Kfm0;Vi^@2i^KT0`/;20<K6aP31`L400P3Cdm<01`3De=@0_kno0;bl
_02f][H0b<S80=oOg`3=cLd00P37alL01`3AdM40d];B0:RXZ034a<@0b/[:0;no_`3Hf=P00P3:b/X0
1`3;bl/0alO70<K6aP3>c/h0d=3@08^;R`2d];@00P2o_kl0103?cll0`L710<;2`P2m_KdT0?ooo`03
0=Lco`1VXol0IZ?o0080ec?o00<0IZ?o0=Lco`1VXol0503G<ol00`1VXol0ec?o0=Lco`0=0=Lco`03
06JSo`3G<ol0ec?o00h0ec?o00<0IZ?o0=Lco`3G<ol08P3G<ol00`1VXol0ec?o0=Lco`0G0=Lco`03
06JSo`3G<ol0ec?o00T0ec?o00<0IZ?o0=Lco`3G<ol01@3G<olW0?ooo`009@3oool00`2d];@0/;2`
0<K6aP030;Vi^@060<G5a@32`/80`/;20<;2`P36a/H0bLW90P38b<P01`3@d=00b<S80<c<c034a<@0
`L710;Fe]@2n_[h00P39bLT01`30`<00b/[:0<_;b`2^[Zh0`l?30;Vi^@33`l<00P2`/;020<_;b`05
0;Bd]02OWil0^k^k0=OGe`31`L400P3Cdm<01`2o_kl0dm?C08:2PP36a/H0`<3009:BTP3?cll00P2j
^[X01`2[Zj/0d=3@0=SHf02a/K40]KFe0;fm_@3;bl/00P2YZJT01`2e]KD0c<c<0:NWY`2c/k<0_;bl
0<o?c`2b/[800P2i^KT01`2n_[h0^[Zj0<S8b02f][H0_[jn0:f][@2e]KD00P2g]kL01@34a<@0a/K6
0;fm_@2i^KT0/k>c0080cLg=0P2n_[h01`37alL0clo?09JFUP3<c<`0]kNg0;no_`32`/800P2e]KD0
1`2_[jl0ZJVY0;>c/`2i^KT0`L710;Ng]`2e]KD00P30`<001`2g]kL0c<c<0;Vi^@2o_kl0b<S80;jn
_P2WYjL00P2j^[X01`39bLT0e=CD0<C4a03Fe]H0^k^k0;fm_@33`l<00P39bLT01`3@d=00c/k>0;2`
/032`/80`<300<c<c02][Jd00P30`<001`3Bd]80kno_08R8R035aLD0alO70<_;b`36a/H00P2f][H0
1034a<@0clo?0<[:bP2h^;PT0?ooo`030=Lco`1VXol0ec?o01L0ec?o00@0IZ?o0=Lco`3G<ol0ec?o
0P1VXol30=Lco`0306JSo`3G<ol0ec?o00D0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o0`3G<ol0101VXol0
ec?o0=Lco`1VXol30=Lco`80IZ?o0P3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o00L0ec?o00<0IZ?o
0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`040=Lco`80IZ?o3@3G<ol00`1VXol0ec?o0=Lco`0;
0=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol00`3G<ol00`3o0000IZ?o0=Lco`090=LcobL0oooo000U
0?ooo`030<G5a@2n_[h0_[jn0080alO700L0`l?30:b/[036a/H0alO70;Rh^02n_[h0bl_;0080^;Rh
00L0a<C40;fm_@36a/H0a/K60;Vi^@39bLT0`/;20080/[:b00L0[Jf]07UiN@2m_Kd0_kno0;fm_@3;
bl/0^k^k0080aLG500L0`L710<?3``2e]KD0`<300;Vi^@2l_;`0d=3@0080_;bl00L0_kno0<_;b`32
`/80b<S80<30`02SXj<0f][J0080bl_;00L0^;Rh0;Vi^@39bLT0eMGE08b<S034a<@0bLW90080^k^k
00L0`/;20:^[Z`2YZJT0]kNg0:n_[`2JVYX0]kNg0080^KVi00<0b/[:0;Rh^02i^KT00P2n_[h01@2f
][H0X:2P0;^k^`2k^k/0alO70080`<300P2n_[h02`3Hf=P0^KVi0<c<c03<c<`0c/k>09RHV03Bd]80
[jn_0:BTY02o_kl0/K6a0080e=CD00@0^k^k0;Ng]`37alL0^k^k0P37alL02P30`<00_kno0;no_`34
a<@0`/;20;no_`32`/80d=3@0<[:bP30`<020<o?c`060<W9b@36a/H0`/;20=KFeP3De=@0b<S80`3>
c/h01`34a<@0cLg=0<o?c`36a/H0c<c<0;no_`3Bd]800P3<c<`01`34a<@0c<c<0=[JfP37alL0_[jn
0<W9b@38b<P00P2j^[X0103?cll0a/K60<W9b@34a<@T0?ooo`H0ec?o00<0IZ?o0=Lco`3G<ol0303G
<ol306JSo`0309Wo`P3G<ol0ec?o01<0ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lc
o`030=Lco`80IZ?o00<0ec?o06JSo`1VXol02@3G<ol00`1VXol0ec?o0=Lco`0:0=Lco`0606JSo`3G
<ol0IZ?o06JSo`3G<ol0IZ?o<`3G<olW0?ooo`009@3oool00`2b/[80];Bd0;2`/0020<30`0070;^k
^`2NWYh0_;bl0<71`@2g]kL0_;bl0:b/[0020;Bd]0070<C4a032`/80]kNg0;2`/02g]kL0`<300<S8
b0020<[:bP070;^k^`2YZJT0b<S80<K6aP3<c<`0b<S80<K6aP020=3@d00709JFUP2g]kL0[Jf]0<30
`03?cll0alO70<W9b@020<O7a`070;Vi^@37alL0c<c<0<S8b02_[jl0^k^k0=;BdP020;Rh^0070<c<
c02i^KT0Y:BT0:JVYP2[Zj/0]KFe0<;2`P020:BTY0070;Vi^@32`/80^k^k0;Bd]02k^k/0c/k>0;no
_`020<C4a0040:n_[`36a/H0_kno0:VYZ@80^KVi00X0U9BD0<30`030`<00[jn_0=KFeP2i^KT0d];B
0<30`032`/80f=SH0P2][Jd01`3>c/h0/k>c0=3@d02e]KD0ZJVY0;Zj^P2f][H00P2@T9001`38b<P0
_kno0;2`/02a/K40_kno0;Fe]@2^[Zh00P2][Jd01`2i^KT0e=CD0;no_`3Bd]80c/k>0;Vi^@36a/H0
0`3:b/X01P3<c<`0d=3@0<k>cP2i^KT0a<C40<;2`P80/K6a00L0^k^k0<C4a02TY:@0cLg=0<;2`P3J
f]X0a/K60080`/;200L0][Jf0;Rh^03_knl0/K6a0<C4a02l_;`0][Jf0080hN7Q00@0fMWI0<;2`P33
`l<0^k^k903oool00`1VXol0ec?o06JSo`030=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lc
o`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`040=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lc
o`1VXol02P3G<ol00`1VXol0ec?o0=Lco`040=Lco`<0IZ?o0P3G<ol206JSo`T0ec?o00@0IZ?o0=Lc
o`3G<ol0IZ?o0P3G<ol0101VXol0ec?o0=Lco`1VXol60=Lco`80IZ?o103G<ol00`1VXol0ec?o0=Lc
o`0206JSo`80ec?o0P1VXol20=Lco`<0IZ?o403G<ol206JSo`80ec?o00<0IZ?o0=Lco`3G<ol01P3G
<ol00`3o0000IZ?o0=Lco`080=LcobL0oooo000U0?ooo`030;Vi^@32`/80b<S80080_kno00L0alO7
0;no_`3=cLd0bl_;0<O7a`39bLT0`L710080alO70P2o_kl01@2i^KT0^k^k0;Jf]P2PX:00_Kfm0080
_;bl00L0`<300;no_`2b/[80aLG50<O7a`2g]kL0c<c<0080a/K600L0`l?30<K6aP2g]kL0^KVi0;no
_`3;bl/0d];B0080`L7100L0^[Zj0<g=c@2k^k/0e=CD0<G5a@2o_kl0`/;20080Z:RX00L0a<C40:b/
[032`/80_kno0:NWY`2l_;`0]KFe0080d];B00L0bLW90;fm_@34a<@0_kno0;bl_034a<@0^KVi0080
_kno00@0_Kfm0:^[Z`36a/H0_kno0P2i^KT02P2`/;00];Bd0;Bd]03MgMd0d];B0;Vi^@3=cLd0`<30
0;Vi^@3;bl/20<30`0070;^k^`3<c<`0dM7A0;no_`2TY:@071`L0<S8b0020<O7a`070<o?c`2e]KD0
a<C40<c<c02n_[h0/[:b0<W9b@020<30`0060<C4a038b<P0]KFe0<[:bP3<c<`0b<S80`36a/H01`34
a<@0`/;20;fm_@3?cll0a<C40=WIf@3GemL00P34a<@01`2LW9`0`<300<W9b@2m_Kd0d];B0<K6aP34
a<@00P2g]kL01`2YZJT0_Kfm09jNWP3?cll0c/k>0<C4a03]kNd00P3De=@0102g]kL0YjNW0<30`036
a/HT0?oooa<0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`0D0=Lco`80IZ?o00D0
ec?o06JSo`3G<ol0ec?o06JSo`0>0=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol0
3@3G<ol00`1VXol0mOo<0=Lco`070=Lco`0306JSo`3G<ol0ec?o01<0ec?o00<0IZ?o0=Lco`3G<ol0
1P3G<ol00`1VXol0ec?o06JSo`030=Lco`050?l0003G<ol0ec?o0=Lco`1VXol00P3G<olW0?ooo`00
9@3oool00`2f][H0^k^k0<K6aP020;>c/`070<S8b02l_;`0`/;20=WIf@31`L40_Kfm0<71`@020<_;
b`070;Bd]030`<00]kNg0<W9b@36a/H0`<300;Jf]P020;Bd]0070;>c/`31`L40`l?30;bl_03@d=00
b/[:0<?3``020;Ng]`070<S8b033`l<0_;bl0;Zj^P3:b/X0`<300<o?c`020<30`0060<?3``31`L40
gMgM0<W9b@3;bl/0`/;20`3:b/X01`3Fe]H0c<c<0<C4a02i^KT0bLW90<C4a02l_;`00P2d];@01`2^
[Zh0alO70<O7a`2i^KT0Y:BT0;Fe]@2YZJT00P34a<@01`3Fe]H0[jn_0<;2`P31`L40_Kfm0;Ng]`2S
Xj<00P3<c<`01@2d];@0jn_[0:RXZ02m_Kd0`<300080^;Rh0P39bLT01`3@d=00b<S80>SXj03;bl/0
VYZJ0<71`@32`/800P2YZJT01P32`/80aLG50;2`/02k^k/0]KFe0;no_`<0`/;200L0bl_;0;jn_P30
`<00fm_K0<30`032`/80]kNg0080`/;200L0b<S80<C4a03Bd]80ZJVY0:^[Z`39bLT0`/;20080a<C4
00L0`/;20;6a/@38b<P0aLG50<C4a03AdM40cLg=0080_kno00L0/[:b0=KFeP2l_;`0bLW90<;2`P3E
eMD0/;2`0080b/[:00@0]KFe0<g=c@3<c<`0[jn_903ooolk0=Lco`0706JSo`3G<ol0ec?o0=Lco`1V
Xol0ec?o06JSo`030=Lco`0306JSo`3G<ol0ec?o0080ec?o00H0IZ?o0=Lco`3G<ol0ec?o0?l0001V
Xol80=Lco`030?l0003G<ol0IZ?o0080ec?o0P1VXol20=Lco`0306JSo`3G<ol0ec?o0100ec?o0P1V
Xol50=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lc
o`030=Lco`0306JSo`3oool0oooo02D0oooo000U0?ooo`030:VYZ@2j^[X0_[jn00<0^;Rh00H0a/K6
0<?3``36a/H0_Kfm0;^k^`2b/[820<S8b0070;jn_P3Kfm/0a/K60;Jf]P36a/H0b<S80<C4a0020;no
_`070;fm_@34a<@0/[:b0<O7a`2h^;P0a/K60<G5a@020<O7a`070;^k^`39bLT0_Kfm0<;2`P37alL0
`<300<[:bP020=?Cd`040<K6aP3AdM40^k^k0<O7a`80_[jn00X0/K6a0:n_[`2_[jl0`<300;6a/@38
b<P0Zj^[0:n_[`3Fe]H0`<300P2m_Kd01`39bLT0^KVi0<?3``36a/H0_kno0<[:bP32`/800P3Bd]80
1`2e]KD0a<C40<30`03Jf]X0^k^k0;6a/@3De=@00P2j^[X01`3Ph>00[Zj^0;^k^`2g]kL0`/;20=3@
d02^[Zh00P3Bd]801`36a/H0hN7Q0<o?c`2i^KT0`<300:ZZZP3Ti>@00P3;bl/01`2d];@0`<300<;2
`P3;bl/0alO70<K6aP2m_Kd00P3Ogml01`2g]kL0_kno0;^k^`30`<00cLg=0<[:bP2ATI400P37alL0
103AdM40]kNg0;Fe]@31`L420<W9b@0:0;>c/`34a<@0a<C40:b/[033`l<0alO70;Vi^@3?cll0c/k>
0;fm_@80/K6a00L0a<C40<o?c`1iNGT0/[:b0;Vi^@30`<00alO70080/K6a00@0_Kfm0:f][@2a/K40
_Kfm903oool00`1VXol0ec?o0=Lco`080=Lco`0306JSo`3G<ol0ec?o00/0ec?o00<0IZ?o0=Lco`3G
<ol04`3G<ol306JSo`030=Lco`1VXol0ec?o0080IZ?o4P3G<ol00`1VXol0ec?o0=Lco`020=Lco`03
06JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lco`0@0=Lco`03
06JSo`3G<ol0ec?o00T0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol206JSo`80ec?o00<0VOo206JSo`3G
<ol00P3G<ol206JSo`040=Lco`1VXol0IZ?o0=LcobL0oooo000U0?ooo`030:NWY`38b<P0_[jn0080
[:b/00L0`/;20<O7a`2l_;`0c<c<0<g=c@2g]kL0aLG50080alO700L0bl_;0<;2`P2j^[X0YjNW0;fm
_@2l_;`0YjNW0080_kno00L0_Kfm0<C4a02l_;`0_;bl0=7Ad@30`<00]kNg0080^k^k00L0`/;20;Vi
^@2g]kL0_[jn0<30`02d];@0a/K60080cLg=00L0_[jn0<K6aP2e]KD0g]kN0<C4a032`/80a/K60080
d=3@00L0a/K60:^[Z`34a<@0c<c<0<30`03Fe]H0a/K60080d=3@00L0a/K60=;BdP2a/K40/;2`0;^k
^`32`/80`<300080/K6a00D0`/;20=3@d02j^[X0b<S80<C4a0020;Rh^080_Kfm00L0Y:BT0<W9b@2m
_Kd0clo?0:NWY`35aLD0e]KF0080inOW00L0cLg=0<?3``2m_Kd0a<C40<K6aP38b<P0_Kfm0080a/K6
00L0`/;20;Zj^P2][Jd0RHV90;:b/P3:b/X0`l?30080YJFU00L0b<S80;fm_@2o_kl0bl_;0<S8b030
`<00a/K60080fMWI00L0gmoO0=_Kf`3<c<`0d];B0;fm_@3>c/h0b/[:0080c/k>00H0c<c<0;fm_@38
b<P0_kno0<c<c034a<@30:VYZ@070=;BdP34a<@0`L710<C4a02ZZZX0YZJV0=_Kf`020<30`0040=;B
dP32`/80a<C40;Vi^B@0oooo00<0IZ?o0=Lco`3G<ol00P1VXol<0=Lco`0406JSo`3G<ol0ec?o06JS
oah0ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol206JSo`<0ec?o0P1VXol90=Lco`0506JSo`3G<ol0ec?o
0=Lco`1VXol00P3G<ol20?l000/0ec?o0`1VXol20=Lco`80IZ?o603G<ol306JSo`@0ec?o0P1VXol7
0=LcobL0oooo000U0?ooo`030;Fe]@2d];@0_[jn0080cLg=00L0^[Zj0<S8b02f][H0^[Zj0=;BdP2e
]KD0^;Rh0080d];B00L0/k>c0;bl_02j^[X0][Jf0;Bd]02b/[80^k^k00@0alO700D0_;bl0<71`@37
alL0_Kfm0;6a/@020;^k^`070<C4a032`/80_Kfm0<S8b03;bl/0`/;20;bl_0020<;2`P070<S8b03<
c<`0fm_K0=WIf@38b<P0_[jn0<30`0020<o?c`070<W9b@34a<@0bl_;0;fm_@3;bl/0_Kfm0<_;b`03
0<;2`P060<30`03AdM40dm?C0:f][@34a<@0YJFU0P30`<001`39bLT0a/K60;:b/P2j^[X0];Bd0;bl
_02i^KT00P2c/k<01`2`/;00^k^k0;fm_@33`l<0_kno0:f][@3De=@00P36a/H01`30`<00]kNg0;^k
^`3<c<`0a/K60;^k^`31`L400P2f][H00`2g]kL0YJFU0<C4a0020;Vi^@0;0;Bd]02^[Zh0_Kfm0;fm
_@30`<00`/;20<C4a03De=@0c<c<0<k>cP34a<@00P2o_kl01`3;bl/0f=SH0<k>cP2i^KT0`/;20<K6
aP3De=@00P36a/H01`3;bl/0d];B0<o?c`38b<P0a<C40;Vi^@2g]kL00P2YZJT01`35aLD0_[jn0;no
_`2n_[h0e=CD0<[:bP2e]KD00P2i^KT01038b<P0dm?C0;bl_032`/8T0?oooa<0ec?o00<0IZ?o0=Lc
o`3G<ol01`3G<ol00`1VXol0ec?o0=Lco`0O0=Lco`0306JSo`3G<ol0IZ?o00@0ec?o00<0IZ?o0=Lc
o`3G<ol0103G<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0ec?o00/0ec?o00<0IZ?o0=Lc
o`3G<ol00P3G<ol00`1VXol0ec?o0=Lco`0I0=Lco`80IZ?o3@3G<olW0?ooo`009@3oool00`2e]KD0
];Bd0;jn_P020<g=c@070;Zj^P38b<P0][Jf0;Zj^P3Bd]80]KFe0;Rh^0020=;BdP070;>c/`2l_;`0
^[Zj0;Jf]P2d];@0/[:b0;^k^`040<O7a`050;bl_031`L40alO70;fm_@2a/K400P2k^k/01`34a<@0
`/;20;fm_@38b<P0bl_;0<;2`P2l_;`00P32`/801`38b<P0c<c<0=_Kf`3IfMT0b<S80;jn_P30`<00
0P3?cll01`39bLT0a<C40<_;b`2m_Kd0bl_;0;fm_@3;bl/00`32`/801P30`<00dM7A0=?Cd`2][Jd0
a<C40:FUY@80`<3000L0bLW90<K6aP2b/[80^[Zj0;Bd]02l_;`0^KVi0080/k>c00L0/;2`0;^k^`2m
_Kd0`l?30;no_`2][Jd0e=CD0080a/K600L0`<300;Ng]`2k^k/0c<c<0<K6aP2k^k/0`L710080][Jf
00<0]kNg0:FUY@34a<@00P2i^KT02`2d];@0[Zj^0;fm_@2m_Kd0`<300<;2`P34a<@0e=CD0<c<c03>
c/h0a<C40080_kno00L0bl_;0=SHf03>c/h0^KVi0<;2`P36a/H0e=CD0080a/K600L0bl_;0=;BdP3?
cll0b<S80<C4a02i^KT0]kNg0080ZJVY00L0aLG50;jn_P2o_kl0_[jn0=CDe03:b/X0]KFe0080^KVi
00@0b<S80=?Cd`2l_;`0`/;2903ooolC0=Lco`0306JSo`3G<ol0ec?o00L0ec?o00<0IZ?o0=Lco`3G
<ol07`3G<ol00`1VXol0ec?o06JSo`040=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lco`3G
<ol00P3G<ol00`1VXol0ec?o0=Lco`0;0=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G
<ol06@3G<ol206JSo`d0ec?o9`3oool002D0oooo00<0[Zj^0<C4a032`/800P34a<@01`2o_kl0bLW9
0;jn_P39bLT0a/K60=;BdP2d];@00P2j^[X01`37alL0^KVi0;^k^`3;bl/0][Jf0;^k^`2l_;`00P2k
^k/01036a/H0_Kfm0;:b/P2l_;`20<S8b00:0;Ng]`33`l<0`l?30;fm_@2g]kL0[Zj^0;no_`2WYjL0
^k^k0=?Cd`80a<C400L0^KVi0<S8b02e]KD0`l?30;Vi^@2`/;00bl_;0080`<3000L0e]KF0<K6aP31
`L40YZJV0<[:bP3De=@0^k^k0080a<C400L0b<S80<71`@39bLT0alO70<K6aP3=cLd0^k^k0080b<S8
00L0`<300:BTY02h^;P0e=CD08b<S02QXJ40XZ:R0080]kNg00<0`<300;6a/@3>c/h00P38b<P02@3>
c/h0^KVi0<c<c03<c<`0/;2`0<C4a039bLT0/[:b0;Ng]`020<S8b080^k^k00L0cLg=0;Vi^@32`/80
][Jf0;fm_@2e]KD0a/K60080a<C400L0e]KF0;fm_@3:b/X0b/[:0<30`03:b/X0_Kfm0080b/[:00L0
d];B0<C4a036a/H0ZJVY0<W9b@37alL0aLG50080^k^k00L0^[Zj0<K6aP3:b/X0dm?C0<g=c@38b<P0
`/;20080_;bl00L0b<S80=CDe03Lg=`0`<300;^k^`32`/80`<300080^k^k00@0/;2`0;Vi^@37alL0
_Kfm903oool00`1VXol0ec?o0=Lco`0F0=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`1V
Xol02@3G<ol00`1VXol0ec?o0=Lco`040=Lco`0306JSo`3G<ol0ec?o00d0ec?o00<0IZ?o0=Lco`3G
<ol00`1VXol30=Lco`0306JSo`3G<ol0ec?o00D0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o6P3G<ol00`1V
Xol0ec?o0=Lco`0E0=Lco`0406JSo`3G<ol0ec?o0=LcobL0oooo000U0?ooo`030:VYZ@2e]KD0`L71
0080a/K600L0aLG50;Zj^P2l_;`0`<300<;2`P2d];@0`<300080_kno00L0`l?30;no_`2o_kl0_kno
0;Fe]@2i^KT0`/;20080a<C400L0`/;20<30`02c/k<0f=SH0<_;b`31`L40XJ6Q0080bLW900L0b<S8
0;Bd]03;bl/0b/[:0;Rh^038b<P0`/;20080a/K600L0][Jf0<;2`P3=cLd0`l?30;:b/P34a<@0/k>c
0080ZZZZ00L0bLW90<71`@2c/k<0^k^k0;fm_@37alL0`l?30080];Bd00L0^[Zj0<C4a02f][H0X:2P
0=CDe02`/;00[Jf]0080a/K600L0b<S80<C4a034a<@0^KVi0:2PX02][Jd0/k>c0080^KVi00<0a/K6
0<30`035aLD00P30`<002`2l_;`0alO70:6QX@2QXJ40bLW90<S8b035aLD0^[Zj0;^k^`39bLT0]kNg
0080alO700L0_;bl0;Jf]P2m_Kd0b/[:0<k>cP2k^k/0][Jf0080a<C400L0`<300;bl_030`<00a<C4
0<K6aP32`/80^KVi0080]kNg00L0][Jf0;Bd]02k^k/0`L710=OGe`30`<00/[:b0080bLW900L0hN7Q
0<S8b034a<@0`/;20<S8b02d];@0]KFe0080^k^k00L0a/K60:VYZ@2m_Kd0c<c<0=gMg@3@d=00f=SH
0080c<c<00@0a/K60<;2`P3:b/X0^k^k903oool00`1VXol0ec?o0=Lco`0J0=Lco`0306JSo`3G<ol0
ec?o00d0ec?o00<0IZ?o0=Lco`3G<ol00P1VXol<0=Lco`0406JSo`3G<ol0IZ?o06JSo`H0ec?o0P1V
Xol:0=Lco`80IZ?o8@3G<ol00`1VXol0ec?o0=Lco`0:0=Lco`0306JSo`3G<ol0ec?o00T0ec?o9`3o
ool002D0oooo00<0];Bd0<71`@2o_kl00P39bLT01`3?cll0];Bd0;Vi^@35aLD0`L710;bl_02m_Kd0
0P2o_kl01`35aLD0[jn_0;no_`32`/80];Bd0<K6aP2m_Kd00P37alL01`34a<@0WinO0:^[Z`2e]KD0
]kNg0;jn_P38b<P00P30`<001`2d];@0bl_;0;^k^`37alL0^KVi0:b/[038b<P00P2k^k/01`2o_kl0
dM7A0<S8b03?cll0^KVi0;Bd]033`l<00P37alL00`31`L40_;bl0<;2`P020<;2`P0;0;Ng]`3=cLd0
bl_;0<_;b`39bLT0c/k>0:VYZ@30`<00eMGE0;no_`3=cLd00P36a/H01`32`/80/K6a0;no_`2a/K40
]KFe0;no_`2^[Zh00P3;bl/01`37alL0a/K60;Fe]@2j^[X0a/K60=gMg@3:b/X00P2l_;`01P3Vi^H0
a/K60;>c/`32`/80eMGE0=;BdP<0a<C400L0^[Zj0:j^[P33`l<0[:b/0;Rh^02@T900`<300080k^k^
00L0`<300:f][@2g]kL0c<c<0<;2`P3=cLd0^k^k0080aLG500L0bLW90<g=c@38b<P0bl_;0=SHf02Y
ZJT0][Jf0080d=3@00L0`/;20<W9b@3=cLd0c/k>0;^k^`3?cll0alO70080clo?00L0bLW90<_;b`34
a<@0`l?30;Rh^030`<00_[jn0080hn?S00@0dM7A0<_;b`3Cdm<0b/[:903oool?0=Lco`0306JSo`3G
<ol0ec?o00H0ec?o0P1VXol;0=Lco`0306JSo`3G<ol0ec?o01D0ec?o00<0IZ?o0=Lco`3G<ol01@3G
<ol00`1VXol0ec?o06JSo`020=Lco`0306JSo`3G<ol0ec?o01<0ec?o00H0IZ?o0=Lco`1VXol0ec?o
06JSo`3G<ol20?l000030=Lco`1VXol0ec?o00/0ec?o00<0IZ?o0=Lco`3G<ol05`3G<olW0?ooo`00
9@3oool00`2n_[h0[:b/0<30`0020<;2`P80b<S800D0^k^k0<;2`P3GemL0cLg=0;Ng]`020;^k^`80
^KVi00D0_kno0;Ng]`2h^;P0`/;20<G5a@020<C4a0070<g=c@3EeMD0`<300;no_`2YZJT0a<C40<K6
aP020<30`0070<_;b`2g]kL0]KFe0<K6aP2g]kL0_kno0=3@d0020<_;b`070<30`02k^k/0_;bl0<30
`02i^KT0clo?0;:b/P020;Bd]0050<K6aP3]kNd0_Kfm0;Vi^@2k^k/00P2m_Kd20<g=c@070;Fe]@2m
_Kd0]KFe0;no_`3<c<`0_kno0;Zj^P020<S8b0040;>c/`2g]kL0/k>c0;no_`80`/;200X0]kNg0<;2
`P32`/80^k^k0<71`@2k^k/0_Kfm0<S8b032`/80^k^k0P2o_kl01`2][Jd0a<C40;fm_@34a<@0fMWI
0;6a/@36a/H00P3Cdm<01`3?cll0cLg=0<O7a`2m_Kd0a<C40<_;b`3EeMD00P3;bl/01`3AdM40]KFe
0;no_`2k^k/0c<c<0<;2`P2d];@00P2o_kl00`39bLT0`l?30<W9b@020<c<c00;0<o?c`3Bd]80b<S8
0<S8b03=cLd0e=CD0<C4a03<c<`0]kNg0<O7a`2a/K400P2OWil01`2NWYh0`<300<30`03Fe]H0`L71
0<C4a03:b/X00P2o_kl0102YZJT0a<C40::RXP2g]kLT0?ooo`030=Lco`1VXol0ec?o01P0ec?o00<0
IZ?o0=Lco`3G<ol04@3G<ol01@1VXol0ec?o0=Lco`3G<ol0o`000280ec?o00<0IZ?o0=Lco`3G<ol0
0P3G<ol00`1VXol0ec?o0=Lco`0R0=Lco`@0IZ?o203G<ol0101VXol0ec?o06JSo`3G<olW0?ooo`00
9@3oool00`2/[:`0c<c<0;no_`020;>c/`070<;2`P2n_[h0ZJVY0;jn_P32`/80ZJVY0;Fe]@020<C4
a0070;Rh^02i^KT0alO70<30`02e]KD0aLG50;:b/P020<O7a`070;:b/P2k^k/0_Kfm0<W9b@38b<P0
_[jn0:j^[P020;Fe]@070<C4a02e]KD0`/;20;bl_02YZJT0]kNg0=oOg`020;jn_P070:j^[P34a<@0
UiNG0;Vi^@2e]KD0bLW90=gMg@020=cLg0030;Ng]`3=cLd0^k^k0080^;Rh00/0a/K60:JVYP2h^;P0
^;Rh0<W9b@3;bl/0`<300;Rh^02j^[X0_;bl0;>c/`020<[:bP070;Fe]@2g]kL0a<C40<30`034a<@0
[Jf]0;^k^`020<C4a0070:n_[`34a<@0eMGE0;Vi^@2LW9`0][Jf0<g=c@0209VIV@070=OGe`36a/H0
bLW90<K6aP2m_Kd0d];B0;6a/@020=7Ad@050:n_[`3@d=00`/;20<[:bP3?cll00P2n_[h20<;2`P07
0<C4a02;Rh/0_Kfm0;Bd]02b/[80bl_;0;fm_@020<30`0060=3@d03<c<`0`/;20>OWi`3:b/X0Y:BT
0`3<c<`0103:b/X0bLW90<o?c`3;bl/20<S8b0030;no_`2ZZZX0ZZZZ0080^k^k00D0Z:RX08N7Q`34
a<@0b<S80<_;b`020:j^[P040;2`/02QXJ40`/;20;Bd]2@0oooo00<0IZ?o0=Lco`3G<ol0103G<ol0
101VXol0ec?o0=Lco`1VXol90=Lco`0406JSo`3G<ol0ec?o06JSo`D0ec?o00<0IZ?o0=Lco`3G<ol0
103G<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3G<ol0IZ?o00`0ec?o00<0IZ?o0=Lco`3G<ol0
3P3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o00<0ec?o00<0IZ?o0=Lco`3G<ol00P1VXol60=Lco`04
06JSo`3G<ol0ec?o06JSo`T0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o1`3G<ol00`3o0000ec?o06JSo`0:
0=Lco`80IZ?o0P3G<ol206JSo`<0ec?o101VXol20=LcobL0oooo000U0?ooo`030<G5a@34a<@0`/;2
0080bLW900L0`l?30<71`@39bLT0bLW90<O7a`2m_Kd0];Bd0080_kno00L0[Zj^0<C4a035aLD0]kNg
0<_;b`3<c<`0`/;20080_kno00L0alO70:j^[P2n_[h0];Bd0<o?c`2k^k/0ZJVY0080^;Rh00L0_kno
0;Vi^@2o_kl0bl_;0;fm_@32`/80_;bl0080/[:b00L0^;Rh0<W9b@39bLT0d];B0;jn_P39bLT0^[Zj
00<0`/;200H0Xj>S0:NWY`2j^[X0b<S80=3@d03Bd]820<W9b@070;jn_P3@d=00b/[:0;jn_P2k^k/0
/K6a0<K6aP020<[:bP070;Vi^@2d];@0`/;20<K6aP2e]KD0^k^k0:NWY`020:^[Z`050<;2`P38b<P0
`<300<g=c@2l_;`00P3;bl/20;Vi^@070:f][@3AdM40c<c<0=CDe03;bl/0dM7A0<W9b@020<K6aP07
0<o?c`36a/H0aLG50:ZZZP3IfMT0bl_;0:NWY`020;Bd]0070<C4a02l_;`0Xj>S0:6QX@2k^k/0clo?
0=_Kf`020<k>cP070<_;b`30`<00][Jf0<_;b`20P800b/[:0<o?c`020;fm_@070;Jf]P35aLD0cLg=
0;Jf]P3@d=00[:b/0:JVYP020<?3``0707emO@2e]KD0fMWI0=3@d02l_;`0SXj>0<;2`P020<_;b`04
0<30`034a<@0S8b<0=OGeb@0oooo3P3G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JSo`3G<ol0ec?o
0080ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol206JSo`X0ec?o0P1VXol;0=Lco`0306JSo`3G<ol0ec?o
00L0ec?o0`1VXol90=Lco`0306JSo`3G<ol0ec?o00T0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o103G<ol2
06JSo`T0ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol206JSo`80ec?o00<0VOo20=Lco`3G<ol00P3G<ol0
0`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0oooo02H0oooo000U0?ooo`80_[jn00X0_;bl0<?3
``33`l<0bLW90<71`@2m_Kd0a<C40;Bd]02h^;P0]KFe0P2l_;`01`2n_[h0^k^k0<O7a`2i^KT0/;2`
0;jn_P36a/H00P31`L400`2YZJT0d=3@0<?3``020<C4a00;0;Vi^@32`/80a<C40<C4a03=cLd0bLW9
0<g=c@32`/80/[:b0:FUY@2f][H00P30`<001`2k^k/0alO70;jn_P2d];@0Ti>C0<_;b`3GemL00P3;
bl/01`2j^[X0a<C40<O7a`39bLT0e=CD0<C4a031`L400P2e]KD01`34a<@0b/[:0;^k^`2[Zj/0b/[:
0;Ng]`39bLT00P3?cll01`2][Jd0a<C40;Vi^@32`/80a/K60;:b/P2`/;000P34a<@01`2n_[h0^;Rh
0<;2`P2VYZH0^;Rh0;Fe]@2i^KT00P2g]kL01`38b<P0d=3@0<W9b@33`l<0d=3@0=WIf@2g]kL00P3:
b/X01`2m_Kd0/[:b0<C4a03@d=00^;Rh0;jn_P32`/800P3?cll01`3;bl/0^;Rh09bLW02d];@0a<C4
0<;2`P34a<@00P3>c/h01`38b<P0`<300<S8b03@d=00[Zj^0<;2`P2[Zj/00P2a/K420<c<c0050<;2
`P39bLT0HV9R09RHV02b/[800P3Fe]H01`2TY:@0T92@0=SHf032`/80]KFe0:VYZ@2k^k/00P2KVi/0
102k^k/0]KFe0<C4a033`l<T0?oooa80ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol00`1VXol0ec?o0=Lc
o`0:0=Lco`80IZ?o1`3G<ol00`1VXol0ec?o0=Lco`0>0=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0
IZ?o0=Lco`3G<ol00P3G<ol206JSo`D0ec?o00<0IZ?o0=Lco`3G<ol03@3G<ol00`1VXol0ec?o0=Lc
o`070=Lco`0306JSo`3G<ol0ec?o00P0ec?o00<0IZ?o0=Lco`1VXol00P1VXol40=Lco`0309Wo`P1V
Xol0IZ?o0080ec?o0P1VXol30=Lco`0406JSo`3G<ol0IZ?o06JSo`@0ec?o9`3oool002D0oooo00<0
];Bd0<30`02i^KT00P39bLT01`3@d=00]kNg0:BTY02i^KT0b<S80;Vi^@3GemL00P2j^[X01`2k^k/0
_kno0;fm_@2/[:`0^[Zj0;Bd]02f][H00P34a<@01`2b/[80bl_;0;Ng]`2n_[h0alO70<K6aP2j^[X0
0P37alL01`36a/H0`<300;Ng]`36a/H0eMGE0;>c/`3:b/X00P2i^KT01`2`/;00d=3@0<C4a02b/[80
f=SH06i^KP35aLD00P2e]KD01`38b<P0_;bl0=7Ad@3Hf=P0_kno0=3@d02k^k/00P39bLT01`2^[Zh0
f=SH0;>c/`3:b/X0a/K60<S8b03Lg=`00P2a/K401`39bLT0_Kfm0;fm_@2o_kl0^KVi0:ZZZP32`/80
0P35aLD01`2][Jd0[Zj^0=;BdP39bLT0_Kfm0<G5a@39bLT00P2m_Kd01`2n_[h0_Kfm0<C4a03Bd]80
f=SH0;Rh^02b/[800P3;bl/01`3EeMD0aLG50=3@d03<c<`0[:b/0:ZZZP36a/H00P2l_;`01P2g]kL0
_;bl0=SHf035aLD0a/K60;6a/@<0[Jf]00L0_[jn0;Jf]P32`/80cLg=0;Fe]@2n_[h0][Jf00<0`L71
00H0hN7Q0<;2`P2m_Kd0[Jf]0<O7a`2/[:`209bLW0070:JVYP2[Zj/0ZJVY0<S8b030`<00]KFe0:j^
[P020=[JfP040<W9b@3alO40b/[:0?gmoB@0oooo1`3G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JS
o`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol03`3G<ol01P1VXol0ec?o0=Lco`1VXol0ec?o09Wo
`P`0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol206JSo`D0ec?o00@0IZ?o0=Lco`3G<ol0ec?o0P1VXol=
0=Lco`0306JSo`3G<ol0ec?o00@0ec?o0P1VXol80=Lco`@0IZ?o3@3G<ol00`1VXol0ec?o06JSo`05
06JSo`<0ec?o00L0IZ?o0=Lco`3G<ol0ec?o0?l0003G<ol0o`0002L0oooo000U0?ooo`030;Bd]030
`<00^KVi0080bLW900L0d=3@0;Ng]`2TY:@0^KVi0<S8b02i^KT0emOG0080^[Zj00L0^k^k0;no_`2m
_Kd0[:b/0;Zj^P2d];@0][Jf0080a<C400L0/[:b0<_;b`2g]kL0_[jn0<O7a`36a/H0^[Zj0080alO7
00L0a/K60<30`02g]kL0a/K60=GEe@2c/k<0b/[:0080^KVi00L0/;2`0=3@d034a<@0/[:b0=SHf01^
KVh0aLG50080]KFe00L0b<S80;bl_03AdM40f=SH0;no_`3@d=00^k^k0080bLW900L0[Zj^0=SHf02c
/k<0b/[:0<K6aP38b<P0g=cL0080/K6a00L0bLW90;fm_@2m_Kd0_kno0;Vi^@2ZZZX0`/;20080aLG5
00L0[Jf]0:j^[P3Bd]80bLW90;fm_@35aLD0bLW90080_Kfm00L0_[jn0;fm_@34a<@0d];B0=SHf02h
^;P0/[:b0080bl_;00L0eMGE0<G5a@3@d=00c<c<0:b/[02ZZZX0a/K60080_;bl00H0]kNg0;bl_03H
f=P0aLG50<K6aP2a/K430:f][@070;jn_P2f][H0`/;20<g=c@2e]KD0_[jn0;Jf]P030<71`@060>7Q
h@32`/80_Kfm0:f][@37alL0[:b/0P2LW9`01`2VYZH0Zj^[0:VYZ@38b<P0`<300;Fe]@2^[Zh00P3J
f]X01039bLT0lO7a0<[:bP3moOdT0?ooo`L0ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol00`1VXol0ec?o
0=Lco`030=Lco`0306JSo`3G<ol0ec?o00l0ec?o00H0IZ?o0=Lco`3G<ol0IZ?o0=Lco`2Iol8<0=Lc
o`0306JSo`3G<ol0ec?o00@0ec?o0P1VXol50=Lco`0406JSo`3G<ol0ec?o0=Lco`80IZ?o3@3G<ol0
0`1VXol0ec?o0=Lco`040=Lco`80IZ?o203G<ol406JSo`d0ec?o00<0IZ?o0=Lco`1VXol01@1VXol3
0=Lco`0706JSo`3G<ol0ec?o0=Lco`3o0000ec?o0?l0000W0?ooo`009@3oool20<;2`P0:0;^k^`2m
_Kd0_Kfm0;fm_@2n_[h0_Kfm0<G5a@30`<00clo?0<K6aP80];Bd00@0b<S80;fm_@31`L40^k^k0P2^
[Zh02P2n_[h0a/K60<K6aP34a<@0`l?30<_;b`34a<@0_Kfm0=;BdP3=cLd30<O7a`060;bl_034a<@0
b/[:0<30`02a/K40d=3@0P3:b/X01`37alL0bl_;0:b/[03Fe]H0[Zj^0;6a/@3=cLd00P2_[jl01`3D
e=@0b<S80<71`@3?cll0eMGE0=gMg@34a<@00P2YZJT01`2n_[h0clo?0;6a/@2NWYh0];Bd0<30`035
aLD00P33`l<00`2m_Kd0c/k>0<30`0020<?3``0;0;no_`2YZJT0_;bl0;bl_02f][H0a<C40<;2`P3<
c<`0a<C40<71`@3;bl/00P2`/;001`35aLD0f=SH0<[:bP2m_Kd0b<S80;Rh^02[Zj/00P2k^k/01`2X
Z:P0`/;20<S8b032`/80`<300<;2`P3Fe]H00P2m_Kd01`2k^k/0b/[:0<71`@3>c/h0`<300<C4a03;
bl/00P36a/H01`2m_Kd0cLg=0;Ng]`2l_;`0]kNg0<W9b@3;bl/00P37alL00`2d];@0^k^k0;Rh^002
0<30`00;0;Zj^P2c/k<0/;2`0;2`/027QhL0`<300:VYZ@2i^KT0YjNW0<S8b034a<@00P33`l<01038
b<P0a/K60<S8b02IVITT0?oooa80ec?o0P1VXolA0=Lco`0306JSo`3G<ol0ec?o00<0ec?o00D0IZ?o
0=Lco`1VXol0IZ?o0=Lco`0206JSo`L0ec?o0P1VXol20=Lco`80IZ?o2`3G<ol00`1VXol0ec?o0=Lc
o`070=Lco`80IZ?o1P3G<ol0101VXol0ec?o0=Lco`1VXolQ0=Lco`<0IZ?o00@0ec?o06JSo`3G<ol0
IZ?o1`3G<ol00`1VXol0oooo0?ooo`0U0?ooo`009@3oool00`2e]KD0_[jn0<S8b0020:^[Z`070;Zj
^P36a/H0alO70<K6aP38b<P0c/k>0;no_`020;Vi^@070<W9b@2][Jd0_Kfm0<O7a`2e]KD0[jn_0;bl
_0020;Jf]P070<C4a032`/80bLW90<30`034a<@0_kno0;:b/P020:NWY`070=?Cd`3<c<`0][Jf0;fm
_@32`/80_Kfm0<c<c0020;bl_0070;Vi^@39bLT0`/;20<S8b02LW9`0_Kfm0<_;b`020;Jf]P070<30
`034a<@0b/[:0;fm_@38b<P0j^[Z0<o?c`020=OGe`070:>SX`3Cdm<0]KFe0;Jf]P2e]KD0^k^k0=;B
dP020;no_`070=3@d02h^;P0_kno0=oOg`2o_kl0]KFe0:f][@020;2`/0070<C4a02k^k/0a<C40:f]
[@2d];@0b/[:0;Bd]0020=oOg`070=7Ad@39bLT0f=SH0;Vi^@30`<00a/K60=;BdP020=gMg@070<30
`02[Zj/0a/K60<K6aP39bLT0_Kfm0<K6aP020<;2`P070<_;b`3AdM40`/;20=3@d031`L40cLg=0<[:
bP020<;2`P070<30`032`/80]KFe0<K6aP38b<P0cLg=0;no_`020;^k^`070<o?c`38b<P0b/[:0;Ng
]`2c/k<0`L710;Vi^@020;Ng]`070<K6aP3>c/h0^KVi0<S8b030`<00_kno0<k>cP020<[:bP040<;2
`P2k^k/0_Kfm0<[:bR@0oooo0`3G<ol206JSo`X0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`090=Lc
o`<0IZ?o3@3G<ol00`1VXol0ec?o0=Lco`070=Lco`050?l0003G<ol0ec?o0=Lco`1VXol03P3G<ol3
06JSo`<0ec?o00<0IZ?o0=Lco`3G<ol03@3G<ol00`1VXol0ec?o0=Lco`0]0=LcobL0oooo000U0?oo
o`030;bl_02^[Zh0`L710080_;bl00L0W9bL0;Vi^@36a/H0Zj^[0=3@d032`/80_kno0080/;2`00L0
b<S80<;2`P2k^k/0[:b/0;Ng]`3:b/X0eMGE00<0`<3000H0WYjN0<K6aP36a/H0`<300;:b/P2WYjL2
0<[:bP070000002a/K40][Jf0<30`02k^k/0]kNg0<S8b0020<c<c0070=3@d03=cLd0^k^k0;fm_@2o
_kl0T92@0;Vi^@020:FUY@<0`/;200@0ZJVY08b<S02o_kl0`/;20P2k^k/01`2_[jl0d=3@0=3@d036
a/H0_Kfm0<[:bP38b<P00P34a<@0103@d=00`<300;:b/P2/[:`20<K6aP0:0:^[Z`2o_kl0_kno0<[:
bP3<c<`0e=CD0<;2`P36a/H0bLW90;fm_@80];Bd00L0MWIf0<W9b@2k^k/0b<S80;>c/`36a/H0`/;2
0080];Bd00L0^[Zj0;no_`2d];@0`l?30=;BdP36a/H0e=CD0080_kno00L0^;Rh0<c<c030`<00fMWI
0;^k^`3<c<`0hN7Q0080Y:BT00H0_kno0;^k^`39bLT0^k^k0<O7a`39bLT30<[:bP070;2`/03?cll0
]KFe0<S8b02m_Kd0]kNg0:n_[`020;Ng]`070;fm_@3Hf=P0Y:BT0<G5a@2d];@0Y:BT0<c<c0020=;B
dP040;6a/@2[Zj/0dM7A0=OGeb@0oooo00<0ec?o06JSo`3G<ol00P3G<ol0101VXol0ec?o0=Lco`1V
Xol30=Lco`80IZ?o0`3G<ol00`1VXol0ec?o0=Lco`040=Lco`0406JSo`3G<ol0ec?o0=Lco`80IZ?o
0P3G<ol00`3oool0IZ?o0=Lco`0;0=Lco`0406JSo`3G<ol0IZ?o06JSo`<0ec?o0P1VXol40=Lco`03
06JSo`3G<ol0ec?o00P0ec?o0P1VXol20=Lco`0306JSo`3G<ol0ec?o00T0ec?o00<0VOo20=Lco`3G
<ol05P3G<ol206JSo`T0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`020=Lco`04
06JSo`3G<ol0ec?o06JSo`<0ec?o0P1VXol20=LcobL0oooo000U0?ooo`030<[:bP2e]KD0`/;20080
a<C400L0b<S80;no_`3<c<`0a/K60<_;b`32`/80d];B0080alO700L0][Jf0:FUY@2n_[h0^[Zj0;^k
^`38b<P0_kno0080aLG500L0cLg=0<C4a02g]kL0^;Rh0;Bd]032`/80_[jn0080a/K600L0Xj>S0;jn
_P2o_kl0/[:b0;Rh^02d];@0^[Zj0080_;bl00L0bl_;0<C4a03IfMT0_kno0=;BdP38b<P0]kNg0080
X:2P00L0^k^k0;Vi^@36a/H0a<C40=kNgP34a<@0dM7A0080]KFe00L0`L710=?Cd`2`/;00dM7A0:VY
Z@38b<P0[Zj^0080Zj^[00L0`/;20<30`032`/80^k^k0<K6aP2o_kl0YZJV0080/[:b00L0b<S80<;2
`P36a/H0/K6a0;Bd]02n_[h0^[Zj0080IVIV00L0Zj^[0;no_`2][Jd0f=SH0;Bd]02m_Kd0`<300080
];Bd00L0dm?C0<O7a`3?cll0cLg=0=KFeP2e]KD0b/[:0080^;Rh00L0b/[:0<30`02m_Kd0c/k>0;Ng
]`2o_kl0/;2`0080`L7100L0_kno0<;2`P3Bd]80`l?30<c<c03Bd]80]kNg0080a/K600L0d=3@0;>c
/`2/[:`0];Bd0;>c/`32`/80]kNg0080]KFe00L0d=3@0;no_`2k^k/0^[Zj0<30`038b<P0^k^k0080
a/K600@0_Kfm0=?Cd`2k^k/0XZ:R903oool?0=Lco`0306JSo`3G<ol0ec?o00h0ec?o00@0IZ?o0=Lc
o`3G<ol0IZ?o303G<ol206JSo`/0ec?o00@0IZ?o0=Lco`1VXol0ec?o0`1VXol60=Lco`<0IZ?o0`3G
<ol0101VXol0ec?o0=Lco`3G<ol209Wo`P0306JSo`3G<ol0IZ?o01D0ec?o00<0IZ?o0=Lco`3G<ol0
2`3G<ol00`1VXol0ec?o0=Lco`0@0=Lco`0306JSo`3oool0oooo02D0oooo000U0?ooo`80`<3000X0
b<S80;Fe]@2e]KD0c<c<0<K6aP30`<00dM7A0;fm_@2i^KT0]kNg0P30`<001`32`/80`<300;Zj^P2f
][H0_;bl0<71`@2g]kL00P2n_[h01P2h^;P0`/;20;Jf]P2b/[80a<C40:NWY`<0_;bl00L0a/K60<;2
`P2k^k/0^k^k0=3@d02[Zj/0b/[:0080_Kfm00<0d];B0<_;b`3Bd]800P2i^KT02@3<c<`0f=SH0<S8
b038b<P0h^;R0;Jf]P2VYZH0Xj>S0<K6aP020;Ng]`80a/K600L0b/[:0<71`@3=cLd0][Jf0=WIf@3;
bl/0c<c<0080^KVi00L0_kno0<K6aP2e]KD0`<300<_;b`38b<P0YJFU0080[jn_00L0`L710<;2`P2g
]kL0a/K60;6a/@2k^k/0`/;20080clo?00L0e]KF0<k>cP3:b/X0_[jn0<K6aP32`/80hN7Q0080`L71
00L0^[Zj0;fm_@3=cLd0bl_;0;jn_P30`<00]KFe0080/;2`00L0`L710;>c/`3De=@0_Kfm0<O7a`3=
cLd0`<300080`/;200L0e]KF0>;RhP37alL0[Jf]0;no_`2i^KT0d=3@0080^k^k00L0cLg=0;Vi^@2M
WId0[jn_0=3@d03;bl/0];Bd0080[Jf]00L0k^k^0;Bd]037alL0_Kfm0:b/[039bLT0_kno0080f=SH
00@0alO70;^k^`2SXj<0^[Zj903ooolJ0=Lco`0306JSo`3G<ol0IZ?o00P0ec?o00<0IZ?o0=Lco`3G
<ol0303G<ol206JSoa@0ec?o0`1VXol40=Lco`0306JSo`3G<ol0ec?o0180ec?o0P1VXol<0=Lco`03
06JSo`3G<ol0ec?o00D0ec?o0P1VXol30=Lco`80IZ?o00D0o`000=Lco`3G<ol0ec?o06JSo`060=Lc
o`0306JSo`3G<ol0oooo02H0oooo000U0?ooo`030;fm_@32`/80b<S80080^k^k00@0Zj^[0:j^[P2o
_kl0e=CD0P3>c/h02P36a/H0a<C40<C4a02n_[h0b<S80<_;b`36a/H0]kNg0;Rh^02k^k/20<S8b007
0<30`02g]kL0alO70<30`02d];@0`<300<;2`P020;no_`070<C4a03:b/X0^KVi0<;2`P2g]kL0b/[:
0;no_`020:VYZ@070<K6aP38b<P0dM7A0;Rh^02o_kl0`<300;jn_P020;Ng]`070:n_[`32`/80`<30
0<C4a02`/;00[Jf]0;2`/0020<[:bP070>7Qh@34a<@0YJFU0;Fe]@32`/80gmoO0;no_`020<30`007
0<S8b02g]kL0[Zj^0<g=c@3:b/X0/[:b0:^[Z`020<S8b0070;Rh^02a/K40bl_;0<;2`P2e]KD0clo?
0<S8b0020<_;b`070<O7a`33`l<0aLG50<71`@2o_kl0`<300=[JfP020<G5a@070<;2`P3;bl/0XJ6Q
0<O7a`2m_Kd0bLW90<o?c`020;no_`070<?3``34a<@0`/;20=;BdP3=cLd0/[:b0<K6aP020;^k^`07
0<c<c03>c/h0UYJF0;Vi^@2a/K40[Jf]0<G5a@020=_Kf`070;no_`2_[jl0clo?0<C4a03>c/h0b<S8
0>c/k0020=_Kf`070;Rh^03MgMd0alO70;:b/P2o_kl0`<300;Fe]@020<?3``040<c<c02k^k/0cLg=
0<30`2@0oooo1@3G<ol206JSob00ec?o0P1VXol90=Lco`0406JSo`3G<ol0ec?o0=Lco`<0IZ?o103G
<ol00`1VXol0ec?o0=Lco`060=Lco`0306JSo`3G<ol0ec?o0080IZ?o0`3G<ol00`1VXol0ec?o0=Lc
o`0@0=Lco`0306JSo`3G<ol0ec?o00T0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol0101VXol0ec?o06JS
o`1VXol40=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0o`000=Lco`3G<ol00`3G<ol00`1VXol0ec?o
0=Lco`070=LcobL0oooo000U0?ooo`030;bl_02f][H0/k>c0080^;Rh00L0_[jn0<;2`P2i^KT0^KVi
0;2`/034a<@0/K6a0080aLG500L0a/K60;bl_02l_;`0cLg=0<;2`P2m_Kd0^KVi0080b/[:00L0]KFe
0<c<c036a/H0`<300<;2`P38b<P0][Jf0080_;bl00<0`<300;fm_@2YZJT00P2n_[h02`2`/;00bl_;
0;no_`2o_kl0[:b/0;Ng]`2d];@0_[jn0<[:bP3<c<`0b/[:0080lO7a00L0g=cL0=[JfP2o_kl0alO7
0<[:bP2a/K40^KVi0080c/k>00L0`/;20<[:bP30`<00bl_;0;^k^`32`/80g]kN0080bLW900H0f][J
0<30`02e]KD0aLG50<S8b02m_Kd30;^k^`070:f][@3?cll0`<300;Vi^@38b<P0_[jn0<30`0020<S8
b0070<g=c@2e]KD0`<300;fm_@2c/k<0c<c<0<o?c`020<;2`P070;6a/@2o_kl0ZJVY0<30`031`L40
`l?30<c<c0020;>c/`040;6a/@2/[:`0^KVi0<?3``80_kno00X0gMgM0=CDe03De=@0_Kfm09RHV03A
dM40]kNg0;:b/P2d];@0b<S80P3:b/X01`38b<P0e]KF0;Jf]P3=cLd0[:b/0;Rh^02ZZZX00P2o_kl0
1`2a/K40aLG50<S8b03:b/X0cLg=0<K6aP3>c/h00P2e]KD01034a<@0^[Zj0<;2`P2a/K4T0?ooo`T0
ec?o00<0IZ?o0=Lco`1VXol05P3G<ol0101VXol0ec?o0=Lco`1VXol30=Lco`0306JSo`3G<ol0ec?o
00@0ec?o0P3o00050=Lco`0306JSo`3G<ol0ec?o01<0ec?o00<0IZ?o0=Lco`3G<ol03`3G<ol00`1V
Xol0ec?o06JSo`060=Lco`80IZ?o203G<ol0101VXol0ec?o0=Lco`1VXol80=Lco`0306JSo`3G<ol0
IZ?o0080ec?o00<0IZ?o0=Lco`3G<ol02@3G<ol00`1VXol0oooo0?ooo`0U0?ooo`009@3oool00`2l
_;`0Zj^[0<K6aP020:>SX`070;Rh^02f][H0b<S80;no_`30`<00][Jf0:VYZ@020<o?c`070<G5a@2d
];@0`l?30<O7a`32`/80`<300<G5a@020<O7a`050<71`@37alL0bLW90<o?c`2h^;P00P34a<@20:^[
Z`070;Vi^@2c/k<0a<C40<c<c02`/;00`<300;fm_@020;Vi^@070;Rh^038b<P0`/;20;Ng]`3:b/X0
_kno0<S8b0020<k>cP070:RXZ033`l<0bl_;0:^[Z`2e]KD0c/k>0<c<c0020;Bd]0070<C4a039bLT0
[Zj^0<K6aP2k^k/0^KVi0:n_[`020;^k^`070<O7a`3@d=00`<300:f][@3<c<`0]KFe0::RXP020;^k
^`030<W9b@2j^[X0_;bl0080_;bl00T0c<c<0:n_[`3Bd]80d];B0=3@d039bLT0b<S80;fm_@3De=@0
0P3;bl/20;fm_@0709jNWP31`L40/k>c0;no_`2LW9`0a/K60:FUY@020<W9b@040<_;b`2h^;P0^k^k
0;Vi^@80_[jn00X0n?Sh0:JVYP2VYZH0X:2P0;jn_P28R8P0a/K60;Vi^@30`<00^[Zj0P3De=@01`3J
f]X0^k^k0;>c/`2m_Kd0b/[:0<c<c02f][H00P2KVi/01`3Ogml0a<C40;^k^`2WYjL0`/;20<o?c`2g
]kL00P31`L40103>c/h0a<C40<g=c@2i^KTT0?ooo`030=Lco`1VXol0ec?o0080IZ?o1P3G<ol00`1V
Xol0ec?o0=Lco`0@0=Lco`80IZ?o103G<ol00`1VXol0ec?o0=Lco`0;0=Lco`0406JSo`3G<ol0ec?o
06JSo`L0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`050=Lco`0406JSo`3G<ol0ec?o06JSo`P0ec?o
00<0IZ?o0=Lco`3G<ol02@3G<ol01`1VXol0ec?o0=Lco`3G<ol0IZ?o0=Lco`1VXol0203G<ol01P3o
0000IZ?o06JSo`1VXol0ec?o06JSo`d0ec?o0P1VXol30=Lco`0306JSo`3G<ol0ec?o00L0ec?o9`3o
ool002D0oooo00<0_;bl0:^[Z`36a/H00P2SXj<01`2h^;P0][Jf0<S8b02o_kl0`<300;Jf]P2YZJT0
0P3?cll01`35aLD0];Bd0<?3``37alL0`/;20<30`035aLD00P37alL01@31`L40alO70<W9b@3?cll0
^;Rh0080a<C40P2[Zj/01`2i^KT0/k>c0<C4a03<c<`0/;2`0<30`02m_Kd00P2i^KT01`2h^;P0b<S8
0<;2`P2g]kL0b/[:0;no_`38b<P00P3>c/h01`2XZ:P0`l?30<_;b`2[Zj/0]KFe0<k>cP3<c<`00P2d
];@01`34a<@0bLW90:j^[P36a/H0^k^k0;Vi^@2_[jl00P2k^k/01`37alL0d=3@0<30`02][Jd0c<c<
0;Fe]@2RXZ800P2k^k/00`39bLT0^[Zj0;bl_0020;bl_0090<c<c02_[jl0d];B0=;BdP3@d=00bLW9
0<S8b02m_Kd0e=CD0080bl_;0P2m_Kd01`2NWYh0`L710;>c/`2o_kl0W9bL0<K6aP2UYJD00P39bLT0
103;bl/0^;Rh0;^k^`2i^KT20;jn_P0:0?Shn02VYZH0YZJV0:2PX02n_[h0R8R80<K6aP2i^KT0`<30
0;Zj^P80e=CD00L0f][J0;^k^`2c/k<0_Kfm0<[:bP3<c<`0][Jf0080Vi^K00L0gmoO0<C4a02k^k/0
YjNW0<;2`P3?cll0]kNg0080`L7100@0c/k>0<C4a03=cLd0^KVi903oool00`3G<ol0IZ?o0=Lco`02
06JSo`H0ec?o00<0IZ?o0=Lco`3G<ol0403G<ol206JSo`@0ec?o00<0IZ?o0=Lco`3G<ol02`3G<ol0
101VXol0ec?o0=Lco`1VXol70=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol01@3G<ol0101VXol0ec?o
0=Lco`1VXol80=Lco`0306JSo`3G<ol0ec?o00T0ec?o00L0IZ?o0=Lco`3G<ol0ec?o06JSo`3G<ol0
IZ?o00P0ec?o00H0o`0006JSo`1VXol0IZ?o0=Lco`1VXol=0=Lco`80IZ?o0`3G<ol00`1VXol0ec?o
0=Lco`070=LcobL0oooo000U0?ooo`030<W9b@3:b/X0_Kfm0080b<S800<0]KFe0;fm_@2n_[h00P2e
]KD0102i^KT0`<300;fm_@2m_Kd20<30`0050;no_`2OWil0^KVi0<S8b036a/H00P38b<P01`2n_[h0
b/[:0<[:bP34a<@0`<300<K6aP2o_kl00P2m_Kd01`2e]KD0_Kfm0;Fe]@2TY:@0a/K60:f][@3:b/X0
0P37alL01`34a<@0`/;20;Zj^P3Cdm<0`<300=?Cd`3<c<`00P30`<001@2c/k<0[Jf]0<k>cP2m_Kd0
b<S80080`/;20P2XZ:P01`33`l<0c/k>0;no_`3@d=00^k^k0;Zj^P2UYJD00P3@d=001`2g]kL0_[jn
0:f][@1oOgl0alO70<30`02UYJD00P2k^k/01`3Fe]H0e=CD0=;BdP39bLT0]kNg0:j^[P2HV9P00P3I
fMT01`2k^k/0b<S80;jn_P2n_[h0^k^k0<[:bP3Ogml00P2^[Zh01`2k^k/0`l?30;Jf]P2g]kL0bLW9
0<C4a02f][H00P2h^;P01034a<@0a/K60;Fe]@3De=@20<c<c00:0;fm_@2^[Zh0[Zj^0=;BdP34a<@0
_kno0<S8b02QXJ40/[:b0<_;b`80b/[:00D0a/K60;2`/030`<00`<300<K6aP020<S8b080^k^k00L0
bl_;0:f][@3@d=00a<C40=3@d03MgMd0e=CD0080`L7100@0bLW90<k>cP2h^;P0]KFe903ooolA0=Lc
o`0306JSo`3G<ol0ec?o00l0ec?o00<0IZ?o0=Lco`1VXol03@3G<ol00`1VXol0ec?o0=Lco`030=Lc
o`80IZ?o1P3G<ol00`1VXol0ec?o0=Lco`020=Lco`0506JSo`2Iol80ec?o0=Lco`1VXol01`3G<ol2
06JSo`T0ec?o0P1VXol@0=Lco`80IZ?o103G<ol206JSo`@0ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol0
0`1VXol0ec?o0=Lco`090=LcobL0oooo000U0?ooo`030<;2`P2ZZZX0a/K60080`/;200L0_;bl0<;2
`P32`/80XJ6Q0<30`02a/K40Xj>S0080`l?300L0`<300<_;b`2m_Kd0_;bl0<_;b`35aLD0[Jf]0080
WYjN00L0_kno0;6a/@2h^;P0a/K60;Rh^03>c/h0`<300080^k^k00L0YJFU0;2`/037alL0`/;20;Rh
^02f][H0[Zj^0080d];B00L0d=3@0=_Kf`2UYJD0Xj>S0<?3``34a<@0^k^k0080^;Rh00L0_Kfm0<O7
a`39bLT0`L710<;2`P2j^[X0alO70080bl_;00L0e]KF0>KViP32`/80a<C40;Bd]02KVi/0fm_K0080
^;Rh00L0eMGE0=?Cd`2f][H0_kno0<S8b02_[jl0]kNg0080Zj^[00L0gmoO0;Zj^P2[Zj/0_;bl0<[:
bP2][Jd0_kno0080b<S800L0_kno0;2`/02e]KD0a/K60<k>cP2m_Kd0][Jf0080[Zj^00L0]KFe0<S8
b03>c/h0gmoO0;Jf]P3Jf]X0/[:b0080^KVi00L0f=SH0:NWY`3@d=00`l?30;Rh^037alL0gMgM0080
ZZZZ00L0dm?C0<G5a@3:b/X0];Bd0=?Cd`32`/80a/K60080a<C400L0bl_;0;Ng]`2j^[X0c<c<0;no
_`2e]KD0b<S80080_kno00L0`<300<C4a030`<00cLg=0;:b/P2h^;P0`<300080Ti>C00@0a<C40<K6
aP3Cdm<0[jn_903oool00`3G<ol0IZ?o0=Lco`050=Lco`0406JSo`3G<ol0IZ?o06JSo`P0ec?o0`1V
Xol00`3G<ol0IZ?o0=Lco`060=Lco`80IZ?o103G<ol00`1VXol0ec?o0=Lco`020=Lco`80IZ?o3`3G
<ol01@3o0000ec?o0=Lco`3G<ol0IZ?o00P0ec?o00@0IZ?o0=Lco`1VXol0IZ?o0P3G<ol0101VXol0
ec?o0=Lco`1VXol40=Lco`0306JSo`3G<ol0ec?o00<0ec?o0P1VXol60=Lco`0506JSo`3G<ol0ec?o
0=Lco`1VXol01@3G<ol206JSoaH0ec?o00<0IZ?o0=Lco`3G<ol00P1VXol30=Lco`0306JSo`3oool0
oooo02D0oooo000U0?ooo`030;fm_@32`/80cLg=0080`<3000L0a/K60<;2`P30`<00_Kfm0;no_`30
`<00_Kfm0080c/k>00L0b<S80;^k^`35aLD0clo?0;Ng]`2/[:`0cLg=0080_kno00L0_[jn0;fm_@2j
^[X0_;bl0;Vi^@2[Zj/0b/[:0080]kNg0P30`<001@2o_kl0b<S80;Zj^P2i^KT0_kno0080b/[:00L0
cLg=0;Jf]P2h^;P0`L710;2`/02e]KD0clo?0080^k^k00L0/k>c0:b/[03;bl/0a<C40<o?c`3Cdm<0
d=3@0080bl_;00L0d];B0=CDe02o_kl0^k^k0:n_[`3De=@0[jn_0080a<C400L0`<300;bl_03;bl/0
`/;20<c<c032`/80_kno0080b<S800L0cLg=0;:b/P30`<00/[:b0<71`@2TY:@0]kNg0080c<c<00L0
WinO0;fm_@2i^KT0Z:RX0<G5a@2l_;`0fm_K0080YjNW00L0d];B0<;2`P2f][H0`/;20<C4a02h^;P0
b/[:0080b<S800L0`/;20<C4a02o_kl0/[:b0:n_[`2UYJD0`<300080^;Rh00L0^k^k0;Bd]03=cLd0
a/K60<g=c@2^[Zh0ZZZZ0080^k^k00D0a<C40:FUY@2f][H0VIVI0<G5a@020;Ng]`80]KFe00L0alO7
0<g=c@2d];@0^;Rh0<_;b`2k^k/0`/;20080bLW900@0[Jf]0:b/[031`L40Ng]k903ooolC0=Lco`03
06JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol03P3G<ol00`1VXol0ec?o0=Lco`030=Lco`03
06JSo`3G<ol0ec?o00T0ec?o00<0IZ?o0=Lco`1VXol0303G<ol01@1VXol0ec?o06JSo`3G<ol0IZ?o
00<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o0`3G<ol206JSo``0ec?o0`1VXol80=Lco`80IZ?o0`3G<ol0
0`1VXol0ec?o06JSo`0>0=Lco`80IZ?o00<0ec?o09Wo`P3oool09P3oool002D0oooo00<0];Bd0;Zj
^P2][Jd00P2e]KD01`2g]kL0a/K60;no_`37alL0bl_;0;^k^`34a<@00P39bLT01`32`/80a<C40:f]
[@3;bl/0`/;20:f][@2[Zj/00P39bLT01`32`/80`L710<O7a`37alL0^[Zj0<;2`P39bLT00P2m_Kd0
1`39bLT0cLg=0:j^[P2][Jd0/[:b0<O7a`36a/H00P3=cLd01`3:b/X0_[jn0<_;b`31`L40a/K60<?3
``3@d=000P2g]kL01`2][Jd0e=CD0<;2`P2f][H0bLW90:^[Z`3?cll00P29RHT01`38b<P0][Jf0<S8
b02RXZ80`/;20<30`038b<P00P2g]kL01`30`<00c<c<0<O7a`34a<@0`/;20:^[Z`31`L400P3Kfm/0
1`2n_[h0emOG0<K6aP3:b/X0^KVi0<C4a02UYJD00P2n_[h01`2j^[X0MWIf0;Ng]`33`l<0alO70=oO
g`3Ph>000P32`/801`2j^[X0_[jn0=WIf@38b<P0c<c<0;^k^`33`l<00P34a<@01`2h^;P0e]KF0<S8
b02VYZH0_Kfm0<g=c@36a/H00`38b<P01P2j^[X0^KVi0=gMg@34a<@0TI6A0;>c/`80b<S800L0/;2`
0;fm_@2d];@0Shn?0;Vi^@2IVIT0_kno0080bLW900L0`/;20<C4a034a<@0bl_;0<;2`P3Cdm<0cLg=
0080c<c<00@0]KFe0<C4a02b/[80Z:RX903oool20=Lco`0306JSo`3G<ol0ec?o00/0ec?o00<0IZ?o
0=Lco`3G<ol00P1VXol=0=Lco`<0IZ?o3@3G<ol00`1VXol0ec?o0=Lco`020=Lco`0406JSo`3G<ol0
IZ?o06JSo`<0ec?o00<0IZ?o0=Lco`3G<ol0203G<ol00`1VXol0ec?o0=Lco`070=Lco`0506JSo`3G
<ol0ec?o0=Lco`2Iol804`3G<ol00`1VXol0ec?o0=Lco`080=Lco`0506JSo`3G<ol0ec?o0=Lco`1V
Xol00P3G<ol00`1VXol0ec?o06JSo`0>0=Lco`80IZ?o9`3oool002D0oooo00<0]KFe0;Zj^P3IfMT0
0P2b/[820;Ng]`050<30`02l_;`0^;Rh0<O7a`36a/H00P39bLT01`2k^k/0b/[:0<;2`P2d];@0]kNg
0<W9b@2i^KT00P35aLD01`2i^KT0c<c<0<O7a`34a<@0]KFe0;2`/03=cLd00P3IfMT00`2GUiL0b<S8
0<;2`P020;jn_P0;0:NWY`39bLT0_kno0;no_`31`L40bLW90<O7a`3@d=00a/K60;Fe]@3?cll00P2g
]kL01`2^[Zh0bLW90<W9b@3<c<`0clo?0<_;b`31`L400P2i^KT01`37alL0/[:b0:^[Z`3Fe]H0b<S8
0;jn_P2j^[X00P3=cLd01`38b<P0c<c<0<S8b02n_[h0/;2`0;Rh^02_[jl00P2k^k/01`38b<P0`/;2
0<K6aP2m_Kd0^k^k0;:b/P3=cLd00P20P8001`36a/H0X:2P0:^[Z`3@d=00e=CD0=3@d03<c<`00P2h
^;P01P3;bl/0b<S80<C4a02c/k<0`<300<[:bP<0_Kfm00L0^KVi0;no_`2][Jd0T92@0<[:bP2e]KD0
a/K60080`l?300L0^k^k0<K6aP2UYJD0[Zj^0<k>cP3=cLd0WinO0080^KVi00L0c<c<0;fm_@3:b/X0
[Jf]0;2`/031`L40alO70080b/[:00L0c/k>0<K6aP30`<00_Kfm0<?3``39bLT0_kno0080bl_;00@0
cLg=0=?Cd`2o_kl0Zj^[903oool30=Lco`80IZ?o5`3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o00@0
ec?o00<0IZ?o0=Lco`3G<ol02P3G<ol00`1VXol0ec?o0=Lco`070=Lco`80IZ?o2P3G<ol00`1VXol0
ec?o06JSo`070=Lco`0506JSo`3G<ol0IZ?o06JSo`3G<ol00P1VXolA0=Lco`80IZ?o1`3G<ol206JS
o`80ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol206JSoa00ec?o00<0IZ?o0?ooo`3oool09@3oool002D0
oooo00<0/K6a0;jn_P30`<000P32`/820<C4a0040<W9b@2d];@0`<300<30`0<0a<C400L0_;bl0;:b
/P2b/[80^k^k0;Vi^@2g]kL0a<C40080_Kfm00L0ZJVY0;Ng]`2e]KD0a/K60;Zj^P2o_kl0`L710080
]kNg00L0Vi^K0;:b/P2m_Kd0`<300<K6aP2l_;`0bl_;0080_Kfm00L0_;bl0=3@d02j^[X0clo?0<?3
``3?cll0];Bd0080dM7A00H0_kno0:b/[03AdM40alO70<g=c@3;bl/30<30`0070<S8b02n_[h0^k^k
0<?3``3AdM40`/;20<S8b0020;>c/`070<;2`P3?cll0/k>c0<30`03:b/X0a/K60;:b/P020<C4a003
0;no_`36a/H0_Kfm0080bl_;00/0aLG50:j^[P2o_kl0_kno0;^k^`2FUYH0_[jn0<K6aP32`/80c/k>
0;no_`020;Rh^0070<[:bP2m_Kd0_[jn0;:b/P2f][H0aLG50<;2`P020:j^[P80_Kfm00D0[Zj^0;Ng
]`3QhN40^KVi0:f][@020<71`@070<C4a03Bd]80_kno0:BTY03:b/X0YjNW0:VYZ@020;Jf]P070<S8
b03@d=00b<S80;no_`3Jf]X0k>c/0=7Ad@020:j^[P070<30`02c/k<0[Jf]0<30`032`/80_kno0<30
`0020;2`/0040=;BdP30`<00_[jn0:^[Zb@0oooo00<0IZ?o0=Lco`3G<ol0303G<ol206JSo`H0ec?o
00<0IZ?o0=Lco`3G<ol01P3G<ol206JSoa40ec?o00<0IZ?o0=Lco`3G<ol0503G<ol00`1VXol0ec?o
0=Lco`060=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol02P3G<ol0101VXol0ec?o0=Lco`3G<ol206JS
o`80ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`050=Lco`0406JSo`3G<ol0IZ?o06JSo`L0ec?o00@0
o`000=Lco`1VXol0IZ?o0P3G<ol00`1VXol0ec?o0=Lco`020=Lco`80IZ?o0`3G<ol00`1VXol0oooo
0?ooo`0U0?ooo`009@3oool00`2[Zj/0][Jf0<C4a00209bLW0070;Bd]02j^[X0YZJV0;bl_035aLD0
a/K60<71`@020;2`/0070<o?c`38b<P0a/K60<_;b`2WYjL0_kno0:VYZ@020;^k^`070<[:bP2j^[X0
/[:b0;:b/P2f][H0`l?30<K6aP020;Vi^@070;^k^`3;bl/0][Jf0;jn_P2m_Kd0ZJVY0;>c/`030<;2
`P050<c<c02d];@0/K6a0<g=c@36a/H00`30`<001P2k^k/0c/k>0=7Ad@2h^;P0/[:b0=SHf0<0bLW9
00L0alO70::RXP3De=@0YjNW0<;2`P3/k>`0^KVi0080a<C400L0b/[:0;>c/`34a<@0`/;20:^[Z`2o
_kl0bl_;0080]kNg00L0[Zj^0<O7a`3=cLd0b<S80=SHf030`<00a<C40080`<3000L0];Bd09jNWP3<
c<`0a<C40<K6aP2h^;P0UIFE0080j>SX00D0`/;20<S8b02f][H0[Jf]0=;BdP020;fm_@80a/K600L0
_;bl0<_;b`38b<P0VIVI0:j^[P2d];@0`<300080_Kfm00L0clo?0;jn_P3Ogml0`L710:2PX030`<00
_kno0080`/;200L0b<S80;bl_02l_;`0`<300;^k^`2i^KT0bLW90080];Bd00<0bl_;0<G5a@3Cdm<0
0P34a<@02039bLT0_kno0:b/[02/[:`0clo?0:2PX02j^[X0a/K6903oool00`1VXol0ec?o0=Lco`02
06JSo`80ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol206JSo`@0ec?o00<0IZ?o0=Lco`1VXol0103G<ol2
06JSo`X0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JSo`3G<ol0
ec?o00<0ec?o00D0IZ?o0=Lco`1VXol0ec?o0?l000070=Lco`0306JSo`3G<ol0ec?o0080ec?o00<0
IZ?o0=Lco`3G<ol01`3G<ol00`1VXol0ec?o0=Lco`020=Lco`0306JSo`3o0000o`0000<0ec?o00<0
IZ?o0=Lco`3G<ol01P3G<ol206JSo`P0ec?o00<0IZ?o0=Lco`3G<ol04P3G<ol206JSo`040=Lco`1V
Xol0ec?o0=LcobL0oooo000U0?ooo`030;Jf]P2i^KT0a<C40080^KVi00L0bLW90<K6aP2m_Kd0/k>c
0;^k^`33`l<0`<300080Y:BT00L0bl_;0;Bd]034a<@0dm?C0:VYZ@2UYJD0]kNg0080/[:b00D0/;2`
0;jn_P36a/H0_Kfm0=SHf0040<;2`P070;:b/P32`/80^[Zj0<30`031`L40^KVi0<O7a`020;:b/P07
0;Ng]`3De=@0clo?0<O7a`2f][H0/k>c0<;2`P0209jNWP070;no_`2c/k<0a<C40<C4a03no_h0<30`
0:BTY00209>CT`070<;2`P36a/H0_[jn0;Zj^P2a/K40a/K60=;BdP020<c<c0070;Ng]`2o_kl0/[:b
0<S8b036a/H0ZJVY0<K6aP020;Vi^@070<c<c02n_[h0[Jf]0;^k^`2i^KT0b<S80;jn_P020;bl_007
0;no_`2OWil0][Jf08j>SP3Cdm<0]kNg0:VYZ@030<C4a0060:j^[P34a<@0]kNg09nOW`34a<@0a/K6
0P2m_Kd01`38b<P0^k^k0;^k^`30`<00a/K60<30`03:b/X00P2_[jl01`2i^KT0_[jn0<W9b@37alL0
]kNg0:>SX`2@T9000P2[Zj/01`34a<@0f=SH0<K6aP2][Jd0^k^k0;2`/036a/H00P3;bl/00`2l_;`0
`/;20;fm_@020;fm_@080<c<c03@d=00f][J0=[JfP3:b/X0]kNg0;:b/P2UYJDT0?ooo``0ec?o0P1V
Xol40=Lco`80IZ?o00@0ec?o06JSo`1VXol0IZ?o203G<ol00`1VXol0ec?o0=Lco`040=Lco`80IZ?o
1`3G<ol206JSo`@0ec?o00<0o`000?Goc01VXol00P1VXol40=Lco`0306JSo`3G<ol0ec?o00@0ec?o
00@0IZ?o0=Lco`3G<ol0IZ?o1@3G<ol00`1VXol0ec?o0=Lco`050=Lco`0306JSo`3G<ol0IZ?o0080
ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`020=Lco`0306JSo`3G<ol0ec?o00T0ec?o0P1VXol50=Lc
o`@0IZ?o0`3G<ol00`1VXol0ec?o06JSo`0>0=Lco`80IZ?o9`3oool002D0oooo00<0][Jf0;Vi^@34
a<@00P2i^KT01`39bLT0a/K60;fm_@2c/k<0^k^k0<?3``30`<000P2TY:@01`3;bl/0];Bd0<C4a03C
dm<0ZJVY0:FUY@2g]kL00P2b/[801@2`/;00_[jn0<K6aP2m_Kd0f=SH00@0`/;200L0/[:b0<;2`P2j
^[X0`<300<71`@2i^KT0alO70080/[:b00L0]kNg0=CDe03?cll0alO70;Jf]P2c/k<0`/;20080WYjN
00L0_kno0;>c/`34a<@0a<C40?knoP0`<300Y:BT0080Ti>C00L0`/;20<K6aP2n_[h0^[Zj0;6a/@36
a/H0d];B0080c<c<00L0]kNg0;no_`2b/[80b<S80<K6aP2YZJT0a/K60080^KVi00L0c<c<0;jn_P2]
[Jd0^k^k0;Vi^@38b<P0_[jn0080_;bl00L0_kno09nOW`2f][H0SXj>0=?Cd`2g]kL0ZJVY00<0a<C4
00H0[Zj^0<C4a02g]kL0WinO0<C4a036a/H20;fm_@070<S8b02k^k/0^k^k0<30`036a/H0`<300<[:
bP020:n_[`070;Vi^@2n_[h0bLW90<O7a`2g]kL0Xj>S092@T0020:^[Z`070<C4a03Hf=P0a/K60:f]
[@2k^k/0/;2`0<K6aP020<_;b`030;bl_032`/80_Kfm0080_Kfm00P0c<c<0=3@d03Jf]X0f][J0<[:
bP2g]kL0/[:b0:FUYB@0oooo303G<ol206JSo`@0ec?o0P1VXol0103G<ol0IZ?o06JSo`1VXol80=Lc
o`0306JSo`3G<ol0ec?o00@0ec?o0P1VXol70=Lco`80IZ?o103G<ol00`3o0000mOo<06JSo`0206JS
o`@0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol0101VXol0ec?o0=Lco`1VXol50=Lco`0306JSo`3G<ol0
ec?o00D0ec?o00<0IZ?o0=Lco`1VXol00P3G<ol01@1VXol0ec?o0=Lco`3G<ol0IZ?o0080ec?o00<0
IZ?o0=Lco`3G<ol02@3G<ol206JSo`D0ec?o101VXol30=Lco`0306JSo`3G<ol0IZ?o00h0ec?o0P1V
XolW0?ooo`009@3oool00`2n_[h0^[Zj0;fm_@020<K6aP070<;2`P36a/H0][Jf0;no_`30`<00cLg=
0<W9b@020<c<c0070;jn_P2i^KT0b<S80;Rh^02[Zj/0QhN707MgM`020;Rh^00709nOW`3AdM40`/;2
0<30`036a/H0_;bl0<?3``020=KFeP070:f][@3=cLd0/[:b0;Fe]@2o_kl0fMWI0<S8b0020<K6aP07
0=;BdP34a<@0dM7A0<K6aP2i^KT0^[Zj0;:b/P020<;2`P070<[:bP2o_kl0^;Rh0:VYZ@2_[jl0TY:B
0<W9b@020;Ng]`070:f][@3Fe]H0`L710;fm_@3=cLd0a<C40;no_`020<G5a@070;:b/P39bLT0`/;2
0=OGe`3=cLd0];Bd09fMW@020:n_[`80_Kfm00D0aLG50;fm_@3>c/h0b/[:0<C4a0020<30`00709VI
V@2h^;P0WIfM0::RXP2a/K40_kno0;>c/`020=oOg`070=;BdP3=cLd0Shn?0:JVYP39bLT0/;2`0<30
`0020<k>cP070<c<c02m_Kd0/;2`0;Bd]038b<P0/k>c09fMW@020=SHf0070;^k^`30`<00RHV90<30
`02XZ:P0/;2`0:j^[P020=?Cd`070::RXP2^[Zh0Y:BT0;fm_@3Jf]X0`<300;Bd]0020;>c/`070<S8
b034a<@0[jn_0<C4a03AdM40bLW90<S8b0030<K6aP80`<3000<0Z:RX0?ooo`3oool08P3ooolB0=Lc
o`80IZ?o00@0VOo20=Lco`3G<ol0IZ?o203G<ol00`1VXol0ec?o06JSo`0<0=Lco`0306JSo`3G<ol0
ec?o00<0ec?o0`1VXol30=Lco`0306JSo`3G<ol0ec?o00H0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol3
06JSo`T0ec?o00<0IZ?o0=Lco`1VXol00P1VXol60=Lco`80IZ?o00<0ec?o06JSo`3G<ol0103G<ol0
1@1VXol0ec?o0=Lco`3G<ol0IZ?o00@0ec?o00<0IZ?o0=Lco`1VXol00P1VXol20=Lco`<0IZ?o203G
<ol00`1VXol0ec?o0=Lco`070=Lco`0306JSo`3oool0oooo02D0oooo000U0?ooo`030;jn_P2e]KD0
^KVi0080]kNg00L0/[:b0<g=c@2g]kL0aLG50<30`038b<P0a/K60080b<S800L0];Bd0;no_`2i^KT0
^k^k0<G5a@2`/;00`<300080a<C400H0][Jf0<30`02e]KD0][Jf0<?3``3Fe]H30;^k^`070<30`02`
/;00_kno0=CDe02m_Kd0YjNW0<;2`P020<C4a0070;Zj^P2MWId0d=3@0<;2`P36a/H0[Jf]0;>c/`02
0<;2`P050<g=c@3Cdm<0`<300<30`02m_Kd00P36a/H20:^[Z`070;bl_02f][H0a<C40<30`02d];@0
gmoO0:ZZZP020<K6aP070;2`/02OWil0];Bd0<S8b02m_Kd0/[:b0;>c/`020<S8b0070;Ng]`38b<P0
a/K60<30`02l_;`0bl_;0<[:bP020;2`/0070<C4a02h^;P0SHf=0:j^[P3:b/X0[:b/0<k>cP020;jn
_P070;fm_@2_[jl0]KFe0<k>cP34a<@0_kno0;Vi^@020<g=c@070;^k^`2e]KD0YJFU0<W9b@3De=@0
/K6a0;jn_P020;fm_@070<W9b@30`<00b<S80;bl_02f][H0RHV90;Vi^@020;jn_P070;fm_@3<c<`0
/K6a0<S8b024Q8@0^;Rh0<S8b0020<C4a0070;no_`38b<P0b<S80<C4a032`/80b/[:09VIV@020;Vi
^@040<_;b`2n_[h0_;bl0:NWYb@0oooo1@3G<ol00`1VXol0ec?o0=Lco`0;0=Lco`0306JSo`3G<ol0
ec?o00/0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`040=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol0
2P3G<ol206JSo`H0ec?o00<0IZ?o0=Lco`3G<ol00P1VXol30=Lco`0306JSo`3G<ol0ec?o00P0ec?o
0P1VXol20=Lco`80IZ?o00<0ec?o06JSo`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`070=Lco`0406JS
o`3G<ol0ec?o06JSo`P0ec?o00<0IZ?o0=Lco`3G<ol00`3G<ol00`1VXol0ec?o06JSo`0:0=Lco`03
06JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0?ooo`3oool09@3oool002D0oooo00<0[Jf]0;Zj^P2f][H0
0P2k^k/01`2m_Kd0a/K60;>c/`2RXZ80_Kfm0;jn_P2j^[X00P2k^k/01`2QXJ40alO70;2`/032`/80
_[jn0<O7a`30`<000P3>c/h01`32`/80_;bl0<K6aP39bLT0cLg=0;^k^`2f][H00P2l_;`00`2f][H0
bl_;0<71`@020;fm_@0;0<[:bP2k^k/0/k>c0;>c/`38b<P0a<C40;Ng]`2e]KD0_kno0:BTY02d];@0
0P34a<@01`2d];@0]kNg0<?3``2e]KD0`L710<S8b036a/H00P3Jf]X01`3MgMd0clo?0<;2`P2j^[X0
_[jn0<[:bP3Hf=P00P2WYjL01`2`/;00Z:RX0;^k^`3Jf]X0bLW90;bl_038b<P00P2e]KD01`2d];@0
bLW90<c<c03AdM40a<C40:f][@2HV9P00P3EeMD01`39bLT0a<C40;bl_02^[Zh0a/K60;Bd]03Bd]80
0P35aLD01`2d];@0bl_;0;Jf]P2o_kl0WYjN0=KFeP2k^k/00P2b/[801`2VYZH0[Zj^0<S8b03EeMD0
]kNg0;jn_P2][Jd00P2WYjL01`31`L40WIfM09VIV@30`<00/k>c0;Vi^@2l_;`00P32`/801`2ZZZX0
TI6A0;Vi^@2j^[X0a<C40<S8b02k^k/00P2l_;`01`37alL0b<S80<G5a@39bLT0cLg=0=CDe034a<@0
0P3/k>`0102^[Zh0][Jf0:6QX@2MWIdT0?ooo`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lco`3G
<ol00`3G<ol00`1VXol0ec?o06JSo`0M0=Lco`0306JSo`3G<ol0ec?o0140ec?o101VXol<0=Lco`80
IZ?o1@3G<ol00`1VXol0ec?o0=Lco`070=Lco`0306JSo`3G<ol0ec?o00@0IZ?o103G<ol306JSo`03
0=Lco`1VXol0IZ?o00H0ec?o0P1VXol>0=Lco`80o`0000@0IZ?o0=Lco`1VXol0IZ?o9`3oool002D0
oooo00<0/K6a0;Bd]02][Jd00P2e]KD01`33`l<0`<300<30`032`/80];Bd0;Rh^02`/;000P2o_kl0
1`2TY:@0YjNW0<S8b032`/80b<S80;Vi^@36a/H00P2c/k<01`2o_kl0cLg=0<S8b02`/;00c/k>0;no
_`32`/800P2n_[h01`32`/80cLg=0<30`030`<00a/K60<71`@2d];@00P2g]kL01`31`L40]KFe0;^k
^`39bLT0e=CD0;no_`36a/H00P2b/[801`30`<00`l?30<S8b03:b/X0c<c<0;no_`30`<000P32`/80
1`3Hf=P0/[:b0;Jf]P3@d=00]kNg0<S8b037alL00P2o_kl01`2j^[X0d];B0<30`02f][H0c<c<0;fm
_@35aLD00P2g]kL01`30`<00YJFU0;Jf]P2o_kl0`/;20<K6aP2b/[800P2j^[X01`3Bd]80a/K60;Vi
^@2TY:@0/;2`0=;BdP36a/H00P3Zj^X01`2][Jd0cLg=0;Bd]02h^;P0[Zj^0<71`@2g]kL00P2CTi<0
1`26QXH0/k>c0;Bd]036a/H0_kno0<;2`P3>c/h00P2UYJD01`2e]KD0^[Zj0:RXZ02m_Kd0[Jf]0<C4
a033`l<00P2m_Kd00`2e]KD0`/;20<_;b`020;Vi^@070<g=c@3;bl/0dM7A0=7Ad@37alL0f=SH0<G5
a@020<W9b@080<[:bP2h^;P0b<S80<S8b02f][H0_[jn0=cLg02`/;0T0?ooo`0306JSo`3G<ol0IZ?o
00P0ec?o00<0IZ?o0=Lco`3G<ol00P1VXol:0=Lco`0306JSo`3G<ol0ec?o01<0ec?o0P1VXol:0=Lc
o`0306JSo`3G<ol0ec?o00l0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol00`1VXol0ec?o0=Lco`030=Lc
o`80IZ?o0P3G<ol20?l0000506JSo`3G<ol0ec?o0=Lco`1VXol00P3G<ol306JSo`H0ec?o0P1VXol2
0=Lco`0306JSo`3G<ol0IZ?o01T0ec?o00<0IZ?o0?ooo`3oool09@3oool002D0oooo00<0/k>c0;2`
/02g]kL00P2n_[h20:j^[P030;no_`2k^k/0_;bl0080a/K60P2][Jd0102h^;P0[Jf]0<C4a030`<02
0;no_`0:0<;2`P38b<P0b<S80<K6aP2QXJ40_;bl0<K6aP2i^KT0[Zj^0<C4a080b<S800L0`<300;>c
/`2j^[X0aLG50<C4a02n_[h0_Kfm0080e=CD00D0f=SH0=WIf@3Hf=P0`/;20;Fe]@020<;2`P80][Jf
00L0^[Zj0:NWY`2`/;00a<C40<;2`P3>c/h0[jn_0080b<S800H0a<C40=CDe02h^;P0/k>c0<o?c`3B
d]830<30`0070:BTY02^[Zh0`<300<71`@3<c<`0]KFe0:BTY0020;Vi^@050;jn_P3:b/X0`<300;^k
^`3:b/X00P30`<020<G5a@070=KFeP34a<@0d];B0:f][@3=cLd0a<C40<_;b`020:n_[`070<;2`P36
a/H0VIVI0;jn_P27QhL0d];B0<K6aP020:f][@070:BTY02g]kL0^k^k0;Jf]P31`L40_kno0;Bd]002
0;no_`070:j^[P2WYjL0][Jf0;Ng]`2[Zj/0^;Rh0<;2`P020;Bd]0070<S8b03?cll0];Bd0;fm_@3:
b/X0b<S80<k>cP020;>c/`070<k>cP2b/[80DE5A0;fm_@2k^k/0`/;20<W9b@020<;2`P040;bl_039
bLT0b<S80<K6aR@0oooo00<0ec?o06JSo`3G<ol00P3G<ol206JSo`D0ec?o0P1VXol00`3G<ol0IZ?o
0=Lco`070=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol05P3G<ol206JSo`<0ec?o00<0IZ?o0=Lco`3G
<ol02@3G<ol206JSo`@0ec?o00<0IZ?o0=Lco`3G<ol0303G<ol0101VXol0ec?o0=Lco`3G<ol206JS
o`80ec?o00<0IZ?o0=Lco`1VXol00P3G<ol306JSo`P0ec?o0P1VXol20=Lco`0306JSo`3G<ol0ec?o
00`0ec?o00<0IZ?o09Wo`P3G<ol02@3G<olW0?ooo`009@3oool00`32`/80Zj^[0;>c/`020;Rh^007
0<G5a@38b<P0_[jn0:2PX038b<P0]KFe0<C4a0020;Vi^@030<30`02e]KD0/[:b0080_kno00/0_;bl
0;no_`35aLD0aLG50;Vi^@2[Zj/0jNWY0;>c/`2n_[h0_Kfm075aL@020;Zj^P070<;2`P2m_Kd0_;bl
0;Jf]P2c/k<0[Zj^0=3@d0020<_;b`050=kNgP3EeMD0`/;20;:b/P32`/800P2m_Kd20<O7a`070;no
_`2d];@0e=CD0;fm_@3?cll0fMWI0>KViP020<g=c@070:2PX02o_kl0]kNg0<K6aP3;bl/0d];B0;bl
_0020<K6aP070<g=c@3@d=00^[Zj0;Bd]02FUYH0X:2P0;>c/`020:NWY`070;no_`34a<@0b<S80<C4
a038b<P0d];B0<[:bP020:RXZ0070;Fe]@2o_kl0a/K60;Rh^02n_[h0dm?C0:BTY00209JFUP070;^k
^`2m_Kd0ZJVY0:2PX02FUYH0VIVI0;Zj^P020820P00709^KV`36a/H0_;bl0;jn_P35aLD0_kno0=[J
fP020;^k^`070<71`@33`l<0VIVI09RHV02QXJ40_Kfm0<C4a0020<K6aP070;Vi^@2k^k/0bl_;0<G5
a@3Cdm<0a<C40<;2`P020=CDe0070<O7a`2n_[h0]KFe0;Ng]`2o_kl0Zj^[0;Jf]P020<C4a0040<W9
b@36a/H0];Bd0<S8b2@0oooo00<0ec?o06JSo`3G<ol01@3G<ol00`1VXol0ec?o0=Lco`050=Lco`03
06JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0?l0003G<ol00P3G<ol00`2Iol80ec?o0=Lco`050=Lco`03
06JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`0:0=Lco`80
IZ?o00<0ec?o06JSo`1VXol01`3G<ol206JSo`H0ec?o0`1VXol20=Lco`@0IZ?o00@0ec?o06JSo`1V
Xol0IZ?o2P3G<ol306JSoa80ec?o00<0IZ?o0=Lco`3G<ol01@3G<olW0?ooo`009@3oool00`2c/k<0
Zj^[0;bl_0020:VYZ@070;Ng]`2c/k<0^[Zj0;jn_P3Fe]H0d=3@0<K6aP020:^[Z`070;>c/`2k^k/0
]kNg0<?3``2LW9`0_[jn0;Zj^P020:VYZ@0709fMW@34a<@0[:b/0<O7a`2g]kL0^k^k0:JVYP020;bl
_0070<;2`P2o_kl0alO70;2`/033`l<0gMgM0<W9b@020;Ng]`0608J6QP1WIfL0YjNW0;fm_@38b<P0
a/K60`2i^KT01038b<P0`l?30;Fe]@31`L420<W9b@0:0;bl_036a/H0a/K60<o?c`3=cLd0Zj^[09VI
V@2`/;00YjNW0<[:bP80^k^k00H0`L710<[:bP38b<P0^;Rh0<C4a02m_Kd30<C4a0030<g=c@2[Zj/0
^KVi0080a/K600/0clo?0<G5a@39bLT0bLW909jNWP2f][H0^k^k0<;2`P3:b/X0/;2`0:^[Z`020:f]
[@070;Zj^P32`/80^;Rh0<k>cP2`/;00Z:RX0<30`00208F5Q@0708>3P`2`/;00c<c<0=GEe@2OWil0
`<300:^[Z`020;^k^`070:j^[P3=cLd0][Jf0<;2`P2h^;P0a/K609VIV@030<?3``060;no_`3Ng]h0
^k^k0<K6aP2e]KD0]kNg0`30`<001P2b/[80d=3@0<30`02][Jd0e=CD0;^k^`80^[Zj00@0dm?C0<30
`03Ogml0X:2P903oool00`3G<ol0IZ?o0=Lco`0206JSo`L0ec?o0P1VXol40=Lco`0306JSo`3G<ol0
ec?o00<0IZ?o00<0ec?o06JSo`3G<ol00P3G<ol00`1VXol0ec?o0=Lco`030=Lco`0306JSo`3G<ol0
ec?o00<0ec?o00<0IZ?o09Wo`P1VXol04@3G<ol406JSo`d0ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol0
0`1VXol0ec?o0=Lco`020=Lco`@0IZ?o103G<ol206JSo`030=Lco`1VXol0IZ?o0080IZ?o0P3G<ol0
0`1VXol0ec?o06JSo`020=Lco`0306JSo`3G<ol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol02P3G<ol0
101VXol0ec?o0=Lco`1VXol70=Lco`0306JSo`3oool0oooo02D0oooo000U0?ooo`030:b/[02i^KT0
];Bd0080^[Zj00L0ZJVY0;Rh^02i^KT0`/;20<C4a036a/H0aLG50080YjNW00L0]KFe0<;2`P2h^;P0
[Jf]0;>c/`2n_[h0/[:b0080^;Rh00L0^KVi0<g=c@3=cLd0];Bd0:f][@2o_kl0^KVi0080`<3000L0
^KVi0:FUY@2WYjL0_Kfm0<[:bP2a/K40^k^k0080TY:B00L0a<C40<_;b`3?cll0];Bd0=CDe02e]KD0
e=CD0080[:b/00L0`/;20;Bd]03=cLd0gMgM0;Vi^@2f][H0`<3000<0]kNg00H0aLG50<S8b02f][H0
bl_;0<;2`P30`<020<[:bP070<c<c034a<@0`/;20<_;b`38b<P0];Bd0:f][@020:VYZ@070;Vi^@34
a<@0^;Rh0<g=c@2i^KT0`L710<30`0020;Bd]0070=;BdP2d];@0`l?30<W9b@36a/H0^;Rh09^KV`02
0<S8b0070;bl_02/[:`0_[jn0<;2`P2`/;00alO7096AT@0209NGU`040;6a/@38b<P0_Kfm0<;2`P80
]kNg00X0b/[:0<;2`P32`/80^;Rh0;no_`34a<@0^[Zj0<g=c@34a<@0^;Rh0P2f][H01`3=cLd0_kno
0;Ng]`2g]kL0c/k>0;Jf]P3Vi^H00P36a/H01`2m_Kd0bLW90;Zj^P32`/80b<S80<K6aP38b<P00P3K
fm/0103@d=00`<300;>c/`32`/8T0?ooo`0306JSo`3G<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol0
103G<ol206JSo`<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o1P3G<ol00`1VXol0ec?o0=Lco`030=Lco`80
IZ?o0P3G<ol0101VXol0ec?o06JSo`1VXol70=Lco`80IZ?o603G<ol306JSo`l0ec?o00D0IZ?o0=Lc
o`3G<ol0ec?o06JSo`020=Lco`0306JSo`3G<ol0IZ?o00<0IZ?o5`3G<ol00`3o0000ec?o0=Lco`0=
0=LcobL0oooo000U0?ooo`030:b/[02i^KT0];Bd0080^[Zj00L0ZJVY0;Rh^02i^KT0`/;20<C4a036
a/H0aLG50080YjNW00L0]KFe0<;2`P2h^;P0[Jf]0;>c/`2n_[h0/[:b0080^;Rh00L0^KVi0<g=c@3=
cLd0];Bd0:f][@2o_kl0^KVi0080`<3000L0^KVi0:FUY@2WYjL0_Kfm0<[:bP2a/K40^k^k0080TY:B
00L0a<C40<_;b`3?cll0];Bd0=CDe02e]KD0e=CD0080[:b/00L0`/;20;Bd]03=cLd0gMgM0;Vi^@2f
][H0`<3000<0]kNg00H0aLG50<S8b02f][H0bl_;0<;2`P30`<020<[:bP070<c<c034a<@0`/;20<_;
b`38b<P0];Bd0:f][@020:VYZ@070;Vi^@34a<@0^;Rh0<g=c@2i^KT0`L710<30`0020;Bd]0070=;B
dP2d];@0`l?30<W9b@36a/H0^;Rh09^KV`020<S8b0070;bl_02/[:`0_[jn0<;2`P2`/;00alO7096A
T@0209NGU`040;6a/@38b<P0_Kfm0<;2`P80]kNg00X0b/[:0<;2`P32`/80^;Rh0;no_`34a<@0^[Zj
0<g=c@34a<@0^;Rh0P2f][H01`3=cLd0_kno0;Ng]`2g]kL0c/k>0;Jf]P3Vi^H00P36a/H01`2m_Kd0
bLW90;Zj^P32`/80b<S80<K6aP38b<P00P3Kfm/0103@d=00`<300;>c/`32`/8T0?ooo`0306JSo`3G
<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol0103G<ol206JSo`<0ec?o00@0IZ?o0=Lco`3G<ol0IZ?o
1P3G<ol00`1VXol0ec?o0=Lco`030=Lco`80IZ?o0P3G<ol0101VXol0ec?o06JSo`1VXol70=Lco`80
IZ?o603G<ol306JSo`l0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`020=Lco`0306JSo`3G<ol0IZ?o
00<0IZ?o5`3G<ol00`3o0000ec?o0=Lco`0=0=LcobL0oooo000U0?ooo`030;^k^`34a<@0/K6a0080
Zj^[00L0^;Rh0=WIf@3AdM40_;bl0<;2`P2j^[X0`/;20080^;Rh00L0ZJVY0<c<c02f][H0`/;20;Jf
]P3;bl/0`/;20080`<3000L0_Kfm0<C4a02i^KT0[jn_0;no_`2c/k<0_kno0080c<c<00D0_;bl0;:b
/P2n_[h0_kno0;Fe]@0209bLW080Ph>300L0]KFe0;fm_@3Bd]80^KVi0<C4a02k^k/0/k>c0080bl_;
00L0`/;20<_;b`3>c/h0b<S809bLW032`/80e]KF0080d=3@00L0a<C40;fm_@3:b/X0dM7A0;Vi^@3A
dM40c/k>00<0b<S800H0g]kN0<g=c@2c/k<0^k^k0<C4a02WYjL20;^k^`070=?Cd`30`<00bl_;0<C4
a02o_kl0^KVi0;no_`020<;2`P070:2PX03Jf]X0ZJVY0;6a/@3>c/h0jNWY07]kN`020=KFeP0709nO
W`3;bl/0][Jf0;Zj^P2h^;P0/[:b0:RXZ00209jNWP070=oOg`39bLT0`/;209ZJVP2_[jl0]KFe0;no
_`020=CDe0070:j^[P3De=@0f][J0;Zj^P30`<00][Jf0<G5a@020=_Kf`070<_;b`3:b/X0i>CT0;2`
/02i^KT0_[jn09nOW`020:n_[`070<30`02b/[80_Kfm0=;BdP2m_Kd0c<c<0=3@d0020:BTY0040<c<
c02DU9@0aLG50;bl_2@0oooo0P3G<ol306JSo`T0ec?o00<0IZ?o0=Lco`3G<ol02@3G<ol00`1VXol0
ec?o0=Lco`040=Lco`0406JSo`3G<ol0ec?o0=Lco`@0IZ?o3@3G<ol00`1VXol0ec?o0=Lco`0A0=Lc
o`0306JSo`3G<ol0ec?o00T0ec?o00L0IZ?o0=Lco`1VXol0IZ?o0=Lco`3o0000VOo20080ec?o00<0
IZ?o0=Lco`3G<ol00P3G<ol406JSo`<0ec?o0P1VXol40=Lco`0306JSo`3G<ol0ec?o00T0ec?o00<0
IZ?o0=Lco`3G<ol00`1VXol00`3G<ol0IZ?o0=Lco`040=Lco`80IZ?o00@0ec?o06JSo`3G<ol0ec?o
9`3oool002D0oooo00<0^KVi0;Rh^02k^k/00P39bLT01`2GUiL0[Zj^0;Zj^P2l_;`0_Kfm0;Vi^@3F
e]H00P2b/[801`2`/;00_[jn0:j^[P2`/;00c/k>0<;2`P2l_;`00P35aLD01`32`/80/K6a0;no_`38
b<P0a<C40<[:bP37alL00P2j^[X01`2n_[h0bl_;0<;2`P3>c/h0a/K60:JVYP2/[:`00P3;bl/01`38
b<P0]kNg0;jn_P36a/H0/;2`0<W9b@2f][H00P3=cLd01`37alL0_kno0<C4a02e]KD0_[jn0=3@d03:
b/X00P36a/H20<_;b`050<30`036a/H0^k^k0<k>cP3AdM400P32`/801`2d];@0eMGE08Z:RP2o_kl0
e=CD0;6a/@2HV9P00P2a/K401`37alL0c/k>0<30`02m_Kd0`l?309jNWP2c/k<00P36a/H01`32`/80
_kno0<k>cP30`<00Zj^[0:j^[P2JVYX00P3IfMT01`30`<00h>3P0;Zj^P2g]kL0Xj>S0=OGe`34a<@0
0P2WYjL01`27QhL0`<300<[:bP2LW9`0c<c<0;fm_@3Rh^800P3Fe]H01@2f][H0a/K60;Ng]`3EeMD0
[Jf]0080a<C40P30`<001`2l_;`0bLW90;fm_@30`<00[Jf]0<k>cP3:b/X00P2SXj<01`2VYZH0_[jn
0;jn_P2k^k/0_kno0=3@d02c/k<00P2o_kl01032`/80a/K60<;2`P2`/;0T0?ooo`D0ec?o0P1VXol5
0=Lco`<0IZ?o00<0ec?o06JSo`1VXol01P3G<ol00`1VXol0ec?o0=Lco`0:0=Lco`80IZ?o1P3G<ol0
0`1VXol0ec?o0=Lco`0F0=Lco`0306JSo`3G<ol0ec?o00@0IZ?o1@3G<ol00`1VXol0ec?o0=Lco`05
0=Lco`<0IZ?o1P3G<ol00`1VXol0ec?o0=Lco`0306JSo`80ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol0
0`1VXol0ec?o0=Lco`060=Lco`0306JSo`3G<ol0ec?o00<0IZ?o2`3G<ol00`1VXol0oooo0?ooo`0U
0?ooo`009@3oool00`2h^;P0_[jn0<K6aP020<;2`P050<S8b02][Jd0[Zj^0;bl_02n_[h00P34a<@2
0:6QX@040;>c/`2d];@0`l?30<C4a080a/K600X0alO70<C4a034a<@0][Jf0<S8b034a<@0`l?30;2`
/03Hf=P0a<C40P2i^KT01P2][Jd0a/K609jNWP36a/H0clo?0<30`0<0]kNg00L0a<C40<;2`P2k^k/0
/k>c0;Vi^@30`<00_Kfm0080cLg=00L0`<300<O7a`2k^k/0b<S80<c<c02VYZH0c/k>0080a<C400L0
c/k>0=7Ad@3>c/h0clo?0:2PX02o_kl0`l?30080[Zj^00L0MgMg0:NWY`2b/[80^[Zj0<S8b02/[:`0
a<C40080a/K600L0`<300<k>cP2d];@0^k^k0<30`02ZZZX0^[Zj0080WYjN00L0e=CD0<k>cP2k^k/0
`<300=;BdP2g]kL0`l?30080Ti>C00L0VIVI0:BTY02c/k<0/k>c09jNWP29RHT0YjNW0080X:2P00L0
/k>c0=;BdP34a<@0b<S80;^k^`3UiND0XZ:R0080];Bd00L0]KFe0<C4a02a/K40YJFU0:j^[P2b/[80
e=CD0080[Jf]00L0c/k>0;2`/02i^KT0aLG50<S8b032`/80f][J0080c/k>00L0a<C40=;BdP2m_Kd0
^KVi0;Ng]`34a<@0a/K60080_[jn00@0];Bd0;fm_@2h^;P0]KFe903oool60=Lco`80IZ?o103G<ol2
06JSo`d0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol00`1VXol0ec?o06JSo`0D0=Lco`0306JSo`3G<ol0
ec?o00D0ec?o00<0IZ?o0=Lco`3G<ol00P1VXol00`2Iol80IZ?o06JSo`020=Lco`0306JSo`3G<ol0
ec?o00H0ec?o00@0IZ?o0=Lco`1VXol0IZ?o1`3G<ol406JSo`80ec?o1@1VXol60=Lco`0306JSo`3G
<ol0ec?o0080ec?o101VXol01@3G<ol0IZ?o06JSo`3G<ol0IZ?o01@0ec?o9`3oool002D0oooo00<0
^;Rh0<?3``31`L400P2f][H20<C4a0050:NWY`2c/k<0`/;20;jn_P2f][H00P2l_;`01P2UYJD0_kno
0;Ng]`2e]KD0`/;20;:b/P<0^KVi00L0/k>c0;bl_032`/80`<300<;2`P2^[Zh0a<C400<0`<3000H0
^k^k0:FUY@2d];@0alO709JFUP3>c/h20;Bd]0070<[:bP38b<P0^KVi0;Zj^P3<c<`0b<S80<30`002
0<71`@070<_;b`3?cll0a/K60=3@d02SXj<0m_Kf0<W9b@020<C4a0070<;2`P2b/[80c<c<0;bl_039
bLT0i^KV0:j^[P020=[JfP070:BTY03?cll0ZJVY0;Jf]P34a<@0][Jf0;bl_0020;Rh^0070<K6aP2d
];@0a<C40;Rh^035aLD0bLW90;Fe]@020:RXZ0070;>c/`2k^k/0b<S809ZJVP2NWYh0][Jf0;Bd]002
08R8R0070;:b/P30`<00b<S80:^[Z`2`/;00Zj^[0;Rh^00209jNWP070:JVYP3Hf=P0Zj^[0;6a/@30
`<00/K6a0<[:bP020:BTY0070<o?c`2e]KD0^k^k0;no_`2LW9`0^k^k0:j^[P020<?3``070;>c/`2g
]kL0_Kfm0;Vi^@2g]kL0_Kfm0<C4a0020<;2`P070<30`032`/80b<S80;fm_@32`/80alO70<?3``02
0<k>cP040<30`036a/H0`<300;Fe]B@0oooo1`3G<ol00`1VXol0ec?o0=Lco`040=Lco`0306JSo`3G
<ol0ec?o0080ec?o00<0IZ?o0=Lco`3G<ol01P3G<ol00`1VXol0ec?o0=Lco`030=Lco`0406JSo`3G
<ol0ec?o06JSoa00ec?o00<0IZ?o0?l0003G<ol00`3G<ol00`1VXol0ec?o0=Lco`020=Lco`0606JS
o`3G<ol0ec?o06JSo`3G<ol0IZ?o3@3G<ol206JSo`<0ec?o0P1VXol20=Lco`<0IZ?o0P3G<ol306JS
o`050=Lco`1VXol0IZ?o06JSo`3G<ol00P1VXol00`3G<ol0IZ?o0=Lco`0206JSo`@0ec?o00<0IZ?o
0=Lco`1VXol0603G<olW0?ooo`009@3oool00`30`<00_Kfm0=KFeP020<C4a0030<O7a`2d];@0^k^k
0080/k>c00/0b/[:0:^[Z`2c/k<0/k>c0;Fe]@2g]kL0[Jf]0;Vi^@32`/80`<300:6QX@020;bl_007
0<;2`P2b/[80a/K60=KFeP30`<00`/;20;no_`030;fm_@060;Rh^02_[jl0^KVi0<71`@2][Jd0^KVi
0P2WYjL01P38b<P0c/k>0<K6aP31`L40`<300;^k^`<0`l?300L0`/;20<C4a034a<@0c<c<0<;2`P2X
Z:P0`<300080^k^k00L0e=CD0<c<c02TY:@0_Kfm0;bl_02i^KT0a<C40080^KVi00L0][Jf0<G5a@32
`/80b/[:0<S8b02o_kl0];Bd0080/K6a0P35aLD01@31`L40bLW90;Zj^P2[Zj/0b<S80080/[:b00L0
Z:RX0;no_`3Ogml0`<300<S8b02b/[80_kno0080Zj^[00L0dm?C0<K6aP2:RXX0]kNg0;fm_@2g]kL0
`/;20080^k^k00L0/K6a0;>c/`2i^KT0V9RH0=SHf030`<00a/K60080`<3000L0]KFe0<C4a02YZJT0
aLG509bLW03<c<`0clo?0080`l?300L0d];B0<g=c@3Bd]80cLg=0<o?c`2l_;`0/K6a0080/k>c00@0
_;bl0;^k^`33`l<0_Kfm0P34a<@0103<c<`0_[jn0;jn_P2m_Kd20;Fe]@030<;2`P3oool0oooo0280
oooo2`3G<ol00`1VXol0ec?o0=Lco`020=Lco`0506JSo`3G<ol0ec?o0=Lco`1VXol00`3G<ol00`1V
Xol0ec?o0=Lco`070=Lco`0506JSo`3G<ol0ec?o06JSo`3G<ol00P1VXol>0=Lco`0306JSo`3G<ol0
ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol02`3G<ol206JSo`D0ec?o00<0IZ?o0=Lco`1VXol00P1VXol4
0=Lco`0406JSo`3G<ol0IZ?o06JSo`80ec?o00<0IZ?o0=Lco`3G<ol0103G<ol0101VXol0ec?o0=Lc
o`1VXol70=Lco`0306JSo`3G<ol0IZ?o00X0ec?o00<0IZ?o0=Lco`3G<ol03@3G<olW0?ooo`009@3o
ool00`2k^k/0[Jf]0<;2`P020;Jf]P070;Rh^02b/[80a/K60<S8b02][Jd0^;Rh0;jn_P020::RXP07
0:^[Z`2d];@0^KVi0;Ng]`2m_Kd0];Bd0:^[Z`020;fm_@070<O7a`3=cLd0ZJVY0;Fe]@30`<00a<C4
0;2`/0020<C4a0040;Rh^02b/[80`<300;^k^`80`<3000X0/[:b0<_;b`3;bl/0];Bd0;2`/038b<P0
XJ6Q0<G5a@32`/80HF5Q0P2m_Kd01`34a<@0_kno0;jn_P2VYZH0a/K60=OGe`31`L400P3Bd]801`3D
e=@0^[Zj0:VYZ@3Ogml0`l?30;>c/`2l_;`00P3;bl/01`2d];@0c<c<0;fm_@33`l<0aLG50;no_`2[
Zj/00P2d];@01`2k^k/0[jn_0<S8b034a<@0_;bl0;no_`2i^KT00P32`/80103=cLd0Y:BT0<O7a`3=
cLd20<K6aP0:0<?3``2RXZ80XZ:R0<W9b@3AdM40][Jf0:f][@31`L40^[Zj0:JVYP80`l?300L0cLg=
0:BTY02o_kl0][Jf0;no_`2`/;00][Jf0080XZ:R00L0clo?0;Ng]`2[Zj/0b<S80<;2`P2m_Kd0bl_;
0080a/K600L0^k^k0<c<c03MgMd0YJFU0;>c/`2PX:00];Bd0080XJ6Q00L0^KVi0:n_[`36a/H0bl_;
0<S8b02i^KT0[Jf]0080b<S800@0a<C40;Jf]P32`/80d=3@903oool00`3G<ol0IZ?o0=Lco`030=Lc
o`0406JSo`3G<ol0ec?o06JSo`80ec?o0`1VXol50=Lco`0306JSo`3G<ol0ec?o0080ec?o00D0IZ?o
0=Lco`3G<ol0ec?o06JSo`030=Lco`0306JSo`3G<ol0ec?o0080ec?o00L0IZ?o0=Lco`3G<ol0ec?o
06JSo`3G<ol0IZ?o0080ec?o00<0VOo20=Lco`3G<ol00`3G<ol00`1VXol0ec?o0=Lco`050=Lco`03
06JSo`3G<ol0ec?o00X0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`080=Lco`0306JSo`3G<ol0ec?o
00<0ec?o0P1VXol30=Lco`0406JSo`3G<ol0ec?o06JSo`<0ec?o00H0IZ?o0=Lco`3G<ol0ec?o06JS
o`3G<ol206JSo`80ec?o00<0IZ?o0=Lco`3G<ol01`3G<ol0101VXol0ec?o06JSo`3G<ol206JSo`03
0=Lco`1VXol0ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol0103G<olW0?ooo`009@3oool20;^k^`0:0;bl
_02h^;P0^;Rh0;jn_P32`/80bl_;0<30`02o_kl0`L710;fm_@80/[:b00L0YJFU0;2`/02`/;00_;bl
0;Fe]@2j^[X0^;Rh0080`<3000L0YZJV0;Jf]P2HV9P0/K6a0;fm_@38b<P0^;Rh0080b<S800L0^k^k
0;Fe]@2YZJT0]kNg0<;2`P30`<00bl_;0080^KVi00L0f][J0<;2`P30`<0020P80<K6aP38b<P0^[Zj
0080UiNG00L0]kNg0<K6aP35aLD0c/k>0;:b/P2e]KD0cLg=0080^;Rh00L0[jn_0<k>cP2HV9P0W9bL
0;Jf]P30`<00`/;20080b/[:00L0`<300<W9b@2NWYh0]KFe0;fm_@2j^[X0^;Rh0080Ph>300L0]kNg
0?7al@3Cdm<0`L710<k>cP2i^KT0[Zj^0080a/K600H0`<300;fm_@34a<@0c<c<0=KFeP2RXZ830;^k
^`070=_Kf`3>c/h0c/k>0<G5a@2j^[X0b<S80;no_`020:VYZ@0709^KV`2BTY80S8b<0<_;b`2NWYh0
^KVi0=CDe0020:^[Z`070=3@d02/[:`0e]KF0;no_`2TY:@0d=3@0=CDe0020=_Kf`070<c<c02`/;00
^k^k0<;2`P2f][H0_kno0;fm_@020;Zj^P070;no_`2a/K40_Kfm0;fm_@35aLD0]kNg0<K6aP020<_;
b`040:JVYP32`/80a<C40;Ng]b@0oooo303G<ol506JSo`H0ec?o00@0IZ?o0=Lco`1VXol0IZ?o1`3G
<ol00`1VXol0ec?o0=Lco`070=Lco`040?ooo`3G<ol0ec?o0=Lco`80IZ?o103G<ol00`1VXol0ec?o
0=Lco`020=Lco`0406JSo`3G<ol0IZ?o06JSo`L0ec?o00<0IZ?o0=Lco`3G<ol00P3G<ol206JSo`03
0=Lco`3o0000ec?o00<0ec?o00<0IZ?o0=Lco`3G<ol01@3G<ol00`1VXol0ec?o0=Lco`080=Lco`D0
IZ?o00@0ec?o06JSo`3G<ol0ec?o0P1VXol01@3G<ol0IZ?o0=Lco`3G<ol0IZ?o00D0ec?o00<0IZ?o
0=Lco`3G<ol01P3G<ol00`1VXol0ec?o0=Lco`050=Lco`0406JSo`3G<ol0ec?o0=LcobL0oooo000U
0?ooo`030;^k^`2e]KD0_Kfm0080[Zj^00L0_Kfm0;Fe]@2k^k/0_[jn0<30`02i^KT0`<300080];Bd
00H0[Jf]0;Zj^P2k^k/0/[:b0;>c/`2i^KT30<71`@070;Vi^@2j^[X0a/K60:VYZ@32`/80a<C40=CD
e0020<;2`P070<G5a@3no_h0^;Rh0=;BdP2e]KD0/[:b0<C4a0020<o?c`040;Vi^@34a<@0^;Rh0;fm
_@80bLW900X0_kno0:b/[02/[:`0a/K60<;2`P38b<P0/k>c0<k>cP36a/H0]KFe0P3AdM401`2a/K40
`/;20:n_[`2f][H0]kNg0<S8b039bLT00P3?cll01`30`<00_[jn0<K6aP36a/H0^k^k0:n_[`2b/[80
0P2j^[X01`36a/H0[jn_0;jn_P2][Jd0a<C40;bl_034a<@00P3EeMD01`2k^k/0`/;20<W9b@2m_Kd0
][Jf0<S8b033`l<00P34a<@01`2_[jl0a/K60;Rh^034a<@0/;2`0:NWY`2ATI400P2WYjL01`38b<P0
^k^k0<30`02b/[80aLG50;Zj^P3De=@00P34a<@01`3GemL0[jn_0;>c/`3Fe]H0b<S80<_;b`2i^KT0
0P2SXj<01`2YZJT0]KFe0<c<c02NWYh0^k^k0;Jf]P34a<@00P2WYjL20<C4a0050<;2`P38b<P0]kNg
0<30`034a<@00P2k^k/0102i^KT0];Bd0<30`02o_klT0?ooo`<0ec?o0P1VXol90=Lco`0406JSo`3G
<ol0ec?o06JSo`P0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol01@3o0000ec?o0=Lco`3G<ol0IZ?o00X0
ec?o0P1VXol90=Lco`0306JSo`3G<ol0IZ?o00/0ec?o0P1VXol30=Lco`0306JSo`3G<ol0IZ?o00h0
ec?o00@0IZ?o0=Lco`3G<ol0ec?o1@1VXol30=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lc
o`3G<ol00`3G<ol306JSo`80ec?o00@0IZ?o0=Lco`3G<ol0ec?o0P1VXol=0=LcobL0oooo000U0?oo
o`030;^k^`2e]KD0_Kfm0080[Zj^00L0_Kfm0;Fe]@2k^k/0_[jn0<30`02i^KT0`<300080];Bd00H0
[Jf]0;Zj^P2k^k/0/[:b0;>c/`2i^KT30<71`@070;Vi^@2j^[X0a/K60:VYZ@32`/80a<C40=CDe002
0<;2`P070<G5a@3no_h0^;Rh0=;BdP2e]KD0/[:b0<C4a0020<o?c`040;Vi^@34a<@0^;Rh0;fm_@80
bLW900X0_kno0:b/[02/[:`0a/K60<;2`P38b<P0/k>c0<k>cP36a/H0]KFe0P3AdM401`2a/K40`/;2
0:n_[`2f][H0]kNg0<S8b039bLT00P3?cll01`30`<00_[jn0<K6aP36a/H0^k^k0:n_[`2b/[800P2j
^[X01`36a/H0[jn_0;jn_P2][Jd0a<C40;bl_034a<@00P3EeMD01`2k^k/0`/;20<W9b@2m_Kd0][Jf
0<S8b033`l<00P34a<@01`2_[jl0a/K60;Rh^034a<@0/;2`0:NWY`2ATI400P2WYjL01`38b<P0^k^k
0<30`02b/[80aLG50;Zj^P3De=@00P34a<@01`3GemL0[jn_0;>c/`3Fe]H0b<S80<_;b`2i^KT00P2S
Xj<01`2YZJT0]KFe0<c<c02NWYh0^k^k0;Jf]P34a<@00P2WYjL20<C4a0050<;2`P38b<P0]kNg0<30
`034a<@00P2k^k/0102i^KT0];Bd0<30`02o_klT0?ooo`<0ec?o0P1VXol90=Lco`0406JSo`3G<ol0
ec?o06JSo`P0ec?o00<0IZ?o0=Lco`3G<ol0103G<ol01@3o0000ec?o0=Lco`3G<ol0IZ?o00X0ec?o
0P1VXol90=Lco`0306JSo`3G<ol0IZ?o00/0ec?o0P1VXol30=Lco`0306JSo`3G<ol0IZ?o00h0ec?o
00@0IZ?o0=Lco`3G<ol0ec?o1@1VXol30=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lco`3G
<ol00`3G<ol306JSo`80ec?o00@0IZ?o0=Lco`3G<ol0ec?o0P1VXol=0=LcobL0oooo000U0?ooo`03
0;^k^`2i^KT0YjNW0080`<3000L0]kNg0;Rh^02o_kl0e]KF0;fm_@32`/80_kno0080b<S800H0X:2P
0;Jf]P37alL0/;2`0:f][@2h^;P30<C4a0070;Vi^@2m_Kd0YjNW0<C4a02h^;P0^[Zj0:j^[P020;Zj
^P070<C4a020P800[:b/0<;2`P38b<P0/[:b0;bl_0020<;2`P070<K6aP3Cdm<0_[jn0<30`02c/k<0
`<300;>c/`020<C4a0070;no_`32`/80fMWI0<K6aP3=cLd0_[jn0<K6aP020;>c/`070<S8b02c/k<0
a<C40<;2`P2YZJT0`/;20>7Qh@020;Vi^@060;>c/`2k^k/0^k^k0:^[Z`3;bl/0_;bl0`36a/H01`2j
^[X0];Bd0<o?c`39bLT0_Kfm0<g=c@3Bd]800P3:b/X01`2m_Kd0bLW90;>c/`3Fe]H0[jn_0;fm_@2i
^KT00P3=cLd01`3:b/X0f][J0=3@d032`/80/[:b0;fm_@2f][H00P31`L401`2k^k/0a<C40:^[Z`36
a/H0/[:b0<o?c`3=cLd00P36a/H01`3Bd]80e]KF0<k>cP3<c<`0`/;20;^k^`2d];@00P2PX:001`30
`<00b/[:0;bl_02g]kL0];Bd0<S8b02k^k/00P2n_[h01`34a<@0fMWI0<[:bP36a/H0_Kfm0<O7a`2]
[Jd00P36a/H01039bLT0a/K60<_;b`36a/HT0?ooo`80ec?o00<0IZ?o0=Lco`3G<ol02@3G<ol00`1V
Xol0ec?o0=Lco`0206JSo`H0ec?o00D0IZ?o0=Lco`3G<ol0ec?o06JSo`030=Lco`80IZ?o0P3G<ol0
0`1VXol0ec?o0=Lco`0G0=Lco`0306JSo`3G<ol0ec?o00D0ec?o00<0IZ?o0=Lco`3G<ol0403G<ol0
0`1VXol0ec?o0=Lco`060=Lco`0306JSo`3G<ol0ec?o00@0ec?o00<0IZ?o0=Lco`1VXol02`3G<ol2
06JSo`l0ec?o00<0IZ?o0=Lco`3G<ol0103G<olW0?ooo`009@3oool00`38b<P0f=SH0<g=c@020<g=
c@070;^k^`2][Jd0_;bl0;2`/02j^[X0/k>c0<71`@020;6a/@070:NWY`2l_;`0];Bd0;no_`36a/H0
a<C40;Ng]`030;no_`060:BTY02m_Kd0ZJVY0<S8b01<C4`0_kno0P2k^k/01`3;bl/0^[Zj0;Fe]@32
`/80`<300<K6aP32`/800P3?cll01P38b<P0`<300<;2`P30`<00^;Rh0<?3``<0`/;200D0_;bl0<W9
b@31`L40bLW90;Zj^P020;bl_080_Kfm00L0X:2P0<[:bP34a<@0_kno0<30`02h^;P0b<S80080`<30
00L0^;Rh0<_;b`2l_;`0`<300<g=c@32`/80[Jf]0080Y:BT00<0[:b/0;Rh^02h^;P00P2l_;`02`3@
d=00Shn?0;Rh^02h^;P0alO70;Vi^@36a/H0/k>c0<30`036a/H0];Bd0080dM7A00@0e=CD0<;2`P36
a/H0^KVi0P2NWYh02P2^[Zh0/[:b0;:b/P2_[jl0`/;208b<S034a<@0];Bd0;jn_P2m_Kd20=KFeP07
0::RXP2b/[80]KFe0;^k^`2d];@0b/[:0<;2`P020<g=c@070=KFeP38b<P0e=CD0;jn_P2:RXX0]KFe
0<71`@020<G5a@070=?Cd`2k^k/0`/;20;no_`34a<@0X:2P0;Vi^@020:ZZZP040=7Ad@30`<00];Bd
0<C4a2@0oooo1P3G<ol00`1VXol0ec?o06JSo`030=Lco`<0IZ?o2@3G<ol01@1VXol0ec?o06JSo`3G
<ol0mOo<01h0ec?o00<0IZ?o0=Lco`3G<ol0303G<ol406JSo`D0ec?o00<0IZ?o0=Lco`3G<ol03@3G
<ol606JSo`030=Lco`1VXol0ec?o00D0ec?o0P1VXol;0=Lco`0306JSo`3G<ol0ec?o00L0ec?o00@0
IZ?o0=Lco`1VXol0IZ?o103G<olW0?ooo`009@3oool00`2o_kl0][Jf0;Zj^P020<C4a0070;Fe]@3=
cLd0X:2P0<K6aP2h^;P0/k>c0<K6aP020:j^[P0709JFUP2QXJ40`/;20;Zj^P2m_Kd0`/;20;no_`02
0:^[Z`060:f][@36a/H0a<C40;Jf]P3;bl/0_;bl0`30`<001`2NWYh0`/;20:BTY02LW9`0X:2P0:b/
[03;bl/00P32`/801`2b/[80`/;20<k>cP32`/80a<C40;>c/`2k^k/00P3;bl/01`32`/80a/K60;Vi
^@38b<P0bLW90;Zj^P2QXJ400P34a<@01`3:b/X0dm?C0:6QX@2f][H0`<300<;2`P2_[jl00P32`/80
1`2j^[X0b<S80<71`@2k^k/0eMGE0<71`@1mOGd00P2b/[820=CDe0050<o?c`30`<00b/[:0<C4a02m
_Kd00P3Bd]801`3=cLd0b<S80<_;b`2m_Kd0^;Rh0<W9b@2/[:`00P2`/;001`2d];@0aLG50;Jf]P2i
^KT0[Zj^0::RXP2k^k/00P3?cll0102CTi<0][Jf0:BTY032`/820<[:bP0:0:ZZZP2i^KT0^KVi0:>S
X`3=cLd0]kNg0;no_`3AdM40cLg=0=SHf080b<S800L0a<C40=_Kf`3<c<`0a/K60=7Ad@32`/80^KVi
0080d];B00D0^KVi0<;2`P2h^;P0T92@0<S8b0020<_;b`80a<C400@0eMGE0=7Ad@2j^[X0`/;2903o
ool70=Lco`0306JSo`3G<ol0ec?o0080ec?o101VXol50=Lco`<0IZ?o203G<ol00`1VXol0ec?o06JS
o`0306JSo`<0ec?o00<0IZ?o0=Lco`3G<ol0303G<ol00`1VXol0ec?o0=Lco`020=Lco`0506JSo`3G
<ol0ec?o0=Lco`1VXol0203G<ol00`2Iol80IZ?o06JSo`0?0=Lco`<0IZ?o103G<ol206JSo`<0ec?o
00<0IZ?o0=Lco`1VXol00`3G<ol0101VXol0ec?o0=Lco`1VXolD0=Lco`0306JSo`3G<ol0ec?o00L0
ec?o9`3oool002D0oooo00<0];Bd0;jn_P2l_;`00`2g]kL01P36a/H0_[jn0;jn_P2WYjL0^[Zj0;jn
_P80][Jf00L0Rh^;09FEU@2h^;P0^;Rh0<S8b02][Jd0^KVi0080a/K600L0`<300=CDe02k^k/0];Bd
0;jn_P30`<00clo?0080_;bl00L0];Bd0;Fe]@2j^[X0_[jn0;Zj^P31`L40b<S80080a<C400L0bLW9
0<;2`P2h^;P0_[jn0<C4a036a/H0b<S80080cLg=00L0]KFe0=;BdP3?cll0[Jf]0<W9b@2^[Zh0a/K6
0080b/[:00L0e]KF0;fm_@2m_Kd0/k>c0;Vi^@2c/k<0c/k>0080^;Rh00L0a/K60=[JfP3Lg=`0`L71
0<c<c02ZZZX0]kNg0080]KFe00L0bl_;0=?Cd`3IfMT0_kno0=3@d032`/80c<c<0080cLg=00L0a/K6
0:f][@2^[Zh0bl_;0:n_[`2^[Zh0a<C40080^KVi00L0^k^k0;no_`3=cLd0YjNW0;2`/02][Jd0cLg=
0080alO700L0YZJV0;Rh^02][Jd0c<c<0<o?c`2c/k<0]kNg0080d];B00L0`l?30<O7a`2m_Kd0clo?
0<W9b@37alL0f=SH0080`/;200L0a<C40;Bd]039bLT0_kno0;^k^`3:b/X0XZ:R0080VYZJ00L0`L71
0;Jf]P2n_[h0`/;20<_;b`3IfMT0dM7A0080c<c<00@0`<300<S8b02i^KT0`<30903oool90=Lco`03
06JSo`3G<ol0ec?o0080ec?o0P1VXol30=Lco`0306JSo`3G<ol0ec?o01l0ec?o00<0IZ?o0=Lco`1V
Xol04@3G<ol00`1VXol0ec?o0=Lco`0;0=Lco`80IZ?o00<0ec?o06JSo`1VXol01P3G<ol306JSo`<0
ec?o00<0IZ?o0=Lco`1VXol05@3G<ol306JSo`d0ec?o9`3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool007<0oooo0T00
003o0?oooa`0oooo001e0?ooo`03@000003oool0oooo0?l0oooo6@3oool003l0oooo0T0000030?oo
o`9000000P3oool3@00000<0oooo0T0000030?ooo`9000000P3oool3@00000d0oooo00I000000?oo
od000000oooo@000003oool4@0000080oooo1D0000020?ooo`03@000003ooom00000009000000`3o
ool2@00000<0oooo0d0000020?ooo`=000000P3oool2@00006l0oooo0T0000020?ooo`=000000P3o
ool4@00000030?oood000010000000<0oooo0T0000030?ooo`=000000P3oool3@0000080oooo0d00
00030?ooo`9000000`3oool3@00000`0oooo00=000000?ooo`3oool0C`3oool003h0oooo00=00000
0?oood0000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00I00000
0?ooo`3ooom000000?oood0000020?ooo`04@000003oool0oooo@00000h0oooo00I000000?oood00
0000oooo@000003oool3@0000080oooo00I000000?ooo`3ooom000000?oood0000020?ooo`04@000
003oool0oooo@00000<0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom0
00000080oooo00=000000?oood000000L03oool00d000000oooo0?ooo`030?ooo`04@000003oool0
oooo0?ooo`=00000103oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000
103oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood000000103oool014000000
oooo0?oood00000;0?ooo`03@000003ooom000000500oooo000n0?ooo`03@000003ooom000000080
oooo0d0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool014000000
oooo0?oood0000020?ooo`03@000003oool0oooo00`0oooo00E000000?oood000000oooo@0000003
0?ooo`04@000003oool0oooo@0000080oooo00=000000?oood0000000P3oool014000000oooo0?oo
od0000030?ooo`03@000003oool0oooo0080oooo00I000000?ooo`3ooom000000?oood0000020?oo
o`03@000003ooom0000000900000KP3oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo
00<0oooo00E000000?ooo`3oool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00=00000
0?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`=000000P3o
ool014000000oooo0?oood00000=0?ooo`03@000003oool0oooo04h0oooo000n0?ooo`05@000003o
ool0oooo@000003oool00d0000020?ooo`=0000000<0oooo@000040000000T0000030?ooo`900000
0P3oool4@00000`0oooo0T0000000`3ooom000000?ooo`020?ooo`9000000`3oool7@0000080oooo
0T0000020?ooo`A0000000@0oooo@00004000000oooo0T0000020?ooo`=0000000@0oooo@0000400
00100000KP3oool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo0080oooo0T0000030?oo
o`9000000`3oool2@0000080oooo0T0000030?ooo`=000000P3oool2@00000<0oooo0d0000030?oo
o`=000002`3oool2@0000540oooo000m0?ooo`05@000003oool0oooo0?oood0000002`3oool00d00
0000oooo0?ooo`0a0?ooo`03@000003oool0oooo00X0oooo00=000000?ooo`3oool0L03oool00d00
0000oooo@00000030?ooo`03@000003oool0oooo01H0oooo00=000000?ooo`3oool03P3oool00d00
0000oooo0?ooo`090?ooo`03@000003oool0oooo0500oooo000m0?ooo`90000000<0oooo@0000400
0000>`3oool00d000000oooo0?ooo`0=0?ooo`900000LP3oool3@0000080oooo0T00000C0?ooo`03
@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@000000:0?ooo`9000002`3oool3@000
0500oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo001W0?oo
o`900000DP3oool2@0000=<0oooo001Y0?ooo`03@000003oool0oooo0540oooo00=000000?ooo`3o
ool0d03oool005/0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00A000000?ooo`3oool0
oooo0T0000060?ooo`03@000003oool0oooo00T0oooo0T0000030?ooo`9000000P3oool3@00000<0
oooo0T0000030?ooo`9000000P3oool3@00000d0oooo00I000000?oood000000oooo@000003oool4
@0000080oooo1D0000020?ooo`03@000003ooom00000009000000`3oool2@00000<0oooo0d000002
0?ooo`=000000P3oool2@0000180oooo0d000000103ooom00000@000040000020?ooo`900000103o
ool2@0000080oooo0d0000020?ooo`=0000000<0oooo@000040000000T0000030?ooo`=000000P3o
ool2@0000080oooo0d0000030?ooo`90000000<0oooo@000040000000P3oool00d000000oooo0?oo
o`1W0?ooo`00G03oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3o
ool00d000000oooo0?ooo`090?ooo`03@000003oool0oooo00h0oooo00=000000?oood0000000P3o
ool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00I000000?ooo`3ooom00000
0?oood0000020?ooo`04@000003oool0oooo@00000h0oooo00I000000?oood000000oooo@000003o
ool3@0000080oooo00I000000?ooo`3ooom000000?oood0000020?ooo`04@000003oool0oooo@000
00<0oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom000000080oooo00=0
00000?oood0000004`3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo00<0oooo
00A000000?ooo`3ooom000000P3oool014000000oooo0?oood0000040?ooo`05@000003oool0oooo
0?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00A00000
0?ooo`3ooom000000`3oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?ooo`3o
ool0I`3oool005`0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`0?0?ooo`03@000003ooom000000080
oooo0d0000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool014000000
oooo0?oood0000020?ooo`03@000003oool0oooo00`0oooo00E000000?oood000000oooo@0000003
0?ooo`04@000003oool0oooo@0000080oooo00=000000?oood0000000P3oool014000000oooo0?oo
od0000030?ooo`03@000003oool0oooo0080oooo00I000000?ooo`3ooom000000?oood0000020?oo
o`03@000003ooom00000009000004@3oool014000000oooo0?oood0000020?ooo`03@000003oool0
oooo0080oooo00E000000?ooo`3oool0oooo@00000050?ooo`03@000003oool0oooo0080oooo00E0
00000?ooo`3oool0oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000
1@3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?oood0000000P3oool00d000000
oooo0?ooo`1W0?ooo`00G03oool2@00000<0oooo0T0000040?ooo`=000002`3oool00d000000oooo
0?ooo`0>0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`=0000000<0oooo@0000400
00000T0000030?ooo`9000000P3oool4@00000`0oooo0T0000000`3ooom000000?ooo`020?ooo`90
00000`3oool7@0000080oooo0T0000020?ooo`A0000000@0oooo@00004000000oooo0T0000020?oo
o`=0000000@0oooo@0000400001000004P3oool3@00000030?oood000010000000@0oooo0T000000
0`3ooom00000@0000002@0000080oooo140000000`3ooom00000@00000030?ooo`=0000000@0oooo
@00004000000oooo1T0000020?ooo`900000103oool2@00000030?oood000010000000900000JP3o
ool005`0oooo00A000000?ooo`3ooom000004`3oool00d000000oooo@000000?0?ooo`05@000003o
ool0oooo0?oood0000002`3oool00d000000oooo0?ooo`0a0?ooo`03@000003oool0oooo00X0oooo
00=000000?ooo`3oool05P3oool00d000000oooo0?ooo`090?ooo`03@000003oool0oooo00`0oooo
00=000000?ooo`3oool01`3oool00d000000oooo0?ooo`1i0?ooo`00F`3oool5@0000080oooo00=0
00000?ooo`3oool03`3oool00d000000oooo0?ooo`0>0?ooo`90000000<0oooo@00004000000>`3o
ool00d000000oooo0?ooo`0=0?ooo`9000005`3oool2@0000080oooo00=000000?ooo`3oool04@3o
ool00d000000oooo0?ooo`02@00000l0oooo00=000000?ooo`3oool0L`3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.157534, -0.0238147, 
  0.00580218, 0.00580218}, {{27.125, 191.25}, {185.313, 
  21.1875}} -> {-33.101, -6.22906, 0.889305, 0.889305}, {{207.688, 371.813}, {
  185.313, 21.1875}} -> {-193.676, -6.22906, 0.889305, 0.889305}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
%%ImageSize: 400 20 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00238095 0.952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00238095 0.97619 0.097619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.160256 0.00192308 0.0480769 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .00192 translate
.96154 .09616 scale
18 string
6 2 8 [6 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFF5FFCC99FFC266A3FFD733FFFF0000
FFFFFFF5FFCC99FFC266A3FFD733FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{200, 20},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400038000052000`400?l00000o`00003ob03oool0
0<P0oooo000Y0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo2
7@1VXolM0=Lcoad0o`003P3oool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y
0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lc
oad0o`003P3oool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<
7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3o
ool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<7@2Iol8M06JS
oad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3oool002T0oooo
7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o
000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3oool002T0oooo7@3eol`M09Wo
`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00
:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3oool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G
<olM0?l000h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 199}, {19, 0}} -> {-0.0498739, -0.00250052, 
  0.00552637, 0.00552637}, {{9, 189.938}, {18.5, 
  0.4375}} -> {-0.436354, -0.0975889, 0.0345471, 0.115157}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "A simple vector magnitude image on the left in Fig. 3 does not extract the \
cracks clearly, but the blue lines shows the cracks in the classified image \
on the right. To extract the cracks more clearly, we use the other vector \
property \[OpenCurlyDoubleQuote]inner product\[CloseCurlyDoubleQuote] between \
the unit directional and characteristic vectors. Defining a following ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]innerPro3D\[CloseCurlyDoubleQuote] \
carries out a three-dimensional inner product computation.",
    FontFamily->"Times New Roman"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Century",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function innerPro3D",
    FontFamily->"Century",
    FontSize->10.5]
}], "Subsubsection"],

Cell["\<\
innerPro3D=Compile[{{vector3D,_Real,3}},
\tModule[{ref={0.},vec={0.},dim={0},i=0,j=0},
\t\tref={1.,1.,1.}/Sqrt[3.];
\t\tdim=Dimensions[vector3D];
\t\tTable[
\t\t\tvec={vector3D[[1,i,j]],vector3D[[2,i,j]],
\t\t\t\tvector3D[[3,i,j]]};ref.vec,
\t\t{i,dim[[2]]},{j,dim[[3]]}]
\t]];\
\>", "Input",
  CellLabel->"In[34]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "We compute an inner product distribution between the unit directional and \
characteristic vectors in Fig. 2 by means of this function.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["innerPro=innerPro3D[sample];", "Input",
  CellLabel->"In[35]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "We construct an image data of the inner products, and then we classify the \
inner products into 5 levels by the magnitude. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
innerProG=ListDensityPlot[innerPro,
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->\"Inner products\",DisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[36]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Figure 4 shows the inner product distributions. A simple inner product \
distribution on the left in Fig.4 does not extract the cracks but the \
classified distribution on the right clearly extracts the cracks as the light \
blue dotted lines.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
innerProCG=ListDensityPlot[1. Round[nx innerPro]/nx,
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->StringForm[\"Classified``\",nx],
\tColorFunction->hueColor,DisplayFunction->Identity];
Show[GraphicsArray[{innerProG,innerProCG}],
\tPlotLabel->\"Fig.4. Inner product distribution\",
\tImageSize->{400,200}];
Show[GraphicsArray[{colorBar5}],ImageSize->{400,20}]; \
\>", "Input",
  CellLabel->"In[37]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -101 0 ]
[.5 .48869 101 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.4) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Inner) show
141.000000 12.812500 moveto
(product) show
189.000000 12.812500 moveto
(distribution) show
261.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -44 0 ]
[.5 1.0125 44 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Inner) show
99.000000 12.812500 moveto
(products) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CCC4C8B8C5BCC3C1B8C1BFC8C0B7ACB2B2BABBBEB5AFB5AA
D1AEB1BABAB2BEBEB9C5D2BEC0C9C5C3BEC2C294C5BAC5B8
BEAABECDC0C1C7BBB5C9A28EC2C3B6A190B3C0C5C0C3CBB7
97C7C6BDC2CACAD0C9C0CCC0C5C0B6C7C8C6C5C7BEC7C3AA
B9BFC5C9C5C2B9C9BCD1C7C3C7C9C4C3CACCCCD1B6BDC9B9
B2C6BFBEBCC5C7C2
B9C2C3B0CAC6C3C1D0C5D6C9BDC6BBB3BDB6C3B9BDB9C348
D4BBB0B9AFB6C0C0B3B9DBC2C9BAAFB6D0C3C7D0B7C3BCBE
BEC0A9B6D08CB9CEAED4B0A2BCB8B0CEBFA6C186ADC0B2BC
C3B2C0CDD1BABDC9C3C7BEC5C3B4B8BDC2CCD1BCCEB2CAC3
C0C3B2C0CAC0CDC3BFCCD2CECFC6B1C9C5C9C3B4CFB2CBD1
A1BBCCCCC9B9B6CC
C1C1BEBABEAAB6C9C7CAC5B9BEB7B9BBC2C5B9BEBCC7C1A8
BCBBB6ADBCB7BAB7CCAFCAC2BAC7A0C8C9CCD0C7BBAEC5C5
B9B4C9C5C5BFCABDC8AFA9A1B7A9B8C3B9BBCFB9B2A8C5C1
BCC2C1C3C7D4BFC9C9BDB3C7CCC1C5C7C8C8CCC6C2CFCAAF
B2C1CFBEC4BDC7C7C1C3CECCB3C4B7BDC9BDD4D0C5B6D6C9
B2C3BDC9C1CAB4C5
B7B7C8B3AFABB5BBBEB5CAADC7C0BEBBCCC1C1C5C5C1C3BF
A3B3C3B7C0BBBBA6B9D4D8C3C7C1C9C0C3A9BDB0C2CCBCB3
BBBD93BFB4C6CCC8CAB6917BBCACBAC9A4B6B9AAB2D1BEB8
CCC3C1C7C7B4CBC7BDB4AACDBEA9CFC5CBC1C2C9BFDAC5B7
BEBBCACABFC5CAC2BED1C5CAC9D4B4C3BAC5C0B8E1C5E3C5
B8CEBDA8BEA9C3BD
C5C2BACAB9BBC0BCB4D7D0B4B2B7B9B6C3C1C1C3B9B4C1CC
C2C3C397B6B9A8BDC2C4CCB9B7C8B6BDC7C7C7B9B89FB6AA
C3B4C9D1BAC0BCA8CAAE8E88B6ABB9D5A3B4C0B4C538B9BB
C3C9B4BBBBADBABEC0B4B6C3B5C5CACAC2B8CBCCB9C5BBBB
D2C9D2CAC9C3C7B9C7BABCC2CEB0CFC3C5CAC7D3B9A3C5B0
CEBDBFB6BCB8B0B2
B2C6C0B9D2CCBDC1BBCBC6CCB7BCC7BBC9C1C7B6BDBDBBDF
9789ABAB82A8B6BBBEC2D3C5CFCABACECEBDAFB6A3C0D6B0
C1BBB4BFB2C9BEBCBECB8B8BA8C7A1B9BDB7BABEBCCBC1C3
B5ADB4C3BAC9C0C9C3C2C5C0C7C2D1C3C5C2C3A9C2B6BDBD
B6C5C4ABC4C9CDC2CAC3CDCBD1C3C9C7D4BDCEACB5C7BCB4
C8C2C4BABEBFC5BF
C2B0B9C2BBBCBBC188ADB2CAC7C2BBBDC0C2A1C8BBD1ADD4
C5B2C5BBADBCABA1C9A8DAC5CAC9B4C7C3C0CED1C3ABCCBE
C2C9C5CCB6B2A9C9C6BC868CBBBB9EB6B8ADBCD060ACD3B9
BCC1C3C3BFB6ACC3CABCC5C0C1C3BFC1C5CAB7CBD1BBACB7
C6BDC5CFC5C7B8C5C7D0C9C9C0C7C2C0CAD4D1CDD0C5CDBB
C5BAC3C7C9C1CCC3
C19ABBCEC1B6CACAB1CCBFC9C9C9C4C3C9BDBFB3AAB7B4BE
AEBAA4C5B6B6B8B6B0B9CCCAC5CBB2BEC7C3C5CABFC1CEC7
BBC2C5DDA4BBC0CAC8C5A18CCFADC1B7A0A9BCC1CABFD1A8
BCCAD0BFC0B6B6C3C5C5C0C9C5B5B0C4C7C3C9C2BEACB6C9
D2D6CFC9C3BD9FC9CEC9CDCDCFC7C9C2CE95B9BFB7B1C1C5
C9C2B6B2C3C7C0D1
AEA8BEA8C1CAB6ACA8B6AED2C9C2BCB0B0C7B9C5AEBBBEB7
B997BBCAB3C0C4B9AFA3B9C5C6BCC3C1D1CACEC6C0CCBDCC
C4C2B7B6ABCBD0C5C3BA9CACA3B6B4C2ABAFC1CAADAEC5C2
B9B2AFBDB9C9BDC1BFADBAC5C9A8C0BCCDBEBEBEB9C7C9B4
CDCDCCBFCAC7CED2C0CEC7ADC3B4B8CFC2CBC0BCC3D5B6C5
C7C5C9C2CCC9CBA7
C4BCBCBFBEBAB7BEC0CCC5BFC7C8C0C1C0BCB7BBBCB7C3B7
AFBDC1C4BEC0C7B7A974C0B9C5C1D4CAD7D6CCBAC5CDC7C9
B7B3D1ABCCC8C2BCB7AE928990C4B1BAC4ABCECFC3B6C5C9
C3C7C0BCC9C5BAACC5C5B4B4C5B9B2D0B9BCC3C5B6B9B0B8
ABC7C4D7B7C8CCBCBCCECCC8D0C5CCC5D3C6BDBBBFC7C7CA
BFD1C5C0C0BEBDCA
C8C2C5BCB4B4BFBDC2B5BEBFC6BDC5BFBEC4CFC1B9CBC3B2
BEC2BFC5BFBDBDBFA3BBA8BFC3C1C7B6C8BFB2C8CEC4BEC2
CFCAC3C7C9C7C5C5CEB287979BBB9EB9ADB0BCB7B6B0A3C3
BFB7B6D2AFC3B7B5B3E2B8BCB2B4CFC2C9C9B4D1D9C5CCCE
C3BEC0B4D1C1C5D0CAC1C7CCC1C5CEC5B6CED2CCC7B4C3B8
C3CEC2D659BCD978
C5C0BCB8C9C2C2B3B6CF8ACDC2C2C0C2C3A8BECEBEB7C5CF
C4C4BEB9B9BFB4BFC3C5CE81C8CAD5ABC4B7CABCCED7C7B9
C0BCB4B1BBC9C7BEC0AD304589C5B0BFA8BFB8B4C3C7BCA5
B2AFBACBACBBCDBECCC7C3CCB5BBCDBBCFC0BEDAC2BEA5B2
B8C2AEC5C1BEC6EBD4CAC3C1C8B9BEC7BDBBC4C8CABFB9C6
B3C8C0CFC5C5BBC2
BFC9B7B4B4BCBAC2C1CAC3C9C7C8B9BAC2C4C4B7B7BCDAC9
B9CCB8BBC1C2BBBBC9C1D7C59DB4CCC7CACBC5CEBBBF8DFA
C0CBC3B7C4C7C3B7B44FAFB2E3C9C3C3C9C3C9C3ADAFB4C0
B6C2C2C3C5C3BABEB7C5CDB5BCC6C5C5C2C6C2D6D8C8C2C0
BDC7C3C9BFB8C1CABDC7CBC7C2C6C4BCC2BBCCCAC9C0C4C6
C8BEC2C1EBC5E1C9
CFBEB8C2C2B9CABEB9C2BAC1C5BFC9C5BBBBC4BEC4C1BCC0
C8C4B9C7BDBEC9B7C0C6D7C2CBB0A5CAC9BDC3C7BEC2CAB5
BEC0BCBCBCBCBEB7A7BCA8B987B9C9BDD0AFB7C2B2C2ABBA
C0BAC3C7C4CCC0B2B2C4CBBDB2A6CFC3CBC7BEBBB9A4BCC0
C3B8C7CCC4C5C4CBBCCDBFCAC1C5CEC3C9C2C0C8CDCDC8C0
B9C5B6BFC0C7BAB6
BBC0AFA5BAB9C2BEAAB0ACC1B7C3C1BDC0C6C9C1C3CABFC5
84B9C7C7C5C1BCB7CCBBB9B6CCC5C29CC9CEC9CAC4BBB4BC
C2C2B8D1C1C3BCBAB4E3D6E1C7B5B6C39CA9B6C9BEC5C1AF
C1C7D6CCBECABCBEC2CABCC5ABC3C7BDC9CBB6B4BABAA5C7
CFCFC7C9B0BCC7CBBECBC2C4CEC7D0C5C3D4CEC9D1D7D8C8
BDB8A1C7BAC7BAC9
B8B987B9C9C1BEADB7C2C0B9BCC4B7C9C7BDC4CAC0BDC9C5
C0B9C5BDBFC0C3BBC3C3C3CFC8BCC5C9BAD1CAD1C9B3D0C7
CAD2CECBC9B6B0BED0BFC7B6B7BEB8B4B6AAD1CECCB7C5CE
C2D8BEC9BCBDC0A8C7CDB8B7B2C2B9BFC3CFBCBABEB6C0C7
C3C0C3C7BACBB6D2C9C9C9BCC0C9C7C3B8BEBFB2AAB7B6C5
DDC5D4BFC9CBD1BC
C1B8ABC0BDB2C2C2CDC3C2C9C2C2C3D3CFC7C9CABEC3BDCE
C7BFB4BCC0C4C8BDC5BFC7B8CAC0D0B9BBCFD2B9CEC7D1DA
D0BBC1B6CAC2C4D8D1C9C9AFBDC5AFC79E9AC0C0C9C3A1CA
B4CDC5A7C4C2BCAECFB6C5C09FBCC3BDC2C5B6B8B0B6C0BC
C6C9E4D3D5C9C0B7C1A8C5C7D1CCEDB0C3A0C6BCC7BAC0CB
C0C0CFD4CCCAC9D0
BAB4BBB8BDB9C1B7CAC7C7CABBBFC5BBBBBFBBC3C2BEBED0
C5BBAFBEB9C1C5C1C5AEC7BABFC2AFCCB5A5AFB79BBBC0AB
CFDACFC3C7D1D3AAAAC3C7B6C6A4B9BEBEB7BEBEBABCB4BE
C1C3BCB8CCBBD0C9BFC3C3B4AFBCC2B9C4BBBDB6C5BEC3C2
B9C9C0C5BCC0BCCACCD0C3CFCDBFBEBAC0B1CFCFC5C3C1C7
BFC7C9C3CCCABDC9
BEC6A0BE9CC9C0ACBEC6CAC3C5B6B9BDBBC893C7C5C0C2C6
CCB0B7C3B6BCC0C9BBBABDB0C2C7DAC7C2E1D7A5BEC3AFBF
C7B4B4C5CBC0B9CBC0BCBDC3CAB9B9B2ADB8B4C2B2AFC090
BACBB6C3C7C7C3B2C5C5CCB892C3C9BEC2C7A9BABAC5C2C5
CBD0D3D3C0C9B8D2BDB4BEBBCAC9B8C3B6CAD0B0D0B6C5C3
C0C3BECDBCC9C3BE
BBBBC2B7B9B3B6BFC7C5C1C3C6C7C3B9BCCACFCDBFC2B5C5
C4ACAFC8C0CADDA8BEC7B6BC98C5B6BBDF97F0B9B8BE9EAD
ABB2B2C1C7CFCFADC6BCB6BCB0CEB8BCC2B6BFC1C2CBB8C5
C7B7B7CDC0B0AFC2BEC8D1C29EBABFBFB7BAB2B6C0AFB8BC
B6B4BFD1D1CFCFAABBC9C1CEBBB6B9CEC0D5CDBAC9BCCFDA
BEC7D3B1B5C6C0CD
C9BBB4B1C0C3DADEC7B7B6C3BDC7C2C5B9C3C6C4C0C9C3BE
CFCFC9BFC2C3BDB6B6CACEBEBCB79EAFBDADB59C8C9FA484
98C1C2CFC9D3C3C1BCB7A9A4BCC3B7C5CDACB0C3CCB8C7C8
B4BBBBC2CBCDCAC9A5B4C5BAAFC3C0BAC6BAB3B0ABAFB2BA
A8C2C2B6C0C0BECAC9A8C8D0D2C6C539B6D0C0C6B0CFC3AA
CEC2D1CDC6CED0C1
B6C3B4C2B7B5A687CCC5A8AABEA3D9B9C2C0ECD0C8C0C2C0
BCBFB7BCBBC0D0C2A0C5C2C7C8CDC3BBC1ADB2C7E2C3B2C5
B2C3A5979B98B2C9C7B8B9C3B4C5BFB6CEAFC2B1B2BAC2B6
C9B5C0C0D6C5B6A4C1BABEBBAFBBBAB4C5D1C5B2C9C3C7B4
C9CAC7D6C3C9BCC0CDC9D3C9CBC9C3BAB8BEB4BEB9BDCFE2
D1BBC792AECCB4C7
BEBFB9BBB9BBBDC5D8BECFBDB8C6FFB8BCCEAAC5BEBFBBAE
C1C5BEBEC8D1BBA8ACB8C7CDCAC3C4C3B6C3B4ADC2BBCEB9
C2C2AABACBCFD1B7B289C3C56BB0BAB7A3AFD6C3BEB8B8C0
C4BDE2C3C3C9B6D2DABCC9C7A1BEC2BCC2B9ABC5C3C3C3BD
C6C4B9C2D4CEC3BACBC9D2CEC2C9C2CCCFC0BEC5C0B8ADCB
C0BBBAB6BEC9CAB8
CCC9C4B2C5CCBEB2B7CEC5CAC2CEC4C0BFC5C2BCBE9FABC3
CCBEB0C7C5C4B89BE2C5C4C0C9CCC5BCC3C2C0BBA6CEB8C7
C5C7B8B9CCB6D5CA7DC2AFB0C7C2BEB2B8A7D3C3ABC3D1A6
B4DAB9C1C4B1C3C3ABBAC7BCA7BCC7BACDC9C5C2C6D5C3BE
C5C9C7C3D2C0A8ABC3CDC3D0C8CFD3C3CDCAC5BFC9B6C7CF
CFC58BBEC0C5C9C5
B9AEBBB1C0BCB9C1C8C6BE97CABAC7BCC6ABC0C7C0CCBEB4
C3B8C7CCDBBCAEB0B4C4C3B9BE9DB4C9BDBBCED5A1B7C5BD
BCC9CFB9BACAC1B685BBC0C7B4BAC0C2BAB9C7C5D1BEC2B2
D8B9CAE2D1CBCFD1C0CBCFB9B0A5C3C0D5BCBAC7B6B6B8BE
B0C7BEC3CDC3CFCFAFCECBCFC0C4C0B79CCAB4BDC5CFB7C1
9BA8C7CBB2B0BDB9
C5C5A7B0B4A7B7CABDC3BDBCC8CCC3C2BCBECAC1C9BBBEBB
BFC1C0C2ACD1B9BDBDBDCABFC2ACB5CAD1C8BCDBB9C0B6B7
BEC7C3B4B0BB92B64DC3CBDAC0BEB4A8C9B7CEAFB1BFBBDA
C5B7C3A6BECBD3D1C3C7C2CAB7C4C9C1DAC3C3CCA7C7C4BC
C0BBB8CCCEB4C3DDDAADC7C0D0C9CBD1D1B7C5BBADB6B8BF
C3B9BFC2C7C0CCC5
D6BEC9C3BBB6C0D0C9D2C2C6C8BBCCBFBCCAC1BDC7BBBBB7
BBC9C4C1BAC7ADC0B0BFC9B6C7B7D0C1C0BFD1DFCBC1CFA0
B0B3BBA3AFB6B2D1D0C9A7CFBCADBEB3AD8791AFCFB6B2AF
C7D0C7C7CBBAC3D1C9BBC7C2B6C7CDC5BEADC0C3BEB9B8AF
BCBEC8BBC3C7DCD1B3B1BEC9CFC9D5C1D3C5CAAECCD4BCCE
B4ACBEBAC5BCC7BB
CAC4C0C2B3B0D3BDC9C8C1BCCFB2BCB4BFBEC3C2CFB9CAD3
C8CCC3CAC1BFB9BCCBBFD2C5C7BDCAD6D3CAD8D9C6B9BFB2
B2D1A7B2D498C0B3B9C3C0C0BC93B9CABBAEB9BFC9C5BAE7
C5BEC6C3C5C7C9C7C7B6C9B8B4C3C9BABEBBA8C5C7CCC7B4
C7D0C1C5C5B0C2CCC6CECADABDC7CEBCCAC9C8ADBBC4C5D5
BCABCAC5B6C0CAC6
C3BBAFC9BFC3C7CCC3BEC2B2C6BCC3B6C9BDCABFD2C2C5C5
CCCACFBC9FC4C2C0ABC5C7D6C0C2C3C6AAC1AFA3B2BABFE1
C3BAAABC93BBCEB4C5B0CBC8ACC1E2AAC3B6BCBCC7CAB6CB
BCB6BECBC9C5D3C5A5BEC7C3B2C2E7B4CBD3BAC5C3C1C3BD
A3C2CBC2ABCAB6C9C9CCBBD6CFD5BEB0C3C7B6C9D4C599A8
B7D2B0B2C5ADC2C3
BABAB5B2AABDC0D4C0C0BCB7C0ABC0BCC7C7CAB2C1C7CAC8
C2C0B2BECCCECEC9A1B7C5B9C7CBC2ADC1C5B2A4B0ABABBE
BDB6AEBABAC9C7CBB8C3B6C8DCBECDB68CC0C7CDC2C3CBC5
CAB8BAC5BBD6C5CDC0C7D3DABCC9B7BBC2ADB9B1CE9FCBBC
B6BCBBD8ADBAC2CFBCC2B4C3CDD5ADCDCD83D1C2C9BDC7AC
BFCACABCC0C5CFCD
C7C3C0BDCAC3A5B7B6C9BFC0CCB5C2C2C8BEC1B4C1C8CFC2
BFBDC1C2C8CCCFD1AEBCB7BBB0C3B9C3CCC7C9A5B6ADB4B8
C1C99CAFBCADC2BEC9BDACBCBFC6B6B4BAB8CAC2BEC3C2C1
CAC3C5C5CF7DCDADCCCCD6B8B6C3CB9EC0D3B9BEC0C2C5CF
D5C9BDC7CCBDCFBEC7CFC7C2C3B4ADC0C7CFD1D3CEB2B0BA
BBC0B8C3CDD1D6C9
BCC2B1BAB9C0C1C3C1C5BBA7C6B9BEC8BECAC8AAC6A4CAC3
B7C7D1C5BCC2BDBC9ECDA9B9CCCCB4B5CAB2C9CEC0CABAC5
C0C2D1ABBEAEB2DDB0A7AFB8C0C3B8C9BCABB9C3CAC3C9CC
D0CADACCCCC9CAD2C1BECCBCBAC7C5C7D8C5BDB6C5A9B6B0
CEC5B9C7B9D1BED3C3CFC9BFDAD1C5B9B9C5E9C5B6BCC9A5
C2C0D8B5CFCEBCCF
B2B9CCC7B6C7C8C7C7AEAEC3BDB5C8C0C2BECABEC4CECEBE
C2C3C9BCC5C3C7BEA6B2C7C5BBC1BBCCCFBFA8C5BEB9D5D1
BACACFB1B7B0D6B8C7A7BAC2DABBB7CFC0A9BBC5B97BC7D6
CDDDC2B4B7ADD1B2CDD4D1BCBCCBB4A4C1C5AFB2BDC2B0A9
B0BEB2CBA8C7B0C5C5BAC7C5C2C2C7C0C4BED1C9CBCDB2D6
C3C5C3D1C3BCCADD
C2B2AFC2C2C4B6C9B8B2B2C9CDBEC7C3B5C4C5B6C8BDC2C3
C9C1C2CECBC0C3BFBAC5C5B2B7C7C3BBC3B4C5ABA7B9B9C0
B7CC91C5C0C0AFBCB8B4C2B6C2B9C3C0A8B1C8BCC8C7DFD7
CBB7BCBCB0C0AFC7DEBEBCCDBEC3CBC2C9C0AFC5C3C5BCCF
C9C3D0C9CBBEC7A8CFCFD4CBC2BEC7C5C0C9D0AED3CDBACD
D1CCCBBCCFBECCC9
C0ABB7C5C3B6C5D1B4BAC5C5C8C1C7B7B9C1BCBCBDC3C3BA
C9CEBBC88EBDC1BBADB8C7C7C0C0C5BAC2C9BDC5C0C3C0B9
C1C3A7B69EAFB4A5BEC99CB4BEBFB1C0CBA462BCC09C78BE
C7B8CBC2B0CCC0ADD7B8ADC7C0BCB0B6C3BEC9C0D1D6BBC7
BED1C7C7C5DEC3A1CBD1C3CDBCC7B2C9C5BFC1E3CD9EB8D1
C1AF9FB7C9B6C5CE
C1C4C6ADBBB7C2B9BBBCC0CCC7C2CEC3BABFCAB9BDC9C1CC
BBB1C0D6B9BDB9B8BABECCC9C2C9B8CCC1C9CBC5C0CACFB8
BBB9C2CFC8C7A7C3D39DB0C0BAC2C0BCAFC2BBC1E0B0B6C9
BCCBC5C9D1C5CABFB2C0BEC7B6C0BCC7B1C5BEBBC9BCC6A0
C7D0C5C3D1D3C4BABEC3D4D4C5C6C5C0B4C1C9B6C7C0D3B8
C5C3B6C7BFBFD1BA
BBB7A8C3BFD4C9B2C2B0C7CBB7BCBDB4AABECCCCCCBBC1B6
BFBFCAC5C1D6C7B8C0CAD0BFC0C7C7C5BC96CDB6C5CAB4BE
BFBBB7C2A4C6C4CEA097BBBDC0C2ADC9A1B6B8BAB8B6BEDA
CCB2BFBFD8CEB4C7C5BEBACCC2C0C2C2CAC4B1BFC1C3BCDE
C9B6C5C2C2AAAAC9C0ACC5CFD0D5D8D3C99FCBBFC7AFCBDA
D1C9E1E1C3CBCEC1
BCC6C6B7C1BBCEB3ACBDC1C4BBC3C3BFC8C4BCC3CFC1C5C9
C7CDB2BBCBC9BAB2BAB7B9C3B2BCC9C9C9C2CDB4C9CFB6C5
B4C7CDB4A4B5B5C091ACAAAAB6C9C5B4C0B4A3B8C3BEC7AC
BBB8BACFBAD6CECEC5BCC3C2B4ADCFC2B0C0C3D0BFA4BBC0
C9C2C0CBD8BEC2C5C9C9CAC2C3CDCCC9C0CEC7A6C5EBBEC7
C9CAC1CFA476B6C7
B4B9DBB9C3CCC3C1CFC5B5C5C9C5BBBCCCC5C8C2BBCBB7BF
C5BEB9B6C3C9B6C7BFBDC9BCCDC0BEC5B2C2C0B6C9BABFCF
ACBCC9C7A5D1BCC79EBCA6B4B9C2C0AFB8ABB9C9CFBCCDB2
D3C5BCC3C5BAC7C1C3DDCCC2BCCAB5BBADB2D6ABCDE4D5D7
C2BABBCFD3B4BCBBBCB6D2C5C9CDC2CABDCFCAD3CFAFB7B0
C5B4D2C3BCBCCAC1
C1C9C7B6B8C5B4C0BCC2BECCBDC7CAC7C7C2CEC6C6C7BDC3
C7C3BACCB7C0C3B0D3BACDB9C0B4CAA8C1C4CBC7C9C2BEC0
B4B6CEC59FC0CBCAB9C5B098ADADA8BAB0BAD3D19FB0C0C0
B0B6C2C9BEBAC0CBC3C3C7CFC9BECCCEC0BCBBD5C7CCB0B1
BACBCFCDC5CFA1CFD5C7D1D5C9C9D6BAC5B4BA6AC7C9C0BC
B8CACAC3C9C3CCBA
B9BBB2C0BCABBAC9C6BCBCD1C0BCAFC5BEC3B9B7B5C0CFCF
CBD8C5CAC0C0B2C7BEBFC5C3C3BBCAAFC2B4BCCABDBBBBBF
B2C4B6C1D8C2BCB650BCBEAF98B5BBAEB288C5B8BA96C5CB
CDCBB4ADC7C3CBCDC9C2C7B6C289D3BCC5C5BEB2CFB6C7B8
CCCECFC5D1BFC9BFD0C3CFB4CBC5C7BEADC0D4CBB4B8B0C2
C7A8C9BABD9AD1B2
C4ADBDCDBFC9DBD1C7BFC7C5C9BCBFB9CBC5C3D0B9C6BACD
C5B6C0B7C3C8C7BEC4C9C9C3C2BABDD0B4B2C087BEB6C5D1
C5D0D6D5C2C7C3B8C5B8B2C5C3859AA6AAAA9FC4C7A3C0CF
C6C0C8C6C8C5CBC5C7B2CCB9B9B7C0D6BCC3B4BECBC3CBD3
D4C3D6D8D3C9BCD8CDD3D2C7D3C9ACBCB8ABB0D1D6DFDACF
A9CADBC3D5C9C5CC
B1B2BFBEAEB0C0B7B4D0C1BDBFC7C3BCB4B4C9C5C5C1C1CC
C5BFC4BCB7B5C2BCC0D1C9CFC2CDBBBDB6ABC3CAC0CECAD1
D0C7DDD3B6C3C7C1CFC5B6C0B2A178BCA0B5C5D4BFBFBEB4
CCCACCCAAAC0BEBBC0D7C9C6BE9ECACCBCC2CFC2CDEDADC5
C9C9CFA7CBD5CBC5C0CBC5CAC7D6CCCDD1BFC9E3CF99ADC4
CCC3C9CEBAACC1B6
BDC0C2ADA0CFB7C5BCC0BBBCC8AECEBFB0C7BFCEC0BACBBD
C3CECEB9BFC5B9C7BBBEC7C2C7C7C7A6BDADB6D6CED2ACDA
DDEACEB6CAB9B2C5B8BCC2C2C7C3BAA492B7BFA4D39FAFBE
B2CACBCFC9BAC7C97DC3DAB2C9ABD3BCC5BEB4B7D7C2BAC0
C7C5C9A9DEB0C7D0D1C9BEC3C2BFBEB4BAE2CBB6C8C2C3C9
CBC3DCCCAAA8BCD2
C2CEC2BBAEC7C9C5CCBBB5C2C5C2BCB4C7BAC3CED0CDC0C8
C0B7AFAEBFCAC6B0BCAECAC3D1D0C8BDB2C2C0CCBDABBECA
DCCFCDB9C7C7CBB8D2BEC7C3BCB1AF9AA79FB2B7B7B1BDA3
CBCAC5CABBB5CBCBB4D3C7BDB4C3C0BE98C2C7C7C0BECBC3
B9BDD4D1A5CFC7C7D2BCAEB2C5A7D1C5C0CAC5CD95C7A0A6
ADABC5B7C6B9CED9
BBC3C1D1AB96BCB9BDC7C0C3B6BEC9C0C4CCC7BDC3CBC9C1
CABFB095B0C0B1CCCBB0CDBCD1CFBFBDA4C2C0D5D7E1BCCF
CBB0B2B7CAC2C2C7BAC7BBC5C1AEC3AAA9B1BB9EBAB8A7C3
CBAFC2B6C79FCFC3CCCB9CCAB2D5CEC0C1BCACC0B0BBC1B6
CDBECAC5CFC7B9D3C2DAB8C5AFC0CDD1D3C0B8B6B9CBC0BE
F0C7C0C5B4C0C9D0
BFCABDB4CAD1CCB4BCBCCCB4CEC2D1C7BEBCC1D0B4BDB4C0
C7B4B0A095CBC4BCBECAC5B7C3C5B6C3B8B6C3C5C3CDA88A
919395D1B6CEC6BBBECFD8A1C1B8BCC2B7ABCEC9C5B0C9C7
D4CACFC5E0C5CEB6D8CDC3D6B4C7CBD5D3BCCCA7C9B9C9CE
EBB2DCC5DAD1C5C7CFDACDBFB2C9CBA2C3B4C99AC2BEB9C3
CEC0CAD0CEC7D8D6
C9BCC5C0B4B7B6C5CAC9C7C3C5C2D1C1CCC9CEC1C3CAB6C9
B2C3C2C5D8B9BEB9BFCACCCBC3B0B6C5B8CBC79581989FAB
7FB2C0C9CBD5BEBECEC0C9C3C2B2C3BCC0C29AB7B0B2A7B0
BDCCC9AACCCED0C0C9C2C7CEBFCEA7C5BCC2CEBEC5CDCBC0
C0C3EDD0C1C2C7BDD3CAC3B8C7C5BAB1A7C2B8CBC2B0BDCC
CAC2BFCEBBB7D3BC
B3BEC6BAB7C7CCC7C2BCC2C4BCB6C3C5C3C5CFC5BEBBB9CC
C7B9BEC9C9A5B6BEC3C3CACFC8C2C5C3CAB4CAC7B798A1BA
BEBEB8C0C5BACDC7BDB9B2BEC6BEC5C2ABBCCCD1BCA3C3C9
BEC2CBBAB0C3C3BDCCCAC5D1B6BBC0A5B6B4B2CBCFCACFC7
C5BCB2CBD1C7C9CAE1CABABCCFC0D1C0BECFBAD5BED3BAB9
BDC1C3B6CDCECACF
C3C5B9BBB1B4C6B5B2C7B4B7AFCFB6BCC0BBBEABC7BBC5CD
C7B8BFCABAB6C3BEC5C9C5CDCEB6C9B2BBBDB2B4B69CC2CF
B2BAC9B2B7C3C0C3D8BEBBB7BBB4BFB6BAB4DE92D3CDB6CB
C2AFE2C5B7BDBAB2C7DAC5CBC2B6C3CBD3BCC2DAC1C2D5A7
B4C5AFCBCBC5CFD1BACDC1C9C3CDCFC1A8A3CBC5C2C3B8C5
C2CAD5D2C0B9BAC5
BEC6C588968CB2A4CBC4B7BFC1AAB6C1AAB7CDC0B6CCBCBB
CCC5CBC0CFC3CFC3C5B0C9C9DAD2BCCCCFB3C7D8C9AACDBA
BCD3D5C7C1C7C7CCC3C2CCC0BAB0B8BCCBB0B9B2BC9EB9CE
C3DAC3BCD1C9D1BEB8C7C7B4C1A8C5B2CCA9B7C4C9C7C0C5
CBC5C7C5B3C9B8B8CDC9BCB9C7CCCAC9C5BEB4D6C7C2E4C2
D8B89FC3D5BBBAD6
A8BAAEBBC3D4BBC7C7C1C3BFC3C0C2AAB0C3BBBBC9B9B9D1
C2C7B7D1B7CEC3C7B0BEC7C5C8B7C3C3BAB6C2B9ABACBDB0
BDC3C3BACDBCD1C9C0D3C0CDB8C5B2C5B2A9B9BCC5A5BAD1
B6D8BCDEC1BACCBEC2C3C9CBC39FC2CFAFC4B0C0C0C3CAD0
BED6C3BAAFB8C2C2CBB2BED6CFC7BAB9BCBDCEC2A7CACBC2
C5D1DACFB4C7D7D6
C5C7C1BDCACFB9C3D3C0ADB9B9AFC2BECEC3C5C7C3B9A6BE
CBC7C0C7C7BDCCC5BCB8C5CBBCC3C7C9C3B6C9CABC82D1A3
AFBFC3BEC7C5C0C3BACFA9C2ABCDB0C0C3B0BCB0C2CDA3D1
C2C5C3ABB7ADC0CAC8D5D3C9C5CDBEB5C5B7C0C3C3C0D5C0
CCBBC7BCB6C7C5CAC2D9CCD8CDD3B6C7BAC7C9BAC7CCAFB7
E1DFCFCFCFC1C7C4
C3CCC5CCBEB6BDC9D1BEC6BFBDB9BBC9B0BCCEB6C1BEC7BA
BCC2ABC5C5C3CFCBB2C7C1C7ABB4E7CFCBD0D8DFE1C7C9B0
CDC9CFD8C1B6BEC3B6C7CABCBEB9B7A9BCB2B0C3DAC2A3A9
A1B8C7BBBEC7C7CBB8ABC0C9C3BECEC2AEC3C3BCC5C3C3BA
C5C9C7C7BFC2CBE7C0D3CBBECBB0C7CFC0C2C3B9E5C9BDAB
82BAC9C7C2C3D5C9
BEBDC1B7ABB7C5D2D3B7B5B8C7C7C8C5D8DCD0B0CDBCB8C5
C3BDCFC7B8C0B0C2BECBC7D0CFC3CCEAC0D0B0CFD1BCB4CB
AAB0DAC1B9B4C9BACCB79AC9B4BECBCBABBDBBBEC9B9BCB4
D4B8C7BCC2C0B6BCBEC3C3C2B0B0D3B5A8AEC3C0C0ADB6C0
D3D5BEC7B6BFB3C2B0D927CEBBB9D3C9CBA3C3BAB7A7CAB2
C3D0DAC5D1D2C9C5
BDBBC6C5C7B6D1B3C3BFCECCBBC1C0B0C0CEB5B7C2C6C6BD
C5C9BABEBFB6C3BCD3C9CDCBC2F7C0B4C5C3BCA3DAB8D9C8
91CEBBBBC3B8BFC9B7BBC1BBD4B0C7B6BAB6C29F729FADCD
E7CEBBB4C0C0DAC5D6DAC1B4B8B2ADBEB9BCB4C3BEC1C7CA
C3C3B9C3BEC5CBC5C5C5A3CBCDC1A9C9C2D3C5B4DABDE2E0
C7DDC3D0D0D0C7E2
B9CEC1B8B3CCD3BBC1C3ACCEC7C3B6BFCABEAFBFB9C3B9C0
C2BEBCC5C5C5D1CCCFC9C6C7B6B0B6C0C5C3A6D6C093C1B6
ADCBB7C5BDCCCADAB6B6C7C3C7A8C5BFB6B6B2B6C2C5D9A1
95AEC1BBB6C1BAC5BDBDCDC6C5BCC2BEBEAFB4C9A5ADCDC3
CABBD3C7C9BDDBD7D1ADCBC3C2BEBCBCD3CABBABB4B9D1AB
C0D6CFD3C5D6CEBA
ADD0C5BEB3C9BEC1C2B6C9D2C9BCBCB6C3BEC9B6AEC1B4C2
C6C6BCC8BEC0CDC3C9C2C0D3D3BBABB8CF90C99EB8ACD0D2
B6D1B1B6BDDDC3BDA4C1B0B4C3BEBCBAB6B0C5C9C7B7C2C9
BCC5B2C0BFB6BCB8BF95C9CBC3D1BEC5BCC2BECBC3C7BEC3
CECCD6CBADD5C7BBC8C2B4BCCCBDC5D8C7D6DDD1BCB6CCCE
DFD8C9C3D1A6B4CB
BBB4B3B0B6C1B9C5C3CDB0D0C1C9C7BCC3BCADB6C7C6C7C1
C3D0BCB4BDCED0BCB4C0D3CCC2BEC7B6C2BABAB9D8C7CCC9
CDC2B8C2D6BEC9CDB4BCC3BEC5BFC5D8BEB0959FD4B6BCC9
D1B8C0C2C5C0C2C3CBD2A3CFC9BEC2C3B8CFD8C7C0CDD1C8
AFB0BCC5B4CCC0CEC2A4D3B1BEDAD8CDC9C5CDBEBCC7C3B7
93BEC2BAD5CCA3FF
D18FC0CAB9BEC7C0B6C3B7B7C3BDC3BFBBB5C9CDC5A7C7BB
C1C3CABF9EC7C3C5C7C7C5D3B6CB92C1BFD0CED3CDA7C377
CDC9C0BAB4C7C9DACBC3C3BAB3C2BCB9B7B1BEC5BCBEC7C0
CBB4BBC0CCBDC8D8D2CAB4D8BCC0B4C3BBB3ADABB2CFBEC3
D0DAD1C7CBC3C5B6B6BECFB6C9CAD8B2CBC5D6CF81BDC3C2
CDB6B8D0BCC3C89C
C5CCC9BCBEB8C5C7C5B7A9B4BFB4C0C3D0B6CFB4C2BCCFC5
BCBCC7C7A4BBC7C9C5C7CBDAC0D5BCD4BCBCD3C5C3AEC7C9
B6CDCFAEBDCFD5ADBCC0B4AFB7B2B8B250B2B6C3CCB3B3B1
C0B8BEE6A7C2B7BBB0C0C3BEC5C3C6C9C6BAC9AFBEB0ADA5
C0B6C0C9AFC9C7CED3B9C1D4CDC7C1D1AFD3BAB6C9CFB49C
C3D6C3B5D8A3BCAC
BDC2C0B4B5C1B9CDCBCFC9C9C5C5C3CDD4BBB6B6D0C0C2C2
C5BCBFCEC5C0BEC5CBB8D1C9B6BDBABEB4C9C2BC9EBE8AD0
BACBBDCAC5B2C2B6BCA1BBBBBDB7C3B79BB8D5A6C3CCBDA4
B7DDB2C3D6A9B8B4B4D8C9A5CDD7AFD293C0B9C7BCCFB8BC
C1D2F4C5B9BFCED1BED3B0BDC7C9C3CFD7B6DAA3CBCDCAC5
ACC7D6D5C646B2CF
D4BFB2E4B9CABDC5C1CAC7C3C3CAC1C1C7C9C0B2C9C7CECA
B8BFC2CFBEC0C9CBBEBCCBC3C5D4B2BABAD1B6C0CDBAC9CA
ADC9C5B4CCC5BCBA9EA3AFC3C7B8BAB1AAADB4C7C5C2CFAD
D9C1CACCD0BBD8CBD1BFD8D8CBCCCEC2CEBEC7D6C2B4C5CD
C7C7BFC5C7CEDDC1BBB0C1B9D0ABC9C4B5CDBEC9C1D1BCBA
B3BCC7B3607DC8C5
BCBDB7BEC0CAB4B3BCCCB9BCCEBBBBD5D4C9B0B8B8CFC4C2
C5C0BFC3CCBBCAD3BABDD3CBBFA1C9CCB9CDC3C7D0C9CAA7
B6CFC2C2B0C0C3BEB8BAB2BCBCB6B0C2CEA1C0BAC9BEC3D1
C3BDD4AAC3D8B0B6D3D1BCD3BEA3C8C6AFB0BABCC3BCC9DA
D3C9D4B7C6B6C9C3C2B7B4B4BCD1C2CAC8A7C3D0D6BDABB0
B9D5B7B7C0B4BEC2
B6C0C8BEB9C2C4B9C6D3C4D5CAC0C8CECEC0C0C5BDC7B7C5
BBC3BCBCC9BDB2CBC7CFC7C6D1B8D3B6C0CAA4C1B1B5CAC2
B2A994BCAFA5B6BCBCC3BE94C9CFB8B2B6B2C3C9B4C7CBB2
B4BDD3D6B3BEC5B8C7BCCAC7BEB4B0AFE4C3BC9CCDACC4D8
C59EC8C9BCC2C7B8A9BAB5BBC9D6B2BBCB7CC2D4B8B8CDC0
B8BEBCCFCBB8C3B2
B6ADC6AFC5C7A6C7C9C2C3D0CABECCCAC0ACCFC6BCBBBDC3
C3C3B9B6C7B7BAC0B9C0C9CBCEBAC8C4BCD8C3C6B7CED4BC
BCC0CFCBBEB9BEC7BAC5C9CAC1BCC0D6C2B0ACB4C7C9BAC2
BACEC8BBB0C3C0CFD1C5BBCBC7B6BADEADB8B8C8D6C9B5C7
C8C2C9C5CBCFBBC7C9CBD4BFD8BEB0C5C7CED6E2C9D6C5D6
B4AAC8C5C2C9C3C3
C1C6C4C2B5BCB6C9C3B0B7C1C2C2BDC0C2CCBEC9A4C3C9C6
B7D1C2B7C5C1C5BFBCC1C4D3CBC5ABC2B2C2B6C0AFC4B7C3
B9B6BDCEC3B0CFB2B6BEC2BED1AAC7CCC386B9B7ADB9A2CC
BFBABAA5C9C7BCCDBCD6ADC0C3C2AEAFA5C5BFC2C9BA99C7
CDA1ADCDD0C3D8C1C5D0B8D1CBD3C3E7C3B6BECCCCCEB8C5
D3B6C1C9CDBACCBF
BBD7CABEB9C6C7C3CDBBBEB8A8BBC5B8CAB7C0BCBEB2BCC2
C8C6C5CCC7C9C7BDADB9B7C0CEC195C99BBEC2C4C6CEB2B7
C7C3BBAAA1B6BCC09EC4C2C1BAC5C3B9BAC5BBD3C5A9D3CD
C7BEB6CBBEC7C9C3D5D3C5C7C5C0BAB8C5BEBABCC4B6B0BB
9FB2C3C2BFC5D2D5CB83D6D1CAC3C4CDD1A1B6A0AABDBEC0
BEC3B9D1BAC5CDDA
B8CAB9B9C7BDC0C2B8C3BEBDAABEB3BAADBEB6D1C5D1B0B6
C1CEBEBAC4C0B3BEBEB3CCCCB9C6BBCCD9C0D8D1DAC3A8BB
C3B7B9BAB0BAB2BCBEC5B7C3CAC3C2C4CAC2A3B0CACAADD2
BFBCBCBED6D5BEBEC7CCB4CFC2BCBBC97DBCBABCC9E1CAD2
BCC5C3CABED1BFE0B4B4C7AF9CC7C7C7BCC9CBBEB8C2CFCF
BCB8C3BCC2C5DCC3
B1C6BBC0AAC0C3BEBEB7C0B9C6BACBB4C8C5C7B9C3C7CECA
BCD0C5C3C5D2C7BEB4C3C0C2C8CEC2BBC8C0C0AFB2D1A080
D1ABB7B0C9B0C5CAC6C8C1B9BFBECDB7C5C7C0C0B9C7C3C5
C0BEB4BAB5CBC3C9AED4C5B9C6C0BFB0C7BCBACACFBDCCC9
C3C5CBC2C2BCBAD3C0C3BEC5CB87C9D2B96CBBC0C3CFCA84
B3A9B6C3CFC3B4D3
C4ACC5B2CCB7C7C5D1C5BCB4C2B9C1BAC9BBBBB6C7B6CABB
C1BDBECACAC2D3CDC0D4D2CAC0BEC7CEBEC9D0CCA4CEADB1
B0AFADBAAFC9AAD1C7BDC2BEC5CDCCD6D4C3AEBBB6C7BEB4
C3C39FC3C5BDC7D2C3CFC2C2C4BFD1C5BFBFC3C9C7D3C5CB
B2B6C7D2C2CEBFB4B8CBC3C9CCCCC4C8CCC2D5D1CFBDCBC9
B0FAB9C3D0C1C8B5
C9B7B9BBBEC6C8C4BFC5BFBABEA8B9BDC2B1A9B8D0B8C0C1
B6C5A5BEC9B3C2C9B6C2C9CEC1BFD5BCBAC2BBBC87BFBEB1
AFC0DCC5BCC7C2AFB4B7B8C2D5CBB9C5AF9AA8BCB2BEAACD
C3B4C5ABC9B2BBE4BCD5B7A3B2BCE6C5CFD6C0D3B4B8C3D1
B6B6C7D6DBCECAC4BECECBCBE2CECEBEC0CBCBB6CAC9CDB0
C9B4C3C7CAC3CBCB
B6B6B2CCC6C4C0B9C1C5BBBEBECAAEB7B9BCB7B6B4BABCC7
C9B9B4CAB9A0C5B7BECACBC5C3CDC5B9B6C5CEAEB2CBB9B7
C3CCC9CECAC7C0A5B6C7DAD1BEB9CBA8A9AA95A7B9B4C3AD
CFC7CBD1B6B8A5C1DAAAC0C5C9BEC3C7B5C4CACAC7BEB3BC
B7CAB0A4C7C1C3D1C3BCC2D6C5C9CCCAC3B6D6B6ADBDC9D1
BCCBC7C2C7C0D1C3
B5C9B4BFBFDDCABBCBBCC2C2C3C0C8C7BEBCC6C4B1C6BED3
C3C4C9C2D0C1BFC5BCC2C4CEC5C2CEB1BECDC0BFB6AACDC1
AEB3C0B7B0B6B4A3CCCACBB889B2C0CDB4B4B6BDB0BAC5C9
C9BAC3B2BDB7C9D0B9C3C0DACABEBDD6BBC5ADC9C0D6CBE1
C9C7CCD4CCD1CACBC5D6CFC5D6BFDDD1D4C7E1BDCEBBC9B4
8AB6C6C0C2C7D8BD
AEBDBAC3C2C2CEC1C0BECABEBECCCEB7BEC2BEC2CAC7C6C0
C7B2CCD5C6CCC8C9C2C7C8D3BEC9C4D3C0BCB4C5CBC9B4C5
DFD5C3BEC5B0C3D1CBC7CD92BCC9C3B9BCBAB0C2C7C0C3C3
B4C3C3C2C399C0D6C3CEB5D8B69FC2C7CCCBD1C9CBC2C2C2
D3C7BAC0D3C0B4B8BAC0C8CBC0CCDAD7D3D3D6AAC5B6C2BD
BCDCCBC2CFCDCCC1
B5ADAABEB2BCAEBDC4C0B5B8C9C4C5BAB9C0B6C3C7CCB6CA
D7B4B6B4C2CEC0CFC5C0CBC2CDC7D5AFBBB9CFC7B9D1D7C4
B8D6D6C2D5BBADBCC3D5C2BEBBC2D1C5B9B8B6B9C8C5CCB4
D3C4C9DCC3BACECCD6CFCECCC2BEBBB2D2E0BCD1BABEBABA
C3C7C2D4D5C0BDB7C9DFCEC9D2D3AAC5CBC0D8CBCCC9C7CF
D18CB5C0CFC2C3BE
B6B2C7BBBBC6C3C3C3C7CAC9D1C9CDC5C2B7BFCAC2CBCCAF
C4BBC4B1CCCCB5A1BCD8C2D4C0D484C7C194D0BBADD1D8B2
B6BECCAAB7CDA9B4BDCFB3BABFBBC9B7BFAEB6B8C5C7BEBB
B4CECEBFC8CF98CDB8C0C3B6B0ABB4BBC2B8B6C2B8CDBAC0
C9C0A8BBCAD5C5D6BCBEC4CAD1CFB1C3C2CDAFC1D3EF89C6
C8CCC7B7C5D0CBB9
C6C0C0C8C4ADC7C9B9BFCCB9C5BEC7C7BBCAC3B3AF7BBEC0
BECCBCC6C2C4B7C1BBBDD1BDC0CCC3C9C1A4DBCCB9BACAD6
8EC5CABCC3ADABB8B09CB8BACBB9BABFBFB7A2BCC9C2C2BF
BFD8BACDCF9AD3B0A5C0B2D5BCB8C9BCC9C8C2C0C5C3C0C3
D1CBC1D0CAC7C3D6D5C9CFCFC5CECFC7CDC0D3CDC5CDDAC8
BFCAC9BBD0C7CAC5
B4B6B2C2BC9FBDC2B9BDADB6C5C3B8B2B8C2C9CBBCAAC9C7
CDC9C7D198B8AFC1D0C9CAC9BBC8CDC9B0BCD3B9CDBAA6A8
ADB6C3A5BAC3BCB6BCCFC0C5B0C7C0ABBABA96C2B0D6BAD3
C1C3D8AFCFB4D1B6ABBBB792C9C0B2B2C0B6B0AFBAD5C0D3
CFBAC7CBCBCDD1CFBAC5C3B2BCC5A5CEC3DAC7C3B7B9EFB2
C5BDB7E2DAC3C4BC
BAC3C9C0C8C0CECCC8CAC2C9C0C0BBBCB7A1BEBDC1C0B4C6
C8B9CDC7C4C7B9BBC0CCD3C2BBCEBCD5C6C0C3AAC5ADC3C0
A9BDB7D3CABEC5C0BDC5BAC0BEADC7C0BABAB1B5DED3BACE
C2BACCC1BCCDD2C0A520C9C9D0B6C5CDBFB4CAC2C5C9B6CB
CDC9C7C7C5C3BED0C5DAD8C59EC2CABED3C7C5B8ABBEA0CF
CFC5EDD5B8A9C1C7
B7BCC7B4C9BDC3DAC2BEC2CCB5C1B8CAC7C1B7B6B4C2C4BD
D1CBC4B8C9C4BDBBCBC2D0C2C4C2DECACCC3CBCBD6CDC5BA
CAC5BDB6B0C9C9BBA5B6AAC5D6B0C3C2BEB8A4CDB6EBAABE
C2B9B9CAD1C9E8CC9CC2C3ABC3C6B2BCB6C0C3C3CCBFC1DB
C2C3B8C3C9C5D3ABADCAC3C5C3B2C9C6C5D1CEC0B3D7BDCA
C3D6B2CBB6CECDB0
AABBBFB9B9C7C4C7BEBCB3C9BFDCC7B7C7C9C5C0BEC5B4C9
B9C7C6C8BCCABEC3C9C1CBD4C7D2BCC8BFBFB2B0C2B2C9AC
B0D6C2BECABAC4C7C0CBC3D3B6C5C1DABCB2D5BBE1B0BCB8
C3D1B0D3C7E2D0BBC2ABE4CCB6C1C3CCC8C7BEDFB9C0BCC1
CECB93C8D1B8B6C2CACAB4C5ADC4C8BBCFCFBEB2C5D07BB3
BAC2C9B2BEAFB2BE
A9C9BFADC3C9BDCDCEB9C6C8CCC3BBA9BEBDA9C0BEC5BDBD
D2C1B9BCC3BBB9C0C2B5C7CEBFC7B6DFC5C3C7D1C7ACC5CD
C2D6C7D1C7D3B2B1BCC3C2B2C3D1BBC9C5B9B9BEA6CABED0
A9C6D7E7CEC4BEC5C7C9BEC7C3BBAF8BB3CBC4A6C9BEC0CC
C9C2C7DAE0DCCDD3BECFCBCFCDBEC9C0CDC5ABABD3C5C2C5
ABA8DBC2D3C3C5BA
B6B6BFCEBBC9B7BBD3B6B9D3B4BDBBB7B6B3BCC8C9C9BDC2
C8BEB2BCC5C3BEC9CCC3BDC3C9CDDBDAC9C0C2D0CAC5CCBE
CCBECCC3C3C1D2D4AFC5A6C1CAC7B3BBB6BDBAB4B2BCBEC4
C0AFD5C7C2B8BCCDC7BCC2B7B8A6C5BABAB6B0BEC2C3C5D5
CDCFC5C0CCD9CFBAC3C7D5C7CCD3CFC9C5BAB8ABC6C0C0C0
D5CBB6BBC9D4BDC3
B0C5C3C5C0CABFCAC7D3B5BBC8BBBCCCB7BCBDBCC7BEB3BD
C9C9B9C4BEB9AFC0A9BCD4C5BAC9B7C4BBB2CCC2D6C7C2A7
CBD5BCC5C9C2CAC8C7CEBCC9C2A5B9D58EA3A4B8C2B2CFC9
C9CFBACDB2C5CAB3B8C9C9BCCEBBC3B7BEB6C7C5D6BECBCB
C2CBBECBD3C5C7AACAC8C6BCBBC7CBD4CEC9C3BDC9D5DDC2
BCC3C2BCB1BBC8BE
ABB7C2C7C6BBBDC1C3B6C1C0C4C0C0C0B6BAC3C5C3C2B4D8
CCC2A3CAC9B5CCCBB9C9C3C7B7C3CEC4B4C5B4ABCAC2B4BC
BEC8C4B5BBC5B7A2D5B2AFC7C9C5C5BAA1AFB4BAC7C2C6C2
C2BDC9A3CAC9C6BBBCCAB8C8BDB7BECBCFBCB7C5C2BDC2C5
C7C3BAB8B7B5BCC2D8C2B4CAE1C9C5C3C9B5B6BCC7AABECD
DED1D8CDC7C3CBBC
B6C2C0CACFB5BAC6C2BDBEC0C6B0C0C3B6C7BEC9C5A1ACB6
B8C0C9C2B5CCBCC9BBADC9BCC0D2C9D0BAB5C4C9C2BDC3C3
C3B8CECCCACFABC2D6C0CEC7C3B2C0B2B6C0B0CCC8C7B6BB
C7DDCBBDE6C7B4C3D6D3C5C5BBB0C4AEB992C1EEC2AFB8CD
C3CEBCC6CACEC9CCD8AAB7D1C3CACECFBCD0C8D0CACCC4C4
B9C2C0E4D2CCD4CB
BFADC1C3C9C9BCC3D8CEB8BCBABAC0B8B9C3C6C5CED6C1C0
ABC5C7C1CCB9B7C7B8C0D1CCC1BCBDC1BAD0B3B5C7EEBEBA
BCBEBECEB6BEB6C0CDC0BBC9B4B8B4C0C3C3B8C3BCC2BCBE
C9C3BCC0AEC5BEC5DAB2C7D4D0CEC8BEC5CCD6CCD2B6C0BC
CDC3B5C0CAC4CACDCDCFD3C9CED5C5CDB8C8B2A19FC2C1D6
C2C5CBC0ABC5A3B8
AECDC0B4C3C0AABFC3AAB6C5B9BAC8C1B7C6B4C9B4BCBECA
C9BFB0B6C5B6C3BDAAB8DFC0B0C598BBB7CADEDDB9CEBCB9
B9C7A8B9CACCC2B9BBBDB4CBB6B8C5C1C5AEBCC5B0C5D6BB
9EB7CE9BD8C7CAC7BED3B2D1B0D1C3CBD0BFBFC3C58DBEB5
B4CCBEC2D1CDC3E7CBA5CDCDCBCAD0CCC9C9C0ABBCBCA988
C5C9CCB0B2A3C3B6
C6C5C3CAC4C2CACAC9BEB6C0AFC5C6B8CCCDC3C0C8B0BFB6
D0BCAAB9C0BAC0CCBEC3BDB4B9CACAD3C0CABBC3C3A4A8BB
C9D1D3CAC0D1CBC0BCB2C7CBBAB6C3C7B6BCA8ACC3C9C2CE
BDCCCCBAAFD2CDD5CCD2CAC7CFC7C6ABDACCA8B6C5BDA4A3
BCD0DBCFCCC1B7CC82CBD0BEB7C6CEB7D1ADA8C47FB6DAD1
BD90C3CCC1C58ED8
C0BFBDC4CAC2BEC5B6B9B6BDBFBCC8BBB2BFC7C2ABD1C4C5
C5BBC3C5CECACEC3B4A6B7C1BCC8BFB695CCD8CCBBC5C8CA
D5C5C2B6C5CBBCADCBB8CAD0AEC5BBC3C7B4B2C5BFB9C3A8
B9B6BAB8C9D1CAC4D1DAB8CBBEB3C5D1B9BFC3CFCCB99EB6
C5C3C5CFC9C2C9D1B0C3ADB2CDCDC3CA649AB4D7A692D9C3
B6ABBC9CBCB6C5C4
B5C1BBCAD1B9A6BBC9BBD8BBBCC0BEADBBB6B7C5B4CCB9BF
C9C7BBC9C7C2B8C7D6B4CBBAB1D1C5B4D870C6B6C9BDD2D8
C0D1BCCAB0D9B4CBC7C9DDB2CABEBEC0BBABC3C6AFAFD3CA
BEC6CABEBFBEC5D3D8B9B3CCD5C6D1CDADABC7BDB8BDD9C6
C7B2AEAFBFB7C3CEB6BFB7C2C2E1C3BEAFC8AD9EA8ACAAC9
C1B6B0DACAF1CBFD
C3C3BCBEBEBFBEC6C2CFC7B6C9BEC2BCB0B0BFC7C5C4CCC5
BED3CEC8C9BDC5CBC2B2D1CBC8CCADD6AFB2CEB0D5C9C2D0
D6DDC5AABFD0B29FB6C1C6C4BECFC2C4C4C0ABBDB7C5C3CD
C5C2CCB1C6D9CBBEC9B9ACBCAAC3C9C3C2C3D6BEBCCBC2CF
C2C5CCC7BECEB8BDB8CACCC8B6BCB9C1C1BBB4B189C2ABBA
A9C9C5C4C9C7C99B
B6C0C9ACBBC7C9C7C9CFC0BACAAFBEC8B7B0BDB7C5C3CAC2
C5C0B4A8D4CDB7BEC3BECDBDBBCAC3C99EBECCB7C2C5CBBE
C9EAD0D8A4D4B6B7B6BCD3C0D1B9C0E0C0B6AEB2C5BCC5AE
B6CBB6DFD2CAD9BAC2C7D3DEC2ADC7C7CABEC7C3CCD1C3D1
C2CECBC3C2C3B6C7C9CEC0BCD0C9CBB8B4C2BBB8C7CFBAC9
C2C0CFCBC3BCBECB
BDAFC2BD9EBAC7ADD1C3C0B2C9C3BCAEB8CBD6C1C19FC7C7
C1B4A8CB00B2B7C1BCB8C9CDD1CEBCBEC092BAA7C3C3C3AB
8EC0C3BCB0D1D1C7BECBC9C5D1C1B4ADC7C7ADC0CBCDD5C3
C7CABEB578CABCC9B4C7C3B5BBC0B5C4D3C7D5C0B9CDC2DA
BCCDE2A6C0BCCABCC8CACBCBB1D0B6C9BEB8B0B8BED9A6C5
B5A5CDD3B2ADD2D8
CBB6C3C5C9C0CDC7CCC3D3C9B7A6BFBBBCC9C0C6CEC5B8B9
B6C3BFC7A4BFC0B4B9B6BBBDCCC5DAC0D3C9B8A1BCBAC7C5
DFC5D2B6C2D4B1D2ABC9B0ACC3C1C3BCC7C0A8B3C9C3C7B2
B5BFBB69ADC0AED9B6BEC2B5D4C8D0CED6B6CBB9CBC2BECF
B8C0B1C2C0C3D3C4CDD3B8C7D1B4ADB5B4C3B8B6D1C0BCBB
C2C9BCC7BED4BCA3
C1C1C9B6CDC7C1D2BEBAB8C2C3C1BBB7BDC2B9BFB9C3B7B4
C5A8BDBDC7C3BCBCD1ADCBBED3CCD3BABACDD9C9E3B7A8A4
C7B8B8C7CBC2CEB7DACCCDBAC0C7B6C2CCC9A7B0C2C3B8C7
B2BCC3CFD6CFCABFC7C3E1C2BBBECECCBFC2B6B1C2B4D5BE
C8CEC2C3D6E2C8AFC0BAD1BCCEBA9FB0D1CCB6AEEEB5C8BE
ADCAC0D9C8BCA4BB
BEC3C9BCADB0C0D5CFCFC7C5BFC9CCC7B8B9BCC9C1B9C8C1
B6C1C3C0C5CBBAC3B8CBC0ABC7C9D2B9C0C1BFB8B0C3C1C5
B2AEB2CBE2C5A7B6C3DFC0C2C9B9AFCECBB3ADC9B9B2CCC3
B6CFC9CCC8C4C6C2C0C2DAC6C3CCA2C8BECACFC0C4C5C3D3
CEB3C7BCCDCF98BAB2AFC6DCC0B0D0C5CFC9EDDBB9DEC8B3
C0C1B6C4CDBCCEC1
BDB7B4B9BFC3BABAB2C5B2C6C7BDBDCEC3BEBACBB6CDC7C2
C3C9B7BDC2BEABBFBFB1CCC0AEB8B6BFCBCDCBF1DDDBC0C8
CBB2BACFC3CBC2CCBCC3DFCADBC2B6C6C9BEBCBCAED0C1BA
C9BFC1C9CEB6C2BEB4CDD0C3B2C0AAC2C2C3CDB4B2ADBBC4
C0C0DDD5BE9AD2B8B3B5C9CBC9D6B7CEADB9ABC0B2C6C9CB
CEC7CFB6C5BBC3B2
BDACC7A4B9B7C9C0C1B7AACFC6B6C4C9C3C1C6C8C2C8CAD0
B9C5C5ADBAB4C5CDB2C1BEBAB9C9C3B8CBC0C9CFAAC4CCAD
B6CFCDB6C5CAB0C7BCBAB0BCC8D1C2AFCDB6A3BCCABBBDBD
BDCDB0D3D1CAC9BED5CCCCBE9FC2B4C09EC7A7CACCB9BCBB
BFBFF9A8A1BF8AC7BAC2BBD5DABCB4BECBCDB79CE0C5BCA8
C3CFB8C2CFC5CEBA
CACBBEC9B6BEC0B7B6BAC2BEC2C1C0A1BAC9C7C9BFCBCBC5
C2C7C0BEB6BEB6A5C7AECBC9C5C3BBD4C1D4CDC2B4AECFBE
C9C3C3AAC4CFC0D1BCBBA7D1B8BFAE81C9C2A7BCD6D5D3CA
B9AF9ADABCC9BFBFBCCBDFB0BCC4B7B8CAC5B7B9C5C7B6D5
CDCDBEAFD3C5C0C9A3B4CCCBC7B2C2C1C7C9C9BCCCAFD1C5
D1DED5C2CACFB9B6
C3ABC7C3BDC3C3A3C1B2A4C4C2CCBEBDCCC6AFA0C0B2B9C7
B9CFC2BCA6B2C9C3B9B7AFD3D1DBA6A4C4C5BCB9BEC8CAC2
C3BBC8CCD6E7C3C5B69CDBB9D6D4B7C0C9B0B8ADDFBBACBD
CBAFC0C9C0B1B6C7CFBEB7B0B6C9CEDFB7DAB4BBD8A8D1C4
B9C8DDABD4C6CBB6D4C3C7C5CCB8BBCDC0B6C9C0C1C5C2CE
B4B9C295C5C7D4B0
BEC3CEC1C7C3C2BEC0C2BECFC9BCC6D0B9ADCEC0C0BEBBBD
BAADCBB8C2C2C0C9BBBBC0CBCEB7B9C2B1B6CFBCB4ADCCC5
D0D4D1CCD3D5C0BCB0D5B0C5C1BDCCC3CDC3C0C9CEB4C1B3
C2A5B8CDA1BEBBAAC6BDDBA9D3C3B7C3C5B9CBC9C3C5C0B3
B0A7C2B9BCB6CEC7CEB0ABBCC5A7B79AC6B8B8B6C8CEB5B9
CCBCC3CAAFADC27D
B5BBAEB6B8C7C0C8CCBCC5CAC3C5AFCCC3AFACCAC3C2C8C9
BBC3CABECACEAFAEB4C8C7CECBBFCCC2C7C4D1B9AFD5C3B7
CAACD08BC9B7C9A3C3C1C9B8C2CDC9C5C3ADC2DBBFD8C7CB
BAC5A6BFBB78B8C4C9DFE1C3BBBFDAC9CDBCC4C5B9D6C9A8
BECEC7C9C9BBBBDDC593B4C9B1BEB591BA9BC0CAC3C5C5CC
C3D4CECDB6C5B3AA
B7BBDAB3B9B9C1BDB9C9C7CABCCBC3B5B9CABBC6BBCDC8C5
B7B1CEDA99C9C3BFBFA8CAC0C2CAC8D1C7B6D0B9AFCACACD
D0CCC2BAC9B4ADD7C9BFBBCEC9CDC9BFB2B9B0BCC9C3C7BE
BCB4CE82C7A2ADD1D5D1CDB9CCC9C5B4C1CBBEBEBAC0AF92
CBB6C7C4BCC7A6B0CFCEA1BACDBECBAEB2C2C9CBCFC7C2BE
C4CAC0CCCED4C0AC
B2BFC1C3C5C5CAB6C2C2C5C5BDB4B3BCBAB8C5BEABB9B6C7
BBC0C2B99DB3BEC1C7BDCCBEBDD1BBD0C4D0B6D2C0ADD2C9
CECCC1C2C9BFBCC4D1C3C9B4C3CFB4C1CBC7B4C5C0C7BECC
CCC6AFC0BC98BFC7C3CFC0B9CBBEC0B4B7C6C3AFBEBEAFB8
E2BBAFC2C5D3C0A5CBA9ABB7C9D1C9C0DBEDD2B0C2B4AEC1
C3C0C2B2D3C2BFAC
ACB7C59EB5BBA8BDC6C7C2B1D0C9C7CCA8C0AABCCBBBB4B3
B7C4C7BABCCCB7C0BEAAB4C3C3CDB5B2CEC7C1C2BCCFD1B9
B2D8CACAC9A3D5A9C3EDBAC5CAB4C5C3ADC0CCB8AFC9CEC9
D8C1C5C1B5A0CDC5C7B997E9C3C9B7AFD3BEBEC7BDCCC99B
AFB5C2BECFBFDFC2A2C2C0C3C9BDBDC2BCBACAB5CCC6D3C5
C5CAC0ADCFA2BBC7
B7BAC5BACAC7BEB4BCC4C1A5CCB6C5D4AAA7B8B3B1BFC7BE
D8C3C3C3B4C3BBC1C2BBC9B3B8D5CFC8B7B4C39FC0B4C5C5
FE33A595C3C7BFBBB2C7D3CDB8C0B3C9C7ABC7BACDBFAEBC
BBC9BFBDC0A1B790D4B9ABC5C5B0C5B8A1C5C7BEC9BCBCC2
C7C1CBB0BBBFCAC8B8A492ACC5D8C7AFBCB2C7CCBDC3BEBE
BECDD1DACBB8B3A7
C0BBBEC7C3C7B7C0C1CECACDC0BBC9B9AC8979B9A0D2C3C2
C7BDC4D7AECEB4B6C0DAC9C7D3C5D1C7BBBBB4C3CBC0B9AA
B094CAB8AFD6C2BECEC5C0C6B3CAC3D8CEB69FB0BEBEC6BE
CFCBC5C29AB99FA4B2C0B4DFD3CE91A8CAB2C1CFCDBEB2B6
C9B49ED8BCC28BC1AAB1AFD4A3AFA6BEDAC1B6B4C9C5B0C5
D1CAC9C7C7C2C2AA
C0B6BBB9B3CEB9C6C2C9C7C9B5C0BABCC6B1C2C5B7C2B6B7
C4D6BCBCC1B2C0D5BEA8C3C5BB9FD1C3C7AFB4C3CED4C1C1
BEC7C7ADBDB7C5C2B6DFABC7B2A1B6C9BEB4B4C9B8C9C7C1
BDCCCBB1C5B98FAFCBADCFBFBEB0B6CFC5C0BACEBCB6A6CA
D5B2BFBECAC2C9BDB78BBBBFBECDB2C986B9C9C5C0C9C9C5
C3CB9BBBCCBFBDA9
AFBBB7BCBEC7B4A3BEBFBBBCA3C9B2C3BFC8C2CFC3BDC7CA
CEBCB7BDB7CCC2BEBECBBCB4C9C5B8B6C0A5B6C5B6B9C4B7
C2C9C7DADDD0C3BBBFCBD8A8B2AABCDBCABDC9B6B5CACDD2
C5AF9AD6CAC5BDAFC7B5D3C6B5CCB7C09FD7BCB3A8B0C9D6
B8BFAEA9C29F9BC2B4BABDC3AB93BBBBC5C9BCBDC8C9C6CA
CED5C5EDB0B7A39F
B2B5AFB6C4C1C2C3B6B9B2C0A5A9C9C3C9BAC7B4C0CEC9B1
CFC0C3BFC3CEC2C2C7C2B6B9C2B6BCCAD5C0C7B3C2C4C9CB
CDC0C2C3D8B4B7D1B8C9C8C0BBD3C1B7CDBEC6B8C1A7B7C0
C3C7B3BBD3C7BBA5B1D3C7EBAFCEB5B9AFC2B99588B4B5C7
C0C3CFA7B6BBAABEAEC5C4BEB6C3CCBBBACECCD2C8D8C6CA
CACAB9C9B7BFDDB2
B4B1B8C0AFB0C0BCBDC7C7AEB9AEC5C1C0C0C3C9C7A3BDC7
BAAFC5C9C1B4BBC6C5BFBED5D9DAD9C3B6C3C3B7BBA8B2C5
C3CFB0C9C5D5B9B4CFD3C2C2A5AFC2C2CDB6A6BABFCBC2BC
CBC1C1C6D6C5D3AFCEC5CCB0C3C79ABF89D3C7AEA5B8BCB7
C2C0B5C0AFA8B7B8ACB9C3B6C9CFB5BECBC9CFB4CFB353BE
BCC3CAC3BDCAC9C7
C3ACB4B9C6C9BFA1C9B6C5BAC2B6B4C0C0BDC0C6BBADE9B4
BFBE74BBC3BEBDB7B4B0D1CCDFD5C3B4C3BEBEC8C0B5D5BE
D0DAE6CEA2C0B8C7CCD3BDC7CED1BBB698A1B4A9C0C5C9C5
C9D3CBAAB6C0C7B9BFD4A698BCBEABA1979ABB829CC7BDBF
C6C0DBBCC2C49A9AA3BEC5C7BABCCCC6D4C5C3D5C9BFB7B9
C0ADB7C5CAC7B6C9
B4ACBDABB8B4BBBFD6D1C7ADB4BCB9C49EBFBBAA9FC5ADC8
B9BCA7BDC3C0C8B2C4DDCAB8886AA9BEC9C7BABAC9C4B7C2
CACABDC7CFCEAD9BB1A9CBBCC2CAC9B9C5BEC5C5CEADBBC7
C7CFC6CA9FB7BCC3CBB1ACAFBBC3B9CFB1AAC28785B1CDD6
A0C2ACBCB0CEB7C3B9C79BC4C4C0DFBCC7B6B8C2C1B4D1C1
AFD5BCBBD4C2E0A1
ADBBB5BBABB9BAC3C5C7C6A8B6C3B9AFB4BFB4B9BACECEB6
AFC0BAC2BAA6A9BECBB2BC93C5CCD0B6D5B6D5ADC3B5CEDD
BAB7C1B8B8C6C9B7CCC3C2CBCDC5C3CCC9B6AEAABAC5B9CE
BAC2C2B5D3B5C3CAC7B99DC9BDADBFC3B1C89398B2C9BEC3
B8B8CBC3B9C0C5BBCEC5B9B7CEC0B9B8CFB7E7C7BECABBC3
C9C7C9DCD1C2B4C3
BCC5B2ACB9DAD2BDC3BBC3B9AACDB7C3B7CCC3C1BEC5BAB0
C0B4C0CDBDB4BFC0B69E9E85B6BED3BAC5BCB4CCC3CCCFC9
9EC3D7D1C5BECBD1BBD1CFC9C9DFCEB4BCC5A8BCD4C1CCC5
C0BAC0C3A2DBABB2CFE97DD6A1CCB7BBB9B4AA9FDFCAC39C
B0B6C0D5AFD5DBBBC1B7C6DBCCCBE5B2BABFA1B0C2B4BED3
BECDD1A5CD96C6BD
BBB9BCCA99B0BBBDBEBBD7B4B2BFB0B1CFC3BDC6C3B2C0C9
C5CBC9BBBFCCC3CFC7A8ADCCC9B8BFC7B2CAB7CEC9C0C5B6
BFD1CBC7CCCCC1C7BCCFD2C3B6D68CC0D5B29AB2C8CFC2BE
C49FB4C7C3C0CFC2ADAF9CDAC2E1BBB9A4D8C5A989C1CB9E
CDBEE2D6B7C7B8D6AEC5C5C1BDCABEC1AFCFCBA4A8C0C0BC
C0D1B4C0C3C7C3B2
B9C0C7C3C9AEAFBDBFC5C5A3B4B6C4C5C7C7C8C5B7C9C5C4
B1D9C5BAAEC79FC7D0C2B8B9C5C3BCB4BAC2BECEC2C8BCC9
CDA8CFC5CFD1CFD0A2C0C4AF79A9B3BBC9ADC5C7C2CFB6BC
C2ABBB9FD5CFBCC2D3B8C3949AA5B4B4A08BA9A1B4D3C5C9
BCE6A3B6B7C5B2A7B0B4D5AFCFB2BAC6C9C3DACFC5D3BEBA
B8C5C7BFB6BEB9B6
B9C4C2B7C5C5A9B4C3BFB7BDA6C0B8B6C3B4BABAB4BDC3C1
C3B0C5C2C2BCA7B6C998CFB6CBC9BABBCDC9C1C2CCCFC7D1
A4F6CAC5C3B3CDBDCAE6AFDAA6D0AAB7C5B7BDB9C7B6C5B9
C6CAB6A9B4BCC99C9FB7B68AB4C2C9ADB1ACB99FA8D8ADB2
C2B2CBA5D0B6BCC09EBCAFC4B4B8BEBAB8BEC5C3C2C3C9BE
C3C8C4CFC2C7C1B6
C1BED7C5C9B6BCB4B4CBADB4B7B8AFBAC3C1A3BDC3B4C7D6
C2C3C0BEBEB9B0BBC2AFBAA8C9CFC7C2C1BCC4C4C3C5C5CD
C3AAC1BCD5CDA5BEBDBAC5BAB7C6C3CBC9C0B6B2C6C6C2CA
BBADC9B3AAC0E0C2C9B3C0ADD4C78CB8BEB8C3BCB2B4BA9A
D8C2C7C2B6C5AAC69ECDCFC4D3CED3CED0BDB2B4BDBCC4BE
C5C5CDBFBEB6B6C3
BCAEC3B7B9B4C7C9AEB9BFA3ACB5BAB8BEB6ADBEC8CEABB6
C2C5B2C5B9B4C1BCC1C1B3CCB5B2C9A3C6C364BEC5C0BFA8
C7D8C2D3D5BBAAE0C4B4BCCCB5CDBEC4C6C0ACB5BCB0C9C5
BDC0BBC3CEA5C8CEC7C7C4A3CAD2B7AEC2BBA8C3CEA5C0B7
C0B1B7A3D0B9ADC9C3BECCC7BCCDDEA6B4A2B5A3BAB0C7CC
C9BBAFC9C5B7C3D1
BCBCBDB9BFC3CCC1C0C2BEB4A7B2B2BDB6BBB9C1A8B79AB2
BEC9B9C9BCB6ABB8C3C1CCBADBC3C108C7C9BB98B8C7C6CF
B3B6CEB9B0CF9A9EB7C2C3CBC2CA9FB6BEBBB986B8F1D4C2
CFBBAFC7C2BEC5CDD7A3BCBCDCCFCFC6BBC9C0AA9C948ECC
9FBAD5ADD1ADD7C0A5D1D5DBCDB1BCC3B7C0BEBBC0B2BEBE
C6B8C7CCA8C3C5B8
BCB6BEB0BEB6BCBFC1BBC2B6AEBBBCB4B4BAC2C2BBBBC7AA
C3C5D5C3C6FEB9D3B6B4C5D0BBC5B9BECACAC0AEC7C3C9B4
CFC7B6D2B2C3B0B7B8C9CAD0C1C0C7C7BCB0B4BBC7B0BFAE
C5BDC5D6BCC3CABEB7C9C4C5B0C7B9C5B1A893A9C9BCC2B4
C6BBD5C5D8B0B4D6C9CCBAA4ABB6CD9FBCB7C5A8C5C5C3C9
B8C1C5BCBAB5C2C0
BCBAA9C1B9B9C0D6BEC3C0C9A1B7C9B2AEB9C5C5BABEA8C5
B9BBB0BBC582ADC3C9B4BDC3C7D4BFC2B4C2B4C5C0C3DAC7
CEBFC7B4C9B4C5C3AAC3E2BAB4BCBCADCCBDC7C7BBB6CFCA
BECED3CABECAB4D6B0BEBACECBDAD1C3B3BEB7C2BCC5ADC7
B4D0CEC7D3D6CFCDC3BCB5A1C1CBBDB9B6C9BCBFC5DACBC7
BEC9AFC7CAC7CCC7
C9D8CECEBCAEBDB2BBB4C2B2A8BDB6C0C7C5B8C0C0A5BEAB
C94FC0BCCCBBB6C3C1C7C3D0C9C1C3C1B9C4C3C3BDCAC2CA
BBBDBDBEA1CBC5C0C1B9C9C1B9CCBDC1CEC3AFA5ADB9B9BD
BDD191B9C8BAC7B4C2C7B6D1D5C3C7BBA09FAFB3B0C38EC5
B5BFBED7A4B3B6BCB5CBC3CED7C9D5BF8CB6C2C6D4BCC3C0
C5A1BAABD1C2B6C5
C0B7BBC5B7CEA1C7B9B4C7B098A3C3BBBEC3C0ADAEC7C5B7
CCBDC1C19FC3A59EA1ADCCC3B4C3CFC3C5B4BCCCC3C7BAC9
CABBA3C5CBD3A2B7C2C3B0C3BBC9C2BCD5C27FB4D5D5CFC2
CBC5BED3CEC9CCBEB9CAADB1B5C6B7BBAFA4BCCF95B7A6C3
CBCBABBAA4CEB8C0D1CED8C9C5DCCDC7D2C3BAD3BBC3B992
C9CCCCC5D6D2BBC3
B5BFBDB8B9C7BFBFA9BBBFB78D97B9B9C9AEBAC7C1D5BCB6
BFC1D0BDB6B6BBBFBBC2C9C5CAC3B9BFC5C7C9CEB6D3CFAF
CAB0C7CBD6BEBEB4BAB4CFB9C7DADDC2CDABB9B6CCD4DAC0
D1C3CDCEC7AFAFCCB0B0C5BBBCC0CEA9B2AECEC8A8B9AFCD
D0B4B8D3C4C8BED0CAC8D8C3C5B6CAC0BCCBA39CC2B7C0C3
CCDAD2CDC2C9BAC2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[.5 1.0125 -35 0 ]
[.5 1.0125 35 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Classified) show
123.000000 12.812500 moveto
(5) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF\
A03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFE0FFC0
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFFF0000A03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000
7FFFFF7FFFFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF00007FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFFFFFFE0FFC07FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFFFF0000\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFFF0000A03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFFF0000A03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFFF00007FFFFFFF0000A03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFE0FFC0A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFE0FFC0\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFFF0000A03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFE0FFC0A03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFE0FFC0A03FFFA03FFF7FFFFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000FF0000A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
7FFFFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFF7FFFFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFFF00007FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFFF0000FF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFFFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
FF0000A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000FF0000
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFFF0000
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFE0FFC0A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFE0FFC07FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFFF0000A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFE0FFC0A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF00007FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFFFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFFF0000A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFFF0000FF0000A03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFE0FFC07FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
FF0000A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFFF0000A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFFFFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFE0FFC0A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000FF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFFF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFFF0000FF0000A03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFFFF0000A03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
FF0000FFFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFFF0000A03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFFF0000A03FFFA03FFF7FFFFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFE0FFC0A03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFFF0000A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF7FFFFF\
E0FFC0A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF00007FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
FF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFFF00007FFFFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFFF0000A03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF\
FF0000A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF7FFFFF
A03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF\
A03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFFF00007FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
7FFFFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFE0FFC0A03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFF7FFFFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFFFFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFFF0000A03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFF7FFFFFA03FFF
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFFF0000A03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFE0FFC0A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFF7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF\
7FFFFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFFF0000A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF\
A03FFFA03FFFA03FFFA03FFFA03FFF7FFFFF7FFFFFA03FFFA03FFFA03FFFA03FFF
A03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFFA03FFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{400, 190.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`009@3oool00`3<c<`0a<C40<S8b0020;Rh^0070<G5
a@2l_;`0`l?30<71`@2h^;P0`L710;no_`020<S8b0030<30`02g]kL0[:b/0080/[:b00/0^[Zj0;^k
^`2n_[h0_[jn0;Fe]@2_[jl0]KFe0:ZZZP3AdM40[Zj^0;6a/@030;Zj^P060;:b/P2n_[h0_[jn0;Vi
^@35aLD0d];B0P2n_[h01@30`<00bLW90<G5a@33`l<0_[jn0080`/;20P2DU9@01`35aLD0^[Zj0<G5
a@2h^;P0_[jn0:ZZZP2n_[h00P3=cLd01`30`<00`L710<O7a`2k^k/0]KFe0<W9b@2RXZ800P2>SXh0
1`32`/80`l?30;Jf]P2QXJ40T92@0;>c/`30`<000P35aLD01`30`<00`l?30<_;b`2g]kL0UiNG0<O7
a`36a/H00P2m_Kd01`32`/80b/[:0<[:bP3@d=00bLW90<30`03<c<`00P30`<001`35aLD0`<300;Jf
]P37alL0b<S80<K6aP35aLD00P37alL01`2n_[h0alO70<?3``2ZZZX0^KVi0;no_`35aLD00P39bLT0
1`35aLD0`/;20;Vi^@39bLT0_;bl0=7Ad@37alL00P33`l<01@37alL0bLW90<C4a033`l<0b/[:0080
c<c<0P3AdM401`2f][H0_Kfm0<W9b@2i^KT0/[:b0<K6aP2o_kl00P2n_[h0102l_;`0aLG50<O7a`32
`/8T0?oooc00X3oo0P1oool?0:0oo`<0Oooo0`2P?ol207ooo`P0X3oo00<0Oooo0:0oo`2P?ol0?02P
?olW0?ooo`009@3oool00`2i^KT0`/;20<?3``020;2`/0070<[:bP36a/H0`l?30<71`@3@d=00aLG5
0=KFeP020<W9b@070;fm_@36a/H0^k^k0;>c/`2m_Kd0][Jf0<?3``020;Vi^@070;fm_@2i^KT0`l?3
04Q8B03De=@0^k^k0;2`/0020;Vi^@070:n_[`2f][H0`<300<30`02c/k<0^KVi0=_Kf`020<;2`P07
0<W9b@2j^[X0[jn_0;Jf]P3@d=00`l?30<O7a`020=3@d0030;Ng]`33`l<0_;bl0080_[jn00/0`<30
0:VYZ@2f][H0][Jf0=3@d02<S8`0^KVi0<k>cP2^[Zh0e=CD0;2`/0020::RXP070;bl_02h^;P0/;2`
0<k>cP2o_kl0YZJV0<71`@0208J6QP070:f][@30`<00/[:b0;bl_033`l<0/[:b0<30`0020<g=c@07
0=7Ad@2j^[X0_Kfm0<W9b@33`l<0alO70;jn_P020<G5a@070<?3``2d];@0^;Rh0;fm_@32`/80c<c<
0=7Ad@020;bl_0070<k>cP2b/[80b/[:0<?3``30`<00`l?30;:b/P020<30`0070<[:bP30`<00cLg=
0<?3``2o_kl0c<c<0=;BdP020<k>cP070<o?c`36a/H0/K6a0<W9b@35aLD0bLW90<?3``020;Bd]006
0<o?c`2b/[80bl_;0=7Ad@2QXJ40^k^k0`3<c<`01039bLT0^KVi0;Jf]P3<c<`T0?oooaX0X3oo00<0
h?o00:0oo`2P?ol07`2P?ol00`1oool0X3oo0:0oo`030:0oo`80Oooo1`2P?ol207ooocX0X3oo00<0
Oooo0:0oo`2P?ol01P2P?olW0?ooo`009@3oool20<71`@0:0;jn_P2j^[X0^[Zj0;jn_P2ZZZX0][Jf
0<W9b@37alL0b/[:0<G5a@80^KVi00L0_[jn0;Ng]`2i^KT0^k^k0<;2`P35aLD0^KVi0080_[jn00L0
_;bl0<O7a`31`L40Z:RX0;bl_02k^k/0][Jf0080[Jf]00L0_;bl0;Ng]`2j^[X0]kNg0<c<c02_[jl0
b/[:0080`/;200L0^[Zj0<O7a`2PX:00b<S80<W9b@3<c<`0d=3@0080alO700L0^k^k0:j^[P35aLD0
aLG50;Vi^@2d];@0bLW900<0aLG500H0_kno0<[:bP2m_Kd0b<S80:n_[`2YZJT20:6QX@070;Ng]`2Y
ZJT0^;Rh0<?3``2i^KT0^k^k0<o?c`020;Vi^@070;:b/P2XZ:P0aLG50<71`@2l_;`0`/;20<71`@02
0<?3``030<O7a`3De=@0_kno0080bLW900P0_Kfm0;>c/`37alL0alO70<c<c031`L40aLG50<O7a`80
b<S800X0c<c<0<K6aP36a/H0`/;20<o?c`3:b/X0[jn_0;:b/P31`L40clo?0P2n_[h01`34a<@0_Kfm
0<O7a`37alL0`L710<?3``3>c/h00P3<c<`01`2c/k<0a<C40;Ng]`2m_Kd0bLW90;fm_@3De=@00P3@
d=001`35aLD0][Jf0=KFeP39bLT0/[:b0<?3``2m_Kd00P39bLT01031`L40b/[:0;Bd]035aLDT0?oo
ob/0X3oo00<0Oooo0:0oo`2P?ol0502P?ol207oood`0X3oo9`3oool002D0oooo0P2g]kL02P38b<P0
/k>c0;>c/`2_[jl0Zj^[0;Fe]@2k^k/0_[jn0;Fe]@3:b/X20:f][@050<O7a`30`<00_[jn0;^k^`3<
c<`00P31`L430<G5a@060<71`@33`l<0_kno0:>SX`2c/k<0`l?30P2g]kL01`30`<00^k^k0;^k^`2V
YZH0^KVi0=CDe03Hf=P00P33`l<01`37alL0`L710<W9b@30`<00`l?30:VYZ@2m_Kd00P2`/;001`32
`/80c<c<0;bl_02c/k<0^k^k0;fm_@2CTi<00P2o_kl01`2d];@0a/K60<c<c038b<P0b/[:0;Jf]P2A
TI400P1kNg/01`2l_;`0[:b/0;Zj^P39bLT0Y:BT0;Jf]P2i^KT00P2ZZZX01`2b/[80dM7A0;jn_P2h
^;P0c<c<0<?3``31`L400`37alL01P2d];@0bl_;0<O7a`2m_Kd0];Bd0:ZZZP80cLg=00L0_[jn0:VY
Z@3?cll0aLG50<_;b`31`L40`/;20080bLW900H0_kno0=[JfP35aLD0]kNg0;jn_P2k^k/30<[:bP07
0;no_`35aLD0b/[:0<;2`P2n_[h0dM7A0<G5a@020<[:bP070<W9b@3De=@0];Bd0<?3``2j^[X0aLG5
0<30`0020;Rh^0070>7Qh@35aLD0hn?S0<G5a@2h^;P0c/k>0;fm_@020:RXZ0040;jn_P2YZJT0`l?3
0;fm_B@0oooo6`2P?ol00`1oool0X3oo0:0oo`0J0:0oo`0307ooo`2P?ol0X3oo00H0X3oo0`1oool4
0:0oo`0307ooo`2P?ol0X3oo03P0X3oo00<0o`000:0oo`3o00002P2P?olW0?ooo`009@3oool20;Ng
]`0:0<S8b02c/k<0/k>c0:n_[`2[Zj/0]KFe0;^k^`2n_[h0]KFe0<[:bP80[Jf]00D0alO70<30`02n
_[h0^k^k0<c<c0020<71`@<0aLG500H0`L710<?3``2o_kl0Xj>S0;>c/`33`l<20;Ng]`070<30`02k
^k/0^k^k0:JVYP2i^KT0e=CD0=SHf0020<?3``070<O7a`31`L40bLW90<30`033`l<0ZJVY0;fm_@02
0;2`/0070<;2`P3<c<`0_;bl0;>c/`2k^k/0_Kfm09>CT`020;no_`070;Bd]036a/H0c<c<0<S8b03:
b/X0][Jf096AT@0207]kN`070;bl_02/[:`0^[Zj0<W9b@2TY:@0][Jf0;Vi^@020:ZZZP070;:b/P3A
dM40_[jn0;Rh^03<c<`0`l?30<71`@030<O7a`060;Bd]03;bl/0alO70;fm_@2d];@0ZZZZ0P3=cLd0
1`2n_[h0ZJVY0<o?c`35aLD0bl_;0<71`@32`/800P39bLT01P2o_kl0f][J0<G5a@2g]kL0_[jn0;^k
^`<0b/[:00L0_kno0<G5a@3:b/X0`/;20;jn_P3AdM40aLG50080b/[:00L0bLW90=CDe02d];@0`l?3
0;Zj^P35aLD0`<300080^;Rh00L0hN7Q0<G5a@3Shn<0aLG50;Rh^03>c/h0_Kfm0080Z:RX00@0_[jn
0:VYZ@33`l<0_Kfm903ooolK0:0oo`0307ooo`2P?ol0X3oo01X0X3oo00<0Oooo0:0oo`2P?ol01P2P
?ol307ooo`@0X3oo00<0Oooo0:0oo`2P?ol0>02P?ol00`3o0000X3oo0?l0000:0:0oobL0oooo000U
0?ooo`030<G5a@32`/80^[Zj0080b/[:00L0^KVi0;^k^`30`<00_;bl0;Bd]03GemL0d=3@0080];Bd
00D0/[:b0;Ng]`2i^KT0][Jf0<?3``020<71`@80`l?300D0^KVi0;Bd]031`L40c<c<0<;2`P020<?3
``80UiNG00L0][Jf0;Vi^@2XZ:P0_Kfm0<;2`P34a<@0c<c<0080^KVi00@0]kNg0<S8b02f][H0_Kfm
0`37alL20;Vi^@070;Rh^02OWil0][Jf0:ZZZP33`l<0];Bd0<W9b@020=7Ad@070;Zj^P30`<00_;bl
0:RXZ03:b/X0[Zj^08j>SP0208R8R0070;Jf]P2[Zj/0^KVi0=GEe@2SXj<0];Bd0<30`0020;Bd]007
0<G5a@0h>3P0^KVi0;^k^`33`l<0bLW90;Bd]0030;^k^`060:f][@2j^[X0_[jn0<30`02d];@0][Jf
0P33`l<01`2e]KD0aLG50<[:bP3:b/X0`/;20;Rh^03;bl/00P3<c<`01`2i^KT0aLG50;^k^`2k^k/0
d];B0<W9b@3Bd]800P3:b/X01`39bLT0`l?30<O7a`2i^KT0alO70;Zj^P2l_;`00P32`/801`3>c/h0
/;2`0<o?c`33`l<0aLG50<[:bP37alL00P3Cdm<01`2i^KT0Xj>S0<G5a@2`/;00c/k>0;fm_@2o_kl0
0P2f][H0102l_;`0^;Rh0;2`/02b/[8T0?oooah0X3oo0P1ooolC0:0oo`0307ooo`2P?ol0X3oo00/0
X3oo0`1oool40:0oo`0307ooo`2P?ol0X3oo00<0X3oo00<0h?o00:0oo`2P?ol0<`2P?ol00`1oool0
X3oo0:0oo`090:0oobL0oooo000U0?ooo`030;:b/P36a/H0`<300080^KVi00L0d];B0<c<c02m_Kd0
`L710;^k^`3;bl/0a/K60080c<c<00L0]kNg0;bl_037alL0^k^k0<W9b@31`L40alO70080][Jf0P2m
_Kd0102k^k/0gmoO09NGU`29RHT30:^[Z`0708:2PP2XZ:P0][Jf0;^k^`2n_[h0`/;20=?Cd`020<G5
a@030<o?c`3:b/X0^[Zj0080c/k>00/0_Kfm0:n_[`2f][H0][Jf0:>SX`30`<00e]KF0;2`/031`L40
^k^k0;Bd]0020;no_`060;:b/P39bLT0_[jn0;bl_02n_[h0bl_;0`2;Rh/01`2XZ:P0alO70:6QX@2i
^KT0_Kfm0;Ng]`2j^[X00P2n_[h01`2l_;`0bl_;0<71`@33`l<0]KFe0:f][@2d];@00P33`l<01`2j
^[X0bLW90<30`039bLT0`l?30<;2`P35aLD00P30`<001`37alL0`/;20=7Ad@33`l<0aLG50<;2`P33
`l<00P2YZJT01`32`/80][Jf0;fm_@2m_Kd0][Jf0<G5a@34a<@00P2[Zj/01`34a<@0bLW90<g=c@32
`/80b/[:0<?3``3=cLd00P3;bl/01`3AdM40`l?30<W9b@37alL0e=CD0;fm_@3>c/h00P2/[:`01`2e
]KD0alO70;bl_02d];@0b<S80<;2`P34a<@00P2j^[X0102n_[h0_kno0<G5a@2o_klT0?oooaX0X3oo
00<0o`0007ooo`1oool00`2P?ol00`1oool0X3oo0:0oo`0?0:0oo`0307ooo`2P?ol0X3oo00`0X3oo
0`1oool20:0oo`0307ooo`2P?ol0X3oo04L0X3oo9`3oool002D0oooo00<0`/;20;2`/02i^KT00P32
`/801`2k^k/0_;bl0;^k^`31`L40R8R80:f][@2b/[800P3:b/X01`37alL0`/;20;^k^`2m_Kd0`<30
0<;2`P2QXJ400P38b<P01`2k^k/0dM7A0:f][@3De=@0aLG50;:b/P35aLD00P2k^k/01`2][Jd0_;bl
0:^[Z`2QXJ40bLW90:RXZ03Jf]X00P35aLD01`3:b/X0bLW90;Bd]037alL0`l?30<30`03>c/h00P3A
dM401`33`l<0Zj^[0<c<c02n_[h0`/;20<W9b@35aLD00P3<c<`01`2f][H0/[:b0:VYZ@39bLT0a/K6
0;bl_026QXH00P2<S8`20;^k^`0509jNWP2f][H0^;Rh0:f][@2l_;`00P3@d=001P1PH600[:b/0=?C
d`2i^KT0_;bl0<71`@<0`l?300L0_kno0;Jf]P2/[:`0`l?30<[:bP2l_;`0aLG50080`<3000L0`L71
0<?3``2o_kl0`L710<G5a@3:b/X0]kNg0080bl_;00L0dM7A0;^k^`2/[:`0]kNg0<K6aP2m_Kd0aLG5
0080clo?00H0aLG50<O7a`2h^;P0aLG50<O7a`3@d=030<W9b@070<30`037alL0`/;20<30`03:b/X0
e=CD0=7Ad@020<g=c@070=3@d035aLD0cLg=0;^k^`35aLD0^[Zj0<?3``020<O7a`040<W9b@31`L40
c<c<0<?3`b@0oooo2@2P?ol00`1oool0X3oo0:0oo`080:0oo`0307ooo`2P?ol0X3oo00`0X3oo00<0
Oooo0:0oo`2P?ol06`2P?ol307ooo`80X3oo00<0Oooo0:0oo`2P?ol0102P?ol00`3Pol00X3oo0:0o
o`100:0oobL0oooo000U0?ooo`030<71`@2JVYX0^k^k0080c/k>00L0`L710;Jf]P3:b/X0b/[:0;6a
/@3<c<`0_kno00@0bLW900D0a<C40<?3``39bLT0_Kfm0;no_`020;>c/`070:ZZZP2g]kL0];Bd0;jn
_P2^[Zh0^[Zj0:BTY0020<G5a@80][Jf00D0^;Rh0;Jf]P2`/;00^KVi0<c<c0020<[:bP070<G5a@3;
bl/0/[:b0;jn_P37alL0`l?30<G5a@020<[:bP070;no_`31`L40c/k>0<O7a`2k^k/0`/;20<G5a@02
0=gMg@070:BTY02k^k/0`<300<[:bP38b<P0aLG50:6QX@0208b<S0070<o?c`2][Jd0`L710;Ng]`2P
X:00ZJVY0;bl_0020<71`@070<[:bP2o_kl0dM7A0:RXZ02l_;`0b/[:0=3@d0020;no_`040<30`02f
][H0][Jf0<?3``80aLG500X0`<300<W9b@39bLT0aLG50;Fe]@2`/;00a<C40<O7a`33`l<0bLW90P32
`/801`2n_[h0[:b/0;Jf]P39bLT0d];B0=KFeP3?cll00P39bLT01P33`l<0_Kfm09nOW`39bLT0c/k>
0<W9b@<0cLg=00L0clo?0<O7a`39bLT0`/;20<k>cP2EUID0^KVi0080_kno00L0]kNg0;6a/@31`L40
aLG50<W9b@32`/80][Jf0080/[:b00@0`l?30<O7a`30`<00dM7A903oool00`2P?ol0Oooo0:0oo`0J
0:0oo`0307ooo`2P?ol0X3oo01T0X3oo0P3o00000`1oool0X3oo0:0oo`030:0oo`<0Oooo102P?ol0
0`1oool0X3oo0:0oo`0X0:0oo`0307ooo`2P?ol0X3oo00T0X3oo00<0Oooo0:0oo`2P?ol03P2P?olW
0?ooo`009@3oool00`2^[Zh0Z:RX0;jn_P020:RXZ0070<71`@3:b/X0][Jf0:b/[02XZ:P0][Jf0:j^
[P020=;BdP030<W9b@32`/80_;bl0080/;2`00/0alO70;Vi^@35aLD0aLG50:j^[P2k^k/0_[jn0;Ng
]`2i^KT0UiNG0;^k^`020<[:bP070;>c/`30`<00a<C40;Vi^@2_[jl0Xj>S0;Vi^@020<G5a@070<K6
aP2l_;`0`l?30<71`@3AdM40b/[:0<k>cP020<K6aP070<30`03<c<`0_Kfm0<c<c034a<@0`/;20;Ng
]`020;Jf]P070:^[Z`3;bl/0d=3@0<G5a@33`l<0^[Zj09bLW0020:b/[0070:>SX`2f][H0];Bd0<;2
`P2[Zj/0[jn_0<71`@020<[:bP070:f][@2^[Zh0aLG50<;2`P2i^KT0/[:b0:n_[`020;fm_@070;Vi
^@39bLT0_Kfm0<71`@2o_kl0[Jf]0;Zj^P020<G5a@050<W9b@2XZ:P0`<300;bl_03=cLd0102n_[h0
102i^KT0alO70<W9b@2d];@20<g=c@0:0<c<c02o_kl0_kno0<[:bP37alL0c/k>0=;BdP30`<00c/k>
0<O7a`80[Jf]00L0`l?30;Bd]02h^;P0clo?0<;2`P3;bl/0`<300080_;bl00L0`l?30=GEe@2f][H0
aLG50<O7a`35aLD0bLW90080`/;200@0c<c<0<W9b@3;bl/0YjNW903ooolL0:0oo`0307ooo`2P?ol0
X3oo00H0X3oo00<0Oooo0:0oo`2P?ol06@2P?ol0101oool0X3oo0:0oo`1ooom;0:0oobL0oooo000U
0?ooo`030<C4a02l_;`0_;bl0080_kno00L0_[jn0;Zj^P2g]kL0_[jn0<30`03<c<`0aLG50080_kno
00L0alO70<S8b030`<00`L710<30`02l_;`0]kNg0080^k^k00L0_;bl0;Ng]`33`l<0]kNg0:n_[`2m
_Kd0`L710080a<C400L0_[jn0<30`037alL0]kNg0:VYZ@1dM7@0`<300080^KVi00L0aLG50<71`@3D
e=@0b/[:0=OGe`3Fe]H0c<c<0080^[Zj00L0aLG50<g=c@37alL0bLW90;Ng]`2c/k<0dM7A0080Zj^[
00L0c<c<0<S8b032`/80_;bl0;Ng]`2^[Zh0TY:B0080RHV900L0T92@0<C4a02a/K40^[Zj0<C4a02[
Zj/0c/k>0080clo?00L0`l?30;Jf]P35aLD0bLW90<?3``37alL0`<300080_;bl00@0bLW90<G5a@2j
^[X0[:b/0P35aLD30;Bd]0070<G5a@2i^KT0/[:b0=3@d02i^KT0_;bl0<?3``020<G5a@070;Jf]P2i
^KT0/;2`0;Rh^02[Zj/0alO70<C4a0020=OGe`030;Ng]`38b<P0c<c<0080_;bl00/0c/k>0<c<c038
b<P0b<S80=3@d035aLD0c<c<0<G5a@3Cdm<0a/K60;fm_@020;^k^`070;no_`37alL0alO70<[:bP2o
_kl0dM7A0<G5a@030<30`0030;jn_P2m_Kd0b/[:02@0oooo9@2P?ol00`1oool0X3oo0:0oo`0I0:0o
o`@0OoooB`2P?olW0?ooo`009@3oool00`38b<P0`/;20<G5a@020;bl_080];Bd00D0_kno0;fm_@32
`/80]KFe0;jn_P020;no_`070<K6aP2m_Kd0aLG50;no_`2n_[h0a<C40<o?c`020<71`@070;Vi^@3;
bl/0`l?30;:b/P2n_[h0`/;20;no_`020<G5a@070;no_`2m_Kd0_Kfm0;no_`2SXj<0^k^k0:RXZ002
0;no_`070<?3``31`L40alO70;Jf]P38b<P0_kno0;:b/P020<S8b0070<k>cP34a<@0_[jn0<;2`P3?
cll0b/[:0<?3``020<O7a`070<W9b@37alL0aLG50<G5a@3>c/h0/[:b08N7Q`0209NGU`0709^KV`2k
^k/0WYjN0;Vi^@2][Jd0/;2`0;bl_0020;Ng]`070;Jf]P2`/;00Xj>S0<?3``2o_kl0]kNg0;Jf]P02
0=;BdP070:n_[`33`l<0]kNg0;Fe]@2c/k<0h^;R0;Rh^0020;bl_0040;:b/P2d];@0clo?0<;2`P80
bLW900X0];Bd0=7Ad@3AdM40fMWI0<G5a@3<c<`0c/k>0<?3``2n_[h0`<300P2d];@01`3AdM40`L71
0<G5a@3@d=00b/[:0<71`@37alL00P3<c<`01`31`L40aLG50<k>cP35aLD0][Jf0<k>cP3Bd]800P3<
c<`01`37alL0];Bd0<?3``2h^;P0`l?30<k>cP32`/800P3Fe]H0101IFET0_;bl0=WIf@1hN7PT0?oo
ob@0X3oo00<0Oooo0:0oo`2P?ol06P2P?ol407ooo`030:0oo`1oool0X3oo00L0X3oo00<0Oooo0:0o
o`2P?ol02@2P?ol00`3o0000X3oo0:0oo`0^0:0oo`040>3o`02P?ol0X3oo07ooobL0oooo000U0?oo
o`030<G5a@30`<00_;bl0080^;Rh00L0bLW90<;2`P32`/80/k>c0;Jf]P3?cll0RXZ:0080cLg=0P32
`/801@30`<00`/;20<?3``2XZ:P0_[jn0080c/k>00@0_[jn0;Ng]`35aLD0clo?0P34a<@02P2n_[h0
^KVi0;Vi^@2i^KT0_kno0;Bd]02o_kl0`l?30<G5a@3>c/h20861P@070<S8b03:b/X0eMGE0:^[Z`34
a<@0]kNg0<[:bP020;bl_0070<k>cP3GemL0alO70;Vi^@30`<00_;bl0;Bd]0020;6a/@070;^k^`39
bLT0alO70;jn_P30`<00[Jf]030`<00204E5A@0708V9R@35aLD0/;2`0;no_`2XZ:P0_kno0;Rh^002
0;Bd]0070<?3``37alL0_;bl0:FUY@2b/[80[jn_0;Zj^P020<_;b`070:b/[02k^k/0cLg=0;jn_P3<
c<`0alO70<?3``020<c<c0070;Fe]@2k^k/0cLg=0;^k^`3?cll0`<300;jn_P020=[JfP070<;2`P2n
_[h0YJFU0;:b/P2h^;P0`/;20:j^[P020<G5a@070<71`@2n_[h0a/K60>_[j`3De=@0b/[:0<?3``02
0<71`@070<S8b02i^KT0_[jn0<O7a`2m_Kd0^k^k0<C4a0020<S8b0070<[:bP2o_kl0^KVi0<K6aP2c
/k<0b<S80<30`0020<o?c`80aLG500<0^k^k0<;2`P3oool08`3oool;0:0oo`0307ooo`2P?ol0X3oo
01T0X3oo0P1ooolH0:0oo`040?ooo`3Pol00h?o007ooobl0X3oo00<0o`000:0oo`2P?ol06@2P?olW
0?ooo`009@3oool00`35aLD0`<300;bl_0020;Rh^0070<W9b@32`/80`/;20;>c/`2f][H0clo?08Z:
RP020<g=c@80`/;200D0`<300<;2`P33`l<0Z:RX0;jn_P020<k>cP040;jn_P2g]kL0aLG50<o?c`80
a<C400X0_[jn0;Vi^@2i^KT0^KVi0;no_`2d];@0_kno0<?3``35aLD0c/k>0P21PH401`38b<P0b/[:
0=GEe@2[Zj/0a<C40;Ng]`3:b/X00P2l_;`01`3>c/h0emOG0<O7a`2i^KT0`<300;bl_02d];@00P2a
/K401`2k^k/0bLW90<O7a`2n_[h0`<300:f][@0`<3000P15ADD01`29RHT0aLG50;2`/02o_kl0Z:RX
0;no_`2h^;P00P2d];@01`33`l<0alO70;bl_02UYJD0/[:b0:n_[`2j^[X00P3;bl/01`2/[:`0^k^k
0<g=c@2n_[h0c<c<0<O7a`33`l<00P3<c<`01`2e]KD0^k^k0<g=c@2k^k/0clo?0<30`02n_[h00P3J
f]X01`32`/80_[jn0:FUY@2b/[80^;Rh0<;2`P2^[Zh00P35aLD01`31`L40_[jn0<K6aP3[jn/0e=CD
0<[:bP33`l<00P31`L401`38b<P0^KVi0;jn_P37alL0_Kfm0;^k^`34a<@00P38b<P01`3:b/X0_kno
0;Vi^@36a/H0/k>c0<S8b030`<000P3?cll20<G5a@030;^k^`32`/80oooo02<0oooo2`2P?ol00`1o
ool0X3oo0:0oo`0I0:0oo`80Oooo602P?ol0103oool0h?o00>3o`01oool_0:0oo`030?l0002P?ol0
X3oo01T0X3oo9`3oool002D0oooo00<0_kno0<W9b@2g]kL00`2d];@01P2l_;`0^[Zj0<;2`P31`L40
b/[:0<?3``80bLW900D0alO70<S8b02i^KT0^[Zj0<;2`P020<C4a0<0]kNg00H0_;bl0=[JfP39bLT0
^KVi0<c<c02h^;P20;^k^`070<71`@32`/80^k^k0;^k^`39bLT0`L710=OGe`020<G5a@0709fMW@2d
];@0c<c<0<O7a`3:b/X0bl_;0<G5a@020<k>cP070;^k^`2o_kl0SHf=0?[jnP30`<00bl_;0<?3``02
0;Ng]`070<C4a037alL0`l?30;Ng]`2d];@0Cdm?0:n_[`020;:b/P070>?Sh`39bLT0`l?30<?3``39
bLT0`l?30<W9b@020<?3``050:f][@2_[jl0];Bd0<30`02f][H00P32`/820<?3``070<G5a@33`l<0
^[Zj0;jn_P2g]kL0aLG50<g=c@020;Fe]@070;bl_036a/H0aLG50<G5a@32`/80a/K60<;2`P020=KF
eP070=SHf038b<P0`/;20<30`02m_Kd0alO70<?3``020<W9b@070;no_`2h^;P0`L710<[:bP2m_Kd0
alO70<_;b`020<O7a`070<;2`P36a/H0a<C40;bl_032`/80^k^k0<c<c0020<[:bP070<W9b@30`<00
a<C40<K6aP38b<P0_[jn0<;2`P020<71`@040>_[j`35aLD0hN7Q0<W9bB@0oooo:@2P?ol00`1oool0
X3oo0:0oo`080:0oo`0307ooo`3o0000X3oo00T0X3oo00D0h?o00:0oo`2P?ol0X3oo0?l000170:0o
o`040?l0002P?ol0o`000:0oobL0oooo000U0?ooo`030<o?c`2n_[h0^;Rh00<0`/;200H0^KVi0<[:
bP2n_[h0^KVi0<;2`P2j^[X20<71`@040<G5a@2o_kl0bLW90<G5a@80^k^k00X0a<C40;jn_P2n_[h0
a<C40<71`@2l_;`0`<300<S8b034a<@0^KVi0P37alL01`2m_Kd0_[jn0<W9b@2g]kL0`<300<K6aP3G
emL00P32`/801`3;bl/0/;2`0:FUY@3:b/X0bLW90;fm_@33`l<00P37alL01P2n_[h0`/;20<[:bP2e
]KD0_[jn0<30`0D0_;bl00D0_[jn0;Ng]`2WYjL0_;bl0:RXZ0020;Vi^@0708N7Q`2i^KT0bLW90;fm
_@3@d=00[jn_0;Ng]`020<;2`P070;:b/P32`/80Zj^[0;Zj^P30`<00^[Zj0<?3``020<O7a`030<C4
a03<c<`0`<300080/[:b00/0a<C40<_;b`2m_Kd0_Kfm0;:b/P2VYZH0clo?0<?3``3;bl/0alO70;jn
_P020;^k^`070;Vi^@2TY:@0_;bl0<30`033`l<0^;Rh0<O7a`020<c<c0070<C4a035aLD0a<C40<_;
b`2l_;`0cLg=0;no_`020<[:bP070<71`@35aLD0c/k>0<?3``39bLT0`/;20<30`0020<S8b080cLg=
00D0b<S80<30`02i^KT0aLG50;Jf]P020;no_`040<30`037alL0^[Zj0;Jf]R@0ooooA02P?ol00`1o
ool0X3oo0:0oo`0R0:0oo`0307ooo`2P?ol0X3oo02@0X3oo9`3oool002D0oooo00<0^k^k0<30`02_
[jl00P2UYJD01`2j^[X0^KVi0<;2`P2n_[h0ZZZZ0;2`/02/[:`00P31`L401`2g]kL0`l?30<71`@2m
_Kd0`<300<K6aP39bLT00P31`L401P33`l<0b/[:0;no_`35aLD0Q8B40;Vi^@<0alO700L0aLG50<71
`@2l_;`0]kNg0<c<c02k^k/0^KVi0080][Jf00L0c<c<0<G5a@32`/80W9bL0<W9b@3>c/h0bLW90080
b/[:00@0a<C40;^k^`2d];@0_;bl0P32`/802P2h^;P0dM7A0=7Ad@31`L40`l?30;bl_02j^[X0];Bd
0>?Sh`3Fe]H20>7Qh@070<O7a`2e]KD0][Jf0<?3``2LW9`0ZJVY0;Jf]P020<W9b@070;jn_P35aLD0
`L710:n_[`31`L40alO70=KFeP020<c<c0070;jn_P3:b/X0_;bl0;jn_P32`/80b/[:0;bl_0020<G5
a@070:^[Z`33`l<0alO70;fm_@39bLT0bl_;0;Jf]P020;Bd]080^[Zj00D0YJFU0<O7a`3?cll0clo?
0<O7a`020<W9b@070;2`/02l_;`0alO70<_;b`2n_[h0bl_;0<;2`P020<C4a0070<k>cP37alL0d=3@
0<G5a@33`l<0e=CD0<k>cP020<W9b@070=7Ad@3GemL0f=SH0<S8b02m_Kd0^;Rh0:6QX@020<O7a`04
0;Zj^P37alL0^[Zj0<W9bB@0oooo6`2P?ol00`1oool0X3oo0:0oo`0>0:0oo`0307ooo`2P?ol0X3oo
0140X3oo00@0o`000:0oo`3o0000o`00102P?ol00`1oool0X3oo0:0oo`0n0:0oo`0307ooo`2P?ol0
X3oo00@0X3oo9`3oool002D0oooo00<0^;Rh0;Vi^@27QhL00P2i^KT01`39bLT0`L710;jn_P2][Jd0
]kNg0<;2`P30`<000P2i^KT01`2l_;`0a<C40;Ng]`39bLT0alO70;fm_@34a<@00P3:b/X01`30`<00
_Kfm0<W9b@35aLD0`<300;Vi^@35aLD00P2m_Kd0102o_kl0`<300<?3``2k^k/30<?3``80clo?00L0
b<S80;bl_035aLD0bLW90;Zj^P3AdM40b/[:0080dM7A00L0bLW90;>c/`3@d=00alO70<[:bP3Bd]80
c/k>0080bl_;00L0bLW90;Jf]P2`/;00_[jn0=3@d02o_kl0alO70080][Jf00L0]kNg0;jn_P2h^;P0
];Bd0;Jf]P2ZZZX0dM7A0080c/k>00L0c<c<0;Ng]`35aLD0c/k>0<;2`P3Hf=P0_[jn0080bLW900L0
_;bl0;fm_@30`<00Z:RX0<O7a`3=cLd0^;Rh0080]kNg00L0/[:b0<;2`P2i^KT0_kno0<?3``3?cll0
_;bl0080^[Zj00L0_[jn0;Jf]P30`<00alO70<?3``30`<00`l?30080alO700@0^[Zj0<_;b`2f][H0
d];B0`39bLT20;bl_0070<30`039bLT0alO70<?3``2h^;P0_[jn0;no_`020;:b/P070:ZZZP2g]kL0
][Jf0<G5a@3MgMd0aLG50=CDe0020;no_`040<W9b@3;bl/0dM7A0;bl_2@0oooo0P2P?ol00`1oool0
X3oo0:0oo`220:0oo`030?l0002P?ol0X3oo00H0X3oo9`3oool002D0oooo00<0`L710;Rh^02[Zj/0
0P30`<001`2m_Kd0/[:b0<;2`P32`/80cLg=0<?3``32`/800P39bLT20<;2`P050<?3``3Cdm<0clo?
0<O7a`39bLT00P3:b/X01`2n_[h0`l?30;fm_@3>c/h0alO70;no_`2d];@00P2l_;`01`30`<00a<C4
0<S8b02m_Kd0aLG50;no_`37alL00P2h^;P01`3:b/X0`<300=3@d02i^KT0^k^k0<o?c`3Bd]800P2i
^KT01`3>c/h0alO70=7Ad@3Jf]X0d=3@0;^k^`31`L400P2f][H01@3:b/X0`/;20<C4a03Hf=P0dM7A
0080bLW90P2_[jl01P2m_Kd0aLG50:n_[`37alL0WYjN09ZJVP<0`<3000L0bLW90<?3``2QXJ40b/[:
0;Bd]03=cLd0aLG50080YjNW00L0a<C40<;2`P2l_;`0[Zj^0<o?c`2f][H0aLG50080`<3000L0WinO
0;bl_033`l<0_Kfm0<;2`P35aLD0][Jf0080^;Rh00L0/;2`0;Jf]P30`<00_;bl0<K6aP39bLT0i>CT
0080dm?C00L0eMGE0<W9b@30`<00]kNg0<71`@2XZ:P0aLG50080alO700L0dM7A0<c<c03]kNd0/;2`
0<?3``2PX:00a/K60080_;bl00@0alO70;Zj^P30`<00bl_;0P30`<001`3?cll0e=CD0=CDe03<c<`0
b/[:0<W9b@3@d=00903ooom80:0oo`80Oooo1@2P?ol00`1oool0X3oo0:0oo`0=0:0oo`0307ooo`2P
?ol0X3oo00`0X3oo00<0o`000:0oo`2P?ol02`2P?ol0103o0000X3oo0:0oo`1oool@0:0oobL0oooo
000U0?ooo`030;Zj^P2d];@0^k^k0080^;Rh00D0_Kfm0;Vi^@31`L40]kNg0<[:bP020<O7a`80b/[:
00<0^k^k0;no_`35aLD00P2k^k/01@2o_kl0^k^k0<?3``33`l<0`/;20080_[jn00@0d=3@0<G5a@2k
^k/0[jn_0P2n_[h01`2i^KT0`L710<G5a@31`L40aLG50:j^[P37alL00P2j^[X01`2o_kl0`/;20:n_
[`3<c<`0]KFe0:FUY@2_[jl00P2g]kL01`2KVi/0^k^k0<30`02[Zj/0clo?0=[JfP3?cll00P33`l<0
0`37alL0dM7A0=?Cd`020:ZZZP070<?3``37alL0][Jf0;Jf]P36a/H0Y:BT0;Vi^@020;jn_P0;0;Ng
]`2n_[h0_[jn0;jn_P2j^[X0_;bl0;Bd]02n_[h0`L710<?3``2l_;`00P2h^;P01@3<c<`0^k^k0=3@
d039bLT0_kno0080`l?30P2d];@01`2_[jl0_;bl0<;2`P2i^KT0a<C40;^k^`2m_Kd00P2f][H01`35
aLD0_[jn0<?3``32`/80^KVi0<W9b@30`<000P35aLD01`2l_;`0`<300;bl_03:b/X0c<c<0=3@d033
`l<00P3?cll01P3=cLd0_kno0;jn_P2j^[X0`<300;6a/@<0clo?00L0aLG50<?3``31`L40alO70;no
_`37alL0bLW90080`l?300@0c<c<0<[:bP2m_Kd0bLW9903ooolb0:0oo`0307ooo`2P?ol0X3oo0100
X3oo00<0Oooo0:0oo`2P?ol0B02P?olW0?ooo`009@3oool00`2n_[h0a/K60:2PX0020;jn_P0709bL
W039bLT0`<300:b/[02n_[h0a/K60<[:bP020<?3``070<G5a@2f][H0^KVi0;fm_@2k^k/0b<S809>C
T`020<O7a`070<G5a@30`<00`/;20<K6aP3<c<`0/;2`0;Ng]`020<?3``070;Jf]P2l_;`0`<300<W9
b@2k^k/0^[Zj0;fm_@020;2`/0070<;2`P37alL0f][J0<O7a`32`/80hN7Q0=OGe`020:FUY@050;jn
_P33`l<0[jn_0;no_`37alL00P2d];@20<G5a@070<_;b`30`<00^KVi0<_;b`30`<00_;bl0;fm_@02
0<?3``070<[:bP2i^KT0^KVi0;:b/P2][Jd0^;Rh0;Bd]0020<;2`P070;:b/P2_[jl0`<30092@T02j
^[X0bl_;0;Jf]P020<?3``80alO700D0`l?30;:b/P35aLD0aLG50<c<c0020;Rh^00709:BTP33`l<0
bLW90;jn_P32`/80alO70:VYZ@030;Zj^P050<G5a@32`/80aLG50<_;b`3@d=000`3Cdm<01`30`<00
bLW90;Rh^03Bd]80_Kfm0;Bd]02n_[h00P2k^k/01`3:b/X0bLW90;Rh^033`l<0][Jf0<[:bP3@d=00
0P2`/;001`3@d=00][Jf0<G5a@33`l<0`<300<?3``2n_[h00P3=cLd0102l_;`0bLW90<?3``2n_[hT
0?ooo`80X3oo00@0Oooo0:0oo`2P?ol0Oooo3P2P?ol00`1oool0X3oo0:0oo`0G0:0oo`030?l0002P
?ol0X3oo01l0X3oo00<0Oooo0:0oo`2P?ol0302P?ol00`1oool0X3oo0:0oo`0^0:0oobL0oooo000U
0?ooo`80^k^k00X0`/;20;Ng]`2g]kL0^KVi0;>c/`2f][H0_kno0<O7a`35aLD0`L710P33`l<01`36
a/H0alO70<?3``2i^KT0_;bl0<[:bP3?cll00P3=cLd01`2o_kl0`/;20;Fe]@35aLD0a<C40:b/[02_
[jl00P38b<P01`30`<00b/[:0=gMg@2XZ:P0_[jn0<O7a`2f][H00P2l_;`01`2HV9P0aLG50;Jf]P2k
^k/0gmoO09NGU`3`l?000P2i^KT01@2h^;P0_[jn09jNWP2][Jd0Zj^[0080/[:b0P31`L401`37alL0
clo?0<o?c`2][Jd0a/K60;bl_02f][H00P2l_;`01`2`/;00c/k>0;Rh^02l_;`0`/;20;Jf]P2o_kl0
0P31`L401@32`/80bl_;0;Rh^035aLD0alO70080]kNg0P3=cLd01`30`<00/;2`0:n_[`32`/80_[jn
0<S8b03AdM400P32`/801`2NWYh0^[Zj0;no_`2o_kl0]kNg0;Zj^P2b/[800P2f][H01`30`<00[jn_
0;Rh^02l_;`0][Jf0;Bd]02o_kl00`3AdM420<o?c`040:ZZZP2k^k/0bLW90<71`@80c/k>00L0^k^k
0;Jf]P2i^KT0c/k>0<30`03EeMD0cLg=0080^[Zj00L0bLW90;bl_03?cll0f][J0;jn_P37alL0dm?C
0080/K6a00@0]KFe0<K6aP30`<00cLg=903ooolR0:0oo`030?l0002P?ol0X3oo00@0X3oo00L0Oooo
0:0oo`2P?ol0X3oo0?l0001oool0o`0000@0X3oo00<0Oooo0:0oo`2P?ol0:02P?ol00`1oool0X3oo
0:0oo`0^0:0oobL0oooo000U0?ooo`80^k^k00X0`/;20;Ng]`2g]kL0^KVi0;>c/`2f][H0_kno0<O7
a`35aLD0`L710P33`l<01`36a/H0alO70<?3``2i^KT0_;bl0<[:bP3?cll00P3=cLd01`2o_kl0`/;2
0;Fe]@35aLD0a<C40:b/[02_[jl00P38b<P01`30`<00b/[:0=gMg@2XZ:P0_[jn0<O7a`2f][H00P2l
_;`01`2HV9P0aLG50;Jf]P2k^k/0gmoO09NGU`3`l?000P2i^KT01@2h^;P0_[jn09jNWP2][Jd0Zj^[
0080/[:b0P31`L401`37alL0clo?0<o?c`2][Jd0a/K60;bl_02f][H00P2l_;`01`2`/;00c/k>0;Rh
^02l_;`0`/;20;Jf]P2o_kl00P31`L401@32`/80bl_;0;Rh^035aLD0alO70080]kNg0P3=cLd01`30
`<00/;2`0:n_[`32`/80_[jn0<S8b03AdM400P32`/801`2NWYh0^[Zj0;no_`2o_kl0]kNg0;Zj^P2b
/[800P2f][H01`30`<00[jn_0;Rh^02l_;`0][Jf0;Bd]02o_kl00`3AdM420<o?c`040:ZZZP2k^k/0
bLW90<71`@80c/k>00L0^k^k0;Jf]P2i^KT0c/k>0<30`03EeMD0cLg=0080^[Zj00L0bLW90;bl_03?
cll0f][J0;jn_P37alL0dm?C0080/K6a00@0]KFe0<K6aP30`<00cLg=903ooolR0:0oo`030?l0002P
?ol0X3oo00@0X3oo00L0Oooo0:0oo`2P?ol0X3oo0?l0001oool0o`0000@0X3oo00<0Oooo0:0oo`2P
?ol0:02P?ol00`1oool0X3oo0:0oo`0^0:0oobL0oooo000U0?ooo`030<W9b@2k^k/0];Bd0080/K6a
00L0`<300<?3``3Jf]X0g]kN0<O7a`2g]kL0][Jf0080`l?300L0_Kfm0<O7a`32`/80aLG50;Vi^@33
`l<0a/K60080a<C400@0`<300<W9b@33`l<0_[jn0P3?cll01P39bLT0_kno0;no_`32`/80`l?30;fm
_@80][Jf00/0b/[:0<k>cP2n_[h0_[jn0;bl_02g]kL0WYjN0:n_[`2m_Kd0[Jf]0;Fe]@0209bLW007
08b<S02OWil0Y:BT08B4Q02HV9P0`L710<;2`P020<o?c`070<W9b@3Cdm<0`l?30<71`@2l_;`0]kNg
0:VYZ@020:BTY0070;bl_033`l<0]kNg0<G5a@3=cLd0[:b/0;2`/0020<?3``050<c<c02h^;P0alO7
0<S8b02d];@00P2k^k/20<;2`P070<_;b`3=cLd0b/[:0<W9b@2UYJD0];Bd0<G5a@020;Zj^P070:n_
[`33`l<0`<300;Zj^P36a/H0^[Zj0;>c/`020;2`/0050:^[Z`2_[jl0/[:b0;Zj^P2XZ:P00P32`/82
0;Jf]P80`<3000D0_[jn0<[:bP39bLT0Z:RX0<S8b0020=3@d0070=;BdP36a/H0aLG503Ti>@2f][H0
d=3@0<30`0020<K6aP070;2`/03?cll0`l?30:ZZZP3>c/h0`/;20=7Ad@020<g=c@040<K6aP3>c/h0
d=3@0<71`B@0oooo202P?ol00`3o0000X3oo0:0oo`0P0:0oo`0307ooo`2P?ol0X3oo0080X3oo1`1o
ool;0:0oo`80Oooo>@2P?ol00`3Pol00X3oo0:0oo`0@0:0oobL0oooo000U0?ooo`030;Jf]P33`l<0
];Bd0080`/;200L0]kNg0;Fe]@2VYZH0QhN70<c<c035aLD0Z:RX0080ZZZZ00L0_[jn0:>SX`3IfMT0
^KVi0<;2`P30`<00k>c/0080d=3@00L0b<S80<30`032`/80`<300;bl_02o_kl0]kNg0080_;bl00L0
^k^k0<30`03@d=00`/;20:2PX035aLD0`/;20080alO700L0b<S80<g=c@33`l<0^k^k0<71`@2][Jd0
/[:b0080alO700L0h^;R0<?3``2b/[80aLG50;:b/P33`l<0YJFU0080UiNG00L0Vi^K09RHV02b/[80
bLW90<O7a`2h^;P0^KVi0080`l?300L0];Bd0<G5a@2o_kl0][Jf0<k>cP2_[jl0`/;20080/K6a00H0
/[:b0;Zj^P32`/80][Jf0<W9b@2e]KD30<30`0070=KFeP35aLD0][Jf0:BTY031`L40^[Zj0;jn_P02
0;^k^`070:n_[`2k^k/0^[Zj0;Bd]035aLD0dM7A0<G5a@020;:b/P070<W9b@33`l<0alO70;Bd]039
bLT0b/[:0<O7a`020=KFeP070<?3``39bLT0_;bl0<30`03=cLd0bLW90=?Cd`020<W9b@070<_;b`39
bLT0`l?30;Zj^P2h^;P0_[jn0;Bd]0020;jn_P070;Vi^@2m_Kd0clo?0>;RhP3AdM40^k^k0<O7a`02
09:BTP040:j^[P3<c<`0];Bd0<O7ab@0oooo202P?ol00`1oool0X3oo0:0oo`040:0oo`0307ooo`2P
?ol0X3oo0080X3oo00<0o`000:0oo`2P?ol03@2P?ol00`1oool0X3oo0:0oo`0;0:0oo`030?l0002P
?ol0X3oo00@0X3oo101ooolL0:0oo`0307ooo`2P?ol0X3oo02X0X3oo00@0o`000:0oo`2P?ol0X3oo
0P1oool40:0oobL0oooo000U0?ooo`030;jn_P2o_kl0^KVi0080^k^k00L0^KVi0;^k^`2m_Kd0aLG5
0=SHf02n_[h0clo?0080_Kfm00L0^;Rh0<K6aP3oool0^;Rh0;bl_03>c/h0ZZZZ0080aLG500H0_[jn
0;no_`2k^k/0[Zj^0<71`@35aLD30;jn_P070<S8b03AdM40^k^k0:RXZ02/[:`0^;Rh0<O7a`020<g=
c@070<[:bP33`l<0a<C40<?3``2f][H0`l?30;Bd]0020:f][@040<;2`P2k^k/0c/k>0;Vi^@80`/;2
00X0ZZZZ0;Zj^P2j^[X0bl_;0<o?c`3AdM40]kNg0;:b/P29RHT0`l?30P35aLD01`1[Jf/0/;2`0;Zj
^P2g]kL0Xj>S0:n_[`3Fe]H00P33`l<01`2n_[h0^;Rh0;Rh^030`<00a<C40;fm_@3Rh^800`33`l<0
1P39bLT0][Jf0=;BdP3Jf]X0_;bl0<W9b@80alO700L0XJ6Q0;jn_P32`/80_;bl0<;2`P2i^KT0Zj^[
0080aLG50`33`l<0102m_Kd0a/K60<C4a02i^KT20<;2`P070=CDe03>c/h0`l?30;Zj^P3;bl/0bLW9
0=;BdP020<k>cP070<;2`P39bLT0`/;20<c<c03?cll0`<300;jn_P020<G5a@070<30`02h^;P0[Jf]
0<_;b`30`<00^k^k0;Zj^P020;Jf]P040;jn_P39bLT0b/[:0;Rh^2@0oooo402P?ol00`3o0000X3oo
0:0oo`0]0:0oo`0507ooo`2P?ol0X3oo0:0oo`3Pol000`2P?ol00`1oool0X3oo0:0oo`080:0oo`03
0?l0002P?ol0X3oo00T0X3oo00<0Oooo0:0oo`2P?ol0;P2P?olW0?ooo`009@3oool00`3<c<`0bLW9
0<C4a0020;:b/P070<G5a@3<c<`0_[jn0;:b/P2g]kL0c/k>0<G5a@020<[:bP070<;2`P3>c/h0a<C4
0<30`02o_kl0aLG50<;2`P020;bl_0070;jn_P2OWil0Zj^[0<?3``3<c<`0_[jn0;2`/0020<O7a`07
0<G5a@34a<@0^;Rh09^KV`3Rh^80aLG50<C4a0020<30`0070<W9b@3<c<`0aLG50;bl_033`l<0`/;2
0<30`0020;^k^`070:JVYP3>c/h0^;Rh0<O7a`35aLD0alO70;Rh^0020;Vi^@070<c<c02f][H0eMGE
0<[:bP1mOGd0`/;20:n_[`020;2`/0070<O7a`32`/80_[jn0;:b/P2h^;P0YjNW0=?Cd`020<?3``07
0:^[Z`33`l<0dM7A0:JVYP2d];@0f][J0;Vi^@020<71`@070<C4a02a/K40`l?30<?3``2[Zj/0^[Zj
0<O7a`020;bl_0070:NWY`2l_;`0alO70;Zj^P3=cLd0bLW90<G5a@020<;2`P070<K6aP3EeMD0`l?3
0;jn_P35aLD0bLW90<O7a`020<?3``070=;BdP30`<00Z:RX0:^[Z`33`l<0cLg=0<?3``020=3@d007
0<S8b03?cll0dm?C0<?3``3=cLd0b/[:0<G5a@020;no_`030<W9b@2f][H0alO70080clo?00P0aLG5
08^;R`2n_[h0_[jn0<30`035aLD0bLW90<G5aB@0oooo602P?ol00`1oool0X3oo0:0oo`080:0oo`03
07ooo`3o0000X3oo01T0X3oo00<0Oooo0:0oo`2P?ol0A`2P?ol00`1oool0X3oo0:0oo`040:0oobL0
oooo000U0?ooo`030;Vi^@2^[Zh0^k^k0080/K6a00L0`<300;bl_02i^KT0`L710<S8b036a/H0_[jn
0080UiNG00L0b/[:0;Zj^P37alL0_;bl0<K6aP2[Zj/0`<300080alO700L0`<300<c<c02n_[h0];Bd
0<?3``2h^;P0alO70080c<c<00L0fm_K0;bl_02^[Zh0/;2`0;Bd]034a<@0`l?30080^KVi00L0_[jn
09fMW@2d];@0bLW90;fm_@2k^k/0c/k>0080eMGE00L0XJ6Q0;Ng]`35aLD0_Kfm0;bl_039bLT0clo?
0080^KVi00L0^[Zj0<[:bP31`L40][Jf08F5Q@2k^k/0`<300080alO700L0];Bd0;Zj^P30`<00`/;2
0;Zj^P2i^KT0alO70080aLG500L0dM7A0;jn_P32`/80/[:b0=SHf02i^KT0b/[:0080h^;R00L0dM7A
0<_;b`3?cll0dM7A0<30`03;bl/0clo?0080^KVi00L0/;2`0:FUY@33`l<0`<300=GEe@2l_;`0^[Zj
0080alO70P2f][H01@2h^;P0_[jn0;2`/037alL0_[jn0080`l?300L0cLg=0<?3``3?cll0clo?0:n_
[`3>c/h0bl_;0080clo?00L0`<300<C4a030`<00]kNg09bLW03:b/X0];Bd0080_Kfm00L0aLG50<o?
c`2g]kL0`L7109^KV`2XZ:P0alO70080bl_;00@0/[:b0;2`/02m_Kd0^KVi903oool<0:0oo`80Oooo
702P?ol00`1oool0X3oo0:0oo`050:0oo`0307ooo`2P?ol0X3oo00X0X3oo00<0Oooo0:0oo`2P?ol0
4P2P?ol20?l002P0X3oo00<0Oooo0:0oo`2P?ol01P2P?ol00`1oool0X3oo0:0oo`060:0oobL0oooo
000U0?ooo`80aLG500X0YjNW0;2`/02`/;00];Bd0:NWY`2g]kL0b/[:0;fm_@33`l<0_Kfm0P2l_;`0
1`38b<P0c<c<0<?3``32`/80_;bl0;jn_P3:b/X00P31`L401`39bLT0^k^k0;jn_P2k^k/0_kno0<71
`@30`<000P32`/800`2/[:`0dM7A0;Vi^@030;fm_@0:0<[:bP2o_kl0_kno0<;2`P2/[:`0]KFe0<[:
bP3AdM40b<S80;bl_080fm_K00L0^KVi0<30`02f][H0]kNg0;jn_P37alL0`l?30080];Bd00L0/;2`
0;^k^`2BTY80][Jf04e=C@33`l<0bl_;0080f][J00L0`<300;jn_P2d];@0Z:RX0<W9b@2g]kL0c/k>
0080[jn_00L0/K6a0;no_`2k^k/0f][J0<G5a@2g]kL0`l?30080YZJV00L0_[jn0<_;b`3Cdm<0dM7A
0<?3``37alL0`/;20080b/[:00D0]kNg0<C4a039bLT0`L710=[JfP020<?3``80c<c<00L0YjNW0<O7
a`34a<@0_;bl0<30`02k^k/0^;Rh0080c<c<00L0c/k>0;Bd]033`l<0gMgM0=[JfP2][Jd0alO70080
`<3000<0d=3@0<W9b@3;bl/00P3AdM402`2g]kL0aLG50;^k^`2k^k/0[Jf]0;Jf]P2h^;P0_kno0<?3
``2i^KT0_kno0080`/;200@0alO70<30`03<c<`0aLG5903ooolm0:0oo`0307ooo`2P?ol0h?o003@0
X3oo00<0o`000:0oo`2P?ol06@2P?olW0?ooo`009@3oool00`3Fe]H0_[jn0<W9b@020<?3``070;^k
^`2f][H0`<300=3@d039bLT0d];B0<;2`P020<K6aP070<S8b02k^k/0c<c<0;no_`2l_;`0b/[:0<71
`@020;fm_@070<O7a`2k^k/0^k^k0;Ng]`2k^k/0bLW90<C4a0020<71`@070;Zj^P37alL0[Jf]0<30
`02`/;00_kno0<W9b@020;Jf]P070<O7a`2g]kL0d=3@0<71`@30`<00_kno0=7Ad@020=oOg`070<_;
b`31`L40clo?0:2PX02`/;00/k>c0;^k^`020:>SX`070:n_[`2f][H0/[:b0=7Ad@3@d=00bLW90:NW
Y`020<o?c`070;bl_02][Jd0_[jn0;>c/`2][Jd0QhN7096AT@020:n_[`060<o?c`2f][H0/[:b0:n_
[`37alL0d=3@0`37alL01`3;bl/0^[Zj0<?3``3AdM40bLW90;^k^`37alL00P32`/801`2f][H0alO7
0<g=c@35aLD0_[jn0:f][@30`<000P33`l<01`2n_[h0^KVi0;Rh^02_[jl0_;bl0;jn_P38b<P00P2k
^k/01`33`l<0alO70=cLg03AdM40/k>c0;6a/@2n_[h00P39bLT01`3?cll0bLW90=GEe@31`L40dm?C
0<G5a@3:b/X00P2^[Zh01`3<c<`0e=CD0;bl_03>c/h0];Bd0:b/[02n_[h00P2j^[X01035aLD0_;bl
0<O7a`2k^k/T0?oooc00X3oo0P3o00030:0oo`0407ooo`2P?ol0X3oo0:0oo`80Oooo3P2P?ol207oo
odD0X3oo9`3oool002D0oooo00<0b/[:0<C4a030`<000P32`/801`2c/k<0/;2`0=?Cd`2m_Kd0bLW9
0<S8b031`L400P2l_;`01`3?cll0/[:b0;bl_02d];@0_kno0;jn_P33`l<00P32`/801`3?cll0^KVi
0<[:bP3Cdm<0b<S80<c<c033`l<00P3:b/X01`31`L40_kno0;Vi^@2l_;`0bl_;0;no_`3Bd]800P35
aLD01`37alL0_Kfm0<[:bP3Fe]H0dm?C0<[:bP3Hf=P00P3IfMT00`36a/H0^KVi0;no_`020;:b/P0:
0=7Ad@2WYjL0/[:b0;:b/P3De=@0V9RH0<30`02c/k<0^KVi0<?3``<0`<3000L0_;bl09>CT`2i^KT0
b/[:0;^k^`2^[Zh0^KVi0080_kno00L0bLW90<G5a@2j^[X0inOW0<G5a@2n_[h0a/K60080`l?300<0
aLG50<O7a`39bLT00P37alL02`2f][H0bLW90;Rh^02h^;P0];Bd0<?3``39bLT0^[Zj0;jn_P2k^k/0
Z:RX0080aLG500L0alO70<c<c037alL0];Bd0<O7a`3@d=00`L7100<0aLG500H0/;2`0<;2`P3<c<`0
a/K60<k>cP3:b/X20=[JfP070;fm_@37alL0c/k>0;bl_03:b/X0bLW90<S8b0020:f][@070;^k^`34
a<@0aLG50=GEe@2l_;`0Zj^[0<[:bP020<G5a@040;Jf]P30`<00b/[:0<K6aR@0oooo?02P?ol00`1o
ool0X3oo0:0oo`060:0oo`0307ooo`2P?ol0X3oo00P0X3oo00<0o`000:0oo`2P?ol0?@2P?olW0?oo
o`009@3oool00`3:b/X0a<C40<30`0020<;2`P070;>c/`2`/;00dm?C0;fm_@39bLT0b<S80<71`@02
0;bl_0070<o?c`2b/[80_;bl0;Bd]02o_kl0_[jn0<?3``020<;2`P070<o?c`2i^KT0b/[:0=?Cd`38
b<P0c<c<0<?3``020<[:bP070<71`@2o_kl0^KVi0;bl_03;bl/0_kno0=;BdP020<G5a@070<O7a`2m
_Kd0b/[:0=KFeP3Cdm<0b/[:0=SHf0020=WIf@030<K6aP2i^KT0_kno0080/[:b00X0dM7A0:NWY`2b
/[80/[:b0=CDe02HV9P0`<300;>c/`2i^KT0`l?30`30`<001`2l_;`0Ti>C0;Vi^@3:b/X0^k^k0:j^
[P2i^KT00P2o_kl01`39bLT0aLG50;Zj^P3WinL0aLG50;jn_P36a/H00P33`l<00`35aLD0alO70<W9
b@020<O7a`0;0;Jf]P39bLT0^;Rh0;Rh^02d];@0`l?30<W9b@2j^[X0_[jn0;^k^`2XZ:P00P35aLD0
1`37alL0c<c<0<O7a`2d];@0alO70=3@d031`L400`35aLD01P2`/;00`/;20<c<c036a/H0c/k>0<[:
bP80f][J00L0_Kfm0<O7a`3>c/h0_;bl0<[:bP39bLT0b<S80080[Jf]00L0^k^k0<C4a035aLD0eMGE
0;bl_02[Zj/0b/[:0080aLG500@0][Jf0<30`03:b/X0a/K6903oooll0:0oo`0307ooo`2P?ol0X3oo
00H0X3oo00<0Oooo0:0oo`2P?ol0202P?ol00`3o0000X3oo0:0oo`0m0:0oobL0oooo000U0?ooo`03
0<?3``2k^k/0[jn_0080bLW900L0_kno0<?3``37alL0c<c<0<?3``2n_[h0`/;20080/[:b00L0a/K6
0;bl_033`l<0][Jf0<W9b@2m_Kd0b/[:0080_kno00L0d];B0<;2`P35aLD0aLG50<c<c03:b/X0clo?
0080_;bl00L0WinO0<C4a032`/80`<300:^[Z`35aLD0alO70080e]KF00L0`<300<;2`P33`l<0a/K6
0:ZZZP31`L40[jn_0080Xj>S00L0/[:b0;Zj^P2o_kl0hN7Q0<?3``2j^[X0ZZZZ0080_;bl00L0Ti>C
0;^k^`3>c/h0];Bd0<G5a@2`/;00bl_;0080b<S800H0[:b/0<71`@3Rh^80ZZZZ0<?3``2f][H30;bl
_0070<O7a`3:b/X0][Jf0<_;b`2l_;`0][Jf0;jn_P020<_;b`070<W9b@35aLD0dm?C0<G5a@2UYJD0
_[jn0<O7a`020<?3``070;:b/P32`/80inOW0;Bd]03;bl/0dm?C0;Zj^P020<G5a@070<?3``31`L40
`l?30;fm_@2SXj<0`/;20<_;b`020<;2`P030:^[Z`3:b/X0][Jf0080bLW900/0c<c<0;^k^`3Fe]H0
e]KF0<o?c`3EeMD0_[jn0;2`/033`l<0alO70;Jf]P020<W9b@070=CDe035aLD0VIVI0:RXZ02g]kL0
d];B0;2`/0020;:b/P040<G5a@2][Jd0`/;20<?3`b@0oooo802P?ol00`1oool0X3oo0:0oo`0=0:0o
o`80Oooo0`2P?ol00`3o0000X3oo0:0oo`030:0oo`0307ooo`2P?ol0X3oo00P0X3oo00<0o`000:0o
o`2P?ol0602P?ol00`3o0000X3oo0:0oo`080:0oo`0307ooo`2P?ol0X3oo01H0X3oo00<0Oooo0:0o
o`2P?ol0202P?olW0?ooo`009@3oool20;Zj^P070;Fe]@2b/[80/[:b0:ZZZP2m_Kd0`<300=CDe002
0<30`0070;bl_02g]kL0]kNg0<30`02[Zj/0`<300;bl_0020<O7a`0:0<[:bP2b/[80/[:b0<71`@37
alL0b/[:0<S8b032`/80`<300;:b/P80_[jn00L0c<c<0<k>cP3>c/h0bLW90:6QX@2g]kL0aLG50080
^KVi00L0alO70<_;b`32`/80[Jf]0<71`@35aLD0/[:b0080Y:BT00L0/;2`0:^[Z`2[Zj/0_[jn0;fm
_@2f][H0[Zj^00<0^[Zj00H0bLW90<O7a`3;bl/0^;Rh0<?3``2f][H20<S8b0070=cLg02n_[h0cLg=
0;Jf]P2<S8`0`<300<O7a`020<g=c@070<;2`P33`l<0bl_;0<G5a@3:b/X0^;Rh0;Zj^P020<G5a@07
0;^k^`3Fe]H0aLG50<g=c@30`<00alO70=?Cd`020=[JfP070;bl_039bLT0]kNg0;^k^`32`/80[Jf]
0;Vi^@020;6a/@070<k>cP2OWil0bl_;0;bl_02f][H0_;bl0;^k^`020=SHf0070:f][@2j^[X0`/;2
0<o?c`2l_;`0`/;20;Bd]0020<?3``030<g=c@3EeMD0[Jf]0080cLg=00T0Ph>30=7Ad@32`/80`/;2
0<W9b@2m_Kd0alO70:b/[02o_kl00P3:b/X20;bl_0040<30`035aLD0clo?0<g=cB@0oooo902P?ol0
0`1oool0X3oo0:0oo`090:0oo`80Oooo5P2P?ol00`1oool0X3oo0:0oo`0N0:0oo`0307ooo`2P?ol0
X3oo01<0X3oo00<0Oooo0:0oo`2P?ol03P2P?olW0?ooo`009@3oool00`37alL0`l?30<30`0020;fm
_@070<[:bP33`l<0YJFU0;Ng]`2f][H0bLW90;no_`020<30`0070<c<c02e]KD0`/;20<;2`P38b<P0
_[jn0<71`@020;Bd]0070<71`@38b<P0clo?0<;2`P2o_kl0_Kfm0<71`@020<;2`P070<S8b03<c<`0
clo?0=7Ad@2^[Zh0_;bl0;Ng]`020;^k^`070;2`/033`l<0^KVi0<?3``3<c<`0alO70<W9b@020:FU
Y@070;Jf]P2][Jd0];Bd0;Rh^031`L40bLW909bLW0020:n_[`070;bl_02][Jd0`/;20;jn_P39bLT0
_Kfm0:b/[0020;bl_0070;no_`36a/H0][Jf0;Bd]02j^[X0^;Rh0<[:bP020<;2`P060;jn_P33`l<0
`/;20<71`@3:b/X0`l?30`35aLD0103?cll0OGem0<g=c@2][Jd20<c<c00:0=KFeP2h^;P0^;Rh0;Jf
]P33`l<0bl_;09jNWP30`<00dm?C0;Vi^@80_[jn00L0`<300<;2`P35aLD0clo?0=GEe@39bLT0_Kfm
0080alO700L0c<c<0;fm_@3?cll0_[jn0<O7a`3?cll0alO70080`/;200L0`l?30;Bd]02][Jd0`<30
0<O7a`3?cll0dM7A0080dm?C00L0c/k>0;:b/P2`/;00^[Zj0;^k^`30`<00^;Rh0080`l?300@0cLg=
0=7Ad@3Fe]H0bLW9903ooolh0:0oo`0307ooo`2P?ol0X3oo01`0X3oo00<0Oooo0:0oo`2P?ol0202P
?ol00`1oool0X3oo0:0oo`0[0:0oobL0oooo000U0?ooo`030;bl_032`/80/K6a0080^[Zj00L0^KVi
0<30`031`L40`l?30<71`@35aLD0^k^k0080YjNW00L0a/K60;Vi^@2n_[h0b<S80;jn_P3:b/X0b<S8
0080ZZZZ00L0a/K60:BTY03:b/X0`l?30;Ng]`37alL0dM7A0080aLG500L0_;bl0<;2`P2m_Kd0_;bl
09jNWP3=cLd0ZJVY0080^KVi0P3<c<`01@2d];@0]KFe0<[:bP2b/[80bLW90080c/k>00L0`<300<[:
bP2j^[X0aLG50<30`032`/80dM7A0080Zj^[00L0_[jn0:j^[P2b/[80gMgM0;2`/02WYjL0[jn_0080
^;Rh00L0`<300<?3``2h^;P0bLW90;bl_02[Zj/0^KVi0080`l?300L0b/[:0<?3``39bLT0c<c<0=3@
d03:b/X0f][J00<0c<c<00H0bLW90<[:bP3Bd]80`L710;jn_P3<c<`20;bl_0070;Zj^P37alL0aLG5
0<O7a`3Hf=P0aLG50;fm_@020;Jf]P070<G5a@2YZJT0][Jf0;2`/03>c/h0aLG50;Vi^@020<O7a`07
0;Vi^@3AdM40_[jn0=?Cd`33`l<0clo?0<W9b@020;no_`030=[JfP3AdM40aLG50080^KVi00/0aLG5
0>WYj@35aLD0aLG50;Jf]P2l_;`0bLW90:FUY@32`/80`<300=SHf0020;Fe]@040<o?c`3>c/h0_;bl
0<o?cb@0oooo602P?ol00`1oool0X3oo0:0oo`090:0oo`0307ooo`2P?ol0X3oo01L0X3oo00<0o`00
0:0oo`2P?ol0?`2P?ol00`3o0000X3oo0:0oo`0=0:0oobL0oooo000U0?ooo`030;:b/P2i^KT0c<c<
0080alO700<0][Jf0<O7a`38b<P00P37alL20:j^[P80`l?300L0_Kfm0;Fe]@38b<P0`<300<;2`P2n
_[h0b/[:0080_[jn00L0a<C40<k>cP3>c/h0_[jn0<;2`P33`l<0bLW90080_;bl00L0aLG50<?3``37
alL0_[jn0:JVYP2b/[80alO70080aLG500L0^k^k0<71`@2k^k/0c<c<0<o?c`2o_kl0Z:RX0080aLG5
00L0_[jn0;Vi^@3EeMD0dM7A0;Zj^P3:b/X0clo?0080/K6a00L0]kNg0;2`/03Fe]H0^;Rh0<O7a`2W
YjL0^[Zj0080`/;200L0f][J0;^k^`2g]kL0clo?0<30`02YZJT0^k^k0080aLG500L0^KVi07]kN`37
alL0e]KF0<g=c@3MgMd0`/;20080];Bd00L0]kNg0:f][@3AdM40/[:b0<g=c@3De=@0dM7A00<0_;bl
00H0bl_;0;Bd]02TY:@0`L710<G5a@2_[jl20;:b/P070;fm_@32`/80/;2`0:VYZ@2`/;00_[jn0;:b
/P020<_;b`030:RXZ037alL0/;2`0080aLG500@0^[Zj0<O7a`35aLD0aLG50P32`/801@37alL0`<30
0<C4a02n_[h0dM7A0080bLW900L0bl_;0<g=c@2b/[80e]KF0<?3``35aLD0`l?30080dM7A00@0`l?3
0;bl_03:b/X0gMgM903ooom>0:0oo`0507ooo`2P?ol0X3oo0:0oo`3o00003`2P?ol00`1oool0X3oo
0:0oo`0Z0:0oo`030?l0003oool0oooo02D0oooo000U0?ooo`030<;2`P2b/[80[jn_00<0`/;200@0
a<C40;Jf]P39bLT0^;Rh0P2b/[820<W9b@070<g=c@2n_[h0alO70<?3``2e]KD0a<C40<G5a@020;Jf
]P070<S8b02m_Kd0`/;20<?3``39bLT0`L710<;2`P020<k>cP050<_;b`30`<00`l?30;no_`2j^[X0
0P35aLD20;:b/P070;Ng]`37alL0`l?30;^k^`33`l<0];Bd0<G5a@020:^[Z`070:NWY`2i^KT0^KVi
0<30`02g]kL0c<c<096AT@020<G5a@80`<3000D0[jn_0;bl_02h^;P0];Bd0<;2`P020;Jf]P070<;2
`P2i^KT0`l?30<30`02XZ:P0/K6a0<S8b0020;bl_0060<S8b037alL0gmoO0=OGe`3;bl/0]kNg0`2l
_;`01`2`/;00`<300:n_[`37alL0g]kN0;jn_P2l_;`00P3=cLd01`2n_[h0`l?30<_;b`32`/80bLW9
0<30`02_[jl00P35aLD01`33`l<0aLG50;bl_03?cll0bLW90<?3``3@d=000P39bLT0103;bl/0_[jn
0<O7a`2XZ:P20<o?c`0:0=CDe03;bl/0bl_;0<;2`P2n_[h0alO70<G5a@30`<00bLW90=3@d080[Zj^
00L0dm?C0<g=c@2j^[X0cLg=0=7Ad@3<c<`0bl_;0080_;bl00@0clo?0;jn_P3<c<`0bLW9903ooolh
0:0oo`0307ooo`2P?ol0X3oo01@0X3oo00<0o`000:0oo`2P?ol0202P?ol00`3o0000X3oo0:0oo`0c
0:0oobL0oooo000U0?ooo`030<30`02[Zj/0]kNg0080aLG500H0`l?30;Jf]P35aLD0dM7A0;Bd]02j
^[X30<G5a@060<S8b031`L40alO70;Ng]`2i^KT0`L710`2l_;`01`2m_Kd0`l?30<?3``2j^[X0bLW9
0<k>cP2k^k/00P38b<P01P2>SXh0_Kfm0<71`@2k^k/0[Jf]0;Rh^0<0alO70P30`<001@35aLD0^[Zj
0<;2`P39bLT0_Kfm0080aLG500L0`<300<?3``30`<00^KVi0<71`@33`l<0YjNW0080][Jf00L0WYjN
0:n_[`2d];@0YJFU0;jn_P39bLT0W9bL0080];Bd00L0_[jn0;no_`2a/K40`<300<_;b`2TY:@0HV9R
0080_;bl00L0`<3009bLW01hN7P0_[jn0<O7a`2h^;P0bl_;0080`/;200L0/;2`0<c<c030`<00[Jf]
0=OGe`2h^;P0[Jf]0080alO700L0`<300;bl_02`/;00][Jf0<?3``2n_[h0bLW90080`<3000H0dM7A
0=KFeP2k^k/0alO70;jn_P3AdM430<O7a`070<G5a@3Ng]h0`l?30:6QX@3;bl/0dM7A0<?3``020<g=
c@070;bl_037alL0/[:b0<W9b@35aLD0_kno0<71`@020>?Sh`070<g=c@2NWYh0^;Rh0=7Ad@31`L40
[jn_09nOW`020;Ng]`040<W9b@2f][H0aLG50<k>cR@0oooo802P?ol00`1oool0X3oo0:0oo`0H0:0o
o`0307ooo`2P?ol0X3oo00<0X3oo00<0Oooo0:0oo`2P?ol01@2P?ol00`1oool0h?o00:0oo`020:0o
o`80Oooo8P2P?ol00`3o0000X3oo07ooo`0<0:0oo`80o`0000<0X3oo07ooo`2P?ol00`2P?ol00`1o
ool0X3oo0:0oo`040:0oobL0oooo000U0?ooo`030<71`@34a<@0a/K60080[Jf]00L0^k^k0;Ng]`32
`/80^KVi0;^k^`2l_;`0`<300080c<c<00L0alO70<;2`P3>c/h0`l?30;Zj^P2o_kl0b/[:0080^KVi
00L0_Kfm0<W9b@31`L40c<c<0;^k^`2a/K40`<300080e]KF00L0^KVi0;fm_@2i^KT0^;Rh0;Zj^P2n
_[h0c<c<0080bLW900L0`/;20<W9b@2h^;P0c<c<0<71`@39bLT0bl_;0080aLG500L0`<300<[:bP3?
cll0^;Rh0;^k^`2i^KT0`/;20080clo?00L0b<S80<O7a`2WYjL0`l?30=?Cd`2MWId0/;2`0080`<30
00L0^[Zj0<;2`P30`<00_;bl0:n_[`32`/80^k^k0080`L7100L0h>3P0;2`/02f][H0bLW90;bl_03;
bl/0aLG50080bLW900L0dM7A0<G5a@3:b/X0_kno0;:b/P30`<00_[jn0080alO700L0][Jf0<30`02l
_;`0alO70;6a/@35aLD0_[jn0080^k^k00L0bLW90;bl_036a/H0X:2P0<O7a`3@d=00aLG50080`l?3
00H0dM7A0=?Cd`34a<@0^[Zj0;jn_P33`l<30=CDe0070<G5a@36a/H0aLG50<30`02d];@0`L710<W9
b@020;Jf]P070<O7a`30`<00dm?C0;Rh^035aLD0`l?30;Jf]P020<O7a`80_kno00<0dM7A0;Zj^P3o
ool08`3ooom00:0oo`0307ooo`2P?ol0X3oo00X0X3oo00<0o`000:0oo`2P?ol06`2P?ol00`1oool0
X3oo0:0oo`0R0:0oobL0oooo000U0?ooo`030<71`@34a<@0a/K60080[Jf]00L0^k^k0;Ng]`32`/80
^KVi0;^k^`2l_;`0`<300080c<c<00L0alO70<;2`P3>c/h0`l?30;Zj^P2o_kl0b/[:0080^KVi00L0
_Kfm0<W9b@31`L40c<c<0;^k^`2a/K40`<300080e]KF00L0^KVi0;fm_@2i^KT0^;Rh0;Zj^P2n_[h0
c<c<0080bLW900L0`/;20<W9b@2h^;P0c<c<0<71`@39bLT0bl_;0080aLG500L0`<300<[:bP3?cll0
^;Rh0;^k^`2i^KT0`/;20080clo?00L0b<S80<O7a`2WYjL0`l?30=?Cd`2MWId0/;2`0080`<3000L0
^[Zj0<;2`P30`<00_;bl0:n_[`32`/80^k^k0080`L7100L0h>3P0;2`/02f][H0bLW90;bl_03;bl/0
aLG50080bLW900L0dM7A0<G5a@3:b/X0_kno0;:b/P30`<00_[jn0080alO700L0][Jf0<30`02l_;`0
alO70;6a/@35aLD0_[jn0080^k^k00L0bLW90;bl_036a/H0X:2P0<O7a`3@d=00aLG50080`l?300H0
dM7A0=?Cd`34a<@0^[Zj0;jn_P33`l<30=CDe0070<G5a@36a/H0aLG50<30`02d];@0`L710<W9b@02
0;Jf]P070<O7a`30`<00dm?C0;Rh^035aLD0`l?30;Jf]P020<O7a`80_kno00<0dM7A0;Zj^P3oool0
8`3ooom00:0oo`0307ooo`2P?ol0X3oo00X0X3oo00<0o`000:0oo`2P?ol06`2P?ol00`1oool0X3oo
0:0oo`0R0:0oobL0oooo000U0?ooo`030;^k^`2g]kL0Z:RX0080`l?300L0_kno0=CDe039bLT0/[:b
0<;2`P2`/;00alO70080bl_;00H0]kNg0;bl_02m_Kd0];Bd0:ZZZP2n_[h40<c<c0030;^k^`31`L40
][Jf0080_kno00X0b/[:0<G5a@35aLD0`L710=KFeP37alL0^;Rh0<30`03:b/X0d=3@0P2o_kl01`30
`<00alO70<O7a`35aLD0_;bl09JFUP3=cLd00P2f][H01`35aLD0b/[:0;Bd]02n_[h0_kno0;^k^`2g
]kL00P32`/801`2TY:@0a/K60<C4a03>c/h0X:2P09NGU`2k^k/00P2m_Kd01`30`<00`/;20:f][@39
bLT0XJ6Q0;Jf]P2h^;P00P2j^[X01P2h^;P0][Jf0;jn_P3Jf]X0c<c<0;:b/P<0_kno00L0f=SH0<k>
cP2d];@0alO70<G5a@2n_[h0^[Zj0080c<c<00L0`/;20<30`032`/80`/;20<[:bP34a<@0/K6a0080
_kno00L0`L710<?3``2l_;`0g]kN0<W9b@2f][H0aLG500<0`/;20P2ZZZX01039bLT0`<300:b/[035
aLD20<o?c`070=3@d03EeMD0f=SH0=?Cd`39bLT0WinO0<_;b`020;no_`060<O7a`2_[jl0bl_;0=[J
fP3AdM40bLW90`3QhN401033`l<0bl_;0<k>cP31`L4T0?ooobh0X3oo00<0Oooo0:0oo`2P?ol02P2P
?ol0101oool0X3oo0:0oo`2P?ol207ooo`L0X3oo00<0Oooo0:0oo`2P?ol0802P?ol00`3o0000X3oo
0:0oo`0A0:0oo`0307ooo`2P?ol0X3oo00L0X3oo0`3o00040:0oobL0oooo000U0?ooo`030;bl_036
a/H0a/K60080]kNg00L0`L710;^k^`3>c/h0/k>c0:b/[02m_Kd0`L710080a<C400L0^k^k0<?3``33
`l<0_kno0<S8b034a<@0_;bl0080`l?300L0clo?0<71`@35aLD0bLW90<O7a`3=cLd0/[:b0080^k^k
00L0bl_;0<W9b@2j^[X0/[:b0;Zj^P2g]kL0^KVi0080`l?300<0/[:b0;bl_039bLT00P39bLT02`32
`/80cLg=0;Bd]02d];@0bLW90<o?c`2f][H0aLG50;Bd]037alL0cLg=0080];Bd00H0Y:BT0;Fe]@2e
]KD0`<30096AT@2/[:`30:ZZZP070;Jf]P39bLT0aLG50;Bd]030`<00];Bd0:>SX`020;Rh^0070<?3
``2n_[h0alO70:b/[02k^k/0^;Rh0;Zj^P020<o?c`070;Zj^P3Fe]H0c/k>0<k>cP35aLD0_;bl0<?3
``020<;2`P070;Bd]02][Jd0clo?0<;2`P2`/;00`<300<?3``020=3@d0070;no_`2TY:@0^k^k0<30
`039bLT0`/;20<30`0020<_;b`040=SHf02n_[h0`/;20<G5a@80bLW900X0b/[:0<;2`P32`/80`l?3
0<g=c@3<c<`0bLW90<30`03>c/h0alO70P2VYZH01`35aLD0jn_[0;jn_P37alL0bLW90<[:bP31`L40
0P3?cll0102TY:@0MWIf0;Jf]P37alLT0?oooc/0X3oo00D0Oooo0:0oo`2P?ol0X3oo07ooo`0:0:0o
o`0307ooo`2P?ol0X3oo01`0X3oo00<0Oooo0:0oo`2P?ol0602P?ol00`3o0000X3oo0:0oo`050:0o
o`80Oooo0P2P?olW0?ooo`009@3oool00`2d];@0^KVi0=_Kf`020;Vi^@070<?3``3<c<`0`l?30<71
`@3?cll0aLG50;Fe]@020<G5a@070<W9b@35aLD0^k^k0;bl_03<c<`0aLG50<S8b0020<;2`P070;^k
^`3;bl/0]kNg0;no_`35aLD0_[jn0;Vi^@020;Jf]P070<?3``39bLT0][Jf0<O7a`2o_kl0_Kfm0<W9
b@020;bl_0070<g=c@30`<00_[jn0<G5a@2b/[80`/;20<30`0020;Jf]P070<W9b@2j^[X0_kno0<o?
c`2/[:`0_;bl0<W9b@020<O7a`070:FUY@3AdM40_;bl0<O7a`2NWYh0_;bl0:JVYP020;Bd]0070;Vi
^@32`/80`<300:n_[`2h^;P0Zj^[0;Vi^@020<W9b@070<o?c`2l_;`0cLg=0;:b/P3Cdm<0aLG50;bl
_0020<?3``070<G5a@2j^[X0alO70<71`@33`l<0gMgM0<c<c0020<;2`P070;bl_03:b/X0]KFe0;^k
^`2][Jd0/[:b0=KFeP020:^[Z`070<g=c@3Ti>@0eMGE0=OGe`32`/80^[Zj0;^k^`020<o?c`070=?C
d`2d];@0_;bl0;^k^`2l_;`0][Jf0=;BdP020<G5a@070<W9b@3=cLd0`/;20<[:bP2m_Kd0clo?0<[:
bP020=?Cd`070<o?c`2_[jl0]kNg0;2`/035aLD0];Bd0=;BdP020<?3``80_;bl00<0b/[:0<71`@3o
ool08`3ooolo0:0oo`0307ooo`2P?ol0X3oo01T0X3oo00<0o`000:0oo`2P?ol02`2P?ol00`3o0000
X3oo0:0oo`0T0:0oobL0oooo000U0?ooo`030<71`@39bLT0alO70080][Jf00L0^;Rh0<G5a@2d];@0
`<300;bl_032`/80_[jn0080c<c<00<0_Kfm0<O7a`3:b/X00P37alL00`32`/80c/k>0<K6aP020<K6
aP060<O7a`2m_Kd0`l?30<O7a`33`l<0^[Zj0P3<c<`01`2g]kL0`<300<?3``2`/;00dm?C0;Zj^P3=
cLd00P2i^KT01`30`<00];Bd0<[:bP2XZ:P0`L710<C4a03;bl/00P37alL01`39bLT0`/;20;jn_P30
`<00];Bd0;Jf]P3>c/h00P35aLD01`2OWil0`<300<_;b`3:b/X0^KVi0<G5a@2`/;000P2HV9P20:f]
[@050:RXZ02j^[X0/;2`0;Zj^P3Cdm<00P3AdM401`2OWil0/;2`0<30`030`<00/;2`0;Jf]P32`/80
0P39bLT0102n_[h0^[Zj0<30`03;bl/20<?3``0:0<O7a`3?cll0clo?0<W9b@2n_[h0c<c<0<k>cP30
`<00_;bl0;^k^`80eMGE00L0alO70<c<c02`/;00/K6a0;Zj^P3;bl/0clo?0080cLg=00L0aLG50<o?
c`2QXJ40clo?0=GEe@37alL0dM7A0080eMGE0P39bLT01@3Fe]H0^[Zj0<G5a@2d];@0^[Zj0080JVYZ
00D0alO70<W9b@30`<00_;bl0;Rh^0020<[:bP80`l?300@0bLW90<?3``3<c<`0^[Zj903ooolk0:0o
o`0307ooo`2P?ol0X3oo00@0X3oo0P1oool90:0oo`0307ooo`2P?ol0X3oo02<0X3oo00<0Oooo0:0o
o`2P?ol02`2P?ol20>3o`0d0X3oo9`3oool002D0oooo00<0^KVi0;^k^`2b/[800P30`<001@2l_;`0
Zj^[0;Zj^P39bLT0a/K60080_;bl0P3AdM401`30`<00_;bl0:n_[`35aLD0_[jn0<?3``2i^KT00P2g
]kL01`2e]KD0`<300<o?c`3?cll0bl_;0=SHf035aLD00P3:b/X20<30`0050;:b/P37alL0_[jn0;no
_`35aLD00`33`l<01P2k^k/0b/[:0:n_[`32`/80];Bd0;bl_080b/[:00L0_Kfm0;^k^`2k^k/0_kno
0;:b/P34a<@0][Jf0080`L7100L0f=SH0<;2`P2l_;`0][Jf051@D02l_;`0_[jn0080[jn_00L0V9RH
0;Fe]@2k^k/0[Zj^0;:b/P28R8P0aLG50080^;Rh00L0^[Zj09JFUP35aLD0bl_;0<g=c@3;bl/0];Bd
0080[Jf]00L0alO70<?3``3;bl/0cLg=0<W9b@32`/80alO70080][Jf00@0`/;208V9R@3Cdm<0_;bl
0P35aLD02P2n_[h0/[:b0;:b/P3?cll0][Jf0<O7a`2h^;P0c<c<0<k>cP3?cll20<G5a@070=7Ad@2o
_kl0bLW90;no_`3@d=00`l?30<o?c`020;Bd]0070<_;b`35aLD0alO70;jn_P2][Jd0`<300=CDe002
0<_;b`070;Bd]02h^;P0/;2`0<;2`P37alL0Z:RX0<W9b@020;Zj^P040;fm_@2JVYX0dM7A0;:b/R@0
oooo?`2P?ol00`3Pol00X3oo0:0oo`020:0oo`0307ooo`2P?ol0X3oo0080X3oo00<0Oooo0:0oo`2P
?ol00P2P?ol00`1oool0X3oo0:0oo`0?0:0oo`0307ooo`2P?ol0X3oo02X0X3oo00<0Oooo0:0oo`2P
?ol09`3oool002D0oooo00<0a<C40:f][@2m_Kd00P3=cLd01`2o_kl0bLW90=_Kf`3AdM40alO70;no
_`37alL00P35aLD01`39bLT0_;bl0;no_`2i^KT0bl_;0<G5a@33`l<00P3@d=001`2i^KT0a/K60;Zj
^P3=cLd0aLG50;Jf]P30`<000P2g]kL01@33`l<0b<S80<O7a`2n_[h0a<C40080bLW90P33`l<01`32
`/80^[Zj0;fm_@3@d=00];Bd0;:b/P30`<000P27QhL01`2n_[h0][Jf0<G5a@3AdM40aLG50=3@d03F
e]H00P3EeMD01`32`/80alO70<?3``2h^;P0aLG50;Rh^02b/[800P35aLD01033`l<0QHF509ZJVP2V
YZH20:ZZZP0:09nOW`34a<@0a<C40<O7a`2SXj<0`<300<o?c`36a/H0`<300<S8b080a/K600L0b<S8
0<G5a@3;bl/0aLG50<O7a`2b/[80c<c<00<0^KVi00H0]kNg0<30`03Fe]H0_;bl0<?3``2d];@20;jn
_P070<_;b`33`l<0bl_;0=?Cd`3De=@0`l?30=KFeP020=SHf0070=?Cd`39bLT0_;bl0=SHf03=cLd0
dm?C0=;BdP020<O7a`070=?Cd`39bLT0[:b/0;bl_02h^;P0Zj^[0;2`/0020=7Ad@070=KFeP3Ogml0
f][J0<o?c`2YZJT0b/[:0=_Kf`020<?3``040=GEe@39bLT0aLG50<c<c2@0oooo<02P?ol207oooa<0
X3oo0P1oool30:0oo`0507ooo`2P?ol0X3oo0:0oo`1oool0=@2P?ol00`3o0000X3oo0:0oo`090:0o
obL0oooo000U0?ooo`030;6a/@2b/[80_kno0080_[jn00L0[Zj^0;2`/030`<00]kNg0;Bd]03@d=00
`L710080_Kfm00@0_kno0<O7a`33`l<0_;bl0P2d];@01039bLT0aLG50<G5a@35aLD20<71`@040<c<
c035aLD0_kno0<C4a080_;bl00L0]kNg0;Fe]@32`/80_;bl0<30`03AdM40bLW90080clo?00L0`/;2
0<g=c@2k^k/0_Kfm0;Jf]P2[Zj/0`l?30080b/[:00L0`<300<k>cP3:b/X0dM7A0=3@d037alL0gMgM
0080dm?C00L0][Jf0<?3``37alL0`L710<o?c`35aLD0][Jf0080`<3000L0/[:b0:6QX@1hN7P0_;bl
0:2PX02e]KD0aLG50080e=CD0P2o_kl01@2n_[h0];Bd0<c<c03:b/X0c<c<0080b/[:00L0ZZZZ0<30
`02n_[h0^k^k0<30`03GemL0bLW90080a/K600L0_[jn09jNWP3:b/X0c<c<0;bl_032`/80clo?0080
`/;200@0cLg=0>g]k@2][Jd0aLG50P39bLT02P3?cll0YjNW0:NWY`3;bl/0eMGE0<_;b`35aLD0`<30
0<_;b`35aLD20<[:bP070<O7a`3Fe]H0c<c<0<g=c@3AdM40_kno0<W9b@020>?Sh`070<o?c`2IVIT0
[Jf]0<C4a03<c<`0`l?30<W9b@020<k>cP040;Zj^P2/[:`0`L710;Jf]R@0oooo>02P?ol00`3o0000
X3oo0:0oo`0:0:0oo`80Oooo00<0X3oo07ooo`2P?ol05P2P?ol00`1oool0X3oo0:0oo`060:0oo`03
0?l0002P?ol0X3oo01D0X3oo0P3o00000`2P?ol0Oooo0:0oo`0:0:0oobL0oooo000U0?ooo`030;fm
_@30`<00`/;20080[Jf]00L0X:2P0<o?c`2g]kL0aLG50;bl_030`<00^k^k0080_;bl00L0b<S80:j^
[P3>c/h0_kno0;2`/037alL0_kno0080c/k>00D0`<300;Zj^P3;bl/0_Kfm0<?3``020<k>cP80^KVi
00L0_kno0<G5a@2i^KT0alO70;^k^`2n_[h0alO70080`/;20`37alL0102VYZH0_Kfm0:f][@2f][H2
0=KFeP070<k>cP3Bd]80[:b/0=[JfP3MgMd0j^[Z0<k>cP020;Jf]P060<[:bP2i^KT0/[:b0<G5a@2h
^;P0_;bl0`32`/801`37alL0`l?30;Zj^P2TY:@0TY:B0;Ng]`2o_kl00P2TY:@01`3Cdm<0WinO0:n_
[`2n_[h0/[:b0<[:bP3;bl/00P3?cll01`39bLT0^[Zj0<O7a`39bLT0OGem0<?3``3Jf]X00P2b/[80
1`39bLT0Zj^[0=?Cd`2l_;`0aLG50;jn_P2d];@00P2g]kL01`3GemL0`/;20;Zj^P30`<00alO70<G5
a@39bLT00P2YZJT01`3Ng]h0/;2`0<O7a`3@d=00dM7A0<W9b@2n_[h00P33`l<01`32`/80_kno0;jn
_P2d];@0^[Zj0>;RhP3;bl/00P2f][H01`38b<P0`/;20<?3``39bLT0bl_;0<?3``3Lg=`00P3<c<`0
102ZZZX0Z:RX0;bl_03Bd]8T0?ooo`D0X3oo00<0Oooo0:0oo`2P?ol0;P2P?ol20?l000l0X3oo0P1o
ool20:0oo`80Oooo00<0X3oo07ooo`2P?ol02P2P?ol00`1oool0X3oo0:0oo`0D0:0oo`030?l0002P
?ol0X3oo00/0X3oo00<0o`000:0oo`2P?ol03P2P?olW0?ooo`009@3oool00`2m_Kd0`<300<;2`P02
0:f][@070:2PX03?cll0]kNg0<G5a@2l_;`0`<300;^k^`020;bl_0070<S8b02^[Zh0c/k>0;no_`2`
/;00alO70;no_`020<k>cP050<30`02j^[X0bl_;0;fm_@33`l<00P3>c/h20;Vi^@070;no_`35aLD0
^KVi0<O7a`2k^k/0_[jn0<O7a`020<;2`P<0alO700@0YZJV0;fm_@2][Jd0][Jf0P3Fe]H01`3>c/h0
d];B0:b/[03Jf]X0gMgM0>[ZjP3>c/h00P2f][H01P3:b/X0^KVi0;:b/P35aLD0^;Rh0;bl_0<0`/;2
00L0alO70<?3``2j^[X0Y:BT09:BTP2g]kL0_kno0080Y:BT00L0dm?C09nOW`2_[jl0_[jn0;:b/P3:
b/X0bl_;0080clo?00L0bLW90;Zj^P37alL0bLW907emO@33`l<0f][J0080/[:b00L0bLW90:^[Z`3C
dm<0_;bl0<G5a@2n_[h0];Bd0080]kNg00L0emOG0<;2`P2j^[X0`<300<O7a`35aLD0bLW90080ZJVY
00L0g]kN0;2`/037alL0d=3@0=7Ad@39bLT0_[jn0080`l?300L0`/;20;no_`2n_[h0];Bd0;Zj^P3R
h^80bl_;0080][Jf00L0b<S80<;2`P33`l<0bLW90<_;b`33`l<0g=cL0080c<c<00@0ZZZZ0:RXZ02l
_;`0d];B903oool50:0oo`0307ooo`2P?ol0X3oo02h0X3oo0P3o000?0:0oo`80Oooo0P2P?ol207oo
o`030:0oo`1oool0X3oo00X0X3oo00<0Oooo0:0oo`2P?ol0502P?ol00`3o0000X3oo0:0oo`0;0:0o
o`030?l0002P?ol0X3oo00h0X3oo9`3oool002D0oooo00<0`/;20<k>cP32`/800P2k^k/01`2^[Zh0
alO70<W9b@35aLD0c<c<0;^k^`2e]KD00P32`/801`35aLD0`/;20;bl_02d];@0alO70;Zj^P33`l<0
0P3>c/h01`3@d=00cLg=0<30`038b<P0`<300;Ng]`2_[jl00P2^[Zh01`2o_kl0b/[:0<K6aP2`/;00
_;bl0:j^[P3:b/X00P33`l<01`3AdM40d=3@0<S8b02m_Kd0/[:b0<;2`P30`<000P3<c<`01`2m_Kd0
Zj^[0;jn_P3:b/X0g=cL0<o?c`3=cLd00P2i^KT20<O7a`050<_;b`2h^;P0d];B0;jn_P37alL00P33
`l<01`2l_;`0/K6a0:n_[`2JVYX0YjNW09nOW`2b/[800`2g]kL01P2a/K40_Kfm0:>SX`3;bl/0b/[:
0<G5a@80b/[:00L0^k^k0;Fe]@3;bl/0bl_;0;Bd]03Cdm<0alO70080_Kfm00H0];Bd0<?3``30`<00
_[jn09RHV032`/830<O7a`070<30`02n_[h0bl_;0<?3``2i^KT0_Kfm0=CDe0020=7Ad@070:FUY@3?
cll0alO70<O7a`3Bd]80_;bl0:j^[P020;:b/P070<G5a@2WYjL0dM7A0<G5a@30`<00b/[:0<G5a@02
0<g=c@0709FEU@37alL0X:2P0:JVYP2][Jd0Zj^[0<G5a@020;Ng]`040<K6aP2i^KT0c/k>0=WIfB@0
ooooA`2P?ol00`1oool0X3oo07ooo`060:0oo`0307ooo`2P?ol0X3oo0100X3oo00<0Oooo0:0oo`2P
?ol07@2P?ol00`1oool0X3oo07ooo`0:0:0oobL0oooo000U0?ooo`030;^k^`33`l<0`L710080dM7A
00L0Zj^[09JFUP2l_;`0^KVi0;fm_@37alL0`<300080`l?300L0][Jf0;jn_P39bLT0`<300<C4a03<
c<`0alO70080_Kfm00L0`l?30<_;b`39bLT0`L710<[:bP2o_kl0/;2`0080UIFE00L0/;2`0<30`02a
/K40c<c<0<_;b`2`/;00cLg=0080_;bl00L0dM7A0<o?c`2o_kl0_Kfm0:BTY032`/80`<300080eMGE
00L0emOG0>7Qh@2l_;`0clo?0<_;b`2`/;00/[:b0080]kNg00L0b/[:0<;2`P32`/80alO70;Zj^P37
alL0^k^k0080aLG500L0`L710:j^[P33`l<0ZZZZ0:VYZ@2a/K40^k^k0080WYjN00L0^[Zj0;Rh^02W
YjL0`l?30<_;b`2_[jl0`/;20080][Jf00L0alO709nOW`3?cll0`l?30<c<c03;bl/0W9bL0080b/[:
00L0/[:b0=GEe@3>c/h0`<300<71`@2l_;`0[:b/0080`<3000L0/;2`0;^k^`31`L40][Jf0<g=c@2n
_[h0b/[:0080aLG500L0clo?0<O7a`2i^KT0dm?C0<;2`P3Jf]X0^;Rh0080aLG500L0[jn_0<30`03=
cLd0dM7A0=?Cd`30`<00^;Rh0080][Jf00L0^KVi0<_;b`30`<00_[jn0?3`l037alL0`<300080aLG5
00@0];Bd0<30`039bLT0d=3@903oool60:0oo`0307ooo`2P?ol0X3oo01D0X3oo0P1oool=0:0oo`03
07ooo`2P?ol0X3oo00<0X3oo00<0o`000:0oo`2P?ol05@2P?ol207ooo`X0X3oo00<0Oooo0:0oo`2P
?ol00P2P?ol00`1oool0X3oo0:0oo`0X0:0oo`030?l0002P?ol0X3oo00H0X3oo9`3oool002D0oooo
00<0_kno0<[:bP2m_Kd00P2d];@0103:b/X0dM7A0<c<c02d];@20;bl_00:0<c<c02d];@0];Bd0<k>
cP32`/80dM7A0<O7a`2n_[h0_;bl0<71`@80d=3@00L0];Bd0;fm_@2d];@0`<300<O7a`2d];@0/;2`
0080X:2P00L0UIFE0<_;b`34a<@0_;bl0;jn_P3:b/X0aLG50080]kNg00L0`l?30<G5a@2f][H0`l?3
0;Rh^02f][H0`l?30080aLG500L0`l?30<g=c@2XZ:P0RXZ:096AT@2CTi<0UIFE0080dM7A00L0][Jf
0<k>cP36a/H0^k^k0;jn_P3?cll0f=SH0080XJ6Q00L0`L710;Rh^02l_;`0`/;20;Ng]`2[Zj/0c/k>
0080bLW900L0aLG50;2`/039bLT0alO70=CDe03:b/X0clo?0080aLG500L0h>3P0<G5a@3>c/h0][Jf
0=SHf03=cLd0`l?30080e]KF00L0];Bd0<O7a`3;bl/0eMGE0=?Cd`2l_;`0c<c<0080YjNW00L0bLW9
0;Vi^@39bLT0c/k>0>_[j`2b/[80g=cL0080aLG500L0f][J0=7Ad@35aLD0alO70<o?c`3Jf]X0cLg=
0080_kno00L0/[:b0<W9b@3;bl/0XZ:R0<?3``2d];@0bLW90080VYZJ00L0`/;20;jn_P2i^KT0`l?3
0<k>cP30`<00b/[:0080d=3@00@0c/k>0<O7a`3Hf=P0e]KF903ooolN0:0oo`<0Oooo502P?ol407oo
o`T0X3oo0P1ooolB0:0oo`030?l0002P?ol0X3oo01<0X3oo00<0o`000:0oo`2P?ol03P2P?ol0101o
ool0X3oo0:0oo`2P?ol207ooo`d0X3oo9`3oool002D0oooo00<0bLW90;bl_035aLD00P30`<001`2d
];@0]kNg0;Jf]P35aLD0b/[:0<W9b@37alL00P33`l<01`35aLD0`/;20=7Ad@31`L40c<c<0<W9b@3>
c/h00P31`L401`33`l<0b/[:0;Jf]P39bLT0/[:b0<?3``32`/800P35aLD01`3Hf=P0^KVi0;jn_P2i
^KT0_kno0<[:bP3<c<`00P3;bl/01`33`l<0/;2`0;Jf]P35aLD0^;Rh0<_;b`37alL00P2EUID01`21
PH40V9RH09nOW`2[Zj/0Ogmo0;:b/P30`<000P39bLT01`3;bl/0eMGE0;jn_P2n_[h0c/k>0<30`039
bLT00P33`l<01`32`/80/[:b0<?3``2l_;`0`<300<;2`P2JVYX00P2g]kL01`2`/;00/[:b0:NWY`2`
/;00_Kfm0<c<c039bLT00P2ZZZX01`3<c<`0c/k>0=3@d030`<00bLW90<;2`P37alL00P3>c/h01`2o
_kl0c/k>0:NWY`35aLD0_;bl0<;2`P3>c/h00P2n_[h00`35aLD0cLg=0<_;b`020<30`00;0<?3``3]
kNd0d=3@0=3@d031`L40`/;20<O7a`2m_Kd0dm?C0<[:bP33`l<00P2h^;P01`37alL0aLG50;Zj^P2a
/K40YjNW0<;2`P2h^;P00P3;bl/01`32`/80/;2`0;fm_@3<c<`0b/[:0<;2`P2o_kl00P3>c/h0102k
^k/0]kNg0=?Cd`2l_;`T0?oooc00X3oo1@1oool00`2P?ol0Oooo0:0oo`0B0:0oo`0307ooo`2P?ol0
X3oo0240X3oo00<0o`000:0oo`2P?ol07`2P?olW0?ooo`009@3oool00`2c/k<0_[jn0<K6aP020;Zj
^P070;Ng]`37alL0c<c<0<O7a`32`/80_;bl0<;2`P020<C4a0070;bl_02f][H0`l?30<G5a@33`l<0
aLG50<o?c`020<G5a@070;jn_P2k^k/0^KVi0<c<c037alL0^KVi0;jn_P030<W9b@030:FUY@2f][H0
_[jn0080`l?300X0b/[:0<o?c`3?cll0b<S80<;2`P35aLD0`l?30<[:bP2d];@0b/[:0P37alL0102g
]kL0V9RH0:6QX@2j^[X20;jn_P0:0;Rh^030`<00`<300<G5a@2j^[X0cLg=0<O7a`2m_Kd0^KVi0;:b
/P80_[jn00L0a/K60;jn_P35aLD0`/;20:^[Z`2l_;`0c<c<0080dM7A00L0_;bl0:>SX`33`l<0bLW9
0;jn_P32`/80bl_;0080^[Zj00L0/;2`0<?3``33`l<0_Kfm0<c<c03:b/X0aLG50080dM7A00L0][Jf
0;^k^`30`<00YJFU0;Jf]P2d];@0/[:b0080bl_;00L0clo?0<[:bP3?cll0alO70<G5a@2l_;`0/[:b
0080bl_;00L0dM7A0<O7a`39bLT0b/[:0>7Qh@3:b/X0^[Zj0080_;bl00L0clo?0<30`03AdM40`<30
0;jn_P3?cll0^[Zj0080eMGE00L0_[jn0=?Cd`2j^[X0^KVi0;fm_@31`L40`l?30080][Jf00@0cLg=
0<k>cP3:b/X0clo?903ooolc0:0oo`80Oooo6@2P?ol00`1oool0X3oo0:0oo`0T0:0oo`030?l0002P
?ol0X3oo01P0X3oo9`3oool002D0oooo00<0`l?30<G5a@2i^KT00P2k^k/01`2a/K40];Bd0<K6aP2e
]KD0/[:b0<O7a`2d];@00P2g]kL01`2_[jl0clo?0;Jf]P2l_;`0`<300;^k^`2n_[h00P2[Zj/01`37
alL0^k^k0<G5a@3=cLd0alO70;Rh^02o_kl00P3:b/X01`2j^[X0][Jf0<?3``2n_[h0aLG50<W9b@35
aLD00P3=cLd01`3>c/h0][Jf0<W9b@2b/[80^k^k0;fm_@2b/[800P2d];@01`2f][H0W9bL0<;2`P3?
cll0/[:b0;Zj^P39bLT00P2b/[801`2g]kL0`l?30<30`033`l<0f=SH0;jn_P2k^k/00P2g]kL01`2k
^k/0];Bd0;no_`2f][H0^[Zj0;Bd]03Ng]h00P2BTY801`3Cdm<0cLg=0;Jf]P3;bl/0`/;20:n_[`3R
h^800P35aLD01`2g]kL0_Kfm0;Zj^P2b/[80alO70=[JfP35aLD00P3;bl/01`32`/80][Jf0<?3``3;
bl/0dm?C0;bl_032`/800P3Jf]X01`31`L40`/;20=GEe@2WYjL0];Bd0<G5a@2_[jl00`3;bl/01P35
aLD0clo?0=7Ad@2j^[X0cLg=0<71`@80bLW900L0`l?30<g=c@3?cll0`L710:RXZ02SXj<0bl_;0080
aLG500L0`/;20<?3``2h^;P0aLG50<;2`P3:b/X0eMGE0080d];B00@0`<300;Vi^@2j^[X0aLG5903o
oolc0:0oo`0307ooo`2P?ol0X3oo01@0X3oo00<0o`0007ooo`1oool01P2P?ol00`3o0000X3oo0:0o
o`0Y0:0oo`0307ooo`2P?ol0X3oo00h0X3oo9`3oool002D0oooo00<0_[jn0<K6aP35aLD00P28R8P0
1`2FUYH0S8b<0;:b/P2TY:@0bl_;0<C4a02g]kL00P2o_kl01`31`L40ZZZZ0;Jf]P31`L40ZZZZ0;Ng
]`3=cLd00P30`<001`2f][H0c<c<0;bl_02k^k/0c<c<0<G5a@3;bl/00P30`<001P3?cll0`l?30<o?
c`33`l<0aLG50;2`/0<0bLW900L0f][J0=;BdP2l_;`0c<c<0<o?c`2c/k<0alO70080f=SH00L0bLW9
0:ZZZP3=cLd0^[Zj0;bl_03Cdm<0eMGE0080alO700L0`L710<O7a`37alL0c<c<0<?3``32`/80c<c<
0080`<3000L0^[Zj0;2`/02h^;P0_;bl0<_;b`2`/;00^KVi0080/[:b00L0_;bl09jNWP2i^KT0c/k>
0<?3``3Jf]X0`l?30080_;bl00D0dM7A0<W9b@3AdM40_[jn0;Rh^0020<O7a`80];Bd00L0`L710:RX
Z035aLD0/[:b0<c<c02YZJT0]kNg0080a<C400L0bLW90<O7a`30`<00aLG50<_;b`35aLD0alO70080
aLG500L0/k>c0<W9b@2h^;P0^;Rh0<g=c@39bLT0_;bl0080^KVi00L0alO70<c<c03:b/X0bLW90<G5
a@2n_[h0];Bd0080e]KF00L0alO70<;2`P3Ti>@0`/;20=SHf02h^;P0WinO0080`l?300@0eMGE0;^k
^`2j^[X0e]KF903oool30:0oo`@0Oooo00<0X3oo07ooo`2P?ol0A02P?ol00`1oool0X3oo0:0oo`0d
0:0oo`050?l0002P?ol0X3oo0:0oo`1oool01P2P?olW0?ooo`009@3oool00`2XZ:P0^[Zj0:j^[P02
0;^k^`030<?3``3De=@0^k^k0080alO700X0`L710<?3``2o_kl0_kno0<?3``30`<00`/;20:ZZZP2`
/;00`l?30`2k^k/01`39bLT0^KVi0;Vi^@3AdM40`/;20<O7a`2g]kL00P3AdM401`2g]kL0c/k>0<?3
``37alL0/;2`0;jn_P37alL00P35aLD01`38b<P0]kNg0<?3``33`l<0^[Zj0;Jf]P32`/800P2i^KT0
1@2[Zj/0[:b/0;fm_@2`/;00_Kfm0080`l?30P2j^[X01`3=cLd0_;bl0=7Ad@39bLT0`<300=?Cd`30
`<000P3=cLd01`2h^;P0aLG50;:b/P35aLD0/[:b0:VYZ@2i^KT00P2l_;`01`35aLD0YJFU0;Zj^P3A
dM40][Jf0=SHf02l_;`00P3Ng]h01`31`L40^[Zj0<c<c02n_[h0`/;20<?3``39bLT00P3;bl/01`33
`l<0WinO0<;2`P3?cll0[jn_0<C4a02`/;000`30`<001P33`l<0b/[:0=3@d02n_[h0e]KF0<?3``80
^[Zj00L0[jn_0;Rh^032`/80`/;20<_;b`2b/[80_[jn0080e]KF00L0clo?0<O7a`2j^[X0^KVi0;bl
_02m_Kd0c/k>0080`/;200L0YjNW0<[:bP3;bl/0`/;20<G5a@3AdM40f][J0080clo?00@0];Bd0<O7
a`3GemL0e]KF903ooomD0:0oo`80o`002P2P?ol00`1oool0X3oo0:0oo`0]0:0oobL0oooo000U0?oo
o`030:RXZ02j^[X0[Zj^0080^k^k00<0`l?30=CDe02k^k/00P37alL02P31`L40`l?30;no_`2o_kl0
`l?30<30`032`/80ZZZZ0;2`/033`l<30;^k^`070<W9b@2i^KT0^KVi0=7Ad@32`/80alO70;Ng]`02
0=7Ad@070;Ng]`3>c/h0`l?30<O7a`2`/;00_[jn0<O7a`020<G5a@070<S8b02g]kL0`l?30<?3``2j
^[X0][Jf0<;2`P020;Vi^@050:^[Z`2/[:`0_Kfm0;2`/02m_Kd00P33`l<20;Zj^P070<g=c@2l_;`0
dM7A0<W9b@30`<00dm?C0<30`0020<g=c@070;Rh^035aLD0/[:b0<G5a@2b/[80ZJVY0;Vi^@020;bl
_0070<G5a@2UYJD0^[Zj0=7Ad@2f][H0f=SH0;bl_0020=kNgP070<71`@2j^[X0c<c<0;jn_P32`/80
`l?30<W9b@020<_;b`070<?3``2OWil0`/;20<o?c`2_[jl0a<C40;2`/0030<30`0060<?3``3:b/X0
d=3@0;jn_P3Fe]H0`l?30P2j^[X01`2_[jl0^;Rh0<;2`P32`/80bl_;0;:b/P2n_[h00P3Fe]H01`3?
cll0alO70;Zj^P2i^KT0_;bl0;fm_@3>c/h00P32`/801`2WYjL0b/[:0<_;b`32`/80aLG50=7Ad@3J
f]X00P3?cll0102d];@0alO70=OGe`3Fe]HT0?oooe@0X3oo0P3o000:0:0oo`0307ooo`2P?ol0X3oo
02d0X3oo9`3oool002D0oooo00<0aLG50<O7a`31`L400P2m_Kd01`3:b/X0clo?0;Vi^@33`l<0dm?C
0<30`02][Jd00`2i^KT01P2_[jl0`/;20;jn_P3>c/h0`l?30<G5a@80alO700L0`l?30;Vi^@2VYZH0
_[jn0<_;b`37alL0`<3000<0alO700H0_Kfm0<c<c035aLD0_;bl0;Rh^035aLD20<_;b`070;bl_033
`l<0alO70<W9b@33`l<0][Jf0<W9b@020<[:bP070;bl_022PX80dM7A0:>SX`2_[jl0_kno0<?3``02
0;jn_P070<O7a`35aLD0`<300<?3``2j^[X0clo?0:VYZ@020<;2`P070:^[Z`3=cLd0/;2`0<30`033
`l<0/;2`0;bl_0020;2`/0070<;2`P3=cLd0Xj>S0=7Ad@32`/80aLG50<?3``020:^[Z`070;Ng]`2]
[Jd0`<300<[:bP38b<P0eMGE0=?Cd`020<W9b@070<G5a@3=cLd0_[jn0;Fe]@35aLD0]kNg0<30`003
0<?3``060<30`03EeMD0`<300<c<c02k^k/0alO70P2l_;`01`2f][H0alO70<G5a@3:b/X0`/;20=WI
f@3<c<`00P3Hf=P01`3=cLd0dm?C0;Jf]P37alL0^[Zj0<O7a`39bLT00P2j^[X01P37alL0c<c<0:n_
[`2g]kL0hN7Q0=oOg`@0clo?00<0`L710<O7a`34a<@0903ooolc0:0oo`0307ooo`2P?ol0Oooo01T0
X3oo00<0Oooo0:0oo`2P?ol0=@2P?ol20?l000L0X3oo9`3oool002D0oooo00<0`l?30<c<c035aLD0
0P3<c<`01`2n_[h0][Jf0;fm_@39bLT0dM7A0;jn_P36a/H00P2o_kl01`2m_Kd0^KVi0;^k^`39bLT0
/;2`0;bl_03>c/h00P2f][H01`31`L40_[jn0<O7a`2j^[X0_;bl0<;2`P2[Zj/00`35aLD01P33`l<0
clo?0<_;b`2b/[80alO70<71`@80alO700L0Zj^[0;Bd]03WinL0clo?0<_;b`3@d=00f=SH0080gmoO
00L0hN7Q0<O7a`39bLT0/;2`0<g=c@39bLT0clo?0080f=SH00L0`L710;Jf]P2n_[h0`l?30;Jf]P37
alL0b/[:0080_;bl00L0_[jn0;Vi^@2g]kL0ZJVY0;bl_02b/[80/;2`0080`l?300L0f][J0<;2`P2S
Xj<0ZJVY0:6QX@2h^;P0alO70080^k^k00L0_[jn0<O7a`37alL0bl_;0;Rh^02[Zj/0`<300080bLW9
00D0`l?30;jn_P3>c/h0`/;20:j^[P020<?3``80_;bl00H0aLG50<?3``33`l<0^[Zj0<G5a@39bLT3
0<O7a`070;no_`32`/80bl_;0>OWi`30`<00dm?C0<_;b`020;jn_P070<_;b`2`/;00alO70<o?c`30
`<00`/;20<?3``020;Vi^@070>GUi@39bLT0_Kfm0:^[Z`22PX80^[Zj0<W9b@020<O7a`040<;2`P33
`l<0eMGE0<W9bB@0oooo:`2P?ol00`3o0000X3oo0:0oo`020:0oo`<0o`00702P?ol00`1oool0X3oo
07ooo`0R0:0oo`030?l0002P?ol0X3oo00`0X3oo00D0o`000:0oo`2P?ol0X3oo07ooo`080:0oobL0
oooo000U0?ooo`030;jn_P2m_Kd0`L710080]kNg00L0Zj^[0;Ng]`35aLD0d];B0=?Cd`2g]kL0]KFe
0080^;Rh0P37alL01@38b<P0aLG50=SHf03Lg=`0d=3@0080/;2`00L0cLg=0;bl_02h^;P0aLG50<?3
``2m_Kd0clo?0080alO700L0^;Rh0<30`02`/;00`/;20;jn_P3;bl/0alO70080d=3@00L0clo?0<?3
``3<c<`0j^[Z0<30`03@d=00/;2`0080clo?00L0dM7A0;bl_02d];@0bl_;0:ZZZP2`/;00f][J0080
`L7100L0^KVi0;Bd]039bLT0^[Zj0<c<c02g]kL0VYZJ0080bLW900L0];Bd0;jn_P3;bl/0bl_;0:^[
Z`2m_Kd0^k^k0080_[jn00L0bLW90;Vi^@2l_;`0];Bd0=CDe02h^;P0alO70080_;bl00D0`/;20<30
`02f][H0_;bl0;jn_P020<?3``80`/;20P2`/;001@3Cdm<0]KFe0:RXZ02^[Zh0`l?300<0`<3000H0
[Jf]0;Jf]P30`<00dm?C0=GEe@2n_[h20<O7a`070;Jf]P2o_kl0/k>c0<;2`P2`/;00fMWI02LW9`02
0<k>cP070;^k^`2i^KT0dm?C0<W9b@3;bl/0Xj>S0<?3``020;Zj^P070;Ng]`2WYjL0b/[:0;:b/P33
`l<0d=3@0=[JfP020<G5a@040=7Ad@3Bd]80bLW90<G5aB@0oooo;02P?ol00`3o0000X3oo0:0oo`0B
0:0oo`0307ooo`2P?ol0X3oo03<0X3oo00<0oooo0:0oo`2P?ol01@2P?ol00`1oool0X3oo0:0oo`0>
0:0oobL0oooo000U0?ooo`030;fm_@2k^k/0a/K60080aLG500L0alO70;Jf]P3AdM40/k>c0<?3``2o
_kl0c/k>0080c<c<00L0^k^k0<71`@30`<00/;2`0<30`03>c/h0]KFe0080]kNg00L0`/;20<K6aP36
a/H0_Kfm0<G5a@39bLT0^[Zj0080_[jn00L0_kno0;Jf]P33`l<0_;bl0=?Cd`39bLT0cLg=0080bl_;
00L0`/;20?Ogm`30`<00];Bd0<G5a@33`l<0_;bl0080Xj>S00H0f][J0;Rh^03IfMT0b<S8096AT@3>
c/h30;^k^`070<?3``2h^;P0_kno0<W9b@2g]kL0^k^k0<71`@020;^k^`070=CDe02`/;00alO70;Jf
]P2j^[X0][Jf0<;2`P0209nOW`07079bLP2OWil0[Jf]0<g=c@3WinL0c/k>0;^k^`020;Bd]080`<30
00D0f][J0<G5a@3Fe]H0f][J0<71`@020;Bd]0070;Rh^02b/[80[Jf]0;jn_P2i^KT0_;bl0;Bd]002
0<?3``040;jn_P31`L40alO70<[:bP80`l?300H0^KVi0<?3``33`l<0_[jn0<G5a@3;bl/30<G5a@0:
0:>SX`3;bl/0bl_;0<g=c@31`L40ZJVY0<W9b@32`/80dm?C0<G5a@80];Bd00L0f][J0;fm_@3Rh^80
h>3P0<O7a`3MgMd0`l?300@0d=3@00<0alO70>;RhP3oool08`3ooolZ0:0oo`030?l0002P?ol0X3oo
00<0X3oo0P1oool40:0oo`0307ooo`2P?ol0X3oo0180X3oo101oool20:0oo`030?l0002P?ol0X3oo
02<0X3oo00<0Oooo0:0oo`2P?ol02`2P?ol20?l000030:0oo`3o0000X3oo00D0X3oo00<0o`000?oo
o`3oool09@3oool002D0oooo00<0^KVi0<k>cP31`L400P2h^;P01`2c/k<0c<c<0=?Cd`2k^k/0`L71
0<?3``2/[:`00P3>c/h01`37alL0`l?30;Jf]P2o_kl0b/[:0;jn_P2_[jl00P2o_kl01`2i^KT0`l?3
0;Vi^@30`<00`/;20;jn_P2l_;`01035aLD01@3AdM40c<c<0<o?c`39bLT0a/K60080alO700L0][Jf
0;2`/02f][H0`<300<G5a@33`l<0YZJV0080e]KF00L0`<3009>CT`31`L40][Jf0:f][@3;bl/0]kNg
0080aLG500@0_Kfm0<c<c03:b/X0f][J0P2f][H01`37alL0`l?30<?3``37alL0Z:RX0<G5a@2o_kl0
0P2f][H02P2b/[80][Jf0;Jf]P32`/80aLG50=WIf@2QXJ40UIFE0:j^[P31`L420;^k^`040;Jf]P31
`L40^[Zj0<G5a@80_Kfm00H0cLg=0<K6aP36a/H0aLG50;bl_032`/820;jn_P0;0:n_[`2d];@0bLW9
0<W9b@2UYJD0[Jf]0<g=c@33`l<0b/[:0;^k^`3Cdm<00P37alL01`39bLT0_Kfm0=_Kf`3GemL0dM7A
0:f][@3;bl/00P33`l<01`32`/80_[jn0;bl_02l_;`0dm?C0<[:bP2k^k/00P2[Zj/01`2d];@0^KVi
0=7Ad@2[Zj/0`<300=KFeP3?cll00P3Cdm<01035aLD0e]KF0<k>cP2j^[XT0?oooc<0X3oo00<0Oooo
0:0oo`2P?ol06P2P?ol207oooch0X3oo9`3oool002D0oooo00<0[Jf]0=3@d035aLD00P2n_[h01`2c
/k<0bLW90;jn_P31`L40`/;20;Jf]P39bLT00P3Bd]801`39bLT0_;bl0;bl_02f][H0`l?30;jn_P39
bLT00P2f][H0102^[Zh0`L710;Bd]032`/820<K6aP0:0;bl_038b<P0b<S80;jn_P30`<00cLg=0<?3
``39bLT0`/;20<30`0<0dm?C00H0^k^k0:^[Z`2h^;P0clo?092@T039bLT209jNWP070;Rh^02/[:`0
d=3@0=;BdP2f][H0dM7A0;6a/@020;Jf]P070;fm_@3MgMd0`l?30;fm_@2TY:@0`L710;2`/0020;Bd
]0070<?3``2n_[h0_;bl0;Zj^P2f][H0/;2`0<G5a@020<W9b@070<O7a`2g]kL0`/;20<W9b@2l_;`0
aLG50;:b/P020<30`0070;no_`2f][H0_;bl0;Rh^02o_kl0UIFE0<W9b@020<_;b`070<?3``3AdM40
_[jn0<G5a@2l_;`0`/;20;jn_P020<_;b`070<?3``37alL0_[jn0<?3``3>c/h0c<c<0=KFeP020<_;
b`070:f][@3EeMD0alO70;^k^`38b<P0`/;20;Bd]0020;bl_0070<c<c02m_Kd0aLG50=SHf037alL0
e]KF0=gMg@020=7Ad@070;bl_02f][H0c<c<0<k>cP3Ogml0f=SH0<W9b@020<?3``040=7Ad@2VYZH0
];Bd0<_;bb@0oooo;P2P?ol0101oool0X3oo07ooo`1oool:0:0oo`040?l0002P?ol0X3oo07oooa/0
X3oo00<0Oooo0:0oo`2P?ol08P2P?ol00`3o0000X3oo0:0oo`040:0oo`030?l0002P?ol0X3oo00H0
X3oo9`3oool002D0oooo00<0^k^k0;Bd]02c/k<00P2`/;001`2f][H0`L710;Vi^@35aLD0`l?30<g=
c@2`/;000P3@d=001`31`L40bLW90<O7a`2l_;`0`l?30;bl_02][Jd00P2f][H01`37alL0a/K60<O7
a`31`L40`l?30=3@d02l_;`00P2d];@01`2m_Kd0c/k>0=3@d02l_;`0];Bd0<30`03Cdm<00P3<c<`0
1@32`/80_[jn0<O7a`2f][H0`/;20080^[Zj0P2i^KT01`3Hf=P0alO70<c<c039bLT0cLg=0<;2`P2h
^;P00P32`/801`3Fe]H0_[jn0<W9b@3=cLd0];Bd0;bl_033`l<00P2n_[h01`35aLD0_kno0<G5a@3H
f=P0_[jn0;2`/02EUID00P2OWil01`3De=@0][Jf0;bl_039bLT0dM7A0;Rh^030`<000P32`/801`35
aLD0`<300<;2`P33`l<0bl_;0=;BdP2SXj<00P3?cll01`39bLT0_[jn0<;2`P33`l<0^;Rh0<o?c`3H
f=P00P37alL01`30`<00cLg=0=7Ad@38b<P0[jn_0;2`/02l_;`00P35aLD01`2d];@0c<c<0<30`03>
c/h0`/;20:BTY03Cdm<00P2a/K401`2n_[h0f][J0=SHf03=cLd0bLW90<G5a@3=cLd00P2n_[h01`2l
_;`0alO70<?3``2g]kL0Ti>C0;jn_P32`/800P2j^[X00`3EeMD0c<c<0:>SX`0U0?ooodX0X3oo0`1o
ool?0:0oo`0307ooo`2P?ol0X3oo01L0X3oo00<0Oooo0:0oo`2P?ol03P2P?ol00`1oool0X3oo0:0o
o`040:0oo`0307ooo`3o0000oooo02H0oooo000U0?ooo`030=7Ad@2?Shl0`<300080b/[:00H0^KVi
0;jn_P37alL0`<300;Jf]P33`l<30;Ng]`070<?3``2m_Kd0`l?30;no_`2k^k/0]KFe0<W9b@020<g=
c@070<G5a@2WYjL0alO70;^k^`31`L40`l?30<[:bP020;no_`0409jNWP37alL0`l?30<G5a@80alO7
00X0aLG50=?Cd`3Cdm<0][Jf0<_;b`2BTY80`L710;no_`3@d=00c/k>0P3Cdm<01`3=cLd0YjNW0<?3
``1gMgL0cLg=0<W9b@30`<000P2j^[X01@2d];@0alO70<W9b@3Jf]X0bl_;0080`l?30P2j^[X01`2c
/k<0`/;20;bl_02i^KT0]kNg0;6a/@2n_[h00P35aLD01`2l_;`0_[jn0<O7a`30`<00bl_;0;Bd]02k
^k/00P30`<001`3<c<`0_Kfm0<S8b03Hf=P0d];B0<[:bP2d];@00P3Hf=P01`2l_;`0`<300;Bd]033
`l<0^k^k0;>c/`2][Jd00P2[Zj/01`2b/[80clo?0;jn_P33`l<0d=3@0=[JfP3AdM400P37alL00`3;
bl/0`l?30<G5a@020;Jf]P0;0;jn_P3?cll0][Jf0;Jf]P39bLT0b/[:0=SHf02b/[80bl_;0<G5a@3F
e]H00P3?cll01`21PH40_Kfm0<?3``32`/80cLg=0;Jf]P2h^;P00P3@d=00102l_;`0`l?30<S8b02L
W9`T0?ooo`030:0oo`1oool0X3oo01d0X3oo00<0Oooo0:0oo`2P?ol0202P?ol00`1oool0X3oo0:0o
o`070:0oo`0307ooo`2P?ol0X3oo04/0X3oo00<0Oooo0:0oo`2P?ol02@2P?ol00`1oool0oooo0?oo
o`0U0?ooo`009@3oool00`3AdM40Shn?0<30`0020<[:bP060;Vi^@2n_[h0alO70<30`02f][H0`l?3
0`2g]kL01`33`l<0_Kfm0<?3``2o_kl0^k^k0;Fe]@39bLT00P3=cLd01`35aLD0YjNW0<O7a`2k^k/0
`L710<?3``3:b/X00P2o_kl0102NWYh0alO70<?3``35aLD20<O7a`0:0<G5a@3Cdm<0dm?C0;Jf]P3;
bl/0TY:B0<71`@2o_kl0d=3@0<k>cP80dm?C00L0cLg=0:NWY`33`l<0MgMg0<g=c@39bLT0`<300080
^[Zj00D0];Bd0<O7a`39bLT0f][J0<_;b`020<?3``80^[Zj00L0/k>c0<;2`P2l_;`0^KVi0;Ng]`2a
/K40_[jn0080aLG500L0_;bl0;jn_P37alL0`<300<_;b`2d];@0^k^k0080`<3000L0c<c<0;fm_@38
b<P0f=SH0=;BdP3:b/X0];Bd0080f=SH00L0_;bl0<30`02d];@0`l?30;^k^`2c/k<0[Jf]0080Zj^[
00L0/[:b0<o?c`2n_[h0`l?30=3@d03Jf]X0dM7A0080alO700<0bl_;0<?3``35aLD00P2f][H02`2n
_[h0clo?0;Jf]P2f][H0bLW90<[:bP3Hf=P0/[:b0<_;b`35aLD0e]KF0080clo?00L0PH610;fm_@33
`l<0`/;20<g=c@2f][H0^;Rh0080d=3@00@0_;bl0<?3``38b<P0W9bL903oool00`2P?ol0Oooo0:0o
o`0M0:0oo`0307ooo`2P?ol0X3oo00P0X3oo00<0Oooo0:0oo`2P?ol01`2P?ol00`1oool0X3oo0:0o
o`1;0:0oo`0307ooo`2P?ol0X3oo00T0X3oo00<0Oooo0?ooo`3oool09@3oool002D0oooo00<0aLG5
0<c<c039bLT00P2l_;`01`2n_[h0^;Rh0<G5a@37alL0aLG50;Ng]`2YZJT00P2d];@01`2o_kl0];Bd
0<30`033`l<0d=3@0;Jf]P3?cll00P2d];@01032`/80_;bl0<o?c`35aLD20;bl_0<0alO700L0Y:BT
0;^k^`37alL0bLW90<G5a@37alL0bl_;0080f][J00@0`<300=GEe@2l_;`0e=CD0P2l_;`02P3Cdm<0
aLG50<G5a@33`l<0[Zj^0<O7a`39bLT0][Jf0<g=c@3?cll20:j^[P070;fm_@3?cll0eMGE0:f][@2l
_;`0`<300;Bd]0020:n_[`070;Ng]`2b/[80^;Rh0;:b/P1@D500/[:b0;Jf]P020<?3``070<c<c02c
/k<0/k>c0;6a/@30`<00^;Rh0;jn_P020>KViP070:NWY`32`/80]kNg0;^k^`2`/;00`<300<?3``02
0;jn_P070<G5a@33`l<0a/K60<W9b@36a/H0^[Zj0<W9b@020:n_[`070;jn_P2`/;00[Jf]0:FUY@30
`<00][Jf0<30`0020<W9b@070:n_[`39bLT0alO70<k>cP3Cdm<0^KVi0<71`@020=CDe0070<g=c@37
alL0`L710=7Ad@2_[jl0dm?C0;Zj^P020;Jf]P070<W9b@3?cll0];Bd09bLW033`l<0e]KF0<?3``02
0;Fe]@040=SHf02SXj<0_;bl0:b/[2@0oooo802P?ol00`1oool0X3oo0:0oo`0U0:0oo`030>3o`02P
?ol0X3oo00T0X3oo0P3o000`0:0oo`0307ooo`2P?ol0X3oo00@0X3oo00<0Oooo0:0oo`2P?ol09`3o
ool002D0oooo00<0_Kfm0<;2`P30`<000P2d];@01P2e]KD0`L710;Vi^@3=cLd0bl_;0<o?c`<0bLW9
0P35aLD01033`l<0cLg=0=CDe02k^k/30;Jf]P070=3@d030`<00`/;20<;2`P35aLD0_;bl0;no_`02
0<k>cP070<G5a@30`<00_[jn0<G5a@3;bl/0^;Rh0=7Ad@020<W9b@070;Jf]P2m_Kd0^[Zj0;jn_P2d
];@0bLW90<;2`P020;bl_00709jNWP2n_[h0RXZ:0=3@d02j^[X0bl_;0;fm_@020<[:bP060<G5a@2b
/[80`/;20;Jf]P2l_;`0XJ6Q0`2k^k/01`2m_Kd0]kNg0<?3``2g]kL0Vi^K0;Rh^03EeMD00P2VYZH0
1`33`l<0c<c<0;fm_@2TY:@0]kNg0=gMg@2b/[800P33`l<00`3Fe]H0ZJVY0;Rh^0020;Bd]00;0=SH
f039bLT0YJFU0:FUY@3=cLd0emOG0:n_[`3Bd]80Ti>C0<30`02i^KT00P37alL01`2l_;`0clo?0;Rh
^02l_;`0`L710=;BdP3dm?@00P35aLD01`2i^KT0_kno0<k>cP3AdM40_[jn0=?Cd`2`/;000P2m_Kd0
1`37alL0bLW90<?3``3?cll0emOG0;Jf]P3Jf]X00P2SXj<01`3;bl/0cLg=0<[:bP35aLD0[:b/0<O7
a`3Fe]H00P3EeMD01036a/H0ATI60;:b/P3?cllT0?oooc80X3oo00<0Oooo0:0oo`1oool02`2P?ol0
0`1oool0X3oo0:0oo`050:0oo`0307ooo`2P?ol0X3oo00D0X3oo00<0Oooo0:0oo`3o0000402P?ol0
0`1oool0X3oo0:0oo`080:0oo`030?l0002P?ol0X3oo0100X3oo0P1oool:0:0oo`030>3o`02P?ol0
X3oo02L0oooo000U0?ooo`030=CDe02o_kl0/[:b0080i>CT00L0^KVi0<[:bP2m_Kd0aLG50<71`@3:
b/X0alO700<0`l?300H0b/[:0<71`@31`L40alO70<W9b@30`<020;:b/P070<W9b@37alL0c/k>0<[:
bP2h^;P0_kno0<;2`P020<o?c`070;jn_P30`<00bLW90<_;b`2n_[h0_;bl0<_;b`020<?3``030<G5
a@3De=@0/[:b0080^[Zj00/0dM7A0;Jf]P30`<00`<300<g=c@2j^[X0bLW90<[:bP2][Jd0bLW90<G5
a@020;Bd]0070<c<c035aLD0_;bl0;Zj^P2NWYh0Xj>S0:n_[`020<?3``070<O7a`2h^;P0^[Zj0;6a
/@2ZZZX0[Jf]0;Bd]0020<O7a`070<G5a@32`/80clo?0:f][@3IfMT0`L710<[:bP020<c<c0060=3@
d02k^k/0f=SH0<_;b`3AdM40_kno0`3Hf=P01`3;bl/0c<c<0<k>cP32`/80c/k>0;jn_P37alL00P3F
e]H01032`/80];Bd0<G5a@3=cLd20<O7a`0:0;no_`35aLD0aLG50<O7a`3>c/h0gMgM0<71`@2k^k/0
/;2`0<71`@80^KVi00L0d=3@0:^[Z`39bLT0a<C40;Fe]@3=cLd0_[jn0080bLW900L0`L710=7Ad@2l
_;`0^[Zj0;>c/`2l_;`0alO70080/k>c00@0H61P07emO@38b<P0aLG5903oool30:0oo`80o`00>P2P
?ol207oooc80X3oo00<0o`000:0oo`2P?ol05P2P?ol0103Pol00Oooo0:0oo`2P?olW0?ooo`009@3o
ool00`2l_;`0_Kfm0;Ng]`020;jn_P070<30`03:b/X0];Bd0;>c/`2l_;`0c<c<0;Vi^@020;bl_007
0<k>cP2k^k/0^k^k0=GEe@3De=@0bLW90;2`/0030;Rh^0060<o?c`34a<@0`/;20<G5a@30`<00_kno
0P33`l<01`3<c<`0^k^k0<[:bP3Cdm<0^[Zj0;fm_@3Cdm<00P3;bl/01`2o_kl0XJ6Q0<W9b@3<c<`0
^KVi0<g=c@33`l<00P37alL01P3@d=00bLW90<[:bP2WYjL0][Jf0<o?c`<0`/;200L0/;2`0<30`033
`l<0_[jn0;Rh^02j^[X0/[:b00<0_;bl00H0][Jf0;2`/032`/80c/k>0:6QX@30`<020;Zj^P070<W9
b@2n_[h0`l?30=7Ad@33`l<0_Kfm0=CDe0020:ZZZP070<?3``3Hf=P0/;2`0;Jf]P3Cdm<0dM7A0;bl
_0020=?Cd`070;jn_P2SXj<0b<S80<K6aP2_[jl0/;2`0;Zj^P020;bl_0070<?3``2l_;`0bLW90=[J
fP3Cdm<0bLW90=CDe0020;Ng]`060<K6aP2f][H0bLW90<?3``32`/80]kNg0`2d];@01`2l_;`0dM7A
0<;2`P3:b/X0b<S80:NWY`33`l<00P3@d=001P3Fe]H0_Kfm0:^[Z`2`/;00^KVi0=GEe@<0]kNg00@0
`<300;Bd]02n_[h0`/;2903ooolZ0:0oo`0307ooo`2P?ol0X3oo01`0X3oo00<0Oooo0:0oo`2P?ol0
502P?ol00`1oool0X3oo0:0oo`0]0:0oobL0oooo000U0?ooo`030;Jf]P30`<00b<S80080_[jn00L0
^KVi0<;2`P34a<@0^KVi0<K6aP3Cdm<0a<C40080eMGE00<0b/[:0<30`038b<P00P3>c/h20<30`080
aLG500H0_Kfm0<O7a`2g]kL0aLG50;^k^`33`l<30;bl_0070<W9b@2m_Kd0/[:b0<_;b`37alL0clo?
0<O7a`020<K6aP070=7Ad@2h^;P0dm?C0;Jf]P30`<00b/[:0:BTY0020<71`@070;6a/@2e]KD0b/[:
0<;2`P2b/[80ZJVY09BDU0020;bl_0030:n_[`2UYJD0][Jf0080_;bl00/0`l?30;jn_P2DU9@0U9BD
0<W9b@3?cll0^;Rh0;:b/P2f][H0/[:b0<?3``020<W9b@070;Bd]037alL0bl_;0;:b/P2d];@0_Kfm
0=?Cd`020=KFeP070;>c/`2n_[h0aLG50;Rh^037alL0_;bl0<[:bP020<O7a`070;jn_P2d];@0/;2`
0:n_[`3Ti>@0`l?30;bl_00209bLW0070<g=c@2/[:`0a<C40=SHf035aLD0WYjN0<S8b0020<W9b@07
0;bl_032`/80alO70;Rh^02YZJT0^[Zj0;Fe]@020;^k^`070<W9b@3Fe]H0/[:b0;^k^`3;bl/0O7al
0<;2`P020=CDe080^;Rh00D0cLg=0<30`02h^;P0_[jn0;bl_0020<o?c`040<_;b`2h^;P0`l?30;:b
/R@0oooo;`2P?ol00`1oool0X3oo0:0oo`060:0oo`0307ooo`2P?ol0X3oo00L0X3oo0P1ooolO0:0o
o`030?l0002P?ol0X3oo0080Oooo1@2P?ol00`1oool0X3oo0:0oo`0?0:0oo`0307ooo`2P?ol0X3oo
00h0X3oo9`3oool002D0oooo00<0][Jf0:f][@36a/H00P2_[jl01`35aLD0alO70:JVYP37alL0bLW9
0<;2`P33`l<00P3@d=001`3:b/X0_[jn0<c<c03:b/X0`<300:b/[03?cll00P36a/H00`2l_;`0^k^k
0;fm_@030<?3``0:0;Vi^@2f][H0][Jf0<O7a`2g]kL0^[Zj0<30`02i^KT0`<300<W9b@80bl_;00L0
c/k>0;Zj^P38b<P0a<C40;bl_03Hf=P0`l?30080a/K600<0]kNg0<k>cP3De=@00P2l_;`02`30`<00
clo?0<_;b`3;bl/0_[jn0;Vi^@2n_[h0alO70;Zj^P35aLD0bLW90080b/[:00L0`L710;bl_030`<00
e]KF0<;2`P2`/;00[:b/0080];Bd00L0alO70<W9b@2j^[X0`/;20;Zj^P3>c/h0b<S80080^k^k00L0
/;2`0<?3``30`<00clo?0=7Ad@35aLD0^k^k0080bl_;00D0alO70;Jf]P2j^[X0g]kN0:f][@020;Rh
^080b<S800L0e]KF0<W9b@2e]KD0alO70<S8b032`/80bLW90080aLG500L0bl_;0<o?c`2k^k/0alO7
0<W9b@3;bl/0e=CD0080_kno00L0f=SH0;jn_P2`/;00aLG50<O7a`3>c/h0e]KF0080h^;R00L0bLW9
0=KFeP35aLD0e]KF0;Bd]02ZZZX0b<S80080aLG500@0`/;20<W9b@33`l<0`l?3903ooomR0:0oo`03
0?l0002P?ol0X3oo01`0X3oo0P3o000=0:0oobL0oooo000U0?ooo`030<71`@36a/H0a<C40080`/;2
00L0]KFe0;bl_02f][H0bLW90<?3``2`/;00]kNg0080`L710P32`/801@2m_Kd0`<300<;2`P3<c<`0
_[jn0080bLW900L0Y:BT0<?3``39bLT0a/K60;Ng]`3AdM40`/;20080]kNg00L0aLG50<71`@35aLD0
_kno0;bl_031`L40a<C40080dm?C00L0bl_;0<G5a@2[Zj/0`/;20;:b/P32`/80][Jf0080`<3000L0
[jn_0<C4a02g]kL0`l?30;Vi^@2f][H0_Kfm0080c/k>00L0`l?30;2`/03?cll0/[:b0;Jf]P2n_[h0
`/;20080_[jn00L0dM7A0:ZZZP37alL0c<c<0<?3``26QXH0^KVi0080]kNg00D0[Jf]0;Vi^@2RXZ80
c<c<0;no_`020;Zj^P80YJFU00L0bLW90<O7a`2l_;`0cLg=0;bl_03Fe]H0[Jf]0080`<3000L0`l?3
0<;2`P2^[Zh0[jn_0:FUY@35aLD0_kno0080`/;200L0bLW90;Zj^P2IVIT0alO70<g=c@2QXJ40[Jf]
0080cLg=00L0d=3@0<?3``3Hf=P0`L710<G5a@3@d=00^;Rh0080dM7A00L0bl_;0=?Cd`33`l<0inOW
0<?3``2f][H0_[jn00<0c<c<00H0c/k>0;Rh^035aLD0dm?C0;Jf]P31`L420<W9b@040<g=c@2j^[X0
c<c<0;no_b@0oooo5`2P?ol00`1oool0X3oo0:0oo`0_0:0oo`0307ooo`2P?ol0X3oo00<0X3oo00<0
Oooo0:0oo`2P?ol0602P?ol0101oool0X3oo0:0oo`1oool?0:0oo`030?l0002P?ol0X3oo0100X3oo
9`3oool002D0oooo00<0^k^k0=OGe`3:b/X00P2n_[h01`2i^KT0a/K60<O7a`33`l<0cLg=0;^k^`2n
_[h00P2h^;P01`2XZ:P0^k^k0<G5a@2h^;P0b/[:0;Ng]`30`<000P2l_;`01`2n_[h0/[:b0;bl_032
`/80b<S80<K6aP35aLD00P3<c<`01`37alL0bLW90<O7a`2m_Kd0[Jf]0;Vi^@2g]kL00P30`<001`3>
c/h0`L7109FEU@39bLT0Vi^K0;jn_P32`/800P34a<@01`36a/H0c/k>0;:b/P2g]kL0alO70<?3``2k
^k/00P2ZZZX01`2QXJ40][Jf0;bl_030`<00WYjN0<C4a032`/800P31`L401`2j^[X0aLG50<?3``2i
^KT0^[Zj0<G5a@2k^k/00P3Cdm<01`35aLD0ZJVY0=?Cd`3=cLd0alO70;jn_P2f][H00P3;bl/01`2n
_[h0alO70<W9b@33`l<0eMGE0=?Cd`35aLD00P37alL01`35aLD0`<300;Zj^P2h^;P0aLG50;jn_P2j
^[X00P2l_;`01`34a<@0][Jf0;2`/02k^k/0WinO0;:b/P33`l<00P32`/801`2o_kl0aLG50=;BdP3E
eMD0bl_;08>3P`3Fe]H00P3AdM401`3:b/X0`l?30<C4a03=cLd0dM7A0:6QX@2f][H00P2PX:001`2Z
ZZX0_Kfm0;jn_P30`<00_[jn0<?3``2i^KT00P3AdM40102j^[X0aLG50<g=c@3Jf]XT0?ooob/0X3oo
00<0Oooo0:0oo`1oool03@2P?ol01@1oool0X3oo0:0oo`2P?ol0Oooo02`0X3oo00<0Oooo0:0oo`2P
?ol01`2P?ol00`1oool0X3oo0:0oo`060:0oo`0407ooo`2P?ol0Oooo07ooo`d0X3oo9`3oool002D0
oooo00<0^k^k0=OGe`3:b/X00P2n_[h01`2i^KT0a/K60<O7a`33`l<0cLg=0;^k^`2n_[h00P2h^;P0
1`2XZ:P0^k^k0<G5a@2h^;P0b/[:0;Ng]`30`<000P2l_;`01`2n_[h0/[:b0;bl_032`/80b<S80<K6
aP35aLD00P3<c<`01`37alL0bLW90<O7a`2m_Kd0[Jf]0;Vi^@2g]kL00P30`<001`3>c/h0`L7109FE
U@39bLT0Vi^K0;jn_P32`/800P34a<@01`36a/H0c/k>0;:b/P2g]kL0alO70<?3``2k^k/00P2ZZZX0
1`2QXJ40][Jf0;bl_030`<00WYjN0<C4a032`/800P31`L401`2j^[X0aLG50<?3``2i^KT0^[Zj0<G5
a@2k^k/00P3Cdm<01`35aLD0ZJVY0=?Cd`3=cLd0alO70;jn_P2f][H00P3;bl/01`2n_[h0alO70<W9
b@33`l<0eMGE0=?Cd`35aLD00P37alL01`35aLD0`<300;Zj^P2h^;P0aLG50;jn_P2j^[X00P2l_;`0
1`34a<@0][Jf0;2`/02k^k/0WinO0;:b/P33`l<00P32`/801`2o_kl0aLG50=;BdP3EeMD0bl_;08>3
P`3Fe]H00P3AdM401`3:b/X0`l?30<C4a03=cLd0dM7A0:6QX@2f][H00P2PX:001`2ZZZX0_Kfm0;jn
_P30`<00_[jn0<?3``2i^KT00P3AdM40102j^[X0aLG50<g=c@3Jf]XT0?ooob/0X3oo00<0Oooo0:0o
o`1oool03@2P?ol01@1oool0X3oo0:0oo`2P?ol0Oooo02`0X3oo00<0Oooo0:0oo`2P?ol01`2P?ol0
0`1oool0X3oo0:0oo`060:0oo`0407ooo`2P?ol0Oooo07ooo`d0X3oo9`3oool002D0oooo00<0^;Rh
0<[:bP2i^KT00P2i^KT01`37alL0_Kfm0<30`032`/80^;Rh0<?3``2n_[h00P2m_Kd01`2ZZZX0_[jn
0;>c/`2j^[X0[Jf]0;jn_P2f][H00P3AdM401`35aLD0dM7A0;2`/02f][H0`L710<k>cP2n_[h00P2j
^[X00`34a<@0`<300;>c/`020;jn_P0;0;>c/`3<c<`0c<c<0<c<c02i^KT0a/K60;^k^`3<c<`0fMWI
0<30`03Hf=P00P3AdM401`3Jf]X0`l?30:RXZ02k^k/0`l?30;Ng]`2i^KT00P2j^[X01`2`/;00^[Zj
0;:b/P2l_;`0_[jn0<G5a@2g]kL00P33`l<01`3:b/X0`l?30<;2`P34a<@0b/[:0<;2`P2SXj<00P2`
/;020<[:bP030:f][@3Bd]80_kno0080_;bl0P2n_[h01`3Fe]H0eMGE0;jn_P2n_[h0alO70<c<c02d
];@00P3?cll01`32`/80_;bl0;^k^`39bLT0OGem0;bl_02j^[X00P2l_;`01`39bLT0hN7Q0<[:bP3B
d]80_;bl0<G5a@33`l<00P3:b/X0102n_[h0dM7A0;no_`3Ph>020;Bd]0040<O7a`2_[jl0[jn_09bL
W0<0alO700<0_;bl0<W9b@3;bl/00P2n_[h01`2h^;P0`/;20<o?c`3?cll0_;bl0;Rh^033`l<00P2l
_;`01032`/80aLG50=cLg033`l<T0?ooodX0X3oo00<0Oooo0:0oo`2P?ol05P2P?ol00`1oool0X3oo
0:0oo`030:0oo`030?l0002P?ol0X3oo00P0X3oo00<0o`000:0oo`2P?ol00`2P?ol00`1oool0X3oo
0:0oo`0C0:0oobL0oooo000U0?ooo`030;6a/@36a/H0^k^k0080`<3000<0ZZZZ0<30`033`l<00P2n
_[h02`2g]kL0`<300;Vi^@2i^KT0a/K60;Zj^P3;bl/0];Bd0<S8b035aLD0alO70080^KVi00L0`l?3
0<O7a`3>c/h0b/[:0;bl_03@d=00aLG50080`l?300L0aLG50=;BdP37alL0_[jn0;Bd]033`l<0`<30
0080`/;200D0b<S80<k>cP32`/80^k^k0<S8b0020<30`080[jn_00L0/[:b0=7Ad@2PX:00P8200=7A
d@2[Zj/0]kNg0080/;2`00L0bLW90;2`/035aLD0b/[:0<K6aP38b<P0`L710080^KVi00H0_kno0;jn
_P3=cLd0]kNg0<G5a@37alL30<30`0070;Vi^@37alL0`l?30<G5a@30`<00_[jn0;Bd]0020;Zj^P07
0;Fe]@3;bl/0`l?30<W9b@2^[Zh0e=CD0<G5a@020;Vi^@070<K6aP30`<00_kno0;2`/037alL0_;bl
0;Zj^P020<[:bP070<o?c`2m_Kd0c<c<0<W9b@33`l<0aLG50<_;b`030<;2`P060;bl_02j^[X0dm?C
0<30`033`l<0_[jn0P35aLD01`3;bl/0QhN70<W9b@3Bd]80^KVi06a/K02k^k/00P30`<001`33`l<0
clo?0<[:bP24Q8@0/k>c0:VYZ@2f][H00P33`l<0103?cll0`l?30;Bd]03Cdm<T0?oooc@0X3oo0P1o
oom50:0oo`0507ooo`2P?ol0X3oo0:0oo`3Pol001P2P?ol00`1oool0X3oo0:0oo`070:0oobL0oooo
000U0?ooo`030<C4a02/[:`0aLG50080/[:b00L0c<c<0;Ng]`37alL0aLG50=7Ad@35aLD0_;bl0080
];Bd00D0`/;20;Vi^@31`L40^[Zj0<W9b@020;^k^`80][Jf00L0alO70;Jf]P3:b/X0^k^k0<71`@2m
_Kd0_[jn00<0b/[:00H0`/;20=?Cd`3=cLd0`<300=CDe03Bd]820<[:bP070<30`02n_[h0alO70<k>
cP2n_[h0bLW90=3@d0020<c<c0070:BTY03>c/h0[Jf]0;6a/@2`/;00[jn_0:f][@020;Zj^P070:n_
[`39bLT0ZZZZ0=7Ad@37alL0_Kfm0<;2`P020;jn_P070<G5a@3=cLd0c<c<0=KFeP3De=@0`l?30:j^
[P020;^k^`040;Jf]P37alL0_[jn0;Bd]080`l?300T0WinO0<?3``33`l<0aLG50;fm_@37alL0d];B
0<?3``3?cll00`32`/801034a<@0_kno0=7Ad@35aLD20;no_`0:0<?3``39bLT0bLW90<O7a`3Cdm<0
aLG50<_;b`2b/[80][Jf0<O7a`80d];B00L0`/;20<k>cP2o_kl0];Bd0;Rh^03;bl/0`l?30080bLW9
0P3<c<`01@34a<@0b<S80<c<c032`/80eMGE0080dM7A00L0clo?0;fm_@3;bl/0bLW90;2`/03jn_X0
^KVi0080`l?300@0d=3@0<71`@38b<P0]KFe903ooolb0:0oo`0307ooo`2P?ol0X3oo01h0X3oo00<0
Oooo0:0oo`2P?ol0<P2P?ol00`3o0000X3oo0:0oo`050:0oobL0oooo000U0?ooo`030<W9b@2g]kL0
^KVi0080^k^k00L0_[jn0<K6aP38b<P0a<C40;no_`35aLD0_kno0080^[Zj00L0_[jn0:RXZ02i^KT0
_Kfm0<;2`P2a/K40ZJVY0080^;Rh00L0d=3@0;Rh^030`<00`L710;Jf]P35aLD0YJFU0080_[jn00L0
bLW90;>c/`32`/80bLW90;Jf]P32`/80bLW90080c/k>00L0`L710;no_`3EeMD0_;bl0;Zj^P32`/80
^k^k0080_;bl00L0QhN70;no_`2n_[h0/K6a0:n_[`30`<00g=cL0080aLG500L0_;bl0<O7a`32`/80
[jn_0;Bd]02g]kL0^;Rh0080`/;200L0eMGE0<_;b`2i^KT0aLG50:n_[`2JVYX0Z:RX0080_;bl00L0
/[:b0;jn_P2ZZZX0cLg=0<?3``2d];@0aLG50080Zj^[00L0bLW90;:b/P2k^k/0i>CT0;bl_03EeMD0
]kNg0080Xj>S00L0/[:b0;bl_03Vi^H0aLG50<o?c`3Fe]H0`<300080dm?C00@0];Bd0;Rh^033`l<0
dM7A0P2f][H02@37alL0e]KF0=KFeP3Kfm/0c/k>0<[:bP34a<@0_[jn0<k>cP030<_;b`050>;RhP3>
c/h0c/k>0;jn_P30`<000P3;bl/20;Jf]P070<[:bP39bLT0cLg=0;2`/039bLT0];Bd0<?3``020<O7
a`040<[:bP33`l<0bl_;0<_;bb@0oooo<P2P?ol00`1oool0X3oo0:0oo`0D0:0oo`0307ooo`2P?ol0
X3oo00d0X3oo00@0o`000:0oo`2P?ol0X3oo0P1oool20:0oo`030?l0002P?ol0X3oo01H0X3oo00<0
o`000:0oo`2P?ol04`2P?olW0?ooo`009@3oool20;Jf]P0:0;:b/P3<c<`0c<c<0<K6aP34a<@0`<30
0;Vi^@31`L40aLG50;^k^`<0_[jn00H0b/[:0:j^[P2g]kL0^KVi0;bl_02g]kL20;Jf]P070;Bd]02j
^[X0_;bl0<O7a`39bLT0^KVi0;Bd]0020<[:bP070;Vi^@2PX:00aLG50;Ng]`2n_[h0b/[:0<_;b`02
0<G5a@070<?3``3=cLd0aLG50;Vi^@2f][H0aLG50<k>cP020:j^[P070;:b/P3;bl/0^KVi0;Ng]`33
`l<0c<c<0<W9b@020<k>cP070<[:bP37alL0`<300:FUY@2f][H0alO70=[JfP020=7Ad@070;jn_P2i
^KT0bl_;0:RXZ02YZJT0ZZZZ09FEU@020:NWY`070;Vi^@2d];@0`l?30:f][@3?cll0alO70<_;b`02
0=7Ad@070;Jf]P2h^;P0YJFU0<71`@3Jf]X0ZZZZ0<30`0020<G5a@060<W9b@2n_[h0`l?30<O7a`2e
]KD0a<C40`3:b/X01`37alL0_[jn0;>c/`2l_;`0]kNg0<[:bP2`/;000P2TY:@01`37alL0`L710<?3
``3AdM40`l?30;bl_032`/800P3Fe]H01`35aLD0bLW90<c<c03:b/X0`l?30;Jf]P3Fe]H00P2f][H0
1`2][Jd0_Kfm0<W9b@3AdM40_;bl0<_;b`37alL00P32`/801037alL0`<300=7Ad@33`l<T0?ooob40
X3oo00<0Oooo0:0oo`2P?ol09P2P?ol00`1oool0X3oo0:0oo`0R0:0oo`80Oooo7`2P?olW0?ooo`00
9@3oool00`2e]KD0bLW90;Bd]0030;no_`050=gMg@3:b/X0^k^k0<_;b`2l_;`00`32`/801`33`l<0
`<300<S8b037alL0_[jn0;bl_036a/H00P34a<@01`2a/K40a/K60;jn_P3Cdm<0`l?30<C4a039bLT0
0P32`/801`3@d=00`L710;no_`35aLD0_;bl0<;2`P34a<@00P3>c/h01`35aLD0`/;20<k>cP2a/K40
_[jn0<g=c@30`<000P2o_kl01`2f][H0ZZZZ0<g=c@31`L40[Zj^0;>c/`30`<000P2g]kL01`2`/;00
][Jf0;Bd]02SXj<0c<c<0<[:bP3;bl/00P2h^;P01029RHT0/[:b0<30`03=cLd20;Bd]0060;Jf]P2m
_Kd0_Kfm0;2`/02j^[X0aLG50P39bLT02`2j^[X0`l?30;:b/P2b/[80_Kfm0;Ng]`39bLT0d=3@0;Vi
^@33`l<0`<300080f][J00L0b/[:0;jn_P2m_Kd0e]KF0;^k^`35aLD0[Jf]0080bLW900L0`<300=KF
eP3;bl/0hN7Q0<W9b@37alL0c<c<0080e=CD00L0c<c<0=7Ad@3:b/X0bl_;0<G5a@3Fe]H0clo?0080
aLG500L0e]KF0;no_`3MgMd0dM7A0=CDe037alL0hN7Q0080_Kfm00L0c/k>0;^k^`39bLT0];Bd08Z:
RP2f][H0a/K60080`<3000@0`/;20<O7a`3Hf=P0_Kfm903oool60:0oo`030?l0002P?ol0X3oo03D0
X3oo00<0Oooo0:0oo`2P?ol00`2P?ol00`1oool0X3oo0:0oo`0T0:0oo`030?l0002P?ol0X3oo00h0
X3oo00D0o`000:0oo`2P?ol0X3oo0?l000060:0oo`0307ooo`2P?ol0X3oo00H0X3oo9`3oool002D0
oooo00<0[Zj^0;fm_@2j^[X00P33`l<20<;2`P050<k>cP31`L40`<300;jn_P3:b/X00`2n_[h01P3<
c<`0c/k>0;Ng]`2n_[h0`/;20;jn_P80`/;200L0b/[:0<O7a`36a/H0`<300<O7a`2b/[80c<c<0080
eMGE00L0a/K60<c<c038b<P0bLW90<;2`P37alL0b<S80080dm?C00L0_[jn0<W9b@34a<@0dm?C0<30
`02l_;`0];Bd0080aLG500L0bl_;0<W9b@2d];@0aLG50=oOg`3EeMD0`l?30080_[jn00L0aLG50;2`
/033`l<0dM7A0<_;b`37alL0cLg=0080TY:B00L0_;bl0<W9b@33`l<0^KVi0;bl_02j^[X0/;2`0080
`/;200D0alO70<30`033`l<0`l?30;Bd]0020<?3``80`/;200L0`l?309VIV@30`<00e]KF0<?3``3>
c/h0]KFe0080f=SH00L0][Jf09nOW`32`/80alO70<c<c03;bl/0dM7A0080bLW900L0bl_;0<;2`P32
`/80`/;20=?Cd`37alL0^[Zj0080`<3000L0dm?C0<30`02d];@0^;Rh0;Zj^P30`<00b<S80080bl_;
00@0`<300<c<c03Jf]X0emOG0P3Cdm<02P3Fe]H0ZZZZ0:ZZZP35aLD0][Jf0<;2`P2m_Kd0_;bl0=cL
g03;bl/20<;2`P040<o?c`3=cLd0c<c<0<71`B@0oooo=P2P?ol00`3o0000X3oo0:0oo`090:0oo`80
Oooo4`2P?ol00`1oool0X3oo0:0oo`060:0oo`0307ooo`2P?ol0X3oo02d0X3oo9`3oool002D0oooo
00<0]KFe0:f][@2ZZZX00P2n_[h01`2b/[80_;bl0:j^[P2m_Kd0a<C40<30`02e]KD00P2h^;P01`39
bLT0a<C40<G5a@2j^[X0^KVi0<30`02f][H00P33`l<01`37alL0c<c<0;Jf]P3:b/X0emOG0;Bd]02f
][H00P2d];@01`32`/80c/k>0<30`03?cll0aLG50<30`03;bl/00P32`/801`3=cLd0alO70=GEe@2_
[jl0^k^k0;Vi^@3?cll00P37alL01@2i^KT0dM7A0=OGe`34a<@0^;Rh0080e]KF0P32`/801`3EeMD0
^k^k0:f][@2l_;`0`l?30=GEe@32`/800P2n_[h01`2k^k/0`/;20=7Ad@35aLD0^KVi0;Rh^02f][H0
0P2i^KT01`38b<P0aLG50<c<c02d];@0dm?C0<C4a039bLT00P3Lg=`01`33`l<0^[Zj0<k>cP3<c<`0
e]KF0<o?c`3>c/h00P3<c<`01`32`/80_[jn0;^k^`2b/[80d];B0>3Ph02l_;`00P3AdM401`2j^[X0
_[jn0;Zj^P2j^[X0`l?30<O7a`32`/800P3De=@01`3EeMD0`<300;fm_@2g]kL0bLW90=oOg`3>c/h0
0P39bLT01`3Bd]80dm?C0:ZZZP35aLD0bl_;0<30`03Hf=P00P3;bl/01`3<c<`0bLW90<O7a`3?cll0
dM7A08b<S02e]KD00P30`<00103?cll0`/;20<?3``2n_[hT0?ooof@0X3oo00<0o`000:0oo`2P?ol0
3`2P?ol00`3o0000X3oo0:0oo`0?0:0oo`0307ooo`2P?ol0X3oo00D0X3oo9`3oool002D0oooo00<0
]KFe0:f][@2ZZZX00P2n_[h01`2b/[80_;bl0:j^[P2m_Kd0a<C40<30`02e]KD00P2h^;P01`39bLT0
a<C40<G5a@2j^[X0^KVi0<30`02f][H00P33`l<01`37alL0c<c<0;Jf]P3:b/X0emOG0;Bd]02f][H0
0P2d];@01`32`/80c/k>0<30`03?cll0aLG50<30`03;bl/00P32`/801`3=cLd0alO70=GEe@2_[jl0
^k^k0;Vi^@3?cll00P37alL01@2i^KT0dM7A0=OGe`34a<@0^;Rh0080e]KF0P32`/801`3EeMD0^k^k
0:f][@2l_;`0`l?30=GEe@32`/800P2n_[h01`2k^k/0`/;20=7Ad@35aLD0^KVi0;Rh^02f][H00P2i
^KT01`38b<P0aLG50<c<c02d];@0dm?C0<C4a039bLT00P3Lg=`01`33`l<0^[Zj0<k>cP3<c<`0e]KF
0<o?c`3>c/h00P3<c<`01`32`/80_[jn0;^k^`2b/[80d];B0>3Ph02l_;`00P3AdM401`2j^[X0_[jn
0;Zj^P2j^[X0`l?30<O7a`32`/800P3De=@01`3EeMD0`<300;fm_@2g]kL0bLW90=oOg`3>c/h00P39
bLT01`3Bd]80dm?C0:ZZZP35aLD0bl_;0<30`03Hf=P00P3;bl/01`3<c<`0bLW90<O7a`3?cll0dM7A
08b<S02e]KD00P30`<00103?cll0`/;20<?3``2n_[hT0?ooof@0X3oo00<0o`000:0oo`2P?ol03`2P
?ol00`3o0000X3oo0:0oo`0?0:0oo`0307ooo`2P?ol0X3oo00D0X3oo9`3oool002D0oooo00<0][Jf
0;:b/P37alL00`2k^k/01P36a/H0`l?30<?3``33`l<0alO70<[:bP80bLW900L0dM7A0<W9b@3=cLd0
aLG50<;2`P2g]kL0_kno0080b/[:00L0`/;20<_;b`3<c<`0[jn_0<C4a02k^k/0a<C40080/K6a0P3<
c<`01@2e]KD0XJ6Q0;bl_03Hf=P0`/;20080e=CD00L0`<300=CDe024Q8@0alO70<71`@2DU9@0d=3@
0080^k^k00L0[Jf]0=7Ad@3Hf=P0/[:b0;Jf]P2n_[h0c<c<0080ZZZZ00L0]kNg0<g=c@2YZJT0];Bd
0;fm_@3?cll0/k>c0080^[Zj00L0_kno0;^k^`39bLT0]kNg0;no_`2^[Zh0][Jf0080^;Rh00D0aLG5
0<O7a`2n_[h0^k^k0;Bd]0020<k>cP80_kno00L0b<S80<o?c`2HV9P0cLg=0;Rh^030`<00`l?30080
][Jf00L0/;2`0:^[Z`2d];@0^k^k0<;2`P2h^;P0][Jf0080`/;200L0^;Rh0<g=c@2j^[X0`<300<W9
b@30`<00Z:RX0080^k^k00L0b/[:0=GEe@35aLD0e]KF0;bl_02n_[h0a<C40080b/[:00L0dM7A0<o?
c`2a/K40`l?30<;2`P3=cLd0[jn_0080`L7100L0dm?C0>o_k`29RHT0a/K60<S8b03<c<`0alO70080
]kNg00@0aLG50=3@d03;bl/0^KVi903ooolS0:0oo`0307ooo`2P?ol0X3oo00D0X3oo00@0Oooo0:0o
o`2P?ol0Oooo:@2P?ol00`1oool0X3oo0:0oo`0Y0:0oo`030?l0001oool0X3oo00T0X3oo9`3oool0
02D0oooo00<0a/K60<30`030`<000P38b<P01`34a<@0[Jf]0<O7a`39bLT0^KVi0;no_`3<c<`00P2i
^KT01`35aLD0_[jn0<O7a`37alL0^k^k0<[:bP33`l<00P2c/k<01`2_[jl0Ng]k0;jn_P30`<00_[jn
0<c<c02l_;`00P36a/H01`32`/80a<C40;Ng]`31`L40^k^k0;fm_@3AdM400P2m_Kd01`30`<00c<c<
0<?3``39bLT0`L710:BTY03Kfm/00P3<c<`01`2i^KT0^[Zj0<[:bP3Fe]H0SXj>0<G5a@3:b/X00P2l
_;`01`33`l<0[Jf]0:^[Z`2h^;P0/;2`09bLW02h^;P00P2j^[X00`3;bl/0^KVi0;Zj^P020;no_`05
0;Ng]`2RXZ80_;bl0;bl_039bLT00P32`/820;no_`0;0=SHf02j^[X0cLg=0<g=c@3?cll0VYZJ0=?C
d`2`/;00YJFU0<30`02b/[800P3EeMD01`2l_;`0^;Rh0<W9b@2l_;`0bLW90<S8b032`/800P30`<00
1`35aLD0`l?30<30`033`l<0dM7A0<_;b`31`L400P3@d=001P3:b/X0alO70<?3``3Fe]H0eMGE0<W9
b@<0clo?00L0aLG50<k>cP3?cll0alO70<g=c@30`<00dm?C0080cLg=00L0aLG50<g=c@3Jf]X0b<S8
0;no_`3:b/X0bLW90080^k^k00@0d=3@0<O7a`3:b/X0aLG5903ooolH0:0oo`0307ooo`2P?ol0X3oo
01<0X3oo00<0Oooo0:0oo`2P?ol01@2P?ol00`1oool0X3oo0:0oo`070:0oo`0307ooo`2P?ol0X3oo
00L0X3oo00<0Oooo0:0oo`2P?ol02P2P?ol00`1oool0X3oo0:0oo`0f0:0oobL0oooo000U0?ooo`03
0;Bd]02f][H0/[:b0080`/;200L0_;bl09nOW`2m_Kd0`/;20;Vi^@2m_Kd0[Jf]0080][Jf00L0aLG5
0<?3``2h^;P0/[:b0;Rh^032`/80bLW90080bl_;00L0_;bl0:ZZZP39bLT0alO70<g=c@39bLT0alO7
0080dM7A00L0V9RH0;Rh^02_[jl0`L710=3@d039bLT0b/[:0080bLW900L0^k^k0<S8b03=cLd0bLW9
0;2`/02l_;`0dm?C0080^KVi00L0cLg=0;Zj^P2VYZH0Z:RX0:f][@2f][H0`l?30080YJFU00L0^[Zj
0<?3``2l_;`0][Jf0;bl_03?cll0`<300080aLG500@0/;2`0<O7a`30`<00Zj^[0P2j^[X02P2FUYH0
`/;20<;2`P2`/;00e]KF0;Zj^P3Cdm<0`L710<?3``3Hf=P20:n_[`070<o?c`2d];@0dM7A0;Jf]P2[
Zj/0^k^k0;Ng]`0209:BTP070<W9b@30`<00/[:b0;:b/P30`<00][Jf0;2`/0020:n_[`070;Zj^P3E
eMD0`<300=?Cd`3?cll0^[Zj0<O7a`030<_;b`060<g=c@3AdM40clo?0;Zj^P35aLD0`l?30P2b/[80
1`2l_;`0aLG50:FUY@3>c/h0`l?30=[JfP37alL00P33`l<01`2g]kL0^KVi0>o_k`2b/[80aLG50;fm
_@2g]kL00P3Rh^80103Jf]X0`l?30<C4a02l_;`T0?ooo`H0X3oo00<0Oooo0:0oo`2P?ol05`2P?ol0
0`1oool0X3oo0:0oo`0W0:0oo`0307ooo`2P?ol0X3oo0100X3oo0P1ooolV0:0oo`030?l0002P?ol0
X3oo0080X3oo0P3o00040:0oobL0oooo000U0?ooo`030;Zj^P33`l<0bLW90080`<3000L0b<S80<30
`03>c/h0c<c<0<S8b03:b/X0`/;20080bLW90P30`<001@2k^k/0_;bl0;Ng]`2QXJ40_[jn0080_Kfm
00L0`L710<30`02d];@0a/K60<S8b02i^KT0cLg=0080alO700L0a<C40<O7a`2i^KT0^k^k0<30`03<
c<`0dm?C0080`/;200L0^k^k0<k>cP2l_;`0eMGE0<K6aP30`<00`l?30080ZZZZ00L0aLG50:f][@33
`l<0`<300:VYZ@2m_Kd0]kNg0080dm?C00L0b/[:0;jn_P35aLD0`<300;fm_@35aLD0^[Zj0080`<30
00@0_[jn0:f][@37alL0`<300P2j^[X02P2a/K40]KFe0;Fe]@3Ng]h0dm?C0;Zj^P3>c/h0`/;20;Zj
^P3<c<`20<71`@060;bl_03=cLd0d];B0<30`02UYJD0820P0`39bLT01`3@d=00][Jf0<G5a@3=cLd0
_kno0;Bd]03:b/X00P32`/801P35aLD0bLW90;Jf]P3;bl/0cLg=0<W9b@<0alO700L0aLG50<?3``2n
_[h0d=3@0<G5a@3Jf]X0f=SH0080aLG500L0WYjN0<;2`P3:b/X0_[jn0=?Cd`37alL0aLG50080^;Rh
00<0Zj^[0;jn_P2PX:000P3?cll02035aLD0kNg]0=GEe@3EeMD0^;Rh0:VYZ@31`L40alO7903ooolC
0:0oo`0307ooo`2P?ol0X3oo03L0X3oo00<0o`000:0oo`2P?ol02`2P?ol00`3oool0X3oo0:0oo`0L
0:0oo`0307ooo`2P?ol0X3oo00P0X3oo00D0Oooo0:0oo`2P?ol0X3oo0?l000060:0oobL0oooo000U
0?ooo`030;Ng]`2l_;`0alO70080];Bd00L0bLW90;fm_@33`l<0f][J0<;2`P2n_[h0`/;20080c<c<
00L0]KFe0<71`@2h^;P0b/[:0<O7a`31`L40]kNg0080][Jf00L0];Bd0<;2`P34a<@0_Kfm0=7Ad@3;
bl/0a<C40080^;Rh00L0bLW90<C4a02m_Kd0^k^k0<_;b`32`/80d=3@0080`/;200H0a<C40<;2`P3N
g]h0b/[:0<c<c033`l<30<_;b`070=KFeP3=cLd0aLG50;Zj^P3:b/X0aLG50;fm_@020;Jf]P070;2`
/039bLT0bLW90;^k^`2UYJD0][Jf0:ZZZP020<G5a@070=KFeP2`/;00`l?30<;2`P2n_[h0^;Rh0:BT
Y0020<g=c@050;Jf]P3[jn/0ZZZZ0;jn_P32`/800P2i^KT20<[:bP070=7Ad@39bLT0j>SX0<c<c02L
W9`0`/;20<?3``020:^[Z`060<?3``36a/H0/[:b0;bl_02f][H0`<300`33`l<01`3<c<`0_kno0<71
`@3Kfm/0`/;20<?3``2h^;P00P33`l<01`39bLT0aLG50=?Cd`2[Zj/0[Jf]0<[:bP33`l<00P35aLD0
1`33`l<0/[:b0<W9b@36a/H0aLG50=7Ad@3>c/h00P30`<001`2c/k<0emOG0;fm_@3:b/X0`l?30=KF
eP2b/[800P3;bl/0102f][H0c/k>0<g=c@2`/;0T0?ooob/0X3oo00<0o`000:0oo`2P?ol0702P?ol0
1@1oool0X3oo0:0oo`2P?ol0o`0000T0X3oo00<0o`000:0oo`1oool0=@2P?olW0?ooo`009@3oool0
0`2ZZZX0^k^k0;no_`030;Vi^@060<O7a`34a<@0alO70;jn_P2l_;`0/k>c0P39bLT01`2o_kl0g=cL
0<O7a`2g]kL0alO70<W9b@35aLD00P30`<001`2n_[h0aLG50;Bd]039bLT0^KVi0<O7a`36a/H00P38
b<P01`2l_;`0b/[:0;jn_P33`l<0bLW90<71`@3;bl/00P3De=@01037alL0d];B0;bl_038b<P20;no
_`0:0;:b/P2`/;00/;2`0<;2`P2b/[80bLW90:b/[02`/;00e]KF0<;2`P80_[jn00L0b/[:0;Zj^P34
a<@0alO70<30`03;bl/0`l?30080dm?C00L0][Jf0<G5a@31`L40f][J0;bl_02b/[80eMGE0080^k^k
00L0hN7Q0;2`/02l_;`0^;Rh0<?3``3AdM40/;2`0080dm?C00L0alO70>;RhP3@d=00^k^k0<;2`P2[
Zj/0i>CT0080c<c<00L0][Jf0<71`@33`l<0c<c<0<S8b037alL0_[jn0080gmoO00L0^KVi0<30`02l
_;`0`L710<k>cP3;bl/0Ti>C0080b<S800@0dM7A0;Rh^02f][H0`/;20P3:b/X01`2d];@0aLG50<G5
a@2][Jd0a<C40<S8b02k^k/00P3?cll02P2n_[h0/[:b0;:b/P35aLD0d=3@07]kN`2c/k<0^[Zj0<;2
`P39bLT20;:b/P040;jn_P2_[jl0/[:b0;jn_R@0ooooC@2P?ol00`3o0000X3oo0:0oo`070:0oo`03
0?l0002P?ol0X3oo0080X3oo00<0o`000:0oo`2P?ol01`2P?ol20?l000H0X3oo00<0Oooo0:0oo`2P
?ol0502P?ol00`1oool0X3oo0:0oo`080:0oobL0oooo000U0?ooo`030:VYZ@39bLT0_kno0080[Jf]
00L0`l?30<W9b@2m_Kd0cLg=0<k>cP2i^KT0a/K60080b<S800L0c<c<0<?3``2k^k/0ZJVY0;jn_P2m
_Kd0ZJVY0080`<3000L0_[jn0<G5a@2m_Kd0_Kfm0=;BdP31`L40^KVi0080_;bl00L0`l?30;^k^`2i
^KT0`<300<;2`P2e]KD0alO70080c/k>00L0_kno0<O7a`2f][H0gmoO0<G5a@33`l<0alO70080dM7A
00L0alO70:b/[035aLD0cLg=0<;2`P3Fe]H0alO70080dM7A00L0alO70=?Cd`2b/[80/K6a0;bl_033
`l<0`/;20080/[:b00D0`l?30=7Ad@2k^k/0bLW90<G5a@020;Vi^@80_[jn00L0YZJV0<[:bP2n_[h0
d=3@0:VYZ@36a/H0emOG0080inOW00L0c/k>0<C4a02n_[h0aLG50<O7a`39bLT0_[jn0080alO700L0
`l?30;^k^`2_[jl0Rh^;0;>c/`3;bl/0a<C40080YZJV00L0bLW90;jn_P30`<00c<c<0<W9b@32`/80
alO70080f][J00L0h>3P0=cLg03=cLd0dm?C0;jn_P3?cll0bl_;0080clo?00H0cLg=0;jn_P39bLT0
`<300<g=c@35aLD30:^[Z`070=?Cd`35aLD0`/;20<G5a@2[Zj/0Z:RX0=_Kf`020<;2`P040=?Cd`33
`l<0aLG50;Zj^R@0oooo;02P?ol00`3o0000X3oo0:0oo`0U0:0oo`80o`00302P?ol00`1oool0X3oo
0:0oo`0<0:0oo`030?l0002P?ol0X3oo01`0X3oo9`3oool002D0oooo0P2f][H02P2o_kl0c/k>0<k>
cP2k^k/0bLW90;Ng]`2k^k/0dm?C0;Jf]P2i^KT20=?Cd`070;Bd]02m_Kd0^k^k0;Ng]`2f][H0/k>c
0;bl_0020<S8b080bLW900D0_Kfm0<;2`P38b<P0_[jn0;:b/P020;bl_0070<G5a@33`l<0_[jn0<W9
b@3<c<`0`l?30;fm_@020<?3``070<W9b@3=cLd0fm_K0=[JfP39bLT0`<300<;2`P020=3@d0070<[:
bP35aLD0c<c<0;jn_P3<c<`0_[jn0<c<c0030<?3``060<71`@3Bd]80e=CD0:n_[`35aLD0YZJV0P31
`L401`3:b/X0alO70;>c/`2k^k/0][Jf0;fm_@2j^[X00P2d];@01`2b/[80_;bl0;jn_P34a<@0`<30
0:n_[`3EeMD00P37alL01`32`/80^;Rh0;bl_03=cLd0alO70;bl_032`/800P2g]kL00`2h^;P0YZJV
0<G5a@020;Zj^P0;0;Jf]P2`/;00_[jn0;jn_P32`/80`l?30<G5a@3EeMD0cLg=0<o?c`35aLD00P30
`<001`3<c<`0fMWI0<o?c`2j^[X0`l?30<O7a`3EeMD00P37alL01`3<c<`0dm?C0<o?c`39bLT0aLG5
0;Zj^P2h^;P00P2[Zj/01`36a/H0`<300<30`030`<00eMGE0<_;b`2f][H00P2k^k/01039bLT0e=CD
0;fm_@33`l<T0?oooi00X3oo9`3oool002D0oooo0P2f][H02P2o_kl0c/k>0<k>cP2k^k/0bLW90;Ng
]`2k^k/0dm?C0;Jf]P2i^KT20=?Cd`070;Bd]02m_Kd0^k^k0;Ng]`2f][H0/k>c0;bl_0020<S8b080
bLW900D0_Kfm0<;2`P38b<P0_[jn0;:b/P020;bl_0070<G5a@33`l<0_[jn0<W9b@3<c<`0`l?30;fm
_@020<?3``070<W9b@3=cLd0fm_K0=[JfP39bLT0`<300<;2`P020=3@d0070<[:bP35aLD0c<c<0;jn
_P3<c<`0_[jn0<c<c0030<?3``060<71`@3Bd]80e=CD0:n_[`35aLD0YZJV0P31`L401`3:b/X0alO7
0;>c/`2k^k/0][Jf0;fm_@2j^[X00P2d];@01`2b/[80_;bl0;jn_P34a<@0`<300:n_[`3EeMD00P37
alL01`32`/80^;Rh0;bl_03=cLd0alO70;bl_032`/800P2g]kL00`2h^;P0YZJV0<G5a@020;Zj^P0;
0;Jf]P2`/;00_[jn0;jn_P32`/80`l?30<G5a@3EeMD0cLg=0<o?c`35aLD00P30`<001`3<c<`0fMWI
0<o?c`2j^[X0`l?30<O7a`3EeMD00P37alL01`3<c<`0dm?C0<o?c`39bLT0aLG50;Zj^P2h^;P00P2[
Zj/01`36a/H0`<300<30`030`<00eMGE0<_;b`2f][H00P2k^k/01039bLT0e=CD0;fm_@33`l<T0?oo
oi00X3oo9`3oool002D0oooo00<0/;2`0<G5a@33`l<00P35aLD01`30`<00b/[:0;no_`3:b/X0alO7
0=?Cd`2e]KD00P2k^k/01`38b<P0^k^k0;bl_03<c<`0]kNg0;bl_02m_Kd00P2l_;`01037alL0_[jn
0;>c/`2m_Kd20<W9b@0:0;Vi^@34a<@0a<C40;jn_P2i^KT0[jn_0<30`02YZJT0_;bl0=CDe080aLG5
00L0^[Zj0<W9b@2g]kL0a<C40;^k^`2b/[80c<c<0080`/;200L0e]KF0<O7a`32`/80YjNW0<_;b`3E
eMD0_;bl0080aLG500L0bLW90<;2`P3:b/X0b<S80<O7a`3>c/h0_;bl0080bLW900L0`/;20:FUY@2i
^KT0eMGE08j>SP2SXj<0Y:BT0080^;Rh00<0`/;20;:b/P3?cll00P39bLT02@3?cll0^[Zj0<g=c@3=
cLd0/[:b0<G5a@3:b/X0/k>c0;Rh^0020<W9b@80_;bl00L0c/k>0;^k^`33`l<0]kNg0;jn_P2f][H0
alO70080aLG500L0e]KF0;jn_P3;bl/0bl_;0<;2`P3;bl/0_[jn0080bl_;00L0dm?C0<G5a@37alL0
ZZZZ0<[:bP38b<P0a/K60080_;bl00L0^k^k0<O7a`3;bl/0e=CD0<k>cP39bLT0`l?30080_Kfm00L0
bLW90=GEe@3MgMd0`/;20;bl_033`l<0`/;20080_;bl00@0/K6a0;^k^`38b<P0_[jn903ooom80:0o
o`<0Oooo>P2P?ol00`3o0000X3oo0:0oo`080:0oobL0oooo000U0?ooo`030:^[Z`2g]kL0`/;20080
alO700L0a/K60;^k^`2m_Kd0`L710<?3``2f][H0`L710080`<3000L0a<C40<30`030`<00`<300;Jf
]P2j^[X0`l?30080aLG500L0`l?30<;2`P2d];@0f=SH0<c<c032`/80Xj>S0080b/[:00L0bLW90;Fe
]@3<c<`0bl_;0;Vi^@39bLT0`l?30080alO700L0]kNg0<?3``3>c/h0a<C40;Bd]035aLD0];Bd0080
Zj^[00L0b/[:0<;2`P2d];@0_;bl0;jn_P38b<P0a<C40080]KFe00L0^k^k0<G5a@2g]kL0XZ:R0=GE
e@2b/[80[jn_0080alO700L0bLW90<G5a@35aLD0^[Zj0:6QX@2_[jl0];Bd0080^[Zj00<0alO70<;2
`P36a/H00P32`/802`2m_Kd0bLW90:>SX`2SXj<0b/[:0<W9b@36a/H0^k^k0;bl_03:b/X0^;Rh0080
b<S800L0_Kfm0;Ng]`2n_[h0bl_;0<o?c`2l_;`0]kNg0080aLG500L0`/;20;fm_@32`/80aLG50<O7
a`33`l<0^[Zj0080^;Rh00L0]kNg0;Fe]@2l_;`0`/;20=SHf032`/80];Bd0080b/[:00L0hN7Q0<W9
b@35aLD0`l?30<W9b@2e]KD0][Jf0080_;bl00L0alO70:ZZZP2n_[h0cLg=0=kNgP3AdM40f=SH0080
cLg=00@0alO70<?3``3;bl/0_;bl903ooolM0:0oo`0307ooo`2P?ol0X3oo01h0X3oo00<0Oooo0:0o
o`2P?ol01`2P?ol00`1oool0X3oo0:0oo`090:0oo`80Oooo902P?ol00`3o0000X3oo0:0oo`0:0:0o
o`030?l0002P?ol0X3oo00H0X3oo9`3oool002D0oooo00<0][Jf0<;2`P30`<000P3:b/X01`3?cll0
]KFe0;Zj^P36a/H0`/;20;fm_@2n_[h00P30`<001`36a/H0/;2`0<30`033`l<0][Jf0<O7a`2n_[h0
0P39bLT01`35aLD0XJ6Q0:b/[02f][H0^;Rh0<30`039bLT00P32`/801`2e]KD0c<c<0;bl_039bLT0
^k^k0:f][@39bLT00P2l_;`01`30`<00d];B0<W9b@3@d=00^[Zj0;Fe]@34a<@00P39bLT00`32`/80
_Kfm0<?3``020<?3``0;0;Rh^03>c/h0c<c<0<c<c03:b/X0clo?0:^[Z`32`/80e]KF0<30`03>c/h0
0P37alL01`33`l<0/[:b0<30`02b/[80][Jf0<30`02`/;000P3<c<`01`38b<P0alO70;Jf]P2k^k/0
alO70=gMg@3;bl/00P2m_Kd01P3Vi^H0alO70;Bd]033`l<0e]KF0=?Cd`<0aLG500L0^k^k0;2`/034
a<@0[Zj^0;Vi^@2BTY80`L710080k^k^00L0`/;20:n_[`2h^;P0cLg=0<?3``3>c/h0_;bl0080a/K6
00L0b/[:0<k>cP39bLT0c<c<0=SHf02ZZZX0]kNg0080dM7A00L0`l?30<[:bP3>c/h0clo?0;bl_03@
d=00b<S80080d=3@00L0b/[:0<c<c034a<@0a<C40;Vi^@32`/80`<300080i>CT00@0d];B0<c<c03D
e=@0bl_;903ooolH0:0oo`0307ooo`2P?ol0X3oo03L0X3oo00D0o`000:0oo`2P?ol0X3oo0?l0000=
0:0oo`0407ooo`2P?ol0o`000?l00280X3oo0P3o00040:0oobL0oooo000U0?ooo`030;no_`2][Jd0
`L710080`l?30P39bLT01@2l_;`0`l?30=SHf03>c/h0^;Rh0080_;bl0P2j^[X01@30`<00^;Rh0;Vi
^@33`l<0a/K60080aLG500L0c/k>0=KFeP31`L40`<300:^[Z`35aLD0alO70080`L7100L0c<c<0;Vi
^@2g]kL0alO70;Rh^030`<00dM7A0080c<c<00L0`L710;bl_02m_Kd0`L710;Zj^P3@d=00/k>c0080
]KFe00D0alO70>k^kP2n_[h0^[Zj0;bl_0020;jn_P80c/k>00L0][Jf0;jn_P2f][H0`<300<g=c@30
`<00^k^k0080bLW900@0];Bd0;Rh^02d];@0`<300P33`l<02P2h^;P0`l?30<?3``2l_;`0`/;20;bl
_02n_[h0bLW90<?3``2l_;`20<30`0070:j^[P35aLD0_[jn0<G5a@3Jf]X0/[:b0<O7a`020=CDe007
0=3@d03>c/h0b<S80;jn_P35aLD0c<c<0=KFeP020<c<c0070=;BdP2f][H0`<300;bl_03=cLd0`l?3
0;Fe]@020<30`0030<[:bP34a<@0b/[:0080cLg=00/0clo?0=?Cd`39bLT0bLW90<k>cP3EeMD0aLG5
0<g=c@2h^;P0b<S80;:b/P020:6QX@0709nOW`32`/80`L710=KFeP32`/80aLG50<_;b`020<30`004
0:^[Z`35aLD0Xj>S0;Rh^2@0oooo<`2P?ol00`3o0000X3oo0:0oo`1;0:0oo`<0Oooo2P2P?ol00`1o
ool0X3oo0?ooo`0V0?ooo`009@3oool00`2^[Zh0cLg=0<30`0020;Bd]0070<?3``30`<00ZZZZ0;no
_`33`l<0ZZZZ0;Jf]P020<G5a@070;Vi^@2j^[X0b<S80<71`@2g]kL0a/K60;Bd]0020<W9b@070;Bd
]02l_;`0_[jn0<[:bP39bLT0_kno0;2`/0020;Jf]P070<G5a@2f][H0`l?30;fm_@2ZZZX0^;Rh0=oO
g`020<30`0070;2`/035aLD0V9RH0;^k^`2g]kL0b/[:0=kNgP020=gMg@030;Vi^@3>c/h0_;bl0080
^KVi00/0alO70:RXZ02i^KT0^KVi0<[:bP3<c<`0`/;20;Vi^@2k^k/0_Kfm0;Bd]0020<_;b`070;Jf
]P2h^;P0aLG50<71`@35aLD0[Zj^0;bl_0020<G5a@070;2`/035aLD0e]KF0;^k^`2NWYh0]kNg0<k>
cP0209^KV`070=SHf037alL0b/[:0<O7a`2n_[h0dm?C0;:b/P020=7Ad@050;2`/03AdM40`l?30<_;
b`3@d=000P2o_kl20<?3``070<G5a@2=SHd0_[jn0;Fe]@2d];@0c<c<0;jn_P020<;2`P060=7Ad@3=
cLd0`l?30>OWi`3;bl/0YJFU0`3=cLd0103;bl/0b/[:0=3@d03<c<`20<W9b@030<30`02[Zj/0Zj^[
0080_;bl00D0ZJVY08R8R035aLD0bLW90<c<c0020;2`/0040;:b/P2SXj<0`l?30;Jf]R@0oooo9P2P
?ol00`3o0000X3oo0:0oo`020:0oo`0407ooo`2P?ol0X3oo0:0oo`<0o`007`2P?ol00`1oool0X3oo
0:0oo`0207oooa<0X3oo00<0Oooo0:0oo`2P?ol0202P?ol00`3o0000X3oo0:0oo`0?0:0oo`0307oo
o`2P?ol0X3oo00@0X3oo00<0Oooo0:0oo`2P?ol09`3oool002D0oooo00<0a/K60<G5a@33`l<00P3:
b/X01`34a<@0`/;20<[:bP3:b/X0bLW90;jn_P2f][H00P30`<001`2_[jl0aLG50<K6aP2h^;P0c<c<
0<g=c@33`l<00P30`<001`38b<P0/;2`0;no_`2f][H0d=3@0;bl_02ZZZX00P2i^KT01`30`<00^[Zj
0<30`03<c<`0_[jn0<?3``2m_Kd00P2d];@01`2i^KT0b/[:0<[:bP3Cdm<0`<300<[:bP2k^k/00`33
`l<01P2TY:@0Z:RX0;^k^`39bLT0dM7A0=?Cd`80b/[:00L0`<300=7Ad@3;bl/0`<300;bl_02b/[80
alO70080bl_;00L0^[Zj0;Jf]P33`l<0alO70;Jf]P2l_;`0Z:RX0080[:b/00D0`l?30<W9b@32`/80
c/k>0;fm_@020<c<c080^[Zj00L0[jn_0=;BdP3=cLd0eMGE0<c<c03Bd]80b/[:0080alO700L0clo?
0<O7a`36a/H0Zj^[0=[JfP3<c<`0Z:RX0080][Jf00L0aLG50;fm_@2TY:@0Xj>S0;bl_03@d=00fm_K
0080clo?00L0c<c<0<71`@2g]kL0c<c<08:2PP3;bl/0d=3@0080_[jn00L0]kNg0<K6aP3>c/h0]kNg
0=7Ad@2][Jd0Z:RX0080a<C400L0Ogmo0;Jf]P3Jf]X0dM7A0;fm_@2@T900`l?30080c<c<00@0`L71
0<G5a@2>SXh0f=SH903ooolc0:0oo`0307ooo`2P?ol0X3oo03@0X3oo0P1oool90:0oo`0307ooo`2P
?ol0X3oo00/0X3oo00<0Oooo0:0oo`2P?ol00P2P?ol00`1oool0X3oo0:0oo`030:0oo`0307ooo`2P
?ol0oooo02H0oooo000U0?ooo`030<30`02o_kl0_Kfm0080a<C400L0b/[:0<;2`P2n_[h0aLG50;Jf
]P2i^KT0][Jf0080_Kfm00L0_kno0;bl_038b<P0^k^k0;:b/P2o_kl0alO70080`/;200<0Zj^[0=7A
d@34a<@00P35aLD02`2k^k/0`l?30<G5a@35aLD0c/k>0<[:bP3>c/h0`l?30;Bd]02VYZH0]kNg0080
`L7100L0_;bl0<S8b02o_kl0][Jf09FEU@3<c<`0f=SH0080c<c<00L0^k^k0<G5a@38b<P0b/[:0=GE
e@35aLD0`/;20080][Jf00L0aLG50<_;b`2l_;`0[Jf]0<_;b`2h^;P0b/[:0080d=3@00L0[Zj^0<G5
a@2k^k/0`l?30<O7a`2d];@0/[:b0080aLG500L0_kno0;Vi^@33`l<0Z:RX0;Vi^@2f][H0^[Zj0080
^;Rh00L0bLW90=7Ad@3:b/X0a<C40=7Ad@3Jf]X0^;Rh0080bl_;00L0_[jn0;>c/`35aLD0dM7A0;Vi
^@2o_kl0`l?30080clo?00L0c<c<0;Vi^@2NWYh0][Jf0<G5a@33`l<0aLG50080clo?00L0bLW90<;2
`P39bLT0dM7A0;2`/033`l<0[Jf]0080/[:b0P3=cLd01@33`l<0b/[:06ATI02JVYX0];Bd0080emOG
00L0YZJV09:BTP3IfMT0`l?30;Jf]P2[Zj/0_;bl0080W9bL00@0_;bl0;Jf]P35aLD0a<C4903oool]
0:0oo`0307ooo`2P?ol0X3oo03X0X3oo00<0Oooo0:0oo`2P?ol04@2P?ol00`3Pol00Oooo0:0oo`03
0:0oo`0307ooo`2P?ol0X3oo00<0X3oo0P1oool40:0oobL0oooo000U0?ooo`030;Fe]@31`L40^k^k
0080b/[:00L0dM7A0;Vi^@2VYZH0^k^k0<W9b@2k^k/0f=SH0080^k^k00L0_;bl0<30`02n_[h0[Jf]
0;^k^`2f][H0]kNg0080aLG500L0];Bd0<c<c02i^KT0_kno0<W9b@37alL0^k^k0080bLW900L0alO7
0<;2`P2h^;P0alO70=KFeP2d];@0bl_;0080^[Zj00L0/K6a0=7Ad@35aLD0];Bd0=SHf01`L700a/K6
0080][Jf00L0bLW90;fm_@3Bd]80f=SH0<30`03AdM40_;bl0080b/[:00L0/;2`0=WIf@2d];@0bl_;
0<O7a`39bLT0gMgM0080/[:b00L0b/[:0;jn_P2n_[h0`<300;^k^`2[Zj/0`l?30080a/K60P2_[jl0
1@3Cdm<0b/[:0;jn_P36a/H0b/[:0080_[jn00L0_kno0;jn_P35aLD0dm?C0=SHf02i^KT0/k>c0080
c<c<00L0eMGE0<K6aP3AdM40cLg=0:f][@2[Zj/0alO70080_Kfm00L0^;Rh0;fm_@3IfMT0a/K60<O7
a`2b/[80[Zj^0080[jn_00L0_kno0;Ng]`33`l<0c/k>0;Jf]P2o_kl0]kNg00<0`/;200H0hN7Q0<?3
``2n_[h0[jn_0<S8b02][Jd209jNWP070:RXZ02/[:`0ZZZZ0<W9b@31`L40][Jf0;2`/0020=[JfP04
0<[:bP3alO40bl_;0?gmoB@0oooo;P2P?ol00`1oool0X3oo0:0oo`0@0:0oo`030?l0002P?ol0X3oo
03L0X3oo00<0o`000:0oo`2P?ol00`2P?ol207ooo`X0X3oo00<0o`000:0oo`3o00009`3oool002D0
oooo00<0]KFe0<71`@2k^k/00P3:b/X01`3AdM40^KVi0:JVYP2k^k/0bLW90;^k^`3Hf=P00P2k^k/0
1`2l_;`0`<300;jn_P2][Jd0^k^k0;Jf]P2g]kL00P35aLD01`2d];@0c<c<0;Vi^@2o_kl0bLW90<O7
a`2k^k/00P39bLT01`37alL0`/;20;Rh^037alL0e]KF0;Bd]03;bl/00P2j^[X01`2a/K40dM7A0<G5
a@2d];@0f=SH071`L036a/H00P2f][H01`39bLT0_Kfm0=;BdP3Hf=P0`<300=7Ad@2l_;`00P3:b/X0
1`2`/;00fMWI0;Bd]03;bl/0alO70<W9b@3MgMd00P2b/[801`3:b/X0_[jn0;jn_P30`<00^k^k0:^[
Z`33`l<00P36a/H20:n_[`050=?Cd`3:b/X0_[jn0<K6aP3:b/X00P2n_[h01`2o_kl0_[jn0<G5a@3C
dm<0f=SH0;Vi^@2c/k<00P3<c<`01`3EeMD0a/K60=7Ad@3=cLd0[Jf]0:^[Z`37alL00P2m_Kd01`2h
^;P0_Kfm0=WIf@36a/H0alO70;:b/P2^[Zh00P2_[jl01`2o_kl0]kNg0<?3``3>c/h0][Jf0;no_`2g
]kL00`32`/801P3QhN40`l?30;jn_P2_[jl0b<S80:f][@80WYjN00L0Z:RX0:b/[02ZZZX0bLW90<71
`@2f][H0/;2`0080f][J00@0b/[:0?7al@3;bl/0oOgm903oool^0:0oo`0307ooo`2P?ol0X3oo0100
X3oo00<0o`000:0oo`2P?ol0=`2P?ol00`3o0000X3oo0:0oo`030:0oo`80Oooo2P2P?ol00`3o0000
X3oo0?l0000W0?ooo`009@3oool20<?3``0:0;bl_02n_[h0_[jn0;jn_P2o_kl0_[jn0<K6aP32`/80
clo?0<O7a`80][Jf00@0bLW90;jn_P32`/80_;bl0P2`/;002P2o_kl0alO70<O7a`35aLD0a<C40<c<
c035aLD0_[jn0=?Cd`3>c/h20<S8b0070<W9b@2m_Kd0aLG50<_;b`32`/80/[:b0=7Ad@020<_;b`07
0<S8b03<c<`0[Jf]0=KFeP2_[jl0/[:b0<k>cP020;2`/0070=GEe@39bLT0`/;20=3@d03Fe]H0gMgM
0<G5a@020:ZZZP070;no_`3@d=00/[:b09nOW`2f][H0`L710<K6aP020<C4a0030;jn_P3?cll0`/;2
0080a<C400/0`<300:^[Z`2m_Kd0_Kfm0;Ng]`35aLD0`l?30<g=c@35aLD0`/;20<c<c0020;6a/@07
0<K6aP3IfMT0bl_;0;jn_P39bLT0^KVi0:b/[0020;bl_0070:ZZZP33`l<0bLW90<?3``32`/80`l?3
0=KFeP020;jn_P070;bl_03;bl/0`/;20<o?c`32`/80aLG50<c<c0020<O7a`070;jn_P3>c/h0^;Rh
0;fm_@2h^;P0b/[:0<c<c0020<S8b0030;Jf]P2l_;`0^KVi0080`L7100/0^k^k0;Bd]02a/K40/K6a
08V9R@32`/80Zj^[0;Zj^P2YZJT0bLW90<G5a@020<C4a0040<W9b@37alL0bLW909^KVb@0oooo=`2P
?ol00`3o0000X3oo0:0oo`040:0oo`0307ooo`2P?ol0X3oo0480X3oo00<0Oooo0:0oo`2P?ol02@2P
?ol00`1oool0oooo0?ooo`0U0?ooo`009@3oool00`2f][H0`<300<W9b@020:b/[0070;^k^`37alL0
bLW90<O7a`39bLT0clo?0<30`0020;Zj^P070<[:bP2_[jl0_[jn0<S8b02g]kL0/;2`0;fm_@020;Ng
]`070<G5a@33`l<0b/[:0<;2`P35aLD0`<300;Bd]0020:RXZ0070=CDe03=cLd0]kNg0;jn_P33`l<0
_[jn0<g=c@020;fm_@070;^k^`3:b/X0`l?30<W9b@2NWYh0_[jn0<c<c0020;Ng]`070<;2`P35aLD0
bl_;0;jn_P39bLT0j^[Z0=3@d0020=SHf0070:BTY03De=@0][Jf0;Ng]`2f][H0_;bl0=?Cd`020<30
`0070=7Ad@2i^KT0`<300>3Ph030`<00][Jf0:j^[P020;:b/P070<G5a@2l_;`0aLG50:j^[P2f][H0
bl_;0;Jf]P020=oOg`070=;BdP3:b/X0fMWI0;Zj^P32`/80alO70=?Cd`020=kNgP070<;2`P2][Jd0
alO70<O7a`3:b/X0_[jn0<O7a`020<?3``070<c<c03AdM40`l?30=7Ad@32`/80c/k>0<_;b`020<?3
``070<;2`P33`l<0][Jf0<O7a`39bLT0c/k>0<30`0020;bl_0070=3@d039bLT0bl_;0;Rh^02d];@0
`/;20;^k^`020;Rh^0070<O7a`3?cll0^[Zj0<W9b@32`/80`<300<o?c`020<_;b`040<?3``2l_;`0
_[jn0<_;bb@0oooo;@2P?ol00`1oool0X3oo0:0oo`070:0oo`050?l0002P?ol0X3oo0:0oo`1oool0
2`2P?ol00`3o0000X3oo0:0oo`0:0:0oo`80o`001`2P?ol20?l00340X3oo9`3oool002D0oooo00<0
_Kfm0:n_[`32`/800P2m_Kd01`2NWYh0^[Zj0<O7a`2][Jd0dM7A0<?3``30`<000P2b/[801`39bLT0
`l?30;bl_02^[Zh0^;Rh0<_;b`3Fe]H00`31`L401P2OWil0alO70<O7a`31`L40];Bd0:RXZ080bl_;
00L000000;:b/P2g]kL0`L710;bl_02h^;P0bLW90080cLg=00L0dM7A0<k>cP2l_;`0_[jn0<30`02B
TY80^[Zj0080YjNW0`33`l<0102[Zj/0SXj>0<30`033`l<20;bl_0070;2`/03AdM40dM7A0<O7a`2n
_[h0bl_;0<W9b@020<G5a@040=7Ad@31`L40];Bd0:f][@80alO700X0[Jf]0<30`030`<00bl_;0<g=
c@3EeMD0`l?30<O7a`3:b/X0_[jn0P2e]KD01`1hN7P0b/[:0;bl_039bLT0];Bd0<O7a`33`l<00P2e
]KD01`2k^k/0`<300;Fe]@34a<@0dm?C0<O7a`3EeMD00P30`<001`2i^KT0cLg=0<;2`P3Jf]X0_;bl
0<g=c@3Rh^800P2VYZH01P30`<00_;bl0<[:bP2l_;`0b<S80<[:bP<0bl_;00L0/K6a0=3@d02f][H0
bLW90;jn_P2h^;P0/;2`0080^;Rh00L0_[jn0=WIf@2VYZH0aLG50;Fe]@2UYJD0cLg=0080dm?C00@0
/[:b0:f][@3Bd]80f=SH903oool50:0oo`0307ooo`2P?ol0X3oo0100X3oo00<0Oooo0:0oo`2P?ol0
1@2P?ol00`3oool0X3oo0:0oo`0;0:0oo`0307ooo`2P?ol0X3oo00D0X3oo00<0Oooo0:0oo`2P?ol0
7@2P?ol00`1oool0X3oo0:0oo`0E0:0oo`030?l0002P?ol0X3oo01l0X3oo9`3oool002D0oooo00<0
bl_;0;Jf]P33`l<00P35aLD01`39bLT0`<300<g=c@37alL0c<c<0<?3``3Cdm<00P39bLT01`2g]kL0
YZJV0;no_`2k^k/0_;bl0<W9b@30`<000P36a/H01`3>c/h0aLG50;Rh^02i^KT0][Jf0<?3``2o_kl0
0P37alL01`2TY:@0_kno0<30`02d];@0^KVi0;Jf]P2k^k/00P2m_Kd01`3<c<`0aLG50=[JfP30`<00
dm?C0<W9b@2h^;P00P2QXJ401`2l_;`0^[Zj0<O7a`35aLD0gmoO0<G5a@3Bd]800P2f][H01`32`/80
e=CD0;6a/@3Bd]80Zj^[0<W9b@2`/;000P2/[:`01`33`l<0`L710<?3``2l_;`0alO70<30`02XZ:P0
0P2c/k<01`39bLT0`l?30<O7a`2b/[80]KFe0;no_`2k^k/00P1YJFT01`2][Jd0`<300:j^[P3IfMT0
][Jf0;jn_P32`/800P2e]KD01`3De=@0b<S80=3@d03>c/h0e]KF0;Jf]P3;bl/00P2i^KT01`3;bl/0
`/;20;jn_P3?cll0^;Rh0<30`02a/K400P32`/801`30`<00`l?30=?Cd`34a<@0cLg=0=?Cd`2h^;P0
0P37alL01`3AdM40];Bd0:f][@2e]KD0];Bd0<?3``2h^;P00P2f][H01`3AdM40`<300;bl_02k^k/0
`/;20<W9b@2l_;`00P37alL0102n_[h0e=CD0;bl_02SXj<T0?ooob00X3oo00<0Oooo0:0oo`2P?ol0
3@2P?ol207ooo`@0X3oo00<0o`000:0oo`2P?ol06`2P?ol20>3o`3T0X3oo00<0Oooo0?ooo`3oool0
9@3oool002D0oooo0P31`L402P39bLT0][Jf0;Jf]P3=cLd0alO70<71`@3Bd]80_[jn0;Zj^P2h^;P2
0<;2`P070<?3``31`L40^k^k0;Ng]`2m_Kd0`/;20;Vi^@020;no_`060;Vi^@33`l<0]kNg0;Bd]035
aLD0Z:RX0`2m_Kd01`37alL0`l?30;bl_02l_;`0dM7A0:f][@3;bl/00P2n_[h00`3Cdm<0c<c<0=?C
d`020;Zj^P090<g=c@3IfMT0bLW90<W9b@3Shn<0]kNg0:RXZ02TY:@0alO70080^;Rh0P37alL01`3;
bl/0`/;20<k>cP2g]kL0f][J0<c<c03=cLd00P2j^[X01`30`<00alO70;Jf]P32`/80c<c<0<W9b@2W
YjL00P2`/;001`32`/80`l?30;Rh^037alL0/[:b0;bl_033`l<00P3?cll01`3Fe]H0clo?0<[:bP2o
_kl0alO70<?3``3QhN400P32`/801`2k^k/0_[jn0<k>cP3<c<`0_kno0<;2`P2f][H00P2a/K401`32
`/80];Bd0=GEe@2n_[h0b<S80<k>cP32`/800P33`l<01`3Fe]H0h^;R0<S8b02_[jl0`<300;Zj^P3A
dM400P2l_;`01`3>c/h0^[Zj09nOW`2`/;00dM7A0<c<c02f][H00P2^[Zh01`3^k^h0]KFe0<S8b02n
_[h0[Jf]0<[:bP30`<000P3IfMT01038b<P0_;bl0:BTY02k^k/T0?oooc80X3oo00@0o`000:0oo`2P
?ol0Oooo9P2P?ol00`3o0000X3oo0:0oo`0C0:0oo`030?l0002P?ol0X3oo00L0X3oo00<0Oooo0:0o
o`2P?ol0102P?ol00`3o0000X3oo0:0oo`080:0oo`0307ooo`2P?ol0oooo02H0oooo000U0?ooo`03
0;jn_P33`l<0bLW90080_;bl00@0[Jf]0;2`/030`<00eMGE0P3?cll02P37alL0aLG50<G5a@2o_kl0
bLW90<c<c037alL0^;Rh0;Vi^@2l_;`20<W9b@070<71`@2i^KT0b<S80<71`@2f][H0`L710<?3``02
0<30`0070<G5a@3;bl/0^[Zj0<?3``2h^;P0bl_;0<30`0020:^[Z`070<O7a`39bLT0d];B0;Vi^@30
`<00`L710;no_`020;Rh^0070;2`/033`l<0`L710<G5a@2b/[80[Zj^0;:b/P020<_;b`070>;RhP35
aLD0YjNW0;Jf]P33`l<0gmoO0<30`0020<;2`P070<W9b@2i^KT0[jn_0<k>cP3;bl/0/k>c0:f][@02
0<W9b@070;Vi^@2b/[80c<c<0<?3``2f][H0clo?0<W9b@020<c<c0070<S8b034a<@0a/K60<;2`P30
`<00`/;20=[JfP020<K6aP070<?3``3<c<`0XZ:R0<S8b02n_[h0b/[:0<o?c`020<30`0070<C4a035
aLD0`l?30=?Cd`3>c/h0/k>c0<O7a`020;bl_0070<g=c@3?cll0V9RH0;Zj^P2b/[80[jn_0<K6aP02
0=cLg0070<30`02`/;00d=3@0<G5a@3?cll0bLW90>g]k@020=_Kf`070;Vi^@3Ng]h0b<S80;>c/`30
`<00`L710;Jf]P020<C4a0040<g=c@2l_;`0c/k>0<71`B@0oooo>`2P?ol00`3o0000X3oo0:0oo`02
0:0oo`030?l0002P?ol0X3oo01h0X3oo00<0Oooo0:0oo`2P?ol03`2P?ol00`1oool0X3oo0:0oo`0:
0:0oo`050?l0002P?ol0X3oo0:0oo`3o00002`2P?olW0?ooo`009@3oool00`2m_Kd0]kNg0;Bd]002
0;Vi^@070;no_`33`l<0^[Zj0;Zj^P2b/[80aLG50;:b/P020<K6aP070<O7a`2m_Kd0_Kfm0<k>cP33
`l<0_[jn0;Zj^P020<_;b`070;Jf]P3=cLd0alO70<;2`P33`l<0bLW90;Ng]`020;fm_@030<;2`P2n
_[h0Zj^[0080_kno00/0/K6a0<c<c030`<00`<300:j^[P2h^;P0][Jf0;no_`3;bl/0cLg=0<_;b`02
0?7al@070=gMg@3Kfm/0`<300<S8b03;bl/0/[:b0;Zj^P020<o?c`070<?3``3;bl/0`/;20<c<c02l
_;`0`l?30=oOg`020<[:bP060=_Kf`32`/80][Jf0<K6aP39bLT0_[jn0`2l_;`01`2^[Zh0d=3@0<71
`@2j^[X0bLW90;no_`31`L400P39bLT01`3>c/h0][Jf0<;2`P2n_[h0];Bd0<g=c@3@d=000P33`l<0
0`2b/[80`<300:ZZZP020<;2`P080<?3``3=cLd0];Bd0;Bd]02b/[80[Jf]0;^k^`34a<@20<30`00:
0=gMg@3EeMD0eMGE0;jn_P2JVYX0d];B0;Rh^02c/k<0]KFe0<W9b@80bl_;00L0bLW90=KFeP2g]kL0
c/k>0:f][@2i^KT0Zj^[0080`<3000L0/[:b0<K6aP39bLT0bl_;0<k>cP37alL0clo?0080][Jf00@0
aLG50;^k^`33`l<0/[:b903oool`0:0oo`<0o`003P2P?ol00`3o0000X3oo0:0oo`0Z0:0oo`050?l0
002P?ol0X3oo0:0oo`1oool07@2P?olW0?ooo`009@3oool00`2m_Kd0[:b/0<O7a`020:BTY0070;Vi
^@2g]kL0bLW90<30`031`L40]kNg0:ZZZP020<o?c`070<K6aP2f][H0a<C40<W9b@33`l<0`L710<K6
aP020<S8b0050<;2`P38b<P0b/[:0=3@d02i^KT00P35aLD20:f][@070;Zj^P2d];@0aLG50<g=c@2b
/[80`L710;jn_P020;Zj^P070;Vi^@39bLT0`l?30;Rh^03;bl/0`<300<W9b@020<o?c`070:ZZZP34
a<@0c<c<0:f][@2f][H0clo?0<g=c@020;Jf]P070<G5a@3:b/X0/;2`0<O7a`2l_;`0^[Zj0;2`/002
0;bl_0070<S8b03AdM40`/;20:n_[`3=cLd0][Jf0:>SX`020;bl_0030<[:bP2k^k/0_Kfm0080_Kfm
00T0cLg=0;2`/03Cdm<0dm?C0=7Ad@3:b/X0bLW90;jn_P3EeMD00P3<c<`20;jn_P0709nOW`32`/80
];Bd0<30`02NWYh0alO70:NWY`020<[:bP040<c<c02i^KT0_;bl0;^k^`80_kno00X0nOWi0:RXZ02X
Z:P0XJ6Q0;no_`2:RXX0alO70;Zj^P32`/80^k^k0P3EeMD01`3Jf]X0_;bl0;Bd]02n_[h0bl_;0<g=
c@2g]kL00P2LW9`01`3Ph>00aLG50;bl_02XZ:P0`l?30<o?c`2h^;P00P32`/80103?cll0aLG50<k>
cP2j^[XT0?ooo`<0X3oo0P1ooom50:0oo`0307ooo`2P?ol0X3oo0180X3oo00D0Oooo0:0oo`2P?ol0
X3oo07ooo`0:0:0oo`060?l0002P?ol0X3oo07ooo`2P?ol0Oooo3@2P?ol207ooo`030?l0002P?ol0
X3oo00X0X3oo9`3oool002D0oooo00<0_Kfm0:b/[037alL00P2TY:@01`2i^KT0]kNg0<W9b@30`<00
`L710;Ng]`2ZZZX00P3?cll01`36a/H0][Jf0<C4a039bLT0`l?30<71`@36a/H00P38b<P01@32`/80
b<S80<[:bP3@d=00^KVi0080aLG50P2][Jd01`2j^[X0];Bd0<G5a@3=cLd0/[:b0<71`@2n_[h00P2j
^[X01`2i^KT0bLW90<?3``2h^;P0bl_;0<30`039bLT00P3?cll01`2ZZZX0a<C40<c<c02][Jd0][Jf
0<o?c`3=cLd00P2f][H01`35aLD0b/[:0;2`/037alL0_;bl0;Zj^P2`/;000P2l_;`01`38b<P0dM7A
0<;2`P2_[jl0cLg=0;Jf]P2SXj<00P2l_;`00`3:b/X0^k^k0;fm_@020;fm_@090<g=c@2`/;00dm?C
0=?Cd`3AdM40b/[:0<W9b@2n_[h0eMGE0080c<c<0P2n_[h01`2OWil0`/;20;Bd]030`<00WYjN0<O7
a`2WYjL00P3:b/X0103<c<`0^KVi0;bl_02k^k/20;no_`0:0?Win@2XZ:P0Z:RX0:6QX@2o_kl0RXZ:
0<O7a`2j^[X0`/;20;^k^`80eMGE00L0f][J0;bl_02d];@0_[jn0<_;b`3=cLd0]kNg0080W9bL00L0
h>3P0<G5a@2l_;`0Z:RX0<?3``3?cll0^;Rh0080`/;200@0clo?0<G5a@3>c/h0^[Zj903oool30:0o
o`80OoooA@2P?ol00`1oool0X3oo0:0oo`0B0:0oo`0507ooo`2P?ol0X3oo0:0oo`1oool02P2P?ol0
1P3o0000X3oo0:0oo`1oool0X3oo07ooo`d0X3oo0P1oool00`3o0000X3oo0:0oo`0:0:0oobL0oooo
000U0?ooo`030<[:bP3;bl/0_[jn0080bLW900L0][Jf0;jn_P30`<00]kNg0;Jf]P2j^[X0`/;20080
_[jn00L0`/;20<71`@30`<00XJ6Q0;Zj^P39bLT0alO70080bLW900L0_kno0<_;b`3;bl/0aLG50<;2
`P37alL0`<300080_[jn00L0][Jf0;jn_P2f][H0YJFU0<O7a`2^[Zh0bl_;0080bLW900L0aLG50<?3
``2k^k/0e=CD0<71`@3De=@0cLg=0080`/;200D0];Bd0:j^[P3?cll0_[jn0<W9b@020<?3``80ZZZZ
00L0a<C40<o?c`30`<00dM7A0;bl_02k^k/0YjNW0080dM7A00L0^;Rh0;no_`2^[Zh0PH610<W9b@32
`/80YjNW0080_;bl00L0e]KF0=GEe@3Cdm<0b/[:0;Vi^@2_[jl0VYZJ0080f][J00L0_;bl0<W9b@2o
_kl0_kno0;bl_03;bl/0gmoO0080/;2`00L0_;bl0<C4a02g]kL0^;Rh0<[:bP35aLD0]kNg0080^KVi
00@0aLG50<O7a`2f][H0eMGE0P3=cLd02P2n_[h0[jn_0:n_[`3Cdm<0aLG50<30`039bLT0Xj>S0;Bd
]03<c<`20<_;b`050<O7a`2b/[80`/;20<71`@37alL00P39bLT20;bl_0070<c<c02_[jl0dM7A0<G5
a@3AdM40g]kN0=GEe@020<;2`P040<[:bP3?cll0^KVi0;Jf]R@0oooo4@2P?ol00`1oool0X3oo0:0o
o`0c0:0oo`0307ooo`2P?ol0X3oo00T0X3oo00<0Oooo0:0oo`2P?ol01P2P?ol00`3o0000X3oo0:0o
o`0F0:0oo`0307ooo`2P?ol0X3oo0100X3oo00<0o`000:0oo`2P?ol01@2P?olW0?ooo`009@3oool0
0`33`l<0Zj^[0<O7a`020<?3``070;fm_@33`l<0`l?30:>SX`31`L40/[:b0:BTY0020<C4a0070<;2
`P3<c<`0_[jn0;fm_@3<c<`0a/K60:n_[`020:2PX0070<30`02b/[80^KVi0<O7a`2i^KT0clo?0<;2
`P020;bl_0070:JVYP2b/[80bLW90<?3``2i^KT0]kNg0:n_[`020=?Cd`070=7Ad@3Kfm/0YZJV0:BT
Y034a<@0aLG50;bl_0020;Vi^@070;jn_P38b<P0b/[:0<;2`P33`l<0^k^k0<S8b0020<c<c0070=KF
eP3WinL0`l?30<G5a@2f][H0W9bL0=_Kf`020;Vi^@070=KFeP3De=@0]kNg0<30`039bLT0/;2`0;Rh
^0020:f][@070=oOg`2k^k/0[:b/0;fm_@3;bl/0[jn_0<30`0020<W9b@070<30`02a/K40][Jf0<O7
a`3?cll0_[jn0;Ng]`020;2`/0070;Jf]P39bLT0c/k>0=oOg`2g]kL0f][J0;Bd]0020;^k^`070=SH
f02XZ:P0dM7A0<C4a02i^KT0b<S80=gMg@020:^[Z`070=CDe036a/H0bl_;0;Jf]P3De=@0`l?30<O7
a`020<G5a@070<c<c02h^;P0^k^k0<g=c@30`<00][Jf0<W9b@020<30`0070<71`@35aLD0`/;20<k>
cP2d];@0^KVi0<;2`P0209FEU@040<G5a@37alL0e=CD0;2`/2@0oooo202P?ol0101oool0X3oo0:0o
o`1oool90:0oo`80Oooo5@2P?ol00`1oool0X3oo0:0oo`0=0:0oo`050?l0002P?ol0X3oo0:0oo`1o
ool0302P?ol00`3o0000X3oo0:0oo`0B0:0oo`030?l0002P?ol0X3oo00T0X3oo00<0o`000:0oo`2P
?ol06@2P?ol207ooo`@0X3oo9`3oool002D0oooo00<0_[jn0<?3``3>c/h00P31`L401`37alL0`l?3
0<;2`P2n_[h0`<300<;2`P2n_[h00P3?cll01`39bLT0_;bl0<K6aP3@d=00^KVi0:f][@3>c/h00`30
`<001P2n_[h0^k^k0;fm_@2j^[X0[Jf]0<_;b`80^;Rh0P32`/801@30`<00bLW90;^k^`2k^k/0`<30
0080bl_;00L0c/k>0;Ng]`2i^KT0`/;20;6a/@2f][H0clo?0080_;bl00L0];Bd0:f][@3<c<`0aLG5
0=3@d03De=@0dM7A0080c<c<00L0dm?C0=GEe@30`<00_;bl0;2`/03EeMD0/;2`0080aLG500L0`L71
0;fm_@3<c<`0`l?30<g=c@33`l<0`<300080bLW900L0c/k>0;Bd]031`L40/k>c0<;2`P2UYJD0^;Rh
0080cLg=00L0XJ6Q0;jn_P2k^k/0ZZZZ0<K6aP2m_Kd0fm_K0080ZJVY00L0dm?C0<?3``2g]kL0`l?3
0<G5a@2i^KT0bl_;0080bLW900L0`l?30<G5a@30`<00/k>c0;2`/02WYjL0`/;20080^KVi00L0_;bl
0;Jf]P3>c/h0alO70<k>cP2`/;00Zj^[0080_;bl00D0aLG50:NWY`2g]kL0VYZJ0<K6aP020;Rh^080
][Jf00L0b<S80<k>cP2e]KD0^KVi0<c<c02l_;`0`l?30080b/[:00@0[jn_0:f][@32`/80OGem903o
oomF0:0oo`0307ooo`2P?ol0X3oo02@0X3oo00<0Oooo0:0oo`2P?ol03`2P?ol00`1oool0oooo0?oo
o`0U0?ooo`009@3oool00`2e]KD0^k^k0:j^[P020;Jf]P070;Rh^037alL0`<300<S8b03<c<`0_;bl
0<G5a@020<[:bP070<?3``35aLD0[jn_0<c<c033`l<0[jn_0:b/[0020<[:bP070<?3``32`/80b<S8
0<W9b@2k^k/0`l?30<[:bP020;jn_P070<[:bP3>c/h0[jn_0:j^[P2d];@0b<S80<O7a`020<k>cP07
0<_;b`2o_kl0c<c<0<;2`P37alL0a<C40=7Ad@020;Vi^@070:n_[`3EeMD0`l?30;Ng]`3:b/X0[:b/
0=3@d00208^;R`070<W9b@2g]kL0bLW90:>SX`33`l<0`L710<W9b@020;Rh^0070<;2`P3=cLd0bLW9
0<G5a@33`l<0[Jf]0<;2`P020=_Kf`070;no_`3Hf=P0alO70<_;b`2j^[X0aLG50:JVYP020;no_`07
0;^k^`1hN7P0^;Rh0<C4a039bLT0gmoO0>7Qh@020<?3``070;^k^`2o_kl0f][J0<W9b@3=cLd0_;bl
0<C4a0020<G5a@070;Vi^@3Fe]H0bLW90:RXZ02n_[h0c/k>0<O7a`030<W9b@80^k^k00@0gMgM0<G5
a@2CTi<0];Bd0P39bLT01`2a/K40_[jn0;Fe]@2ATI40^[Zj09^KV`30`<000P3:b/X01`33`l<0aLG5
0<G5a@3<c<`0`l?30=CDe03>c/h00P3=cLd0102f][H0aLG50;>c/`2ZZZXT0?ooocT0X3oo0P1oool3
0:0oo`0307ooo`2P?ol0X3oo01H0X3oo00@0Oooo0:0oo`2P?ol0X3oo0P3o000G0:0oo`030?l0002P
?ol0Oooo00H0X3oo00<0Oooo0:0oo`1oool0402P?olW0?ooo`009@3oool00`2g]kL0^k^k0=[JfP02
0;>c/`80^KVi00D0`L710;fm_@2i^KT0bLW90<O7a`020<[:bP070;bl_03;bl/0`l?30;Fe]@2i^KT0
b/[:0;^k^`020<K6aP070;^k^`3=cLd0b<S80<G5a@2g]kL0/K6a0<k>cP020=[JfP0309VIV@39bLT0
`l?30080_kno00/0Z:RX0<[:bP30`<00`<300<;2`P3:b/X0b<S80=7Ad@37alL0][Jf0=3@d0020;Vi
^@070:n_[`3:b/X0b/[:0<g=c@3@d=00c<c<0<;2`P020;Zj^P070<W9b@2d];@0[Jf]0=OGe`39bLT0
_kno0;^k^`020<k>cP070<W9b@3=cLd0bLW90;no_`2b/[80^KVi0;2`/0020;bl_0070<W9b@33`l<0
alO70;jn_P2l_;`0];Bd0<k>cP0208:2PP070<O7a`2RXZ80[Jf]0=7Ad@3EeMD0dM7A0<g=c@020;Vi
^@060<c<c039bLT0aLG50;Bd]031`L40bl_;0`2n_[h01`2j^[X0`<300:n_[`2BTY80bl_;0;Jf]P37
alL00P34a<@01`2l_;`0alO70:JVYP2`/;00clo?0<k>cP2QXJ400P2j^[X01`3=cLd0_[jn0<_;b`2^
[Zh0/[:b0<;2`P39bLT00P3;bl/01`3?cll0alO70<;2`P2n_[h0a<C40<[:bP30`<000P3<c<`0103>
c/h0e=CD0<30`02/[:`T0?ooob00X3oo00<0Oooo0:0oo`2P?ol0<@2P?ol207ooo`030:0oo`1oool0
X3oo0180X3oo00<0Oooo0:0oo`2P?ol02@2P?ol00`1oool0X3oo0:0oo`0F0:0oobL0oooo000U0?oo
o`030;:b/P2o_kl0`L710080`l?30P35aLD0103:b/X0][Jf0<;2`P32`/830<G5a@070;fm_@2d];@0
/k>c0;bl_02j^[X0^;Rh0<G5a@020;jn_P070:^[Z`2i^KT0][Jf0<O7a`2k^k/0`<300<;2`P020;Vi
^@0709fMW@2c/k<0_[jn0<71`@37alL0_Kfm0<c<c0020;jn_P070;fm_@3AdM40^k^k0=3@d034a<@0
d=3@0;Jf]P020=;BdP070<30`02][Jd0d];B0<W9b@3>c/h0c<c<0<71`@020<;2`P070<W9b@2o_kl0
_;bl0<C4a03AdM40`l?30<W9b@020;Bd]0070<?3``3?cll0];Bd0<71`@3;bl/0alO70;Bd]0020<G5
a@030<30`037alL0_[jn0080c<c<00/0a/K60:n_[`30`<00`<300;bl_02HV9P0_kno0<O7a`33`l<0
clo?0<30`0020;Vi^@070<_;b`2n_[h0`<300;Bd]02g]kL0a/K60<?3``020:n_[`80_[jn00D0[jn_
0;Rh^03Rh^80^k^k0:n_[`020<;2`P070<G5a@3Cdm<0`<300:FUY@3;bl/0ZJVY0:^[Z`020;Ng]`07
0<W9b@3AdM40bLW90<30`03Kfm/0kNg]0=;BdP020;2`/0070<;2`P2d];@0[Zj^0<71`@33`l<0`<30
0<;2`P020;:b/P040=?Cd`32`/80_kno0:b/[2@0oooo802P?ol00`1oool0X3oo0:0oo`0d0:0oo`03
07ooo`2P?ol0X3oo0180X3oo00<0o`000:0oo`2P?ol0402P?ol00`3o0000X3oo0:0oo`0>0:0oobL0
oooo000U0?ooo`030:b/[02g]kL0aLG50080WYjN00L0]KFe0;^k^`2XZ:P0_Kfm0<K6aP37alL0`/;2
0080/K6a00L0d=3@0<W9b@37alL0c<c<0:RXZ030`<00ZZZZ0080_;bl00L0bl_;0;^k^`2d];@0/k>c
0;Ng]`34a<@0alO70080^[Zj00L0_;bl0<c<c02g]kL0`<300;jn_P2ZZZX0];Bd00<0`l?300H0cLg=
0;Fe]@2b/[80c/k>0<O7a`31`L420<;2`P060;bl_03?cll0dM7A0;Vi^@2b/[80f=SH0`3:b/X01`39
bLT0Xj>S0=GEe@2YZJT0`l?30>g]k@2j^[X00P35aLD01`3:b/X0];Bd0<G5a@33`l<0[Jf]0<30`03<
c<`00P2h^;P01`2_[jl0bLW90<k>cP39bLT0f=SH0<71`@35aLD00P31`L401`2e]KD0X:2P0<g=c@35
aLD0alO70;Vi^@2GUiL00P3YjNT01@33`l<0bLW90;Ng]`2_[jl0dm?C0080_[jn0P37alL01`2m_Kd0
c<c<0<W9b@2KVi/0[jn_0;Fe]@32`/800P2n_[h01`3?cll0_kno0=oOg`32`/80XZ:R0<;2`P30`<00
0P33`l<01`39bLT0_Kfm0;fm_@32`/80_;bl0;Zj^P3:b/X00P2e]KD00`3<c<`0a/K60=?Cd`020<G5
a@080<[:bP30`<00[Jf]0:f][@3?cll0XZ:R0;^k^`37alLT0?ooo`<0X3oo0P1ooolg0:0oo`0507oo
o`2P?ol0X3oo0:0oo`3o00005P2P?ol00`1oool0X3oo0:0oo`020:0oo`0307ooo`3o0000o`0000`0
X3oo00<0Oooo0:0oo`2P?ol01@2P?ol00`3o0000X3oo07ooo`0G0:0oo`0307ooo`2P?ol0X3oo02L0
oooo000U0?ooo`030;Ng]`2j^[X0aLG50080^[Zj00L0b/[:0<O7a`2n_[h0];Bd0;bl_034a<@0`L71
0080YJFU00L0c<c<0;Jf]P35aLD0e=CD0:ZZZP2WYjL0^;Rh0080/k>c00D0/K6a0;no_`37alL0_[jn
0=SHf0040<?3``070;Bd]033`l<0^k^k0<71`@32`/80^k^k0<W9b@020;>c/`070;Rh^03EeMD0clo?
0<S8b02g]kL0];Bd0<?3``0209nOW`070<30`02d];@0aLG50<G5a@3no_h0<c<c0:FUY@0209FEU@07
0<?3``37alL0_kno0;^k^`2b/[80alO70=?Cd`020<g=c@070;Rh^030`<00/k>c0<W9b@37alL0Zj^[
0<O7a`020;Zj^P070<g=c@2o_kl0[Zj^0;bl_02k^k/0bLW90;no_`020;fm_@070<30`02QXJ40]kNg
092@T03De=@0^KVi0:^[Z`030<G5a@060;2`/035aLD0^;Rh0:6QX@35aLD0alO70P2n_[h01`39bLT0
_;bl0;bl_032`/80alO70<71`@3;bl/00P2`/;001`2k^k/0_kno0<[:bP38b<P0^;Rh0:BTY02BTY80
0P2/[:`01`35aLD0f=SH0<O7a`2_[jl0_;bl0;:b/P37alL00P3<c<`00`2m_Kd0`l?30;jn_P020;jn
_P080<g=c@3AdM40f][J0=[JfP3;bl/0^;Rh0;>c/`2WYjLT0?oooc00X3oo0P1oool40:0oo`030?l0
003oool0X3oo0080Oooo702P?ol00`1oool0X3oo07ooo`090:0oo`0307ooo`2P?ol0X3oo0100X3oo
0P1ooolH0:0oobL0oooo000U0?ooo`030;Ng]`2j^[X0aLG50080^[Zj00L0b/[:0<O7a`2n_[h0];Bd
0;bl_034a<@0`L710080YJFU00L0c<c<0;Jf]P35aLD0e=CD0:ZZZP2WYjL0^;Rh0080/k>c00D0/K6a
0;no_`37alL0_[jn0=SHf0040<?3``070;Bd]033`l<0^k^k0<71`@32`/80^k^k0<W9b@020;>c/`07
0;Rh^03EeMD0clo?0<S8b02g]kL0];Bd0<?3``0209nOW`070<30`02d];@0aLG50<G5a@3no_h0<c<c
0:FUY@0209FEU@070<?3``37alL0_kno0;^k^`2b/[80alO70=?Cd`020<g=c@070;Rh^030`<00/k>c
0<W9b@37alL0Zj^[0<O7a`020;Zj^P070<g=c@2o_kl0[Zj^0;bl_02k^k/0bLW90;no_`020;fm_@07
0<30`02QXJ40]kNg092@T03De=@0^KVi0:^[Z`030<G5a@060;2`/035aLD0^;Rh0:6QX@35aLD0alO7
0P2n_[h01`39bLT0_;bl0;bl_032`/80alO70<71`@3;bl/00P2`/;001`2k^k/0_kno0<[:bP38b<P0
^;Rh0:BTY02BTY800P2/[:`01`35aLD0f=SH0<O7a`2_[jl0_;bl0;:b/P37alL00P3<c<`00`2m_Kd0
`l?30;jn_P020;jn_P080<g=c@3AdM40f][J0=[JfP3;bl/0^;Rh0;>c/`2WYjLT0?oooc00X3oo0P1o
ool40:0oo`030?l0003oool0X3oo0080Oooo702P?ol00`1oool0X3oo07ooo`090:0oo`0307ooo`2P
?ol0X3oo0100X3oo0P1ooolH0:0oobL0oooo000U0?ooo`030<30`02k^k/0_[jn0080alO700L0`l?3
0<O7a`2g]kL0`<300<71`@3>c/h0b/[:0080cLg=00L0`<300;^k^`39bLT0^KVi0:b/[029RHT0NGUi
0080^KVi00L0X:2P0=;BdP33`l<0`/;20<O7a`2m_Kd0a<C40080emOG00L0[Zj^0<k>cP2d];@0][Jf
0<30`03Jf]X0bLW90080alO700@0dm?C0<G5a@3AdM40alO70P2k^k/02P2d];@0`l?30<?3``3;bl/0
`<300;Vi^@2ZZZX0/;2`09BDU03:b/X20;Rh^0070:n_[`3Fe]H0`/;20;jn_P3>c/h0aLG50<30`002
0<K6aP070;>c/`3:b/X0`l?30=SHf03>c/h0][Jf09nOW`020;2`/080_[jn00D0a/K60;jn_P3?cll0
bl_;0<G5a@020<;2`P0709ZJVP2i^KT0WinO0:BTY02b/[80`<300;Bd]0020=oOg`070=?Cd`3>c/h0
TI6A0:RXZ03:b/X0/[:b0<71`@020<o?c`070<g=c@2n_[h0/[:b0;Jf]P39bLT0];Bd09jNWP020=SH
f0070;bl_032`/80Rh^;0<71`@2ZZZX0/K6a0:n_[`020=CDe0070:>SX`2_[jl0YZJV0;jn_P3Jf]X0
`L710;Jf]P020;Bd]0070<W9b@35aLD0/;2`0<G5a@3AdM40b/[:0<W9b@030<O7a`80`/;200<0ZZZZ
0?ooo`3oool08P3ooolC0:0oo`80Oooo0P2P?ol00`1oool0X3oo0:0oo`0M0:0oo`0307ooo`2P?ol0
X3oo0100X3oo00<0Oooo0:0oo`2P?ol02@2P?ol0101oool0X3oo07ooo`1oool30:0oo`80o`000P2P
?ol00`1oool0X3oo0:0oo`0:0:0oo`0307ooo`2P?ol0X3oo0080X3oo00<0Oooo0:0oo`2P?ol0102P
?ol00`1oool0X3oo0:0oo`0C0:0oobL0oooo000U0?ooo`030<30`02f][H0^k^k0080^KVi00L0/k>c
0<k>cP2i^KT0a/K60<;2`P39bLT0alO70080bLW900L0]KFe0<30`02j^[X0_;bl0<K6aP2a/K40`/;2
0080aLG500H0]kNg0<;2`P2f][H0]kNg0<C4a03Fe]H30;bl_0070<71`@2b/[80`<300=GEe@2n_[h0
Z:RX0<?3``020<G5a@070;^k^`2OWil0dM7A0<?3``37alL0[jn_0;Bd]0020<?3``050<k>cP3De=@0
`L710<71`@2n_[h00P37alL20:f][@070;fm_@2g]kL0aLG50<;2`P2f][H0gmoO0:^[Z`020<O7a`05
0;:b/P2QXJ40][Jf0<W9b@2n_[h00P2d];@20<W9b@070;Rh^039bLT0alO70<71`@2m_Kd0c<c<0<_;
b`020;6a/@070<G5a@2i^KT0Shn?0:n_[`3;bl/0[Jf]0<o?c`020;no_`070;jn_P2`/;00][Jf0<o?
c`35aLD0`<300;Zj^P020<k>cP070;bl_02f][H0YZJV0<[:bP3EeMD0/[:b0;no_`020;jn_P070<[:
bP32`/80bLW90;fm_@2g]kL0Rh^;0;^k^`020;no_`070;jn_P3=cLd0/[:b0<W9b@26QXH0^KVi0<W9
b@020<G5a@070<30`039bLT0bLW90<G5a@33`l<0bl_;09^KV`020;^k^`040<c<c02o_kl0_Kfm0:VY
ZB@0oooo:P2P?ol00`1oool0X3oo0:0oo`0C0:0oo`030?l0002P?ol0X3oo0080X3oo00<0Oooo0:0o
o`2P?ol0402P?ol00`1oool0X3oo0:0oo`0K0:0oo`0307ooo`2P?ol0X3oo00D0X3oo00<0Oooo0:0o
o`2P?ol0202P?ol00`1oool0X3oo0:0oo`040:0oobL0oooo000U0?ooo`030:n_[`2k^k/0]kNg0080
_;bl00L0_[jn0<O7a`2d];@0Xj>S0;jn_P2o_kl0^k^k0080_;bl00L0Xj>S0<W9b@2b/[80`l?30;no
_`38b<P0`/;20080clo?00L0`l?30;fm_@37alL0b/[:0<k>cP2l_;`0]kNg0080_Kfm00<0]kNg0<c<
c032`/800P2n_[h02`3;bl/0_;bl0;Bd]02d];@0bLW90<G5a@2h^;P0][Jf0<30`02UYJD0][Jf0080
aLG500L0][Jf0;Vi^@34a<@0]kNg0<;2`P39bLT0alO70080f][J00L0gMgM0=3@d033`l<0^k^k0;no
_`3;bl/0f=SH0080Z:RX00L0/[:b0:ZZZP2l_;`0fm_K0<[:bP2m_Kd0bLW90080][Jf00L0]KFe0<[:
bP3=cLd0d];B0<G5a@2_[jl0VYZJ0080e]KF00L0b/[:0<G5a@2m_Kd0[jn_0<O7a`2e]KD0dm?C0080
a/K600L0]KFe0<c<c02g]kL0`<3009nOW`3GemL0_;bl0080/k>c00L0Z:RX0;2`/039bLT0e]KF0;Rh
^02o_kl0[Zj^0080ZJVY00L0`/;209nOW`2KVi/0`/;20;Bd]02j^[X0_Kfm0080`l?300L0Zj^[09>C
T`2k^k/0^k^k0<G5a@39bLT0_;bl0080_Kfm00L0b<S80<W9b@36a/H0b/[:0<k>cP3EeMD0aLG50080
kNg]00@0/;2`0;Ng]`2SXj<0WinO903oool80:0oo`0307ooo`2P?ol0X3oo00<0X3oo00<0Oooo0:0o
o`2P?ol0:P2P?ol00`3o0000X3oo0:0oo`0E0:0oo`0307ooo`2P?ol0X3oo00d0X3oo00<0Oooo0:0o
o`2P?ol0302P?ol207ooo`L0X3oo00<0Oooo0:0oo`2P?ol0302P?ol20?l00080X3oo0P1ooolW0?oo
o`009@3oool00`2b/[80]KFe0:n_[`020;Jf]P070<C4a031`L40`/;20<?3``2f][H0^KVi0;:b/P02
0<30`0070:FUY@2YZJT0bLW90<?3``39bLT0^[Zj0<O7a`020;Bd]0070<30`03>c/h0bLW90;6a/@3?
cll0`<300<?3``020;no_`070<?3``3>c/h0`/;20<;2`P37alL0`/;20;Jf]P020;Vi^@070<;2`P2f
][H0_;bl0<[:bP3EeMD0`<300<O7a`020;>c/`070<;2`P34a<@0bLW90<_;b`3=cLd0`<300<;2`P02
0<?3``070=SHf02d];@0]kNg0=7Ad@2h^;P0bLW90<S8b0020<30`0070;^k^`3Cdm<0`L710;Ng]`3=
cLd0_[jn0<K6aP020;Rh^0070<71`@2WYjL0]kNg0<30`033`l<0alO70;>c/`020;^k^`070=?Cd`37
alL0^k^k0:FUY@2a/K40dm?C0<O7a`020>_[j`070:n_[`3>c/h0]KFe0;Vi^@2_[jl0`/;20;Vi^@02
09FEU@0708R8R02d];@0]KFe0<O7a`30`<00`l?30<o?c`020:NWY`070;Jf]P2k^k/0ZZZZ0;jn_P2^
[Zh0aLG50<C4a0020;jn_P070;Jf]P33`l<0c<c<0;^k^`2j^[X0c/k>0<c<c0020=;BdP030<S8b03H
f=P0a/K600<0b/[:00L0^KVi0<W9b@39bLT0]kNg0;no_`3MgMd0/[:b02@0ooooG@2P?ol20?l000L0
X3oo0`1ooolU0:0oo`030?l0002P?ol0oooo02H0oooo000U0?ooo`030;Bd]02a/K40^;Rh0080`<30
00D0[jn_0;2`/030`<00_;bl0;fm_@020<O7a`80[Zj^00@0^KVi0:j^[P35aLD0`L710P30`<002P33
`l<0bLW90<W9b@37alL0Xj>S0;fm_@37alL0^[Zj0:n_[`35aLD20<W9b@070<71`@2d];@0^k^k0<K6
aP35aLD0_kno0;jn_P020=GEe@050=WIf@3Jf]X0fMWI0<?3``2f][H00P33`l<20;Ng]`070;^k^`2X
Z:P0/[:b0<G5a@33`l<0clo?0;2`/0020<W9b@060<G5a@3EeMD0^KVi0;Bd]03?cll0dm?C0`32`/80
1`2UYJD0[jn_0<;2`P32`/80cLg=0;Jf]P2VYZH00P2j^[X01@2o_kl0bl_;0<;2`P2l_;`0bl_;0080
`L710P36a/H01`3Fe]H0aLG50=?Cd`2_[jl0c/k>0<G5a@3<c<`00P2`/;001`33`l<0alO709ZJVP2o
_kl0RHV90=?Cd`37alL00P2^[Zh01`2UYJD0^;Rh0;bl_02g]kL0`/;20<30`02e]KD00P30`<001`2_
[jl0Z:RX0;Ng]`2h^;P0[:b/0;Vi^@33`l<00P2f][H01`39bLT0clo?0;Fe]@2n_[h0bl_;0<W9b@3?
cll00P2d];@01`3?cll0/k>c05=CD`2n_[h0_;bl0<?3``3:b/X00P33`l<0102m_Kd0b/[:0<W9b@37
alLT0?oooaP0X3oo00<0Oooo0:0oo`2P?ol0AP2P?ol00`1oool0X3oo07ooo`0Q0:0oo`030>3o`02P
?ol0X3oo00P0X3oo9`3oool002D0oooo00<0`l?30:b/[02d];@00P2i^KT01`36a/H0bLW90;no_`2Q
XJ40bLW90;Jf]P35aLD00P2j^[X00`32`/80][Jf0;Bd]0020<30`00;0;fm_@30`<00a/K60<K6aP2k
^k/0[Jf]0>WYj@2d];@0_kno0;jn_P1dM7@00P2k^k/01`33`l<0_[jn0;fm_@2g]kL0];Bd0;2`/03A
dM400P3<c<`01@3Ogml0eMGE0<?3``2d];@0`l?30080_[jn0P38b<P01`30`<00]KFe0=GEe@2n_[h0
d=3@0=[JfP3Vi^H00P3>c/h01`2RXZ80`<300;Rh^037alL0c<c<0=?Cd`2m_Kd00P37alL01`3>c/h0
dM7A0;^k^`2f][H0V9RH0:6QX@2d];@00P2YZJT01`30`<00aLG50<W9b@35aLD0bLW90=?Cd`3;bl/0
0P2ZZZX01`2f][H0`<300<O7a`2i^KT0_kno0=CDe02VYZH00P2HV9P01`2l_;`0_[jn0:^[Z`2QXJ40
UiNG09ZJVP2k^k/00P22PX801`2LW9`0alO70;fm_@2o_kl0a/K60<30`03Kfm/00P2l_;`01`32`/80
a<C409ZJVP2JVYX0Xj>S0;jn_P35aLD00P37alL01`2j^[X0_;bl0<c<c036a/H0e=CD0<G5a@33`l<0
0P3EeMD01`39bLT0_kno0;Ng]`2i^KT0`<300:f][@2g]kL00P35aLD0103:b/X0alO70;Jf]P39bLTT
0?ooo`P0X3oo00<0Oooo0:0oo`2P?ol03P2P?ol01@3o0000X3oo0:0oo`2P?ol0Oooo00/0X3oo00<0
o`000:0oo`2P?ol0302P?ol0103o0000X3oo0:0oo`1oool<0:0oo`80Oooo4`2P?ol207ooo`<0X3oo
0`1oool0102P?ol0Oooo07ooo`1oool:0:0oo`<0Oooo6P2P?olW0?ooo`009@3oool00`2d];@0[:b/
0;fm_@020:^[Z`070;Rh^02d];@0^k^k0;no_`3Fe]H0dM7A0<O7a`020:f][@070;Bd]02l_;`0^KVi
0<C4a02NWYh0_kno0;^k^`020:ZZZP0709nOW`35aLD0[Jf]0<S8b02i^KT0_;bl0:NWY`020;fm_@07
0<?3``30`<00b<S80;:b/P34a<@0gMgM0<[:bP020;Rh^00608R8R01ZJVX0ZJVY0;jn_P39bLT0alO7
0`2j^[X01039bLT0a<C40;Ng]`32`/820<[:bP0:0;fm_@37alL0alO70<o?c`3>c/h0[Jf]09^KV`2a
/K40ZJVY0<_;b`80_;bl00H0`/;20<[:bP39bLT0^KVi0<G5a@2n_[h30<G5a@030<k>cP2][Jd0^k^k
0080alO700/0clo?0<K6aP3:b/X0b/[:09nOW`2g]kL0_;bl0<?3``3;bl/0/K6a0:b/[0020:n_[`07
0;^k^`33`l<0^KVi0<o?c`2a/K40ZZZZ0<;2`P0208N7Q`0708F5Q@2a/K40cLg=0=KFeP2PX:00`/;2
0:b/[0020;bl_0070;2`/03>c/h0]kNg0<?3``2i^KT0alO709^KV`030<C4a0060<30`03Ogml0_;bl
0<O7a`2f][H0^;Rh0P32`/801`31`L40];Bd0=7Ad@31`L40[jn_0=GEe@2l_;`00P2k^k/0103De=@0
`/;20>3Ph02QXJ4T0?oooa80X3oo00<0Oooo0:0oo`2P?ol00P2P?ol00`1oool0X3oo0:0oo`0;0:0o
o`060?l0002P?ol0X3oo0:0oo`1oool0h?o04`2P?ol00`1oool0X3oo0:0oo`0E0:0oo`0307ooo`2P
?ol0X3oo00d0X3oo0`1oool30:0oo`0307ooo`2P?ol0X3oo00P0X3oo00<0Oooo0:0oo`2P?ol00P2P
?ol00`3o0000X3oo0:0oo`0?0:0oo`030?l0001oool0oooo02H0oooo000U0?ooo`030:f][@2k^k/0
]KFe0080^k^k00L0Zj^[0;Vi^@2j^[X0`l?30<G5a@37alL0a/K60080Z:RX00L0][Jf0<?3``2i^KT0
[jn_0;Bd]02o_kl0];Bd0080^KVi00L0^[Zj0<k>cP3>c/h0][Jf0:n_[`30`<00^[Zj0080`/;200L0
^[Zj0:JVYP2YZJT0_[jn0<_;b`2b/[80_;bl0080Ti>C00L0aLG50<c<c03@d=00][Jf0=GEe@2f][H0
eMGE0080[Jf]00L0`l?30;Fe]@3>c/h0gMgM0;Zj^P2g]kL0`L7100<0^;Rh00H0a/K60<W9b@2g]kL0
c<c<0<?3``32`/820<_;b`070<g=c@35aLD0`l?30<c<c039bLT0][Jf0:j^[P020:ZZZP050;Zj^P35
aLD0^KVi0<k>cP2j^[X00P32`/820;Fe]@070=?Cd`2e]KD0`l?30<[:bP37alL0^KVi09fMW@020<W9
b@070;fm_@2][Jd0_kno0<?3``2a/K40b<S809>CT`0209RHV0040;:b/P39bLT0_[jn0<?3``80^;Rh
00X0bl_;0<?3``33`l<0^KVi0<30`035aLD0^k^k0<k>cP35aLD0^KVi0P2g]kL01`3>c/h0`<300;Vi
^@2h^;P0clo?0;Ng]`3WinL00P37alL01`2n_[h0b/[:0;^k^`33`l<0bLW90<O7a`39bLT00P3Lg=`0
103AdM40`/;20;Bd]033`l<T0?ooobL0X3oo0P1oool<0:0oo`030?l0002P?ol0X3oo02@0X3oo00<0
Oooo0:0oo`2P?ol01P2P?ol307oooaP0X3oo00<0o`000:0oo`2P?ol03@2P?olW0?ooo`009@3oool0
0`2][Jd0^k^k0;Fe]@020;^k^`070:^[Z`2i^KT0^[Zj0<?3``35aLD0alO70<K6aP020:RXZ0070;Jf
]P33`l<0^KVi0:n_[`2d];@0_kno0;Bd]0020;Vi^@070;Zj^P3>c/h0c/k>0;Jf]P2_[jl0`<300;Zj
^P020<;2`P070;Zj^P2VYZH0ZJVY0;jn_P3;bl/0/[:b0;bl_00209>CT`070<G5a@3<c<`0d=3@0;Jf
]P3EeMD0][Jf0=GEe@020:f][@070<?3``2e]KD0c/k>0=gMg@2j^[X0]kNg0<71`@030;Rh^0060<K6
aP39bLT0]kNg0<c<c033`l<0`/;20P3;bl/01`3=cLd0aLG50<?3``3<c<`0bLW90;Jf]P2^[Zh00P2Z
ZZX01@2j^[X0aLG50;Vi^@3>c/h0^[Zj0080`/;20P2e]KD01`3Cdm<0]KFe0<?3``3:b/X0alO70;Vi
^@2MWId00P39bLT01`2m_Kd0[Jf]0;no_`33`l<0/K6a0<S8b02CTi<00P2HV9P0102b/[80bLW90;jn
_P33`l<20;Rh^00:0<_;b`33`l<0`l?30;Vi^@30`<00aLG50;^k^`3>c/h0aLG50;Vi^@80]kNg00L0
c/k>0<30`02i^KT0^;Rh0<o?c`2g]kL0inOW0080alO700L0_[jn0<[:bP2k^k/0`l?30<W9b@37alL0
bLW90080g=cL00@0dM7A0<;2`P2d];@0`l?3903ooolW0:0oo`80Oooo302P?ol00`3o0000X3oo0:0o
o`0T0:0oo`0307ooo`2P?ol0X3oo00H0X3oo0`1ooolH0:0oo`030?l0002P?ol0X3oo00d0X3oo9`3o
ool002D0oooo00<0_;bl0<G5a@2b/[800P2/[:`01`2i^KT0f][J0=;BdP2m_Kd0`l?30;^k^`33`l<0
0P2i^KT01`2ZZZX0cLg=0;Ng]`33`l<0]kNg0<c<c033`l<00P31`L401`2n_[h0aLG50;Zj^P2`/;00
`<300;Bd]030`<000P3=cLd01@2m_Kd0];Bd0;no_`30`<00][Jf0080WYjN0P25QHD01`2f][H0_[jn
0=?Cd`2j^[X0aLG50;bl_02d];@00P3<c<`01`33`l<0c<c<0<o?c`39bLT0WYjN0<?3``3GemL00P3A
dM401`35aLD0_[jn0<_;b`3AdM40^k^k0=7Ad@3?cll00`39bLT01P3Ogml0c/k>0;Bd]02l_;`0aLG5
0:RXZ080_;bl00L0e=CD0<71`@3<c<`0aLG50<30`02j^[X0`<300080`l?300L0XZ:R0=_Kf`2[Zj/0
/[:b0<o?c`3YjNT0OGem0080e]KF00L0XJ6Q0<c<c02g]kL0^k^k0;Vi^@2d];@0ZZZZ0080WinO00L0
gmoO0<[:bP33`l<0W9bL0;2`/02f][H0`<300080eMGE00L0[jn_0=GEe@3Kfm/0^k^k0<71`@2g]kL0
a/K60080fm_K00L0c<c<0<_;b`3UiND0/[:b0;Zj^P2o_kl0XJ6Q0080/;2`00L0`/;20;Bd]02n_[h0
dm?C0;jn_P3=cLd0dM7A0080YJFU00@0cLg=09JFUP36a/H0_Kfm903ooolU0:0oo`@0Oooo3@2P?ol0
0`1oool0X3oo0:0oo`0<0:0oo`030?l0002P?ol0X3oo00h0X3oo00<0Oooo0:0oo`2P?ol00P2P?ol0
1@3o0000Oooo0:0oo`2P?ol0Oooo00H0X3oo0P1oool0103o0000X3oo0:0oo`1oool@0:0oo`050?l0
002P?ol0X3oo0:0oo`1oool0302P?ol00`1oool0X3oo0:0oo`0W0?ooo`009@3oool00`2k^k/0^KVi
0;bl_0020<[:bP0709VIV@2`/;00^k^k0;fm_@2n_[h0^k^k0=OGe`020;Bd]0070;:b/P2o_kl0/;2`
0;6a/@3?cll0`l?30;fm_@020<K6aP070<?3``2b/[80`<300<W9b@35aLD0bl_;0<W9b@020;^k^`07
0;no_`3<c<`0`l?30<o?c`37alL0Z:RX0:f][@020<c<c0070<W9b@2h^;P0_kno0<O7a`2b/[80b/[:
0;Ng]`020<k>cP070<W9b@30`<00aLG50;Jf]P2o_kl0dM7A0<_;b`020<O7a`80c<c<00D0`L710<O7
a`2l_;`0clo?0=;BdP020<?3``070;Jf]P3Fe]H0S8b<0<30`03EeMD0/[:b09ZJVP020;:b/P070<S8
b03?cll0`/;20;jn_P34a<@0WinO0;Bd]0020<O7a`070<?3``30`<00clo?0<;2`P2][Jd0[jn_09bL
W0020=[JfP070<;2`P3QhN40^k^k0;Vi^@2TY:@0f=SH0<G5a@020:VYZ@0708V9R@31`L40bl_;09jN
WP3=cLd0_[jn0>;RhP020=KFeP050;Ng]`37alL0^;Rh0=KFeP2^[Zh00P35aLD20<71`@070;fm_@3:
b/X0_[jn0<71`@2_[jl0clo?0<_;b`020:BTY0070:RXZ030`<00`<300;bl_030`<00dM7A0;Bd]002
0<30`0040<?3``37alL0`l?30;:b/R@0oooo1@2P?ol00`1oool0X3oo0:0oo`0n0:0oo`0507ooo`2P
?ol0X3oo0:0oo`1oool01`2P?ol00`1oool0X3oo0:0oo`070:0oo`0507ooo`2P?ol0X3oo0:0oo`3o
00000P2P?ol00`1oool0X3oo0:0oo`020:0oo`0407ooo`2P?ol0X3oo07ooo`80X3oo00<0o`000:0o
o`2P?ol0402P?ol207ooo`d0X3oo9`3oool002D0oooo00<0^KVi0<30`037alL00P33`l<01@39bLT0
[Zj^0:n_[`2m_Kd0_kno0080aLG50P2SXj<0102d];@0][Jf0<C4a035aLD20<O7a`0:0<S8b035aLD0
aLG50;Ng]`39bLT0aLG50<C4a02a/K40fMWI0<G5a@80^[Zj00L0[Zj^0<O7a`2OWil0alO70=3@d032
`/80^;Rh0080^KVi00L0aLG50<?3``2l_;`0];Bd0;Zj^P32`/80_[jn0080c/k>00L0`/;20<S8b02l
_;`0bLW90<g=c@2XZ:P0clo?0080aLG500L0clo?0=7Ad@3?cll0d=3@0::RXP30`<00a<C40080[jn_
00L0NGUi0:VYZ@2c/k<0^k^k0<W9b@2][Jd0aLG50080alO700L0`/;20<o?c`2f][H0_;bl0<;2`P2[
Zj/0^k^k0080WinO00L0eMGE0<o?c`2l_;`0`/;20=?Cd`2h^;P0`l?30080U9BD00L0VYZJ0:FUY@2d
];@0];Bd0:2PX02;Rh/0ZJVY0080XJ6Q00L0];Bd0=?Cd`35aLD0bLW90;bl_03Vi^H0Xj>S0080][Jf
00L0]kNg0<G5a@2b/[80YjNW0;2`/02d];@0eMGE0080[jn_00L0clo?0;:b/P2j^[X0a/K60<W9b@33
`l<0f][J0080clo?00L0aLG50=?Cd`2n_[h0^[Zj0;Rh^035aLD0alO70080_kno00@0][Jf0;jn_P2i
^KT0][Jf903oool<0:0oo`80Oooo502P?ol00`1oool0X3oo0:0oo`0J0:0oo`0307ooo`2P?ol0X3oo
0080X3oo00<0Oooo0:0oo`2P?ol03@2P?ol207ooo`L0X3oo0`1oool30:0oo`80Oooo00<0X3oo07oo
o`1oool01@2P?ol00`3o0000Oooo0:0oo`0P0:0oobL0oooo000U0?ooo`030;Vi^@34a<@0`/;20080
]kNg0P35aLD01@2YZJT0];Bd0<?3``2o_kl0]kNg0080_Kfm00H0YZJV0<30`02h^;P0][Jf0<?3``2d
];@30;Zj^P070;Bd]02m_Kd0`l?30<71`@33`l<0/;2`0<G5a@030<;2`P060;bl_02WYjL0][Jf0<W9
b@2HV9P0clo?0P2f][H01`3;bl/0bLW90;Zj^P2k^k/0cLg=0<W9b@31`L400P32`/801`3<c<`0clo?
0<O7a`3AdM40Y:BT0?KfmP3:b/X00P35aLD01`33`l<0/k>c0<g=c@2m_Kd0b/[:0>KViP2_[jl00P3J
f]X01`2VYZH0d=3@0:ZZZP2g]kL0aLG50;Ng]`2m_Kd00P2i^KT01`37alL0][Jf0<G5a@2i^KT0a/K6
0<[:bP2f][H00P2YZJT01`2d];@0_;bl0<W9b@2LW9`0WinO0;Ng]`2f][H00P2:RXX01`2d];@0`/;2
0<W9b@2][Jd0/K6a0:b/[02i^KT00P2OWil01`2XZ:P0f=SH0:f][@2b/[80`/;20;:b/P3;bl/00P2U
YJD01`3@d=00][Jf0;bl_030`<00WYjN0;bl_02_[jl00P34a<@01`2d];@0^;Rh0;jn_P2j^[X0^;Rh
0;jn_P35aLD00P33`l<01`32`/80`l?30<W9b@2n_[h0`l?30<S8b034a<@00P3?cll01032`/80alO7
0<71`@2f][HT0?ooobD0X3oo00<0Oooo0:0oo`2P?ol03P2P?ol00`1oool0o`000:0oo`070:0oo`03
0?l0002P?ol0X3oo01H0X3oo0P1oool20:0oo`80Oooo1`2P?ol207ooo`d0X3oo00<0Oooo0:0oo`2P
?ol0602P?olW0?ooo`009@3oool00`31`L40_[jn0=OGe`020<G5a@030<W9b@2f][H0_;bl0080];Bd
00/0bl_;0:f][@2d];@0];Bd0;Ng]`2h^;P0[jn_0;Zj^P33`l<0`L710:>SX`020;fm_@070<?3``2d
];@0alO70=KFeP32`/80`l?30<30`0030;jn_P060;Vi^@2`/;00^k^k0<;2`P2_[jl0^[Zj0P2XZ:P0
1P39bLT0clo?0<O7a`32`/80`L710;bl_0<0a<C400L0`l?30<G5a@35aLD0cLg=0<?3``2ZZZX0`L71
0080_;bl00L0eMGE0<g=c@2UYJD0_[jn0;fm_@2j^[X0aLG50080^[Zj00L0]kNg0<K6aP33`l<0bl_;
0<W9b@30`<00][Jf0080/[:b0P36a/H01@32`/80b/[:0;^k^`2][Jd0bLW90080/k>c00L0ZZZZ0<30
`03Ph>00`/;20<W9b@2c/k<0`<300080[Jf]00L0e=CD0<O7a`2<S8`0^;Rh0;jn_P2h^;P0`l?30080
_;bl00L0/[:b0;Bd]02j^[X0VYZJ0=SHf032`/80alO70080`/;200L0][Jf0<G5a@2ZZZX0a/K609jN
WP3=cLd0clo?0080a<C400L0dm?C0<k>cP3Cdm<0c/k>0=3@d02m_Kd0/[:b0080];Bd00@0_Kfm0;bl
_034a<@0_[jn0P35aLD0103=cLd0_kno0;no_`2n_[h20;Jf]P030<?3``3oool0oooo0280oooo502P
?ol00`1oool0X3oo0:0oo`110:0oo`030?l0002P?ol0X3oo00H0X3oo00<0Oooo0:0oo`2P?ol01`2P
?ol00`1oool0X3oo0:0oo`070:0oo`0307ooo`2P?ol0X3oo01P0X3oo9`3oool002D0oooo00<0_;bl
0:j^[P33`l<00P2g]kL01`2i^KT0];Bd0<O7a`39bLT0[Zj^0;Vi^@2o_kl00P2SXj<01`2/[:`0]KFe
0;Zj^P2h^;P0_[jn0;Jf]P2][Jd00P2n_[h01`38b<P0c/k>0:^[Z`2f][H0`/;20<G5a@2b/[800P35
aLD0102i^KT0];Bd0<71`@2l_;`20<71`@0:0;>c/`3<c<`0c<c<0;Fe]@2b/[80bLW90:>SX`36a/H0
`l?306ATI080_[jn00L0aLG50<30`02o_kl0Z:RX0<O7a`3Hf=P0`/;20080dm?C00L0eMGE0;^k^`2Z
ZZX0h>3P0<C4a02d];@0_;bl0080c<c<00L0]KFe0<g=c@2n_[h0a<C40<K6aP30`<00[:b/0080]KFe
00L0_;bl0;2`/039bLT0aLG50;fm_@30`<00^k^k0080`l?300@0c/k>0:FUY@38b<P0c/k>0P37alL0
2P34a<@0Xj>S0:>SX`3:b/X0d];B0;Ng]`2^[Zh0`/;20;^k^`2XZ:P20<?3``070<k>cP2UYJD0`<30
0;Ng]`30`<00/K6a0;Ng]`020:>SX`070=3@d02i^KT0[Jf]0<W9b@33`l<0_[jn0<c<c0020<O7a`07
0;bl_03=cLd0g]kN0:JVYP2d];@0XZ:R0;Fe]@020:>SX`070;Zj^P2`/;00alO70<c<c039bLT0^k^k
0:n_[`020<W9b@040<G5a@2g]kL0`l?30=7AdB@0oooo302P?ol207oooah0X3oo00@0Oooo0:0oo`2P
?ol0h?o03P2P?ol00`3o0000X3oo0:0oo`0L0:0oo`80Oooo402P?ol207ooo`/0X3oo00D0o`000:0o
o`2P?ol0Oooo0:0oo`0207ooo`d0X3oo9`3oool002D0oooo0P2l_;`02P2m_Kd0^KVi0;Vi^@2o_kl0
`l?30<c<c031`L40`<300<;2`P2n_[h20;Bd]0070:NWY`2b/[80/[:b0;fm_@2f][H0^k^k0;Vi^@02
0<71`@070:RXZ02g]kL0VYZJ0;:b/P2n_[h0bLW90;Vi^@020<W9b@070;bl_02f][H0Zj^[0;Rh^033
`l<0`L710<c<c0020;Zj^P070=_Kf`33`l<0`L7100P82037alL0bLW90;^k^`0209RHV0070;Rh^037
alL0a/K60<o?c`2c/k<0][Jf0<k>cP020;Vi^@070;2`/03?cll0VYZJ09jNWP2g]kL0`/;20<?3``02
0<_;b`070<;2`P3:b/X0WinO0;Jf]P2n_[h0^k^k0;Vi^@0208J6QP070;Rh^03alO40e=CD0<;2`P3?
cll0^k^k0:n_[`020<O7a`060<;2`P2n_[h0aLG50<g=c@3GemL0Xj>S0`2l_;`01`3Lg=`0clo?0<o?
c`36a/H0^k^k0<W9b@30`<000P2ZZZX01`2LW9`0U9BD08j>SP3<c<`0WinO0;Zj^P3EeMD00P2][Jd0
1`3AdM40[Jf]0=OGe`30`<00YJFU0=7Ad@3EeMD00P3Kfm/01`3=cLd0/K6a0;bl_033`l<0]kNg0<30
`02n_[h00P2k^k/01`30`<00/[:b0;jn_P2n_[h0a/K60;Rh^037alL00P3<c<`0102XZ:P0`l?30<G5
a@2h^;PT0?oooaT0X3oo00<0Oooo0:0oo`2P?ol0402P?ol0103oool0X3oo0:0oo`2P?ol207ooo`/0
X3oo0P1oool70:0oo`0307ooo`2P?ol0X3oo0080X3oo0P1oool00`2P?ol0o`000:0oo`0;0:0oo`03
07ooo`2P?ol0X3oo00X0X3oo0`1oool00`2P?ol0Oooo0:0oo`0R0:0oobL0oooo000U0?ooo`030;bl
_02f][H0_[jn0080/;2`00L0_[jn0;Jf]P2l_;`0_kno0<71`@2k^k/0`/;20080][Jf00<0[Zj^0;^k
^`2l_;`00P2d];@0102j^[X0`/;20<;2`P32`/820;^k^`050<O7a`2ZZZX0`l?30<G5a@3EeMD00P33
`l<01`36a/H0o_kn0;Vi^@3Cdm<0][Jf0;Bd]035aLD00P3@d=00102k^k/0aLG50;Vi^@2n_[h20<[:
bP0:0<30`02^[Zh0[Zj^0<O7a`33`l<0bLW90;Bd]03?cll0alO70;Jf]P80d];B00L0/[:b0<?3``2`
/;00]kNg0;Rh^039bLT0b/[:0080d=3@00L0`L710<30`037alL0alO70;bl_02`/;00];Bd0080^k^k
00L0alO70;2`/02o_kl0[Zj^0<G5a@2m_Kd0aLG50080e]KF00L0_;bl0<?3``3:b/X0_[jn0;Ng]`39
bLT0a<C40080aLG500L0/;2`0<O7a`2i^KT0aLG50;6a/@2XZ:P0Ti>C0080ZJVY00L0bLW90;bl_032
`/80];Bd0<K6aP2k^k/0eMGE0080aLG500L0f=SH0;2`/02d];@0e]KF0<W9b@3<c<`0^[Zj0080Y:BT
00L0Zj^[0;Jf]P3=cLd0WinO0;bl_02g]kL0aLG50080Z:RX0P35aLD01@33`l<0bLW90;Rh^031`L40
aLG50080_;bl00@0^[Zj0;Fe]@32`/80`<30903ooolQ0:0oo`030?l0002P?ol0X3oo0440X3oo00<0
Oooo0:0oo`2P?ol0402P?ol207ooo`<0X3oo00<0Oooo0:0oo`2P?ol0402P?olW0?ooo`009@3oool0
0`2l_;`0][Jf0;jn_P020;2`/0070;jn_P2f][H0_;bl0;no_`31`L40^k^k0<;2`P020;Jf]P030:j^
[P2k^k/0_;bl0080];Bd00@0^[Zj0<;2`P32`/80`/;20P2k^k/01@37alL0ZZZZ0<?3``35aLD0eMGE
0080`l?300L0a/K60?knoP2i^KT0dm?C0;Jf]P2d];@0aLG50080d=3@00@0^k^k0<G5a@2i^KT0_[jn
0P3:b/X02P30`<00[Zj^0:j^[P37alL0`l?30<W9b@2d];@0clo?0<O7a`2f][H20=;BdP070;:b/P33
`l<0/;2`0;Ng]`2h^;P0bLW90<[:bP020=3@d0070<71`@30`<00alO70<O7a`2l_;`0/;2`0;Bd]002
0;^k^`070<O7a`2`/;00_kno0:j^[P35aLD0_Kfm0<G5a@020=KFeP070;bl_033`l<0b/[:0;jn_P2g
]kL0bLW90<C4a0020<G5a@070;2`/037alL0^KVi0<G5a@2a/K40Z:RX09>CT`020:VYZ@070<W9b@2l
_;`0`/;20;Bd]036a/H0^k^k0=GEe@020<G5a@070=SHf02`/;00];Bd0=KFeP39bLT0c<c<0;Zj^P02
0:BTY0070:^[Z`2f][H0cLg=09nOW`2l_;`0]kNg0<G5a@020:RXZ080aLG500D0`l?30<W9b@2h^;P0
`L710<G5a@020;bl_0040;Zj^P2e]KD0`/;20<30`2@0oooo8@2P?ol00`3o0000X3oo0:0oo`110:0o
o`0307ooo`2P?ol0X3oo0100X3oo0P1oool30:0oo`0307ooo`2P?ol0X3oo0100X3oo9`3oool002D0
oooo00<0_;bl0;Zj^P2YZJT00P31`L420;Vi^@050<30`03Fe]H0_[jn0<?3``30`<000P39bLT01P2Q
XJ40]kNg0<W9b@2b/[80[Zj^0;Vi^@<0aLG500L0^[Zj0;jn_P2XZ:P0aLG50;Vi^@2k^k/0/;2`0080
^k^k00L0aLG508:2PP2][Jd0`l?30<W9b@2d];@0_Kfm0080`l?300L0alO70=CDe02o_kl0`/;20;Bd
]032`/80];Bd0080aLG500L0`<300<?3``3Jf]X0alO70<k>cP2o_kl0alO70080];Bd00L0bLW90;Bd
]035aLD0`l?30:ZZZP33`l<0h^;R0080^[Zj00H0];Bd0;bl_02l_;`0[Jf]0<c<c02m_Kd30<O7a`07
0;^k^`2f][H0clo?0<[:bP2n_[h0c/k>0=?Cd`020<[:bP070;jn_P3:b/X0];Bd0=KFeP2`/;00_[jn
0;Zj^P020<k>cP070<_;b`3Jf]X0dM7A0<?3``2c/k<0_[jn0;Ng]`020<;2`P070;bl_035aLD0[Jf]
0<O7a`2d];@0d=3@0<k>cP020<O7a`070=?Cd`3Fe]H0clo?0<g=c@33`l<0_;bl0;Fe]@020:6QX@07
0<71`@3;bl/0_Kfm0;Vi^@2f][H0bLW90;bl_0020;no_`070<G5a@3Jf]X0bl_;0<O7a`2n_[h0bLW9
0:n_[`020<O7a`040<[:bP37alL0c<c<0<O7ab@0oooo3P2P?ol00`1oool0X3oo0:0oo`0@0:0oo`03
07ooo`2P?ol0X3oo01d0X3oo00<0o`000:0oo`2P?ol0=02P?ol207oooaH0X3oo9`3oool002D0oooo
00<0bLW90=SHf03>c/h00P3>c/h01`2l_;`0[Zj^0;fm_@2b/[80^k^k0;Bd]032`/800P2b/[801`2X
Z:P0_Kfm0;Jf]P30`<00alO70<G5a@2h^;P00`30`<001P2UYJD0_[jn0:^[Z`39bLT0Cdm?0<30`080
_;bl00L0c<c<0;^k^`2f][H0`l?30<71`@37alL0`l?30080d=3@00H0bLW90<71`@33`l<0`L710;Vi
^@34a<@30<?3``050;fm_@3:b/X0`/;20<[:bP2k^k/00P2m_Kd20;jn_P070:6QX@3;bl/0aLG50<30
`031`L40^KVi0<W9b@020<71`@070;Vi^@3<c<`0_Kfm0<71`@3>c/h0`l?30:n_[`020:FUY@030:f]
[@2i^KT0^KVi0080_Kfm00/0dM7A096AT@2i^KT0^KVi0<S8b02j^[X0alO70;Bd]032`/80alO70;Jf
]P020=7Ad@070=GEe@33`l<0alO70;^k^`2PX:00WinO0:n_[`020;>c/`070;2`/033`l<0SXj>0<G5
a@2e]KD0_kno0;jn_P020=OGe`070:BTY02c/k<0][Jf0;bl_02e]KD0bl_;0<?3``020<k>cP070=OG
e`39bLT0eMGE0;no_`2<S8`0][Jf0<;2`P020<K6aP070=CDe02l_;`0`l?30<30`035aLD0XJ6Q0;Zj
^P020:^[Z`040=7Ad@32`/80][Jf0<G5aB@0oooo702P?ol00`3Pol00X3oo0:0oo`0L0:0oo`0307oo
o`2P?ol0X3oo01D0X3oo00<0Oooo0:0oo`2P?ol03@2P?ol207ooo`D0X3oo00<0Oooo0:0oo`2P?ol0
102P?ol00`1oool0X3oo0:0oo`0:0:0oo`0307ooo`2P?ol0X3oo00L0X3oo00<0Oooo0:0oo`2P?ol0
1@2P?olW0?ooo`009@3oool00`30`<00]kNg0;^k^`020<G5a@070;Ng]`3>c/h0XJ6Q0<O7a`2i^KT0
];Bd0<O7a`020;2`/00709RHV02SXj<0`l?30;^k^`2n_[h0`l?30<30`0020:f][@060:j^[P37alL0
aLG50;Ng]`3<c<`0_Kfm0`31`L401`2OWil0`l?30:FUY@2NWYh0XJ6Q0:f][@3<c<`00P33`l<01`2d
];@0`l?30<o?c`33`l<0aLG50;Bd]02l_;`00P3<c<`01`33`l<0alO70;Zj^P39bLT0b/[:0;^k^`2S
Xj<00P35aLD01`3;bl/0dm?C0::RXP2g]kL0`/;20<?3``2`/;000P33`l<01`2k^k/0bLW90<;2`P2l
_;`0eMGE0<;2`P1oOgl00P2d];@20=GEe@050<o?c`32`/80bl_;0<G5a@2n_[h00P3Cdm<01`3>c/h0
bLW90<c<c02n_[h0^KVi0<[:bP2][Jd00P2a/K401`2e]KD0a/K60;Ng]`2k^k/0[jn_0:BTY02l_;`0
0P3?cll0102EUID0]kNg0:JVYP33`l<20<_;b`0:0:^[Z`2j^[X0^[Zj0:BTY03>c/h0^;Rh0<30`03A
dM40c/k>0=SHf080bLW900L0aLG50=cLg03=cLd0alO70=;BdP33`l<0^[Zj0080dm?C00D0^k^k0<?3
``2i^KT0TY:B0<W9b@020<c<c080aLG500@0e]KF0=;BdP2k^k/0`l?3903oool70:0oo`0307ooo`2P
?ol0X3oo00@0X3oo0P1oool@0:0oo`0307ooo`2P?ol0X3oo0080Oooo4`2P?ol00`1oool0X3oo0:0o
o`020:0oo`0307ooo`2P?ol0X3oo00X0X3oo00<0Oooo0:0oo`2P?ol05`2P?ol01@1oool0X3oo0:0o
o`2P?ol0Oooo00P0X3oo00<0Oooo0:0oo`2P?ol04P2P?ol00`1oool0X3oo0:0oo`070:0oobL0oooo
000U0?ooo`030;Fe]@2o_kl0_Kfm0080^;Rh00L0^KVi0<O7a`2o_kl0_kno0:VYZ@2k^k/0_kno0080
]kNg00L0SHf=09NGU`2i^KT0^KVi0<W9b@2^[Zh0^[Zj0080alO700L0`L710=GEe@2l_;`0][Jf0;no
_`31`L40d=3@0080_Kfm0P2f][H01@2k^k/0_kno0;^k^`32`/80bLW90080aLG500L0b/[:0<?3``2i
^KT0_kno0<G5a@37alL0bLW90080c/k>00L0][Jf0=?Cd`3?cll0[jn_0<[:bP2`/;00alO70080bl_;
00L0e]KF0;jn_P2n_[h0];Bd0;Zj^P2d];@0clo?0080^KVi00L0alO70=[JfP3MgMd0`/;20<g=c@2[
Zj/0^KVi0080][Jf00L0c<c<0=CDe03Jf]X0`<300=7Ad@33`l<0cLg=0080c/k>00@0alO70:n_[`2_
[jl0c<c<0P2`/;002P35aLD0^k^k0;^k^`2l_;`0`<300<k>cP2YZJT0/[:b0:j^[P3>c/h20<S8b007
0:RXZ02i^KT0[jn_0<g=c@3@d=00];Bd0;Rh^0020=?Cd`070<C4a038b<P0_[jn0=3@d03:b/X0b<S8
0=SHf0020<?3``070<G5a@2f][H0b/[:0<30`02l_;`0bl_;0:>SX`0209bLW0070<;2`P2g]kL0`<30
0<?3``3<c<`0f][J0=;BdP020<g=c@040<;2`P39bLT0^[Zj0<;2`R@0oooo3P2P?ol207ooocH0X3oo
00<0o`000:0oo`2P?ol0=`2P?ol307ooo`d0X3oo9`3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool006L0oooo0d00003o
0?ooobL0oooo001X0?ooo`03@000003oool0oooo0?l0oooo9P3oool004@0oooo0d0000000`3ooom0
0000@00000020?ooo`=000000P3oool00d000000oooo0?ooo`02@0000080oooo0d00000=0?ooo`=0
00000P3oool3@00000<0oooo0T0000030?ooo`=000000P3oool3@00000040?oood0000100000@000
00<0oooo0T0000020?ooo`900000M@3oool2@0000080oooo0d0000020?ooo`A0000000<0oooo@000
040000000`3oool2@00000<0oooo0d0000020?ooo`=000000P3oool3@00000<0oooo0T0000030?oo
o`=00000303oool00d000000oooo0?ooo`1?0?ooo`00A@3oool01D000000oooo0?ooo`3ooom00000
0080oooo00=000000?oood0000000P3oool00d000000oooo@00000050?ooo`03@000003oool0oooo
00`0oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo00=0
00000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000@0oooo00A0
00000?ooo`3ooom000000`3oool00d000000oooo0?ooo`1a0?ooo`03@000003oool0oooo00<0oooo
00A000000?ooo`3oool0oooo0d0000040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3o
ool0oooo@00000040?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@0000004
0?ooo`04@000003oool0oooo@00000/0oooo00=000000?oood000000D03oool004D0oooo00E00000
0?ooo`3oool0oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000T00
00030?ooo`03@000003oool0oooo00`0oooo00A000000?ooo`3ooom000000P3oool01D000000oooo
0?ooo`3ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03
@000003ooom0000000@0oooo00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`1b0?ooo`03
@000003oool0oooo00<0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom00000
00@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo
0080oooo00A000000?ooo`3oool0oooo0d0000020?ooo`04@000003oool0oooo@00000d0oooo00=0
00000?ooo`3oool0CP3oool004D0oooo00=000000?ooo`3oool0140000000`3ooom00000@0000002
@0000080oooo0d0000020?ooo`A000002`3oool4@0000080oooo140000020?ooo`9000000`3oool5
@00000040?oood00001000000?ooo`=0000000<0oooo@000040000000T0000030?ooo`900000L`3o
ool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo0080oooo0T0000030?ooo`9000000`3o
ool2@0000080oooo0T0000030?ooo`=000000P3oool2@00000<0oooo0d0000030?ooo`=000002`3o
ool2@0000540oooo00150?ooo`03@000003oool0oooo0380oooo00=000000?ooo`3oool02@3oool0
0d000000oooo0?ooo`1h0?ooo`03@000003ooom0000000<0oooo00=000000?ooo`3oool05P3oool0
0d000000oooo0?ooo`0>0?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool0D03oool0
04@0oooo0d00000b0?ooo`900000QP3oool3@0000080oooo0T00000C0?ooo`03@000003oool0oooo
00<0oooo00E000000?ooo`3oool0oooo@000000:0?ooo`9000002`3oool3@0000500oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo001`0?ooo`900000@03oool3
@0000=/0oooo001b0?ooo`03@000003oool0oooo03h0oooo00=000000?ooo`3oool0fP3oool006@0
oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool00P3oool3@00000@0
oooo00=000000?ooo`3oool0203oool3@00000030?oood00001000000080oooo0d0000020?ooo`03
@000003oool0oooo009000000P3oool3@00000d0oooo0d0000020?ooo`=000000`3oool2@00000<0
oooo0d0000020?ooo`=0000000@0oooo@0000400001000000`3oool2@0000100oooo0d000000103o
oom00000@000040000020?ooo`900000103oool2@0000080oooo0d0000020?ooo`=0000000<0oooo
@000040000000T0000030?ooo`=000000P3oool2@0000080oooo0d0000030?ooo`90000000<0oooo
@000040000000P3oool00d000000oooo0?ooo`1`0?ooo`00I@3oool00d000000oooo0?ooo`030?oo
o`05@000003oool0oooo0?oood0000000P3oool00d000000oooo0?ooo`090?ooo`03@000003oool0
oooo00l0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003ooom000000080oooo00=0
00000?oood0000001@3oool00d000000oooo0?ooo`0<0?ooo`04@000003oool0oooo@0000080oooo
00E000000?ooo`3oool0oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood00
00000P3oool00d000000oooo@00000040?ooo`04@000003oool0oooo@00000h0oooo00A000000?oo
o`3ooom000000P3oool00d000000oooo0?ooo`030?ooo`04@000003oool0oooo@0000080oooo00A0
00000?ooo`3ooom00000103oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?oood00
00000P3oool00d000000oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo00I000000?oo
o`3ooom000000?oood0000020?ooo`03@000003oool0oooo0700oooo001U0?ooo`03@000003oool0
oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00L0oooo1400
000@0?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo@00000020?ooo`03@000
003ooom00000009000000`3oool00d000000oooo0?ooo`0<0?ooo`04@000003oool0oooo@0000080
oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oo
od0000000P3oool00d000000oooo@00000040?ooo`03@000003oool0oooo00l0oooo00A000000?oo
o`3ooom000000P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood0000001@3o
ool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo
@00000020?ooo`03@000003ooom0000000D0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03
@000003ooom000000080oooo00=000000?ooo`3oool0L03oool006D0oooo0T0000030?ooo`900000
103oool3@00000T0oooo00=000000?oood0000004@3oool00d000000oooo0?ooo`04@00000030?oo
od0000100000009000000P3oool3@0000080oooo1400000;0?ooo`A000000P3oool4@0000080oooo
0T0000030?ooo`E0000000@0oooo@00004000000oooo0d0000000`3ooom00000@0000002@0000100
oooo0d0000000`3ooom00000@00000040?ooo`90000000<0oooo@000040000000T0000020?ooo`A0
000000<0oooo@000040000000`3oool3@00000040?oood00001000000?ooo`I000000P3oool2@000
00@0oooo0T0000000`3ooom00000@0000002@00007<0oooo001U0?ooo`04@000003oool0oooo@000
01@0oooo0T00000A0?ooo`03@000003oool0oooo0380oooo00=000000?ooo`3oool02@3oool00d00
0000oooo0?ooo`0B0?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool0303oool00d00
0000oooo0?ooo`070?ooo`03@000003oool0oooo0880oooo001T0?ooo`E000000P3oool00d000000
oooo0?ooo`0@0?ooo`03@000003oool0oooo00h0oooo0d00000b0?ooo`9000007`3oool2@0000080
oooo00=000000?ooo`3oool04@3oool00d000000oooo0?ooo`02@00000l0oooo00=000000?ooo`3o
ool0O03oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.157534, -0.0238147, 
  0.00580218, 0.00580218}, {{27.125, 191.25}, {185.313, 
  21.1875}} -> {-33.101, -6.22906, 0.889305, 0.889305}, {{207.688, 371.813}, {
  185.313, 21.1875}} -> {-193.676, -6.22906, 0.889305, 0.889305}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1 
%%ImageSize: 400 20 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00238095 0.952381 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00238095 0.97619 0.097619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.160256 0.00192308 0.0480769 [
[ 0 0 0 0 ]
[ 1 .1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1 L
0 .1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .00192 translate
.96154 .09616 scale
18 string
6 2 8 [6 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFF5FFCC99FFC266A3FFD733FFFF0000
FFFFFFF5FFCC99FFC266A3FFD733FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{200, 20},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400038000052000`400?l00000o`00003ob03oool0
0<P0oooo000Y0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo2
7@1VXolM0=Lcoad0o`003P3oool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y
0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lc
oad0o`003P3oool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<
7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3o
ool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<7@2Iol8M06JS
oad0ec?o7@3o000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3oool002T0oooo
7@3eol`M09Wo`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o
000>0?ooo`00:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3oool002T0oooo7@3eol`M09Wo
`Qd0IZ?o7@3G<olM0?l000h0oooo000Y0?oooad0mOo<7@2Iol8M06JSoad0ec?o7@3o000>0?ooo`00
:@3ooolM0?Goc1d0VOo27@1VXolM0=Lcoad0o`003P3oool002T0oooo7@3eol`M09Wo`Qd0IZ?o7@3G
<olM0?l000h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 199}, {19, 0}} -> {-0.0498739, -0.00250052, 
  0.00552637, 0.00552637}, {{9, 189.938}, {18.5, 
  0.4375}} -> {-0.436354, -0.0975889, 0.0345471, 0.115157}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Thus, it is obvious that the vectored representation of color image is \
useful methodology for the nondestructive inspections.",
    FontFamily->"Times New Roman"]
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.5 Sketch and painted image generation",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "As described in chapter 2, the sketch is one of the human art works. \
However, we have succeeded in work out a plausible monochrome sketch by \
computer graphics with the aid of field theory. \n\tIn this section, we \
propose the two methodologies to work out the sketch from a color graphics \
image. Both methods are based on the nature of color characteristic vectors. \
The distributions of the vector magnitude and of the inner products gives the \
monochrome images. Observing the left side images in Figs 3 and 4 easily \
recognizes this. Applying the method developed to a monochrome image in \
chapter 2 to these images generates the sketch images.\n\tBefore to move on \
the next computations, we remove the needless memories from the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" front end processor and check up the used memories.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Remove[\"sampleG\",\"colorCompG\",\"vectored3D\",\"vectMag\",
\t\"vectMagG\",\"nx\",\"sample\",\"dim\"];
Unprotect[In,Out];Clear[In,Out];Protect[In,Out];
Print[\"Memory: \",Round[N[MemoryInUse[]/1000]],\"K Bytes used\"];\
\>", "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    InterpretationBox[
      \("Memory: "\[InvisibleSpace]2158\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ "Memory: ", 2158, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "We read in the image file \[OpenCurlyDoubleQuote]AF038-256.bmp\
\[CloseCurlyDoubleQuote] by means of the function rgbBMP, and compute the \
size of a list \[OpenCurlyDoubleQuote]sample\[CloseCurlyDoubleQuote].",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
sample=rgbBMP[\"AF038-256.bmp\"];
dim=Dimensions[sample];\
\>", "Input",
  CellLabel->"In[43]:=",
  FormatType->InputForm],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["Figure 5 shows a sample image.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Show[convertRGB[sample],PlotLabel->\"Fig.5. Color image\",
\tAspectRatio->dim[[2]]/dim[[3]]];\
\>", "Input",
  CellLabel->"In[45]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[.5 1.0125 -56 0 ]
[.5 1.0125 56 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
141.000000 12.812500 moveto
(image) show
171.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
768 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5EFCEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BD\
EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADE7BDA5EFC6ADEFC6ADEFC6ADE7BDA5
E7B59CE7B59CE7BDA5DEB59CE7B59CDEAD94E7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94\
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEA58C
DEAD94D6A58CDEAD94DEAD94DEA58CD6A584D6A58CD6A58CD6A584D6A58CDE9C84D6A584D6A58C\
D6A58CD6A58CD6A584D6A584D6A584C69C84D69C84D6A58CD6A58CF7E7DEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7D6C6F7D6C6EFCEB5EFCEB5\
EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADE7BDA5E7BDA5
E7B59CDEB5A5E7B59CE7B59CE7BDA5DEAD94DEAD94DEAD94DEAD94DEAD94DEB59CDEAD94DEAD94\
DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEB59CDEAD94DEA58CDEA58CDEAD94
DEAD94DEAD94DEA58CDEA58CDEA58CD6A58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58C\
D6A584D6A58CD6A58CD6A58CD6A584D69C84D6A584C69C84EFBDADF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5\
EFCEB5EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5EFC6ADE7BDA5E7BDA5E7BDA5E7BDA5
E7BDA5E7B59CE7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94
DEAD94DEA58CDEA58CD6A58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A584D6A58CD6A584D6A58C\
D6A58CD6A584D6A584D6A58CD6A584C69C84D6A58CD6A58CF7D6C6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6AD\
EFC6ADE7BDA5EFC6ADE7BDA5E7BDA5E7BDA5E7BDA5E7BDA5DEB5A5E7B59CDEB59C
E7B59CDEB59CDEB59CDEB59CDEB59CDEAD94DEAD94DEAD94DEA58CDEAD94DEA58CDEA58CDEAD94\
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CDEAD94DEA58C
DEAD94DEA58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A584\
D6A58CD6A584D6A584D6A584D69C84D6A584D6A58CDEB59CF7E7E7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6AD\
DEB5A5EFC6ADE7BDA5E7BDA5DEB5A5E7BDA5E7BDA5DEB59CE7BDA5E7AD9CDEB59C
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CDEAD94D6A58CDEAD94DEA58CDEAD94DEAD94\
DEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEAD94
DEA58CDEAD94D6A58CDEAD94DEA58CD6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A58C\
D6A58CD6A58CD6A584D6A584D6A584C69C84D6A58CD6C6BDF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD\
EFBDADEFBDADDEB5A5E7BDA5E7B59CE7BDA5DEB59CE7AD9CDEB59CDEB59CDEAD94
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CDEA58CDEA58CD6A58CDEA58C\
DEAD94DEA58CDEAD94DEA58CD6A58CDEA58CDEAD94DEAD94DEAD94DEAD94D6A58C
DEA58CDEAD94DEA58CDEA58CD6A58CDEA58CD6A584D6A58CD6A58CDEA58CD6A58CD6A58CD6A584\
D6A58CD6A58CD6A58CD6A58CD6A584D6A584DEAD94EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
EFCEB5EFCEB5F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFCEB5D6C6B5EFC6ADD6C6B5EFBDADE7BDA5\
DEB5A5E7BDA5E7BDA5DEB5A5E7BDA5DEB59CDEB59CDEB59CDEB5A5DEB59CDEB59C
DEB59CD6A58CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CD6A58CDEA58C\
D6A58CD6A58CDEAD94D6A58CDEA58CDEA58CD6A58CDEAD94DEA58CDEA58CDEAD94
D6A58CD6A58CDEA58CDEA58CD6A58CDE9C84D6A58CDE9C84DEA58CD6A58CD6A58CD6A584D6A58C\
D6A584D6A58CD6A58CD6A584D6A58CD69C84DEB59CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5EFCEB5F7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6C6
EFCEB5F7D6BDD6C6C6EFCEB5EFCEB5EFCEB5D6C6B5EFC6ADEFBDADEFBDADEFBDADE7BDA5E7BDA5\
E7BDA5E7BDA5DEB59CE7AD9CDEB59CDEAD94DEB59CDEAD94DEAD94DEB59CDEB59C
DEB59CDEB59CDEB5A5D6A58CD6A58CDEA58CD6A58CDEAD94DEA58CD6A58CDEA58CD6A58CD6A58C\
DEA58CDEA58CD6A58CDEA58CD6A58CDEAD94DEA58CDEAD94D6A58CDEA58CDEAD94
DEAD94DEA58CD6A58CDEA58CD6A58CDEA58CD6A58CDEA58CD6A58CDEA58CDEA58CD6A58CD6A58C\
DEA58CD6A584D6A58CD6A58CD6A584D6A58CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5EFCEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6C6EFCEB5D6C6C6F7D6BD
EFCEB5EFCEB5D6C6BDEFCEB5D6C6B5EFBDADE7BDA5E7BDA5E7BDA5DEB59CE7AD9CE7BDA5E7AD9C\
DEAD94DEB59CDE9C8CDEAD94DE9C8CDEB59CDE9C8CDEB59CDEAD94DEB59CDEB59C
DEB59CDEB59CDEB59CD69C8CDEB59CD6A58CDEB5A5D6A58CDEAD94D6A58CD6A58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94D6A58CDEA58CDEA58CDEAD94
D6A58CDEA58CDEA58CDEA58CD6A584DEA58CDEAD94DEAD94D6A58CDEA58CD6A58CD6A58CD6A58C\
DEA58CD6A58CD6A58CD6A58CD6A584DEB59CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5F7D6C6EFCEB5F7D6C6EFCEB5EFCEB5
F7BDB5EFCEB5EFCEB5F7BDB5EFBDADEFBDADEFBDADEFBDADEFBDADEFBDADE7BDA5E7AD9CE7AD9C\
E7BDA5E7AD9CE7AD9CDEAD94DEAD94DE9C8CDEAD94DE9C8CDEAD94DE9C8CDEB59C
DEAD94DEB59CDE9C8CDEB59CDEB59CDEB59CD6A58CDEB5A5DEB59CD6A58CDEA58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A58C
DEAD94DEAD94DEAD94D6A58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58C\
D6A584D6A58CD6A58CD6A58CD6A58CEFBDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6F7D6BDF7D6BDF7D6BD
D6C6C6EFCEB5F7BDB5EFCEB5F7BDB5F7BDB5F7BDB5EFCEB5EFBDADEFCEB5EFBDADEFB5A5EFBDA5\
EFB5A5E7B59CE7BDA5E7AD9CE7AD9CE7AD9CDE9C8CDE9C8CDEAD94DE9C8CDEAD94
DE9C8CDEAD94DEAD94DEAD94DEAD94DE9C8CDEB59CD6A58CD69C8CDEB59CC6ADA5DEB59CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94DEA58C
DEA58CDEA58CDEA58CDEAD94D6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A584D6A58C\
D6A584D6A58CD6A58CD6A58CD6A584D6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6BDEFCEB5F7D6C6F7D6C6EFD6CEEFCEB5F7D6BDD6C6C6D6C6C6EFCEB5
F7BDB5F7D6BDEFCEB5F7D6BDF7BDB5EFCEB5F7BDB5EFCEB5F7BDB5F7BDB5EFCEB5F7BDB5EFBDAD\
EFBDA5EFBDA5EFB5A5EFB5A5E7B59CE7AD9CDEAD94DE9C8CDEAD94E7AD94DE9C8C
DEAD94DEAD94E7BDA5E7AD9CDEB59CE7AD9CDE9C8CDE9C8CDEA58CD6A58CD69C8CDEB59CDEB5A5\
DEB59CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94
D6A58CD6A58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6C6EFCEB5F7CEB5F7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6EFD6CEF7D6C6EFCEB5EFCEB5EFCEB5F7D6BDEFCEB5EFCEB5EFCEB5
F7D6C6F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDF7BDB5EFBDADF7BDB5\
EFC6ADEFBDADEFB5A5E7B59CE7B59CE7AD9CE7AD9CE7AD94DEAD94DE9C8CDEAD94
E7AD9CE7AD9CEFB5A5E7AD9CE7AD9CE7AD9CDEB59CDEAD94DE9C8CDE9C8CD6A58CD6A58CD6A58C\
DEAD94DEB5A5DEB59CD6A58CD6A584D6A58CD6A58CD6A58CD6A58CD6A584D6A58C
D6A58CD6A58CDE9C84D6A58CD6A58CDEA58CD6A58CD6A58CDEAD94DEA58CD6A58CD6A58CD6A58C\
D6A58CD6A58CDEAD94D6A58CDEAD94F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6EFCEB5\
F7D6BDF7D6C6EFCEB5EFCEB5EFCEB5F7D6C6EFCEB5D6C6C6F7D6BDF7D6C6F7D6BD
EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7BDB5EFCEB5EFCEB5\
EFCEB5EFBDADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CE7AD94E7AD94E7AD94E7AD94
E7AD9CEFB5A5E7BDA5E7BDA5E7BDA5E7AD9CE7AD9CE7AD9CDEAD94DE9C8CDE9C8CDE9C8CD69C8C\
D69C8CD6A58CDEAD94DEB59CD6A58CD6A58CD6A58CDEAD94D6A58CD6A58CD6A58C
DEAD94DEA58CD6A584DEA58CDEAD94D6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A584D6A58C\
D6A58CD6A58CD6A58CD6A58CDEB5A5EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6BDEFCEB5F7D6BDF7D6BDF7D6C6F7D6BD
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5EFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7BDB5F7D6BDEFCEB5F7BDB5\
F7C6ADEFBDADEFBDA5EFBDADEFBDADEFBDA5EFB5A5E7BDA5E7AD9CE7BDA5E7AD9C
E7AD9CE7B59CEFB5A5EFB5A5EFBDADEFB5A5EFB5A5E7BDA5E7AD9CE7AD94DE9C8CDEAD94DEA58C\
DE9C8CD69C8CD69C8CD69C8CDEB5A5D6A58CD6A58CD6A58CDEAD94DEAD94D6A58C
D6A58CD6A58CD6A58CD6A58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A584D6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CEFBDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDEFCEB5\
F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BD\
EFCEB5EFBDA5EFBDADEFBDA5EFC6ADEFC6ADEFC6ADEFBDADE7B59CEFBDA5EFBDA5
E7BDA5E7B59CE7AD9CEFB5A5E7B59CEFB5A5EFBDA5E7B59CEFB5A5E7B59CE7AD9CDE9C8CDEA58C\
DEA58CDEAD94DE9C8CDEAD94DEA58CD6A58CDEB5A5DEB59CDEAD94D6A58CD6A58C
D6A58CD6A58CD6A58CDEA58CD6A58CDEA58CD6A584DEA58CD6A58CDEA58CD6A58CDEA58CD6A584\
D6A58CD6A58CD6A58CDEAD94DECED6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5F7D6C6F7D6C6EFCEB5EFCEB5F7D6C6\
EFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5\
F7BDB5EFC6ADEFC6ADEFBDADEFBDA5EFC6ADEFBDADEFBDA5EFBDA5E7BDA5EFBDAD
EFBDA5EFB5A5EFB5A5E7BDA5E7AD9CEFB5A5EFB5A5E7B59CEFBDA5E7AD9CE7AD9CE7AD94DE9C8C\
DE9C8CE7AD94DEAD94DE9C8CD69C8CD6A58CDEAD94DEB5A5DEB5A5DEAD94DEAD94
D6A58CD6A58CDEAD94D6A58CDEA58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58C\
D6A584D6A58CDEAD94DEB59CF7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6F7D6BD\
F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7CEB5F7BDB5EFC6ADEFC6ADEFBDADEFBDADEFC6ADEFBDADEFBDA5EFB5A5EFBDA5
EFBDADEFBDA5E7B59CEFB5A5E7BDA5EFBDA5EFB5A5EFB5A5E7B59CEFB5A5E7AD94E7AD94E7AD94\
DEAD94DE9C8CDEAD94DE9C8CDEA58CD69C8CD69C8CD6A58CDEB5A5DEB5A5DEAD94
D6A58CD6A58CD6A58CDEA58CD6A58CDEAD94D6A58CDEAD94D6A58CDEA58CD6A58CD6A584D6A58C\
DEAD94D6A58CD6A58CCEB5ADEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5EFCEB5F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECE\
F7D6C6EFCEB5F7BDB5F7C6ADEFCEB5F7C6ADEFBDADEFCEB5EFBDADEFBDADEFBDA5
EFBDADEFBDADEFBDADEFBDA5EFB5A5EFBDA5EFB5A5E7B59CEFB5A5E7B59CE7AD9CE7AD94E7AD9C\
E7AD9CDE9C8CE7AD94DE9C8CDE9C8CDEAD94DE9C8CDEAD94D6A58CDEB59CDEB5A5
DEB59CD6A58CD6A58CD6A58CDEAD94D6A58CDEAD94DEA58CDEA58CD6A58CDEAD94DEA58CD6A58C\
D6A58CDEAD94DEAD94F7BDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6BDF7D6C6EFCEB5F7D6C6EFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BD\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECE
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5EFCEB5F7C6ADEFBDADEFC6ADEFBDAD
EFBDA5EFCEB5EFBDADEFBDADEFB5A5EFBDA5EFB5A5E7B59CEFBDA5E7B59CE7AD9CE7AD9CE7AD94\
E7AD94DEAD94DE9C8CDEAD94DEA58CDEAD94D69C8CDE9C8CD6A58CDEAD94C6ADA5
DEB59CD6A58CD6A58CDEAD94DEA58CDEAD94DEAD94D6A58CD6A58CD6A58CDEAD94D6A58CD6A58C\
D6A58CDEAD94D6A58CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDEFCEB5EFCEB5EFCEB5F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5F7D6BDF7BDB5EFC6ADEFCEB5EFCEB5F7C6AD
EFBDADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFB5A5EFB5A5E7B59CE7B59CE7AD9CE7AD94E7AD9C\
E7AD9CE7AD94DE9C8CDEAD94DEA58CDE9C8CDEA58CDEA58CD6A58CDEAD94D6A58C
DEB5A5DEB59CDEAD94DEA58CD6A58CD6A58CDEA58CDEAD94D6A58CDEA58CD6A58CD6A58CD6A58C\
D6A58CDEAD94DEAD94EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDEFCEB5F7D6C6F7D6C6EFCEB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE
F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7BDB5EFCEB5EFCEB5
F7BDB5EFC6ADEFBDADEFBDA5EFC6ADEFBDADEFBDA5E7B59CE7B59CE7AD9CE7B59CE7AD9CE7AD94\
E7AD94E7AD94E7AD94E7A58CDE9C8CDEA58CDE9C8CDE9C8CDEA58CDEA58CD69C8C
DEB59CDEAD94C6ADA5DEAD94DEA58CD6A58CD6A58CDEAD94DEAD94D6A58CDEA58CD6A58CDEAD94\
D6A58CDEAD94DEAD94DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5
EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6\
F7D6C6F7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5F7BDB5EFCEB5
F7BDB5EFC6ADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CEFB5A5EFB5A5E7AD94E7AD94E7AD9CE7AD94\
E7AD94E7AD9CE7AD94E7AD94E7AD94DE9C8CDEA58CDEA58CDEA58CDE9C8CDEA58C
D6A58CDEB59CD6A58CDEB59CDEB59CDEAD94D6A58CD6A58CD6A58CDEA58CDEAD94D6A58CD6A58C\
D6A58CDEAD94DEB59CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7EFE7E7DEB5A5EFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6BDF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7BDB5F7D6BDEFCEB5F7C6AD
EFCEB5EFC6ADEFBDADEFBDADEFBDA5EFB5A5E7BDA5EFB5A5EFBDA5E7AD9CE7AD94E7AD9CE7AD94\
E7AD94E7AD94E7AD94DEAD94DEA58CDE9C8CDEA58CDEAD94DE9C8CDEA58CD6A58C
DEAD94DEB59CDEB59CD6A58CC6ADA5DEB5A5DEB59CDEA58CD6A58CDEA58CD6A58CDEAD94D6A58C\
D6A58CDEAD94DEB5A5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7E7DEE7C6ADADDEB5A5EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6EFCEB5F7D6C6
F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7DECEF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6\
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7CEB5F7BDB5EFCEB5EFC6AD
F7C6ADEFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59CE7AD9CE7B59CE7AD9C\
E7AD94DEA58CE7AD9CE7AD94E7AD94DEAD94E7A58CDEA58CDEA58CDEA58CDE9C8C
D6A58CD6A58CDEB59CBDA59CD6A58CDEB59CDEB5A5C6ADA5DEA58CD6A58CDEAD94D6A58CD6A58C\
DEAD94DEAD94CEB5ADEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
E7DEEFC6ADA5AD847BE7BDA5F7D6BDF7D6BDF7D6BDF7D6C6EFD6CEEFCEB5EFCEB5
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7CEB5F7BDB5EFC6AD
EFC6ADEFBDA5EFCEB5EFC6ADEFBDA5E7B59CEFBDA5E7B59CEFB5A5E7AD9CE7AD9CE7AD9CDEB59C\
E7AD94DEAD94E7AD94DEAD94E7AD94DEAD94DEA58CDEA58CDE9C8CDEA58CDEA58C
D69C84DEAD94DEAD94DEAD94DEAD94D6A58CD6A58CDEB59CD6A58CD6A58CD6A58CDEAD94DEAD94\
D6A58CDEAD94EFBDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
B5A5A5846B5A9C7363EFC6ADEFCEB5F7D6BDF7D6C6EFD6CEEFCEB5F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7D6BD\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFC6AD
F7C6ADEFBDADEFC6ADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CEFB5A5E7B59CE7AD9CE7AD9CE7AD94\
E7AD9CE7AD94E7AD94E7AD94E7AD94E7AD94E7AD94DEAD94DEAD94DEA58CDEA58C
D6A58CD6A58CDEAD94DEAD94D6A58CD6A58CD6A58CDEB59CDEB59CD6A58CDEAD94DEAD94DEAD94\
D6A58CDEAD94EFCEB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6D6\
73524A634231AD846BEFC6ADEFCEB5F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6\
F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7BDB5EFCEB5EFC6AD
EFC6ADEFBDADEFC6ADEFBDA5EFBDA5EFB5A5E7BDA5EFB5A5E7BDA5E7B59CE7B59CE7AD94E7AD9C\
E7AD94DEAD94DEA58CDEAD94E7AD94DEAD94DEAD94DEAD94DEA58CDEA58CDEA58C
D69C84D6A58CDEA58CDEAD94DEAD94DEAD94D6A58CD6A58CDEB5A5DEB5A5D6A58CDEAD94DEAD94\
DEAD94C6ADA5D6C6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E78C7363\
5A3121634A42B58C73EFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7C6ADEFC6AD
EFBDADEFC6ADEFBDA5EFC6ADEFBDA5E7BDA5EFBDA5E7BDA5EFB5A5E7BDA5E7B59CE7B59CE7B594\
DEAD94E7AD94DEAD94DEA58CE7B59CE7AD94E7A58CDEAD94DEA58CDEAD94DEA58C
DEA58CDEA58CD6A58CDEAD94D6A58CD6A58CDEAD94D6A58CDEB59CCEB5ADDEB5A5DEAD94DEAD94\
DEAD94DEAD94EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFEFA584845A3129\
5A312163423194736BF7D6BDD6C6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6C6\
EFCEB5F7D6BDF7D6BDF7CEB5F7D6BDF7D6BDEFCEB5F7CEB5F7CEB5EFC6ADEFC6AD
EFC6ADEFC6ADEFBDA5EFBDADEFC6ADEFBDA5EFBDA5EFBDA5E7BDA5EFBDA5E7B59CE7AD9CE7B59C\
E7AD9CDEAD94E7AD94DEAD94E7B59CDEAD94DEA58CE7AD94DEA58CDEAD94DEA58C
DEA58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A58CDEB59CDEB5A5DEB5A5DEAD94\
DEAD94D6A58CEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C6B524A634231523129\
4229188C6352DEB5A5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5\
F7CEB5EFC6ADF7C6ADEFCEB5EFC6ADEFCEB5EFBDADEFC6ADEFC6ADEFC6ADEFBDA5
EFBDA5E7B59CEFBDA5EFBDA5E7BDA5EFBDA5E7B59CE7B59CEFBDA5E7B59CE7B59CE7AD9CE7AD94\
DEAD94E7AD94E7AD94E7AD94DEB59CE7AD9CDEAD94DEA58CDEAD94DEA58CDEAD94
DE9C84DE9C84D6A58CDEA58CD6A58CD6A584D6A58CD6A58CDEAD94D6A58CD6A58CDEB59CEFBDAD\
DEB5A5DEAD94F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF6B524A734A39634A42422918\
5A3129CEB5ADF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7C6AD\
EFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFB5A5EFBDA5EFBDA5EFBDA5EFBDA5
EFBDA5EFBDA5E7B59CE7B59CE7B59CEFBDA5E7B59CEFBDA5E7B59CE7B59CE7BDA5E7AD94DEAD94\
E7AD94DEAD94DEAD94DEA58CE7B594DEAD94E7AD9CE7AD94DEA58CDEA58CDE9C84
D6A584D6A58CDE9C84D6A58CDEA58CD6A584D6A58CDEA58CD6A58CDEAD94D6A58CDEAD94DEB5A5\
D6C6B5DEB59CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFD6C6CE6B524A634A425231295A3129\
DEAD94EFD6CEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7BDB5\
EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CEFBDA5EFBDA5EFBDA5
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5EFBDA5E7BDA5E7BDA5E7B59CE7B59CE7AD9CDEAD94\
E7AD94E7AD94DEAD94E7AD94E7AD9CDEAD94E7AD94DEAD94DEA58CDEA58CDEA58C
D6A584DEA58CD6A584DEA58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58CD6A58CD6A58CD6A58C\
DEB5A5D6C6BDF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7947B736B524A634231634231C6ADA5\
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5\
EFC6ADEFC6ADEFBDA5EFC6ADEFBDA5EFC6ADEFBDA5E7BDA5EFB5A5EFBDA5EFBDA5
E7BDA5E7B59CE7B59CE7B59CE7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CDEB59CE7AD94E7B594\
DEAD94DEAD94E7AD94DEAD94DEB59CE7AD94DEAD94DEAD94DEA58CDEA58CDE9C84
D6A58CD6A584DE9C84D6A58CD6A584D6A584D6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A58C\
DEB59CDEB5A5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFAD9C8C5A4239734A39734A39C69C84F7D6C6\
F7D6C6EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5\
EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59C
EFBDA5EFBDA5E7BDA5E7BDA5EFBDA5E7B59CE7B59CE7B59CE7B59CE7AD94E7AD94E7AD94DEAD94\
DEA58CE7B594DEAD94E7AD94E7B594DEAD94DEAD94E7A58CDEA58CDEA58CD6A58C
DEA58CD6A584D6A58CD6A58CD6A584D6A58CD6A584D6A58CD6A584DEA58CDEAD94D6A58CDEAD94\
DEAD94DEB59CF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFBDB5BD6B524A5A42396B524AAD9C8CEFD6CEF7D6C6\
EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7BDB5EFC6ADEFBDA5\
EFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59C
E7BDA5E7B59CE7BDA5E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CDEAD94DEAD94DEA58CE7AD94\
DEAD94DEA58CDEAD94DEAD94DEA58CE7AD94DEAD94DEA58CDEAD94DEA58CDEA58C
D6A58CD6A584D6A584DEA58CD6A584D6A584DEA58CD6A584D6A58CDEA58CD6A58CD6A58CDEAD94\
D6A58CDEB59CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7DEE77B635A5A4239634231AD846BF7D6C6F7D6C6EFCEB5\
F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7BDB5EFCEB5EFCEB5F7C6ADEFC6ADEFBDAD\
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CEFBDA5
E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7B594DEAD94E7B594E7AD9CE7AD94DEAD94DEAD94\
DEA58CDEAD94DEA58CDEA58CDEA58CDEA58CE7B594DEA58CDEA58CDEA58CDEA58C
DEA58CDE9C84D6A584D6A58CDEA58CD6A584D6A58CD6A58CD6A58CD6A58CDEA58CD6A58CDEAD94\
D6A58CDEAD94DEB5A5EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFFFFFC6ADBD634A426342315239317B6352F7DECEF7D6C6F7D6C6F7D6BD\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6
F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5F7BDB5EFCEB5F7BDB5EFBDADEFBDAD\
EFB5A5EFB5A5E7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD94E7AD94E7AD94
E7AD94E7AD94E7AD94E7AD94DEAD94E7AD94DEAD94E7AD94DEAD94E7A58CDEA58CDEA58CDEAD94\
DEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CDEAD94DEA58CDEA58CD6A584
DEA58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58CDEA58CDEAD94D6A58C\
D6A58CDEAD94DEAD94DEB59CD6C6BDEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFE7E7947B73634231634A42734A39BD9C8CF7D6C6EFCEB5F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6\
F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6EFCEB5F7BDB5F7BDB5F7BDB5EFB5A5\
EFB5A5E7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD9CEFB5A5E7AD94E7AD9C
E7AD9CE7AD9CE7AD94DE9C8CE7AD94DEAD94E7AD94DEAD94DEA58CDEAD94DEA58CDEA58CDEA58C\
DEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CDEA58CDEA58CD6A584
DEA58CD6A584D6A584DEA58CDEA58CD6A58CDE9C84DEA58CDE9C84D6A58CDEA58CD6A58CDEAD94\
DEA58CDEA58CDEB59CD6A58CDEB59CEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFBDB5BD5A4239634A42734A39AD8C84EFD6CEF7D6C6F7D6BDF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BD\
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7BDB5F7BDB5F7BDB5F7BDB5EF948CEF948CEF948C\
EF948CE79484E79484E7847BDE9C84E7847BDE9C8CEF948CE7AD94DE9C8CEF948C
E7AD94E7AD94E7AD94E7AD94E7A58CDEAD94DEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58C\
DEA58CDEA58CD6A58CD6A58CDEA58CD6A584DEA58CDEA58CDEA58CDEA58CDEA58C
D6A58CD6A584DEA58CD6A58CDEA58CD6A58CD6A58CD6A58CDE9C84D6A584D6A58CDEA58CD6A58C\
D6A58CDEA58CD6A58CDEB59CDEB59CEFBDADEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7947B73634231634A428C7363EFD6CEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6\
F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7BDB5F7BDB5F7C6ADEF948CEF948CF7BDB5E7AD9CEF948C\
EF948CE7847BE7847BE7847BE7847BE7847BE7847BE7847BEF948CE7847BE7847B
E7847BD68C7BE79484E7A58CE7AD94E7AD94DEAD94DE9C8CDEA58CDE9C84DEA58CDEA58CDEA58C\
DE9C84D6A58CDEA58CDE9C84D6A584D69C84D6A584D6A584DEAD94DEA58CDEA58C
DEA58CDEA58CD6A58CDEA58CDEA58CDEA58CDEA58CDEA58CD6A584D6A584DEA58CD6A58CDE9C84\
DEAD94D6A58CDEAD94D6A58CDEB59CD6A58CEFCEB5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E7DEEF7B635252393173524AEFBDADEFD6CEEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BD\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7BDB5F7BDB5F7BDB5D6BDC6F7C6ADEF948CEF948CEF948C\
E7847BE7847BE7847BE7847BDE7B6BE7847BE7847BDE9C84E7847BE7847BE7847B
DE7B6BE7847BE7847BD68C7BD68C7BE79484DE9C8CE7A58CDE9C8CDEA58CDEA58CD6A58CDEA58C\
DEA58CDE9C84DE9C84D6A58CD69C84D6A584D6A584DEA58CDEA58CDEA58CDEA58C
D6A58CDEA58CD6A58CDEA58CDEA58CDEA58CD6A58CD6A58CD6A58CDE9C84D6A58CDEA58CD6A58C\
DEA58CDEA58CDEAD94DEAD94DEAD94DEB59CDEB5A5DECED6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7CEB5B56B524A634231AD8C84F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5EFCEB5F7CEB5F7D6BDF7CEB5F7D6BD\
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7DECEF7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5EF948CEF948CEF948C\
E7847BE7847BE7847BE7847BE7847BE7847BE7847BEF948CE7847BE7847BE7847B
E7847BDE7B6BE7847BE7847BE7847BD68C7BE7847BCE8C84DE9C8CDE9C8CDEA58CDEA58CD6A58C\
D6A58CD6A58CD6A584D6A584D69C73D6A584D6A584D6A58CD6A584DEA58CDEAD94
DEA58CDEA58CDEA58CDEA58CDEA58CDEA58CDEA58CDEA58CD6A584DEA58CDEA58CD6A584D6A58C\
DEA58CD6A58CDEAD94D6A58CDEAD94DEB59CD6A58CEFBDADF7E7DEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7947B73523931846B5AEFCEB5F7DECEEFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7DECEF7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6C6F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7BDB5\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECE
F7D6C6F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7E7DEF7BDB5F7BDB5F7C6ADF7C6ADEFB5A5EF948C\
E7847BE78473E7847BE7847BE7847BE7847BDE9C8CEF948CE7847BE7847BE7847B
E7847BE7847BDE7B6BE7847BE7847BE7847BDE7B6BE7847BD68C7BDE9C8CDE9C8CDEA58CDEA58C\
DEA58CDEA58CDEA58CD69C84CE947BD69C84D6A584DE9C84D6A58CDEA58CDEA58C
D6A58CDEAD94DEA58CDEA58CDEA58CDEAD94DEAD94DEA58CDEA58CD6A584DEA58CDEA58CD6A58C\
D6A58CDEA58CDEAD94DEAD94D6A58CDEAD94DEB59CDEB59CD6C6C6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
D6C6C6AD9C8C634231AD846BEFD6CEF7DECEF7D6BDEFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDF7CEB5EFCEB5F7CEB5EFCEB5F7CEB5F7D6BDF7D6BDF7BDB5F7CEB5\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7BDB5F7BDB5
F7BDB5F7BDB5DECED6F7BDB5F7BDB5F7BDB5F7BDB5EF948CEF948CE7847BE7847BE78473E78473\
E77B6BE77B6BDE6B5ADE6B5ADE7B6BDE6B5AE7847BE7847BE7847BE77B6BE78473
DE7B6BE78473DE7B6BE78473E7847BE7847BE7847BE7847BD68C7BD67B6BE7847BD69C8CD69C84\
DE9C8CD6A584DEA58CD6A584D69C84D6A584D69C73D69C84DE9C84DEA58CDEA58C
DEA58CDEA58CDEA58CDEAD94DEA58CDEA58CDEAD94DEA58CDEA58CDEA58CDEA58CD6A584DE9C84\
DEA58CD6A58CDEA58CDEAD94D6A58CDEA58CDEAD94DEAD94DEB59CD6C6B5F7F7F7
F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECED6
9484849C8C8C5A3129DEB5A5F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BD\
F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6BDF7D6BDF7CEB5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7CEB5EFC6ADF7D6BD\
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7BDB5F7BDB5F7BDB5
F7BDB5F7DECEF7BDB5F7DECEF7BDB5F7C6ADE7AD9CE79484E78473E78473E77B6BD67363DE6B5A\
DE6B5AD67363DE6B5ADE6B5AE77B6BE77B6BE77B6BE77B6BE78473E77B6BE77B6B
DE6B5ADE6B5ADE7B6BDE7B6BDE7B6BDE7B6BDE7B6BDE7B6BE7847BE7847BD68C7BDE9C84DE9C84\
DE9C8CD6A58CDE9C84D6A58CD69C73D69C84D69C84D6A584D6A584DEA58CDEA58C
DEA58CDEA58CDEAD94DEAD94DEAD94DEA58CDEAD94DEA58CE7A58CDEA58CDEA58CD6A584DE9C84\
D6A58CDEA58CD6A58CDEAD94DEA58CDEAD94DEAD94D6A58CDEB59CDEB5A5F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF9C8C8C
7B635A735A528C7363F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BD\
F7D6BDF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDF7CEB5F7C6ADEFBDA5EFCEB5F7CEB5F7C6ADF7C6ADEFC6ADF7CEB5\
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7BDB5F7BDB5F7BDB5F7BDB5
F7BDB5F7BDB5F7BDB5F7BDB5EFB5A5E79484E79484E78473D67363DE6B5ADE6B5AD66352DE6B5A\
DE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5AD67363DE6B5A
DE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE7B6BDE7B6BDE7B6BE7847BD67B6BD67B6BD68C7BCE8C84\
D69C84DE9C8CD6A58CDE9C84D69C84D69C84D69C73D69C84D6A584D6A584D6A58C
DE9C84DEA58CDEA58CDEA58CDEA58CDEA58CDEAD94DEA58CDEA58CDEAD94DEA58CD6A584DEA58C\
D6A58CD6A58CDEA58CD6A58CDEA58CDEA58CD6A58CDEAD94D6A58CDEB59CE7DEE7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFC6ADBD8C7363
7B635A523129EFCEB5EFD6CEF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BD\
F7D6BDF7CEB5F7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7BDB5F7CEB5EFC6ADEFBDA5EFC6ADF7CEB5EFC6ADF7C6ADEFC6ADF7C6AD\
F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7C6AD
F7BDB5EFB5A5E7AD9CEF948CEF948CE78473E77B6BDE7B6BDE7B6BCE8C84DE9C84CE8C84CE7352\
D68C7BE7847BDE7B6BDE7B6BD67B6BCE5A4AD67B6BD67363DE6B5AD66352DE6B5A
DE6B5AD66352DE6B5AD66352DE6B5ADE6B5AD67363DE7B6BDE7B6BD68C7BD68C7BD67B6BD68C7B\
D68C7BD69C8CDE9C8CD6A584D69C73D69C84D69C73C69C84D69C73D6A584DEA58C
DEA58CDEA58CDEA58CDEA58CDEAD94DEA58CDEA58CE7AD94DEA58CDEA58CDEA58CDEA58CD6A584\
DE9C84DEAD94D6A58CDEAD94DEA58CD6A58CDEAD94DEAD94DEAD94DEB59CEFD6CE
E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E79C8C8C735A52
5A4239523129F7DECEF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BD\
F7D6BDF7D6BDF7CEB5F7D6BDF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7D6BDF7D6BDEFCEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5F7D6BD\
F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7BDB5F7C6ADF7C6ADF7C6ADF7C6ADE7AD9C
EF948CEF948CE79484E7847BE78473DE7B6BD68C7BCE8C84DE9C8CDEB5A5E7AD9CE7AD9CC66B52\
CEB5B5F7BDB5DEB5A5DEB59CDE9C8CB5735AE7AD9CE7AD9CDE9C84D67B6BD67363
D66352D66352CE5A4AD66352D66352DE6B5ADE6B5ADE6B5ADE7B6BDE7B6BD67B6BD67B6BD68C7B\
D68C7BD68C7BDE9C8CD6A58CD69C84D6A584CE947BD69C73D69C84D6A584DE9C84
D6A584D6A584DEA58CDEA58CDEA58CDEA58CE7A58CE7AD94DEA58CDEA58CDEAD94DEA58CDEA58C\
D6A58CD6A58CDEAD94DEA58CDEAD94DEA58CDEA58CDEAD94DEAD94DEAD94DEB5A5
F7E7DEE7DEE7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7DEE79C8C8C8C736B634A42
422921846352F7D6C6F7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5\
F7CEB5F7CEB5F7CEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7CEB5F7D6BDF7CEB5F7C6ADEFBDA5EFBDA5EFBDA5E7B59CEFBDA5EFBDA5EFCEB5F7D6BD\
F7DECEF7D6C6F7DECEF7BDB5F7BDB5F7C6ADEFB5A5EFB5A5E7AD9CEF948CE79484
E7847BE78473D67363D67B6BE7847BCE947BCEB5B5EFD6CED6C6BDEFD6CED6C6C6D6C6BDD69C8C\
DECED6D6C6BDF7BDB5CEB5B5DEB5A5CE8C73CEB5B5CEB5B5DEB5A5DEB5A5CE8C73
A5634AD67363BD846BCE7352CE5A4ADE6B5AD66352D67363DE6B5AD67B6BD67B6BD67B6BD67B6B\
D68C7BD68C7BCE8C84D69C84D69C84D69C73CE947BD69C73D69C84D6A584DE9C84
DE9C84DEA58CDE9C84DEAD94E7AD94DEAD94DEAD94DEAD94DEAD94E7AD94DEAD94DEA58CD6A58C\
DEA58CDEA58CDEA58CDEAD94DEAD94DEA58CDEA58CDEAD94DEAD94D6A58CDEAD94
D6C6B5E7DEE7EFE7E7E7DEEFF7EFEFEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD8C737B6B524A523129
5A3129AD8C84F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BD\
F7C6ADF7C6ADF7CEB5F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7CEB5F7CEB5F7CEB5EFC6ADEFC6ADEFBDA5E7B594E7B594E7B594E7B594EFBDA5F7CEB5F7D6C6\
F7DECEF7D6C6F7BDB5F7C6ADEFB5A5EF948CE7AD94E7AD94EF948CE78473E77B6B
D66352CE5A4AB55239D67363C6ADA5D67B6BE7AD9CD6C6C6D6C6C6EFD6CED6C6C6CEB5B5CEB5B5\
D6C6CECEB5B5CEB5B5EFBDADCEB5B5BDA59CD6C6BDD6C6BDF7BDB5CEB5B5CE8C84
AD6B52C69484D69C8CBD846BA5634A945239CE5A4AD66352D67363D66352D67363D67B6BD67B6B\
D67B6BD68C7BD68C7BD68C7BD6A584D69C84D6A584D69C84D69C73D6A584D6A584
DE9C84D6A584DEA58CDEA58CDEAD94E7B594E7B594DEAD94DEAD94DEAD94DEA58CDEA58CDE9C84\
D6A58CDEA58CDEAD94DEA58CDEAD94DEA58CD6A58CDEAD94DEAD94D6A58CDEAD94
DEB59CE7DEE7E7DEEFF7EFEFE7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E79C8C8C8C7B7363524A523129
6B524ACEB5ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7CEB5\
F7C6ADEFC6ADF7CEB5F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7BDB5EFC6ADF7C6ADEFBDA5EFBDA5E7B594E7B594E7A58CE7A58CEFBDA5F7D6BDF7DECE\
F7DECEF7BDB5E7AD9CE7AD9CEF948CEF948CEF948CEF948CE78473BD5A42BD5A42
CE5A4ACE7352D66352CE7352D67363E79484DE7B6BDE7B6BD68C73E78473D68C73D67B6BD69C84\
D69C8CD6A58CC6ADA5C6ADA5DEB5A5D69C8CCEB5B5D6C6B5CEB5B5D6C6B5D69C8C
BD846BD69C8CC6ADA5C6947BB57B63A54231A54231C66B52D66352D66352D67363D67B6BD67B6B\
D68C7BD67B6BD68C7BCE8C84D69C84D69C84D69C73CE947BD69C73D69C84D6A584
DE9C84DEA58CDEA58CDEAD94DEAD94DEA58CDEAD94E7B594E7B59CE7B594DEAD94DEA58CDE9C84\
DEA58CDEA58CDEAD94DEAD94DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEB59C
DEB59CD6C6C6EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFBDB5BDB59C9C8C7B735A4239523129
C69C84F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7CEB5EFC6AD\
F7C6ADEFBDA5EFC6ADF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6
F7C6ADEFC6ADF7C6ADEFBDA5E7B594E7A58CDE9C84DE9473DE9C84EFBDA5F7D6BDF7D6C6F7BDB5\
E7AD94E7847BE79484E7847BE78473CE8463C66B52842918631810D67B6BEFCEB5
E7AD9CCE8463DE6B5AE79484E79484E79484DE7B6BDE7B6BEFB5A5F7E7DEF7E7E7F7EFEFF7E7DE\
EFD6CEEFD6CEE7AD9CE77B6BD67363E79484D68C7BCE8C73D67363CE735AC66B52
BD8463D69C8CBDA59CBDA59CC69484AD7B6BA56B52AD735AA5634AA55239CE5A4AD66352D66352\
CE735ACE8C73D67B6BCE947BD68C7BD69C84D69C84D69C73C69C84D69C73D6A584
DE9C84DEA58CDEA58CDEAD94DEAD94E7B59CE7B59CE7B594E7B594E7B594E7B594DEAD94DEA58C\
DEA58CDEA58CDEAD94DEAD94DEAD94DEA58CD6A58CDEA58CDEA58CDEAD94DEAD94
DEAD94EFBDADD6C6C6DED6E7F7E7DEF7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6CE9C8C8CB5A5AD7B635A4229216B524A
F7BDB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7C6ADF7C6AD\
F7C6ADF7C6ADEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
EFC6ADF7C6ADEFBDA5E7B59CE7A58CE7A58CDE9C84DE9C84DEA58CEFC6ADF7D6C6F7C6ADE7A58C\
DE7B6BDE7B6BC66B529C5A42CE735ACE8C84DEB59CD6C6BDC68C73EFCEB5F7E7DE
F7E7DEEFBDA5EFBDADF7DECEF7DECEF7BDB5E7AD94E7847BF7E7DEF7EFEFF7EFEFF7E7E7F7E7DE\
F7E7DEEFD6CEF7E7DED6C6C6EFCEB5DECED6EFD6CEF7DECED6C6C6EFBDADD68C7B
D67B6BC66B52BD846BBD9C8CC69484B5846BAD735AAD735AA5735A9C5A42A54231BD5A42CE5A4A\
CE5A4AD67363C66B52D67B6BD68C7BD69C84D69C73D69C84D68C7BD6A584DE9C84
D6A58CDEA58CDEA58CDEAD94E7B594E7B59CEFBDA5E7B59CE7B59CE7B594E7B594DEAD94DEA58C\
DEA58CDEA58CDEAD94DEAD94DEA58CDEAD94DEAD94DEA58CDEA58CD6A58CDEAD94
DEAD94C6ADA5EFCEB5DECED6DED6E7D6C6BDF7E7DEF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7ADA5AD9484849C8C8C5A4239523129B58C73
EFD6CEF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6ADEFBDA5\
EFBDA5EFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6BD
F7C6ADEFBDA5E7B59CE7A58CE7A58CDE9C84DE9473D69C73E7A58CEFC6ADEFB5A5DE7B6BDE6B5A\
D663529C392942181094634ADEB59CEFBDADF7E7DEF7DECEF7CEB5F7E7DEF7E7DE
F7E7DEF7E7DEF7EFEFF7EFEFF7EFEFF7EFEFF7E7DEEFBDA5F7E7E7F7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7DECEF7E7DEEFCEB5EFD6CEEFD6CEF7E7DEEFD6CEEFD6CEEFD6CEEFD6CE
D6C6C6E7847BB55239C66B52B5735AA56B5294736BB58C73AD7B6B945239734A39A54231BD5A42\
CE5A4AC66B52D67363D67363D68C7BDE9C84D69C84D69C73C69C84D69C73D6A584
DE9C84DEA58CDEA58CE7B594E7B59CE7B59CE7BDA5EFBDA5E7B59CE7B59CE7B594E7B594DEA58C\
DEA58CDEAD94DEAD94D6A58CDEAD94DEAD94DEA58CDEAD94D6A58CDEAD94DEAD94
DEAD94DEB59CD6C6B5F7E7E7F7F7F7DED6E7D6C6D6DECED6E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD94948C7B73735A524A3131634A42DEB5A5
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7CEB5F7D6BDF7D6BDF7C6ADF7C6ADEFBDA5\
F7C6ADF7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BD
EFC6ADEFBDA5E7B594E7A58CDE9C84DE9473CE8C6BDE9C84DEA58CE7AD94D67363CE5A4AB55239\
9C3929844A39945239DEB59CEFCEB5F7D6C6F7E7DEF7DECEF7D6C6F7E7DEF7E7DE
F7E7DEF7E7E7F7E7E7F7E7E7F7EFEFF7EFEFF7E7DEF7DECEF7E7E7F7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7E7DEF7DECEEFCEB5EFD6CEF7E7DEEFD6CEEFD6CEEFD6CEEFD6CEEFD6CE
EFD6CEDEB59CCE5A4ACE735ACE5A4AAD5A42A56B52AD7B6BAD7B6B734231734A398452429C3929\
BD5A42CE5A4ACE5A4ACE735ACE8C73CE8C84D69C84D69C84D69C73D69C84D69C73
D6A58CDEA58CDEA58CDEAD94E7B594E7B59CE7B59CEFBDA5EFBDA5E7B594E7B594DEAD94DEA58C\
DEA58CDEAD94DEA58CDEAD94DEAD94DEA58CDEA58CDEA58CDEAD94DEAD94DEAD94
DEAD94DEB59CEFBDADDED6E7F7EFEFF7EFEFF7F7F7D6C6D6DECED6F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C7B7363524A634A42523129845242F7D6C6
EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7C6ADEFBDA5\
EFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
F7C6ADEFBDA5E7A58CE7A58CDE9473CE8C6BCE8463D68C7BD68C73D66352B552399C39298C2921\
8C31299C5A42BD846BD6C6BDEFD6CEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7E7F7EFEFF7EFEFF7E7DEF7E7DEF7DECEF7E7E7F7EFEFF7EFEFF7E7E7F7E7DE\
F7E7DEF7E7DEEFD6CEEFCEB5EFD6CEF7E7E7F7E7DEF7E7DEF7E7DEEFD6CEEFD6CE
EFD6CEDEB5A5E7BDA5D6C6BDC6ADA5CE8C84AD5A42A55239945A4A8C31295A3121633931734229\
9C3929BD5A42BD5A42C66B52CE8C73D68C73D69C84D6A584D69C84D69C73D6A584
DE9C84DEA58CDEA58CE7A58CE7B59CE7B594EFBDA5EFBDA5E7B59CEFBDA5E7B59CE7B594E7B594\
DEA58CDEA58CDEAD94DEA58CDEA58CDEAD94D6A58CDEA58CD6A58CDEAD94DEAD94
DEAD94DEAD94DEB5A5EFCEB5DED6E7F7EFEFF7EFEFF7EFEFEFE7E7E7DEEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7F7F7F7EFE7E7F7F7F7EFE7E7F7EFEFF7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF8C736B5242395239315231298C7363F7DECE
F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5EFC6ADF7C6ADF7C6AD\
EFC6ADF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
EFBDA5E7B594E7A58CDE9C84DE9473CE8463CE8C6BCE735AB55239A542318C29218429187B2918\
945239A5735ADEB59CF7D6C6F7D6BDF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7D6C6F7E7DEF7E7DEF7E7E7F7EFEFF7E7DEF7D6C6F7D6C6F7E7DEF7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7DECEEFCEB5EFBDA5EFD6CEF7E7E7EFD6CEF7E7DEEFD6CEF7E7DEEFD6CE
EFD6CEEFC6ADD6C6C6F7D6C6EFD6CEEFD6CEC6ADA59452399C39298C31297321107B2918422921\
4A10089C3929B55239CE5A4AC66B52D67B6BD68C73D69C84D69C84D69C73D69C84
D6A584DEA58CDEA58CDEAD94E7B594EFBDA5E7B59CEFBDA5EFBDA5E7B59CEFBDA5E7B594DEA58C\
DEA58CDEA58CDEA58CDEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDEAD94DEAD94
DEAD94DEAD94DEB59CD6C6B5EFD6CED6C6D6F7EFEFE7DEEFF7EFEFF7EFEFE7DEEFF7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7E7DEEFE7DEEFF7EFEF\
F7F7F7F7EFEFF7F7F7F7F7F7D6C6D694848463524A5A42395A3129C69C84F7DECE
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7CEB5F7C6ADF7C6ADEFBDA5\
F7CEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BDF7D6BD
E7B59CE7B594E7A58CDE9473CE8C6BD67363CE8C6BA542319C39298C29218429187B29187B3121\
945A52B5735AE7AD9CE7B59CEFCEB5F7E7DEF7E7DEF7D6C6F7DECEF7E7E7F7E7DE
F7D6BDF7E7DEF7E7DEF7E7E7F7EFEFF7E7DEF7D6C6F7D6BDF7E7DEF7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7D6C6F7C6ADE7AD9CF7D6C6F7E7E7F7E7DEF7E7DEF7E7DEEFD6CEEFD6CE
F7D6C6EFBDADD6C6C6F7D6C6D6C6C6F7D6C6EFD6CEC69484A55239AD6B52AD7B6B5221184A1008\
1810104A10089C3929B55239C66B52CE5A4ACE8C73D68C7BD69C84D69C84D69C73
D69C84DEA58CDEA58CDEAD94E7B594E7B59CEFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B594\
DEAD94DEAD94DEAD94D6A58CDEAD94DEAD94D6A58CDEA58CDEA58CDEAD94D6A58C
DEA58CDEAD94DEB59CDEB5A5CEBDB5B59C9CCEBDCED6C6CED6C6D6DED6E7F7EFEFE7DEEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEEFD6CEDEAD9C8C7B635A5239315231298C7363F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7CEB5F7D6BDF7D6BDF7CEB5EFC6ADF7C6ADF7C6ADEFCEB5\
F7CEB5EFC6ADF7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7CEB5F7C6AD
E7A58CDE9473DE9C84DE9473CE8463CE8C6BCE94738C2921A54231A542318C3129842918732110\
A54231D68C73DE7B6BE7A58CF7BDB5E7AD94E79484F7C6ADF7DECEF7DECEF7C6AD
F7C6ADF7D6BDF7E7DEF7E7DEF7E7DEF7D6BDEFB5A5EFBDADF7D6BDF7E7E7F7E7E7F7E7E7F7DECE\
F7D6C6F7C6ADEFB5A5E7AD9CE7AD94EFCEB5EFD6CEF7E7DEEFD6CEEFD6CEEFD6CE
E7BDA5DEA58CEFD6CEF7D6C6F7D6C6D6C6C6F7D6C6D6C6BDDEB5A5DEB59CEFCEB5B58C73844A39\
AD7B6B73524A211010421810A55239BD5A42BD5A42CE735AD68C7BDEA58CD69C73
D6A584DEA58CDEA58CE7B594E7B59CEFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B594\
E7AD94E7B594DEAD94DEAD94DEA58CD6A58CD6A58CDEA58CD6A58CDEA58CDEA58C
DEAD94DEAD94DEAD94E7BDA5D6C6B5B59C9C73524A948484B5A5ADCEBDCED6CEDEE7DEE7EFE7E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFDED6E78C7B736342314A3131523129C6947BF7D6C6EFCEB5
EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7C6ADEFC6ADF7C6ADF7D6BD\
F7C6ADEFBDA5EFBDA5F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7C6AD
E7A58CCE8463DE9C84D68C73C68C63CE8C6BD68C7BBD5A42BD5A42B55239A542318C2921842918\
AD5A42E78473DE7B6BE79484E7A58CDE9473E79484EFBDA5F7D6BDF7D6BDF7BDB5
EFB5A5F7C6ADF7DECEF7E7DEF7E7DEF7C6ADE7AD94F7BDB5F7D6BDF7D6C6F7E7DEF7DECEF7D6BD\
F7C6ADE7AD94EF948CE7AD9CEFB5A5EFBDA5F7D6BDEFD6CEEFD6CEF7D6C6F7D6C6
E7AD94D69C73EFCEB5D6C6C6F7D6C6F7D6BDEFCEB5EFC6ADD6A58CDEB5A5DEB5A5DEB59CBD9C8C\
D6A58CBD9C8C844A397342319C3929A54231B55239C66B52CE8C73D69C84D69C84
D69C84DE9C84DEA58CDEAD94E7B594EFBDA5EFBDA5EFC6ADEFC6ADEFBDA5E7BDA5EFBDA5E7B59C\
DEAD94DEA58CDEAD94DEAD94DEAD94DEA58CD6A58CDE9C84DEA58CDEA58CDEAD94
DEA58CDEAD94DEAD94DEB59CD6C6B5CEB5ADAD9494CEBDB5CEBDB5CEBDB5D6C6BDDECED6DED6E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7DECED6B59C9C63524A422921523129634231DEB5A5F7D6C6F7BDB5
F7D6BDF7BDB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6ADF7C6ADF7C6ADEFBDA5F7CEB5EFCEB5\
F7C6ADEFBDA5F7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFBDA5
DE9473CE8463DE9C84D68C73CE8463D68C73DEA58CDE9C84E7847BDE7B6BCE735AA542319C3929\
B55239D67B6BD67B6BDE9473E7847BDE9473E79484E7A58CE7B59CF7D6BDF7BDB5
E7A58CE7AD94F7D6BDF7D6BDF7D6BDE7AD94E7AD9CF7BDB5F7BDB5EFCEB5EFCEB5F7BDB5E7A58C\
E79484E78473E78473E79484EF948CE7AD9CEFBDA5EFC6ADEFCEB5EFCEB5E7BDA5
DE9473DE7B6BE7B59CF7D6BDF7D6BDEFCEB5EFCEB5DEAD94D6A58CDEB5A5DEB5A5DEAD94BD9C8C\
D6A58CDEAD94AD7B6B9C6B527B31219C3929A54231B55239D67363CE947BD6A584
D69C73DEA58CDEA58CDEA58CE7B59CE7BDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59C\
E7B594DEAD94DEA58CD6A58CDEA58CD6A584DEA58CD6A584D6A58CDEA58CDEA58C
DEA58CDEAD94DEB59CDEB59CDEB5A5D6C6C6D6C6D6DECED6D6C6C6D6C6CED6C6BDCEBDB5CEBDC6\
E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DED6E7CEBDCE948484634231392921312121392921734A42EFCEB5D6C6C6F7BDB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5EFC6ADEFBDA5EFBDA5F7D6BDF7CEB5\
EFBDA5EFBDA5EFBDA5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5EFBDA5
E79484CE7352CE8C6BDE9C84DE9473D6A584E7AD94E7BDA5E7AD9CE7AD9CE7AD94EF948CDE7B6B\
D67363DE6B5ADE7B6BE78473E78473E78473E78473DE9473E79484E7AD9CE79484
E79484E77B6BE7A58CE7AD94E7A58CE78473E7A58CE7AD9CEFB5A5F7BDB5F7BDB5E7AD9CD67363\
DE6B5ADE7B6BDE6B5ADE7B6BE78473E79484E7A58CE7A58CE7AD94E7AD94DE9C84
D67363CE735AE7A58CEFCEB5EFCEB5EFCEB5E7B59CD69C73DEB59CDEB5A5DEB5A5DEAD94D6A58C\
C6ADA5BD9C8CB58C73A5735A8C31297B29188C2921A54231BD5A42CE8C73D68C7B
D69C84DE9C84DEA58CDEA58CE7B59CEFBDA5EFBDA5EFC6ADEFC6ADEFBDA5EFBDA5E7B59CE7B59C\
E7B594DEA58CDEAD94DEA58CD6A58CD6A58CD6A584D69C84DE9C84DEA58CDEA58C
DEA58CDEAD94DEB59CDEB59CDEB5A5D6C6BDDED6E7E7DEE7D6C6D6D6C6CECEBDC6D6C6CED6C6CE\
D6C6D6E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFD6C6D6\
B59C9C735A525A42395242394A3131312118312118A5735AEFCEB5F7D6BDEFCEB5
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7CEB5EFCEB5F7C6ADF7C6ADEFBDA5F7C6ADF7CEB5EFC6AD\
EFBDA5E7B594F7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7CEB5EFBDA5
DE9C84CE7352CE8C6BDEA58CDEA58CE7AD94E7B59CF7BDB5EFCEB5F7BDB5EFCEB5EFBDADEFB5A5\
EFB5A5E7AD9CEF948CE7AD9CE7AD9CEF948CEF948CEF948CE7847BE7847BE78473
E7847BE7847BDE7B6BE7847BE7847BE7847BE7847BE7847BE7847BDE9C84E7847BE7847BDE7B6B\
E7847BDE7B6BDE7B6BD67B6BD67363D67363DE7B6BD68C73E78473DE9473DE7B6B
CE8463D67363CE8C6BE7BDA5EFC6ADE7BDA5DEA58CCE8C6BDEAD94DEB59CEFC6ADDEAD94D6A58C\
DEAD94DEAD94C6947BB57B637342317321107B2918842921A54231C66B52D68C73
D69C73D6A58CDE9C84DEA58CE7B594E7BDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B594\
E7AD94E7B594DEAD94D6A58CD6A584DE9C84D6A584D69C84D6A584DEA58CDEA58C
DEAD94DEAD94DEB59CDEB59CDEB59CD6C6BDE7DEEFE7DEEFE7DEEFE7DEEFCEBDC6CEBDC6D6CEDE\
D6C6D6F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFD6C6D68C7363\
634A42422921392921523129523129422118422921C69484F7DECEF7D6C6EFCEB5
F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7C6ADEFBDA5F7C6ADEFBDA5EFC6ADF7BDB5F7C6AD\
EFBDA5E7AD94EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7BDB5F7C6AD
E7A58CCE735ACE8463DEA58CE7B59CE7BDA5EFB5A5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6BD\
F7D6BDF7D6BDF7D6BDF7BDB5F7BDB5EFBDADEFBDADEFB5A5EFB5A5EFB5A5E7AD9C
E7AD9CEF948CEFB5A5EFB5A5E7AD9CEF948CE7AD9CEF948CEF948CEF948CEF948CE7AD9CDE9C8C\
E7847BDE9C84E7847BDE7B6BDE7B6BDE7B6BD67363DE6B5ACE7352CE735ACE735A
D67363D67363D67363DEA58CDEB59CDEA58CCE8C6BCE735AD68C73DEB59CEFC6ADD6A58CCE8C84\
D6A58CD6A58CB58C73AD7B6B7342316318107321107321108C2921A55239CE8463
D68C7BDE9C84D6A584DEA58CE7B594EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B594\
E7B594DEAD94DEA58CDEA58CDE9C84D6A584D6A584D6A58CD69C84D6A584DEA58C
DEAD94D6A58CDEAD94DEB59CDEB59CEFBDADF7F7F7F7F7F7F7EFEFF7EFEFDECED6D6C6D6D6C6D6\
F7E7DEDED6E7E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C8C8C4A3131\
422921312118421810422921523129422921523129DEB59CF7D6C6EFCEB5F7D6BD
F7D6C6F7D6BDF7D6C6F7D6BDF7CEB5F7CEB5F7C6ADF7C6ADEFBDA5EFC6ADF7BDB5EFC6ADEFBDA5\
E7B59CE7B59CF7CEB5F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7D6BDF7CEB5EFC6AD
E7A58CCE8463CE7352DEA58CE7BDA5EFC6ADEFC6ADF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7BDB5F7BDB5F7BDB5
F7BDB5EFBDADF7BDB5F7BDB5F7BDB5EFB5A5EFB5A5EF948CEFBDADEF948CEF948CEF948CEF948C\
EF948CEF948CEF948CE7847BE7847BE7847BD67B6BD67B6BCE735ACE5A4AC66B52
C66B52C66B52CE735AD68C73D69C84D68C73C66B52C66B52CE8C6BDEAD94DEB5A5D6A584C68C63\
D69C84D69C8CAD735AB57B637342316318105210086318107321108C3129AD5A42
D68C7BD69C84DEA58CDEA58CE7A58CE7B59CEFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5E7B594\
E7B594DEAD94DEA58CDEAD94D6A58CD6A584DE9C84D6A584D6A584D6A584DEA58C
D6A58CDEA58CDEAD94DEB59CDEB59CEFBDADD6C6BDF7E7DEF7F7F7F7F7F7DED6E7E7DEEFF7E7DE\
D6CEDED6C6D6F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7E7DEE7D6C6D6523931422921\
211010312118523129633931523129422918A5735AF7D6C6F7D6C6F7BDB5F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7C6ADEFC6ADEFCEB5F7BDB5EFC6ADEFC6AD\
EFBDA5EFC6ADF7CEB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7C6ADEFBDA5
E7AD94E79484CE8463CE8463E7AD94EFBDA5EFBDADF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECE\
F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECED6C6C6F7BDB5F7D6BDF7BDB5D6C6C6F7BDB5F7BDB5EFBDAD\
EFBDADEFBDADEFBDADEFB5A5E7AD9CE7AD9CEF948CE7847BE7847BDE7B6BD68C7B
E7847BD67B6BD67B6BD67B6BD67363C66B52C66B52C66B52C66B52CE8C6BD69C73CE8C6BC66B52\
BD5A42B5735AAD5A42A542317342314210105210087321108C3129844A398C3129
A55239D69C73D69C84D69C84E7AD94E7B594EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5E7B59C\
E7B594DEA58CDEA58CDEA58CD6A58CD6A58CD69C73D69C84D69C84D6A584D6A58C
DEA58CDEAD94DEA58CDEAD94DEB59CDEB5A5A5847B7B6352B59C9CD6C6C6DED6E7F7E7DEE7DEE7\
DED6E7DECED6E7DEE7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7E7DEE7C6ADBD422921422921\
4229214229215A31296339295A3121522118AD846BF7D6C6F7D6BDF7D6C6EFCEB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7C6ADEFC6ADEFC6ADF7BDB5EFCEB5F7CEB5EFC6AD\
EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7BDB5EFBDA5EFBDA5
E7A58CE7A58CDE9473CE8463DEA58CE7BDA5EFCEB5F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7D6C6\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7C6ADF7CEB5\
F7CEB5F7C6ADEFBDA5EFC6ADF7BDB5EFC6ADE7AD94E7AD94EF948CE79484E7847B
E7847BD68C7BE7847BE7847BD67B6BCE8C73D67363D67363D67363D67363CE8C73BD8463CE634A\
B55239B55239AD5A42A542317B31216318106318107342298C31298C31298C2921
8C3129D68C7BD69C73D69C73DEA58CE7B594E7B59CEFBDA5EFBDA5EFCEB5EFBDA5E7B59CE7B594\
E7AD94DEAD94DEAD94DEA58CDEA58CD6A584D69C84D69C84D69C73D6A584DEA58C
DEA58CDEAD94DEAD94DEAD94DEB59CEFBDADAD9C8C6B524A947B73D6C6C6DED6E7E7DEEFE7DEEF\
F7F7F7E7DEEFE7DEEFEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6BDB5BD9C8C8C422118312118\
5A31295231295A31294229214221185A3121BD9C8CF7D6C6F7D6BDEFCEB5F7D6BD
F7D6BDF7D6C6F7BDB5F7D6BDF7CEB5F7CEB5EFCEB5EFC6ADF7BDB5F7BDB5EFCEB5F7BDB5EFCEB5\
F7BDB5EFCEB5F7CEB5F7D6BDF7D6BDF7BDB5F7D6BDF7BDB5EFCEB5EFC6ADEFBDA5
E7AD94E7A58CDE9C84CE8C6BCE8C6BE7B594EFBDADF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDEFC6ADF7CEB5EFC6ADEFBDA5\
F7C6ADEFBDA5F7C6ADEFBDA5F7C6ADEFC6ADEFBDA5E7B594E7B59CE7B59CE7AD94
E7AD94EF948CDE9C8CDE9C84DE9C84E7847BD68C7BD68C7BE7847BD68C73D67B6BD67B6BD67363\
D67363C66B52C66B52BD5A42AD5A429C39299452399C3929A55239B55239AD5A42
A54231CE8C6BD68C7BD6A584DEA58CE7B594EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5E7B594\
E7B594DEAD94DEAD94DEA58CD6A58CD6A584D69C73D69C84D69C84D69C84D6A58C
DEA58CDEAD94DEA58CDEAD94DEAD94DEB5A5BDA59C7B6352734A39947B73F7E7DEF7F7F7F7EFEF\
F7F7F7EFE7E7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E79C8C8C8C7B73312118422921\
633929634231633931422921422118634231EFBDADF7D6C6EFCEB5F7D6BDF7BDB5
F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5F7CEB5EFC6ADF7BDB5EFCEB5F7D6BDEFCEB5F7D6BDEFCEB5\
F7D6BDF7BDB5F7BDB5F7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7BDB5EFBDAD
E7AD94E7A58CE79484DE9473CE8463DE9C84E7B59CF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7C6ADEFC6ADF7C6ADEFBDA5\
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7AD94
E7AD9CE7AD94E7AD94E7A58CDE9C8CDE9C8CDE9C84DE9C84DE9C84DE9C84DE9C84D68C7BD68C7B\
D68C7BCE8C84D68C7BD68C7BE78473D68C73D67363CE8463D67363C66B52B5735A
C66B52C68C63CE947BD69C84DEA58CE7B594EFBDA5E7B594EFBDA5EFC6ADEFBDA5E7B59CEFBDA5\
E7B594DEA58CDEA58CD6A58CDE9C84D6A584D69C84D69C73D69C73D69C73DEA58C
DEA58CD6A58CDEAD94DEAD94DEAD94DEB5A5C6ADA573524A73524A734A429C8C8CF7E7DEFFFFFF\
EFE7E7F7F7F7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE77B635A5A42395A42399C6B52\
AD847BD69C8CC68C73B5735A7342318C5A4AEFCEB5F7D6C6F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7BDB5EFCEB5F7BDB5F7D6BDF7BDB5F7D6BDEFCEB5F7D6BD\
F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDEFCEB5F7C6ADEFCEB5EFBDA5
E7AD94E7A58CE7A58CDE9C84DE9473DE9473E7B59CEFC6ADEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6\
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7C6ADEFC6ADEFBDA5\
EFBDA5EFBDA5EFBDA5E7B59CEFBDA5EFBDA5E7B59CEFBDA5EFBDA5E7B59CE7B594
E7AD94DEAD94E7A58CDEAD94DEA58CDEA58CDE9C84DE9C84D69C84DE9C84DE9C84DE9C84DE9C84\
D69C84DE9C8CDE9C84D69C84CE8C84D68C7BD68C73D68C73D67B6BCE8C6BD67B6B
CE8463BD8463CE8C6BD69C73DE9C84E7B594E7BDA5E7B594EFBDA5EFC6ADEFBDA5E7B59CE7B59C\
E7B594DEA58CDEA58CD6A58CD6A58CDEA58CD6A584D6A584D69C84D69C73D6A584
DE9C84DEAD94DEAD94D6A58CDEAD94DEB5A5C6ADAD8C7B738C7B73A5847B846352B59C9CF7F7F7\
F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E77B635A523129DEB59CF7BDB5\
F7D6BDF7D6BDEFBDA5E7B59CDE9473B58C73F7D6C6F7D6C6D6C6C6F7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7CEB5EFCEB5F7CEB5F7D6BDEFCEB5F7BDB5F7D6BDF7D6BDF7CEB5F7CEB5\
F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7BDB5EFCEB5F7C6ADF7C6AD
E7B59CE7AD94E7A58CE7A58CDE9473CE8C6BDE9C84EFBDADEFC6ADF7D6BDF7D6C6F7D6BDF7D6C6\
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7C6ADEFBDA5EFBDA5\
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59C
E7AD94E7AD94DEA58CDEA58CD69C84D6A584DEA58CDE9C84DEA58CD69C84D69C84D69C84DE9C84\
D69C84D6A584D69C84D69C84D69C84DE9C84D69C84D69C84D68C7BCE947BCE9473
CE947BCE8C73CE9473D69C73D69C73E7B594EFBDA5E7B594EFBDA5EFBDA5EFBDA5EFBDA5E7B59C\
E7B594DEA58CDEA58CD6A584D6A584DE9C84D69C84D69C84D6A584D69C84DE9C84
DEA58CDEA58CDEA58CDEAD94D6A58CDEB59CCEB5AD948484948484AD9494B59C9CAD9494CEBDCE\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7735A52846352F7D6C6F7D6BD\
F7D6BDEFCEB5F7BDB5EFBDA5E7B59CEFBDA5F7D6C6EFCEB5EFCEB5EFCEB5F7D6C6
F7D6BDF7BDB5F7D6BDEFCEB5F7CEB5F7BDB5EFCEB5F7BDB5F7D6BDF7BDB5F7D6BDEFC6ADF7BDB5\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7BDB5F7D6BDF7D6BDEFCEB5EFC6AD
E7B59CE7AD94E7A58CE7A58CDE9C84DE9473DE9473E7BDA5EFC6ADF7BDB5EFCEB5F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7BDB5F7CEB5EFBDA5EFBDA5EFBDA5\
EFBDA5E7B594E7B59CEFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B59CE7AD94
E7AD94DEAD94DEA58CDE9C84D6A584DEA58CD6A58CDE9C84D69C84D69C73D6A584D69C8CD6A584\
D69C84D69C84D69C84D69C84D69C84D6A584D6A584D69C84D69C73D69C84D69C73
CE8C84D69C73D69C84D6A584D69C73E7A58CE7BDA5E7B594E7B59CEFC6ADEFBDA5EFBDA5E7B594\
DEA58CDEA58CDEA58CDEA58CD6A584D6A584D69C84D6A584D69C84D69C73D6A584
DEA58CDEA58CDEAD94D6A58CDEAD94DEAD94C6ADA5735A527B635AB5A5ADCEBDC6D6C6BDD6C6BD\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7C6ADBD846B5ADEB59CF7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7BDB5EFBDADD6C6B5F7D6C6F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDEFCEB5F7BDB5F7BDB5F7BDB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7BDB5F7D6BD\
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7BDB5EFCEB5
EFB5A5E7B594E7A58CE7A58CE79484DE9C84DE9473E7B594EFC6ADEFCEB5F7D6BDF7D6C6F7D6C6\
F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5F7C6ADEFBDA5E7B594\
EFBDA5E7B594EFB5A5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B594DEA58C
DEA58CDEA58CDEA58CD6A58CD6A584D69C84D69C73C69C84D69C84D69C73CE947BD69C73D69C73\
CE947BD6A584D6A584D69C73D69C73D69C84D69C84D69C84D69C84D6A584D69C84
D69C73D6A584D6A584D69C84D68C73E7B594E7B59CDE9C84EFBDA5EFBDA5EFBDA5E7B59CE7B594\
E7AD94DEA58CD6A584D6A584D6A584D69C8CD6A584D69C84D69C84D69C84DEA58C
DEA58CD6A58CDEA58CDE9C84DEAD94DEB59CC6ADA5735A52735A52AD9494D6C6BDD6C6D6DECED6\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7BDA59CF7BDB5EFCEB5F7D6BDF7D6C6\
F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5F7D6C6D6C6C6EFCEB5EFCEB5F7D6BD
EFCEB5F7D6BDF7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6BD\
F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7C6AD
EFBDA5E7B59CE7B59CE7AD94E7A58CE7A58CDE9C84DE9C84E7B594EFBDA5EFCEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6BDF7CEB5F7CEB5EFBDA5EFBDA5EFBDA5\
E7B594E7B594E7B594E7B59CEFBDA5EFBDA5E7B59CE7B594E7B594E7B594E7B594
E7AD94DEA58CDEA58CD69C84D6A584D69C73D69C84CE947BCE947BCE947BCE8C6BCE9473CE947B\
CE9473CE9473CE9473CE947BD69C73CE947BD69C73D68C7BD69C84D69C84D69C84
D69C73D69C73D6A584D69C73DE9C84E7B594E7B594DE9473EFBDA5EFBDA5E7B59CE7B59CDEAD94\
E7B594DE9C84DEA58CD69C84D69C84D69C84D69C84D69C73D69C84D6A584DEA58C
DEA58CDEA58CD6A58CD6A58CD6A58CD6A58CCEB5AD5239313121218C736BCEBDB5E7DEE7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFEFE7E7D6C6CEEFCEB5F7D6BDF7BDB5F7D6BDF7D6C6\
F7D6C6F7D6BDF7D6C6F7DECEF7D6BDEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7BDB5EFCEB5
F7C6ADEFBDA5EFB5A5E7AD94E7A58CE7A58CE7A58CDE9473E7A58CE7B59CEFBDA5EFCEB5F7D6BD\
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5F7C6ADEFC6ADE7B59C\
E7B59CE7B594E7A58CE7B594E7B59CE7B594E7B594E7B594E7A58CDEA58CDEA58C
DEA58CD6A584D69C84D69C84D69C84D69C84CE947BCE947BCE947BCE947BCE9473CE9473CE9473\
CE9473CE8C73CE9473CE9473CE9473D68C73CE9473D69C73D69C73D69C73D69C84
D68C7BD69C84CE947BD69C73E7B594E7B594DE9C84CE8C6BE7B594E7B59CE7B594E7B594E7B594\
DEAD94DEA58CDEA58CD6A584D69C73D69C84D69C73D69C84D69C84D6A584D6A58C
DEA58CDEA58CD6A58CDEA58CD6A58CDEB59CBDA59C5231295231297B635A9C8C8CD6C6CEF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7D6C6B5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6\
F7D6C6F7D6BDF7D6BDF7DECEEFCEB5EFCEB5F7D6C6EFCEB5D6C6C6F7D6BDF7BDB5
EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7BDB5F7CEB5
EFC6ADEFBDADEFBDA5E7B59CE7AD94E7A58CE7A58CE7A58CDE9C84E7A58CEFBDA5EFC6ADEFCEB5\
F7D6BDF7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BD
F7D6C6F7D6BDF7D6BDF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7BDB5EFCEB5EFCEB5EFBDA5\
E7AD94E7A58CDE9C84E7A58CDEA58CE7AD94DEAD94E7B594DEA58CDEA58CDEA58C
D6A584DE9C84D69C84D69C73C69C84D68C73CE947BCE9473CE9473CE8C73CE947BCE8C73CE8C73\
CE9473CE9473CE8C73CE9473CE8C73CE9473CE9473CE8C73CE9473CE9473D68C73
CE9473D69C73D68C7BDE9C84DEAD94DE9C84D69C73E7A58CE7B59CE7B59CE7B594E7AD94E7AD94\
DEA58CDE9C84D6A584D69C84D69C84D69C84D69C73D69C84D6A584D6A584DE9C84
D6A584D6A58CDEAD94DEA58CD6A58CD6A58CBDA59C5239315239317B635A948484D6C6BDE7DEEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7D6C6B5EFCEB5F7D6BDF7D6C6F7D6BDF7D6BD\
F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5F7D6C6F7BDB5F7D6BDF7D6C6F7D6BD
F7D6BDF7CEB5F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7BDB5
F7C6ADF7C6ADE7B59CE7B59CE7B59CE7B594E7A58CDE9C84DE9C84E7B594E7B59CEFBDA5EFC6AD\
EFCEB5F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFC6ADEFB5A5E7B59C\
E7AD9CDEAD94E7AD94DEAD94DEAD94DEA58CDEA58CDE9C84DE9C84D6A584DE9C84
D69C84D69C73D69C84CE947BD68C7BCE947BCE8C73CE9473CE8C73CE9473CE9473CE9473CE947B\
CE947BCE8C73CE9473CE9473CE9473CE947BCE8C73CE9473CE8C73CE9473CE8C6B
CE9473CE9473D69C73DE9C84DE9C84DE9C84DE9C84DEAD94E7AD94E7B594E7AD94E7B594DEA58C\
D6A584D6A584D6A58CD69C73D69C84D69C84D69C84D69C73D69C84D69C84D6A584
DEA58CDEA58CD6A58CDEAD94D69C8CDEB59CC6ADA54A31315231295A5252AD9494C6ADADE7DEE7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6F7BDB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6BD\
F7D6BDF7D6BDF7CEB5F7C6ADE7BDA5EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7BDB5F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7BDB5EFC6ADEFBDA5EFBDA5E7B59CE7A58CE7A58CE7A58CDE9473DE9C84E7B594EFBDA5EFBDA5\
F7BDB5F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6D6C6C6EFCEB5EFCEB5EFBDADE7B59CE7AD94\
DEAD94E7AD9CE7AD9CE7AD9CE7B59CDEAD94DE9C84DE9C84DE9C84DE9C84D69C84
D69C73D69C84D69C73D68C7BCE9473CE8C73CE947BCE8C73CE8C73CE947BCE9473CE8C73CE9473\
CE8C73CE947BCE947BCE947BD68C73CE9473CE9473CE9473CE9473CE8C6BC68C73
CE9473CE8C6BD6A584DE9C84DE9C84DE9C84E7AD94E7AD94DEAD94E7B594DEA58CE7AD94DEA58C\
DEA58CDE9C84D69C73D69C84D6A584D69C84D69C73D69C84D6A584D69C84D6A584
D6A58CD6A58CDEA58CD6A58CD6A58CD6A58CBDA59C422921312118392921634A425A5252948484\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7CEB5F7CEB5\
F7CEB5F7CEB5EFBDA5E7B59CE7B59CEFCEB5F7D6C6F7D6BDF7D6BDEFCEB5F7D6BD
EFCEB5F7D6BDF7BDB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7BDB5
F7CEB5EFC6ADF7C6ADEFBDA5EFBDA5E7B594E7A58CDE9473E7A58CDE9C84E7A58CE7B594EFBDA5\
EFCEB5F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6BDF7D6BDF7CEB5F7D6BDEFCEB5F7D6BDF7BDB5F7D6BDF7BDB5EFCEB5EFBDADEFBDA5E7AD9C\
E7AD94DEB59CDEAD94DEB59CE7AD9CE7AD9CD68C7BD69C73DE9C84DE9C84D69C73
D69C84D68C7BD69C73CE9473CE8C73CE8C73CE9473CE947BCE8C73CE9473CE9473CE9473CE9473\
CE8C73CE947BD69C73CE947BCE9473CE9473CE9473CE9473CE9473CE8C73CE8C6B
CE9473D69C73DE9C84DE9C84DEA58CE7A58CE7AD94E7B594E7AD94E7AD94DEA58CDEAD94DEA58C\
DEA58CDEA58CD69C84D69C84D69C84D6A584D69C84D69C84D69C84D6A584DE9C84
DE9C84DE9C84D6A58CD6A58CDEAD94DEB59CB59C9C422918312121392921523129634A42AD9494\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6C6C6F7CEB5F7CEB5F7D6BDF7D6C6F7D6C6F7BDB5EFC6AD\
F7C6ADF7C6ADE7B594E7B594E7B59CF7D6BDEFCEB5D6C6C6F7D6BDF7D6BDF7BDB5
F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECE\
F7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7D6BD
F7BDB5F7C6ADEFC6ADEFBDA5EFBDA5E7B59CE7AD94E7A58CE7A58CDE9C84E7A58CE7B594EFBDA5\
EFCEB5F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BD
F7BDB5EFC6ADF7C6ADF7BDB5EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7C6ADEFBDADE7B59C\
E7AD9CE7AD94DEB59CE7AD94DE9C8CDEAD94D69C84D68C73D68C7BD6A584D69C84
D6A58CD69C84D69C84CE9473CE8C73CE8C73CE8C73CE9473CE9473CE947BCE947BCE9473CE947B\
CE947BD69C73CE947BD69C73CE947BCE9473CE9473CE9473CE9473CE9473CE8C73
CE8C6BDE9C84DE9C84E7A58CE7AD94E7AD94E7B594E7B59CE7AD94DEA58CE7A58CDEA58CDEA58C\
DEA58CD6A58CD6A584D69C84D6A584D69C84D6A584D69C84DE9C8CD6A584DE9C84
D6A58CD6A58CD6A58CDEAD94DEAD94D6A58CBD9C8C4229213121213929214229315A4239CEBDB5\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7DECEF7D6BDF7D6BD\
EFBDA5E7AD94E7B59CDEAD94EFBDADEFCEB5F7D6BDD6C6C6F7BDB5F7D6BDEFCEB5
F7BDB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DE\
F7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6BDF7CEB5F7BDB5F7C6ADEFBDA5E7B59CE7B59CE7A58CE7A58CDE9473E7A58CDE9C84E7A58C\
EFB5A5F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7BDB5EFCEB5
F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7BDB5F7C6ADEFC6ADEFBDAD\
E7B59CEFBDA5E7AD9CDEB59CE7AD94DEB59CDEAD94D69C8CCE947BCE8C73CE8C73
D68C7BCE947BCE9473CE8C6BBD846BCE8C6BCE8C73CE9473D68C7BCE947BCE947BD68C7BCE9473\
CE947BD69C84D69C73D69C73D69C73CE947BD68C73CE9473CE9473D68C73D69C73
DE9C84E7AD94E7AD94E7B59CE7AD9CE7B594E7B59CE7AD94E7A58CDEAD94E7AD94DEA58CDEA58C\
DEA58CDEA58CDEA58CD69C84D69C73D6A584D69C84D69C84DEA58CD69C84D6A58C
D6A58CD69C84DEA58CD6A58CDEAD94DEB59CAD9C8C524239634A42634A425A52529C8CA5D6C6D6\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFE7E7F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7DECEF7D6C6EFCEB5\
EFBDA5E7A58CE7B594DEAD94E7BDA5F7D6BDF7BDB5EFCEB5F7D6BDF7D6BDF7BDB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BD
EFCEB5F7BDB5EFC6ADEFCEB5EFBDA5EFBDA5E7B594E7A58CE7A58CE7A58CDE9C84E7A58CE7A58C\
E7B594EFCEB5F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6EFCEB5F7D6BDEFBDADEFC6AD\
EFBDA5EFBDA5E7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94D69C84CE8C6B
BD846BCE8C73CE8C73CE8C6BCE8C6BCE8C6BCE8C73CE947BCE947BCE9473CE9473CE947BCE947B\
CE9473D69C73C69C84D68C7BCE9473D69C73CE947BCE9473D68C73D69C73DE9C84
DEA58CE7B59CE7B59CE7B59CE7B594E7AD9CE7B594E7AD94DEA58CE7AD94DEA58CDEA58CDEA58C\
DEA58CDEA58CD6A584D69C84D69C84D69C84D69C84D69C84D6A58CD69C73D6A584
DE9C84D6A584D6A58CD69C8CD6A58CC6ADA5A584845231294A3131634A427B737BF7E7DEF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFE7E7F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7D6BDEFBDA5\
E7AD94E7B59CE7AD94DEA58CE7BDA5EFCEB5F7D6BDF7D6BDF7D6BDF7BDB5EFCEB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7BDB5EFCEB5F7C6ADEFBDADEFBDA5EFBDA5E7AD9CE7A58CE7A58CE7A58CDE9C84E7A58C\
E7B594F7BDB5F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7BDB5F7D6BDEFC6AD\
EFBDADEFBDA5E7BDA5E7AD9CE7AD94DEAD94DE9C8CD6A58CDEA58CDEAD94D69C8C
CE947BC68C63C68C63CE8C6BBD846BC68C63CE8C6BCE8C73CE8C73CE8C73CE947BCE9473CE9473\
D68C7BCE947BCE947BD69C73D68C7BCE947BD69C73D69C84DE9C84DEA58CE7A58C
E7AD94E7B59CE7B59CE7B59CE7AD9CE7B59CE7B59CE7AD94E7AD94DEAD94DEAD94DEA58CDEA58C\
DEA58CDEA58CDE9C84D69C84D69C84D69C84D6A584D6A58CD69C84D69C84D6A58C
D6A58CD69C84D6A58CD6A58CD6A58CDEB59C947B73422921523129634A428C736BB59C9CB5A5AD\
DED6E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7DECEF7D6BDF7BDB5F7D6BDF7BDB5F7D6C6F7DECEF7DECEEFC6ADE7B59C\
E7B594E7B59CE7A58CDEAD94EFBDADF7BDB5D6C6C6EFCEB5EFCEB5F7D6BDF7D6BD
F7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BD
F7D6BDEFCEB5F7CEB5EFBDADF7C6ADEFC6ADEFBDA5E7B594E7B594E7A58CE7A58CE7A58CE7A58C\
E7A58CEFC6ADF7BDB5F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFBDAD\
EFC6ADEFBDADEFBDA5E7B59CE7AD9CDEB59CDEAD94DEA58CDEA58CDEA58CDEAD94
DEA58CD69C8CCE947BC68C63CE8C73CE8C73BD846BCE8C6BCE8C73CE947BCE9473CE9473CE947B\
CE947BD69C73CE947BD69C84CE947BD68C7BD69C73DE9C84DE9C84DEAD94E7AD94
E7AD94E7B59CE7BDA5E7B594E7B59CE7B59CE7B59CE7B59CDEA58CE7AD94E7AD94DEA58CDEA58C\
DEA58CDEA58CD69C84DEA58CD69C84D6A584DE9C84D69C84D6A58CD69C84DE9C8C
D6A584D6A58CD6A58CD69C8CD6A58CDEB59CAD846B523129422921523129523931523931634A42\
C6ADADE7DEEFE7DEEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7D6BDF7D6BDF7D6BDF7BDB5F7D6BDF7D6C6F7DECEF7D6C6EFBDA5E7B59C\
E7A58CE7B59CDEAD94E7B59CEFC6ADEFCEB5EFCEB5F7D6C6F7BDB5F7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6BDF7BDB5EFBDADEFCEB5F7C6ADEFBDADEFB5A5E7B59CE7AD94E7A58CE7A58CE7A58C\
E7A58CEFBDA5EFC6ADEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7BDB5\
EFBDADEFC6ADEFB5A5E7B59CE7B59CE7AD9CDEAD94DEAD94D6A58CDEAD94D6A58C
DEA58CDEA58CDEAD94D69C84D69C73D6A584CE947BC68C73CE8C6BCE9473CE8C73CE8C73CE947B\
CE9473D68C7BD69C73CE947BD69C73D69C73DE9C84DE9C84E7AD94E7AD94E7B59C
E7B59CE7B59CEFBDA5EFBDA5E7B59CE7B59CE7AD94E7B594E7AD94DEAD94DEA58CDEA58CDEA58C\
DEA58CDE9C84D6A584DEA58CDE9C84D69C84D6A584DEA58CD69C84D69C84D6A584
DE9C84D69C8CDEAD94D6A58CDEAD94C6ADA58C73635A31295A3129523129422921523129523129\
7B635AB59C9CD6C6CEE7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E7DEEFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7DECEEFCEB5E7B594DE9C84\
DE9C84E7B594DEA58CE7BDA5EFC6ADEFCEB5EFCEB5F7BDB5EFCEB5F7D6BDF7BDB5
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7BDB5EFCEB5F7D6BDF7BDB5EFC6ADF7C6ADEFBDA5EFBDA5EFB5A5E7AD94E7A58CE7A58C\
E7A58CE7B59CEFBDA5F7BDB5F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7E7DEF7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5\
EFBDADEFBDA5EFBDA5E7B59CE7AD9CE7AD9CE7AD94DEAD94DEAD94DEA58CD6A58C
DEA58CD6A58CDEA58CDEA58CD6A58CDEA58CDE9C84D69C73BD846BBD846BC68C73C68C73CE8C6B\
CE9473CE9473CE947BD68C7BD69C73DEA58CDEA58CDEA58CE7AD94E7B59CE7B59C
E7B59CEFBDA5E7B59CE7B594E7B59CE7B59CE7B59CE7B59CE7AD94DEA58CE7A58CDEA58CDEA58C\
DEA58CDE9C84DEA58CDEA58CD6A584D69C84DE9C84D69C84D6A584DE9C84D69C84
D6A584D69C84D6A58CDEAD94DEB59CDEB5A5B58C73845242734A39734A395A3129422921312118\
5A42398C736BAD9494DECED6F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7D6BDF7CEB5F7BDB5F7D6BDF7BDB5F7D6BDF7D6C6F7D6C6E7B59CE7A58CCE8C6B\
E7A58CDE9C84DEA58CE7BDA5D6C6B5EFCEB5F7BDB5EFCEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECE
F7D6BDF7D6BDF7BDB5EFCEB5EFBDADEFC6ADEFBDADEFBDADE7B59CE7B59CE7AD94E7AD94E7A58C\
E7AD94E7B59CEFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7D6C6F7D6BDF7D6BDEFC6AD\
EFBDA5EFBDA5EFBDA5E7AD9CE7B59CE7AD9CDEAD94DEAD94DEA58CDEAD94DEAD94
DEAD94D69C8CDEA58CDEA58CDEA58CDEA58CDE9C84D69C84C68C73CE8C6BCE8C6BCE8C6BC68C73\
CE9473CE9473CE9473D69C73DE9C84E7A58CE7A58CE7AD94E7AD9CE7B594E7B59C
EFB5A5E7B59CEFBDA5EFBDA5E7B59CE7B59CE7B59CE7AD94E7AD94DEAD94DEA58CDEA58CE7AD94\
DE9C8CDEA58CDE9C84DEA58CDE9C8CD6A584DE9C8CD6A584D69C84D6A58CD69C84
DE9C84DEA58CDEAD94D69C8CD6A58CDEB5A5C69C84CE8C6BB57B6394634A94634A734A39523129\
5239317B635A8C7B73B59C9CDECED6F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7DECEEFCEB5F7CEB5F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5E7B594EFC6ADDE9C84CE8C6B\
D68C73D69C8CE7B59CEFCEB5F7BDB5EFCEB5EFCEB5F7BDB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DE\
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7BDB5F7C6ADE7B59CE7B59CE7B59CEFBDA5E7B594\
E7B59CEFBDADF7BDB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7CEB5EFCEB5
F7D6BDF7D6BDF7D6C6F7D6BDF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFC6AD\
E7B59CE7AD94E7AD94DEA58CDEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58C
D6A58CDEA58CD69C84D6A58CD69C84DE9C84DE9C8CD6A584D69C73CE8C6BBD846BBD846BCE8C73\
CE9473D68C7BD69C73D69C84DE9C84DEAD94DEAD94E7AD9CE7B59CE7B59CE7B59C
EFBDA5E7B59CEFBDA5E7B59CE7B59CE7BDA5E7BDA5E7B59CDEB59CE7AD94DEAD94E7A58CDEAD94\
DEAD94DEA58CDE9C8CD6A58CDEA58CDEA58CD69C84D6A58CD6A58CDE9C84D6A58C
D6A58CDEA58CD6A58CD6A58CDEB59CE7BDA5D69C73CE8C6BC68C63AD6B52A5634A845239844A39\
5239315A42395A4239634A42735A52AD9494E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFEFCEB5F7BDB5EFCEB5F7D6BDF7D6BDF7D6BDF7BDB5EFBDA5E7B59CEFBDA5D69C84DE9473\
D68C7BDEA58CE7B59CEFBDADD6C6B5F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7BDB5F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5EFBDADE7B59CEFB5A5EFBDA5E7B59CEFBDA5\
EFBDA5EFBDA5F7D6BDF7BDB5F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7BDB5EFC6AD
F7BDB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFC6ADEFC6ADEFBDA5\
E7AD94E7AD94DEA58CDEA58CDEA58CDE9C8CD69C8CDEA58CDEA58CD69C8CD6A58C
D69C8CD6A584D69C8CD69C8CD6A584D6A584D69C73D69C84D68C7BBD846BBD8463BD8463CE8C6B\
CE947BD68C7BD6A584DE9C8CDEAD94E7AD94E7AD94E7B59CE7B59CE7B59CEFBDA5
E7B59CEFB5A5E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7AD9CE7AD94E7AD94DEAD94DE9C8C\
E7AD94DEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CDE9C84D6A58CDE9C84
D6A58CDEA58CD6A58CDEB59CD6A58CC6ADA5D69C84D68C73CE8C73CE8C6BB5735AB5735AA5634A\
633931634231634A42634A427B635AAD9CA5E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7E7EFCEB5F7C6ADF7BDB5F7D6BDF7CEB5F7C6ADE7B59CE7B594EFBDA5DEA58CDE9473DE9C84\
D69C73DEB59CE7BDA5EFCEB5F7BDB5F7BDB5D6C6C6F7D6BDF7D6C6F7D6BDF7D6C6
F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7BDB5EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5\
EFBDA5E7B59CF7D6BDF7D6C6F7DECEF7D6C6F7D6BDF7D6C6EFCEB5EFCEB5F7C6AD
EFC6ADF7BDB5F7D6BDF7D6BDF7D6C6EFCEB5F7D6C6F7D6BDEFCEB5F7D6BDF7BDB5EFBDADEFBDA5\
E7AD94DEAD94DE9C8CDEA58CDE9C84D69C8CD69C8CD69C8CD6A584D69C84D69C84
D6A58CD69C84D69C84D6A584D69C84D69C84D69C84D69C73CE9473BD846BBD8463D67363CE8C6B\
CE9473D69C73DE9C84DEA58CE7AD94E7AD9CE7B59CE7B59CE7B59CE7B59CE7B59C
EFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7B59CDEAD94E7AD9CDEAD94DEAD94E7AD94\
DE9C8CDEAD94DEA58CDEA58CDE9C84DEA58CDE9C84D6A584D6A58CD69C84D6A58C
DEA58CD6A584DEA58CD6A58CDEB59CDEB5A5D69C84D68C7BD69C73CE947BCE8C73CE8C6BBD846B\
9C6B52634A42735A528C7B73C6ADBDE7DEE7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7DEEFC6ADF7C6ADF7CEB5F7C6ADE7B594E7B594E7A58CE79484DE9473DE9473D68C73D69C73\
DEA58CDEB59CEFC6ADF7BDB5EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6C6F7D6BD
F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDEFCEB5F7BDB5F7BDB5EFCEB5EFCEB5F7C6ADEFBDA5EFBDA5EFBDADF7C6AD\
EFBDADEFBDA5EFC6ADF7D6BDF7DECEF7D6C6F7D6C6F7D6BDF7BDB5F7C6ADEFBDAD
EFBDADEFCEB5F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7BDB5EFC6ADEFCEB5EFBDA5E7BDA5\
E7AD9CDEAD94DEA58CD6A58CDEA58CD6A58CD69C73D69C84D69C84D69C84D6A58C
D69C84C69C84D69C84CE947BD69C84D69C84D69C73CE9473CE8C6BBD846BBD8463C68C63CE8C6B\
D68C7BD69C84DE9C8CDEAD94E7AD94E7B59CE7B59CE7B59CE7B594E7B59CEFBDA5
E7B59CE7B59CE7B59CE7B59CE7B59CEFB5A5E7B59CE7B59CE7AD94E7AD94E7AD94DEAD94DEAD94\
DEAD94DEAD94DE9C84DEA58CD6A58CD6A58CD6A58CDEA58CDEA58CD69C84DE9C84
D6A58CD6A58CD69C8CDEB59CDEB59CC6ADA5D69C73D69C84D69C84D69C73CE947BD69C73CE947B\
CE8C7394736B947B73D6C6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7D6C6EFBDA5F7CEB5F7C6ADE7A58CDE9473DE9473CE8463D67363D67B6BD67B6BD68C73D69C84\
DEAD94E7B59CEFBDA5D6C6B5F7BDB5F7D6BDF7BDB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7BDB5F7BDB5EFC6ADEFBDA5EFBDADF7C6ADEFCEB5\
EFBDADF7C6ADEFBDADF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFC6ADF7C6AD
EFBDADF7D6BDEFCEB5F7D6BDF7D6BDF7BDB5F7D6BDEFCEB5F7BDB5EFC6ADEFBDA5EFBDA5E7B594\
E7AD9CE7AD94DEA58CDE9C84D69C84D69C84D69C84D69C84C69C84CE947BCE947B
CE947BCE947BCE947BCE947BD69C73CE947BCE9473CE8C6BBD846BBD846BC68C63CE8C6BCE8C73\
D69C73DE9C8CDEA58CDEAD94E7B59CE7B59CE7B59CE7B59CEFBDA5E7B59CE7B59C
EFBDA5E7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CDEAD94DEAD94E7AD94E7AD94DEA58C\
E7AD94DEA58CD69C8CDEA58CDEA58CDE9C84D69C8CD6A584DE9C8CD6A58CD6A58C
DE9C84D69C84DEB59CD6A58CDEB59CDEB5A5D69C84D69C84D69C84D68C7BD69C84D68C7BD69C84\
CE947BBD9C8CCEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
EFCEB5F7C6ADF7BDB5F7C6ADE7A58CDE9473DE9473DE6B5ACE8C6BCE8C6BCE8C6BCE8C73D69C84\
DEAD94DEB59CEFBDADF7BDB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEDECED6\
F7DECEF7DECEDECED6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6C6
F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDEFCEB5EFC6ADF7C6ADEFBDADEFBDA5EFC6ADEFC6ADF7BDB5\
EFCEB5EFCEB5F7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7BDB5EFCEB5
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFC6ADEFBDADEFC6ADEFBDADE7B59CE7AD9C\
E7AD94DEAD94DEA58CD6A58CD69C84D69C84CE947BCE947BCE8C84CE947BC68C73
C68C73C68C73CE9473CE947BCE947BCE9473C68C73CE8C6BBD846BBD846BCE8C6BCE8C73D69C73\
D69C8CDEA58CDEA58CE7AD94E7AD9CE7B59CEFBDA5E7B59CE7B59CEFBDA5EFBDA5
E7B59CE7B59CE7BDA5E7B59CE7BDA5E7B59CE7AD9CE7B59CE7AD94E7AD94DEB59CDEAD94E7AD94\
DEAD94DEAD94DEA58CDEA58CDE9C84D69C84DEA58CDE9C84D6A58CDE9C8CD69C8C
D6A58CD6A58CD69C8CD6A58CDEB5A5DEB5A5D69C73D69C73D69C73CE947BD69C73D69C73CE8C84\
D69C84DEB59CE7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CE
F7BDB5F7CEB5F7CEB5EFBDA5E79484DE9473E77B6BD67B6BD67B6BD68C73CE8C6BCE947BDEA58C\
DEAD94E7AD9CEFBDADEFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7BDB5F7BDB5F7CEB5EFCEB5F7BDB5F7C6ADEFC6ADEFBDADF7C6ADEFC6ADF7BDB5EFCEB5\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5F7BDB5EFC6ADEFC6ADEFBDA5E7BDA5E7B59C\
DEAD94DEAD94DE9C8CD69C84D69C8CC69C84C6947BC68C73C69C84CE947BC68C73
CE9473C68C73C68C73CE947BCE9473CE9473CE8C6BBD846BCE8C6BBD846BCE8C6BCE947BD68C7B\
DE9C84DEA58CDEAD94DEAD94E7B59CE7B59CEFBDA5EFBDA5EFBDA5EFBDA5E7BDA5
E7B59CE7B59CEFB5A5EFB5A5E7B59CE7B59CE7B59CE7B594E7B594DEB59CE7AD94E7A58CDEA58C\
DEAD94DEA58CDEA58CDE9C84DEA58CD6A58CDE9C8CD6A58CD69C84D6A584DEA58C
D6A58CDEA58CDEAD94DEB59CDEB5A5C6ADA5CE9473D68C73CE9473D68C7BD69C73D68C7BD69C73\
D69C84C6ADA5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECE
EFCEB5F7CEB5F7BDB5EFBDA5E7A58CE79484D68C7BD68C73CE8C6BD68C73BD846BD68C73D6A58C\
DEA58CE7BDA5EFC6ADEFCEB5EFCEB5F7D6C6F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6
F7D6BDEFBDADEFCEB5F7BDB5F7C6ADEFCEB5EFCEB5F7C6ADEFBDADEFCEB5F7BDB5EFCEB5F7D6BD\
EFCEB5F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFC6ADEFBDADEFBDA5EFBDA5E7AD94\
E7AD94DEA58CDEA58CD69C84D69C84D69C84CE947BCE947BCE947BCE947BC68C73
BD846BCE8C6BC68C73CE9473C68C73BD846BCE8C6BC68C73CE8C6BCE8C6BD68C7BD69C73D69C84\
DEA58CDEAD94E7AD94E7AD94E7AD9CE7B59CE7B59CEFBDA5E7B59CE7B59CEFBDA5
E7BDA5E7BDA5E7BDA5E7B59CE7B59CE7B59CE7AD9CE7AD94E7AD9CE7AD94DEAD94DEAD94DEA58C\
DEAD94DEA58CDE9C84D69C8CDEA58CDE9C84D69C84DE9C8CD69C84D69C84D69C84
D6A58CD6A58CD6A58CD6A58CDEB59CDEB5A5D68C73CE8C6BCE9473D68C73D68C7BD69C84D69C84\
D69C84DEB59CF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5
F7BDB5F7CEB5F7C6ADE7B59CE79484E79484DE9473DE9473D67B6BBD846BCE8C73D68C7BD6A58C\
DEB59CEFBDA5EFC6ADEFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6
F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7BDB5F7BDB5
F7D6BDF7D6BDF7BDB5EFCEB5EFCEB5EFCEB5EFBDADEFBDADF7C6ADEFCEB5F7BDB5EFC6ADEFCEB5\
F7BDB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5F7C6ADEFBDA5EFBDA5E7B59CE7B59C\
E7A58CDEA58CD6A58CD69C84D69C84CE947BCE947BCE947BCE947BC68C73C68C73
C68C73CE8C6BC68C73C68C73C68C73CE9473CE947BCE9473CE947BD69C84D69C84DEAD94DEAD94\
E7AD94DEAD94E7AD94E7B59CE7B59CE7B59CE7B59CE7BDA5EFBDA5E7BDA5EFBDA5
EFBDA5EFBDA5E7BDA5E7BDA5E7B59CE7AD9CE7AD94E7B59CDEAD94E7AD94DEAD94DEA58CDEA58C\
DEA58CDEA58CD69C73DE9C8CD6A58CDE9C8CD69C84DE9C8CD69C84D69C84D69C8C
D69C84DEA58CD6A58CDEB59CDEB5A5DEB5A5CE8C6BCE8C6BCE8C6BD68C73D69C84D69C84D69C84\
D6A58CDEB59CEFD6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFC6ADF7BDB5
EFCEB5F7D6C6F7CEB5EFB5A5E7A58CE7A58CE79484DE9473BD846BC68C63CE8C73C69C84DEAD94\
E7B59CEFBDADEFC6ADF7BDB5EFCEB5EFCEB5F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7BDB5EFCEB5EFCEB5F7BDB5EFCEB5F7C6ADF7BDB5EFC6ADEFCEB5EFCEB5F7C6ADEFCEB5F7C6AD\
EFBDADF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5EFCEB5EFB5A5EFBDA5EFBDA5E7AD94\
DEA58CDEA58CDEA58CD69C84D69C84D69C84CE947BCE947BC68C73CE9473C68C73
CE9473C68C73CE9473CE9473CE947BCE947BD68C7BD69C73D69C84DE9C84DEAD94DEAD94DEAD94\
DEAD94DEB59CE7AD94E7AD9CE7BDA5E7BDA5EFB5A5EFBDA5EFBDA5EFB5A5E7BDA5
EFBDA5E7B59CEFBDA5EFBDA5E7B59CE7B59CE7AD94DEB59CDEAD94E7A58CDEAD94DEA58CDEAD94\
DE9C8CDEA58CD69C84D6A584DEA58CD69C84D69C84D69C84D69C84D69C84D69C84
D6A58CD6A584D6A58CDEB59CC6ADA5DEB59CCE9473D68C73CE9473D68C73D69C73D69C84D6A58C\
D6A58CD6A58CD6C6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7BDB5F7C6AD
F7CEB5F7D6C6F7BDB5EFB5A5E7A58CE7A58CE79484DE9473CE8C73BD846BCE8C73D69C84DEAD94\
E7B59CEFBDADEFCEB5EFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6BDEFCEB5
EFCEB5F7BDB5F7D6BDEFCEB5F7BDB5EFCEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFCEB5EFBDAD\
EFC6ADF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7C6ADE7B59CE7B59CE7AD94\
DEA58CDEA58CD69C84D69C84D69C84C69C84CE947BCE947BCE947BCE9473C6947B
CE947BCE947BCE947BD69C84CE947BD69C84D6A584D69C84D69C84D6A58CDEA58CDEAD94DEAD94\
E7AD9CE7AD9CDEB59CE7AD9CE7BDA5EFBDA5E7BDA5EFBDA5E7B59CE7B59CE7B59C
EFBDA5EFBDA5E7B59CE7BDA5E7B59CE7B594E7B59CE7B59CE7AD94DEAD94DEA58CDEAD94DEA58C\
DEA58CD6A58CDEA58CD69C8CDEA58CD69C84D69C84D6A58CD69C84D69C84D69C84
D69C84DEA58CD69C8CDEB59CDEB5A5DEB5A5D68C7BD69C73D68C7BD69C73D69C73DE9C8CD6A58C\
D6A58CD69C84DEB5A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7F7D6BDF7C6ADF7C6AD
F7BDB5F7D6C6F7D6BDF7C6ADE7AD9CE7A58CE79484DE9473CE8C6BBD846BCE8C73C69C84DEAD94\
E7BDA5EFBDADF7BDB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5F7BDB5
EFCEB5EFCEB5F7BDB5EFCEB5EFC6ADEFC6ADEFBDADEFBDADEFBDA5EFBDA5EFBDA5EFC6ADEFBDAD\
F7BDB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7CEB5EFBDADEFBDA5E7AD94DEAD94\
E7AD94DEA58CD6A584D68C7BD69C84D69C84CE947BCE947BCE947BCE947BCE947B
CE947BCE947BD68C7BD69C8CD69C84D69C84D69C84DEA58CD69C8CDEA58CDEAD94DEAD94E7AD9C\
DEB59CE7B59CE7B59CE7B59CE7B59CE7BDA5E7BDA5EFBDADEFBDA5EFBDA5E7B59C
EFBDA5E7BDA5E7B59CE7B59CE7B59CE7AD9CE7B594E7AD94DEAD94E7AD94DEAD94DEA58CDEAD94\
DEA58CDE9C8CDE9C84D6A58CDE9C84D69C84D69C84D69C8CD6A58CD69C84D69C84
D69C8CD6A58CD6A58CDEB59CC6ADA5C6ADA5D69C84D69C73D6A584D69C84D69C84D6A58CD6A58C\
D69C8CD69C84DEA58CF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7CEB5EFBDA5EFBDA5
F7CEB5F7D6C6F7D6C6F7C6ADE7A58CDE9473DE9C84DE9473CE8C6BC68C73C68C73D69C84DEAD94\
E7BDA5EFC6ADEFCEB5F7D6BDF7BDB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6BDEFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5
F7BDB5F7BDB5EFCEB5EFBDADEFC6ADEFBDADEFC6ADEFBDA5EFBDA5EFBDADEFBDADEFBDA5EFC6AD\
EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7BDB5EFBDA5EFBDA5E7AD94E7A58C\
DEAD94DEA58CDE9C8CD69C84D69C84C69C84D69C84CE947BCE947BCE947BCE947B
CE947BD69C73C69C84D69C73C69C84D69C8CD69C84D69C84D6A584DEA58CDEAD94DEAD94DEAD94\
E7AD94E7B59CE7BDA5E7B59CE7BDA5EFBDA5EFBDA5EFBDA5E7B59CE7BDA5EFBDA5
E7B59CEFBDA5E7B59CE7AD94E7AD94E7B594DEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDE9C84\
DEA58CDEA58CD6A58CDE9C84D69C8CD69C84D69C8CD69C84D69C84D69C84D69C8C
D6A584D69C8CD69C8CDEB59CDEB5A5DEB59CD6A58CD6A584DE9C84D6A58CD6A584DEA58CD6A58C\
D69C84D68C7BD69C8CD6C6C6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDF7BDB5E7B594E7B594
F7D6BDF7DECEF7D6C6EFB5A5E7A58CDE9C84E79484D68C7BC68C73BD846BC68C73C69C84DEAD94\
EFBDADEFC6ADEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5\
F7DECEF7D6BDF7D6BDF7D6BDEFBDADF7BDB5EFCEB5F7BDB5EFCEB5EFC6ADEFCEB5
EFCEB5EFCEB5EFBDADF7C6ADEFBDADEFBDA5EFBDADEFBDA5EFBDA5EFC6ADEFBDADEFBDADF7BDB5\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFBDADEFBDA5E7B59CE7AD94\
DEA58CDEA58CD6A584D69C84D69C84CE8C84C69C84CE947BCE947BCE9473CE947B
D69C73C69C84D69C84D69C84CE8C84D69C73D6A58CD6A584D69C8CDEA58CDEAD94DEA58CE7AD94\
DEB59CE7AD9CE7BDA5E7B59CEFB5A5E7BDA5EFB5A5E7B59CE7BDA5EFBDA5E7BDA5
EFBDA5E7B59CDEAD94E7AD94DEAD94E7B59CE7AD9CE7B594DEAD94DEA58CDEA58CD6A58CDEA58C\
DEAD94DEA58CD6A58CDE9C8CD6A58CDE9C84D6A584D69C84D69C84D69C84D69C84
D69C8CD69C84D6A58CDEB5A5DEB5A5DEB59CDE9C84DE9C84DEA58CD6A58CDE9C84D6A58CD6A58C\
CE9473D68C7BD69C73F7BDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDF7C6ADE7B594E7B594
F7D6BDF7D6BDE7BDA5E7AD94E7AD9CDE9C84DE9C84DE9473BD846BBD846BC68C73CE947BDEB59C\
EFBDADEFC6ADF7BDB5EFCEB5EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDF7D6BD\
EFCEB5F7D6BDEFCEB5EFCEB5EFC6ADEFCEB5EFCEB5EFCEB5EFBDADEFBDA5EFBDAD
EFCEB5EFBDADEFCEB5EFCEB5EFBDADEFBDA5EFBDA5EFBDADEFBDA5EFBDADEFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFBDADEFBDA5EFB5A5E7AD94\
DEA58CDEA58CDEA58CD69C84D69C84D69C84CE947BC6947BCE947BCE947BCE947B
C69C84D68C7BC69C84D69C73D69C84D69C84D6A58CDEA58CDE9C84DEA58CDEA58CDEAD94E7AD9C\
DEB59CE7B59CE7B59CE7BDA5E7BDA5E7B59CE7B59CE7BDA5EFBDA5E7B59CE7B59C
E7BDA5E7B59CE7B594E7B594E7AD94DEB59CE7AD9CDEAD94E7AD94DEAD94DEA58CDEA58CD6A58C\
D6A58CD69C84DEA58CD6A584D69C84D69C8CD69C8CD69C84D69C84D69C84D69C84
D69C84D69C8CDEB59CC6ADA5E7AD9CC6ADA5CE9473D6A584D6A584DEA58CD6A58CD6A584DEB59C\
D68C73D68C73D68C73DEAD94F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7C6ADE7A58CDE9473E7B59C
E7A58CD69C8CD69C8CD69C849C6B529C6B52B57B63CE8C73CE8C6BBD846BBD846BC69C84E7BDA5\
EFBDADEFCEB5F7BDB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6BDEFCEB5F7BDB5EFCEB5F7BDB5EFC6ADEFC6ADEFCEB5EFBDADEFBDA5EFC6AD
EFBDA5EFBDA5E7BDA5E7BDA5EFC6ADEFBDADEFBDADF7BDB5EFCEB5F7BDB5EFCEB5F7BDB5F7D6BD\
F7D6BDEFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7BDB5F7BDB5EFC6ADE7B59CE7AD9C\
E7AD94DEA58CD69C8CD69C84CE947BC69C84C69C84CE947BCE947BCE947BCE947B
CE947BCE947BC69C84CE947BD69C84D69C84D69C84D69C84DE9C8CD69C8CDE9C8CDEAD94E7B59C\
E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7BDA5E7B59CE7B59CE7BDA5EFBDA5
E7B59CDEAD94E7AD94DEB59CE7AD94DEB59CDEAD94DEAD94E7AD94DEAD94DEAD94DEAD94DE9C8C\
D6A58CDEA58CD6A58CDE9C84D6A58CD69C8CD69C84D69C84D69C84D69C84D69C84
D6A58CD6A58CD6A58CDEB5A5DEB5A5DEB59CC66B52C66B52CE8C6BDEA58CDEAD94DEAD94DEB59C\
D68C7BCE8C6BDE9473D68C7BEFC6ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6BDE7B594DE9473E7A58CE7A58C
CE8C73DEAD94DE9C8CAD735A9C6B52AD735A9C6B52AD735AB57B63B57B63BD846BD69C84E7BDA5\
EFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFCEB5F7CEB5\
EFCEB5F7D6BDEFCEB5EFCEB5EFCEB5EFC6ADEFCEB5EFBDADEFC6ADEFBDADEFBDAD
E7BDA5EFBDA5EFBDADEFBDADEFBDADEFC6ADEFC6ADEFC6ADEFCEB5EFCEB5EFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5F7D6C6F7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFCEB5EFBDADE7B59CE7AD94\
DEA58CDEA58CD69C84D69C84D69C73CE947BCE947BCE947BCE947BCE947BCE947B
CE947BCE947BC69C84D69C84D69C84D69C84D69C84D6A58CD6A58CDE9C8CDEAD94DEB59CE7AD9C\
DEAD94E7BDA5E7B59CE7B59CE7B59CE7AD94E7B59CE7B59CE7B59CE7BDA5E7B59C
E7BDA5E7B59CE7B59CE7AD94E7B59CDEB59CE7AD94DEA58CDEAD94DEAD94DEAD94DEA58CDEAD94\
D69C8CDEA58CD69C84D6A58CD69C84D69C8CD69C84D69C84D69C84D69C84D6A584
D69C8CD6A58CD6A58CDEB5A5DEB5A5C6ADA5AD6B52C66B52CE7352D69C73D6A584D6A58CDEB59C\
D69C84D68C73D68C73D68C73DEA58CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7CEB5E7A58CDE9473E79484CE8C6B
CE8C73E7A58CB5846B734231945A4AAD735AAD735A94634AA56B52A5735AAD7B6BD6A58CE7B59C\
EFC6ADEFCEB5EFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFC6ADEFCEB5\
EFC6ADEFC6ADEFBDADEFBDA5E7BDA5EFBDADEFBDADEFCEB5EFBDADE7BDA5EFCEB5
EFC6ADD6C6B5EFC6ADEFBDADEFC6ADEFBDADE7BDA5EFBDADEFCEB5EFC6ADEFCEB5EFBDADF7D6BD\
F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7CEB5EFC6ADEFBDA5E7B59CDEAD94\
DEA58CDE9C8CD69C84C69C84CE947BCE947BCE947BCE947BCE947BCE947BCE9473
CE947BCE8C84D69C73D69C84D69C8CC69C84D69C8CDEA58CDE9C8CDEAD94DEAD94E7AD94E7B594\
E7AD9CDEB59CE7B59CE7AD9CE7AD94DEAD94E7AD94E7AD9CDEAD94E7AD9CE7AD9C
DEB59CE7AD9CDEAD94E7AD9CDEAD94E7AD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEA58CD6A58CD6A58CD69C84D69C84D69C73D69C84D69C73D69C84D69C84D69C8C
D6A58CD69C8CDEAD94C6ADA5DEB59CDEB59CB5735AB5735AC66B52CE8463D69C73D6A58CD6A58C\
D6A584D68C7BD68C73DE9473D68C73EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6BDF7C6ADE7A58CE79484D68C7BBD846B
CE8C73AD735A8C5A42B5846BAD735A9C6B528C5A4A8C5A4A94634A9C6B529C7363C69C84E7BDA5\
F7BDB5F7D6BDEFCEB5F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5\
EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFCEB5D6C6B5EFC6ADEFBDADEFBDADE7BDA5
E7B59CE7B59CE7BDA5E7B59CE7BDA5EFBDADE7BDA5EFC6ADEFBDADEFCEB5EFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7CEB5F7BDB5EFCEB5EFC6ADEFBDA5E7AD9CE7AD94\
DEA58CD69C73D69C84D69C84D68C7BCE947BC6947BC68C73CE947BCE947BCE947B
CE9473C69C84CE8C84C69C84D69C8CD69C84D69C84DEA58CD6A58CDEAD94DEAD94DEAD94DEAD94\
E7B59CE7AD9CE7AD9CDEB59CE7B59CDEAD94E7AD94E7AD94DEAD94E7AD94DEB59C
E7AD9CDEAD94E7AD94DEAD94E7AD94DEA58CE7AD94DEAD94DEAD94DEA58CD69C8CDEA58CDEAD94\
DEAD94D6A58CDEA58CD69C8CD69C84D69C84D69C84D69C84D69C84D69C8CD69C8C
D6A58CD69C8CD6A58CE7AD9CC6ADA5D6A58CB5735AC66B52C66B52CE8C6BCE947BD6A58CD6A58C\
DEA58CD69C84D69C84D69C73D68C73F7BDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFEFE7E7F7C6ADEFBDA5DE9473E79484DE9C84AD6B52
8C5A429C5A42BD846BD69C84945A4A8452428C5A4A84524294634A94634AA5735AD69C84E7BDA5\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
EFD6CEF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5
E7BDA5E7BDA5E7B59CE7B59CE7B594E7AD94E7B59CE7AD9CE7BDA5EFBDADEFC6ADEFBDADEFC6AD\
F7BDB5F7D6BDEFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6
F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5EFBDADEFBDA5EFB5A5E7AD94DEA58C\
DE9C84D69C84D69C84D69C73C69C84CE947BCE947BCE947BC68C73CE9473C6947B
CE947BC69C84D69C84D69C84D69C84D69C84D69C8CD6A58CDEA58CDEA58CDEAD94DEAD94E7AD94\
E7AD94DEAD94E7AD94DEB59CDEB59CE7AD94DEB59CE7AD94DEAD94DEAD94E7AD94
E7AD94E7AD94DEB59CE7AD94DEAD94DEAD94DEA58CDEAD94DEA58CD6A58CDEA58CDEAD94DEAD94\
DEA58CDEA58CD69C84D6A58CD6A58CD69C8CD69C84D69C73D69C84D69C84D69C8C
D6A58CD69C8CDEAD94C6ADA5DEB5A5DEB59CB57B63B5735AC66B52C68C63CE9473D6A584D69C73\
D6A58CDEA58CDEA58CD68C7BD68C7BDEAD94F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7C6ADE7B594DE9473E7A58CCE947B945A4A
734229B5735AD69C84BD846B8C5A4A8C6352845242845242734A429C6B52A5735AC69C84E7BDA5\
EFC6ADF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5F7D6C6F7D6C6EFD6CEEFD6CEF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5F7BDB5
EFBDADEFBDADEFBDA5E7B59CE7AD9CE7B59CE7AD9CDEAD94DEAD94DEAD94E7AD9CEFBDADEFC6AD\
D6C6B5EFCEB5EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5EFBDADEFB5A5E7B59CE7AD94DEA58C\
D6A584D68C7BD69C73CE8C84CE947BCE9473CE947BCE9473C68C73CE947BC68C73
C68C73C69C84D69C73D69C84D69C84C69C84D6A58CDEA58CDEAD94D6A58CDEA58CDEAD94DEA58C\
DEAD94DEAD94E7AD94DEAD94E7AD9CE7B59CE7AD9CE7AD9CDEAD94E7AD94DEAD94
DEA58CE7AD94DEAD94E7AD94DEAD94DEAD94DEA58CDEA58CD6A58CDE9C8CDEAD94DEA58CD6A58C\
DEA58CD69C8CDEA58CD6A58CD69C84D6A584D69C84D69C84C69C84D69C84D69C84
D69C8CD6A58CC6ADA5DEB5A5D6A58CD6A58CB57B63B5735AC68C63CE8463CE8C6BCE9473CE9473\
DE9C84DEA58CD6A58CD68C7BDE9473DEA58CF7E7DEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFBDA5E7A58CDE9473EF948CBD846B734A39
734231CE947BBD846BB57B63AD735AC6947B8C73638C5A4A734A42846352A5735AD6A58CE7BDA5\
EFC6ADEFCEB5F7D6BDF7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5EFCEB5F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6D6C6C6
EFCEB5F7BDB5E7BDA5E7BDA5E7BDA5E7B59CE7AD9CE7AD94DEAD94DEAD94DEAD94DEA58CDEB59C\
F7BDB5F7C6ADF7D6BDF7D6C6EFCEB5EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6EFCEB5F7BDB5F7D6BDEFCEB5F7D6BDEFBDA5E7B59CE7AD9CE7AD94DEA58C\
DE9C84D69C84D69C84D69C73CE947BCE9473C68C73CE9473C68C73C6947BCE947B
C6947BCE947BCE947BC69C84D69C84D69C8CD6A58CD6A58CD6A58CDEAD94DEAD94DEAD94DEAD94\
E7AD9CDEAD94E7AD9CDEAD94DEB59CE7AD9CDEAD94DEAD94E7AD94DEAD94DEAD94
DEA58CDEAD94DEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDEA58CDEAD94DEAD94DEA58CDEA58C\
D6A58CDEA58CD6A58CD69C84D69C84D69C8CD69C8CD69C84D69C84CE947BD69C8C
D6A58CD6A58CD6A58CDEB59CDEB59CD6A58CB57B63AD6B52AD6B52B5735AC66B52C66B52C66B52\
CE8C6BDE9C84DEA58CD69C8CD68C73DE9C84EFD6CEFFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7D6C6E7B594DE9473E79484EFB5A5A5735A734229
B5735AAD735A6342315221188C5A42945A528C6352AD846B846352846352846B5AC69C84E7BDA5\
EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5F7D6C6F7D6C6F7D6BDF7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6C6EFCEB5EFCEB5D6C6B5EFC6ADEFCEB5F7D6BDF7D6C6EFD6CEF7D6C6\
EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFD6CED6C6BDF7D6C6F7D6C6EFCEB5
F7D6C6F7BDB5D6C6B5EFBDADE7BDA5E7BDA5E7BDA5E7A58CDEAD94DEA58CDEA58CDEA58CDEAD94\
DEA58CDEB59CEFBDADEFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFC6ADEFBDA5EFB5A5E7BDA5E7A58CDEA58C\
DE9C8CD69C84CE947BCE947BCE947BCE947BCE8C6BC68C73C68C73C68C73CE947B
CE947BC69C84C69C84C69C84D69C8CD69C84D6A584D6A58CDEA58CDEA58CD6A58CDEA58CDEA58C\
DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94
D69C8CDE9C8CD6A58CDEAD94DEA58CDEAD94DEA58CDEAD94DEAD94DEAD94DEA58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A584D69C84D69C84D69C84D6A584D69C84C69C84C69C84
D69C8CD6A58CC6ADA5DEB59CD6A58CD6A58CB57B63A56B52A5634AA55239A55239A55239A54231\
BD5A42CE7352D69C73D69C73D69C8CD68C73EFBDADF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7E7E7F7C6ADE7A58CDE9473E7A58CE7AD9C945A52734A39
B5735A945A4A4218105A3129A5735AAD847B8C5A4A5A4239846352845242A5735AC69C84E7BDA5\
EFCEB5EFCEB5F7D6BDF7D6C6EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDEFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5E7BDA5E7B59CF7D6BDF7D6C6F7D6BD\
F7D6BDD6C6B5EFC6ADEFCEB5F7BDB5DEB5A5DEB5A5DEB59CDEB5A5DEB59CD6A58C
DEB59CDEB59CD6A58CDEB59CE7BDA5E7BDA5E7AD94DEAD94DEAD94E7AD94DEA58CDEA58CDEA58C\
DEA58CDEA58CE7B59CEFC6ADEFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7BDB5EFC6ADEFBDA5EFBDA5E7B59CDEA58CDE9C84\
D6A584D69C73CE947BCE947BCE8C73C68C73BD846BB58C73C68C73CE947BC68C73
CE9473CE947BCE947BD6A584D6A584D6A58CD69C84D6A584D6A584D69C84D69C84D69C84D69C84\
D6A58CD6A58CDEAD94DEAD94DEAD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94
D6A58CD6A58CD6A58CDEAD94DEAD94DEA58CDEAD94DEAD94DEAD94D6A58CD6A58CD6A58CDEA58C\
D69C8CDEA58CD6A584D69C84D69C8CD69C84C69C84D69C84D69C84D69C8CD69C84
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CB5846BA5735AA5634AAD5A429C5A42A55239A55239\
B55239C66B52CE7352D69C73DE9C84D68C73E7BDA5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7E7DEEFBDA5DE9473E77B6BE7AD9CEFBDADAD735A8C5A42
B5735A634231421810845239734A39634231523129634231734A4273524A846352BD9C8CE7BDA5\
EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5EFCEB5EFC6ADDEB59CAD846BC69C84DEAD94DEB59C\
D6A58CD6A584C69C84C6947BCE947BCE8C84C6947BC6947BC69484C69484C69484
C69484C68C73D69C8CC68C73CE8C84DEAD94D69C8CDEAD94DEA58CD6A58CDE9C8CDE9C84DEA58C\
DEA58CDEAD94DEAD94E7BDA5D6C6B5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6EFCEB5F7D6BDEFC6ADEFBDADE7B594E7B59CE7AD94DEA58C\
D68C7BCE947BCE947BCE9473CE9473CE9473CE8C6BCE8C6BC69C73C68C73C6947B
C6947BCE947BCE947BCE947BCE947BD69C73CE947BCE8C84C69C84CE947BD69C8CD69C84C69C84\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94DEB59CD6A58CDEB59CDEAD94
D6A58CD69C8CDEAD94DEAD94DEAD94DEB59CDEAD94DEB59CDEAD94DEAD94DEAD94D6A58CD6A58C\
DEAD94D6A58CD69C8CD6A58CD69C84D6A584D69C8CD69C84C69C84D69C84D69C8C
D69C8CD6A58CDEB59CBDA59CD6A58CC69C84B5846BA5735AA5634A9C5A42AD5A42A55239A55239\
B55239BD5A42C66B52CE8463DE9C84D68C7BE7AD9CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7DECEE7B594DE9473DE9473E7AD94EFBDADB57B63734231
A5634A422921421810734231422921392921422921523931634231734A427B6352C69C84E7BDA5\
EFC6ADEFCEB5F7D6C6EFCEB5F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7D6C6
F7D6BDF7D6C6EFCEB5EFCEB5EFC6ADE7BDA5E7B594D6A58CC6947BAD846B8C5A4A846352846352\
8C5A4AA5735AA5735AA5735ABD846BAD847BBD846BB58C73C6947BC69484C69484
C69484C6947BD69C8CC6947BBD8463BD8463CE947BDE9C8CCE8C84D69C84D69C84D69C84D69C84\
D69C84E7BDA5EFBDADE7BDA5EFBDADEFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7DECE
F7DECEF7D6C6F7DECEF7D6C6F7D6BDF7D6BDF7D6BDF7CEB5EFBDA5EFBDA5E7B59CDEAD94DEA58C\
D69C84D69C84D69C73CE9473C68C73C68C73BD846BC68C73C6947BC68C73C68C73
C69C73C69C73CE947BCE9473CE947BC69C84C69C84D69C8CD69C8CD69C8CD6A58CD69C8CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94D6A58CDEAD94D6A58CDEAD94
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEB59CDEAD94DEA58CDEB59CDEAD94D6A58CDEAD94\
D6A58CD6A584D6A58CD6A584D69C84D69C84D69C73D69C84D69C84D69C8CBD9C8C
D6A58CBDA59CD6A58CDEB59CD6A58CD69C8CB58C73AD735AA56B52A5634AA55239A55239AD5A42\
AD5A42BD5A42C66B52CE8463D69C84DE9473DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7D6BDE7B594DE9473E77B6BE7AD9CEFB5A5BD846B844A39
7342314218103121185A3121312118392921422921523931634231634A42734A42C6ADA5EFC6AD\
EFCEB5F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDEFCEB5
F7D6C6EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADDEB59CD6A584C68C73DEB59CB5846B845242845239\
734A39734A4294634A9C6B52AD735ABD846BCE8C84BD846B9C7363A5735AA5735A
9C73639C6B52A56B52A5735AB5846BBD8463B5735ABD846BC6947BCE947BD68C7BCE947BCE8C73\
CE947BDEAD94E7B59CE7BDA5EFBDA5EFC6ADEFCEB5F7D6BDF7D6BDF7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFBDADEFBDADE7B59CE7A58CDE9C84\
D69C73D69C73C69C84CE947BCE9473CE8C6BC68C73C68C73BD846BC69C73C69C73
BD846BCE8C6BB58C73C69C84C69C84C69C84D69C8CC69C84D69C84C69C84CE947BD69C73C69C84\
D68C7BD69C84CE947BD69C84D69C84C69C84D69C8CD6A58CD6A58CDEAD94DEAD94
DEAD94DEB59CDEB59CDEAD94DEAD94DEB59CE7AD9CDEAD94DEAD94D6A58CD6A58CDEAD94D6A58C\
D69C84D69C8CD6A584D69C84D69C84D6A58CC69C84C69C84D69C84C69C84D69C8C
D6A58CD69C8CD6A58CD6A58CD6A58CC69C84AD846BA5735AA56B52AD5A42AD5A42A55239AD5A42\
B55239BD5A42BD5A42CE8463D68C73DE9C84DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFEFCEB5E7A58CE77B6BDE9473EFB5A5EFB5A5CE947B734A39
5A31212110104218102918183121185231295231294A3131523129734A39734A42D6A58CEFC6AD\
F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6EFCEB5F7D6BDEFCEB5EFCEB5EFCEB5F7D6BD
F7CEB5F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5EFC6ADEFC6ADDEB59CD6A58CDEB5A5C6947B845242\
845242734A39734A39947B73B59C9CCEB5ADCEBDB59484847342296342318C6352
5A31215A31215A31217342297342318C5A4294634AB5735AB5735AC66B52BD8463C68C63B5735A\
CE735ACE8463CE8C6BD69C73DEA58CE7BDA5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDEFCEB5EFBDA5E7B59CE7AD94DE9C84\
D6A584D69C84CE947BCE9473C68C73CE8C6BC68C73BD846BC69C73BD846BBD8463
BD8463C68C73C6947BC69C84C69C84D69C8CD69C84D69C84D69C84D69C84D69C84D69C84D69C84\
D69C73D69C84D69C84D69C84D69C73D69C84D69C73CE947BD69C73C69C84CE947B
D6A58CDEB59CDEB59CDEB59CDEAD94DEAD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94D6A58C\
D6A58CD6A584D69C84D69C84D6A58CC69C84D6A58CD69C84D6A58CC69C84D6A58C
D6A58CD6A58CD6A58CBDA59CD69C8CD69C8CB5846BA5735AAD6B529C5A42AD5A42AD5A42AD5A42\
B55239BD5A42C66B52C66B52D69C73DE9C84DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFEFC6ADDE9473E77B6BDE9473E7AD9CF7BDB5D69C8C633929
4218102110104210103121184229215231295231296342315239316342317B6352BD9C8CEFC6AD\
F7D6BDF7D6C6F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5F7CEB5F7CEB5F7CEB5EFCEB5
F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFC6ADC68C63DEB59CDEAD94C69C84\
9C6B52734A395A4239AD846BB5A5A5CEB5BDBDB5BD7B635A734229AD846BC6ADA5
634A422918182918185A31298452397B31217342299C6B52B57B63B5735AAD6B52A5634AAD5A42\
AD5A42A55239A55239AD5A42C68C63E7B594EFBDA5EFC6ADF7D6C6F7D6C6F7DECE
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFC6ADEFB5A5E7B59CE7B59CDEA58C\
D6A58CD69C73CE947BCE9473CE9473B58C73BD846BC69C73BD8463BD8463BD846B
BD846BB58C73C69C84D69C8CD6A58CD69C8CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEAD94DEAD94DEA58CDEA58CD6A58CD69C8CD6A58CD69C8CD6A584D69C84D69C84
C69C84CE947BD6A584D6A58CDEAD94DEB59CDEB59CDEB59CDEAD94DEAD94DEAD94D6A58CD6A58C\
D6A58CD6A58CD6A584C69C84D6A584D69C84C69C84C69C84D69C84C69C84BD9C8C
D6A58CD69C8CD6A58CD6A58CD6A58CC69C84B5846B9C7363AD6B52A5634AAD5A42AD5A42AD5A42\
BD5A42BD5A42C66B52CE735AD68C73D69C84DEA58CF7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7E7DEF7C6ADDE9473E77B6BDE7B6BEFB5A5F7BDB5E7AD9C633931
421810211010312118392921523129523129523129523931634231634231734A42D6A58CD6C6B5\
F7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFC6ADF7D6BD
EFCEB5F7D6C6F7D6BDEFCEB5F7D6C6EFCEB5F7D6C6EFCEB5EFCEB5CE947BCE947BDEB5A5DEB59C\
C6ADA5C69C84AD846B634A42846352A5847BAD94945A4239845239C6ADA5CEB5AD
7B737B2918182918185231298452399452399452398C7363BDA59CBD9C8CB58C73B57B639C6B52\
8C5A42A56B52A5735AB57B63C68C63DEA58CEFBDA5F7CEB5EFCEB5F7D6C6F7D6C6
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFC6ADEFBDA5E7BDA5E7AD94DEA58C\
DE9C84D6A584D68C7BC68C73CE8C6BCE8C6BC69C73BD8463B57B63B57B63BD846B
C6947BC6947BD6A58CD6A58CDEB59CDE9C8CDEAD94DEB59CDEB59CE7B59CE7BDA5DEB5A5EFBDAD\
DEB5A5DEB59CDEB59CDEB59CDEAD94DEAD94D6A58CDEAD94D6A58CDEA58CD6A58C
D69C84D6A58CD6A58CD6A58CD6A58CD6A58CDEAD94D6A58CDEAD94D6A58CD6A58CD6A58CD6A58C\
DEA58CD6A58CD6A58CD69C84D69C84D6A584D69C84D6A584D69C8CC69C84D69C8C
BD9C8CD6A58CD6A58CD6A58CD69C8CC6947BAD7B6BA5735AA5634AA5634AA5634AAD5A42AD5A42\
AD5A42AD6B52C66B52CE735AD68C73DE9C84DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFFFFFFFEFD6CEE7B59CDE9473CE7352CE8463E7AD94E7AD9CEFB5A5A5735A
5231294229213929213929214229314A31315231295231296342317B635273524ADEB59CEFCEB5\
EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5F7D6BDEFCEB5F7BDB5EFCEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6EFCEB5EFCEB5EFCEB5E7BDA5D6A58CCE8C6BDEAD94\
D6C6B5C6947BBD9C8CA5847BA5735A5A42396342315A3121735A529484849C8C8C
84739429181829181842313973524A8C5A42845239846B5ABDA59CC6ADA5B59C9C9C73638C5A42\
845239AD5A42CE8463D69C73E7B594EFBDA5EFC6ADEFCEB5F7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5EFBDA5EFBDA5E7B594DEA58C\
DE9C84D69C73CE947BCE8C6BCE8C6BBD846BBD8463B5735AB5735AB5735AB5735A
BD8463CE9473D6A584DEAD94DEB59CDEB59CDEB59CDEB59CDEB59CD69C8CDEB59CDEB5A5DEAD94\
D6A58CD6A58CDEB59CD6A58CDEAD94DEB59CDEB59CDEB59CDEAD94D6A58CDEAD94
D69C8CD6A58CD6A584C69C84D6A58CDEAD94DEAD94DEB59CDEB59CDEB59CDEAD94D6A58CD6A58C\
C69C84D6A584C69C84D6A584C69C84C69C84CE947BD6A584C69C84D6A584C69C84
C69C84D6A58CD6A58CD69C8CC69C84C6947B9C7363A56B5294634AA56B52A5634AAD5A42A5634A\
C66B52C66B52CE735ACE8C6BDE9C84DE9C84DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DECED6AD9C8CDEB59CF7C6ADE77B6BCE7352CE735ADE9C8CE7AD94E7AD9CB5846B
6339313929212918182918184229214A3131392921422921523931734A398C7363DEB59CEFC6AD\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7BDB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDEFCEB5E7BDA5DEAD94CE947B\
DEAD94F7D6BDEFCEB5DEAD94C69C84C6947B9C7363734A396339296339317B635A
524A5A1810102918184229315A42397342317342318C7363B59C9CA58484B58C739C6B52A5634A\
AD5A42BD8463CE8C6BD6A584E7B594EFC6ADEFC6ADEFCEB5F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFCEB5F7D6BDEFC6ADEFBDA5E7B59CE7B594DEA58C\
D69C84D69C73CE9473CE8C6BBD846BBD8463B5735AB5735AB5735AA573528C3129
845239A5634AB5735AD69C84D6A58CDEB59CDEB59CD69C8CD69C8CCE947BCE8C84C6947BCE947B\
B58C73BD846BBD846BC68C73B58C73C69C84D6A58CD6A58CD6A58CD6A58CD6A58C
D6A584D6A58CD6A58CC69C84C6947BD6A584D6A58CD6A58CD6A58CD6A58CD6A58CD6A584D6A584\
D6A58CD6A58CD6A584CE947BC69C84D6A584C69C84CE947BD69C84C69C84D6A584
D69C8CD6A58CD6A58CC69C84CE947BB58C739C6B529C6B529C6B52A56B52A56B52A5634AAD6B52\
B5735ACE735ACE8463CE8C6BD69C84D69C8CDEA58CF7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
6B524A734229E7B594F7C6ADCE8463CE7352CE735ADE9C84E7AD9CE7AD94D69C84
734A423121183121214229214229215231295231294229215A3129634231846352DEAD94EFCEB5\
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BD
F7D6BDF7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6EFCEB5EFC6ADE7BDA5DEAD94\
D6A584DEAD94EFCEB5EFBDADDEB59CDEB59CB58C738463528C5A4A634231634231
5231292918183121184221186339297342296339298463527B635A9C6B52AD6B52AD6B52B5735A\
B5735AC66B52CE8C6BDEA58CE7B594E7B59CEFBDADEFCEB5F7D6C6F7D6BDF7D6C6
F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFBDA5E7B594DEA58C\
D6A584D68C7BCE9473BD846BC68C63BD8463B57B63BD8463B5735AAD6B52734229
7B29187B3121844A39B57B63C68C73C6947BCE947BC68C73C68C63BD846BB57B63B5846BB5846B\
A56B52A56B52AD735A9C6B52A5735AB57B63BD846BC6947BC6947BC69484C69C84
C69C84C69C84D6A584D6A584D6A584CE947BC69C84D6A584D6A58CD6A584D6A58CD6A58CD6A58C\
D6A584C69C84C6947BC6947BCE947BC69C84C69C84C69C84C69C84D69C84C69C84
D69C8CC69C84D69C8CC69C84C6947BB58C739C6B5294634A945A4AA5634AA56B52945A4AAD6B52\
D67363CE8463CE8C6BD68C7BD69C73D68C7BD69C84F7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFB59C9C\
421810734229E7B594EFBDA5E79484CE7352D67363E7B594EFBDA5E7B59CE7B59C
8463522110103121184A3131523129422921422931392921523129634A42846352DEB59CEFCEB5\
EFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFC6ADE7BDA5\
E7B59CD6A584DEAD94F7D6BDEFCEB5C6ADA5B58C73DEAD9494736B84524273524A
845239734A3963423163392973423173422963423194634A8C5A4294634AB5735AB5735AC66B52\
B5735AC68C63DE9C84E7B594DEAD94E7B59CE7BDA5EFCEB5F7D6BDF7D6C6F7D6C6
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6EFCEB5EFCEB5EFBDA5E7BDA5E7B594DEA58C\
D6A584D69C73CE9473CE8C6BBD8463BD8463C69C73BD8463B5735AB5735A9C5A42
7342297B3121845242AD847BB58C73C6947BC69484BD846BAD847BAD735AA5735A9C6B5294634A\
94634A9C6B529C73639C73639C7363A5735A9C6B529C6B52AD735AB57B63B58C73
C69484C6947BC6947BC6947BC69C84CE947BC6947BC69C84C69C84D6A584D6A584CE947BD6A584\
CE947BD6A584C69C84CE947BC6947BC6947BC69C84D6A584C69C84C69C84C69C84
D6A584D69C8CD69C84C6947BC6947BAD846B8C5A4A94634A94634A9C6B5294634A94634A94634A\
C68C63CE8C6BCE8C6BDE9473DE9C84D68C73DE9C84F7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7DEE7947B735A3129\
4218105A3121DE9473F7C6ADEFBDA5E7B59CE7B59CF7C6ADE7B59CE7B59CE7A58C
8452422110103929214A3131523129392921422921523129523129634231846352DEB5A5EFC6AD\
EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5EFCEB5F7CEB5EFCEB5
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5EFCEB5\
E7BDA5E7B59CDEAD94DEAD94EFCEB5DEAD94DEB5A5DEB5A59C7363AD846BB5846B
9C6B529C6B5273524A8C5A4A9C6B52845242845242A57352AD6B52AD846BBD8463B5735AB5735A\
B5735AE7B594E7B594E7B594DEA58CE7B594EFBDA5EFCEB5EFCEB5F7D6BDF7D6C6
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7D6C6F7D6BDEFC6ADEFBDA5EFBDA5E7B59CDEA58C\
D69C84D68C7BCE8C6BCE8C6BBD846BBD8463BD846BBD846BBD8463B5735AAD6B52
A573529452398C5A42AD8C84C6ADADCEBDB5D6C6BDD6C6C6BDB5BD846B5A8452396339297B2918\
633929734229634231845242A5735A9C73639C6B52945A528452398C5A4294634A
B57B63B58C73B5846BB58C73B58C73C69C73B58C73CE8C6BC69C73C68C73C6947BC6947BC6947B\
C69C73C6947BCE947BCE947BCE947BCE947BD6A584C69C84C69C84D69C84D69C8C
D69C8CC69C84C69C84C68C73B58C73B57B638452428C5A428C5A4A8C63528C5A4A8C5A4A9C6B52\
C68C63D68C73D68C7BD69C73D69C84CE8463DE9473EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFEFE7E79C8C8C633929422921\
421810522118D69C73E7B594F7C6ADF7C6ADF7C6ADEFBDA5E7AD94E7B594DE9C8C
8452423121185231294A31315239313929214229214229215A3121634A42846352DEB59CEFCEB5\
F7CEB5F7D6C6EFCEB5F7CEB5EFCEB5EFCEB5EFCEB5EFCEB5E7BDA5EFC6ADEFCEB5
F7D6BDF7D6BDEFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5\
EFCEB5EFC6ADE7B59CDEA58CCE947BD6A584E7BDA5DEB5A5C69C84DEB59CD6A584
B58C73A5735A9C6B52AD735A9C6B5294634A94634AB5735AB5735ABD8463BD8463B5735AB5735A\
D69C73DEA58CE7B594DEA58CE7A58CE7B59CEFC6ADEFCEB5EFCEB5F7D6C6F7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6EFCEB5EFBDA5EFBDA5EFBDA5E7B59CDEA58C\
D69C73CE947BCE9473CE8C6BBD8463BD8463B57B63C69C73BD846BB57B63B5735A
B5735AA5634A844A399C7363C6ADA5D6C6BDD6C6C6CEBDC6AD94946339297B3121633929522118\
5A31217342297342297342296342318452399C6B52A56B52945A4A8C5A4A845242
8C5A429C7363AD846BAD846BAD846BB5846BAD846BAD846BAD846BB5846BBD846BBD846BB58C73\
C68C73C6947BCE947BC69C84D69C84D69C84C69C84D69C84C69C84C69C84D6A58C
D69C8CD6A58CC6947BC68C73B58C739C73638452428463527B63528C5A4A846352845242845242\
BD846BD68C73D69C73DE9C84DE9C84CE8463D68C73F7D6C6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADAD634231422921522118\
4218104A2118C68C63E7A58CE7B594F7C6ADF7C6ADE7B59CE7A58CE7A58CD69C84
8C5A4A5A3129524239634A42423139422921312118422921422921634A428C6352DEB5A5EFCEB5\
EFCEB5EFCEB5F7BDB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDE7BDA5E7B59CEFC6AD
EFCEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6EFD6CEF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5\
EFCEB5EFCEB5EFC6ADE7B59CDEB59CD6A58CDEA58CD6A58CD6A58CDEB59CDEAD94
D6A58CB58C73B58C73C68C73BD8463B57B63B5735ABD8463BD8463B5735AB5735AC68C63D6A584\
DE9C84DE9C84E7AD94E7AD94E7AD94E7BDA5EFBDADEFC6ADEFCEB5F7D6BDF7D6C6
F7DECEF7DECEF7E7DEF7E7DEF7DECEF7D6C6EFCEB5F7CEB5EFC6ADEFC6ADE7BDA5E7B59CDEA58C\
D69C84D69C73CE9473CE8C6BBD8463BD8463B57B63BD846BBD846BBD8463B5735A
AD6B52B5735AA56B528C5A42A5847BC6ADADDECED6BDB5BD7B635A845239A5847B523129211010\
312121423139734A398452427B63526342317B6352846B5A9C6B52945A4A8C5A42
6342318463529C6B52A5735A9C73639C73639C6B5294634AA57352AD735AB57B63BD846BCE8C6B\
C68C73CE947BD6A584C69C84C69C84D6A584C69C84C69C84D6A584C69C84D6A58C
D69C84D6A584C6947BB58C73AD846B9C6B52845242845242734A39846B5A8463528C5A4A845242\
CE8C6BD69C84DE9C84DEA58CCE8C6BCE7352DE7B6BD6C6BDF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C6342314229214A2118422921\
4218104218105A3121C66B52E7A58CE7B594E7B594CE8C6BCE8C6BC68C63A5634A
633931634231524239524239523129392921422921422921523129634A42846352D6C6B5EFCEB5\
EFCEB5EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDE7BDA5D69C84CE947B
DEAD94E7BDA5EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6BDEFD6CEEFD6CEF7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6EFCEB5EFBDADEFC6ADE7BDA5E7BDA5E7B59CE7B594DEB59CDEAD94
D6A584D6A584CE9473CE9473CE8C6BBD8463CE8C6BD6A584D6A584DE9C84DE9C84DEA58CDEA58C\
DEA58CDEAD94E7B594E7B59CEFBDA5EFC6ADEFCEB5EFCEB5F7D6BDF7D6C6F7D6C6
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEEFCEB5F7BDB5EFC6ADEFC6ADEFBDA5E7BDA5DEAD94\
D6A58CD69C84CE9473CE8C6BBD8463BD8463BD8463BD846BBD846BC69C73BD8463
B5735AAD6B52BD8463B5846BB5735AA5735A94736B8C736B7B6352C6ADA5BDA59C4A394A181010\
3121215242395242396B524A734A42734A39735A529484849C8C8CA5847B7B635A
6B524A634A42524239634A426B524A6B524A7B63528452429C6B52B57B63C6947BD6A584D6A58C\
D6A584D6A584D6A584C69C84D6A584C69C84D6A584C69C84D69C8CC69C84C69C84
D69C84CE947BC6947BAD846BA5735A7B6352734A396B524A73524A8452396339296342318C5A42\
BD846BD6A58CDEA58CD68C73CE634ACE7352CE8463EFCEB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7846B5A5239315A31294A2118422921\
211010421810421810734229C66B52DE9473DE9473B5735AAD6B52A55239734A39
5A42395A42394A3131422931422921392921392921422921523129734A398C7363EFC6ADF7CEB5\
EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDE7BDA5C6947B
C68C73DEAD94EFBDA5EFC6ADEFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
EFD6CEF7D6C6F7D6C6EFCEB5EFC6ADEFC6ADEFBDADE7B59CE7B59CE7B59CE7B594
DEAD94DEA58CDEA58CDE9C84D6A584D6A584D6A584DE9C84DE9C84DE9C84DE9C84DE9C84DEA58C\
E7A58CE7B594E7B59CE7BDA5EFC6ADEFC6ADF7BDB5F7D6BDEFCEB5F7D6C6F7DECE
F7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFC6ADEFBDA5E7B59CDEAD94\
DEA58CD69C84D69C73C68C73C68C63BD8463BD846BCE8C6BC69C73BD846BC68C63
BD8463AD6B52B5735AB58C73C68C73BD846BB57B63846352734A42A58484ADA5AD423139181010\
3121215A525263524A734A427342316342317B635AA5847B9484848C7B73735A52
524239634231634231634231734A427342317B63529C6B52B57B63B5846BBD8463BD846BCE9473\
CE947BD6A584D6A58CD6A58CD6A58CD6A58CD6A584D6A58CC69C84D6A584D6A58C
C69C84D6A584C6947BAD846B8C6352734A426B524A734A42734A396B524A523931633929845239\
CE8C6BD6A58CDEA58CCE8C6BBD5A42CE7352DE6B5AD6C6B5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5B5734A396342316339315A3129422921\
4218102110104218102110105A3121945239AD5A428C5A4A734231734229634A42
523931523931523931422931422921312118392921312118523129734A39846B5ADEB5A5EFCEB5\
EFCEB5EFCEB5F7BDB5EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5E7AD9C
C6947BCE8C73DEAD94DEB59CEFC6ADEFCEB5F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECE\
F7DECEF7DECEF7D6C6EFCEB5EFCEB5EFCEB5EFCEB5E7BDA5E7B59CDEAD94E7B594
E7B594DEAD94DEAD94DE9C84DE9C84DEA58CDE9C84DE9C84DE9C84DEA58CDEA58CDEA58CDEA58C\
DEAD94E7B59CE7BDA5EFC6ADEFBDA5EFCEB5EFCEB5F7D6BDF7BDB5F7D6C6F7DECE
F7E7DEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDEFCEB5EFC6ADEFBDA5E7BDA5E7B59CDEA58C\
DEA58CD6A584CE947BCE8C6BC68C63BD8463BD846BBD8463C69C73CE8C6BC69C73
C68C63C68C63B5735ACE947BCE947BC68C73B58C73B57B63A5735A8452397B635A423139181010\
2918183929395239316342317342295A3121735A52947B738C7363634A424A3131
634231734A397B635284635284523994634AAD735AB5846BBD846BC6947BC6947BCE947BB58C73\
CE8C6BCE9473D6A584D6A58CD6A584C69C84D6A584D69C84C69C84D69C8CD69C84
C69C84C69C84C6947BAD846B8463526B524A6B524A734A398452426B524A523931634231634231\
CE8C73D6A58CDEA58CCE8463CE634ACE634ACE8463F7BDB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFAD94945A3129523129633929523931523129\
2110104218104218104A10082110104A10084218108452425A4239523129634231
422931392921523931523129392921392921392921392921523129634A42A5735ADEB5A5EFCEB5\
EFCEB5F7BDB5EFCEB5EFCEB5F7BDB5EFCEB5F7D6BDF7D6C6EFCEB5EFCEB5EFBDAD
DE9C8CC6947BD6A58CD6A58CDEAD94EFBDADEFCEB5F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7DECEF7D6C6EFCEB5EFCEB5EFCEB5EFBDADEFC6ADE7B59CE7B59C
DEA58CDEA58CDEA58CDEA58CDEAD94DEA58CDEA58CDE9C84DEA58CDEA58CDE9C84DEA58CE7B594\
DEA58CE7B594E7B59CEFBDA5EFC6ADEFC6ADEFCEB5EFC6ADEFCEB5F7D6C6F7DECE
F7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6EFCEB5F7D6BDEFBDADEFC6ADE7B59CE7B59CDEB59C\
DEA58CD6A58CCE9473CE9473CE8C6BCE8C6BBD846BC69C73C68C63C69C73C69C73
CE8C6BC69C73C69C73CE9473D6A58CD6A584B58C73C6947BC68C739C73636B524A5A3129312121\
2918183121185221186339295A312952312973524A73524A5A42395A4239634A42
5A42398463528463528463529C6B52B57B63C69C73BD846BBD846BBD846BC69C73CE947BD6A584\
C6947BCE9473C69C84CE947BD6A584D6A58CD69C8CC69C84D6A58CC69C84D69C84
D6A584C69C84C6947BA5735A734A42634231734A39734A39634231523129523129634231734231\
CE947BDE9C8CD69C8CCE735ABD5A42CE634ACE8463EFCEB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79484845231295231295231296339295A3129\
4218104221184221184221184210104A1008211010634A425A4239523129392931
422931392921392921523129392921392921392921422118523129734A398C7363EFC6ADEFCEB5\
EFC6ADEFCEB5F7D6BDF7D6BDEFCEB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5
E7AD9CDEA58CC68C73DEAD94DEB59CD6A58CE7B59CEFCEB5F7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7E7DEF7DECEF7DECEF7DECEF7D6C6EFCEB5EFCEB5EFCEB5EFBDADDEB5A5E7B59C
E7B594DEAD94DEA58CDEAD94DEA58CDEA58CDEA58CDEA58CD6A584DEA58CD6A584DE9C84DEA58C\
DEA58CE7B594E7B59CE7B59CEFBDA5EFCEB5EFC6ADEFBDADF7D6BDF7D6C6F7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6EFCEB5F7BDB5EFCEB5EFC6ADEFBDA5E7B59CE7B59CE7B59C\
DEB59CDEA58CD69C84CE947BCE8C6BBD846BC69C73C68C73BD846BC69C73CE8C6B
CE9473CE9473CE947BBD8463CE947BD6A58CD6A58CD6A58CCE947BB58C73A5735A8463528C5A4A\
845242734A39634A426342315A3129523931634231422921634231734A39734A42
7B63529C6B528C5A4A9C6B52AD846BB57B63B5846BBD846BB58C73CE8C6BCE8C6BC68C73CE947B\
D6A584CE947BD69C73D69C84CE947BCE947BD6A584D6A58CC69C84D69C84D6A58C
C69C84C6947BB58C738C7363734A39634A426342315A4239634A42634A42523129734229634231\
C69C84DEAD94D69C84C66B52CE634ACE7352CE8463F7D6C6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7846B5A5A31214229215A3129523931633929\
4218104229214A21185221184218104218104218105A42395239314A3131422921
392921392921312121422921312121392921422921422921422921734A398C7363E7BDA5EFC6AD\
EFC6ADF7CEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6C6EFCEB5
EFCEB5E7AD9CCE947BCE8C84DEAD94DEAD94D69C8CD6A58CEFC6ADEFD6CEEFD6CEF7E7DEF7DECE\
F7E7DEF7DECEF7DECEEFD6CEEFD6CEF7D6C6EFCEB5EFCEB5EFC6ADEFC6ADE7B59C
DEAD94DEAD94DEAD94DEAD94DEB59CDEA58CDEA58CD6A584D69C73D68C7BD68C73CE8C6BD68C73\
DE9C84DEAD94E7B59CE7BDA5EFBDADE7BDA5EFBDADEFCEB5EFCEB5F7D6C6F7DECE
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFBDA5E7B59CE7B59CE7BDA5DEAD94\
DEAD94D6A58CDEA58CC69C84C68C73CE8C6BB58C73CE8C6BC69C73CE9473CE8C6B
CE947BCE947BCE9473D6A584BD8463CE9473D6A58CDEB59CD6A58CC6947BA5735A9C73639C7363\
A5735A845242846352634A42634A428452397B6352523931634A428C6352A5735A
AD846B94634AAD735AB5846BAD846BBD846BB58C73C69C73C68C73C69C73CE9473C69C73C6947B\
D6A584D6A58CC69C84C69C84D69C84C69C84C69C84C69C84D6A584D69C8CD69C84
C69C84C6947BAD846B846352734A39634231523931634A42634A425239315A3129633929633929\
D69C84D6A58CCE8C6BCE634ABD5A42CE7352D68C73EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6735A525231295A3129523931634231633931\
4229214229215A31294229213121184A21185A31215A42394A31314A3131392921
312121392921312121392921422921392921312118422921523129734A39A5735ADEB5A5EFC6AD\
F7CEB5F7BDB5EFCEB5F7D6BDF7CEB5EFCEB5F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6
F7D6BDEFBDADDE9C84D69C8CD6A58CD69C8CC69484C6947BD6A58CF7BDB5EFCEB5F7D6C6F7DECE\
F7DECEF7DECEF7DECEF7D6C6F7D6BDD6C6B5EFC6ADDEB5A5EFC6ADDEB5A5DEAD94
D6A58CD6A584D6A58CD6A584CE947BCE947BCE947BBD846BC68C63B5735AB5735AB5735AC68C63\
D68C7BD6A58CDEAD94E7B59CE7BDA5EFBDADEFBDADEFCEB5F7D6C6F7D6C6EFD6CE
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5EFC6ADEFBDA5EFBDA5EFBDADE7B59CDEA58C\
DEAD94D6A58CD6A58CD6A58CCE947BCE8C6BBD846BC69C73BD846BC69C73CE9473
CE9473CE947BCE9473CE9473D6A584CE9473C69C73D6A584DEAD94DEAD94C6947BC69C84B58C73\
AD846BA5735AA5735A84635273524A8C63529C6B52A5735A735A52A5735AAD846B
A5735AAD846BB57B63B5735ABD846BC68C73C69C73C69C73C69C73CE947BCE947BCE947BCE947B\
CE947BCE947BD69C84D6A584D69C84D6A584D69C84C69C84C69C84D6A584C69C84
C69C84C6947BA5735A845242634A425239315231294231395231294221184229215A31215A3129\
D6A584D69C84CE8463BD5A42BD5A42CE7352D69C73F7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD94A55239315A31295A31295239315A3129634231\
4229215A31296342315A3129523129523129523129523931422921523931392921
2918183121183121183121215231293929213121184229215A3129734A42846352DEB59CEFC6AD\
EFCEB5F7CEB5EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDEFBDADE7AD9CDEB59CD69C8CAD847BAD847BBD846BAD847BC6947BAD847BC6947B\
AD8C84B58C73B58C73B58C73AD7B6B9C6B528C73639C73638C73638463528C5A4A
8C5A4A8C5A4A94634A945A5294634A8C5A428C5A42A5634AA56B52A56B52AD6B52AD6B52AD6B52\
B5735ACE947BD6A58CDEB59CE7AD9CE7BDA5EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6
F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFCEB5EFC6ADEFBDA5EFBDA5EFC6ADE7B59CE7B59CDEB59C\
DEAD94D6A58CD69C8CCE947BCE947BCE9473CE9473CE8C6BBD846BCE8C6BCE8C6B
C69C73C69C73CE947BD6A584D6A584CE9473CE9473DE9C84D6A58CD6A584D6A584D6A584D6A58C\
D6A584C6947BC6947BC6947BAD846BAD846BB57B63AD735AB57B63AD846BA5735A
AD735AB57B63C69C73C68C73CE947BCE947BCE947BCE947BD69C73D69C84D69C84D69C73C69C84\
D69C84D69C84D6A584D6A584C69C84D6A58CD69C84D6A58CD6A584C69C84C69C84
C69C84AD846B8463526342316342315231295A4239634A425231294229214221184A2118734231\
D69C84BD846BCE735ABD5A42BD5A42CE7352DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD734A395A31295A3121422921422118422921\
4A21184229214229214229215231295231295231295239314229214229214A3131
312121312121291818312121523129422921312121392921523129734A399C6B52D6A58CE7BDA5\
EFC6ADEFCEB5F7CEB5EFCEB5F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6EFCEB5F7D6BDEFCEB5EFCEB5E7AD9CD69C8CC69484B58C73B5846BB58C73B58C73B58C73\
C6947BAD847BAD847B94736B94736B94736B8C63528C6352945A528C5A4A8C5A4A
945A52945A529C6B52945A4A945A4A9C5A42945A52945A4AA56B5294634A945A52AD735ABD8463\
BD846BCE947BDEA58CDEAD94E7BDA5EFC6ADEFCEB5EFCEB5F7D6C6EFCEB5F7D6C6
F7DECEEFCEB5F7CEB5EFCEB5EFCEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDADE7BDA5E7B59CDEB59C\
DEB59CD6A58CD69C8CC69C84CE947BCE8C73C68C73BD846BCE8C6BC68C63BD846B
CE8C6BCE8C6BC69C73D6A584D6A584D6A584D6A584CE947BD6A584D6A584D6A58CD6A584D6A584\
D6A584C6947BC69C73C69C73AD846BB5846BB5846BB5846BB57B63AD735AAD846B
BD846BCE947BC6947BCE947BC69C84CE947BD69C84D69C84C69C84C69C84D69C84C69C84D69C84\
C69C84D6A584CE947BD69C84D6A58CD69C84C69C84D6A58CD69C84D69C84C69C84
C6947BAD846B7B6352634A42523129523931634A42524239392921422921312118422118845242\
D69C84BD846BC66B52BD5A42BD5A42CE7352DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5A5634A42523129422921422921422118422921\
3121184229215231293929214229214229215231295231293929214229214A3131
3929213121183121182918183121215231295231294229215231296339298C6352D6A58CEFC6AD\
EFC6ADEFCEB5F7CEB5F7D6BDEFCEB5EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFBDADDEB59CD69C8CB58C7394736BAD7B6B947B73\
C6947BAD8C84B58C73AD7B6BAD7B6BAD7B6B9C73639C6B52945A528C63528C6352
A5735A945A52945A52945A52945A4A8C5A4A945239945A52945A4AA5735AB57B63BD846BBD846B\
B58C73D69C84DEAD94E7B59CE7BDA5F7BDB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDEFCEB5F7BDB5EFCEB5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFBDA5E7BDA5DEB59C\
DEB59CDEAD94D69C84CE8C84CE947BC68C73BD846BBD8463B57B63BD8463BD8463
BD8463C69C73C68C73CE9473CE947BD6A584DEAD94D6A58CDEA58CD6A58CD6A584D6A584CE947B\
CE947BCE9473CE9473C69C73B5846BC69C73CE8C6BBD846BC68C73CE9473CE947B
CE947BCE947BD69C84C69C84D69C73C69C84C69C84D6A584D69C8CD6A584C69C84D6A584D69C84\
D6A584C69C84CE947BC69C84D6A58CC69C84D6A584C69C84C69C84D69C84D6A584
B58C739C6B52734A425231294A3131523931423139634A4252423942292142211842181094634A\
CE947BBD846BB5735AAD5A42BD5A42C66B52DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD634A425A31295231294A2118422921422921\
4221184229214A2118422921422921422921422921422921392921312118523129
392921312121312121312118312118523129523129523129523931634231845242C69C84E7BDA5\
EFC6ADEFCEB5F7CEB5EFCEB5F7D6BDF7D6BDF7D6BDF7BDB5F7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7D6BDEFCEB5EFCEB5EFBDADAD847BBD846BAD7B6BB5846B\
AD7B6BAD7B6BAD7B6BBD846BAD847BAD8C84C6947B947B73AD7B6B9C7363A5735A
945A52A5735AA5735AA5735AA56B52945A4A945A52A56B52A56B52AD6B52B5735ABD846BBD846B\
CE947BE7AD9CE7AD9CE7BDA5EFBDADEFC6ADF7C6ADEFCEB5F7D6C6F7D6C6F7D6C6
F7D6BDEFCEB5F7CEB5F7D6BDEFCEB5EFC6ADEFBDA5EFBDA5EFC6ADEFC6ADE7BDA5EFBDADE7AD9C\
DEB59CDEAD94C69C84C69C84C68C73B58C73AD735AAD735AA5634AA5634AAD6B52
B5735AB57B63CE8C6BC69C73CE9473CE9473D6A584D6A58CD6A584DEA58CDEA58CD6A58CDEA58C\
D6A58CD6A584D6A584CE947BD6A584CE947BD6A584D6A584D6A584C69C84D69C73
D69C84CE947BD6A584C69C84D69C84D6A584D6A584C69C84D6A584D69C8CD6A584D6A58CC69C84\
C69C84D69C84CE947BC69C84D6A58CD6A584C69C84D69C84D6A584D6A58CC6947B
AD846B8C7363634A42523129523129422921524239634A424A3131312118422118422921B57B63\
CE8C6BD67363B5735ACE634AB55239C66B52DEA58CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD634A426339295231294A2118422921422118\
4229214221184229213929214229214A2118422921422921392921211010422921
422921312121312118312121392921422921523931634A42634A42734A397B6352C69C84DEB59C\
DEB5A5EFC6ADEFCEB5F7CEB5F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6EFCEB5EFBDADD6A58CDE9C8CD69C8C\
C69484D69C8CD69C8CAD8C84C6947BCE8C84D69C8CD69C8CC69484C69484AD847B
C68C73C6947BAD847BC6947BC6947BBD846BBD846BBD8463BD846BCE8C73CE947BD69C84DEA58C\
E7AD94EFBDADEFCEB5EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6EFCEB5F7CEB5EFCEB5F7BDB5EFCEB5EFBDA5EFBDA5EFC6ADEFBDADE7BDA5EFBDADDEB59C\
DEB59CDEAD94D69C8CCE8C84C68C73BD846BA56B529C5A429452398C5A429C5A42
9C5A42A5634AB5735ABD846BC69C73CE9473CE947BCE947BD6A584D6A584DEA58CD6A584D6A584\
D6A58CDEA58CD6A58CDEA58CDE9C84D6A584D6A58CD6A584D6A58CD6A584D6A58C
C69C84D69C84C69C84D6A584D6A584D69C8CD69C8CD6A584C69C84D6A58CD6A58CD6A58CD69C8C\
D6A584C69C84D69C73C69C84D69C84D69C8CC69C84D6A584D69C8CC69C84C6947B
AD846B734A426342315231293929213929214A3131524239392921392921312118734A39C68C73\
BD8463BD8463B5735AAD5A42BD5A42CE7352C6947BD6C6BDF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFD6BDC673524A5A3129422921422921422921422921\
4229213929214A2118312118312118422921523129422921422921211010392921
422921312118312121312118312118392921523129634A4273524A734A4273524AB58C73DEAD94\
EFBDADEFC6ADEFCEB5F7CEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7BDB5CEB5B5F7BDB5\
E7AD9CDEB59CDEB5A5E7AD9CDEB59CEFB5A5CEB5B5EFBDADDEB5A5E7AD9CDEB5A5
CEB5ADD6A58CE7AD9CDEB59CDEB59CDEB5A5E7AD9CDEB59CE7AD9CEFBDA5EFBDADEFBDADEFBDAD\
EFCEB5EFBDADF7D6BDEFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6EFCEB5F7D6BD
EFCEB5F7BDB5EFCEB5F7D6BDEFCEB5F7C6ADEFBDA5EFBDADEFC6ADEFCEB5EFBDADEFBDA5E7BDA5\
E7AD9CDEB59CDEAD94D69C8CCE947BBD846BA5735A945A4A945A4A8C5A428C5A42
8452398C5A4294634AAD735AB57B63C69C73CE9473CE9473D6A584D6A584D6A58CDEA58CD6A58C\
DEAD94D6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A584D6A58CD6A58C
D6A58CD6A58CD6A58CD6A58CD69C84D6A58CD6A584D6A58CD6A58CD6A58CD6A58CD6A58CD6A58C\
D6A584D69C8CC69C84CE947BC69C84D6A58CD69C8CC69C84D6A584D6A584C6947B
8C7363734A395239314229213121215231294A31314229313929215242395231298C5A4ACE8C73\
C68C63BD8463B5735AB55239B55239BD8463CE8C6B947B73FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE846B5A6339315A3121312118422921422921\
4A2118392921422921422921422921523129422921422921422921291818312118
422921312118422921312121312121392921392921422921634A428463528C6352C6947BD6A58C\
DEB59CEFC6ADEFC6ADEFCEB5EFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7BDB5F7D6C6D6C6C6F7D6C6D6C6C6F7D6C6F7D6C6D6C6BDF7BDB5
F7BDB5F7BDB5D6C6BDEFCEB5F7BDB5F7D6BDD6C6C6F7D6BDF7BDB5D6C6C6F7D6C6EFCEB5EFCEB5\
F7BDB5EFCEB5F7D6BDEFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
EFCEB5F7C6ADEFCEB5F7D6BDF7CEB5EFC6ADEFBDADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5E7BDA5\
DEB5A5E7AD9CDEB59CD6A58CD69C8CCE947BAD735A9C6B5294634A845242845239
844A39844A39844A3994634AA5735AB57B63BD846BC68C73CE9473D6A584D6A58CD6A58CD6A58C\
DEAD94DEAD94DEAD94DEA58CDEA58CD6A58CD6A58CD6A58CD69C8CD6A584D6A58C
D6A58CD69C84D69C84D6A58CD6A58CD6A58CD6A58CD6A58CC69C84D6A58CD6A58CC69C84C69C84\
D6A58CD6A584D69C84C69C84D69C8CD6A58CD6A584C69C84CE947BD6A584B58C73
8C6352634A42523129422921392921392921422931392921312121634A425239319C6B52CE9473\
B57B63CE735AAD6B52AD5A42AD5A42C66B52BD846B73524ADED6E7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E78C736B6339316339314229214A2118523129\
4A2118392921422921312118312118422921422921422921422921312118211010
312118422921312118392921422921422921523129523931634A42734A397B6352B58C73BD9C8C\
DEB5A5E7BDA5EFC6ADEFBDA5EFCEB5F7CEB5EFCEB5F7D6BDF7CEB5F7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE
F7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEDECED6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6BDEFCEB5F7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6EFCEB5F7D6C6
EFCEB5EFC6ADF7BDB5EFCEB5EFC6ADEFBDA5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFBDADE7BDA5\
E7BDA5E7BDA5E7AD9CDEB59CE7BDA5DEB59CCE8C84BD846BAD735AA5735A945A4A
845239845242845242734A39734231734A398452428452428C5A4A94634ABD846BCE947BCE947B\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A584D6A584C69C84D6A584
D69C84C69C84D6A58CD6A584C69C84D69C84D6A584C69C84D6A58CC69C84CE947BCE947BC69C84\
CE8C84C69C84C69C84D6A58CD69C8CD69C8CD6A584C69C84D69C84CE947B9C7363
6B524A5231294229213929214229214229213929213121214A31315242395A31298C5A4AB57B63\
C68C73AD735AAD6B52A55239AD5A42B5735AA56B52523129AD9494F7E7DEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF8C7B73734A395A42394229213929214A2118\
422921392921312118422921422118392921422921392921523129312118211010
211010422921422921291818422921422921523129523129634A42734A427B6352AD846BC69C84\
DEAD94E7BDA5EFC6ADEFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6BDF7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7DECEEFCEB5F7D6BDF7D6BD
EFCEB5F7CEB5EFCEB5F7C6ADEFCEB5EFBDA5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7BDA5\
EFBDADEFB5A5E7BDA5E7BDA5E7BDA5EFBDADD6A58CD6A58CCE947BBD846BAD735A
945A528C5A428C5A4A734A39734A39633931633929634231634231734A39845242A5735AB57B63\
C69C73D6A584D6A584D6A58CDEAD94D6A58CD6A58CD6A584D6A58CD6A584C69C84
D6A584D6A584C69C84D6A584C69C84D6A584CE947BC69C84CE947BB58C73C68C73B58C73B58C73\
C6947BCE947BD6A58CD69C8CD6A584D6A58CC69C84D69C84C69C84CE947BA5735A
734A395231293929214229214229214229213121215231295242395231295A3129734A39AD6B52\
CE8C6BBD846BAD6B52A55239AD5A42B57B63945A4A5231299C8C8CDECED6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFEFE7E7A5847B634231734A395A3129422921422921\
422118392921312118312118422921392921422921422921422921422921211010
2110103121184229214229213929215231295231295239315A4239734A4273524AAD846BC69484\
C69C84DEB59CE7BDA5EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DE
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7D6BDEFCEB5F7CEB5EFCEB5F7BDB5EFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFBDADEFBDA5E7BDA5\
E7BDA5E7BDA5E7BDA5EFBDADE7BDA5EFBDADE7BDA5DEB5A5DEB5A5DEA58CCE8C84
C6947BAD735A9C6B528C5A4A845239734A39734A39633931633929633931634231734A39634231\
845239A5735AB58C73C6947BD6A58CD6A58CD6A584D6A584C6947BD6A584D6A584
D6A584D6A584CE947BCE947BCE947BC68C73C68C73C6947B9C7363B57B639C73639C6B52AD735A\
B58C73C6947BD6A58CD69C84C69C84D6A584D69C84C69C84C69C84C6947B8C5A4A
6342314229215231293929213929214229213121215239315239314A313142211873422994634A\
BD8463BD8463BD8463AD6B52B57B63B5846B8452396B524A8C736BB5A5A5DED6E7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7948484633931734A39634231523129523129\
392921422921422921392921422118422921422921422921422921422921291818
211010291818422921422921392921523129523129634231734A3973524A846352B58C73C69C84\
D6A58CDEAD94DEAD94EFBDA5EFCEB5F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DE\
F7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6EFCEB5F7CEB5
F7BDB5EFCEB5F7BDB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDADEFBDA5\
EFBDADE7BDA5EFBDADEFBDADE7BDA5E7BDA5DEB5A5DEB5A5E7BDA5DEB5A5DEB59C
D6A58CD69C8CBD846B9C6B52945A52945A528C5A4A734A39734231634231633929633931634231\
6339297342318452398C5A4AB5846BB58C73C68C73C69C73C68C73C68C73C6947B
CE947BC6947BC6947BC6947BB58C73B5846BB57B639C73639C6B529C6B529C6B529C7363BD846B\
CE8C84D6A58CD69C84D69C84C69C84D69C8CD69C84D69C84CE947BC6947B7B6352
5A3129523129422921291818422921392921422921524239422931422921422118734229844A39\
AD5A42AD6B52B5735ABD8463B57B63A5735A734A39634A428C73639C8C8CEFD6CE
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9494634231734A39634231523129523931\
5231293929213929214A2118392921422921312118422921422921422921312118
2110102110103121183929215231294229214A3131523129634A427B63528463529C7363C6947B\
BD9C8CDEAD94DEB5A5EFC6ADEFCEB5EFCEB5F7D6BDF7CEB5F7CEB5F7D6BDF7D6C6
F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6BDEFCEB5F7CEB5EFCEB5
EFCEB5F7D6BDEFCEB5F7C6ADF7C6ADEFC6ADF7C6ADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5EFC6AD\
EFBDA5EFBDA5EFBDADE7BDA5E7BDA5EFBDADEFBDADEFBDADE7BDA5E7BDA5DEB5A5
DEAD94DEAD94D69C8CC6947BAD7B6BAD735AA5735A9C6B529C6B52845242734A39634231633931\
633931634231734A39734A398C5A4A9C6B529C6B52A5735AAD735AAD846BB57B63
BD846BB57B63A5735AA5735A9C6B529C6B529C6B529C6B529C6B529C6B529C7363BD846BC6947B\
D69C8CD6A58CC69C84C69C84D69C84D69C84C69C84C69C84CE947BB58C736B524A
5231295231293121183929215231293121185231294A31314A31315231294229215A31217B3121\
9C5A42A55239A552399C5A429452398452425A42396B524A8C736BAD9CA5E7DEE7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9494634A42634231734A42634231523931\
4229214229213121184229214A2118392921422921422921422921422921422921
312118211010291818392921422921523129634231634A42634A42734A3984635294736BC6947B\
C69484D6A58CDEB5A5EFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECE
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7D6BDF7D6C6F7D6C6F7D6BDF7DECEF7D6C6EFCEB5F7D6BDF7D6C6EFCEB5EFCEB5
F7D6BDEFCEB5F7D6BDEFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFC6AD\
E7BDA5EFBDADEFBDADEFC6ADEFBDADEFBDADEFC6ADEFBDADE7BDA5E7BDA5E7B59C
DEB5A5DEB59CDEAD94D6A58CD69C8CC6947BAD846BAD7B6B9C7363A5735A8C5A4A845242734A39\
734231634231634231634231734A398452428452428C5A4A8C5A4A9C6B52A57352
846B5A9C6B528C5A4A8C63529C6B529C6B52A5735A945A529C6B52AD735AB5846BCE947BD69C8C\
C69C84D6A58CD69C8CD69C84D69C8CC69C84CE947BCE947BC69C73B58C73734A39
5231293121183121184229214229213121214229313929214A3131392921422118522118522118\
7342298C31297342297B31217342316339296342316B524A846B5AB5A5A5F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD734A39634A42734A42734A39523931\
4A31314A2118312118392921392921523129422921392921422921422921422921
3121182110102918183121183121215231295231295A4239734A427B63527B635294736BB58C73\
C69C84D6A58CDEB59CE7BDA5EFCEB5F7BDB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7BDB5F7D6BD
F7D6BDEFCEB5F7D6BDF7C6ADEFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5EFBDAD\
EFC6ADEFC6ADEFC6ADEFBDADEFC6ADEFBDADE7BDA5EFBDA5E7BDA5E7BDA5E7BDA5
E7B59CE7AD9CDEB59CDEAD94D6A58CD69C8CD69C8CC6947BB58C73B57B639C73639C6B528C5A4A\
845242845242734231734231734A39734A398452428452428C5A4A8C5A4A8C5A4A
9C6B529C6B529C6B528C5A4A9C6B52846B5A9C6B529C7363AD735ABD846BCE8C73C69C84C69C84\
D69C8CD69C84D69C84D69C84C69C84CE947BD69C84CE947BC68C73AD846B634A42
422921312118392921422921392921422921392921422931422921392921312118421810631810\
7B29187B29187321105A3121633929633929734A3973524A948484EFE7E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD734A39634231734A39734A42634231\
523129523129422921422921523129523129523129422921422921422921523129
392921291818211010291818523129523129523129634231634A42734A427B63529C7363B58C73\
AD8C84D6A584DEB59CE7B59CEFBDA5F7CEB5EFCEB5F7D6BDF7CEB5F7D6C6F7D6BD
F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFCEB5F7D6BD
EFCEB5F7CEB5EFCEB5EFCEB5EFC6ADEFC6ADF7C6ADEFC6ADEFC6ADEFC6ADEFBDADEFBDA5EFC6AD\
EFBDADEFBDADEFBDADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5E7BDA5E7B59CE7BDA5
E7BDA5DEB5A5DEB59CDEB59CDEB59CD69C8CD6A58CD69C8CC69C84C6947BBD846BB5846B9C7363\
9C7363945A52845242734A39634231734A39734A39845239734A42845239845242
8452428C5A4A8452428C5A4A945A529C6B52AD735AAD735ABD846BCE947BC69C84D69C84D69C8C\
D69C8CC69C84C69C84C69C84D69C84CE947BC69C84C68C73B58C73AD846B634231
422921392921422921422921392921422931422921523129392921422921312118312118420800\
4218106318105221186339295A31295A4239634A426B524AE7DEE7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7B5A5A573524A734A39734A39734A396B524A\
5A3121523931523931392921523129422921422921523129422921523129422921
5239315A42394A3131392921523129523931523129523931734A39734A42846352A5735AB58C73\
C69C84D6A584D6A58CE7BDA5E7B59CEFC6ADF7CEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7BDB5F7D6BDF7D6BD
EFCEB5EFCEB5F7D6BDEFCEB5F7C6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADEFBDADEFBDADEFBDADEFBDADEFBDADE7BDA5EFBDADE7BDA5E7AD9C
E7BDA5E7AD9CE7B59CE7AD9CDEB59CDEB59CDEAD94D69C8CD6A58CC69C84C69484C6947BC6947B\
C6947BB58C73B5846BB57B639C6B529C6B5294634A8C5A42845242845242734A39
844A39945A4A9C6B52A56B52AD735ABD846BBD846BCE947BC69C84D69C84C69C84D69C8CD69C84\
C69C84D69C8CC69C84D69C84CE947BCE947BC6947BC68C73AD846B8C6352523129
5231294229214229213929215231294229315231294A3131312121392921422921312118312118\
312118422921422921422921523931523931634231735A52D6C6D6E7DEE7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7AD9C8C73524A634A42734A39734A4273524A\
5239315239314A3131392921523129523129422921422921422921422921523129
4229215239314A31315231294A31315242395A42395A4239634A42734A42846352A5735AAD846B\
B58C73BD9C8CD6A58CDEB59CEFC6ADEFBDA5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7DECEF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5
F7D6BDEFCEB5F7C6ADEFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5\
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7BDA5EFBDADE7BDA5EFB5A5E7BDA5
E7BDA5DEB5A5E7AD9CE7AD9CDEB59CDEB59CDEB59CDEAD94D6A58CD69C8CD6A58CD69C84C69C84\
D69C8CCE947BC68C73B58C73BD846BB57B639C7363A5735A9C6B529C6B529C6B52
A5735AAD735AAD735AB57B63C68C73C6947BC69C84C69C84C69C84CE947BD69C84D69C84CE8C84\
D69C73C69C84D69C84C69C84CE947BCE947BC68C73B58C73AD846B7B6352523129
5231294229214229214229214229213929215231293121213929214A3131392921211010312118\
3929215231294229215231295239315231295A423963524A8C73639C8C8CD6C6BD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7D6C6CE8C7363846352734A396B524A734A4273524A\
6B524A5239315239315231294229215231294229214229214229215231295A4239
523931523129523129523129523129523129634231523931734A396B524A7B6352846B5A9C7363\
B5846BC69C84D6A58CDEB59CE7BDA5EFC6ADF7CEB5F7D6BDEFCEB5F7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7E7DE\
F7E7DEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECE\
F7DECEF7D6BDF7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDF7BDB5
EFCEB5F7CEB5EFBDA5EFC6ADF7CEB5EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDADEFBDA5EFBDA5\
EFBDADEFBDADEFC6ADEFC6ADEFC6ADEFBDA5EFBDADEFC6ADE7BDA5E7BDA5E7BDA5
E7BDA5E7BDA5DEB5A5DEB59CE7AD9CE7AD9CDEB59CDEAD94DEAD94DEAD94D6A58CD69C8CD6A58C\
D6A58CD69C8CC69C84CE947BC6947BB58C73C68C73BD846BBD846BBD846BBD846B
BD846BBD846BC68C73CE947BCE8C84D6A584D69C8CC69C84D69C84CE8C84D69C8CC69C84D69C84\
D69C84CE8C84C69C84D69C73C69C84CE947BB58C73BD846BA5735A734A42523129
5231294229214229214A31314229213929213929213121214A31314A3131312121312118291818\
4229213929213121185231294A31315231294A3131523931634A4273524AAD9C8C
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5B5846B5A734A39734A396B524A634231734A39\
6B524A6342316342315239315231295231295231294229215231294229214A2118
4229215231294229214229214229215231295231295239316342316B524A734A428C63529C7363\
B5846BC6947BD6A58CDEAD94DEB59CEFC6ADEFC6ADF7CEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DE\
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7DECEF7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6C6
EFCEB5F7BDB5EFC6ADF7CEB5EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFC6ADEFC6ADEFC6ADEFBDAD\
EFC6ADEFCEB5EFC6ADEFBDA5EFBDADEFC6ADEFC6ADEFBDADE7B59CE7B59CE7BDA5
E7B59CE7B59CE7B59CDEB59CDEB59CDEB59CDEB59CDEB59CDEAD94D6A58CD6A58CD6A58CD6A58C\
D69C8CD69C8CD69C8CD69C8CD69C8CCE947BCE947BCE947BCE947BCE8C84CE947B
CE8C73CE947BC69C84D69C8CC69C84D6A58CD69C84D69C84C69C84D69C84D69C84D69C84CE8C84\
C69C84D69C73D68C7BC69C84CE8C84C68C73B58C73AD846B9C6B52734A39523129
5231294229214229214229213929214229213929213929314A3131392921392921312121312121\
3929213121183929214229215231295231295231293929216B524A6B524A9C8C8C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C7B6352734A39634A42734A39634231634A42\
634A425239316339315A4239523931523129523931422921422921392921312118
4221185231295A31295231295231295231295231295A3129523931634231734A427B63528C6352\
9C7363B5846BD6A584D6A58CDEAD94EFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7DECEF7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5EFCEB5F7D6BD
EFCEB5EFCEB5EFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFBDADEFBDADEFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFC6ADEFBDADE7B59CE7BDA5E7BDA5
E7BDA5E7B59CE7BDA5E7BDA5DEB59CE7AD9CDEB59CE7AD9CDEAD94DEAD94DE9C8CDEAD94D69C8C\
DEB59CD6A58CD6A58CD69C8CD6A58CD69C8CD6A58CD69C8CD6A58CD69C84C69C84
C69C84D69C8CD69C84D6A58CD69C84C69C84D69C8CC69C84D69C84D69C84C69C84D69C8CCE947B\
D69C84D68C7BD69C84C69C84C6947BC68C73B57B63A5735A846352634231523129
523129422921392921392921392921422921312121523129422931392921312121312121312118\
3121213929214A3131422921523129422921312118422921634A42634A428C7363
EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C8C8C73524A734A39734A42734A396B524A634231\
634A425239315239315239315239314A3131634231422921422921422921422921
4A2118422921523931523931523129422921422921523129634231634231634231846352846352\
8C7363AD846BC6947BD6A58CD6A58CEFBDA5EFC6ADEFCEB5F7D6BDF7D6BDF7D6C6
F7D6BDF7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DE\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7E7F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDF7CEB5
F7CEB5EFC6ADF7CEB5EFBDA5EFBDA5EFC6ADEFC6ADEFCEB5EFC6ADEFBDADEFBDA5EFC6ADEFC6AD\
EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7BDA5EFBDADEFBDA5E7B59CE7BDA5E7BDA5
E7B59CEFBDADE7BDA5DEB59CE7AD94DEB59CDEB59CDEAD94DEAD94DEB59CDEB59CDEAD94D6A58C\
DEAD94DEB59CD6A58CDEAD94DEB59CDEAD94D6A58CD6A58CD69C84D6A58CD69C8C
D6A58CD6A58CD69C84C69C84D69C84D69C84D6A584D69C84D69C8CD69C8CD69C84D69C84D69C84\
C69C84D69C84C69C84CE947BC68C73B58C73AD846B94634A734A42523931523129
523129523129392921422921422921312121392921422931523129312121392921312118392921\
312121422921422921422921422921312118291818422921634A426B524A63524A
C6ADADFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A5847B7B63526B524A6B524A634A42734A39634A42\
6B524A6342315239316342315A4239523129422921422921523129523129312118
4229214229214229214229214229214229214229214221184229216342315A4239734A42846352\
8C6352AD846BB58C73D6A584DEAD94E7BDA5EFC6ADEFCEB5F7CEB5F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7BDB5EFCEB5F7D6BDEFCEB5F7BDB5
EFCEB5EFC6ADEFC6ADEFBDADEFBDA5EFBDA5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFC6AD\
EFBDA5EFBDA5EFBDA5E7BDA5EFBDA5EFBDADEFBDA5E7BDA5E7BDA5EFBDA5E7BDA5
E7BDA5E7BDA5E7BDA5E7B59CDEB59CDEB59CE7AD9CDEB59CDEAD94DEAD94DEAD94DEB59CDEAD94\
D6A58CD6A58CDEAD94DEAD94D6A58CD6A58CD6A58CD6A58CD69C8CD6A58CD6A58C
D69C84D69C84C69C84D69C84D6A58CC69C84D69C84D69C84D69C84C69C84D69C84C69C84D69C84\
D69C84C69C84CE947BCE947BC6947BAD846B9C6B52846352634231634231523129
5231293929213929214229213121213929214229314A3131392921523129312121312118312118\
3929214A2118523129422921392921211010211010523129634A426B524A734A39
AD9494F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7846B5A7B6352634231734A426B524A73524A73524A\
634A42634A425239315239315A4239633931523931523129392921422921392921
4229214229214229213121184229214229214229214229215231295231296342316B524A734A39\
7B63528C63529C7363B58C73CE947BE7BDA5E7B59CEFC6ADEFC6ADF7CEB5F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECE\
F7DECEF7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5EFCEB5F7CEB5
EFC6ADEFC6ADEFC6ADEFBDADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFC6ADEFBDADEFC6AD\
EFBDA5EFBDA5EFBDADEFBDA5E7BDA5EFB5A5E7BDA5E7B59CEFBDA5E7B59CE7BDA5
E7BDA5E7B59CE7BDA5DEAD94E7AD9CDEB59CE7B59CE7AD9CDEB59CE7AD9CDEAD94DEAD94DEB59C\
DEAD94DEAD94DEB59CDEAD94DEA58CD6A58CD6A58CD6A58CD6A58CD69C8CD6A58C
D69C84D69C8CD69C8CD6A58CD6A58CD69C8CD6A58CD69C8CD69C8CD69C84C69C84D69C84D69C84\
D69C84C69C84CE947BB58C73AD846BA5735A846352734A39523931523129523129
422921422921392921392921312121392921523931392921291818291818312121312118312121\
39292139292131211842292131211829181831211852393152312963423173524A
AD9C8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7846B5A7B63525A3129734A39634231634A42734A42\
6B524A6B524A5A42395A42395A42395239315239315231294A21184229214A2118
3121184229215231295A3121523129523129422921422921523931634231634231734A42734A42\
734A398452399C6B52AD846BB58C73DEAD94E7B59CEFBDADEFC6ADEFCEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7E7DEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7E7F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7BDB5F7D6BDF7C6ADEFC6AD
F7C6ADEFC6ADEFCEB5EFBDA5EFBDADEFBDA5E7B59CEFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDAD\
EFBDA5EFBDA5EFC6ADE7BDA5EFBDA5E7BDA5EFBDADE7BDA5E7B59CEFBDA5E7B59C
E7B59CE7BDA5E7BDA5DEB59CDEAD94DEAD94DEAD94DEB59CDEAD94DEAD94DEAD94DEAD94DEB59C\
DEB59CD6A58CDEAD94DEA58CD6A58CD6A58CD6A58CD6A58CD6A584D6A58CD69C8C
D69C84D6A58CD6A58CD69C84D6A58CD69C84D69C84D69C84D69C84D69C84D69C84CE8C84D69C84\
D69C84C69C84C6947BB5846B9C7363A5735A7B6352734A39523931523931422921
3929213121183121213121215231294A3131392921291818291818392921312118291818392921\
42292131212139292131211831211829181842292152423952312952393173524A
9C8C8CF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F773524A7B6352634231634A42634A426342316B524A\
734A39634A42634A425239315A42395A4239523931523129422921422921422921
312118422118422921422921422921523129523129523129422921523129634231734A42734A39\
7B6352734A42846352A57352B57B63D6A584E7B594EFC6ADEFC6ADEFCEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5F7D6BDEFCEB5EFC6ADEFCEB5
EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5\
EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59CEFBDA5E7BDA5E7BDA5E7BDA5
E7B59CE7B59CE7B59CE7B59CDEAD94E7AD94DEB59CE7AD94DEAD94DEAD94DEAD94DEAD94DEB59C\
DEAD94DEA58CD6A58CD6A58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A584
D6A58CD6A58CD6A58CD6A58CC69C84D69C8CC69C84D69C84C69C84D69C84C69C84D69C84C69C84\
C69C84CE947BBD846BAD846BA5735A7B6352734A395A4239523931523129312118
3121183929213121213929214A3131634231291818291818312121392921291818312121312118\
39292131211839292121101021101031211842292142292152312963423173524A
A5847BDECED6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F75A4239734A39634A426B524A734A39634A42734A42\
634A42634A426B524A634231523931523931523931422921422921422921422921
422921312118422118422118422921422921523129422921523129523129523931734A427B6352\
734A42846352845239845242A5735AD6A584DEAD94EFC6ADEFCEB5EFCEB5F7CEB5
EFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7BDB5EFCEB5
F7BDB5EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5\
E7BDA5EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5EFBDADE7BDA5E7B59CE7BDA5E7AD9C
E7B59CE7B59CE7B59CE7AD94E7AD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEB59CD6A58CDEA58CDEAD94D6A58CD6A58CDEAD94D6A58CDEA58CD6A58CD69C84
D69C84D6A58CD6A58CD69C84D69C8CD69C84C69C84D69C84D69C84D69C84D69C84D69C84CE947B\
CE947BC6947BB5846B9C7363A5735A7B6352734A39634231523129392921392921
3929213121183121215231294A3131392921291818291818312121291818312121312118291818\
3121183121183121212110103121183121184229215231294229215A423973524A
94736BCEBDC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7634A42734A39634A42734A396B524A6342316B524A\
634A42734A396B524A634A425239315A42395A4239523129422921422921422921
5231293121183121184229214A21184229214229215231295231295231295231296B524A73524A\
8452428463528463528452429C6B52C6947BD6A58CDEAD94EFC6ADF7CEB5EFCEB5
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7BDB5EFCEB5EFCEB5EFC6AD
EFCEB5EFBDA5EFBDADEFBDA5EFBDA5EFC6ADEFBDA5E7BDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5\
EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7BDA5E7BDA5E7B59CE7B59CE7B59CE7B59C
DEAD94E7AD94E7B594DEB59CDEB59CE7AD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEA58CDEAD94D6A58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A584D69C8C
D6A58CD6A584D6A58CC69C84D6A584C69C84D69C84D69C8CD6A58CC69C84D69C84C69C84CE947B\
CE947BB58C73AD846BA5735A846352734A39634A42523129422921392921392921
3929213929215231294A3131392921211010312121312121312121312118312118291818312118\
2918183121183121183121182110103929213929215231294229216342316B524A
8C7363D6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E78C736B735A52634231634A426B524A6342316B524A\
6B524A634A426B524A634A425A4239634231634A42523129422921523129422921
5231294229214221184229214229214A2118422921523129523129523129523129634A42845242\
7B635284524284635284524294634AC68C73D6A584DEAD94E7BDA5EFCEB5F7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECE\
F7DECEF7DECEEFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7C6ADF7C6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDAD\
EFBDA5E7B59CEFBDA5EFBDADE7BDA5EFBDADE7B59CE7B594E7B59CDEA58CE7B59C
E7B59CDEAD94DEB59CE7AD94E7AD94DEB59CE7AD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58C\
DEAD94DEAD94D6A58CD6A58CD6A58CD6A58CD6A58CDE9C84D6A58CD6A58CD6A58C
D6A584D6A58CD69C8CD6A584D69C8CD69C84C69C84D6A584D69C84D69C84C69C84CE947BC6947B\
C68C73B5846B9C73639C6B52846352734A42523931523129422921422921392921
3929215231294A3131523129291818291818312118291818312118312121291818312118291818\
2110103121183121182918183121183929213929215231295231295A3129734A39
8C7363DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7EFE7E77B635273524A734A396342316B524A734A39634A42\
634A426B524A6B524A634A425A4239523931634A42523931523129422921523129
5231294229213121183121184229215231294229214229215239315239315239316342316B524A\
734A427B63528C63528463528C5A4ABD846BCE947BDEAD94E7BDA5EFC6ADEFCEB5
F7CEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFC6AD
EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5E7BDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5\
EFBDA5E7B594EFBDA5E7BDA5EFBDA5EFB5A5E7BDA5E7B59CE7B59CE7B59CE7BDA5
E7B59CE7AD9CDEAD94DEB59CDEAD94E7AD9CDEAD94DEAD94DEAD94DEA58CDEAD94D6A58CDEAD94\
DEA58CDEA58CD6A58CDEAD94D6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58C
D6A58CD6A58CD69C84D69C8CC69C84D69C84C69C84D69C8CD69C84C69C84CE947BC6947BC6947B\
C68C73B5846BA5735A8C63527B6352634231523931523129422921392921422921
5239315A4239523129291818291818291818291818312121312121312121291818291818211010\
3121182918183121183121213121183929214229214229215231295239316B524A
947B73E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7D6C6D66B524A6B524A6342315A42396B524A634A42734A39\
734A396B524A634A4273524A634A425A42396342315A4239523129523129523129
4229215231295A31293121184229214229214229215231293929214229215239315A3129633929\
6B524A8452428463529C6B52945A52B5846BC68C73DEAD94E7B59CE7BDA5EFC6AD
EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7DECEF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7CEB5EFCEB5EFCEB5
EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5E7B59C\
E7BDA5EFBDA5E7B59CE7BDA5EFBDA5E7B59CE7B59CE7BDA5E7BDA5E7B59CDEB59C
E7AD9CE7AD94DEAD94DEB59CDEAD94E7AD94DEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDEAD94\
D6A58CDEA58CD6A58CD6A58CD6A58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58C
D6A584D6A58CD6A58CD69C84D69C84C69C84D69C84C69C84C69C84C69C84C6947BC68C73C68C73\
B5846BAD846B8C5A4A7B6352634A42634231523931523931523931634231523931
422921312118312118312118312121312121312121312118312118291818291818291818291818\
312118211010312118392921312118392921422921422921523129634231735A52
CEB5BDFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7DECED6734A395A4239634231634A42734A396B524A634A42\
634A42634A42634A426B524A6B524A5A42395A42395A4239523931523129523129
5231294229215231294229214229214229215231295231295231294229214229215A3129634231\
734A39734A428C5A4A846B5A8C6352BD846BC68C73D6A584DEAD94E7BDA5EFC6AD
EFC6ADF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEEFCEB5F7D6BDF7BDB5F7D6BDF7D6BDEFCEB5F7CEB5EFC6AD
EFBDADEFC6ADEFBDA5E7B59CEFBDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5EFBDA5EFBDA5EFBDA5\
E7BDA5E7B59CEFBDA5EFB5A5E7B59CE7B59CE7B59CE7BDA5E7BDA5E7B59CE7B59C
DEAD94E7AD9CE7AD94E7AD94DEAD94DEAD94DEAD94DEA58CDEA58CDEAD94D6A58CDEAD94DEAD94\
D6A58CDEA58CD6A58CD6A58CD6A58CD6A584DEA58CDEA58CD69C84D69C84D69C84
D6A58CD69C84D69C84C69C84D69C84C69C84D69C84C69C84CE947BC6947BCE9473C68C73B58C73\
AD846B9C7363846352734A42734A39634A425A4239634231523931523129422921
392921312121392921312121312121422921312118312121291818291818291818291818211010\
211010291818392921312118312118392921422921422118523129634231A5847B
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7C6ADBD734A39634A425239315A4239634A42734A42634A42\
734A42734A39734A396B524A6B524A634A42634A425A4239633931523931523129
4229214229215231295231293121184229215231294229215231295A3129422921634A42523931\
634231845242846352A5735A9C6B52BD846BBD846BCE947BD6A584E7B59CEFC6AD
EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DE
F7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5EFCEB5EFCEB5F7BDB5EFC6ADEFC6AD
F7C6ADEFBDADEFBDA5EFBDA5EFB5A5E7B59CEFBDA5E7B59CE7B59CEFBDA5E7B59CE7B59CEFBDA5\
EFBDA5EFBDA5E7BDA5E7B59CE7B59CE7B59CE7BDA5E7B59CE7B59CE7AD94DEAD94
E7AD9CDEB59CDEAD94DEAD94DEAD94E7AD9CDEAD94DEA58CDEA58CDEAD94DEA58CD6A58CDEA58C\
DEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD69C8CD6A58CD6A584D6A584
D69C84D6A584D6A58CD69C8CD6A584D69C84C69C84CE947BC6947BC68C73B58C73BD846BB5846B\
A5735A9C73637B6352734A42734A39634231523931634231523931523931312121
312121312121312121312121392921312121312118291818211010291818291818181010291818\
3121183121183121183121182918184229213121182110105239316B524AAD9494
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5B56B524A734A426B524A634231734A39634A426B524A\
73524A6B524A634A426B524A73524A6B524A634A42634A425A42395A3129523129
523129422921523129523931312118523129523129422921523129523931523931634A42734A39\
634A428452428463529C6B52846B5AAD846BC68C73CE8C6BD69C84E7B59CE7B59C
EFC6ADEFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7DECE\
F7DECEF7D6C6F7D6BDF7D6C6EFCEB5F7D6BDF7BDB5F7D6BDEFCEB5EFBDA5EFBDA5
EFC6ADEFC6ADEFBDA5EFBDA5E7BDA5E7BDA5E7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CEFB5A5\
E7B59CEFBDA5E7B59CE7B59CE7B59CE7AD94E7B59CE7AD94E7AD9CDEAD94E7AD94
E7AD9CDEB59CE7AD9CDE9C8CDEAD94DEA58CDEAD94DEAD94DEAD94DEA58CD6A58CDEA58CDEA58C\
D6A58CD6A58CD6A584D6A58CD6A58CD6A58CD6A584D6A58CD6A584D69C8CD69C84
CE947BD69C8CC69C84D6A58CD69C84C69C84C69C84CE947BC68C73B58C73C68C73B5846B9C7363\
AD846B8C73637B6352734A396342315A42395239315231294A3131422921312121
312118291818312118392921312121312118291818181010291818312121211010211010312118\
312121291818312118312121392921392921312118392921523931735A52CEB5BD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFE7DEEFCEBDC66B524A6B524A6B524A523931634A42634A4273524A\
73524A6B524A734A396B524A6B524A6B524A634A425A4239634A425239314A3131
5231294229215231295231294229215231294229215231295239315A3129523931523931734A39\
6B524A734A428C6352846B5A9C6B52B5846BB58C73C68C73D69C73DEAD94E7B59C
EFC6ADEFCEB5F7CEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7D6C6F7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFC6ADF7C6ADF7C6ADEFC6AD
EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5EFBDA5EFBDA5E7B59CE7B59C\
E7B59CE7B59CEFBDA5E7B59CE7AD94E7BDA5E7AD9CDEB59CE7AD94DEB59CE7AD94
DEAD94E7AD94DEB59CDEAD94DEAD94DEA58CDEAD94DEA58CD69C8CD6A58CD6A58CD6A584D6A58C\
DEA58CD6A58CD6A58CD69C8CD6A58CD69C84D6A58CD6A58CD69C8CD6A58CD69C84
D69C8CD69C84D6A584C69C84D6A584CE947BCE947BC6947BC68C73B58C73B5846BAD846BAD846B\
A5735AA5735A734A39634A42634231523931523129523931422921312121312121
312118312121312121291818312118312121291818291818291818291818211010312121392921\
29181829181839292139292131211831211831211842292152312973524AC6ADAD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFD6C6CE734A42734A39634A42523931634A42734A396B524A\
6B524A734A42634A426B524A6B524A735A526B524A5239315A42395A4239523129
5231295231294229215231295231295231295231295239315239315A31296342315A3129634A42\
734A4273524A8C63528C6352846B5AB57B63BD846BC68C73C69C84DEA58CE7B594
EFBDA5EFC6ADEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE\
F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECE
F7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7C6ADEFC6ADEFC6ADEFC6ADEFBDA5
EFC6ADEFBDA5EFBDA5EFBDA5E7BDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5E7BDA5EFBDA5E7B59C\
E7BDA5EFBDA5E7B59CE7B59CE7B59CE7B59CE7AD94DEB59CE7AD9CE7AD94DEAD94
DEA58CDE9C8CDEAD94E7AD94DEAD94DEA58CDEA58CDEAD94DEAD94D6A58CDEA58CD69C8CD69C8C\
DEA58CD6A58CD69C84D69C84D6A584D69C84D6A58CD6A58CD6A58CD69C84D69C84
D6A584C69C84D69C84D69C84C69C84CE947BC69C84C6947BB58C73B5846BAD846BAD846B9C7363\
A5735A8C5A4A634A426342315231295231294A3131422921392921392921312121
392931392921312121312121312121312118291818312121291818211010312121392921291818\
29181831211831212131211831212131211839292152393152393173524AAD9494
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6C6CE734A396B524A634A425239316342315A42396B524A\
7B635A6B524A6B524A734A3963524A734A39735A52523931634A425A4239523129
4229215231294229215231295A31295239315231295231295239315239315239315239315A4239\
734A397B6352846352945A52A5735AAD846BBD846BC68C73D69C73D6A58CDEB59C
E7B59CEFBDA5F7C6ADF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7E7DE\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7DECEF7D6BDF7D6C6F7D6BDEFCEB5F7C6ADEFCEB5EFC6ADF7BDB5EFC6ADEFBDA5
EFC6ADEFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B59CEFB5A5E7B59CEFBDA5EFBDA5\
EFBDA5E7B59CE7B59CEFB5A5E7B59CE7BDA5E7AD9CE7AD9CE7AD94DEB59CDEAD94
E7AD94DEAD94E7AD94DEAD94DEAD94DE9C8CDEA58CDEA58CDEA58CD6A58CD69C84D6A58CDEA58C\
D69C84D6A584D6A58CD69C84D6A58CD69C84D6A584D69C84D69C84D69C84D6A584
D69C8CD69C84C69C84D69C84C69C84C69C84CE947BC68C73B58C73BD846BB58C73AD846B8C7363\
9C6B527B63526B524A634231523931523931523129392921422921392921392931
422921392921312121392921392931312121312121291818291818392921392921392921291818\
3121212918183121213121183929213929215231294229215A423973524AC6ADA5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7EFE7E7CEB5B5634A427B635A634A42523931634231634A42634A42\
6B524A6B524A6B524A6B524A6B524A6B524A73524A634A42634A42634A42523931
4229214229214229215231295239315239315231295231295239315239316342315A42395A4239\
634A42734A398463529C6B52846B5AB57B63B5846BC68C73CE947BD6A58CE7B59C
E7BDA5EFBDA5EFCEB5F7CEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7E7DE
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6EFCEB5EFC6ADF7BDB5EFC6ADF7CEB5EFCEB5EFBDA5EFC6AD
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B594EFBDA5E7B59CEFBDA5E7BDA5E7BDA5E7B59CE7B59C\
E7B59CE7B594E7B59CE7B59CE7B59CE7B59CDEB5A5E7AD94DEAD94DEB59CE7AD9C
DEB59CDEB59CDEAD94DEAD94DEAD94DEA58CDEA58CD69C8CD69C8CDEA58CD69C8CD69C84D6A58C\
D69C84D6A58CD69C8CD6A58CD6A584D69C8CD69C84D6A58CD69C84D69C84C69C84
D69C84D69C84C69C84D69C8CC69C84CE947BC6947BC6947BB5846BAD846BA5735AA5735AA5735A\
846352734A39634231634231523931523129523129523129392921392921392921
392921392921523129523129392921392921422921422931392921392921312121312121312118\
2918183121213121213929214229214229213929214229215239318C6352D6C6CE
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFDECED6846B5A73524A634A42634231523129634231634A42\
735A5273524A6B524A6B524A73524A6B524A634A42634A42634A42734A39523931
5231294229214229215231295239316339315239315231295231295239315239316B524A734A42\
6B524A734A428463528C7363945A52A5735AAD846BB57B63C68C73CE947BDEAD94
E7B59CE7BDA5EFBDADF7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECE\
F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFCEB5EFC6ADEFC6ADEFC6ADEFBDA5
EFBDA5EFBDA5E7B59CE7B594E7AD94E7B59CE7B594E7AD94E7B594E7B594E7B59CE7B59CE7B594\
E7B59CEFB5A5E7B59CE7B59CE7AD9CE7B59CE7AD9CDEAD94DEAD94DEB59CE7AD94
DEAD94DEAD94E7AD94DEAD94DEAD94DEA58CDEA58CDEA58CD69C8CDE9C8CD6A58CD69C8CD6A58C\
D69C8CD69C8CD69C84D6A584D6A584C69C84D69C84D6A584C69C84D69C84D6A584
D69C84D69C84C69C84CE947BC6947BC68C73CE8C6BB57B63AD735A9C7363A5735A94634A7B6352\
8452426B524A6342316342314A3131523129523129523129422931422921392921
523129523129422931392921523129422931392921392921392921312121312121312121392921\
523129392921392921312118211010291818392921523129846B5ADECED6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7DECED673524A734A426B524A5A42395A3129523931634A42\
634A4273524A735A526B524A73524A735A52634A426B524A523931634A42634A42
5A31294229214229215231295231295A42395239316339315231295231295239315A4239734A42\
73524A7B6352846352A5735A846B5AA5735AA5735AB57B63BD846BCE9473D6A584
DEAD94E7B59CEFC6ADEFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6BDEFCEB5F7C6ADEFC6ADF7C6ADEFC6ADF7C6ADF7C6ADEFBDA5
EFBDA5E7B59CE7B59CE7B594E7B59CE7B594E7B59CE7B59CE7B59CE7B59CE7B59CEFBDA5E7AD9C\
EFBDA5E7B59CE7B59CE7B59CE7AD9CE7B59CDEB59CE7AD9CDEAD94E7AD9CDEAD94
E7AD94DEAD94DEB59CDEAD94DEAD94DEAD94D69C8CD69C84DEA58CD6A58CDE9C8CD6A58CD6A58C\
D6A58CD6A58CD6A58CC69C84D6A58CD69C84D6A584D69C8CD69C84D69C84C69C84
D69C84C69C84CE947BC6947BC6947BB58C73B58C73B5846BAD846B9C736394634A8452427B6352\
734A39734A396342315A31295239315231295231294229315231294A3131422931
4A3131523931523129312121312121291818291818312121392921392921392921312121312121\
211010291818312118291818211010392921523129422921A58484EFE7E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7EFE7E7D6C6CE73524A634A42634231634A425A4239523931634A42\
734A3973524A7B635A6B524A6B524A735A526B524A6B524A5A4239634A42634A42
5A42394229214229214229215231296342315A42395239315239315239315239315A4239734A39\
73524A734A42734A428C6352846B5A94634AA5735AAD846BB57B63C68C73D6A584
DEA58CDEB59CEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7E7DE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDEFCEB5EFCEB5F7BDB5F7CEB5EFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFBDA5
EFBDA5E7B594E7B594E7B59CE7B59CE7B59CE7B59CEFBDA5E7B594E7B59CE7B59CE7B59CE7AD9C\
E7B59CE7B59CE7B59CE7B59CE7B59CE7AD9CDEAD94E7AD9CE7AD9CDEB59CE7AD94
E7AD9CDEAD94E7AD94E7AD94DEAD94DE9C8CDEA58CDE9C8CDEA58CDEA58CD6A58CD6A58CD6A58C\
D69C8CD6A584D69C8CD6A58CD69C8CD6A58CD69C84D6A584C69C84D69C84CE947B
D6A584CE947BC69C84C6947BC68C73BD846BB57B63AD735A9C73638C63528452427B6352734A39\
734A39634231634231523931523129523129422921422921422921392921523129
422921422921422931312121291818291818392921392921291818291818211010291818291818\
291818211010312121211010392921523129422921523931BDA59CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7DECED67B635273524A5A4239634A425A4239634231734A39\
6B524A6B524A7B635A634A42734A39735A52735A526B524A634A42634231634A42
634A424229214229214229215239315231295239315A42395A4239633931523931523931634231\
6B524A7B6352734A398C73638C63528452429C6B52A5735AB57B63BD846BCE9473
DEA58CDEAD94EFC6ADEFC6ADEFCEB5F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5\
F7D6BDF7D6BDF7CEB5EFC6ADEFCEB5EFC6ADF7C6ADEFCEB5F7C6ADEFBDA5EFBDA5
EFBDA5E7B59CEFBDA5E7B59CE7B594EFBDA5E7B59CEFB5A5E7B59CE7B59CE7B59CEFBDA5E7B594\
E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7AD94E7B59CDEAD94E7AD94DEAD94
DEAD94E7AD94DEAD94DEAD94DEAD94DEA58CDEAD94DEA58CDEA58CD6A58CD6A58CD69C8CD6A58C\
D6A58CD69C8CD6A58CD69C84D6A584C69C84D69C84D69C84D69C84D69C84D69C84
C69C84CE947BC69C84C6947BB58C73BD846BAD846B9C7363A5735A8C5A427B6352845242734A42\
734A395A42395231295231295231294A3131422921392921422921392921392921
312118312118422921523129312121312121312121291818291818291818291818291818181010\
291818211010312118291818422921422921422921634231B5A5A5F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7846B5A7B6352734A39634A42634231523931634A42\
634A42634A4273524A6B524A634A4273524A735A526B524A6B524A5A42395A4239
634A425239313929214229215231295A42395239316342315A4239634A425A4239634231523931\
6342317B6352734A428C63528C63528452428452429C6B52B57B63BD846BCE9473
D6A584DEAD94EFC6ADEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6\
F7D6C6F7D6BDEFCEB5F7C6ADF7C6ADEFC6ADEFCEB5F7C6ADEFCEB5EFBDA5EFBDA5
E7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CE7B594E7B594E7B594E7B59CE7B59CE7B59C\
E7B594E7B59CE7B59CE7AD94E7AD94E7AD9CDEAD94E7AD9CE7AD94DEAD94E7AD94
DEA58CDEAD94DEAD94DEAD94DEA58CDEA58CDEA58CD69C84DE9C84D69C8CDEA58CD6A58CD6A58C\
D69C84D6A58CD6A58CD69C84D69C8CD69C73C69C84D6A584C69C84D6A584C69C84
D6A584C6947BC6947BC6947BB58C73AD846BAD846BA5735A8C5A42846352845242734A39634231\
634231523931523931523931523129523129523129422921392921312121312118
312118312121392921392921523129392921291818181010211010312118291818211010291818\
211010291818312118312118392921422921523931734A39CEB5ADFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7DECED68C736B73524A634A425A42395A4239523931734A39\
734A39634A426B524A7B63526B524A6B524A73524A6B524A634A42634A425A4239
634A426342315231294229213929215239316342315239315A4239634A42634A42523129523931\
634231734A3973524A73524A7B63527B63528452399C6B52AD735AB57B63CE9473
D69C84DEA58CEFC6ADEFC6ADEFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6BDEFCEB5F7CEB5EFCEB5EFC6ADF7CEB5EFC6ADEFC6ADF7C6ADEFBDA5E7B59C
E7B59CEFBDA5E7B59CE7B594E7AD9CE7B594E7B594E7B594E7AD9CE7B59CE7B59CE7B594E7AD94\
E7B59CE7AD94E7B594E7AD9CE7B59CE7B59CE7B59CE7AD94DEAD94E7AD94DEAD94
E7AD94DEAD94E7AD9CDEA58CD69C8CDE9C8CDE9C84DE9C84D69C84DEA58CD6A58CD69C84D69C8C\
D69C84D6A584D69C84D6A584D69C84D69C84D69C84D69C84D69C84D69C84C69C84
CE947BC6947BC68C73BD846BB5846BA5735A9C6B528C63528C5A4A7B6352734A39734A39634A42\
634231634231523129422921422921422921422921422921422921392921392921
392921392921312121392921312121392921291818291818312121181010181010291818211010\
211010291818291818312118422921523129634231734A42DECED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7E7DEE79C8C8C7B6352634A426342315A42395239315A4239\
6B524A634A42634A427B63526B524A6B524A6B524A634A42634A426B524A5A4239
5A42395A4239523931422921422921422921523129634231523129634231634A425A42395A3129\
5A4239634A4284524273524A734A428452428452429C6B52AD846BAD735AC68C73
D6A584DEAD94EFC6ADEFC6ADEFCEB5EFC6ADF7C6ADF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5\
F7D6BDF7D6BDF7BDB5EFC6ADF7BDB5EFC6ADF7C6ADEFC6ADEFBDA5EFBDA5EFBDA5
E7B594E7B59CE7B59CE7B594E7B59CE7AD94E7AD9CE7B594E7B59CE7B59CE7B59CE7AD9CE7B59C\
E7B59CE7B594E7AD9CE7B59CE7B59CE7AD94E7AD9CDEAD94E7AD94DEAD94E7AD94
DEAD94DEAD94DEA58CDE9C8CDEA58CDEA58CD69C8CDEA58CD69C8CDE9C84DE9C8CD6A58CD6A58C\
D6A58CD6A58CD69C8CC69C84D69C84C69C84D69C84C69C84C69C84C69C84CE947B
C6947BC68C73BD846BAD846BAD735AA5735AA5735AA5735A7B6352734231734A39734A39634231\
634231523129523129422921422921422921312118312118392921392921291818
312121312121312121312121312121312121312118312121291818291818291818211010181010\
211010291818312121392921422921523931634A4273524AFFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B737B635273524A5A42395A42395A4239634231\
6B524A5A4239634A426B524A7B6352634A426B524A6B524A634A425A4239634A42
5A42396342316B524A5239315231294229213929215231296342315239315239316B524A634A42\
5A4239634231734A397B6352734A42734A42734A3984524294634AAD846BBD846B
C68C73DEA58CE7B59CEFC6ADEFCEB5EFCEB5EFCEB5F7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BD\
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6BD
F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BD\
F7BDB5F7BDB5F7CEB5EFC6ADF7C6ADEFC6ADF7C6ADEFBDA5EFBDA5EFBDA5E7B59C
E7AD94E7B59CE7B594E7AD94E7AD94E7AD94E7B594E7B594E7AD9CE7B59CE7B59CE7AD94E7B59C\
E7AD9CE7B59CDEAD94E7B59CE7AD94E7B594DEA58CE7A58CDEA58CE7AD94DEAD94
DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEA58CDEA58CDEA58CD6A58CD6A584D69C84D6A58C\
D6A58CD6A58CD6A58CD69C84D69C84C69C84D6A584CE947BCE947BCE947BC6947B
B58C73B57B63AD846BAD846BA5735A9C6B528C5A4A845242734A42734A39634231634231634231\
523931523129422921422921422921392921392921392921312121392921392921
422921422921392921392921312121211010312121312121291818312118211010181010291818\
211010312118312121523129633931734A39734A39B5A5A5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7A5847B846B5A735A52734A39734A39634A42523931\
735A525A42395A4239734A397B635A634A42634A427B635A634A42523931634A42
634A425A4239634A425A4239392921523129422921422921523129634231634231734A426B524A\
5A42396342315A423973524A73524A734A42734A398452398C5A4A9C6B52B57B63
BD846BC69C84DEAD94EFBDA5EFC6ADEFCEB5F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD\
F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BD\
EFCEB5F7C6ADEFC6ADEFC6ADF7C6ADEFC6ADEFBDA5EFBDA5EFBDA5E7B594E7AD94
E7B59CE7AD94E7B594E7AD94E7B594E7AD94E7AD94E7AD94E7B59CE7B594E7AD94E7A58CE7AD94\
E7B594DEAD94E7AD94E7AD94E7AD94E7AD94DEA58CDEA58CDEB59CDEAD94DEA58C
DEA58CDEA58CDEAD94DEA58CDEA58CDEAD94DEA58CD6A58CD6A58CDEA58CD69C8CD6A58CD6A58C\
D6A58CD6A58CD69C8CC69C84C69C84C69C84CE947BC6947BC6947BC6947BC68C73
C68C73AD846BAD846B9C73639C6B528C5A4A846352846352734A396342315A3129634231523129\
523129422921392921312118312118392921392921312118312121312118392921
392921392921392921422921392921392921312121392921291818181010291818291818291818\
3121183929214229216339315A423963423194736BE7DEE7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B738C73637B635A6B524A5A42395A4239634231\
6B524A634A425A42395A423973524A73524A634A427B635A634A42523931634A42
634A42634A425A42396B524A4221185231295231294229214229215239315A4239634A426B524A\
634A42523931634231634A42734A42734A396B524A734A398C5A4A9C6B52AD846B
B57B63C69C73D6A58CDEAD94E7B59CEFBDA5EFC6ADF7CEB5F7D6BDF7CEB5F7D6BDEFCEB5F7D6BD\
F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7CEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7BDB5\
F7D6BDEFC6ADEFC6ADF7C6ADEFC6ADEFC6ADEFBDA5E7B594EFBDA5E7B594E7AD94
E7AD94E7B59CE7B59CE7B594E7B594DEA58CE7B594E7B594E7B594E7B594E7B594DEAD94DEAD94\
E7B594E7AD94E7AD94DEAD94DEAD94E7A58CE7AD94DEAD94E7A58CDEA58CDEA58C
DEA58CDE9C84DEA58CDE9C8CDE9C84DEA58CD6A58CD6A58CDEA58CD6A58CD6A58CDEA58CD69C8C\
D69C84D6A584D69C8CD6A584CE947BCE947BC68C73C68C73C68C73C68C73B58C73
BD846BA5735AA5735A9C6B528C5A4A846352845242845242634A426342315A3129523129523129\
523129422921392921312118312118312118312118392921312118392921392921
392921392921392921392921392921392921312121312121392921291818291818312121211010\
2918183929215239315A4239634231734A39B59C9CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B73846B5A846B5A73524A5A4239634A425A4239\
6B524A6B524A5A42395A42396B524A73524A634A42735A52735A525A4239523931
5A42395A42395A42395A42395231293929215231295231295231295231295A3129634231734A39\
634A425A42395239315A31296B524A6B524A734A426342318452428C6352A5735A
B5846BC68C73D6A584E7AD94E7B59CEFBDA5EFBDA5EFCEB5EFCEB5F7C6ADF7CEB5F7CEB5F7D6BD\
F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7BDB5EFCEB5F7BDB5F7D6BDF7D6BDEFC6ADF7C6AD\
EFCEB5F7C6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B594E7B59CE7AD94
E7B594E7B594E7AD94DEA58CE7A58CDEAD94E7A58CDEA58CDEA58CE7A58CE7A58CE7B594E7B594\
DEAD94E7AD94DEAD94E7AD94E7AD94DEA58CDEA58CDEA58CDEAD94DEA58CDEA58C
DEA58CDEA58CDEAD94D6A584DE9C84D6A58CDEA58CD6A58CD69C84DEA58CD6A58CC69C84D69C84\
C69C84C69C84D69C84C69C84CE947BC6947BC68C73C68C73B58C73C68C73B5846B
9C7363A5735A8C73638C63528C6352845239734A39734A39634231634231634231523129422921\
422921422921312118291818312118312118312121312118392921312121392921
312121312121392921392921392921392921392921392921392921291818211010211010211010\
312118422921633931634231523931846352D6BDC6F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C846B5A8C736B846B5A634A425A4239634A42\
634A426B524A634A42634A426B524A6B524A634A4273524A735A52634A42523129
6342316B524A5A42395239315A42395231294229215239315239315A42395239315A4239634A42\
735A52634A425A42395A423963423173524A6B524A6B524A734A39846352A5735A
A5735AB57B63CE947BD6A58CD6A584E7B594E7B59CEFC6ADEFCEB5EFC6ADEFC6ADEFCEB5EFCEB5\
F7CEB5EFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7CEB5F7C6ADEFCEB5F7D6BD\
F7CEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7AD94E7AD94E7B59CE7A58C
E7B594DEA58CE7AD94E7A58CDEA58CDEAD94E7AD94E7AD94DEAD94E7A58CDEA58CDEA58CDEAD94\
E7A58CE7A58CDEAD94E7AD94DEAD94E7A58CDEA58CDEA58CDEA58CDE9C84DEA58C
DEA58CDEA58CDEA58CDEA58CDE9C8CD6A58CDEA58CDEA58CD6A58CD6A58CD69C84D6A58CD6A584\
D69C8CD6A584C69C84CE947BCE947BC69C84C6947BC6947BB58C73B5846BB57B63
AD846BA5735AA5735A9C6B52845242845242734A39734A396342315A3129523129523129422921\
422921422921312118312118312118312118392921312121312118312121392921
422921392921392921312121312121312121291818291818211010211010181010181010291818\
392921523931634231523129734A39846B5ADECED6F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD8C73638C73637B635A735A52634A42634A42\
63423173524A6B524A634A42634A426B524A73524A6B524A735A526B524A5A4239
5A4239634A42634A42523129634A425239313929214229215231295242395A4239734A39634A42\
634A42734A42634A42523931523931734A42734A3973524A845242734A398C5A4A
A5735AAD846BCE9473D6A58CD6A584DEA58CE7B59CE7B59CEFC6ADEFC6ADEFCEB5F7D6BDEFCEB5\
EFCEB5F7CEB5F7D6BDF7D6BDF7D6C6EFCEB5F7CEB5EFCEB5F7D6C6F7D6BDEFCEB5
F7BDB5F7CEB5EFCEB5F7CEB5F7D6BDF7CEB5F7D6BDF7D6BDF7BDB5EFCEB5F7CEB5EFCEB5EFC6AD\
F7C6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7AD94E7B59CE7B59CDEA58C
E7A58CDEA58CE7AD94DEA58CDEA58CE7B594E7A58CDEA58CE7AD94DEA58CE7B594E7A58CE7A58C\
DEA58CDEAD94E7AD94DEAD94DEAD94DEA58CDEA58CDEA58CDEA58CDEA58CD69C84
DE9C8CDEA58CDEA58CDEA58CD69C84DEA58CD6A58CD6A584D6A584D6A58CC69C84D69C8CCE947B\
D6A584C69C84CE947BC6947BC6947BC6947BC68C73BD846BBD846BB57B639C7363
AD846B9C6B528C5A4A8C5A4A7B6352734A39734A396342315A3129523129523129523129523129\
422921392921312118312118291818291818312118312118312121312118312121
392921392921291818312121291818291818211010181010181010181010181010181010211010\
422921634231523129523931734A42A5847BF7E7E7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDC6846B5A94736B947B7373524A734A39634231\
5A42396B524A634A42634A425A4239634A42634A4273524A735A527B635A63524A
523931634A426B524A5239315239315A42395239313929215231295231295239315242395A4239\
734A396B524A6B524A634A425239316B524A6B524A634A4273524A7B6352845242
8C5A4AA5735AB58C73D6A584DEA58CDEAD94E7B59CE7B59CE7BDA5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5F7D6C6
F7D6BDEFCEB5F7BDB5F7D6BDEFCEB5F7C6ADEFC6ADF7CEB5EFCEB5F7C6ADEFC6ADF7C6ADEFC6AD\
EFC6ADEFBDADEFBDADEFBDADEFBDA5E7B59CE7AD94E7B59CE7AD94E7AD94E7A58C
E7A58CE7B594E7AD94DEA58CE7A58CE7A58CDE9C84E7B594DEA58CE7B594E7A58CDEA58CDE9C84\
DEA58CE7B594E7AD94DEA58CE7AD94DEA58CDE9C84DEA58CD6A584D6A584DE9C84
D69C73DE9C8CD69C84D6A584D69C8CD6A584D6A58CD69C84D6A58CD69C8CD69C84D69C84D69C84\
CE947BC69C84CE947BC6947BC6947BC6947BB58C73B58C73B5846BAD846BA5735A
9C6B528C63528C5A4A7B6352734A39734A39734A396342315A3129523129523129523129422921\
422921312118312118291818291818291818291818291818291818312121312121
312118312121211010291818211010181010181010181010181010181010181010181010312118\
5231295239315231295A4239734A39B59C9CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFA584847B63527B6352735A52734A42634A42\
5A4239634A426B524A6B524A634A425A42396B524A5A423973524A6B524A6B524A
5A42395A4239634A425A4239422921422921523129523931523931422921523931523931634A42\
5A4239734A39634A427B63527B635A523931523931634A426B524A6B524A734A39
7B63528C63529C7363B57B63C68C73D6A584D6A58CDEAD94DEB59CDEA58CE7B59CE7BDA5EFBDA5\
EFC6ADEFCEB5EFC6ADEFCEB5F7D6BDEFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5
F7D6BDEFCEB5EFCEB5EFCEB5F7CEB5F7CEB5EFCEB5EFCEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6AD\
EFBDA5EFC6ADEFBDADE7BDA5E7B594DEAD94E7AD94DEA58CDE9C84DE9C84DE9C84
E7A58CDEA58CE7A58CDE9C84DEA58CDEA58CDE9C84DEA58CDEA58CDEA58CDEA58CDE9C84DEA58C\
DE9C84E7A58CDEA58CDE9C84DEA58CDEA58CD69C84DEA58CDEA58CDE9C84DE9C84
D69C84D69C73D69C84D69C84D69C73D69C84D69C73D69C84D69C73C69C84C69C84CE947BC69C84\
C6947BC6947BC68C73C68C73BD846BB57B63B57B63A5735AA5735A9C6B529C6B52
9C6B52845242845242734A39634231634231634231634231523129422921422921422921392921\
312118312121312118291818211010291818291818312121312121312121312121
312121312121291818211010181010181010181010181010181010181010211010291818312118\
5231295231296342315A3129846352DECED6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD8C736384635273524A73524A6B524A\
5A4239634A426B524A6B524A634A425A4239634A42634A426B524A735A5263524A
634A42634231634A425A42394A31313929214A31314A31315239315231294A31315A42395A4239\
634A425A42396B524A6B524A73524A5A4239523931634231734A39734A4273524A
734A397B63529C6B52A5735AAD846BCE8C6BC6947BD6A584D6A58CE7B594E7B59CE7B59CE7B59C\
DEB59CE7BDA5EFC6ADEFC6ADEFC6ADEFCEB5EFCEB5EFC6ADF7CEB5EFCEB5EFCEB5
EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFCEB5EFBDADEFBDA5EFC6AD\
EFBDA5EFC6ADEFBDA5E7BDA5E7AD94DE9C84DEA58CDEA58CDEA58CDE9C84DEA58C
DEA58CDEAD94DEA58CDEA58CDEA58CD6A584DE9C84D6A584DE9C84DEA58CDEA58CDEA58CDEA58C\
DEA58CDE9C84DEA58CDEA58CDEA58CDE9C84DEA58CDEA58CD69C84D69C73D6A584
D69C84D69C84D69C73D69C73D69C84CE947BD69C84CE947BCE947BCE947BC6947BCE947BC6947B\
CE947BC68C73C68C73B58C73AD846BB57B639C7363A5735AA5735AA5735A9C6B52
9C6B52845239734A39734A396342316342315A31295A3129422921422921523129422921392921\
392921312118291818312118291818312118312121291818291818291818291818
291818312121211010211010181010211010181010181010181010181010291818312121523129\
5231295239315A4239633929A5847BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5BD94736B84635273524A73524A6B524A\
634A42634A426B524A6B524A6B524A5A4239634A42634A426B524A735A526B524A
6B524A5239315A4239634A425239315231294229215231294229215231295242395239315A4239\
5A4239634A426B524A6B524A634A427B63525A42395231295A4239634A4273524A
73524A6B524A8463529C6B52A5735A9C7363B57B63BD846BD6A584DEAD94D6A58CD6A58CDEA58C\
DEAD94DEB59CDEB5A5E7BDA5EFC6ADEFC6ADEFC6ADEFC6ADD6C6B5EFCEB5EFC6AD
EFC6ADEFC6ADF7C6ADEFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6AD\
EFBDA5E7BDA5EFB5A5E7B59CDEAD94D69C8CD69C84DEAD94DEA58CDE9C84DEA58C
DEA58CDE9C84DEA58CDE9C84D6A584D6A584D6A584DE9C84DE9C84DE9C84DE9C84DE9C84DEAD94\
DEA58CDEA58CDE9C84DE9C84DEA58CD6A584DEA58CD69C73DE9C84D69C84DE9C84
D69C84D69C84D69C84D68C7BCE947BD69C73CE947BCE947BCE947BCE9473CE947BC6947BC6947B\
C68C73B58C73B58C73BD846BB57B63AD846BA5735AA5735AA5735A9C6B529C6B52
8463527B6352734A39734A396342315239315A31295A3129422921422921422921312121392921\
392921312118312118312118312118291818291818291818211010291818291818
181010312121211010181010181010181010181010181010181010211010312118392921523129\
4229215239315239315A4239D6BDC6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECED6948484846B5A7B635273524A6B524A\
634A42734A396B524A73524A6B524A634A42634231634A4A634A42735A526B524A
634A425A4239634231634A425239314229214229214229215231293121215231295A42394A3131\
5A4239634A42634A426B524A6B524A73524A7B6352524239523129523129634A42
734A4273524A734A428452428C5A4A94634AA5735AB57B63B58C73C68C73C68C73CE947BCE947B\
C69C84D6A58CD6A58CDEB5A5DEB5A5DEB59CDEB59CEFC6ADEFC6ADEFC6ADEFC6AD
E7BDA5EFBDA5D6C6B5EFCEB5E7BDA5EFC6ADEFBDA5EFCEB5EFC6ADEFBDA5E7B594EFBDA5EFC6AD\
EFBDA5E7BDA5E7BDA5E7BDA5DEAD94DEAD94DEA58CC69C84D69C84D69C84DE9C84
D69C84D6A584DEA58CD69C84D69C84D69C73D69C84D69C73D69C84DE9C84D6A584DE9C84DE9C84\
D69C84DE9C84DE9C8CDE9C8CDEA58CDE9C84D69C84D69C84D69C73D69C84D69C84
D69C73D69C73D69C73CE947BD68C7BCE947BD68C7BCE947BC69C73C68C73CE947BC68C73C68C73\
C68C73BD846BBD846BB5846B9C7363A5735AA5735AA5735A9C6B528C5A4A845242
845242734A39734A396342316342315A31295A3121422921422921312118392921422921312118\
312121291818291818211010291818291818291818291818291818181010291818
291818211010211010181010181010181010181010181010181010291818312121523129523129\
5239315239314A211894736BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFB5A5A58C73638463527B6352734A42\
5A4239634A42734A396B524A73524A6B524A5A423963524A634A4263524A735A52
63524A63524A5239315A42395239315231293929213929215231295231294229216B524A634A42\
5231295A42395A4239634A426B524A634A4273524A846B5A6B524A5A4239523931
634231734A427B6352734A428452428463528C63529C6B52A5735AA5735AB57B63B57B63C68C73\
C6947BCE947BD6A58CDEAD94DEAD94D6A58CD6A58CDEAD94DEAD94DEB5A5DEB5A5
DEB59CE7BDA5E7BDA5DEB59CE7BDA5E7BDA5E7BDA5EFBDADE7BDA5E7B59CE7B59CE7B59CEFBDA5\
E7BDA5E7BDA5E7B59CDEB59CD6A58CD69C84C68C73CE8C6BC68C73CE9473CE947B
D69C73CE8C84D69C73CE947BCE8C73D68C7BD69C73D69C84D69C73D6A584DE9C84D69C8CD69C84\
D69C73D69C73D69C73D6A584D69C84D69C84D69C84D69C84D69C84D69C73D69C84
D68C7BD68C73D68C7BD69C84CE947BCE947BC69C84CE947BCE947BCE947BC6947BC68C73B58C73\
C68C73B58C73B5846BAD846BB57B63A5735AA5735294634A845242845239845242
845242734A396342316339295A3129523129422921422921422921422921312118312121291818\
421810291818291818312121211010291818291818312121312121291818291818
211010211010211010181010181010181010181010181010211010312121422921523931422921\
5231294229215A3129CEB5B5FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEBDC694736B846B5A7B635A73524A\
634A425A4239634A426B524A73524A634A42634A42634A42634A42634A42735A52
735A52634A425A42395A42396342314A31315231293929215231295231293929215239316B524A\
6B524A5A42395A42395A42395A42396B524A6B524A6B524A846B5A73524A634A42
523931634231734A427B63527B63528463528463528463528463529C6B52AD7B6BAD735AB57B63\
B58C73C6947BB58C73DEAD94D6A58CC6947BD6A58CD6A58CDEAD94DEAD94D6A584
DEB5A5DEAD94DEAD94DEAD94DEB5A5E7B59CDEB59CE7B59CDEB59CE7AD94DEAD94E7BDA5E7BDA5\
E7B59CDEAD94DEAD94D6A58CC69C84CE9473BD846BB5846BB57B63BD846BBD8463
BD846BCE8C6BCE9473C68C73CE8C6BCE9473D68C7BD69C73D69C84D68C7BCE8C6BD69C73D69C84\
D68C7BCE9473CE8C6BD68C73D69C73D68C7BD69C73D69C84D69C73D69C84D68C7B
D69C73CE947BCE947BCE947BCE947BCE947BC68C73C68C73C68C73C6947BC68C73C68C73BD846B\
B5846BB5846BB57B63AD846B9C6B529C6B528C5A4A8C5A4A8452428452427B6352
734231734A39634231523931523129523129422921422118422921312121211010312118312118\
291818291818291818291818291818291818291818291818312121312121291818
211010211010181010181010181010181010181010181010291818392921523931422921422921\
523129422921845242EFE7E7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE947B73846B5A7B635273524A\
634A425A42395A42396B524A6B524A6B524A6B524A634A42634A42634A4A6B524A
735A52634A42634A425A4239524239524239523129392921392921422921523129392921523931\
6B524A7B635A6B524A634A42634A426B524A6B524A634A426B524A73524A73524A
6B524A634A42634231734A39734A4273524A846352846352945A529C7363B57B639C73639C7363\
B58C73B58C73C6947BBD9C8CC6947BC6947BC6947BDEAD94BD9C8CD6A584C69C84
D6A58CBD9C8CC69C84D6A58CDEAD94D6A584DE9C84DEAD94DEB59CDEAD94D6A58CE7B59CDEB59C\
DEB59CDEAD94D69C8CC6947BC6947BAD7B6BB57B63B5846BB57B63AD735AB5846B
BD846BBD8463BD8463BD846BCE8C6BCE8C73CE9473CE9473CE947BD68C73CE8C73CE9473CE947B\
CE9473CE8C73CE8C73CE9473CE9473CE947BD69C84CE947BD68C7BCE947BD69C73
CE947BCE9473CE8C73C68C73C68C73C68C73CE8C6BBD846BC68C73C68C73C68C73B58C73BD846B\
B5846BB57B639C73639C73639C6B528C5A4A8C5A4A8C5A42845242845239734A39
734A39634231634231523129523129422921422921422921312118421010312118312121312118\
312118291818291818291818291818211010211010291818291818291818211010
211010211010181010181010181010181010181010291818392921523129523129422921523129\
422921523931947B73F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFAD94948C63527B635A7B6352\
6B524A5A4239634A42634A426B524A735A526B524A524239634A42634A42634A42
735A52634A42634A425A42395231296342314A3131523129422921392921422921523129422921\
4A31315A4239735A527B635A735A525A42396B524A634A426B524A6B524A6B524A
6B524A6B524A6B524A734A42734A42734A4273524A846352846B5A846B5A8C73639C73639C7363\
9C7363C6947BAD847BC69C84B58C73C68C73B58C73C6947BC6947BB58C73B58C73
D6A584C6947BC69C84C69C84C69C84C69C84C69C84D6A58CDEAD94D69C8CD6A584DEAD94DEB59C\
DEB59CC69C84C6947BC6947BBD846BAD846BA5735AB57B639C73639C6B52AD735A
AD735AB57B63B57B63BD846BB57B63BD846BCE8C6BCE8C73CE8C6BBD846BCE8C6BCE8C73CE8C73\
CE8C73CE9473CE8C73CE9473CE9473CE8C73CE9473CE9473CE947BCE9473C68C73
CE8C6BCE9473C68C73CE8C6BC68C73BD846BCE8C6BC68C73B58C73BD846BB58C73BD846BB57B63\
B57B63AD846BAD846B9C6B5294634A8C5A4A8C5A42845242734A42845239734A39
734A395A31295231295A3121523129523129523129422921392921312118312118312118312121\
312118291818291818291818291818211010211010211010291818291818211010
1810101810101810101810101810101810102110103121214229214A31314229214A3131523129\
422921734A42CEB5ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6DEA5847B8C73637B6352\
73524A634A42634231634A42634A426B524A6B524A634A42634A425A42395A4239
634A42735A526B524A634A424A3131422921523931523931523129392921422921523931524239\
5A42395239315A42395239315A4239735A52735A5263524A73524A634A425A4239
634A42735A526B524A73524A735A527B63527B63527B635A8463528463528C5A4A8463528C6352\
A5735AAD846BAD846B94736B9C73639C7363AD846BAD846BB58C73AD846BB57B63
9C73639C7363AD846BAD846B9C7363B5846BB5846BC68C73C6947BD6A58CBD9C8CC6947BC6947B\
C69C84BD846B9C73639C73639C73639C6B52945A529C6B52A5735AA5735A8C7363
A5735AA5735A9C6B52A5735AA5735AB5735ABD8463BD8463BD8463C68C63C68C63BD846BC68C63\
C68C73CE8C6BCE8C6BC68C73CE8C6BCE8C6BC68C73BD846BBD8463B57B63BD846B
BD846BBD8463BD846BBD846BBD846BBD846BBD846BB57B63B5846BB5735AB5846BB57B63A5735A\
A5735A9C6B529C6B52A5735A8463527B6352845239734A42634231634231634231
5A3129523129422921523129422921523129523129392921392921312118291818291818312118\
291818291818291818211010211010211010181010181010181010181010181010
1810101810101810101810101810101810103121215231295231294229214A3131422921422921\
73524AB59C9CF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFAD8C8494736B846B5A\
735A526B524A634A425A4239734A396B524A6B524A634A425A4239634A425A4239
634A427B635A6B524A6B524A5242395231295231295239314A3131392921523129523129634231\
5A4239634A425A4239634A42634A4A6B524A7B635A735A52735A52735A5273524A
6B524A634A427B635A735A52634A42735A52735A527B635A735A527B63527B63528463528C6352\
9C73639C73638C73639C6B52A5735A94736B9C736394736BAD846BA5735A8C7363
8C7363A5735A9C7363AD846BA5735A9C7363A5735AAD846BB58C73C69C84D6A584C69484B58C73\
B58C73AD846BAD846B9C73639C6B529C6B52846B5A9C6B528452428C63528C5A4A
94634A8C5A4A8C635294634AA57352AD735AB5735AAD735AB5735ABD8463BD8463B57B63BD8463\
BD846BBD8463BD846BCE8C6BBD846BBD8463BD8463BD846BBD846BBD846BB57B63
AD735AB57B63B57B63B57B63B5735AB57B63B5846BB57B63B57B63B57B63AD735AAD846B9C7363\
A5735A9C6B528C63528C5A4A8452428452428452397342316342315A3129634231
5A3129422921523129422921422921422118422921422921312118312118312118291818291818\
291818291818291818211010211010211010181010181010181010181010181010
1810101810101810101810101810102110105231295231293929214A3131422921422921523129\
94736BEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5B5947B738C7363\
73524A6B524A634A42634A42634A426B524A73524A634A42634A4263524A5A4239
5A4239735A52735A52634A425A4239423139392921523129523931523129523129422921523931\
634A425A423963524A5A42396B524A735A5263524A6B524A6B524A6B524A6B524A
6B524A73524A6B524A735A527B635A735A527B635A7B635A846B5A7B6352846352846B5A8C7363\
8C7363846B5AA5735A9C6B52846B5AA5735A8C7363A5735A8C7363A5735A9C6B52
A5735A8C7363A5735A9C7363A5735AA5735A9C6B52AD846BA5735AAD846BB58C73C69C84B58C73\
9C73639C73639C7363AD7B6B9C7363846B5A8C63528C63528C63527B6352845242
8463528C5A4A8C63528452428C5A4AAD735AA5735AAD6B52AD6B52AD735AB57B63B5735AB57B63\
B57B63BD8463BD846BBD8463BD846BBD846BB5846BBD846BB5846BB57B63B57B63
AD735AAD735AA5735AA5735AAD735AA5735AAD735A9C7363A5735A9C7363A5735AA5735AA5735A\
9C6B528C63528C5A42845242845239634231634231634231634231634231634231
5231295A3121523129422921422921392921422921422921312118312121291818291818291818\
312121312118211010181010211010181010211010181010181010181010181010
1810101810101810101810101810102918184A3131422921422921422921392921422921523931\
B5A5A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE9C8C8C947B73\
735A526B524A734A39634A42634A42634A426B524A6B524A5A423963524A63524A
524239634A427B635263524A5A42395239315231293929215231295A42394A3131523931523931\
5A42396342316B524A735A5263524A6B524A735A527B635A6B524A5A52526B524A
634A4273524A7B635A7B635A846B5A846B5A7B635A735A52735A527B63528C6352846B5AA5735A\
8C63527B6352846B5A846B5A8C73638463528C63528C63528C63528C6352846352
8C63528C63528C5A4A9C6B529C6B529C6B528C5A4AA5735AA5735AA5735AA5735AA5735AAD846B\
9C7363A5735A846B5AA5735A9C7363846B5A8463528463528463528452427B6352
8452427B63528C5A428463528452429C6B5294634A9C6B529C6B52AD735AA57352AD6B52AD735A\
AD735AAD735AB5735AB57B63B5846BB57B63AD846BAD735AAD846BA5735AA5735A
A5735AA5735AA5735AA5735A9C6B52A5735AA5735AA5735A9C6B528C63529C6B529C6B529C6B52\
8C63528452427B6352845242734A39734A396342316342315A31295A31295A3129
523129523129422921422921422118312118392921422921291818312118291818291818211010\
291818291818291818211010211010181010181010181010181010181010181010
1810101810101810101810102918183929214229214229214A31313929213929215A3129633931\
DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFC6ADBDA5847B\
7B635A7B63526B524A634A42634A42634A42634A426B524A634A425A4239634A42
634A42634A426B524A6B524A5A42395A42394A31315231294229315231295A4239523931523931\
634A426B524A6B524A735A52735A52735A526B524A7B635A7B635A7B635A7B635A
5A525263524A7B635A7B63527B635A7B635A7B635A8C736B7B635A846B5A846352846B5A8C7363\
73524A846B5AA5735A8463528463528463527B63527B6352734A427B63528C6352
734A428452428463528463528463528C5A427B63528C635294634A9C6B528C63529C6B529C6B52\
A5735A8C63528C63528463528463528C63527B6352734A427B63528452427B6352
845242734A42734A428C5A4A8452428452428C5A4284524294634A94634AA57352A56B52A5634A\
A57352AD6B52AD735AA57352A57352A57352A5735AA5735A9C6B529C6B529C6B52
A5735A9C6B529C6B529C6B529C6B529C6B529C6B529C6B529C6B529C6B528C5A4A8C5A4A9C6B52\
8C5A42845242845242734A39734A39734A396342316342315A31295A3121523129
5231294229214A2118312118312118392921392921312118291818291818291818291818211010\
211010291818181010181010181010181010181010181010181010181010181010
1810101810101810102918183121215231293929215239314229213929215231295A3129846B5A\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7AD9CA5\
846B5A73524A73524A634A42734A39634A42634A426B524A634A425A4239634A42
63524A634A4263524A735A52634A425A42395239314229213929215242395239315239315A4239\
5A42396B524A6B524A735A527B6352735A527B635A735A526B524A735A52735A52
7B635A735A52634A42735A527B635A8C73638C7363846B5A846B5A8463528C63528C7363846B5A\
846352846B5A8C63527B6352845242734A42734A4273524A734A3973524A8C7363
734A398463527B6352845239734A427B63528452428463528452428463528463528463528C6352\
846352846B5A7B635273524A7B63527B635284635273524A73524A73524A73524A
845242734A42734A426342318452398452428452398452428452428463528C5A428C5A429C6B52\
9C6B529C6B5294634A9C6B529C6B529C6B5294634A94634A8C5A4A8463528C5A4A
9C6B5294634A8C5A428463528C5A428C5A4A94634A8C63528C63528C5A4A8C5A4A845242845242\
8452427B6352734A39734A396342315A31295A31295231295A3121523129523129
523931422921392921312118312118312118312121312118312118211010291818312118291818\
291818181010291818211010181010211010181010181010181010181010181010
181010181010211010291818422921523129523129422921312121422921633931633931AD8C84\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFC6ADAD\
8C736B73524A73524A6B524A634A42634A42634A426B524A6B524A634A425A4239
634A42634A4A634A42735A52634A425A42395239315231295231294231395239315A42395A4239\
5A42395A4239634A42735A527B635A846B5A846B5A7B635A735A52735A526B524A
735A526B524A634A42634A426B524A73524A6B524A6B524A7B63528463528C63528C736373524A\
73524A7B635273524A7B6352846352634A42734A39634A42734A3973524A7B6352
6B524A734A42734A397B63527B63527B6352734A427B6352734A428452427B63528452427B6352\
8463527B63527B63527B6352735A5273524A73524A734A42734A39734A39634A42
734A426B524A734A39734A39634231734A39734A39845242845239845239845242845239845242\
8452428452428C5A428C5A4A846352845242845242845239845242845242846352
8C5A428452427B6352845242734A39734A39734A398452428452398463528452428452427B6352\
734A42845239734A396342316342316342315A31295231295A3129523129422921
523129422118392921392921312118291818312118312118392921291818291818291818211010\
291818211010211010181010181010181010181010181010181010181010181010
1810102110102918183929215231293929215231293121213929216339315A3129633931CEB5B5\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7\
AD94948C736B735A5273524A634A42634A42634A42634A426B524A6B524A634A4A
5A423963524A63524A634A42735A52634A42634A425A423952393142292152393163524A6B524A\
63524A634A42735A527B635A7B635A7B635A735A526B524A73524A846B5A7B6352
735A52735A52634A42634A4273524A735A527B63527B63528463527B6352846B5A73524A7B6352\
8C63527B6352734A3984524273524A734A39734A395A4239634A4273524A6B524A
5A4239734A39634A42734A4273524A73524A63423163392973524A734A42734A39734A427B6352\
7B6352734A39634231634A42734A42735A52634A42634A42634A425231295A4239
6342316342315A4239734A395A4239633929634231634231634231634231634231634231734A39\
734A39734231734A39734231734A39734A39734231734A39734A39734A39734A39
734A395A4239634231634231634231734A39634231633929634231634231634231734A39634231\
6342316342315239316339295A31295A31214229214229214A2118422921422921
392921422921312121312118291818291818291818312118312118312121312121291818291818\
291818291818181010181010211010181010181010181010181010181010181010
291818312121422921392921422921523931312121523129523931633929734A39CEB5B5FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7\
AD9494A5847B7B635A73524A6B524A6B524A634A425A42396B524A6B524A63524A
5A4239634A4263524A634A42735A52735A52634A42634A425A42395242395239316B524A735A52\
7B635A6B524A735A527B635A7B635A7B635A7B635A7B635A735A526B524A735A52
7B635A7B635A735A526B524A634A42734A4273524A73524A7B6352846B5A846B5A6B524A734A42\
7B63526B524A734A396B524A734A395A4239634A426342315A4239634A42634A42
5A42395A4239634231634A426B524A73524A634A425A4239734A397B63526B524A6342316B524A\
734A4273524A634A42523129523931634A42734A39634A425A4239523931523129
5239315239315A31295239316342315231295A31295A31296342315A3129634231734A39634231\
734A396342315A31296342316342316342316342316342315A4239634231634231
634231634231634231633929634231734A395A31296342316342315A31295A3129633929634231\
6342316342315A3129523129523129422921422921422921422921422921312118
422921422921312118291818291818291818291818312121291818312118421810291818291818\
211010211010181010211010181010181010211010181010181010181010291818
3121214229213929214229214A31314229215231295231295A3129633931AD847BF7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7\
C6ADAD9484848C736B73524A73524A634A42734A39634A425A42396B524A6B524A
634A42523931634A4263524A634A426B524A6B524A634A42634A425A42395A42395A42396B524A\
8C73637B635A7B635A735A527B635A846B5A8C736B7B635A7B635A7B635A735A52
6B524A73524A634A425A42396B524A6B524A734A42734A42734A42AD846B846352634A42845242\
6B524A734A396B524A734A396B524A5A4239634231634A425A42395A4239634A42
5239315A4239523931734A39634A426B524A5A423973524A5231296B524A73524A634A42634A42\
6B524A634A42734A39634A425A42395242395A42395A42395A42395A4239523129
5231295239315239315239315239315231295231295231295231295A31295A31295A31295A3129\
6342316342315A3129634231634231634231634231634231633929634231523129
6342316342316339295231295A31295A31296342315A31295A31295A31295239315A3129523129\
6342315A3129634231523129523129523931422921392921422921422921392921
312118422921392921291818291818291818291818312118291818291818291818211010291818\
181010181010211010181010181010181010181010181010181010181010312121
4229314229213929214A31314229213121215A31296B524A634A429C7363D6C6DEF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
D6C6D6AD9494947B737B635A73524A6B524A634A426B524A5A4239634A426B524A
634A4A5A42395A423963524A634A4263524A6B524A6B524A6B524A634A42634A425A4239524239\
73524A7B635A7B635A7B635A735A52735A527B635A846B5A8C736B7B635A73524A
6B524A634A426B524A6B524A73524A73524A6B524A734A427B63528C736373524A734A427B6352\
634A42734A39734A398452426B524A523931634A42634A425A42395A4239634A42
5A4239634A42523129634A42634A426B524A6B524A634A425A42395231296B524A734A39634A42\
634A4273524A5A42395239315239316342315239314A3131523931523129523931
5239314229215231295231295231295231295231295231295231294229215231295231295A3121\
5A3129634A425A3129523129523129634231634231523129523129523129523129
5A31295A31295239315231295231295231295A31295A31295231295231295231295231295A3121\
5231295231295231295231294229214229214A2118422921392921312118392921
392921312118392921312121211010211010211010291818312121211010291818291818291818\
291818211010211010181010181010181010181010181010181010211010392921
42292139292152312952312939292139292152393173524A734A42CEB5ADFFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DECED6C6ADADAD9C8C947B7373524A6B524A634A426B524A634A42634231634A42
6B524A634A42524239634A4263524A634A42634A425A52527B635A735A526B524A5A52525A4239\
5A42396B524A7B635A8C73637B635A63524A735A527B635A7B635A7B635A7B635A
7B635A8C73637B635A7B635A735A5273524A7B63526B524A73524A846B5A734A39734A396B524A\
6B524A734A39634A4273524A6B524A523931734A39634A42634A42634A42634A42
5242395A42395242395A4239634A426B524A6B524A523931634A425231295239316B524A634A42\
634231634A425A42396342315239315239315239314A31315231295239314A3131
4A31314A3131422921523129422921523129523129523129523129422921422921523129422921\
4229215A3129523931422921523129523129523931523931523129523129523129
5231294229215231295A3129523129523129422921523129523129523129422921523129523129\
523129422921523129523129422921422921312118422921392921392921312118
312118291818392921312121291818211010211010291818291818291818181010211010211010\
291818181010181010181010181010181010181010181010291818312121422921
3929215231295231293121213121215231295A3129734A42AD847BF7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
E7DEE7CEB5B59C8C8C9484847B63526B524A73524A6B524A634A42634A42634A42
634A426B524A634A42634A42735A52634A42634A42634A426B524A7B635A735A52735A527B635A\
6B524A5242395A42396B524A7B635A7B635A735A52735A52735A52735A526B524A
6B524A6B524A6B524A73524A6B524A6B524A6B524A73524A846B5A845242634231634A426B524A\
734A39634A425A4239634A425A42395A42395A42395A42395A4239634A42634A42
6342315A42395A42395231296B524A634231634A42523129634A426342314A3131634A42634A42\
5A42395A42395239314A31315231294A31315231293929215231295239314A3131
422921422921422921392921422921422921523129422921422921523129392921523129422921\
392921422921523129523129422921523129523129523129523129523129523129
422921523129523129422921523129523129523129523129523129422921422921523129422921\
4229214229214A2118422921422921312118422118312118312118312118312118
312121312118291818312118211010211010181010291818291818211010291818181010291818\
211010181010181010211010181010181010181010291818291818392921392921
5231295239313929213121215231294229217B6352AD9494D6C6CEF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
E7DEE7D6C6CEB5A5A5B5A5A58C736B6B524A6B524A634A42734A396B524A634A42
634A42735A5263524A5242396B524A5A5252634A425A4239634A4263524A7B635A7B635A7B635A\
7B635A8C736B6B524A5A4239634A42735A526B524A735A52735A526B524A634A42
5A4239523931523931634A426B524A73524A73524A734A428463526B524A634231734A396B524A\
734A39734A42634A42634A42634A42634A42634A42634A425242395A423963524A
5A4239524239634A424A313173524A5A42395242395A42394A3131634A424A31314A3131524239\
5A42395231294A3131523129523129523129422931523129422931422921422921
422921392921392921422921392921422921422921523129422921422921422921392921523129\
422921392921422921523129392921422921422921422921422921392921523129
422921392921523129422921422921523129422921422921523129523129422921422921422921\
422921312118422921422921422921392921312118312118312118211010291818
312118312121312118312121291818211010181010291818291818312121211010211010181010\
2918182918181810101810101810101810102918182918183929213929214A3131
5239313929213121214229215231294A2118A58484D6C6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7E7DEE7D6C6CE9C8C8C947B738C736373524A634A42634A42634A42734A39
634A425A42396B524A735A52634A4263524A6B524A63524A5A42395A42395A42398C73637B635A\
8C73637B635A7B635A8C7363846B5A634A42523931634A42735A525A5252735A52
7B635A7B635A7B635A735A52634A4A634A42634A42734A427B63525A3129523931634A42634A42\
6342315A4239634231634A42634A425242395A4239634A4A524239634A426B524A
523129524239634A425242395239316B524A5231296342314A31315231295239314A3131524239\
3929214A3131523129312121523129523129392921422931422931392921392921
392921392921392921392921392921392921392921392921422921392921422921422921523129\
422921422921422921422921523129422921523129422921523129392921392921
3121185231293121185231293929213121184A2118523129422921523129312121392921422921\
392921392921392921312118422921422921392921312118291818291818211010
211010291818211010291818291818181010181010211010181010211010291818181010181010\
181010211010181010181010291818291818392921392921312121422921392921
291818422921523931422921422921AD8C84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFDECED6CEBDC6A5848494736B7B635A6B524A5A4239634A426B524A
6B524A634A42634A42735A525239315A42395A4239634A4263524A5242395239315A5252735A52\
7B635A7B635A7B635A7B635A7B635A7B635A634A4A5242395242395A4239735A52
7B635A8C736B8C73637B635A7B6352634A42634A42734A42734A42422921634231634A425A4239\
5A42395A42395A4239523931634A42523931634A42634A42634A42634A426B524A
523129523931422931634A424229316B524A5242394A31314A3131523129422931392921523129\
4231394229314A3131523129392921422931422921392921392921392921392921
312121392921392921312118312121392921392921392921392921422921392921422921422921\
392921312118422921422921422921422921312118523129422921422931392921
3121183121183929213929213929213121183121184A2118422921422921312121312121422921\
392921312118312121312121312118422921392921312121312121392921312121
291818211010291818291818291818211010211010291818181010181010181010291818181010\
181010181010211010291818312121392921392921392921422921523931312121
4229215231294229216339318C6352DECED6EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEE7DED6E7CEBDC6AD9494947B736B524A634A425A4239634A42
6B524A634A42634A4263524A634A42524239634A42634A426B524A63524A5A42395A4239634A42\
6B524A735A52735A527B635A7B635A7B635A7B635A7B635A735A527B635A735A52
634A425A4239634A42634A425A4239634A42734A396B524A6B524A4229215A31296342315A4239\
634231634A425A4239523931523931523931523931634A42634A425A4239634A42
4229315231295231295A42394A3131634231634A424229313929213929215231294A3131312118\
4A3131523129423139523129392921392921422921392921392921422921392921
392921312121312118392921312118312121312118392921392921312121392921392921392921\
422921312118392921422921422921422921312118392921422921523129392921
312121312118312118421810392921312118312118312118392921392921422921312118312121\
422921312121291818291818312121392921392921312121312118392921312121
312118291818211010291818291818181010211010211010181010181010181010181010291818\
291818181010291818312121392921312121312121422921523931392921523129
5231295231296339318C7363AD9CB5F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7DECED6DED6E7CEBDCE9C8C8C734A42634A42634A42634A42
6B524A6B524A6B524A634A426B524A634A425A4239634A42634A42634A4263524A5A4239524239\
524239634A426B524A735A52735A527B635A7B635A7B635A7B635A735A526B524A
63524A63524A63524A6B524A5A4239634A426B524A73524A734A39523129523931523931523931\
634A42634A42634A425A42394A31314A31315242395A42395A42395A42395A4239
423139523129422931523129524239523129634A425231294A3131392921422931422931523129\
312121392921422931422931523129392921392921392921312121392921392921
392921312121312121312121312118312118312121312118392921392921312121312121392921\
422921312121312118392921392921392921422921312118392921523129392921
291818392921312118291818312118392921312118312118422921392921422921312121312118\
392921312118312121291818291818392921392921312118312121312118312121
312121291818291818181010291818291818291818211010181010181010181010181010291818\
291818312121312121392921312121312121422921523931392921312121422921
5231295A3129845242BDA59CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFE7DEE7DECED6C6ADAD7B63526B524A5A4239734A39
634A426B524A735A526B524A63524A6B524A52394A5A42395A4239634A42634A4A5A4239735A52\
735A5263524A63524A63524A634A426B524A7B63528C73637B635A735A525A5252
7B635A7B635A735A525A52525A42395A4239634231634A425A4239422921523931523129523931\
5A4239734A39634A425A42394A31315231294A31315A42395239315242395A4239
5A42394A31314A31315231294231394229315A42393929214A3131392921392921422921422931\
3121213929213121215231294A3131523129392921392921392921291818312121
312121312121422918312121312121312118291818291818312121392921392921392921422921\
392921392921291818312118392921392921392921312121312118422921422931
312121291818392921312121312118392921392921312118312118422921422921312118312118\
312121291818291818291818291818291818312121312121291818291818291818
291818291818181010181010181010211010181010181010181010181010181010211010291818\
291818312121392921312121312118422921523931312118392921523129523129
5A4239734A42AD9494F7F7F7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFDECED6D6C6D6846B5A7B6352634A425A4239
5A42396B524A6B524A634A426B524A735A5263524A5A4239634A42634A4263524A634A4A634A42\
6B524A7B635A735A5263524A634A4A634A425A4239634A42735A527B635A735A52
7B635A7B635A8C736B735A52634A42634A425239315A4239634231523129523129523129523129\
5239315A4239634A425A42394A31315231294A3131634A42423139523931634A42
5A42394A31314231394A31315242394229214A3131392921422921423139392921422921422931\
5231293121213929213121213929214A3131422931392931312121312121291818
312121312121312121312121291818312121291818291818291818392921392921392921392921\
392921312118312118291818312118392921392921392921312121312118523129
392921211010312121312121291818291818392921312121291818392921392921312121312118\
312121291818291818312121312121291818291818211010291818291818291818
181010291818181010211010291818291818181010181010181010181010211010291818291818\
3121183121213121213121214A31315A42394A31314231395A4239523931523931
734A42947B73EFE7E7F7F7F7EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6D6C6CE9C8C8C8C736B6B524A634A42
5A4239634A42634A42634A42634A42735A52735A5263524A634A4A63524A735A52634A4A524239\
524239634A4263524A735A52735A527B635A5A52525A4239524239634A42634A4A
634A4263524A7B635A735A525242395A42395A4239634231523931422921422921523129523129\
5239315239315A42395A42394A31315231294A31315A42395242394A31315A4239
5242393929215231294A31315239314229213929215242393929214A3131422931392921392921\
422921291818312121312121291818392921422921392921392921312121312121
291818312121312121312121312121312118291818291818211010291818312121312118312118\
392921392921312121291818291818291818291818312118312121312121312118
523129291818291818392921312121291818312118392921312118312121312121312121291818\
291818291818291818291818291818291818291818291818291818181010291818
291818291818211010181010291818211010181010181010181010291818312121312118312121\
312121312121291818422921523129392921523129422921422921312118734A39
9C7363DECED6F7F7F7EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7A5848494736B7B635273524A
634A425A4239734A39634A42634A42634A42735A527B635A63524A634A42634A42735A52634A4A\
5A42395A423963524A735A527B635A735A52735A52735A5263524A5A42395A4239
634A4A735A527B635A735A525A4239634A425A42395239315239314229215231294A3131422921\
5231295231296342315A42394A31315231294A31315239314A3131523129422931
4A31314229213121184A3131422921422921312121523931422931392921422931392921392921\
312121312121291818312121312121312121392921392921422921392921312121
291818291818312121291818312121291818291818291818291818291818312121312121392921\
312121392921392921291818291818291818291818291818312118312121312121
392921392921291818312121392921291818291818312121312121312118291818312121291818\
291818291818291818211010291818291818291818211010211010211010181010
211010181010181010211010211010181010181010181010291818312121312121312121312121\
2918182918184A3131523129312121422921392921312118392921523129846B5A
CEB5BDF7F7F7F7F7F7EFE7E7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5ADA58484947B737B635A
735A52634A425A42396B524A6B524A634A425A4239634A42735A52634A4A634A42524239634A42\
63524A634A42634A42634A42634A42735A52735A525A525263524A5A4239524239
5A42395242395242394231395231295242396B524A634231523931422921523129392921312118\
4229214229214229215242395239314A31315231294229314A3131523129422931
4A3131524239523129312118392921523931392921392921523129312121312121523129312121\
291818392921392921312121291818312121312121392921312121392921312121
312121291818291818291818291818291818291818291818291818312121291818291818312121\
312121312121312121392921312121211010291818291818291818291818291818
312121312121312121291818291818392921392921291818291818312121291818291818312121\
181010291818211010181010211010291818181010181010181010181010181010
181010181010181010181010291818312121312121312121312121312121291818291818312118\
4229215231293929215231293929213121185231295A42398C5A4A9C6B52D6BDC6
F7F7F7EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7B5A5ADA5847B94736B
846B5A735A52634A425A42396B524A73524A634A42634A426B524A735A5263524A5A4239634A42\
634A42634A42634A42634A4263524A524239634A42634A4263524A6B524A63524A
634A425242395242394A3131523129523931634A42523931523931392921523129422921392921\
4A21184229213121184A31314A31314A31314229214229214A3131422931422921
4A313152393152394A312121312121523129423139312121422921422931312121392921392921\
211010312121392921312121291818312121312121392921392921392921312121
291818291818291818291818291818291818312121312121291818312121291818291818291818\
291818392921392921392921312121291818291818291818291818291818312121
312121312121312121312121291818291818422931392931312121291818312121211010291818\
291818211010211010181010181010211010181010181010181010181010181010
181010181010291818312121312121312121392931392921312121291818291818312121422931\
3929213121215231293929213929215231296342318452429C6B52A5735AEFE7E7
EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDEAD9494947B73
8C736B7B635A6B524A634A426B524A6B524A6B524A634A42524239634A42735A52634A426B524A\
634A4A524239634A42634A42634A42735A526B524A63524A524239524239634A42
523931423139422931392921523129634231734A425A4239523931422921422921392921312121\
3121184229213929215231294A31314A3131422921392921422921422921392921
422931392921634A4A392921312118392921524239291818312121392921392921312118392921\
312121312121392921312118291818291818291818291818392921312121291818
312121291818291818291818291818312121291818291818312121312121291818291818312121\
312121312121392921312121312121312121181010291818181010291818312121
312121291818312121312121312121291818312121423139422931312121291818291818181010\
211010181010181010181010181010211010181010181010181010181010181010
291818312121392921392921392921392921392921291818291818312121392921312121392921\
312121523129422921422921523931734A398452428463529C6B529C7363EFE7E7
E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFCEB5BDA58484
947B73846B5A7B63526B524A5A42396B524A6B524A735A52634A425A423963524A634A4263524A\
6B524A7B635A63524A63524A6B524A6B524A5A5252735A52735A52735A52634A4A
634A4A634A4A524239422931523129634A426B524A523931523931523129422921392921392921\
3121183929213929214229214229214A3131523129392921392921422921392921
4229213929215242394229312918183929214A3131291818291818312118392921291818312121\
392921291818312121312121312121291818312121291818291818312121312121
312121291818291818291818291818291818291818291818312121291818312121291818291818\
312121312121392921523129423139312121312121181010291818291818181010
312121312121312121312121392921392931291818291818312121392931291818211010181010\
181010181010181010181010181010181010181010211010291818291818312121
312121392921422931392921312121312121312121312118312121312121392921523129523129\
5231294229215A3129634231734A39734A398C5A42A5735A9C7363C6ADADF7E7DE
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7ADA5B5
9484848C6352846B5A7B63525A4239634A426B524A6B524A634A425A4239634A42735A52634A4A\
5A42396B524A7B635A735A5263524A73524A6B524A634A42634A42634A4263524A
63524A634A424231394A3131523129634A42634A42634231523129422921422921422921392921\
3121213929213121183121184229214A31314A3131392921392921312121392921
392921392921392921423139291818312121422921312121312118291818312121312121291818\
291818312121291818312121312121312121291818312121181010312121312121
312121312121291818181010181010291818291818312121291818312121312121291818291818\
312121312121392931423139524239423139423139312121291818291818291818
291818312121312121312121312121312121392921312121291818291818392921392921312121\
312121291818291818211010291818312121291818312121312121392921392931
3929214229313121213121212918183929213121213121213929215231294A31314A3131422921\
422921523129634231734A39734A398452428C73639C6B52AD8C84DECED6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7
C6ADAD9484848C736B7B635A6B524A5A4239634A426B524A6B524A63524A5A423963524A63524A\
634A4A5A42395A423963524A735A525A525263524A63524A634A4A634A42634A4A
5A4239523931524239422931392921634A426B524A634A425231293929214A3131422921312121\
312118392921312118312121392921422921422921422921392921312121392921
312118392921312118422921291818291818312121392921312121312118291818392921312121\
291818291818312121312121312121291818291818312121291818291818312121
312121312121291818291818291818291818291818291818291818291818312121312121291818\
31212131212131212142313952394A423139634A42423139312121291818291818
291818291818312121312121312121312121312121392921392931392921312121392921392921\
422921392931392921392921312121392921392921392921312121312121392921
4229313121213121183121212918183929213121213929214A31314A3131422921312121422921\
5239316342316342316342318452429C6B52A5735A94736BC6ADA5E7DEE7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFE7E7ADA5B5A5847B8C63527B635A6B524A634A426B524A634A426B524A63524A634A4263524A\
63524A6B524A5A52525242395242397B635A7B635A7B635A6B524A635A63735A52
635A63634A4A5A42395231295231296B524A634A42634A42523931422921422921422921392921\
312118312121392921392921312118392921422921392921392921392921312121
312121312118312121312121312121291818312118422931312121312121291818312118312121\
312121312121291818291818312121312121291818291818312121181010291818
312121312121312121181010181010291818291818291818291818312121312121312121291818\
2918183121213929213121215242395A52524231397B635A52394A392921312121
291818312121312121312121291818291818312121312121312121392921392931392921392931\
392921392931392931392931392921392921392921312121523129423139523129
392921312121291818291818392921523931523129523129422921312121312118523129634231\
734A3963423163423184523994634AA56B529C6B52AD8C84D6CEDEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFCEBDCEA5848494736B846B5A735A526B524A63524A634A426B524A634A425A4239\
5A423963524A63524A735A52735A52735A525A5252735A52735A527B635A63524A
735A52735A5263524A5242395242396B524A634A42634A425A42394A3131422921523129422931\
392921312121312121312121312121291818392921422921392921312121312118
312121312118312118312121392921291818291818312121392921312121291818312121312121\
291818291818312121291818312121291818291818291818291818291818181010
291818312121392921312121291818181010181010291818291818291818291818312121392921\
3121213121213121213121213929315242396B636B5A5263423139634A42635A63
5A5252392931312121423139422931392921312121312121291818312121312121291818312121\
312121312121312121392921422931422931392921392921312121312121312121
3121214229215242395242395A4239523129392921392921523931634231634231523931523129\
634231734A397B63528C5A4A9C6B528C7363CEB5B5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CEBDC694736B94736B846B5A735A52735A52634A4A63524A63524A6B524A\
634A42634A426B524A63524A634A427B635A7B635A735A5263524A634A42524239
5A42395242395242395231295231296B524A73524A5A42395A4239523931523129422921422921\
422921422921312121312118312118312121312121422921392921312121312118
312118312121312118312118312121392931211010392921392921312121291818291818312121\
312121291818312121312121211010312121291818291818291818312121181010
291818291818312121392931291818291818181010181010181010211010291818312121312121\
4231393929313929213929393121213121215A4A5A7B635A6B636B5A4A5A423139
634A4263524A63524A423139524239422931524239423139423139392931312121312121291818\
3121213121213121213121213121213121213121212918183929215231294A3131
523931523931634231523931312118312121523129523931634231523931523129523129634231\
634231734A398C5A4A9C6B529C7363C6ADADFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEF8C737B94736B947B73846B5A735A52735A526B524A6B524A63524A\
634A425A4239524239634A4252423963524A63524A735A52735A52735A52735A52
735A52735A52634A4A634A4A524239634A42735A526342315A42395A4239523129523129523129\
392921422921392921291818291818312121312118392921422921392921312121
312121312121291818312121312118392921291818291818392921312121312121291818312121\
312121211010291818312121291818312121291818291818291818312121291818
291818291818312121392921291818291818291818291818181010181010291818291818291818\
42293152394A4231394231394A394A3929395242395A5252635A637B635A5A5252
422931523129422931423139423139524239423139423139524239524239422931422931392921\
3929313929213121213121213929213929214229215231294A31315A3129523931
5A42395231294A3131422921523129633931523931634231523129523129634231634231634231\
734A398452429C6B529C6B52AD9494F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7D6C6D6A584848C73638C7363846B5A846B5A7B635A5A525263524A\
634A42634A425A42395242395239315A4239634A4A63524A6B524A63524A63524A
63524A735A527B635A735A526B524A634A426B524A634A425A42395A42395239314A3131523931\
523129422921422921291818291818312118291818312121422921392921392921
312118312118312121312118312121312121312121291818312121392921312121291818291818\
312121291818181010291818312121291818312121291818291818291818312121
291818291818312121312121312121291818181010291818291818181010181010181010291818\
29181831212163524A524239423139634A42423139422931634A42635A637B635A
635A63635A635242394229314229314229315231293929315231294229314A3131423139423139\
4229313929214229214A3131523931523931523931523931523931422921392921
4229215239315231295239315239315239315239315239315239316B524A734A39734A397B6352\
8463528C5A4A945A52AD9494F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECED68C737B8C736394736B846B5A7B635A735A52735A52\
735A5263524A634A425A4239524239634A4263524A63524A63524A635A637B635A
7B635A7B635A63524A63524A735A525A5252634A425A4239634231634A425242395A4239523931\
523931422921422921392921291818291818312121312121392921392921392921
291818312121312118291818312118291818392921291818312121312121392921291818291818\
312121312121291818291818291818312121312121312121291818291818291818
291818291818291818312121312121291818291818291818291818291818291818291818291818\
1810101810103121215A52525A525252394A52394A52394A42313942313963524A
7B635A7B635A6B636B735A527B635A735A525A4A5A634A4A634A4A52394A634A4A6B524A735A52\
634A4A634A4A634A4A5A4239524239523129392921392921312118392921523129
5239315A42395239315239315239315A42395A42395A42396B524A734A42734A39734A42845242\
8C5A4A846352AD8C84F7EFEFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDC6A584848C736394736B846B5A735A52735A52\
735A52735A526B524A634A42634A425A4239634A425A5252735A52735A52735A52
735A525A52527B635A6B636B7B635A7B635A6B524A634A425A4239634A425A42395A4239523931\
524239523931422921422931392921291818291818312121312121422921392921
312118291818392921312121312121312118392921291818291818312121312121291818291818\
312121291818312121291818291818291818312121312121291818291818291818
291818291818312121312121312121312121291818291818291818291818291818291818312121\
291818291818291818312121634A4263524A5A525263524A52394A4A394A423139
422931423139634A42524239634A425A52527B635A735A52735A526B524A6B524A6B524A634A42\
634A425A42395239314229314229213929215231295239315A4239734A39634A42
634A42634A42634A42734A39634A42634A42634A426B524A734A39634231734A39734A39845242\
8C5A4A94634ADECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE9C8C9C8C7363846B5A7B635A6B524A\
6B524A63524A6B524A6B524A63524A5A4239524239634A4263524A6B524A5A5252
735A525A52526B636B7B635A7B6B7B6B636B7B635A735A525A42395A42395A4239524239634231\
5239315239314A31315231294A31313121212918183121213121213929214A3131
422921312121312118312118312121312121312118291818291818312121392921392921291818\
291818291818291818291818181010291818312121312121291818291818291818
291818291818291818312121312121312121312121291818181010291818291818291818392921\
3121213121213121212918183121213929315A525252394A634A42634A425A5252
5A525252394A5242394A394A3929313929213121213929213929213929214A3131524239523931\
5239315A42395A42395A42395A42395A42395A42395A4239634A426B524A634A42
634A42634A42634A42634A42634A42734A39634231634231634231634231734A428C5A4A9C6B52\
9C6B52947B73F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7AD94947B63527B635A\
7B635A735A526B524A634A42634A426B524A6B524A6B524A735A526B524A735A52
5A5252735A527B635A7B635A7B635A8C7B737B6B7B7B635A735A525239315A4239523931523931\
5A42395A42395A42395239315231295239315A4239422921312121392921392921
4A3131422921392921392921312121312121392921422921291818291818312121312121312121\
312121291818291818312121291818291818291818312121392921291818291818
291818312121291818312121312121312121312121312121312121312121291818312121312121\
312121312121392921423139422931422931392931312121422931634A42634A42
634A42634A424A31315239315A423963524A634A426B524A735A525A525263524A6B524A6B524A\
735A5263524A63524A634A42524239524239634A425A4239634A425242395A4239
524239523931523129523129523129634231634231734A398463529C6B528463528C5A4AA5847B\
D6BDC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F794736B8C6352\
7B6352735A52846B5A7B635A63524A634A4263524A6B524A735A52735A527B635A
7B635A735A527B635A6B636B7B635A7B635A8C736B7B635A7B635A634231523931523931523931\
5A42395239315239315239315231294A31314A3131634A4252394A392921422921
5242394A31314A3131422921422921312121422931392921392921211010291818392921312121\
312121291818291818312121392921312121291818291818312121312121291818
291818312121392921312121392931312121312121312121312121392931312121312121392921\
392931423139312121312121312121422931524239524239422931392939422931
634A425A5252634A4A392931312121392921392921422931392921392921422931392921392921\
5231293929213121213121214A31314A31314A31314229215231295242395A4239
5239315231295231295A3129634231734A398452428452429C6B52846352945A52947B73DECED6\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9CB594736B\
8C7363735A526B524A735A5273524A6B524A63524A634A42634A426B524A5A5252
7B635A7B635A7B635A7B635A8C73638C736B9484849C8C8C9484846B524A523931523931523931\
5239315A42395A42395239314A31315231295231294A3131634A425A42394A3131
5242395242395242395242394A3131422921392921392921423139392921291818392921312121\
392921312121291818291818312121422931312121291818312121392921312121
291818312121422931422921392931392931312121392921392931392931524239392921312121\
3929214229314A394A392931312121312121392921422931423139524239392931
39293139292152423963524A634A4A4231394229313121213929213929213121214229214A3131\
4229315231294A31315239315231294229215231295239315A4239634231523129
5231296342316342317342317B6352734A428452428463528C63528C5A4A947B73DECED6F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD\
947B738C7363735A526B524A634A426B524A6B524A6B524A6B524A63524A63524A
735A525A52527B635A7B635A8C736B8C7B73948484A5847B8C737B6B524A6B524A5A42395A3129\
5239315239315239315239315239315231295231295231294A31315239315A4239
5A42395A42395A42395A42395A42395242394229214A3131422931634A4A392931312121523129\
312121312121312121312121312121312121392921392921312121422931392921
3121212110103121214A313152394A4231393929213121214231393929314229315A5252392921\
422931422931634A425A525252394A423139423139423139423139423139392931
3929313929313929213929215242395242395242395242394A31314A31315A4239524239524239\
524239523931523931523129523931634A425A4239634231523129523129634231
634231734A42734A396B524A734A398452428C5A4A8C6352846352AD9494DECED6F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
D6C6CE9484848C63527B635A735A52634A42634A426B524A6B524A6B524A634A42
634A42735A525A52527B635A7B6B7B8C73638C736B8C7B738C7B737B6B7B7B635A735A525A4239\
5239315239316339315231294A31315239314A31315231294A31314A31314A3131
5A4239634A425A4239524239634A42634A424231395242394229215A5252635A63312121392921\
4229314229312918183121214229315231293929314A3131422931422931392921
42313939292131212129181852423952394A4231394231394229315A52634A394A4229315A4A5A\
4231394A3131422931634A426B636B635A636B524A5A4A5A5A52525A4239524239
4A394A4A31314231394A31314229314229314231395A4239634A4A634A42523931524239523931\
5239315239316342315A4239634A425239315239315A4239634A42734A4273524A
734A42734A398452428452429C6B528C73638C6352846352B5A5A5F7EFEFFFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6C6DEAD8C848C73638C73636B524A634A425A42395A4239634A4263524A
6B524A5A52527B635A6B636B8C736B8C736B8C736B8C7B738C7B739484848C736B846B5A7B635A\
634A425242395239315239315231295231295239314A3131523129523129524239
5231295A4239634A42634A42634A42634A4A5A4239524239524239392921735A525A4A5A312121\
4229314229213929212918183121214A31315242394231395242394229314A394A
4231395242394A394A423139524239635A635242395A52524231395242397B737B524A5A6B524A\
7B6B7B635A63422931392931392921634A425A52527B635A7B635A5A5252634A4A
634A4A634A4A634A425A4239634A42634A42634A425A4239634A42634A425A42396342315A4239\
5A4239634A42634A42634A426342316B524A73524A7B635273524A6B524A734A39
634A427B63528452428C6352A5735A8C63528463528C5A4AF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D6CEDEAD94A59484847B635A6B524A6B524A634A425A4239634A42
634A426B524A735A527B635A7B635A8C736B8C736B9484849C8C8C9484848C7B73635A63735A52\
7B635A6B524A634A42634A425A42395239314A3131523129523931524239523931
4229315231295239315A4239634A426B524A6B524A634A4A634A4A52423942293163524A4A394A\
31212142292142313939293129181839292142293152423952423952394A524239
5A525252423963524A5A4A5A52394A6B636B5A525252394A6B524A52423952394A6B636B52394A\
5242398C736B7B6B7B6B524A4A394A4231394A3131524239634A4A634A42634A4A
634A425A42395A4239634A425A42395A42395A42395A4239634A42634A42634A42634A42634A42\
634A42634A42634A426B524A73524A8452427B635273524A734A39734A39734A39
734A398452429C6B528C6352845242734A3973524AB59C9CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7E7DEEFCEBDCE8C7363846B5A7B63526B524A634A42634A42
5242395A42397B635A635A63735A527B635A8C7B849484848C736B9484849C8C8C9484848C736B\
7B635A7B635A735A526B524A6B524A735A526B524A5A42394A31315A42395A4239
5231294A31314A31315A4239735A52634A4A735A52634A4A6B524A735A525A42395231297B635A\
4A394A5239314229215A423942313931212131212152312952394A5A5252634A4A
52394A52394A63524A6B636B6B636B7B737B6B636B5A52525A5252635A63634A4A5242397B6B7B\
5A52525A52526B636B5A52527B635A7B635A5A4A5A5A5252634A4A63524A6B524A
634A4A5A423952394A634A426B524A6B524A6B524A73524A73524A6B524A6B524A735A52735A52\
734A42734A4273524A845242734A39634A42634231734A39734A39734A39845239
8452429C6B52846352734A39734A398C736BCEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDECEB5BD9484948C736B846B5A7B6352
735A5273524A846B5A7B635A735A527B635A7B635A7B635A7B635A8C736B7B737B947B73948484\
9484848C7B737B635A846B5A735A52846B5A8C736B8C73638C736B846B5A7B635A
735A526B524A634A425242395242396B524A6B524A634A4A7B635A7B635A7B635A735A52634A42\
735A526B636B635A635A5252634A4A7B635A52394A3121213121216B636B635A63
634A4263524A5A525263524A5A52526B636B7B635A7B737B6B636B6B636B7B635A5A4A5A634A4A\
634A4A5A4239634A426B524A7B635A735A5263524A634A4A6B524A634A42634A42
6B524A634A42634A426B524A6B524A634A42634A42734A39634A42634A42734A39634231634231\
634A42634A42734A39734A398452428452428452428463528C5A4A94634A8C5A4A
7B63525A42397B6352BDA59CF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFD6C6CEAD94A5947B738C737B
7B635A735A527B635A735A526B524A6B524A735A525A5252735A528C736B8C737B9484847B737B\
8C736B8C7B738C736B8C736B947B738C7B738C736B8C736B8C7B738C736B8C7363
8C7B738C736B7B635A735A52634A4A634A4A6B524A6B524A5A52527B635A7B635A7B6B7B7B6B7B\
735A527B635A6B636B8C7B73635A635A5252736373634A4A4231394229317B635A
5A4A5A52423952394A524239634A4A634A4A5A52527B635A7B6B7B6B636B735A5263524A6B524A\
735A526B524A5A5252634A42634A426B524A73524A735A52735A527B635273524A
73524A73524A73524A734A42734A42734A39634A42634231734A39734A39734A396B524A6B524A\
734A398452427B63528463528C5A4A8C5A4A9C6B52A5735A94634A7B6352845242
734A3994736BCEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFE7DEE7C6ADBDB5A5A5
A58484947B737B635A735A527B6352735A52735A52735A527B635A8C736B8C7B738C7B738C7B73\
8C737B9C8C8C9C8C8C8C736B947B73947B738C736B846B5A8C7B73947B738C7B73
8C736B846B5A8C736B8C7B738C736B8C736B7B635A6B524A6B524A6B524A735A526B636B8C7B73\
7B6B7B7B6B7B7B635A7B6B7B7B737B7B635A7B635A6B636B635A63422931523129
634A42634A425242395242395239315A42395A5252735A527B635A8C7B73635A63634A4A6B524A\
6B524A6B524A73524A6B524A735A526B524A6B524A634A4263524A634A42634A42
634A42634A426342315A4239634231634231634231634231634A426B524A734A4273524A845242\
73524A8463528C5A4A8463528C63529C6B528C6352845242845242734A395A4239
73524AD6C6DEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6DE
B5A5AD947B736B636B846B5A735A527B635A7B635A735A52735A528C736B8C736B8C7B73948484\
8C736B8C7B738C736B8C736B8C7B738C736B8C736B846B5A846B5A8C736B8C736B
8C7B738C7B738C736B8C7B738C736B8C736B8C736B8C736B635A637B635A7B635A735A52735A52\
8C7B738C736B7B737B6B636B735A527B635A7B737B7B737B6B636B5A4A5A634A4A
52394A52423952394A5A42394231394A31315239315239315A4239634A427B635A8C736B6B524A\
6B524A6B524A634A426B524A734A395A42395A42395A4239634231634231634231
6342315A42396342316342315A4239734A39734A4273524A84524273524A7B63528C5A4A846352\
8463528C5A4A8C63528C5A4AA5735A846352845242734A395A4239734A4294736B
D6C6D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E7DEEFBDB5BD9C8C8C8C736B7B6352735A527B6352735A527B635A63524A7B635A8C736B8C736B\
8C736B8C7B738C736B9484848C736B8C736B8C736B8C736B8C736B8C736B8C736B
8C7B738C736B8C736B947B73947B7394736B8C736BA5847B947B738C7B738C736B8C736B735A52\
735A528C7B738C737B8C7B738C7B73635A637B635A8C7B738473846B636B735A52
634A4A6B524A634A4A634A4A5A42395242394A31314229314A31314A3131523931634A42846B5A\
735A52634A42634A42634A42634A42634A425A4239634231634A42734A39634A42
6B524A734A39734A42734A42734A4273524A734A42845242734A428C5A4A8C5A4A8C63528C6352\
8C6352A5735A8C63529C6B52846352734A395A42395A42398463529C8C9CEFE7E7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7CEBDC6AD94A58C737B7B63527B63526B636B7B635A735A527B635A8C73636B636B\
8C7B738C737B9484849C8C8C8C737B8C7B738C7B739484848C7B738C7B738C7363
8C7B738C7B73846B5A8C736B8C7B73948484947B73947B73948484A5847B8C7B738C737B947B73\
7B6B7B8C7B738C737B8C736B9484849484847B6B7B735A528C736B8C7B737B6B7B
7B635A635A636B524A52394A634A4A634A4A634A4A5A42395A42395A4239524239634A42634A42\
735A527B635A7B635A735A5273524A634A4273524A6B524A734A396B524A734A42
8452427B635273524A73524A8C5A4A73524A7B63528463528C6352846B5A8C7363A5735A9C7363\
8C7363A5735A8C6352845242633931634A428C6352A58484D6C6CEFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7EFEFD6C6D6AD94A59484848C7363846B5A846B5A735A52735A527B635A\
7B635A8C736B8C736B8C737B7B737B8C736B8C73637B635A8C737B9C8C8C948484
8C736B94736B8C7B738C7B738C736B8C7B738C7B738C736B947B739C8C8C947B73A5847BA5847B\
947B73947B738C736B8C736B947B739484849484848C737B8C736B8C7B738C736B
7B635A8C736B8C736B846B5A7B635A7B635A7B6352735A52735A52735A52735A52735A526B636B\
7B6352735A5273524A73524A735A527B635273524A7B6352734A4273524A7B6352
73524A73524A8C5A4A846B5A846B5A846B5A9C73639C7363AD7B6B9C736394736B9C7363A5735A\
8C7363845242734A39734A39846352AD9494D6C6DEF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF9C8C9C6B636B73524A524252\
735A526B524A6B524A635A637B635A7B737BAD9494AD94949484848C737B948484
9C8C8CA5847B948484A5847B9C8C8C948484947B738C7B738C736B8C736B8C7B73947B73A5847B\
947B73947B73947B73947B73947B73947B73947B738C736394736BA5847B9C8C8C
947B73947B73947B738C736B846B5A846B5A846B5A8C736B8C736B8C63528C73638C63528C6352\
945A52846B5A945A529C6B52846B5A8C63529C6B52846B5A9C736394736B94736B
94736B94736BAD7B6BAD7B6BAD846B947B73AD846B8C73638C7363AD846B73524A734A42634A42\
734A42846352A58484CEBDC6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6D6AD94A59C8C8C\
6B636B735A52735A52735A52735A528C736B8C736B9C8C8C9C8C8C9484849C8C8C
9C8C8C9C8C8C9C8C8C9C8C8CAD9494AD9494948484947B73947B73947B738C736B8C7B73948484\
947B73947B73947B73947B73948484A58484AD847B9C8C8C94848494736B94736B
947B73947B7394848494736B94736B8C73638C7363846B5A846B5A8C73638C7363846B5A846B5A\
8C7363846B5A846B5A846B5A846B5A8C736394736BAD7B6B947B73AD846BB58C73
B58C73B58C73B58C73A5847BAD846BB58C73AD846BA5735A8C63527B635273524A8463528C6352\
A58484D6BDC6F7EFEFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7\
BDB5BDAD9CB5AD9CAD8C7B8C8C7B738C7B8C8C7B8CAD9494B59C9CA594A5B59C9C
C6B5C6B5ADBDB59C9CAD9494B59C9CAD9CA5B59C9CA58484A5847B948484A5847BA5847B947B73\
947B737B635A8C7B73947B73947B73A5847BA5847BA58484A5847BA5847B9C8C8C
A5847BA5847BA5847BA5847B947B73947B73947B7394736BA5847B8C736394736B94736B8C7363\
8C736394736B94736B947B73947B73AD7B6BA5847BA5847BA5847BAD846B947B73
8C7363846B5A846B5A8C73638C736373524A73524A73524A73524A8452428C73638C737BCEB5BD\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7E7DEEFE7DEE7E7DEEFEFE7E7D6CEDED6CEDEDED6E7D6C6D6
E7DEEFDED6E7C6B5C6B5A5ADCEBDB5BDB5BDAD9CA5ADA5B5B59C9CAD9494AD9494948484948484\
948484A5847B947B73947B738C7B738C736B8C736B8C736B8C736B947B73B58C73
A58484AD8C84AD8C84A5847BA5847BA5847B947B7394736B947B73947B7394736B94736B94736B\
94736B947B73AD7B6B94736B9C73638C736394736B8C73638C7363846B5A8C6352
846B5A8C73638C73637B635273524A73524A73524A73524A8C635294736BDECED6F7EFEFFFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE7DEEFE7DEEF
EFE7E7F7F7F7D6C6D6C6B5C6C6B5C6DECED6BDB5BDE7DEE7C6B5C6B5A5ADAD9494AD9494AD9494\
B59C9CA58484947B73947B73A5847B94736B94736B8C7B738C736B7B6B7B846B5A
8C7B73947B73947B73A5847B947B73A5847BA5847B947B738C736B8C736B94736B8C736B8C736B\
94736B94736B8C73638C73638C736394736B94736B8C7363846B5A846B5A846B5A
846352846B5A846B5A8C5A4A846352846B5A947B73AD94A5AD9CB5D6C6CEFFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFE7E7E7DEEFE7DEE7DED6E7D6C6D6D6C6D6DED6E7D6CEDEEFE7E7E7DEEFD6C6D6B5A5ADAD9494\
AD94A5AD9494AD9494AD8C849C8C8CA5847B947B73A5847BA5847B94736B94736B
8C736B947B738C7B738C736B947B73A58484A5847B9C8C8CA5847B947B738C7B73947B73947B73\
94736B8C736394736B947B7394736B94736B8C73638C7363846B5A7B635A735A52
7B635273524A73524A8C736B948494C6ADBDD6C6DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFEFE7E7F7F7F7E7DEEFEFE7E7EFE7E7E7DEEFF7EFEFF7F7F7EFE7E7D6CEDED6C6D6\
D6C6CECEBDC6B5A5AD9C8C9CAD9494AD94A5B5A5A59C8C9CAD8C84948484947B73
947B7394736B947B73A5847B947B738C7B73947B73947B73947B739C8C8CA5847B947B73947B73\
94736B8C736B8C736B8C736B94736B8C73637B635A846352735A52735A52846B5A
846B5A8C737BAD94A5D6C6DEF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFE7DEE7D6C6DED6C6CED6BDC6AD9CB5
B5A5ADB5A5ADB59C9CAD9494AD9494AD8C84948494A58484AD8C848C737B8C737B948484948484\
948484AD94949C8C9CB59C9CAD94A5CEB5B5DECED6D6CEDEF7EFEFE7DEEFF7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFE7DEEFE7DEE7E7DEE7DED6E7CEBDC6CEBDC6D6C6D6DECED6DECED6D6C6DEE7DEE7EFE7E7\
E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003P3oool>0?Ogm`030?O_k`3gmoL0moOg00X0moOg
00<0mno_0?Ogm`3gmoL0?@3gmoL00`3_e/h0mlje0>o>]@040?OF_@030?OFaP3ge[d0mmK600@0mmK6
0`3gg/h20?OFaP`0mmk>00<0mmK60?ONcP3gg/h00P3gg/h50?OFaP030>o>]@3ge[d0klje00@0klje
00<0klJ]0>NmY@3_aZd00P3_aZd01`3W_JD0ikFL0>NeW03W_JD0g[FL0>NeW03N[I@00P3W]I`?0=j]
U0030=jUS03N[I@0eZF<0080gZfD00P0gZF<0=JUQ03FYH`0eZF<0=JUQ03FYH`0gYb40=JUQ0<0eZF<
0`3FYH@01@36W8@0eYb40=JUS03FYH`0mnON02/0moOg00<0mno_0?Ogm`3gmoL01P3gmoL00`3gknl0
moOg0?Ogm`0;0?Ogma00oooo000>0?ooo`<0moOg00<0mno_0?Ogm`3gknl07P3gmoL00`3gknl0moOg
0?O_k`020?Ogm`030?O_k`3gmoL0moOg00`0moOg00<0mno_0?Ogm`3gmoL0803gmoL00`3gg/h0klje
0?OF_@040?OF_@H0mmK61P3gg/h0103ge/H0mmk>0?ONcP3gg/h30?OFaP<0mmk>00H0mmK60?ONcP3g
g/h0mmk>0?OFaP3gg/h20?OFaP040?OF_@3_c[D0mmK60?OFaPL0klje103_aZd20>NmY@050>NeW03N
]JD0ikFL0>NeW03W_JD01@3N[I@01@3N]I`0gZfD0=j]U03N[I@0gZF<00@0gZfD00@0g[FL0=j]U03N
YH`0gZF<0`3N[I@30=jUS0050=JUS03NYH`0eZF<0=JUS03NYH`00`3FYH`02@3FYH@0eZF<0=JUS03F
YH`0eZF40=JLQ03FYH@0aYb40>nm[@0L0?Ogm`030?O_k`3gmoL0moOg00P0moOg00@0mno_0?Ogm`3g
moL0mno_0`3gmoL01P3gknl0moOg0?Ogm`3gknl0moOg0?O_k`l0moOg403oool000h0oooo00<0mno_
0?Ogm`3gmoL01@3gmoL00`3gknl0moOg0?Ogm`0@0?Ogm`050?O_k`3gmoL0moOg0?Ogm`3gknl00P3g
moL00`3gknl0moOg0?Ogm`0J0?Ogm`80mno_6P3gmoL00`3gimh0klje0?O>]@050?OF_@070?OFaP3g
e[d0mmK60?OF_@3ge/H0mmk>0?OFaP020?ONcP<0mmK61@3gg/h20?OFaP80mmk>00<0mmK60?ONcP3g
e/H00P3gg/h60?OFaP@0klje0`3_aZd20>NmY@030>o6[@3W_JD0ikfU00<0ikfU0`3W]I`:0=j]U003
0=jUS03N[I@0gZfD00D0gZfD00<0gZF<0=j]U03N[I@00P3NYH`20=JUS0070=jUS03FYH`0gZF<0=JU
S03FYH@0eZF<0=JUQ0020=JUS080eZF400<0eZF<0=JUQ036W8@00P3FYH`00`3ge/H0moOg0?Ogm`0=
0?Ogm`030?O_k`3gmoL0moOg02H0moOg00<0mno_0?Ogm`3gmoL0203gmoL@0?ooo`003P3oool:0?Og
m`050?O_k`3gmoL0moOg0?Ogm`3gknl02@3gmoL00`3gknl0moOg0?Ogm`0N0?Ogm`030?O_k`3gmoL0
moOg01l0moOg00<0mmk>0>o>]@3ge[d00P3ge[d00`3ge/H0mmJm0?OF_@020?OFaP030?OF_@3ge/H0
mmk>00<0mmk>0`3ge/H30?ONcP050?OFaP3gg/h0mmK60?OFaP3gg/h00P3ge/H00`3gg/h0mmK60?OF
aP030?OFaP030?OF_@3_c[D0klje00@0klje0P3_aZd00`3W_JD0klJ]0>NmY@040>NmY@040=jeY@3W
]I`0g[FL0>NeW0@0g[FL0`3N[I@0103NYH`0gZfD0=jUS03NYH`90=j]U0040=JUS03N[I@0gZF<0=j]
U0<0gZF<0P3FYH`0203NYH`0eZF<0=JUS03FYH`0gZF<0=JUS03FYH@0eZF<0`3FYH@01@3FW8@0eZF4
0=JUS03N]I`0mnOW0140moOg00@0mno_0?Ogm`3gmoL0mno_0P3gmoL00`3gknl0moOg0?Ogm`030?Og
m`040?O_k`3gmoL0moOg0?O_kaX0moOg00<0mno_0?Ogm`3gmoL01@3gmoL@0?ooo`003P3oool40?Og
m`030?O_k`3gmoL0moOg00T0moOg00D0mno_0?Ogm`3gmoL0mno_0?Ogm`020?O_k`h0moOg00<0mno_
0?Ogm`3gmoL0503gmoL00`3gknl0moOg0?Ogm`0L0?Ogm`030?OWgP3_c[D0mmJm00<0mmJm00H0mmK6
0?OF_@3ge[d0mmK60?OF_@3ge/H40?ONcP<0mmK6103gg/h20?OFaP<0mmk>0P3ge/H0103ge[d0mmK6
0?OFaP3ge/H60>o>]@<0klJ]00D0g[FU0>o6[@3W_JD0ikfU0=jeY@020>NmY@040=jeW03W_JD0ijfL
0=jeW0H0gZfD00D0eZF<0=j]U03FYH`0gZfD0=jUS0070=j]U0030=jUS03N[I@0gZfD00<0gZfD00L0
gZF<0=j]U03FYH`0gZfD0=jUS03FYH`0gZF<00<0eZF<00<0gZF<0=JUS03FYH`00P3FYH`30=JUQ003
0<JLQ03FYH`0e/Jm01/0moOg00<0mno_0?Ogm`3gmoL09P3gmoL@0?ooo`003P3oool20?Ogm`030?O_
k`3gmoL0moOg00P0moOg00<0mno_0?Ogm`3gmoL0603gmoL0103gknl0moOg0?Ogm`3gknl_0?Ogm`03
0?ONcP3_c[D0mmJm00D0mmJm303ge/H00`3gg/h0mmK60?OFaP020?OFaP050?ONcP3ge/H0mmK60?OF
aP3ge[d00P3ge/H50>o>]@H0klJ]0P3__Jd01P3N]JD0ikfU0>NeW03W_JD0g[FL0>N]W080g[FL2@3N
[I@02`3FYH`0gZF<0=jUS03FYH`0gZF<0=j]U03NYH`0gZfD0=jUS03FYH`0gZF<00@0gZfD00<0eZF<
0=jUS03N[I@00P3NYH`00`3FYH`0gZF<0=JUQ0020=JUS0040=jUS03FYH`0eZF<0=JUQ0@0eZF<0P3F
YH@00`3N[I@0kmK>0?Ogm`0d0?Ogm`030?O_k`3gmoL0moOg00H0moOg00<0mno_0?Ogm`3gknl00`3g
moL@0?ooo`003P3ooolI0?Ogm`030?O_k`3gmoL0moOg03l0moOg00<0mmk>0>o>]@3gc[D01@3ge[d4
0?OFaP030?ONcP3ge/H0mmK600<0mmK600<0mmk>0?OFaP3ge/H01`3ge/H0103ge[d0mmK60>o>]@3_
c[D20?OF_@@0klje00H0e/Je0>o6[@3Fa[D0kkf]0>NmY@3N]JD20>NmY@030=jeY@3W_JD0g[FL0080
g[FL00D0g[FU0=jeW03N]I`0g[FL0=JUS0080=j]U080eZF<00D0gZF<0=JUS03FYH`0gZfD0=JUS002
0=jUS0050=JUS03N[I@0gZF<0=jUS03N[I@00P3FYH`20=jUS0050=JUS03NW8@0eZF<0=jLQ03NYH`0
0P3FYH`00`3FYH@0eZF<0=JUQ0020=JUS0050=JUQ03FYH`0eYb40=jeW03gknl06@3gmoL0103gknl0
moOg0?Ogm`3gknl50?Ogm`060?O_k`3gmoL0moOg0?O_k`3gmoL0mno_0P3gmoL00`3gknl0moOg0?Og
m`090?Ogm`040?O_k`3gmoL0moOg0?O_k`80moOg00<0mno_0?Ogm`3gmoL01@3gmoL@0?ooo`003P3o
ool00`3gmoL0mno_0?Ogm`060?Ogm`030?O_k`3gmoL0moOg0080moOg00<0mno_0?Ogm`3gmoL00P3g
moL00`3gknl0moOg0?Ogm`070?Ogm`030?O_k`3gmoL0moOg03/0moOg00<0mnON0>o>]@3_c[D00P3g
e[d0103ge/H0mmJm0?OFaP3ge[d30?OFaP060?ONcP3ge/H0mmK60?OFaP3gg/h0mmK60P3gg/h80?OF
aP050>o>]@3ge/H0klje0?OF_@3Fa/H00`3_c[D00`3Fa[D0klJ]0>nm[@020>nm[@@0ikfU00D0g[FL
0>N]W03N]I`0gZfD0=jeW0020=j]U0@0g[FL00T0g[FU0=JUS03FYH`0gZF<0=JUS03N[I@0gZF<0=JU
S03NYH`00P3FYH`20=jUS0080=JUS03NYH`0eZF<0=j]U03NYH`0gZfD0=JUS03NYH`20=j]U0080=jU
S03FYH`0gZF<0=JUS03NYH`0eZF<0=jUS03FYH`20=jUS080eZF<00L0gZF<0=JUQ03FYH`0eZF<0=JU
Q03FYH`0e/Jm0200moOg00<0mno_0?Ogm`3gmoL02P3gmoL00`3gknl0moOg0?Ogm`0E0?Ogma00oooo
000>0?ooo`H0moOg00<0mno_0?Ogm`3gknl0403gmoL01P3gknl0moOg0?Ogm`3gknl0moOg0?O_k`80
moOg00@0mno_0?Ogm`3gmoL0mno_6@3gmoL00`3gknl0moOg0?Ogm`0J0?Ogm`030>oFcP3_c[D0klje
00H0mmJm0P3ge/H00`3ge[d0mmK60?OFaP040?OFaP030?ONcP3ge/H0mmJm00@0mmK600D0klje0?OF
aP3_c[D0e/K60?OF_@020>o>]@040=K6_@3_c[D0e/Je0>nm[@<0ikfU00d0g[FL0>N]W03W_JD0ijfL
0=j]U03N]I`0gYb<0=j]U03NW8`0g[FL0=jLS03N]I`0gZfD00D0g[FL00H0eYb<0=jeW03FYH`0g[FU
0=JUS03N[I@:0=JUS0060=j]U03FYH`0gZF<0=jUS03N[I@0eZF<0`3NYH`01P3FYH@0gZF<0=j]U03N
[I@0eZF<0=jUS0<0eZF<00L0gZF<0=JUS03FYH`0eZF<0=JUQ03N]I`0knOW01/0moOg00<0mno_0?Og
m`3gknl09`3gmoL@0?ooo`003P3oool20?Ogm`030?O_k`3gmoL0moOg00H0moOg00<0mno_0?Ogm`3g
moL05`3gmoL00`3gknl0moOg0?Ogm`0I0?Ogm`030?O_k`3gmoL0moOg01L0moOg00<0kmK>0?O>]@3g
e[d01@3ge[d50?OFaP030?ONcP3ge/H0mmK600@0mmK600P0mmJm0?OFaP3ge/H0mmJm0>o>]@3ge/H0
klje0?OFaP80klje00@0mkfe0>o>]@3_c[D0mkfe1P3__Jd0103W_JD0ijfL0>N]W03W_JD20>N]W080
gZfD00T0gYb<0=j]U03NW8`0gZfD0=jLS03N]I`0gZfD0=jeW03NW8`00`3N]I`01@3FYH`0g[FU0=je
W03FYH`0gZF<00L0eZF<00<0gZF<0=JUS03NYH`00`3FYH`30=j]U0030=JUS03NYH`0gZF<0080eZF<
00<0gZF<0=JUS03FYH`00P3FYH`00`3FYH@0eZF<0=JUS0020=JUS0030>nm[@3gmoL0moOg01h0moOg
00<0mno_0?Ogm`3gmoL00`3gmoL01@3gknl0moOg0?Ogm`3gmoL0mno_0080moOg00<0mno_0?Ogm`3g
moL0103gmoL01P3gknl0moOg0?Ogm`3gknl0moOg0?O_k`80moOg00D0mno_0?Ogm`3gmoL0moOg0?O_
k`050?Ogma00oooo000>0?ooo`030?O_k`3gmoL0moOg03P0moOg00<0mno_0?Ogm`3gmoL07@3gmoL0
0`3ge/H0klje0?OF_@030?OF_@050?OFaP3ge[d0mmJm0?OF_@3ge/H00P3gg/h20?OFaP030?OF_@3g
e/H0mmK600<0mmK600H0klje0?OFaP3_c[D0mmK60>o>]@3ge/H30?OF_@040=K6aP3_c[D0mkfe0>o>
]@<0mkfe00T0klje0>nm[@3_c[D0kkf]0>neY@3__JD0kkFU0>NeW03W_JD00`3W[I`20=jLS0040=j]
U03NW8`0gZfD0=jLS0@0gZfD00L0gYb<0=jeW03FYH`0eYb<0=jeW036[JD0g[FL00X0eZF<00<0gZfD
0=jUS03NYH`00P3NYH`0103N[I@0eZF<0=JUS03NYH`40=JUS0030=JUQ03FYH`0eZF400<0eZF<00<0
eZF40=K6_@3gmoL06@3gmoL00`3gknl0moOg0?Ogm`0U0?Ogm`040?O_k`3gmoL0moOg0?Ogma00oooo
000>0?ooo`<0moOg00D0mno_0?Ogm`3gmoL0moOg0?O_k`090?Ogm`060?O_k`3gmoL0moOg0?O_k`3g
moL0mno_2@3gmoL00`3gknl0moOg0?Ogm`0;0?Ogm`030?O_k`3gmoL0moOg02X0moOg00<0mmK60>o>
]@3ge[d00`3ge[d20?OFaP80mmJm203ge/H0103ge[d0mmK60?OF_@3_c[D20?OFaP030>oFcP3_c[D0
mmJm0080e/K600T0klje0?Nm]@3ge[d0klje0?OF_@3g_KD0klje0?Nm]@3_c[D00P3g_KD00`3_c[D0
mkfe0>nm[@020>nmY@80kkFU00L0ikFL0>N]W03N[I@0gYb<0=j]U03W[I@0gYb<0080gZfD00@0ikfU
0>N]W03N]I`0ijfL0P3NW8`01P3NYH`0eZF<0=JLS03N]I`0g[FU0=jeW0T0eZF<00<0gZfD0=JUS03F
YH`00`3NYH`00`3FYH`0gZF<0=jUS0020=JUS0030=jUS03FYH`0eZF<00D0eZF<00<0kmK>0?Ogm`3g
moL0A03gmoL@0?ooo`003P3oool80?Ogm`030?O_k`3gmoL0moOg00h0moOg00<0mno_0?Ogm`3gmoL0
5@3gmoL00`3gknl0moOg0?Ogm`0V0?Ogm`040?O_k`3ge/H0klje0?O>]@<0mmJm00<0mmK60?OF_@3g
e[d00P3ge/H00`3ge[d0mmK60?OF_@050?OFaP040?OF_@3ge/H0kmK>0?OFaP<0klje00D0mmJm0>o>
]@3_c[D0klje0?OFaP020?OF_@030>o>]@3ge/H0mmK60080mmJm00P0klje0?OF_@3g_KD0kkf]0?Nm
]@3_aZd0kkf]0>neY@80ikFL0P3W[I`0103W[I@0gZfD0=jLS03N[I@20>N]W0060>neY@3W[I`0ijfL
0>N]W03N]I`0gZfD0P3NW8`30=JUS0050=j]U03N]JD0g[FL0=JUS03FYH@0103FYH`01@3FYH@0eZF<
0=JUS03FYH`0gYb40080eZF<00D0gZF<0=JUS03FYH`0gZfD0=jUS0050=JUS0040=j]U03FYH`0gZfD
0?OWgQT0moOg00<0mno_0?Ogm`3gknl00`3gmoL01@3gknl0moOg0?Ogm`3gmoL0mno_00/0moOg00<0
mno_0?Ogm`3gmoL0503gmoL@0?ooo`003P3oool40?Ogm`030?O_k`3gmoL0moOg01D0moOg00<0mno_
0?Ogm`3gmoL0>`3gmoL00`3gknl0klje0>o>]@070?OF_@<0mmK600T0mmJm0?OFaP3ge[d0mmK60?OF
_@3ge/H0klje0?OF_@3ge/H00`3_c[D02@3ge/H0klje0=K6aP3ge[d0mmK60?OF_@3_c[D0mmK60?OF
_@020?OFaP<0mmJm00<0mmK60?OF_@3g_KD00`3_c[D01P3__Jd0kkfU0>nmY@3__JD0kkFU0>NeW0@0
ijfD00<0ijfL0>neY@3W_JD00P3W_JD30>N]W0040=j]U03NW8`0gYb<0=jLS080eYb<00<0eZF<0=j]
U03N]I`00`3FYH`02@3N[I@0eZF<0=JUS03FYH`0gZfD0=jUS03FYH@0gZF<0=j]U0020=JUS0050=jU
S03FYH`0eZF<0=JUS03FYH@01@3FYH`00`3N]JD0knOW0?Ogm`0L0?Ogm`030?O_k`3gmoL0moOg00D0
moOg00<0mno_0?Ogm`3gmoL07P3gmoL@0?ooo`003P3oool70?Ogm`030?O_k`3gmoL0mno_0080moOg
00<0mno_0?Ogm`3gmoL0B`3gmoL00`3gknl0mmJm0>o>]@020?OF_@040?OFaP3ge[d0mmK60?OF_@D0
mmK600<0mmJm0>o>]@3ge/H00P3ge[d30?OFaP@0klje00D0mmK60>o>]@3ge/H0mmK60?OF_@080?OF
aP080>o>]@3g_KD0mmJm0>o>]@3g_KD0mlJ]0>nm[@3__JD20>nm[@050>nmY@3_]JD0ikfU0>N]W03W
_JD00P3W[I`0103W]I`0kkFU0>neY@3__Jd20>neY@070>NmY@3W[I`0ijfD0=jLS03N[I@0gZF<0=jL
S0030=JLS0040=jeY@3FYH`0eZF<0=JUS080gZfD1@3FYH`20=jUS080eZF<00<0gZF<0=JUS03FYH@0
1P3FYH`00`3__Jd0moOg0?Ogm`150?Ogma00oooo000>0?ooo`050?O_k`3gmoL0moOg0?Ogm`3gknl0
7P3gmoL00`3gknl0moOg0?O_k`020?Ogm`030?O_k`3gmoL0moOg00<0moOg00@0mno_0?Ogm`3gmoL0
mno_:03gmoL00`3ginL0klje0>o>]@060?OF_@030?OFaP3ge[d0mmK600<0mmJm00D0klje0?OFaP3g
e/H0mmJm0>o>]@020?OFaP<0klje00T0mmk>0?OFaP3gg/h0mmK60?ONcP3ge/H0mmk>0?OFaP3gg/h0
0`3ge/H0103ge[d0mmK60?OF_@3ge/H30?OF_@040>o>]@3__JD0kkf]0>nmY@<0klJ]0100kkf]0>Ne
W03__JD0kkfU0>NmY@3W]I`0ijfL0>neY@3W]I`0kkFU0>nmY@3W]I`0kkFU0>NeW03W[I`0gYb<0P3N
YH`0203N[I@0gYb<0=j]U03NYH`0eZF<0=jeY@3N]I`0gZfD1@3FYH`02P3NYH`0eZF<0=jUS03FYH@0
gZF<0=JUS03NYH`0eZF<0=jUS03FYH@30=JUS0030=j]U03Nc]H0oooo04H0moOg403oool000h0oooo
5`3gmoL0103gknl0moOg0?Ogm`3gknlo0?Ogm`050?OWi`3_c[D0mlje0?OF_@3_c[D00`3ge[d20?OF
aP80mmJm00<0mmK60?OF_@3_c[D00P3ge/H20>o>]@040?OFaP3_c[D0mmK60>o>]@P0mmK60`3gg/h0
0`3ge/H0mmk>0?OFaP050?OFaP030?OF_@3_c[D0mkfe0080klJ]00@0kkf]0>nmY@3_aZd0kkf]0P3_
_JD00`3W_JD0kkf]0>nmY@020>neY@060>NmY@3W[I`0kkFU0>neY@3W]I`0kkfU0P3W[I`02@3W[I@0
gYb<0=jLS03W[I@0gZfD0=jLS03FW8`0eZF<0=j]U0020=jeY@80gZfD0P3FYH`01`3N[I@0eZF<0=jU
S03FYH`0gZF<0=JUS03NYH`0103FYH`01@3FYH@0eZF<0=j]U03N]I`0mnON04L0moOg403oool000h0
oooo1@3gmoL00`3gknl0moOg0?Ogm`020?Ogm`030?O_k`3gmoL0moOg04d0moOg00<0mnOW0>o>]@3g
c[D00`3ge[d0103ge/H0mmJm0?OF_@3ge[d30?OFaP0<0>o>]@3ge/H0klje0?OFaP3_c[D0mmK60?OF
_@3ge/H0mmJm0?OFaP3ge[d0mmK60P3gg/h0103ge/H0mmk>0?ONcP3ge/H50?ONcP80mmK600<0mmJm
0?OFaP3ge/H00P3ge/H00`3ge[d0mlje0?Nm]@020>o6[@80kkf]00/0klJ]0>nm[@3__JD0kkFU0>nm
Y@3__Jd0kkfU0>NeW03_]JD0ikfU0>nmY@020>neY@030>NeW03_]JD0ijfD0080ijfD00D0gZfD0=jL
S03N[I@0gYb<0=jUS0020=JLS0040=JUS03N]JD0g[FU0=j]U0<0eZF<00/0gZF<0=JUS03N[I@0eZF<
0=j]U03FYH`0gZF<0=JUS03FYH@0eZF<0=j]U0020=JUS0030<je[@3_inL0moOg01D0moOg00<0mno_
0?Ogm`3gmoL00P3gmoL20?O_kbX0moOg403oool000h0oooo00<0moOg0?O_k`3gmoL02P3gmoL00`3g
knl0moOg0?Ogm`050?Ogm`030?O_k`3gmoL0moOg0480moOg00<0mnON0>o>]@3ge[d01@3ge[d00`3g
e/H0mmJm0?OF_@020>o>]@80mmK600H0klje0?OF_@3ge/H0mmJm0?OFaP3ge[d50?OFaP@0mmk>00<0
mmK60?ONcP3gg/h00P3gg/h40?OFaP0=0?ONcP3ge/H0mmk>0?OFaP3gg/h0mmK60>o>]@3g_KD0mlJ]
0>o>]@3gaZd0kkf]0>o>]@020>nm[@0=0>nmY@3__Jd0kkf]0>nm[@3__JD0kkFU0>nmY@3_]JD0ikFL
0>neY@3W]I`0ijfL0>N]U0020>N]W00;0=jLS03W[I@0gYb<0=jLS03N[I@0gYb<0=j]U03FYH`0g[FL
0=jeY@3N]I`00`3FYH`00`3N[I@0eZF<0=j]U0020=jUS0030=JUS03N[I@0gZF<0080eZF<0P3N[I@0
0`3g_KD0moOg0?Ogm`0H0?Ogm`030?O_k`3gmoL0moOg02/0moOg403oool000h0oooo00<0mno_0?Og
m`3gmoL0303gmoL00`3gknl0moOg0?Ogm`0;0?Ogm`030?O_k`3gmoL0moOg01<0moOg00<0mno_0?Og
m`3gmoL0903gmoL00`3_e/h0klje0>o>]@030?OF_@070?OFaP3ge[d0mmK60?OF_@3ge/H0klje0?OF
aP020>o>]@<0mmJm00<0mmK60?OF_@3ge/H00P3ge/H60?ONcP060?OFaP3gg/h0mmk>0?ONcP3ge/H0
mmk>0P3ge/H60?ONcP80mmK60P3ge[d02P3_c[D0mkfe0>o>]@3_c[D0mlJ]0>nm[@3_aZd0kkf]0>nm
Y@3_c[D20>nm[@060>neY@3__JD0kkFU0>NeW03__JD0ikFL0P3W[I`20>N]U00;0=j]U03NW8`0gZfD
0=jUS03N[I@0eYb<0=jLS03FYH`0gZfD0<J]Y@3N]I`00P3FYH`0103N[I@0gZF<0=j]U03N[I@30=JU
S0070=j]U03FYH`0eZF<0=JUS03N[I@0eZF<0=K6_@0O0?Ogm`040?O_k`3gmoL0moOg0?O_kaP0moOg
00@0mno_0?Ogm`3gmoL0mno_2@3gmoL@0?ooo`003P3oool30?Ogm`070?O_k`3gmoL0moOg0?Ogm`3g
knl0moOg0?O_k`1@0?Ogm`030>oFcP3gc[D0mmJm00D0mmJm0`3_c[D20?OFaP030>o>]@3ge[d0mmJm
0080mmK600<0mmJm0?OFaP3ge/H0103ge/H60?ONcP040?OFaP3gg/h0mmK60?ONcP80mmK61P3gg/h3
0?OFaP80mmJm00@0mkfe0?OF_@3g_KD0klJ]0P3_c[D00`3gaZd0kkf]0>o6[@040>nmY@80kkFU0P3W
]I`02@3W[I`0ijfD0>N]W03W[I`0ijfD0=jLS03N[I@0gZF<0=jLS0020=jUS0070=JUS03N[I@0eZF<
0=jeY@3N]I`0gZfD0=jUS0020=JUS0040=jUS03N[I@0eZF<0=jUS0@0eZF<0P3N[I@00`3_e/h0moOg
0?Ogm`0C0?Ogm`030?O_k`3gmoL0moOg00`0moOg00<0mno_0?Ogm`3gmoL08@3gmoL@0?ooo`003P3o
oomJ0?Ogm`030>oFcP3_c[D0mmJm00D0mmJm00D0klje0?OFaP3ge/H0klje0?OFaP030?OF_@L0mmK6
00<0mmk>0?OFaP3gg/h00P3gg/h00`3gimh0mmk>0?ONcP020?OFaP80mmk>00<0mmK60?ONcP3gg/h0
1P3gg/h00`3ge[d0mmK60?OFaP020?OF_@040>o>]@3ge[d0klje0?Nm]@80klje00L0mkfe0>o6[@3_
_Jd0kkfU0>o6[@3__Jd0kkfU0080ikFL00<0ijfL0>NeW03W[I`0103W[I@00`3WYH`0gYb<0=jUS002
0=jLS080gZF<00H0eYb<0=jeW03N[I@0aZfU0=j]U03NYH`20=JUS080gZfD00D0eZF<0=jUS03FYH`0
gZfD0=JUS0020=j]U0030=k>eP3gmoL0moOg04H0moOg403oool000h0oooo103gmoL0103gknl0moOg
0?Ogm`3gknl50?Ogm`030?O_k`3gmoL0moOg04T0moOg00L0mmK60?OF_@3ge[d0klje0?OF_@3_c[D0
mmJm00@0klje0P3ge/H01`3ge[d0mmK60?OF_@3ge/H0mmJm0?OFaP3gg/h00P3ge/H00`3ge[d0mmk>
0?ONcP070?ONcP@0mmK60`3gg/h00`3gimh0mmk>0?ONcP020?ONcP<0mmK600<0mmJm0?OFaP3ge[d0
0P3ge[d20>o>]@040?Nm]@3_c[D0mkfe0>o6[@<0kkfU00@0kkFU0>NeW03_]JD0kkFU0P3W[I@0103W
[I`0ijfD0>N]U03W[I`30>N]U0090=jLS03NYH`0gZF<0=jUS03NW8`0gZF<0=JUS03N]I`0eZF<0080
g[FL00H0gZfD0=JUS03FYH`0eZF<0=jUS03N[I@30=JUS0030=j]U03N]I`0knOW01@0moOg00<0mno_
0?Ogm`3gmoL00P3gmoL00`3gknl0moOg0?Ogm`0/0?Ogma00oooo000>0?ooo`030?O_k`3gmoL0moOg
0080moOg00<0mno_0?Ogm`3gmoL01`3gmoL0103gknl0moOg0?Ogm`3gknl70?Ogm`030?O_k`3gmoL0
moOg03/0moOg00@0knOW0=jeY@3_c[D0mlje103ge[d0103ge/H0klje0?OFaP3ge[d30?OFaP030?OF
_@3ge/H0mmK600H0mmK600<0mmk>0?OFaP3gg/h01P3gg/h20?OFaP030?OF_@3gg/h0mmK600P0mmk>
103ge/H02@3ge[d0mmK60?OF_@3g_KD0mmJm0>o>]@3gaZd0klje0>o6[@020>nm[@080>nmY@3_]JD0
ikfU0>neY@3__JD0ijfL0>N]U03W[I`40>N]U0090=j]U03NYH`0gYb<0=jUS03N[I@0gYb<0=jUS03F
YH`0gZfD0080g[FL00T0eZF<0<J]Y@3N]JD0g[FL0=jUS03FYH`0gZF<0=JUS03N[I@00P3FYH`00`3N
[I@0g[FU0?O_k`0B0?Ogm`040?O_k`3gmoL0moOg0?O_kc80moOg403oool000h0oooo0P3gmoL00`3g
knl0moOg0?Ogm`050?Ogm`040?O_k`3gmoL0moOg0?O_k`L0moOg00<0mno_0?Ogm`3gknl0?`3gmoL0
0`3Wg^L0aZf]0=jeY@020>o>]@80mmJm00D0mmK60>o>]@3ge/H0mmK60?OF_@020?OFaP050?OF_@3g
e/H0mmK60?OFaP3ge[d0103ge/H01P3ge[d0mmK60?OFaP3gg/h0mmK60?ONcP80mmK60P3gg/h00`3g
e/H0mmk>0?OF_@020?OFaPD0mmk>00@0mmK60?ONcP3gg/h0mmK60`3gg/h20?OFaP80mmJm00D0mlje
0?Nm]@3_c[D0klJ]0?O6[@020>o6[@@0kkfU00T0ikFL0>nmY@3W]I`0ijfL0>NeW03W[I`0ijfD0=jU
S03W[I`00P3W[I@00`3N[I@0ijF<0=jUS0020=jUS00<0=jLS03FYH`0eZF<0=jeW02mYI`0eZF<0=je
W03N]JD0aZfU0=jUS03FYH`0gZfD0P3FYH`20=j]U0030<je[@3_inL0moOg01d0moOg00@0mno_0?Og
m`3gmoL0mno_4P3gmoL01@3gknl0moOg0?Ogm`3gmoL0mno_00l0moOg403oool000h0oooo103gmoL0
0`3gknl0moOg0?Ogm`1?0?Ogm`040>ONk`36[JD0[HAk0>NmY@<0mmJm00D0mmK60>oFcP3_c[D0klje
0?OF_@0=0?OFaP050?ONcP3ge/H0mmk>0?OFaP3gg/h00P3ge/H20?ONcPD0mmK61P3gg/h30?OFaP03
0?OF_@3ge/H0mmK60080mmK600D0mmJm0>o>]@3ge[d0mlje0?Nm]@020>o6[@080>nmY@3_c[D0klJ]
0>nmY@3W]I`0kkfU0>NeW03_]JD30>N]W0070=jeW03W[I@0gZfD0>N]U03N[I@0ijfD0=j]U0020=jU
S0040=jLS03NYH`0gZF<0=JLQ0@0gZfD0P3FYH`0103N]I`0eZF<0=JUS03FYH`20=j]U0030=JUS03N
[I@0kkf]01`0moOg00<0mno_0?Ogm`3gmoL0:P3gmoL@0?ooo`003P3oool20?Ogm`030?O_k`3gmoL0
moOg0080moOg00<0mno_0?Ogm`3gmoL06@3gmoL00`3gknl0moOg0?Ogm`0`0?Ogm`0;0;FUY@24JeX0
W7=S0>o6[@3_c[D0mmJm0?OFaP3_e/h0klje0?OFaP3ge[d00`3ge/H00`3gg/h0mmK60?OFaP090?OF
aP030?ONcP3ge/H0mmk>0080mmk>00<0mmK60?ONcP3ge/H01P3ge/H30?ONcP050?OFaP3gg/h0mmk>
0?ONcP3ge[d0103ge/H02P3ge[d0mmK60?OF_@3ge[d0klje0?OF_@3_aZd0mlJ]0>nm[@3_aZd30>nm
Y@040>neY@3W]I`0kkFU0>NeW080ijfL00<0ijfD0>N]W03W[I@01@3W[I@20=j]U080gZF<0P3FYH`2
0=j]U0<0eZF<0P3N]I`01`3FYH`0gZfD0=j]U03N[I@0eZF<0=j]U03_c[D05P3gmoL0103gknl0moOg
0?Ogm`3gknl_0?Ogma00oooo000>0?ooo`030?Ogm`3gknl0moOg0080moOg00D0mno_0?Ogm`3gmoL0
moOg0?O_k`040?Ogm`030?O_k`3gmoL0moOg00X0moOg00<0mno_0?Ogm`3gmoL0=`3gmoL01P3Fa]H0
Le9:06=2<@2]Q6/0klJ]0>o>]@80mmK600@0klje0?OF_@3ge/H0mmJm1@3ge/H00`3gg/h0mmK60?OF
aP030?OFaP030?ONcP3ge/H0mmK60080mmk>00<0mmK60?ONcP3gg/h00P3ge/H00`3gg/h0mmK60?OF
aP050?OFaP80mmk>1@3ge/H00`3ge[d0mmK60?OFaP040?OFaP040?OF_@3_c[D0mkfe0>o>]@80klJ]
00P0kkf]0>o6[@3__JD0kkfU0>neY@3W_JD0kkFU0>NmY@80ikFL00L0ijfD0>N]W03W[I@0gZfD0=jU
S03N[I@0ijfD00<0gZfD0`3NYH`00`3FW8@0eZF<0=jUS0030=j]U080eZF<0P3N]JD01P3FYH`0gZfD
0=j]U03N[I@0aZfU0=K6aQd0moOg00<0mno_0?Ogm`3gmoL0:@3gmoL@0?ooo`003P3ooomD0?Ogm`09
0=kFi`2<Lf<0FS4Q06=:@P2eS7<0klje0?OF_@3ge/H0klje0080mmJm103ge/H00`3gg/h0mmK60?OF
aP020?OFaP030?ONcP3ge/H0mmK600<0mmK600@0mmk>0?OFaP3ge/H0mmk>103ge/H0203gg/h0mmK6
0?OFaP3ge[d0mmK60?OF_@3ge/H0mmk>1@3ge/H00`3ge[d0mmK60?OFaP030?OFaP030?OF_@3ge/H0
klje0080mmJm00d0klje0?O6[@3_aZd0kkf]0>o6[@3__JD0klJ]0>nmY@3W_JD0kkfU0>NmY@3_]JD0
ikfU0080ikFL00/0ikFD0=j]U03W[I@0gZfD0=jUS03W]I`0ijfD0>NUS03N[I@0gZF<0=j]U0030=jU
S0090=JUS03N[I@0eZF<0=JUS03N[I@0eZF<0=jeW03>]Jd0g[FU00@0gZfD00<0kmK>0?Ogm`3gmoL0
A`3gmoL@0?ooo`003P3oool0103gknl0moOg0?Ogm`3gknl60?Ogm`040?O_k`3gmoL0moOg0?O_k`D0
moOg00<0mno_0?Ogm`3gmoL03P3gmoL00`3gknl0moOg0?Ogm`0[0?Ogm`0:0?ooo`3gknl0YHB405Xa
:@1J<B40Hd8a09AcJ`3ge[d0e/K60?OF_@<0mmK600<0mmJm0?OFaP3ge/H0203ge/H00`3gg/h0mmK6
0?OFaP020?OFaP030?ONcP3ge/H0mmk>00D0mmK600<0mmk>0?OF_@3ge[d0103ge/H00`3gg/h0mmK6
0?OFaP030?OFaP030>o>]@3ge/H0klje0080mmJm00@0mlje0?OF_@3ge[d0klje0P3gc[D40>o6[@03
0>nmY@3__Jd0klJ]00<0kkfU00l0ikfU0>nmY@3W]I`0ijfL0>NeW03W[I`0gZfD0>N]U03N[I@0ikFL
0=j]U03NYH`0ijfD0=jUS03N[I@00`3NYH`00`3FYH`0gZF<0=JUS0040=JUS0030=jeW03N]JD0g[FU
0080gZfD00<0eZF<0>oFcP3gmoL06`3gmoL00`3gknl0moOg0?Ogm`0Z0?Ogma00oooo000>0?ooo`04
0?Ogm`3gknl0moOg0?O_k`/0moOg00@0mno_0?Ogm`3gmoL0mno_0P3gmoL00`3gknl0moOg0?O_k`02
0?Ogm`040?O_k`3gmoL0moOg0?O_kc@0moOg00T0]IbL06]BBP1S@S40DS4Y048Y602<He80g[FU0?OF
aP3ge[d00`3ge/H00`3ge[d0mmK60?OFaP020?OFaP090?ONcP3ge/H0mmK60?OFaP3gg/h0mmK60?ON
cP3ge/H0mmk>00@0mmK600@0mmk>0?OFaP3ge/H0mmk>203ge/H40?ONcP<0mmK600X0mmJm0>o>]@3_
c[D0mlje0>o6[@3gaZd0klje0>o6[@3_c[D0kkf]0`3_aZd20>nmY@050>NeW03__JD0kkfU0>NmY@3_
_JD00P3W]I`01P3__JD0ikFL0>NeW03W[I`0ijfD0=j]U0<0ijfD00L0g[FL0>N]W03N[I@0gZF<0=j]
U03NYH`0gZfD0080gYb400@0eZF<0=jUS03FYH`0eZF40P3FYH`0203N[I@0eZF<0=JUS03N]I`0kkf]
0=jeY@3N[I@0mnONB@3gmoL@0?ooo`003P3oool<0?Ogm`030?O_k`3gmoL0moOg02D0moOg00<0mno_
0?Ogm`3gmoL06P3gmoL03@3oool0Je9:07=:>@1SBT80@RTH05Xa:@3>]Jd0mmK60?OF_@3ge/H0mmJm
0?OFaP3ge[d01@3ge/H0103gg/h0mmK60?OFaP3ge/H20?ONcP030?OFaP3gg/h0mmK600H0mmK600<0
mmk>0?OFaP3ge/H00`3ge/H30?ONcP80mmK600<0mmk>0?OFaP3gg/h0103ge/H00`3ge[d0mlJ]0>o6
[@020>o6[@<0kkfU00<0kkFU0>nmY@3__JD0103__JD30>NeW0030>nmY@3W]I`0kkfU0080ikFL00@0
ikfU0>N]U03N[I@0ijfD0P3N[I@01@3NYH`0ikFD0=j]U03W[I`0ijfD0080gZF<0140gYb40=JUQ03F
YH`0gYb40=JUS03NYH`0eZF40=JUS03NYH`0eZF<0=j]U03FYH`0gZfD0=jeY@3Fa[D0g[FL0>oWi`0Z
0?Ogm`030?O_k`3gmoL0moOg00<0moOg00<0mno_0?Ogm`3gmoL00`3gmoL00`3gknl0moOg0?Ogm`0@
0?Ogma00oooo000>0?ooo`80moOg00L0mno_0?Ogm`3gmoL0moOg0?O_k`3gmoL0mno_00D0moOg00<0
mno_0?Ogm`3gmoL06P3gmoL00`3gknl0moOg0?Ogm`0R0?Ogm`080?ooo`3Fa/h0Je9:06=:@P1B<BT0
FS4Y0=j]U03_e/h30?OFaP030?OF_@3ge/H0mmJm00<0mmK60`3gg/h20?OFaP060?ONcP3ge/H0mmK6
0?ONcP3ge/H0mmk>0P3ge/H00`3gg/h0mmK60?OFaP040?OFaP040?ONcP3ge/H0mmk>0?OFaP80mmk>
00<0mmK60?ONcP3ge/H00`3ge/H40?OF_@030?Nm]@3_aZd0klJ]00@0kkfU0P3W]I`80>nmY@040>Nm
Y@3__JD0ikfU0>NmY@80ikFL00X0ijfL0=j]U03W[I@0ijfD0=j]U03W[I@0ijfL0=j]U03W[I@0gZfD
0`3NYH`01`3FYH@0gZF<0=JUQ03NYH`0eZF<0=jUS03FYH@01P3FYH`00`3N]JD0e/Jm0?OWi`190?Og
ma00oooo000>0?ooo`D0moOg00<0mno_0?Ogm`3gmoL0B03gmoL00`3_inL0U7]c06]BBP0206=2<@06
0<J]Y@3ge/H0mmJm0?OF_@3ge/H0mmJm103ge/H00`3gg/h0mmK60?ONcP030?OFaP030?ONcP3ge/H0
mmK60080mmK600<0mmk>0?OFaP3ge/H02`3ge/H60?ONcP<0mmK600<0mmJm0?OFaP3ge/H00P3_c[D2
0>o6[@070>nmY@3_aZd0kkfU0>o6[@3__JD0ikfU0>neY@020>nmY@030>NmY@3W]I`0ikFL0080ikFL
00<0kkfU0>NeW03W]I`00P3W]I`00`3N]I`0ijfD0>NeU0020=j]U0040>N]U03N[I@0g[FL0>N]U080
gZfD0P3NYH`01@3NW8@0eZF<0=JUQ03NW8@0eZF<0080eZF400<0eZF<0=jUS03FYH`0103FYH`00`3N
]I`0g[FU0?O_k`0W0?Ogm`030?O_k`3gmoL0moOg01l0moOg403oool000h0oooo0`3gmoL01`3gknl0
moOg0?Ogm`3gmoL0mno_0?Ogm`3gknl01`3gmoL00`3gknl0moOg0?Ogm`0k0?Ogm`030?O_k`2]W8`0
FT8i0080LdXi00@0aYb40?OFaP3ge/H0klje0P3ge/H00`3ge[d0mmK60?OFaP050?OFaP<0mmk>2@3g
e/H00`3ge[d0mmK60?OFaP060?OFaPD0mmk>00<0mmK60?ONcP3ge/H00`3ge/H30?OF_@050>o>]@3_
_JD0kkfU0>nmY@3_aZd01@3__JD20>NeW080kkfU0P3W_JD00`3__JD0ikFL0>NeW0020>NeW0<0ijfD
00H0gZfD0=jUS03W]I@0gZfD0>N]U03W]I@20=j]U0060>NUS03NYH`0gZF<0=JUS03NYH`0eZF40P3F
YH`0203FYH@0eZF<0=JUQ03FYH`0eZF40=jUS03N[I@0eZF<0P3N[I@00`3N]I`0mnOW0?Ogm`0[0?Og
m`030?O_k`3gmoL0moOg01X0moOg403oool000h0oooo00<0moOg0?O_k`3gmoL0<03gmoL00`3gknl0
moOg0?Ogm`0H0?Ogm`0;0?ooo`2m]Kd0Je9:05Y2>@1[DTX0[Ib<0>oFcP3ge/H0klje0?OFaP3ge[d0
103ge/H00`3gg/h0mmK60?OFaP020?OFaP80mmk>00<0mmK60?ONcP3ge/H01`3ge/H00`3ge[d0mmK6
0?ONcP060?OFaPH0mmk>00<0mmK60?OF_@3ge/H00`3ge[d00`3g_KD0klJ]0>nmY@040>nmY@0:0>Ne
W03__JD0kkfU0>nmY@3W]I`0kkfU0>NeW03W_JD0ikFL0>NmY@H0ikFL0P3N[I@0103NYH`0ijfD0=j]
U03NYH`20=j]U0050=jUS03W[I@0gZfD0=jUS03N[I@00P3NYH`0103FYH`0eZF40=JUQ03NYH`20=JU
Q0040=jUS03FYH@0eZF<0=jUS080eZF<00@0gZfD0=JUS03N]I`0e/Jm403gmoL00`3gknl0moOg0?Og
m`0L0?Ogm`060?O_k`3gmoL0moOg0?O_k`3gmoL0mno_0P3gmoL0103gknl0moOg0?Ogm`3gknl>0?Og
ma00oooo000>0?ooo`X0moOg00<0mno_0?Ogm`3gknl0@03gmoL01P3oool0imkW07]SFP1J@ST0Hd8a
0:f4J`80mmK600<0klje0?OF_@3ge[d00P3ge[d40?OFaP030?ONcP3ge/H0mmk>00d0mmK600<0mmJm
0?OFaP3ge/H01@3ge/H70?ONcP80mmK600L0mmJm0?Nm]@3_c[D0klje0?O6[@3_aZd0kkf]00D0kkfU
1@3W]I`00`3__JD0ikFL0>NeW0040>NeW0050>NeU03N[I@0ikFD0>N]W03W[I@00P3N[I@00`3NYH`0
gZfD0=jUS0030=jUS0030>NeU03NYH`0gZF<00<0gZF<00D0gYb40=JUQ03FYH`0gZF<0=JUQ0040=JU
S0070=jUS03FYH`0gZfD0=JUS03N[I@0g[FU0>oFcP180?Ogma00oooo000>0?ooo`T0moOg00<0mno_
0?Ogm`3gmoL0@03gmoL01`3oool0aZfm06=:@P1S@S40DSTa07]SDP3gg/h00P3ge/H00`3ge[d0mmK6
0?OFaP030?OFaP80mmk>0P3ge/H00`3gg/h0mmK60?ONcP020?OFaP040?ONcP3ge/H0mmJm0?OF_@<0
mmK60P3ge[d60?OFaP060?ONcP3ge/H0mmK60?ONcP3ge/H0mmk>103ge/H01`3ge[d0mmK60?OF_@3_
c[D0mkfe0>o>]@3g_KD00P3__Jd20>neY@H0ijfL1`3W[I@01P3N[I@0ijfD0=j]U03W[I@0gZfD0>NU
S080gZF<00<0gZfD0=jUS03NYH`00P3NYH`0103FYH`0gZF<0=jUS03N[I@20=jUS0040=JUQ03NYH`0
gZF<0=jUS080eZF<00<0gZF<0=JUQ03FYH`00P3FYH`0103NYH`0gZfD0=JUS03FYH`20=j]U0030=je
W03Fa[d0knOW04H0moOg403oool000h0oooo1@3gmoL00`3gknl0moOg0?O_k`060?Ogm`050?O_k`3g
moL0moOg0?Ogm`3gknl0>@3gmoL03@3_inL0U7]c06=2<@1SBT80LdXi0;fLS03ge/H0klje0?OF_@3g
e/H0mmJm0?OFaP3ge[d01@3ge/H00`3gg/h0mmK60?OFaP060?OFaPH0mmJm0P3ge/H20?OF_@@0mmK6
0`3gg/h60?OFaP040>o>]@3ge[d0mmK60>o>]@<0mkfe0P3_]JD70>N]W0030>neY@3W[I@0ijfL0080
ijfL00P0ijfD0=jLS03W[I@0gZfD0>N]U03N[I@0gZF<0=j]U0P0gZF<00<0eZF<0=jUS03NYH`00P3N
YH`0103FYH@0gZF<0=JUQ03FYH@20=jUS0080=JUS03NW8@0gZF<0=jLQ03FYH`0gZF<0=JUS03N[I@2
0=jUS0040=jeW03FYH`0g[FL0>oFcQT0moOg00<0mno_0?Ogm`3gknl0:P3gmoL@0?ooo`003P3oool2
0?Ogm`030?O_k`3gmoL0moOg00D0moOg00<0mno_0?Ogm`3gmoL0?P3gmoL02@3oool0_KFm05Y2>@1S
BT80LdXi0:f<Q03_e/h0mmK60?OF_@0;0?OFaP80mmk>1P3ge/H50?OF_@050?OFaP3ge[d0mmJm0?OF
aP3ge[d01P3ge/H00`3gg/h0mmK60?OFaP040?OFaP030?ONcP3g_KD0mkfe0080mkfe103_U8`20>ND
Q0080>N4N`3NW8@0ihAk0=jLS03_U8`0ijfD0=jLS03_U8`40>N]U0030>NUS03N[I@0gZF<00@0gZF<
00@0eZF<0=jUS03NYH`0gZF<0P3FYH`00`3NYH`0eZF40=jUS0040=jUS0050=JUS03FYH@0gZF<0=JU
S03NYH`00`3FYH`0103NW8@0eZF40=JUS03NYH`20=JUS0060=jUS03FYH`0g[FL0=jeW03__Jd0knOW
=@3gmoL00`3gknl0moOg0?Ogm`0=0?Ogma00oooo000>0?ooo`P0moOg00<0mno_0?Ogm`3gmoL00P3g
moL00`3gknl0moOg0?Ogm`0l0?Ogm`0609AkL`1S@S40HdY208acH`3_e/h0mmk>0P3ge/H01P3ge[d0
mmK60?OFaP3ge[d0mmK60?OF_@@0mmK60P3gg/h70?OFaPH0mmJm00<0mmK60?OF_@3ge/H00`3ge/H0
103gg/h0mmK60?ONcP3gg/h40?OFaP030?ONcP3ge/H0mmK60080mkfe00D0mlJ]0>nDS03_U8`0mkfe
0>N]W0020>nDS0L0ihAk00L0kiB<0>N4N`3WQ7/0ihAk0=J<N`3WU8@0ijF<0080ijfD00@0gZfD0=jL
S03NYH`0gYb40`3NYH`01P3NW8@0eZF<0=jUS03NW8@0eZF40=JLQ080eZF400<0gZfD0=jUS03NYH`0
0P3NYH`00`3FYH`0gZF<0=jUS0030=jUS080eZF400X0gZF<0=JUS03NW8@0gZfD0=JUS03N[I@0eZF<
0=jeW03FYH`0klje903gmoL00`3gknl0moOg0?Ogm`050?Ogm`060?O_k`3gmoL0moOg0?O_k`3gmoL0
mno_4P3gmoL00`3gknl0oooo0?ooo`0>0?ooo`003P3oool40?Ogm`040?O_k`3gmoL0moOg0?O_k`<0
moOg00<0mno_0?Ogm`3gmoL0?@3gmoL0203Wg^l0Nf=B058i<@1cDTX0kkf]0>oFcP3_c[D0mmJm203g
e/H0103ge[d0mmK60?ONcP3gg/h60?OFaP030?OF_@3ge/H0mlje00L0mmJm103ge/H00`3gg/h0mmK6
0?ONcP020?OFaP060?ONcP3ge/H0mmK60?OFaP3gg/h0mmK60`3g_KD00`3F_LH0mlJ]0>nDS0020>nD
S0@0ihAk00@0gW][0>N4N`3WQ7/0gYb40`3WQ7/00`3NNf/0ihAk0>N4N`020=J<N`040>NDQ03NW8`0
ijF<0=jLS080gZF<00<0eZF<0=jUS03NYH`00P3NW8@0103FYH`0eYb40=JUQ03FYH@40=jUS0030=JU
S03NYH`0eZF<00<0gZF<0`3FYH`0103NW8@0eZF<0=jUS03FYH`20=jUS0<0gZfD00<0g[FL0=jeY@3N
c]H0A03gmoL@0?ooo`003P3oool00`3gmoL0mno_0?Ogm`090?Ogm`030?O_k`3gmoL0moOg03`0moOg
00D0c[Fe06]BBP1S@S40[Hb40?ONcP030?OFaP80mmJm103ge/H00`3ge[d0mmK60?OFaP020?OFaP03
0?ONcP3ge/H0mmK600D0mmK60P3ge[d01@3g_KD0klje0?O>]@3ge[d0mlje0080mmJm0`3ge/H00`3g
g/h0mmK60?OFaP040?OFaP030?ONcP3ge/H0mmk>00L0mkfe0`3_U8`70>N4N`030>nDS03WQ7/0ihAk
0080ihAk00L0gW][0>N4N`3WQ7/0ihAk0=J<N`3WQ7/0cXb40080gYb<0P3NYH`30=JUS080eZF400L0
eYac0=JUQ03FYH@0eZF<0=JUQ03NYH`0gZfD00P0gZF<00h0eZF40=jUS03NYH`0eZF40=JUS03NYH`0
eZF<0=j]U03FYH`0gZfD0=jeW03FYH`0kkf]0?OWgQT0moOg00<0mno_0?Ogm`3gmoL09`3gmoL@0?oo
o`003P3oool90?Ogm`030?O_k`3gmoL0moOg03l0moOg00L0U7]c058i<@24JeX0klje0?ONcP3_c[D0
mmJm0080mmK600<0mmJm0?OFaP3ge[d00P3ge/H30?OF_@030?ONcP3ge/H0mmK600<0mmK6103ge[d0
103gc[D0mmK60?O>]@3gc[D30?OF_@030?Nm]@3ge[d0mmK600@0mmK600H0mmk>0?OFaP3gg/h0mmK6
0?ONcP3ge/H50?Nm]@030?OWgP3g_KD0mkfe0080mlJ]00@0kkFU0>nDS03WQ7/0ihAc103WQ7/00`3N
W8`0kiB<0>N4N`040>N4N`070=ikJ`3WQ7/0ihAk0>N4N`3NNf/0ihAk0=J<N`020=jLS0D0gZF<00H0
eYb40<jDN`3FW8@0eZF40=jLQ03FYH`20=jUS0030=JUS03N[I@0gZF<0080gZF<0P3N[I@20=jUS003
0=JUQ03NYH`0gZF<0080eZF<00D0gZF<0=j]U03N[I@0eZF<0=j]U0020=jeW0030=K6aP3gmoL0moOg
01D0moOg00<0mno_0?Ogm`3gmoL09@3gmoL0103gknl0moOg0?Ogm`3gmoL@0?ooo`003P3oool;0?Og
m`030?O_k`3gmoL0moOg03/0moOg00X0e/K60:fLS01S@S40[HA[0>oFcP3gg/h0mmJm0>o>]@3ge/H0
mmJm1@3ge/H20?OF_@030?OFaP3gg/h0mmK600D0mmK60`3ge[d01@3gc[D0klje0?O>]@3_c[D0mlje
0080mmJm00<0mkfe0?O>]@3ge[d0203ge/H40?Nm]@030=k>eP3g_KD0mkfe0080mkfe0P3_U8`20>N4
N`80ihAc0P3WNf/20=i[FP030=ikJ`3NJeX0ihAk0080ihAk00H0ig][0>N4L`3NNf/0ihAc0=ikJ`3W
Q7<40>N4N`0>0=J<N`3FNf/0ihAk0=JLS03FW8@0gYb<0=JUQ03NYH`0eZF40=JLQ03FYH@0eYac0=JL
Q03NW8@50=jUS0040=j]U03NYH`0gZF<0=j]U0@0gZF<00P0eZF40=jLQ03NYH`0eZF<0=jUS03N[I@0
eZF<0=jUS080gZfD00<0g[FL0=K6]@3gmoL00P3gmoL00`3_inL0moOg0?Ogm`0l0?Ogma00oooo000>
0?ooo`D0moOg00<0mno_0?Ogm`3gmoL0?`3gmoL0203oool0g/kF09B4Q02LS8`0FS4Y0=jeY@3gg/h0
klje0`3ge[d00`3ge/H0mmJm0?OFaP020?OF_@040?OFaP3ge[d0mmJm0?OF_@P0mmK60P3ge[d00`3g
c[D0klJ]0>o6[@020?O>]@030?OF_@3gc[D0klJ]0080mmJm0`3ge/H20?ONcP80mmK6103g_KD01`3g
g/h0mkfe0?ONcP3g_KD0mlJ]0>N]W03WU8@00P3WQ7<01@3WNf/0eW=S0=i[FP3NJeX0eW=S0080gV]J
103WNf/00`3WQ7<0ig][0>MkJ`020=i[FPH0gW][0P3WQ7/0203FS7/0gYb40=jLQ03NW8`0eZF<0=jL
Q03FYH`0eYac0P3FW8@20=JUQ0@0gZF<0`3N[I@0103NYH`0gZfD0=jUS03WYH`20=jUS0070=JUQ03N
W8@0eZF<0=jUS03FYH`0gZfD0=jUS0020=j]U0030=JUS03N]I`0g[FU0080mno_@03gmoL@0?ooo`00
3P3oool20?Ogm`030?O_k`3gmoL0moOg00D0moOg00@0mno_0?Ogm`3gmoL0mno_>@3gmoL01`3gknl0
W8b<07]SFP1cFU80S7=S0?ONcP3_c[D0103ge[d20?OFaP<0mmJm00<0mlje0?OF_@3ge/H0203ge/H3
0?OF_@050?O>]@3gaZd0kkfU0>o>]@3gc[D00P3gaZd00`3_aZd0mlje0?OF_@020?OFaP80mmk>0P3g
e/H80?Nm]@050>neY@3WU8@0iiB40>N4L`3FLf<00P3NJeX00`3FHe80gV]J0=i[FP080=i[FP030=Ic
H`3NJeX0gV]J00@0gV]J0`3NNf/02@3WQ7/0eW][0=IkJ`3FS7/0cXb40=JLQ03NW8`0eZF<0=jLQ002
0=JLQ0060=JLL`3FW8@0eZF40=JUQ03FYH`0gYb41@3NYH`01`3N[I@0gZF<0=jUS03N[I@0gZF<0=JU
Q03NYH`00P3FYH`0203NYH`0eZF<0=jUS03NYH`0eZF<0=j]U03FYH`0g[FL0P3Wg^L00`3gknl0moOg
0?Ogm`0m0?Ogma00oooo000>0?ooodH0moOg00L0oooo0<J]_@2<Lf<0Nf=J058a:@3_c[D0kmK>0080
mmJm00<0mmK60?OF_@3ge/H01@3ge[d20?O>]@030?OF_@3ge/H0mmK600H0mmK60P3ge[d0303g_KD0
mlje0>o6[@3__JD0klJ]0?O>]@3_aZd0mlJ]0>o6[@3gaZd0mmJm0?OFaP80mmk>00<0mmK60?Nm]@3g
_KD00`3g_KD0103gaZd0mkfe0>neY@3W[I`20>nDS00:0>N4L`3WNf/0gW][0=ikJ`3>S8@0gYb40<j<
Q03>Le80eXak0>N4N`80gW][00H0eW][0<iJBP3FNf/0eW=S0=i[FP3FHe820=i[FP030=ISDP3NJeX0
eV=B0080gV]J00<0eW=S0=ikJ`3NNf/00P3FS7/0303FNf/0eXak0=J<N`3FW8`0gYb<0=JUQ03FW7<0
eYb40=JLL`36W8@0eYac0=JUQ0D0gZF<00@0gZfD0=jUS03NYH`0ijfD103NYH`01`3FYH@0gYb40=j]
U03FYH`0gZfD0=jUS03FYH`00`3N[I@0103N]I`0kmK>0>oFcP3Wg^lo0?Ogma00oooo000>0?ooo`<0
moOg00<0mno_0?Ogm`3gmoL01@3gmoL0103gknl0moOg0?Ogm`3gknlg0?Ogm`080=kFi`2LS8`0LeYB
05Y2>@1B<BT0mmk>0?OFaP3_c[D40?OF_@030?OFaP3ge[d0mmJm00<0mmJm00<0mlje0?OF_@3gg/h0
1P3ge/H30?OF_@030>o>]@3_aZd0kkfU00H0kkfU0P3ge[d01@3ge/H0mmk>0?OFaP3ge/H0mkfe00@0
mlJ]00/0ijfL0>nDS03_U8`0iiB40>N4N`3WQ7<0gW][0=J<N`3>S8@0gYb<0=jeY@020>N]W0070<I[
DP3>]KD0mkfe0=jeY@3N]I`0gYb<0;EcFP020>N]W0030=jLQ03FNf/0eW=S0080eV=B00<0cUY:0=IS
DP3FHe800`3NJeX20=ikJ`80eW][0`3FS7/02@3NW8`0eZF<0=JLQ03FYH@0cYAk0=JLL`3FW8@0eZF4
0=jLQ0020=JUQ0@0gZF<00D0ijF<0>N]U03NYH`0gZF<0=j]U0020=jUS080eZF<00<0gZfD0=jUS03N
[I@00P3NYH`30=j]U080g[FU00<0mnON0>ONi`3gknl0?@3gmoL@0?ooo`003P3oool00`3gknl0moOg
0?Ogm`050?Ogm`030?O_k`3gmoL0moOg00@0moOg00<0mno_0?Ogm`3gmoL01P3gmoL0103gknl0moOg
0?Ogm`3gknl30?Ogm`030?O_k`3gmoL0moOg0280moOg00T0oooo0>ONi`2LS8`0S7=[06=:@P12:B40
Q6=B0?OFaP3g_KD00`3ge[d00`3ge/H0mmJm0?OF_@020?OF_@040>o>]@3gc[D0mlje0?O>]@P0mmK6
00D0mmJm0?O>]@3ge[d0mlje0?O6[@030>nmY@080>NeW03__JD0kkfU0>o>]@3ge[d0mmk>0?OFaP3g
g/h20?Nm]@0I0?O6[@3_]JD0kkFU0>N]W03_U8`0iiB40>N4N`3WQ7<0eW=S0=IkJ`3WQ7/0cYAk0<je
]@3_e/h0e/Jm0>oFcP3Fa/H0e/Jm0=JLS03Nc]H0e/Jm0?Nm]@3>]KD0g[FU0<j<L`020<je]@80g[FU
00X0cXac0:ESBP3FLf<0_HA[0<icDP3>FTX0gV]J0=ISDP3FLf<0gV]J103FNf/20=J<N`080<j<Q03F
W8@0eYb40=JLL`3>U7/0eYac0=JLQ03FYH@20=jLQ0040=jUS03NW8@0gZfD0>N]U0@0gZfD00@0ijfD
0=j]U03NYH`0eZF<0`3NYH`20=j]U080gZF<0P3N[I@02@3FYH`0gZfD0=j]U03Fa[D0imkW0>oWi`3W
g^l0mno_0>oWi`0j0?Ogma00oooo000>0?ooo`D0moOg00<0mno_0?Ogm`3gmoL00P3gmoL0103gknl0
moOg0?Ogm`3gknl50?Ogm`030?O_k`3gmoL0moOg02l0moOg00L0aZfm08acN`1[DTX0DS4Y05Xa:@2]
S8@0mmK600@0mmJm0`3ge/H30?OF_@80mlJ]00@0mlje0?OFaP3ge/H0mmk>0`3ge/H00`3gg/h0mmK6
0?O>]@020?O>]@80klJ]00<0kkfU0>NeU03W]I@00P3W]I@02@3__JD0mlje0?OFaP3gg/h0mmK60?Nm
]@3gaZd0kkFU0>nDS0020>N]U00:0>nDS03WQ7<0ig][0=ISDP3>FTX0]E8i0=IcH`36[JD0eW][0>N]
W080e/K600D0kmK>0=K6aP3>]KD0c[Fe0=K6cP020<je]@030>nm[@3>]KD0_JFL0080e/Jm00h0mkfe
0<je]@3>S8@0[F]B0<JDQ03FW8`0_HA[0:ESBP2DDST0cUY:0=ISDP3FLf<0eV=B0=IcH`<0eW][0`3F
S7/01@3FYH@0eYb40=JUQ03FW8@0eYac0080eZF400D0gYb40=JUQ03NYH`0gZF<0=j]U0020>NeU0<0
gZfD0P3NYH`0203NW8@0eZF<0=jUS03N[I@0gZF<0=j]U03NYH`0eZF<0P3N[I@0203FYH`0gZfD0=j]
U03N]I`0imkW0>ONk`3gknl0imk_>`3gmoL@0?ooo`003P3oool?0?Ogm`030?O_k`3gmoL0moOg0380
moOg00P0knOW09b<S02<Ng<0He9:058a:@1[DTX0c[F]0>o>]@D0mmJm0P3ge/H20?OF_@080?O>]@3g
aZd0klJ]0?O>]@3ge/H0mmk>0?OFaP3gg/h40?OFaP040?OF_@3g_KD0klJ]0?O6[@80kkfU0P3W]I@2
0>NUS0050>nmY@3ge[d0mmk>0?ONcP3g_KD00P3W[I`40>nDS0090>N4L`2mFT80_EY20<iJBP3>Le80
eV=B0<icDP3FLf<0iiB40080gW][00L0eXac0>N4L`3FS7<0eW][0=JLQ03FW8`0eZF<0080aZfU00`0
g[FU0=JLS03>]KD0e/Je0<je]@3Fa[D0eYb<0;f4J`3FW8`0aZfU0<JDN`2eNf<20:E2<@040<I[DP3F
He80eV=B0=IcH`80eW][00@0eXak0=IkJ`3FS7/0cXb40P3FW8@01P3FW7<0cYAk0=JLL`3FW8@0eZF4
0=jLQ080gZF<0P3N[I@0203NYH`0gZfD0>NeU03W]I`0ikFD0=j]U03NYH`0gYb40P3NYH`30=j]U003
0=jUS03N[I@0gZfD0080gZfD0`3N]I`00`3Fa/H0knOW0?Ogm`0a0?Ogm`040?O_k`3gmoL0moOg0?O_
k`L0moOg403oool000h0oooo2@3gmoL00`3gknl0moOg0?Ogm`040?Ogm`030?O_k`3gmoL0moOg01`0
moOg00<0mno_0?Ogm`3gmoL04@3gmoL0203Wg^l0_KFm0;FLW02<Ng<0FT8i058a:@36W8@0mmK6103g
e[d02`3ge/H0mmJm0?OFaP3ge/H0mmJm0?O>]@3_aZd0mlJ]0>nmY@3_aZd0mmk>00@0mmK60P3ge[d0
703ge/H0mlJ]0>o6[@3gaZd0kkfU0>NeU03WYH`0gYb40=jDL`3NW8@0kkfU0?OF_@3ge/H0mkfe0>N]
U03WQ7/0iiB40>N4N`3WQ7<0cXAS0<I[DP24:AP0HaP@0=IkJ`3_c[D0ijfL0<j4H`3NJeX30>NDQ080
gW][00D0kkFU0?OWgP3ginL0mno_0?OWgP020>oFcP0;0>N]W03WNf/0eW=S0>NDQ03FS7/0cXac0=Ic
H`3>LeX0aV]B0;f4H`3FW8`00P2mYI`01`36U8@0[G][0:E[DP2]LeX0YF=:0:EB>@3>FTX00P3FHe80
1@3>LeX0cXac0=IkJ`3>U7/0eXak0080eYb400D0eYac0<JLQ03FW7<0eZF40=jLQ0020=jUS080gZfD
0P3W]I`40>NeU0040=j]U03NYH`0gZF<0=jUS0<0gZfD00@0gZF<0=JUS03NYH`0gZF<103N[I@00`3_
_Jd0e/K60=kFi`020?OWgSX0moOg403oool000h0oooo00<0moOg0?O_k`3gmoL02P3gmoL00`3gknl0
moOg0?Ogm`0c0?Ogm`080=K6cP2LS8`0]JF]07]SFP12:B40Je9:0?Nm]@3ge/H30?OF_@030?OFaP3g
e[d0mmK600<0mmJm103gaZd00`3_c[D0mmK60?OFaP060?OFaP040>o6[@3gaZd0kkfU0>NeW080ijF<
0P3NW8@01@3NYH`0klJ]0?OFaP3gaZd0ijF<0080gW][00P0aV]B09aJ@P3>LeX0cXb40=jeW03Fa[d0
aXac0>o>]@80mnON00P0kkfU0>nm[@3gg/h0mmk>0?Nm]@3W[I@0ihAk0?OWgP80mno_01<0mnOW0?OW
gP3gimh0kmK>0?OWgP3Fa/H0klje0=k>eP3_e/h0mmk>0=K6aP3__Jd0eXak0=IkJ`36Je80_HA[0;fL
S036U8@0]HA[0080[G=J00@0YG=J09aJ@P2U@S40_EY20P3>FTX02`3FLf<0aV]B0=IkJ`3FS7/0eYb4
0=JLL`3FW8@0eXak0=JUQ03NW8@0eZF<0080gZF<00@0gZfD0>NeU03W]I`0kkfU0P3W]I`20>NeU004
0=j]U03NYH`0gZF<0=jUS080gZfD00<0gZF<0=j]U03N[I@00P3NYH`02`3FYH`0gZfD0=j]U03N[I@0
aZfU0>o>]@3Nc]H0g]KW0=K6_@3gimh0mno_02P0moOg00<0mno_0?Ogm`3gknl03@3gmoL@0?ooo`00
3P3oool50?Ogm`030?O_k`3gmoL0moOg00/0moOg00<0mno_0?Ogm`3gmoL00P3gmoL00`3gknl0moOg
0?Ogm`0X0?Ogm`070:fU[@2DQ8@0W8b<05Y2>@1B<BT0]Hac0>oFcP030?OF_@80mmK60`3ge[d20?O>
]@050?O6[@3__JD0kkfU0>nmY@3ge[d01@3ge/H01P3gg/h0mmK60?OF_@3gaZd0kkfU0>NeW080ijF<
0140gYb40=jDL`3FW7<0ijF<0>o6[@3_]JD0gW][0=i[FP3FHe80W3TY048H402DHdX0g[FL0>nm[@3g
imh0mmk>0?O>]@040?OWgP@0mno_00<0mnON0>nmY@3ginL00`3gknl20?OWgP030?ONcP3gimh0klje
0080kmK>00<0mnON0>oFcP3_e/h00P3_e/h03`3Fa/H0ihAk0;EB>@36Je80]G=J0:E[DP2DLf/0]Hac
0:ekJ`2DDST0LdXi0:E2<@2mFT80cUY:0<I[DP020=IcH`080=J<N`3NW8@0eYb40=JLL`36W8@0eYac
0=JUQ03NW8@20=jUS0050>NeU03W]I`0ikFL0>NmY@3__JD00P3W]I`20>NeU080gZF<0P3N[I@01P3F
YH`0gZfD0=j]U03NYH`0gZfD0=JUS0@0gZfD00P0g[FL0=K6]@3ginL0moOg0=kFi`3Fa]H0g/kF0>ON
icL0moOg403oool000h0oooo0P3gmoL00`3gknl0moOg0?Ogm`0n0?Ogm`070:fDU02<Ng<0LeYB04Xa
<@1SBT80g[FU0?OFaP020?OF_@050?OFaP3ge[d0mmK60?OFaP3gc[D00P3ge[d20?O6[@030>nmY@3g
aZd0mlJ]00@0mmK601/0mmk>0?OFaP3ge/H0mmK60?OF_@3_aZd0kkfU0>NeU03WYH`0gYb40=jDL`3>
S6/0gYb40=jUS03W[I@0eW=S0<iJBP2eDST0W3TY08A:>@2DDST0g[FL0>o>]@3ge/H0mnON0?ONcP3g
e/H00`3gimh30?OWi`80mno_00<0mnON0?ONcP3ginL00`3gknl30?OWgP040?ONcP3_c[D0kmK>0?OW
gPH0kmK>00H0g[FL0<iJBP3>LeX0cUY:0:eJ@P2UJe820:ekJ`0507=2<@1cBST0Q59209`i:@2mFT80
0P3>FTX00`3>LeX0cXac0<j<Q0020=JLQ0040=JLL`3FW8@0eYac0=JUS080gZF<00@0gZfD0>NeU03W
]I`0ikFL0P3__JD20>NeU0050=j]U03NYH`0gZF<0=j]U03NYH`00P3N[I@30=jUS0D0gZfD00<0g[FL
0>nm[@3Ne^L00P3gknl0103gmoL0e/KF0=k>eP3gknlf0?Ogma00oooo000>0?ooo`H0moOg00<0mno_
0?Ogm`3gknl00P3gmoL0103gknl0moOg0?Ogm`3gknl30?Ogm`030?O_k`3gmoL0moOg00@0moOg00<0
mno_0?Ogm`3gmoL09`3gmoL01`2<Ng<0He9:06=:@P1B<BT0Q5920?OFaP3_c[D00`3ge[d20?OFaP@0
mmJm00D0mlje0?O6[@3__JD0kkfU0?OF_@080?OFaP030?OF_@3gaZd0kkfU0080ijF<00h0gYAc0<j<
J`3>Q6<0eXak0=J<L`3FHe80]E8i09`i:@2<:B40S34Y09aJ@P2mQ6/0e/Jm0>oFcP80mmk>1P3gimh0
0`3ginL0mno_0?O_k`020?OWgP050?ONcP3ginL0mno_0?O_k`3ginL00`3gimh0103_e/h0klje0>oF
cP3ginL30?OWgP<0kmK>00d0g[FU0>NmY@3Fa[d0aZfU0<j<Q02]FT80YE8i09AJBP2<<BT0FS4Q06<i
<@1c@RT0W3TY0080_EY200T0aV]B0<j<L`3FS7<0eYb40=JUQ03FW8@0eYac0=JUQ03NW8@00P3NYH`0
0`3WYH`0ikFL0>NeU0020>nmY@030>NeW03__JD0ikFL0080ikFD0P3NYH`01`3N[I@0gZF<0=jUS03N
[I@0eZF<0=jUS03FYH`01@3N[I@00`3N]JD0klje0=kFi`030?O_k`030>oWi`3Wg^l0moOg03D0moOg
403oool000h0oooo0P3gmoL00`3gknl0moOg0?Ogm`0;0?Ogm`030?O_k`3gmoL0moOg0240moOg00D0
knOW0?Ogm`3_inL0moOg0>oWi`020?O_k`L0moOg00X0imk_08acJ`1B@ST0DSTa058a:@2<Lf<0mmk>
0?OF_@3_c[D0mmK61P3ge[d01P3gc[D0klJ]0?O6[@3gaZd0klJ]0?OF_@P0mmK601<0mmJm0>nmY@3W
]I@0ijF<0=jLQ03NU7<0cXAS0<j<J`3>LeX0]E8i0:E2<@2<:B40Q2TH07/Y602DDST0YG=J0=jeW03g
e/H0mmJm00<0mnON00@0mmk>0?OWgP3gimh0mmK60P3gimh00`3ginL0mno_0?OWgP020?OFaP040?OW
gP3gknl0mno_0?O_k`80mnON00T0mmk>0>o>]@3__JD0kmK>0?OWi`3_e/h0mnON0>oFcP3gimh00P3_
e/h00`3_aZd0e/K60?OFaP020>oFcP0>0<J]Y@2DDST0W3TY08`a:@1c8A00NbTH048Y8@1:40P0W3TY
0;EB>@3>FTX0aV]B0=IkJ`3FS7<20=JLQ0030=JLL`3FW8@0eZF40080gZF<00@0gZfD0>NeU03__JD0
ikFL0P3__JD00`3W]I`0kkfU0>NeU0040=jUS0<0gZfD0`3NYH`50=j]U0060=jeW03Fa[D0kmK>0=K6
eP3gknl0imk_0P3gknl00`3Wg^l0mno_0?Ogm`0c0?Ogma00oooo000>0?oooaP0moOg00L0mno_0?Og
m`3gmoL0moOg0?O_k`3gmoL0mno_01<0moOg00P0knOW0?Ogm`3gmoL0moOg0?O_k`3gmoL0mno_0?Og
m`80imk_00<0mno_0?Ogm`3gknl00`3gmoL01`3Fa]H0U8B406=BBP1J@ST0FS4Y0<JLQ03gg/h00P3g
e[d0203ge/H0mmJm0?OFaP3ge/H0mmJm0?OFaP3ge[d0mlje0P3gaZd0103__JD0mlje0?OF_@3ge[d3
0?OFaP80mmk>01D0mmK60?OF_@3ge[d0ikFL0>NeU03WYH`0gYAc0<j<J`3FLf<0cXa[0:E2<@2L>BT0
S2TQ08@Y601k:AP0Nc4Q09AJDP2eLeX0ijfL0>NeW03_c[D00P3gimh01@3ge/H0mmk>0?OWi`3gimh0
mmJm0080mnON00H0mnOW0?O_k`3gimh0mmK60?OF_@3gimh30?O_k`80mnON00D0mmK60?O6[@3W[I`0
mmK60?OWi`030?OWgP80kmK>01D0mmK60>nm[@3Fa/H0mmK60=K6aP3ge/H0kmK>0<JDQ02UDST0[F]B
0:ekJ`1B8AP0BQ0801P@401:40P0W3TY0;EB>@36Je80cUY:0<j<L`3FS7/00P3FW8@01`3FW7<0eYb4
0=jUS03NYH`0gZfD0>NeU03W]I`0103__JD20>NeW0050>NeU03N[I@0gZfD0=j]U03FYH`00P3N[I@0
103FYH`0gZF<0=jUS03N[I@20=JUS00<0=jUS03N[I@0g[FL0=jeY@3>_KD0]IbL0<jmcP3Fa/h0e/KF
0=kFi`3gknl0imk_=03gmoL@0?ooo`003P3oool_0?Ogm`030?O_k`3gmoL0moOg00d0moOg0P3Wg^l0
203Fc]h0[Ib<07]SFP1B>C40DS4Y08acH`3ge/H0mmJm103ge/H01P3ge[d0mlje0?OF_@3ge[d0mlje
0>o6[@80mlJ]00@0klje0?O>]@3_aZd0mlJ]103ge/H0303gg/h0mmK60?O>]@3gaZd0ijF<0=jDL`3N
W8@0gYAc0<j4H`3>S6/0cYAc08`Y8@80YD8a00/0S34Y08@Y601c8A00YD8a0=J<L`3NNf/0ijF<0?Nm
]@3W[I@0iiB40?O6[@020?ONcP80mlJ]00P0mmJm0?OWgP3gimh0mnON0?OF_@3_]JD0kkf]0?OF_@<0
mnOW00T0mmk>0?OFaP3gaZd0kkFU0>N]W03W[I@0klje0>oFcP3gimh00`3_e/h00`3W_JD0gZF<0>oF
cP020?OFaP0=0=K6aP3ge/H0e/Jm0=jeY@3N]I`0klje0;F<L`24BST0[G][07=BBP0Q4100@QP@0:EB
>@020;eJ@P050<icFP3FS7/0gZF<0=JLL`3FYH@00P3NYH`01@3W]I@0ikFL0>nmY@3__JD0klJ]00<0
kkfU00@0ikFL0>NeU03W[I@0ikFD0P3N[I@01@3NYH`0eZF<0=JUS03NYH`0eZF<00<0gZF<0`3N[I@0
2P3W_JD0e/Je0;FLW01cDTX0U8B40;FU[@3>_Lh0e/kN0>ONi`3_inLc0?Ogma00oooo000>0?ooo`<0
moOg00<0mno_0?Ogm`3gmoL0:03gmoL00`3gknl0moOg0?Ogm`0>0?Ogm`80oooo00L0g]KW08akL`1S
@S40BS4a058a:@36U7/0mmK60080klje203ge[d01@3gaZd0klJ]0?O6[@3ge[d0mlJ]0080kkfU0`3g
e/H0303gg/h0mmK60?OFaP3ge[d0mlJ]0>NUS03>Q6<0gYb40=J<L`36S6<0cXa[0=J<N`80_EY200`0
]E8i0:E2<@2<:B40Q2TH0:eJ@P3WQ7<0gW][0>NDQ03WYH`0gYAc0>NDQ03__JD20?OF_@040?Nm]@3_
]JD0mlJ]0?ONcP80mnON00l0mlJ]0>N]U03g_KD0mmJm0?OFaP3gimh0mmk>0?OF_@3gaZd0ijfD0>nD
S03W[I`0kkFU0>nmY@3ge[d00P3_e/h20?OFaP090>N]U03FW7<0klje0=K6aP3ge/H0mmJm0>o>]@3_
aZd0eZF<0080g[FU00/0g[FL0;fLS03FYH`0_Ib<08A:>@1c@S40W3TY0:E2<@2eDST0aV]B0<j<L`03
0=JLQ0040=jLQ03NYH`0gZfD0>NeU080kkfU0P3_aZd01P3__JD0ikfU0>nmY@3W]I`0gZfD0=jUS0<0
gZfD00<0gZF<0=JUS03NW8@00P3NYH`20=j]U0070=jUS03N[I@0gZfD0=jeW03Fa[D0c[F]0:fDU003
0<jm]@030=K6_@3Nc]H0g]KW01T0moOg00<0mno_0?Ogm`3gmoL05`3gmoL@0?ooo`003P3oool:0?Og
m`030?O_k`3gmoL0mno_00@0moOg00H0mno_0?Ogm`3gmoL0mno_0?Ogm`3gknl20?Ogm`060?O_k`3g
moL0moOg0?O_k`3gmoL0mno_7@3gmoL00`3gknl0moOg0?Ogm`020=k>eP0;0;FLW01SDTX0@RTQ058a
:@1S@S40g[FU0?OFaP3g_KD0mmJm0?Nm]@3ge/H0103ge[d30?O6[@060>nmY@3gc[D0klje0?O6[@3_
_JD0mlJ]1@3ge/H20?OF_@0?0>nmY@3NU7<0cXAS0=jLQ03FS7<0cXAS0=J<L`3NYH`0gYb40>N4N`3N
Nf/0cW=J0:E2<@2L>BT0]E8i0080eW][00X0gYAc0>N4N`3NU7<0iiB40>NUS03W]I`0mmJm0?Nm]@3W
YH`0ijfD0`3ge[d0103W[I@0ijfL0?Nm]@3g_KD20>o>]@030?Nm]@3WYH`0iiB40080ihAc00D0iiB4
0>nDS03W[I`0kkfU0>o6[@020>o>]@040>NmY@3NU7<0gW][0>NeW080mmJm0P3_c[D04P3N[I@0eZF<
0=jeY@3N]JD0gZfD0;fLS03FYH`0gZfD0:ekJ`2LJe80Nc4Q09`i:@2U@S40]E8i0=IcH`3>U7/0eZF4
0=JLL`<0gZF<00@0ikFL0>NmY@3__JD0klJ]0`3__JD20>NeW0090>NeU03N[I@0gZF<0=JUS03NYH`0
eZF40=jUS03FYH@0eZF<00@0gZF<00d0gZfD0=jeW03N]I`0g[FU0=K6aP3Fa]H0g/kF0=K6aP3Fa/h0
e/Jm0<jm]@3>_LH0imk_0380moOg403oool000h0oooo0P3gmoL0103gknl0moOg0?Ogm`3gknlg0?Og
m`0<0=kFi`3>_Lh0U8B409B4Q01S@S40>BTQ034Q8@0i:B40LdY20>o>]@3Fa/H0mkfe1`3ge[d01P3g
c[D0klJ]0>nmY@3__JD0mmJm0?O>]@<0kkfU1P3ge/H02P3_c[D0kkfU0>NDQ03>Le80cXa[0=jLQ03N
U7<0eZF40>N]U03W_JD20>N]W0060>N]U03_U8`0gW][0=IcH`3NJeX0gW][103WQ7<00`3NU7<0iiB4
0>N]W0020>NDQ0080>MkJ`3WYH`0ijfD0>NUS03WQ7<0ijF<0>N]W03_]JD20?Nm]@080>N]W03FLf<0
gV]J0=ikJ`3NJeX0gW][0>N4L`3WU8@20>NUS080ijfD00@0gYb40=IcH`3>LeX0ijF<0`3_c[D00`3W
]I`0eYac0=jeW0020=jeY@0?0=j]U03FYH`0aZfU0;fLS02eS7<0YG=J08`a:@1k:AP0S2TQ0:E2<@2m
FT80cXac0=J<N`3FW8@0gYb40080gZF<00<0ikFL0>nmY@3__JD00P3_aZd20>nmY@80ikFL00@0ikFD
0=jUS03N[I@0gZF<0P3FYH`00`3FYH@0eYb40=jLQ0040=jUS00:0=j]U03N]I`0g[FL0=jeY@3Fa[d0
g]KW0>ONi`3Fa]H0e/K>0<jmaP80e/K>00<0e/KF0>ONk`3gmoL0<03gmoL@0?ooo`003P3ooolk0?Og
m`040>ONk`3Fa]H0]IbL07=JDP80FT8i00P0DT8i04Xa<@0a8AP0<B4H0:EcFP3_c[D0mmJm0>o>]@80
mmJm00D0mmK60?OF_@3ge/H0mlje0>o>]@020?O6[@070>nmY@3gaZd0mlje0>o6[@3__JD0ikFD0?O6
[@050?OFaP060?OF_@3gc[D0kkfU0=jLQ03>Le80cXa[0P3NYH`01`3W[I@0ikFL0?Nm]@3_c[D0mkfe
0>o>]@3__Jd00P3_]JD0103W[I`0kiB<0>N]W03W[I`30>nDS080ihAk00@0ihAc0>N4N`3WQ7/0gW][
1P3WQ7/01@3NW8@0ihAk0>N4N`3NNf/0ihAk0080gW][01D0eW][0=IcH`3FLf<0gW][0=J<L`3WQ7<0
gYAc0=ikJ`3>Q6<0eW=S0<j<J`3W_JD0klJ]0>NmY@3NYH`0cXa[0=j]U03N]I`0klJ]0=j]U03FYH`0
0P3N[I@03`36U7/0]G]S07=2<@1c8A00NbTH08@Y8@2U@S40aV]B0=J<L`3FW7<0eZF<0=jLQ03NYH`0
ikFD0>NmY@050>nmY@0;0>NeW03W]I@0ijfD0>NeU03N[I@0eZF<0=JUQ03NW8@0eZF40=JLQ03FYH@0
0`3NYH`20=j]U0<0g[FL00<0e/Jm0>ONk`3Wg^l00P3Wg^l20<jmaP030=K>gP3Fa]H0mnON0340moOg
403oool000h0oooo>`3gmoL0103Wg^l0e/KF0;FLW01cFU8205Y2>@080592>@1:<C40<B4H034Q602U
LeX0klje0?OF_@3_c[D20?OF_@050?OFaP3ge[d0mmK60?O>]@3_c[D00P3gaZd01`3__JD0mlJ]0?O>
]@3_aZd0kkfU0>NeU03gaZd01@3ge/H01P3ge[d0mlje0>nmY@3NW8@0cW=B0<j<J`80gZF<00L0ijfD
0>NeW03g_KD0klje0?Nm]@3_c[D0kkf]0080kkFU00@0ijfL0>nDS03W[I`0ijfL0`3_U8`20>N4N`04
0>N4L`3WQ7/0ihAk0=ikJ`H0ihAk00D0gYb40>N4N`3WQ7/0gW][0>N4N`020=ikJ`0E0=IkJ`3FLf<0
eW=S0=ikJ`3FS7<0ihAc0=jDL`3NNf/0cXAS0=IcH`3>S6/0ikfU0>o6[@3W_JD0gZF<0<j<J`3N[I@0
g[FL0>o6[@3N[I@0eZF<0080gZfD00l0aYAk0;EkH`1c@S40Lb4@07/Y6024:B40YD8a0<I[DP3FS7<0
eYac0=JUS03NW8@0gZF<0>NeU03W_JD01@3__JD02`3W]I`0ikFD0>N]U03W]I@0gZfD0=JUS03FYH@0
gYb40=JUQ03FW8@0eZF400<0gZF<0P3N[I@30=jeW0030=K6_@3Wg^l0imk_0080imk_0P3>_LH00`3F
c]h0e/KF0?OWgP0a0?Ogma00oooo000>0?ooocX0moOg00D0mno_0=K6eP2<Lf<0HdY2048Y8@0203TY
8@80DS4Y00H0@R4H048Y8@36U8@0mmk>0?OFaP3_c[D30?OF_@0=0?OFaP3ge[d0mmJm0?O6[@3__JD0
mlJ]0>nmY@3_aZd0mkfe0?O6[@3__JD0ijfD0>o>]@020?OF_@80mmK600/0mmJm0?OFaP3g_KD0mlJ]
0>NUS03>LeX0cXAS0=jUS03W]I`0ikfU0>neY@020>o>]@030?OF_@3ge/H0mmK600@0mmJm0P3g_KD2
0>nm[@<0kkFU0P3W[I`01P3_U8`0kkFU0>neY@3W[I`0kiB<0>N]W0@0kiB<00D0ijfL0=jLS03WQ7/0
gYb40>N4N`030=ikJ`030=IcH`3NJeX0cW=B0080cW=J0`3FLf<02P3NYH`0g[FL0=jUS03>S6/0cW=J
0=J<L`3N]I`0klJ]0=JUS03>S8@20=JUS0040;F<L`2]Nf/0Ld8a06<H4080Lb4@00P0S2TQ0:EB>@3>
Q6<0eXak0=jLQ03FYH@0gZF<0>NeU0<0kkfU00@0klJ]0>nmY@3__JD0kkfU0P3W]I@0103N[I@0gZF<
0=jUS03NW8@20=JUQ0030=JUS03FW8@0eZF40080gZF<00<0gZfD0=JUS03N[I@00P3N]I`00`3__Jd0
moOg0?Ogm`020?O_k`060=k>eP3Fa]H0e/KF0?OWgP3Ne^L0imk_<03gmoL@0?ooo`003P3oool00`3g
moL0mno_0?Ogm`020?Ogm`030?O_k`3gmoL0moOg0080moOg00@0mno_0?Ogm`3gmoL0mno_;@3gmoL0
102LS8`0BS4a048Y8@0a8AP2048H400<048Y8@1B<BT0@RTQ058a:@3N]I`0mmK60>o>]@3ge[d0mmK6
0?OF_@3ge/H0mmJm0P3gc[D20?O6[@050>nmY@3_aZd0mkfe0>o6[@3__JD00P3W]I`00`3gc[D0mmJm
0?OFaP020?OF_@090>o>]@3ge[d0mlje0>o6[@3WYH`0cXAS0<icDP3NYH`0ikfU0080klJ]00<0mlje
0?OF_@3ge/H0103ge/H00`3gg/h0mmK60?OFaP030?OFaP030?OF_@3g_KD0mkfe0080mkfe00@0kkf]
0?Nm]@3g_KD0mkfe0P3_]JD00`3_U8`0kkf]0>nDS0060>nDS0<0ihAk0P3FNf/00`3>LeX0cUY:0<I[
DP020<I[DP040<icFP3FS7<0eYb40=J<L`80aV]B0180cXa[0=j]U03N]JD0eZF40<J<H`3FW8@0eYb<
0:ecFP2eNf<0Ld8a06<H401B40P0HaP@07<Q402<<BT0[EY20=J<N`3FW8@20=jUS0030>NUS03W]I`0
kkfU0080kkfU00<0klJ]0>nmY@3__JD00P3W]I@01P3N[I@0gZF<0=j]U03FYH`0eZF40=jLQ0<0eZF4
0P3NYH`00`3FYH`0gZF<0=j]U0020=jeW0030>nm[@3Fa[d0mnON0080moOg00H0g]KW0>ONk`3gimh0
e/kN0=K6eP3gimh`0?Ogma00oooo000>0?oooa@0moOg00<0mno_0?Ogm`3gmoL08@3gmoL20>ONi`05
0=K6eP1B>C40@RTQ024@400a8AP00P1B<BT0101S>C40DS4Y048Y602ULeX20?OFaP030?Nm]@3ge[d0
mmJm00D0mmJm00D0klJ]0?O6[@3_aZd0klje0?Nm]@020>o6[@030>nmY@3_aZd0mlje0080mmJm00P0
mmK60?OF_@3ge[d0klje0?O6[@3__JD0ijfD0>NDQ080cXAS00D0ijfD0>nmY@3__Jd0mmK60?ONcP02
0?OFaP80mmk>00@0mmK60?ONcP3gg/h0mmK60P3gg/h30?OFaPL0mmk>00D0e/K60?Nm]@3ge[d0mkfe
0=K6aP020?Nm]@@0kkf]00@0kkFU0>N]W03W[I`0kiB<0P3WQ7/00`3NNf/0eXak0>N4N`030=IkJ`03
0=IcH`36Je80aV]B0080aV]B0140cXa[0=JLL`3>S6/0aV]B0;eJ@P2eLeX0[EY20:E2<@1c@S40@Q0@
058@201c8A00S34Y08A:>@2<<BT0YE8i0=JLL`020=JLQ0030>N]U03W]I@0kkfU0080kkfU00D0klJ]
0>nmY@3__JD0ikFL0>NeU0030=jUS080eZF<00@0eYac0=JLQ03FW8@0eZF40P3FYH`04@3NYH`0gZfD
0=jUS03N[I@0g[FL0=jeY@2UQ7/0Nf=B0;FLW03Fa/H0g]KW0?OWgP3Wg^L0g]KW0=k>eP3Wg^L0knOW
02l0moOg403oool000h0oooo00<0moOg0?O_k`3gmoL00P3gmoL00`3gknl0moOg0?Ogm`0`0?Ogm`80
imkW00<0aZfm048Y8@12:B400P12:B4205Xa:@0806<i:@1J<B40DR4H0:f4J`3ge/H0mmJm0?OFaP3_
c[D50?OF_@0;0?O>]@3gaZd0klJ]0>o6[@3g_KD0klje0?O>]@3_aZd0klje0?O>]@3_c[D00`3ge[d0
0`3_c[D0mmJm0?Nm]@020>nmY@80ijF<00`0gYAc0<j4H`3NYH`0ikfU0>o>]@3ge[d0mmK60?ONcP3g
e/H0mmk>0?OFaP3gg/h80?OFaP@0mmk>00D0mmK60?ONcP3ge/H0mmK60?ONcP020?OFaP80mmJm00P0
mlJ]0?O>]@3gc[D0mlJ]0>nmY@3_aZd0mkfe0>o6[@80ijfD00D0kiB<0>NDQ03WQ7/0ihAk0=J<N`02
0>N4N`030=IkJ`3>S7<0eW=S00<0eW=S00<0cXac0;f4H`3>HdX00P2eDST00`2]FT80YD8a07/a8@02
06<H400607=2:@2<<BT0S34Y08`Y8@2<<BT0eXak0P3FW7<00`3NYH`0ikFD0>NeW0020>nmY@050>o>
]@3__JD0ikFL0>NeU03W[I@00P3N[I@20=jUS0050=JUQ03FW8@0eYb40=JLL`3FYH@00`3NYH`30=j]
U0070=jeW03__Jd0[Ib<06]BBP2DNg<0e/K60=kFi`020>ONk`040?Ogm`3Wg^l0imk_0>oWibl0moOg
403oool000h0oooo503gmoL00`3gknl0moOg0?Ogm`0Q0?Ogm`070=k>eP2m]Kd0W8b<048Q600a8AP0
FS4Y058a:@0205Xa:@07048Y8@128AP0FS4Q0;fLS03ge/H0mmJm0>o>]@020?OF_@030?OFaP3g_KD0
mmJm0080mlje00X0klje0>o6[@3g_KD0mkfe0>o>]@3g_KD0klje0?Nm]@3_c[D0mlje0P3ge[d02@3g
_KD0mmJm0?Nm]@3_c[D0klJ]0>nmY@3W[I@0ijF<0=jLQ0020<j<J`030>NeU03__Jd0mmJm0080mmK6
103gg/h40?OFaP030?ONcP3ge/H0mmK600<0mmK60`3gg/h40?OFaP0>0?ONcP3ge[d0klJ]0?O>]@3_
aZd0kkfU0?O6[@3__JD0mlJ]0>nmY@3gaZd0klJ]0>nmY@3W]I@20>NeW080ijfD00D0kiB<0=jLS03N
W8@0gYb40>N4N`020=J<N`040>N4N`3FS7<0eW][0=IkJ`80eW=S0P36Je803P2mFT80[EY209`i:@2D
DST0W3TY0:EB>@2eDST0[EY20:E2<@3>S6/0eXak0=JUQ03NYH`0ikFD0`3__JD00`3_aZd0kkfU0>nm
Y@020>NeU080gZfD00@0gZF<0=JUS03FYH@0eYac0`3FW8@20=JUS0030=jUS03N[I@0gZF<0080gZfD
00`0g[FU0;fUW01kHe80LdXi09AkL`3gimh0moOg0?O_k`3gmoL0knOW0?Ogm`3_inL_0?Ogma00oooo
000>0?ooocP0moOg00L0g]KW09b<S02<Ng<0<B4H048Y8@1S>BT0Hd8a0080HcTa00X0@RTQ048Q601S
@S40kkf]0?OFaP3_c[D0mmJm0?Nm]@3ge[d0klje0P3ge[d02P3_c[D0mlje0>o6[@3g_KD0klje0?OF
_@3_c[D0mmJm0>o>]@3ge[d20?Nm]@<0mmJm00d0klje0?OF_@3ge[d0mkfe0>nm[@3W[I@0ijF<0>ND
Q03NU7<0cXAS0=jLQ03W]I`0mmJm00X0mmK600D0mmk>0?OFaP3ge/H0mmK60?ONcP040?OFaP040?ON
cP3ge[d0mmK60?OFaP80mmJm00<0mlJ]0>o6[@3gaZd02`3__JD01@3W[I@0ijfL0>N]U03W[I@0ijF<
0080gYb<1@3NW8@30=J<N`0H0<j<Q03FS7/0eXak0>N4L`3FS7<0eW=S0<j4H`3FLf<0aV]B0;EcFP36
Je80aXaS0<jDN`3FW8@0gZF<0>NeU03__JD0ikFD0>nmY@3_aZd0kkfU0>NeW03__JD0ikFD0P3NYH`0
103FYH`0gYb40=JUQ03FW8@30=JLL`<0gZF<00H0eZF<0=j]U03N[I@0gZfD0=jeY@36[JD207=BBP05
07=:@P2LS8`0mnON0?ooo`3_inL00P3gmoL00`3_inL0moOg0?Ogm`0]0?Ogma00oooo000>0?ooo`03
0?O_k`3gmoL0moOg03D0moOg00L0imkW07]SFP1J@ST0FT8i09a[DP2]Q7/0eYb<0080aXac00D0]G=J
07=2<@2<FTX0klje0?OFaP070?OF_@080?O>]@3g_KD0klje0?Nm]@3ge[d0mkfe0?OF_@3_c[D20?OF
_@030>o>]@3ge[d0klje00<0mmJm00D0klje0?O6[@3_c[D0kkfU0>N]U0020>NUS0060=jLQ03NU7<0
gYAc0>NeW03_aZd0klje103ge/H00`3gg/h0mmK60?ONcP020?OFaP030?ONcP3ge/H0mmK600<0mmK6
00D0mmk>0?OFaP3ge/H0mmK60?ONcP030?OFaP040?OF_@3_c[D0mlJ]0>o6[@@0kkfU00@0ikFL0>nm
Y@3__JD0ikFL0P3__JD01P3W]I`0ikFD0>N]U03N[I@0ijF<0=j]U080gZF<0P3NW8@00`3FW8@0gYb4
0=jLQ0020=jLQ0060=JLQ03NW8`0gYb40=JLQ03>S8@0eXak0P3FS7<03P3FNf/0cXa[0=IkJ`3>Q6<0
_HAS0<j<J`3FW7<0gYb40>NeU03W_JD0ikFD0>nmY@3_aZd0kkfU0P3W]I`00`3W]I@0gZF<0=jUS002
0=JUS0050=jUS03FYH@0eZF40=JLQ03FW7<00P3FYH@01`3NW8@0gZfD0=j]U03FYH`0gZfD0=jeY@36
[Jd00P2<Ng<00`2UQ7/0Q6=B0;FLW0020?Ogm`030>oWi`3gmoL0moOg02l0moOg403oool000h0oooo
0`3gmoL01P3gknl0moOg0?Ogm`3gknl0moOg0?O_k`80moOg00<0mno_0?Ogm`3gmoL0:P3gmoL01@3N
e^L0Nf=J058a:@3N]I`0mkfe0080mmJm0P3__JD00`3W]I`0gYAc0;F<L`020?OFaP040=K6aP3ge[d0
mmJm0>o>]@80mmJm00H0mlje0>o>]@3gc[D0mmJm0>o>]@3g_KD20?OF_@80mlje0P3ge[d00`3_c[D0
mmJm0?OF_@020?OF_@060?Nm]@3_c[D0mlJ]0?O6[@3W]I`0ijfD0P3WYH`0203NU7<0cXa[0=jLQ03_
_Jd0klJ]0?OF_@3ge/H0mmJm0`3ge/H30?ONcP030?OFaP3gg/h0mmK60080mmK600<0mmk>0?OFaP3g
e/H00P3ge/H00`3gg/h0mmK60?OFaP030?OF_@030?O6[@3__JD0kkfU00D0kkfU00@0klJ]0>nmY@3_
_JD0kkfU0P3W]I`20>N]U080gZF<00D0eYb40=JUQ03NYH`0gYb40=jUS0030=JLQ0030=jLQ03FW8@0
eZF400<0eYb400T0gYb40=JLQ03FW8@0eXak0<jDN`3>U7<0cYAk0<j<L`3>U7<00P3FW7<00`3W]I@0
kkfU0>NeU0040>nmY@040>NeW03W]I@0gZF<0=jUS080eZF400D0gYb40=JLQ03FW8@0eZF40=JLQ002
0=jLQ0<0gZF<00@0gZfD0=JUS03N]I`0c[F]0P2DQ8@0102]U9@0]IbL0:fDU03>_Lhc0?Ogma00oooo
000>0?ooocL0moOg00D0mno_0=kFi`1cFU80Q6=B0?OFaP020?OF_@070>o>]@3g_KD0mkfe0>nmY@3W
]I`0kkfU0?OFaP030>o>]@0>0?OFaP3ge[d0mkfe0?OF_@3_c[D0mlje0?Nm]@3_c[D0mkfe0?OF_@3g
_KD0mmJm0>o6[@3g_KD20?OFaP80mmJm00<0mmK60?OF_@3g_KD00P3ge[d0103_c[D0klJ]0>NeW03W
[I@20>NUS0070=jLQ03NU7<0gYAc0>NmY@3_aZd0mkfe0>o>]@030?OFaP050?ONcP3ge/H0mmk>0?OF
aP3gg/h01P3ge/H50?ONcP040?OFaP3ge[d0mkfe0?O>]@@0kkfU00<0ikFD0>NeW03__JD00`3__JD3
0>NeW080ijfD00`0gZfD0=jUS03NW8@0eZF40=jUS03FYH`0gYb40=JLQ03FW7<0eZF40=JLS03FYH@5
0=JLQ080eZF400h0eYb40=JLL`3FW8@0eYac0<j<Q03FW7<0eYb40=JUQ03FW7<0ijF<0>NmY@3W]I@0
ikFL0>o6[@80kkfU00<0ikFD0=jUS03NYH`00P3NYH`20=JUQ0040=JLQ03FYH@0eYb40=JLL`80eZF4
0P3NYH`02@3N[I@0eZF<0=j]U03N[I@0aZfU07=JDP1kHeX0]JF]0<jmaP020=K6_@030?O_k`3gmoL0
moOg0300moOg403oool000h0oooo=`3gmoL0103Wg^L0aZfm08A[FP3N]I`60?OF_@040?Nm]@3__Jd0
e/Je0?OFaPD0mmJm00D0klje0?Nm]@3g_KD0mkfe0>o>]@050?OF_@030?Nm]@3ge[d0mmJm00P0mmJm
00@0mkfe0>o>]@3_]JD0ikFD0P3WYH`01`3WU8@0gYb40=jDL`3W]I@0klJ]0>o>]@3ge[d00P3ge/H2
0?ONcP@0mmK600@0mmk>0?OFaP3ge/H0mmJm0P3ge/H00`3gg/h0mmK60?ONcP020?ONcP0:0?OFaP3g
e[d0mmJm0>o>]@3gaZd0kkfU0>NeU03__JD0ikFD0>neY@D0kkfU00<0ikFL0>NeU03NYH`00`3NYH`0
203FYH`0eZF40=JLQ03FW7<0aYb40=JLQ03FW7<0cYAk0P3FW7<00`3>U7/0eZF40=JUQ0020=JLL`@0
eYb400<0eZF40=JLQ03FW7<00P3FYH@01@3FW8@0eXac0>NeU03W]I`0gYb400<0kkfU00@0ikFL0>Ne
U03W[I@0gZF<0`3FYH@00`3FW8`0eZF40=JLQ0020=JLQ0<0gZF<00H0eZF<0=jUS03NW8@0gZfD0=je
W036[JD207=JDP040:fDU03Fa[d0e/KF0=k>ePd0moOg00<0mno_0?Ogm`3gmoL08`3gmoL@0?ooo`00
3P3ooolf0?Ogm`060?O_k`3Ne^L0_JFL0?Nm]@3_c[D0mmJm0P3ge/H0103ge[d0mmK60?OFaP3ge/H2
0>o>]@080?OFaP3Fa/H0klje0>o>]@3ge[d0klje0?OF_@3g_KD30?OF_@040?OFaP3ge[d0mmK60?OF
_@80mmK60P3ge[d20?OFaP030?OF_@3ge/H0mmJm00<0mmJm00<0klje0?O6[@3__JD00P3W]I`00`3W
[I@0ijF<0>NUS0020=jLQ0030>NeU03__JD0klje00<0mmJm1@3gg/h00`3ge/H0mmk>0?ONcP050?OF
aP@0mmk>00<0mmJm0?O>]@3gc[D00`3__JD30>NeU0040>NeW03__JD0kkfU0>NeW0@0ikFD00L0ijfD
0=jUS03NYH`0eYb40=JUQ03FW7<0eYb400<0cYAk00<0cXa[0<jDL`3>U7/00`3>U7<01@3>U7/0eYac
0<jDN`3FW7<0eXak00<0eYb40P3FW7<00`3FYH@0eYac0=jLQ0020>NeU0030=jDL`3__JD0kkfU0080
ikFL00@0gZfD0>NeU03NW8@0gZF<103FW8@00`3FW7<0eYb40=JUQ0040=jUS0@0eZF<00H0c[F]058i
<@0a8B40S7=[0<jm]@3Wg^Ld0?Ogma00oooo000>0?ooocD0moOg00L0mno_0>oWi`3Fa/h0klje0?OF
_@3g_KD0mmJm0080mmK600D0mmJm0?OFaP3ge/H0mmk>0?OF_@020>o>]@@0mmJm00<0mkfe0?OF_@3g
e[d00`3ge[d20?OFaP060?OF_@3ge/H0mmJm0?OF_@3ge/H0mmJm103ge/H02P3ge[d0mmK60?OF_@3g
e/H0mkfe0>o>]@3gaZd0kkfU0>neY@3W[I@30>NUS0070=jDL`3WYH`0ikFL0>nmY@3_c[D0mmJm0?OF
aP060?ONcP050?OFaP3gg/h0mmK60?OFaP3ge[d00`3ge/H30?ONcP050?OFaP3ge[d0klje0?O6[@3_
aZd00P3W]I`0103W]I@0ijF<0>NeU03W]I`30>NeU0050>NUS03NYH`0gZF<0=jUS03FYH@0103FW8@4
0<jDN`@0cYAc00H0cXac0<jDL`3>U7<0cYAc0=J<L`3>U7<30=JLL`050=JLQ03FS7/0eYb40<jDN`3F
W7<00P3W]I@0103NW8@0cXa[0>NeU03W]I`30>NeU0070=j]U03NYH`0gZF<0=JUQ03FW7<0eYb40=JL
L`020=JLQ0030=JUQ03FYH`0eZF<0080gZF<00D0eZF<0=jUS03FYH`0g[FL0;fUW002058a:@0307]S
FP2LS8`0e/K>03@0moOg403oool000h0oooo=P3gmoL00`3Ne^L0e/Je0?OF_@030?OF_@80mmK60`3g
e[d02@3gg/h0klje0>o>]@3ge/H0klje0=K6aP3ge[d0mkfe0>o>]@070?OF_@P0mmK600<0mmk>0?OF
aP3ge/H00P3ge/H0203ge[d0mkfe0?O>]@3_aZd0kkf]0>nmY@3W]I`0ijfD0`3WYH`01`3NW8@0ijF<
0>nmY@3_aZd0klje0?OF_@3ge/H00`3gg/h20?OFaP80mmk>00<0mmK60?OF_@3ge/H00P3ge[d30?ON
cP80mmK600d0mmJm0?Nm]@3_c[D0klje0>nmY@3W[I@0ijF<0=jLQ03WYH`0gZF<0>N]U03N[I@0ikFD
00<0gZF<00L0eZF40=jLQ03FW8@0eYac0<JLQ03FS7<0cYAk0080cYAc00@0cXac0<jDN`3>S7<0cXac
0P3>U7<00`3>S7<0cYAc0<j<L`020<jDL`0<0<j<L`3>U7<0cYAc0=J<L`3>U7<0eYac0=J<N`3NW8@0
gZfD0=jLQ03FW7<0ijF<0P3W]I`01P3W]I@0ijfD0>N]U03NYH`0gYb40=JUQ0<0eYb400@0eYac0=JL
Q03FYH@0eZF40P3NW8@0103FYH@0eZF<0=j]U03NYH`20=JUS0070;fUW01B>C40DSTa07]SFP2DQ8@0
e/Jm0>ONk`0c0?Ogma00oooo000>0?ooocH0moOg00D0imkW0=K6]@3_c[D0mmJm0?OFaP020?OF_@03
0?OFaP3ge[d0mmK60080mmK60P3_c[D0103ge/H0mkfe0?OF_@3ge/H20?OF_@030?O>]@3ge[d0mmK6
0080mmJm1P3ge/H01`3gg/h0mmK60?OFaP3ge/H0mmk>0?OFaP3gg/h00P3ge/H00`3ge[d0klje0?Nm
]@020?O6[@<0ikFL00X0ikFD0>NUS03NW8@0gYb40>NeU03W]I`0kkfU0>o6[@3_c[D0mmK61P3gg/h<
0?OFaP070?OF_@3_aZd0kkFU0>NeW03W[I`0gZfD0>N]U0020=j]U080gZF<0P3NW8@02`3FYH@0gYb4
0=JLQ03FW7<0eYb40<jDN`3FS7/0cYAk0<j<L`3>U7<0cXac00<0cYAc0P3>U7/02P3>S7<0cYAc0<jD
L`3>U7<0cYAk0<j<L`3>U7<0cXac0<jDL`3>S6/20<jDL`030=JLL`3NW8@0gYb40080gYb400H0gZfD
0>N]U03W]I@0ijfD0>NeU03NYH`20=JUQ0030=JUS03FW7<0eYb40080eYb400<0eYac0=JLQ03FW8@0
0P3FYH@20=jUS00;0=JUS03N[I@0eYb<0=jeW036[JD0BS4a058a:@1JDU80[IBD0<J][@3Wg^L08`3g
moL00`3gknl0moOg0?Ogm`0=0?Ogma00oooo000>0?ooocH0moOg00D0g/kF0?Nm]@3ge[d0mmJm0?OF
aP040?OF_@80mlje00H0mlJ]0>NmY@3_c[D0klje0?OF_@3_c[D20?OF_@80mkfe103ge[d40?OFaPL0
mmk>00<0mmK60?ONcP3ge/H00P3ge/H20?OF_@050?Nm]@3_aZd0kkfU0>nmY@3W]I`00`3WYH`00`3N
U7<0gYb40>NeU0020>nmY@030?Nm]@3ge/H0mmK600H0mmk>1@3ge/H30?OF_@080?OFaP3Fa/H0klje
0>o>]@3__Jd0ikFL0>N]U03N[I@30>N]W0030>NeW03N[I@0gYb400<0gYb400P0eYb40=JLL`3FW8@0
eYac0=J<N`3>U7<0cXac0<jDN`80cXac00D0cYAk0<jDL`3>S7<0cYAc0<j<L`030<jDN`030=J<L`3>
U7<0cYAc0080cYAc00D0cXa[0<J<L`3>U7<0cXa[0=JUQ0030=jLQ080ijfD00@0gZfD0>NeU03NYH`0
ijfD0P3NYH`02@3NW8@0eYac0=JLQ03FYH@0eYb40=JLL`3FW8@0eZF40=JLQ0020=JUQ080eZF<00`0
gZF<0=JUS03FYH`0eZF<0;fUW012:B40<B4H03TY8@1SBT80FU9B09B4Q03gknlb0?Ogma00oooo000>
0?ooocD0moOg00<0knOW0>o>]@3_c[D00P3ge[d00`3ge/H0mlje0?O>]@020?O>]@80kkfU0P3W]I`0
2@3_c[D0mmK60?OF_@3ge[d0klje0?OF_@3_c[D0mmJm0?Nm]@020?OF_@80mmK600<0mmJm0?OFaP3g
e/H01@3gg/h01@3gimh0mmk>0?ONcP3ge/H0mmk>0080mmK600D0mmJm0?Nm]@3gc[D0klJ]0?O6[@02
0>nmY@090>NeU03WYH`0gYAc0>NUS03NW8@0ijF<0>NeU03__JD0klje00<0mmK61`3gg/h20?OF_@0?
0?O>]@3ge[d0klje0?OF_@3g_KD0mmJm0?Nm]@3_c[D0kkf]0>nmY@3W[I`0ijfD0=jeW03N[I@0g[FL
0080ijfL00T0eXak0=JLL`3NW8@0gYb40=JLL`3FW8@0eXak0=JLL`3>U7<00P3>S7<00`3>U7<0cYAk
0<j<L`040<jDL`040<j<L`3>U7/0eYac0<jDN`D0cYAc00@0cXac0<j<J`3>U7<0eYac0P3NW8@0103N
YH`0ijF<0>N]U03W]I@20>N]U0030=jUS03N[I@0gZF<0080gZF<0`3FW8@01@3FYH@0eYb40=JLQ03F
W8@0eZF400@0gYb40P3FYH`02@3N[I@0g[FL0;FLW012:AP0<B4Q03TY8@1B<BT0HdY20:fDU00c0?Og
ma00oooo000>0?oooc@0moOg00D0knOW0=K6aP3gc[D0mlje0?OF_@020?OFaP040?Nm]@3_aZd0mlJ]
0?O6[@<0ikFD00@0ikFL0?OF_@3_c[D0e/K60P3ge[d00`3g_KD0mlje0?OF_@020?OF_@@0mmK600<0
mmk>0?OFaP3gg/h00P3gg/h00`3gimh0mmk>0?ONcP050?ONcP<0mmJm00<0mkfe0?O6[@3_aZd00P3_
_JD02@3W]I`0ijfD0>NUS03WYH`0gYb40>NUS03W]I@0kkfU0>o>]@030?OFaPD0mmk>00H0mmK60?OF
_@3g_KD0klJ]0?O6[@3g_KD20>o>]@0C0?OF_@3_c[D0mmJm0>o>]@3gaZd0kkf]0>NeW03W[I`0ijfD
0=jeW03W[I@0gYb<0=j]U03FW8@0eXac0=J<N`3FYH@0eYb40=JUS0020=JLQ0040<jDL`3>S7<0cXac
0<j<L`80cYAc0P3>U7/01`3>U7<0cYAk0<jDN`3FW7<0cYAk0=JLL`3>U7/01@3>U7<01@3>S7<0cXa[
0=jLQ03NW8@0ijF<0080ijfD00D0ikFD0>NeW03W[I@0gZF<0>NUS0030=jUS0090=JUS03FYH@0eYb4
0=JUQ03FW8@0eZF40=JLQ03NW8`0eZF40080gYb40`3FYH`20=j]U0080=JUS02mW8`0@RTQ034Q8@0i
:B40@RTa05Y2>@3>_KDc0?Ogma00oooo000>0?oooc@0moOg00<0mmK60>o>]@3ge[d00`3ge[d01@3g
g/h0mmJm0?OF_@3__JD0ijfD0080ikFL00T0gZfD0>nm[@3_c[D0mmJm0=K6aP3g_KD0mmJm0>o>]@3g
_KD01`3ge/H40?ONcP<0mnON1P3gg/h30?OFaP050?OF_@3gc[D0mkfe0?O6[@3__JD00P3W]I`20>NU
S0070=jDL`3WYH`0gYb40>NUS03_]JD0mmJm0?OFaP050?ONcP0:0?OFaP3g_KD0klje0?OF_@3ge/H0
mmJm0?OFaP3ge[d0mmK60>o>]@80mmJm00d0mkfe0?O6[@3_aZd0kkf]0>NeW03__JD0ijfL0=jeW03W
[I@0g[FL0=j]U03FW8`0cYAk0080cXac00T0eXak0<jDN`3>U7<0cXa[0;f4J`3>S6/0cXac0<jDL`3F
S7/00P3>U7/0103FS7/0cYAc0<jDN`3FW8@30=JLL`070<jDN`3FS7<0cYAc0<jDL`3FS7<0eYac0=jL
Q0020>N]U0080>NeW03W[I`0ikFD0>NeW03W[I@0ijF<0=j]U03W[I@50=jUS0030=JLQ03FW7<0eZF4
0080eYb400<0gZF<0=JLQ03FYH`00P3FYH`01`3FW8@0gZF<0=JUS03N[I@0g[FL0:fLS01B@ST00P1S
BT800`1JDU80W8bU0=K6eP0c0?Ogma00oooo000>0?oooc<0moOg00@0knOW0?OF_@3ge[d0mmK60P3g
e[d01P3ge/H0mmk>0?OFaP3_c[D0kkfU0>NUS080ikFD00D0gZfD0>NmY@3ge[d0mkfe0>o>]@020?OF
_@030?Nm]@3ge[d0mmJm0080mmJm103ge/H70?ONcP030?OWgP3gg/h0mnON00@0mmk>00H0mmK60?OF
_@3_c[D0mkfe0>o6[@3_c[D20>nmY@050>NeU03WYH`0ijF<0>NUS03NW8@00P3WYH`00`3W]I@0klje
0?OFaP040?ONcP030?OFaP3ge[d0mmJm0080mmK60P3ge[d00`3ge/H0mmJm0?OF_@020?OF_@050?OF
aP3_c[D0mmJm0>nm[@3_aZd00P3__JD20>NeW0D0gZfD00<0eYb40<j<J`2mQ6/00P3>S7<30<j<J`03
0<j<L`3>U7/0cYAk0080cYAc0P3>U7/0303>U7<0eYac0<JLQ03FS7/0cYAc0=JLL`3>U7/0cYAc0=J<
L`3FW7<0gYb40=jUS0<0ikFL00H0ikFD0>N]W03W]I@0ijfD0=jUS03W[I@50=jUS0030=JUQ03FW8@0
eYb400<0eYb40100eZF<0=JLL`3FYH@0eZF40=jLQ03FYH@0eZF<0=JLS03FYH`0aZfU0:F4Q01B<BT0
BS4a06=:@P1kLg/0mnON=03gmoL@0?ooo`003P3ooolc0?Ogm`030>oWi`3ge[d0mmJm0080mmJm0P3g
e/H01@3gg/h0mmJm0>nmY@3W[I@0ikFL0080ijfD00<0gZF<0>NmY@3_c[D00`3ge[d00`3g_KD0klje
0?OF_@030?OF_@030?OFaP3gg/h0mmK600H0mmk>0`3gimh70?ONcP060?OFaP3ge[d0mkfe0>o>]@3g
aZd0kkf]0P3__JD02P3W[I`0ijF<0>NUS03WYH`0gYb40>NUS03W]I@0mkfe0?OF_@3ge/H20?ONcP@0
mmK600<0mmJm0?OFaP3ge/H01`3ge/H0403ge[d0mkfe0?OF_@3_aZd0kkf]0>nmY@3W_JD0ijfL0>N]
U03N[I@0gYb<0=JUS03NYH`0gZfD0=JLS03>U7/20<J<H`040<j<J`2mQ6/0aXaS0<j<J`<0cXac00@0
cYAk0<jDL`3>U7<0eXak0P3>U7/02@3FW7<0eXak0<jDN`3FW7<0eYb40=jLQ03NYH`0ijF<0>N]U003
0>NeW0030>N]W03W]I`0ikFL0080ijfD0P3N[I@40=jUS0060=jLQ03FW8@0eYb40=JLQ03FYH@0eZF<
0P3FW8@30=JUS00=0=JLQ03FYH`0eZF<0=JUS03N]I`0U7]c048Y8@1B<BT0HdY208acJ`2eW9`0]JF]
0=kFi`0b0?Ogma00oooo000>0?oooc<0moOg00H0mmk>0?OF_@3g_KD0mmJm0?Nm]@3ge/H20?ONcP04
0>o6[@3W]I`0ikFD0>NeW080ijF<00@0gZfD0>nm[@3g_KD0e/K60P3_c[D20?OF_@040?Nm]@3ge[d0
mmJm0?OF_@80mmK61@3gg/h0103gimh0mmk>0?ONcP3gimh20?ONcP040?OWgP3gg/h0mmk>0?ONcP80
mmK60P3ge[d01P3_c[D0mlje0>nm[@3gaZd0klJ]0>nmY@80ikFD1@3WYH`0103_aZd0mkfe0?OFaP3g
g/h20?OFaP030?ONcP3ge/H0mmK600<0mmK600@0mmk>0?OFaP3ge/H0mmK60P3gg/h20?OFaP0:0?OF
_@3_c[D0kkf]0>o6[@3__Jd0kkfU0>NeW03W[I`0g[FL0=j]U0<0gZF<00D0gZfD0=jUS03FW8`0cYAk
0<J<H`020<j<L`040;f4J`3>S6/0cXac0<jDN`80cYAc0P3>U7/01P3FW7<0cYAk0=JLQ03>U7/0eXak
0=JLL`80gYb400H0gZfD0>N]U03W[I@0ikFL0>NmY@3W]I@40>NeW0030=jUS03W[I@0ijfD00@0gZF<
00P0eYb40=jUS03FW8@0eZF40=jLQ03FW8@0eZF<0=JLQ080gYb<00X0eZF40=JUS03FYH`0eYb<0=JU
S03N]I`0[HA[058a:@12:B40DS4Y0P1B>C401@1SBT80aZf]0>ONk`3Wg^l0mno_02l0moOg403oool0
00h0oooo3`3gmoL00`3gknl0moOg0?Ogm`0P0?Ogm`0=0?O_k`3ge[d0mmJm0?OF_@3g_KD0mmJm0?OF
aP3gg/h0mmK60>nmY@3W]I`0ijF<0>NeW0020=j]U0060>NeW03_aZd0klje0>o>]@3ge/H0mkfe103g
e[d50?OFaPD0mmk>00<0mnON0?ONcP3gimh00P3gimh50?ONcP<0mmK600T0mmJm0?Nm]@3__Jd0klje
0?O6[@3__Jd0kkFU0>NeW03W[I@0103WYH`00`3__JD0klJ]0>o>]@040?OFaP030?ONcP3ge/H0mmK6
0080mmK600<0mmk>0?OFaP3ge/H0103gg/h30?OFaP040?Nm]@3__Jd0klJ]0>neY@80ikFL00H0ijfL
0=j]U03N[I@0eZF<0=j]U03FYH`20=jUS0080=j]U03FW8@0eYac0=JUQ03>U7/0aXac0<j<J`3>U7<2
0<j<L`050<jDN`3>U7<0eXak0=JLL`3>U7/00P3FW7<20=jLQ080ijfD0`3W]I`20>nmY@80ikFL00@0
ijfD0>NeU03W[I@0gZfD103NYH`01`3NW8@0eZF40=jUS03NW8@0eYb40=JUQ03NYH`00P3FW8@20=JU
Q0070=jLQ03FW8`0gZfD0=JUS03N[I@0aZfU08acH`0205Xa:@08058a:@12:B40DS4Y058a:@1kHeX0
]IbL0=K6cP3Wg^L_0?Ogma00oooo000>0?ooo`80moOg00<0mno_0?Ogm`3gmoL03@3gmoL00`3gknl0
moOg0?Ogm`0M0?Ogm`030?OWgP3_c[D0mlje00<0mmJm00@0mmK60?ONcP3_c[D0ikFD0P3NW8@01@3W
]I@0gZF<0=jUS03W_JD0klJ]0080klje00L0mkfe0>o>]@3ge[d0mkfe0?OF_@3ge/H0mmJm00<0mmK6
203gg/h00`3gimh0mmk>0?OWgP060?ONcP080?OFaP3ge[d0mkfe0>o>]@3ge[d0mkfe0>o6[@3gaZd2
0>nmY@030>neY@3W[I@0ijF<0080ijF<00D0ikFL0>nmY@3g_KD0mmJm0?OFaP020?ONcPL0mmK60P3g
g/h00`3gimh0mmk>0?ONcP020?OFaP030?OF_@3_c[D0kkf]0080kkfU00@0ikFL0>N]W03W[I`0ijfD
0P3N[I@0103NYH`0eZF<0=jUS03FYH`20=jUS0040=JUS03NYH`0gYb40=JLL`80_HA[0P36S7<01P3>
S6/0cYAc0<jDL`3>U7/0eXak0=JLL`<0gZF<00L0ijfD0>NeW03W]I`0ikFL0>nmY@3W]I`0ikFD00@0
ikFL00<0ijfD0=jUS03WYH`00`3NYH`02@3NW8@0gZF<0=jUS03FYH@0eYb40=jLQ03FW8@0eZF40=jL
Q0020=JLQ0080=JUQ03FW8@0eZF<0=j]U03N]I`0g[FU0;F<L`24DT8207=:>@0905Xa:@12:B40<B4H
05Y2>@2<Lf/0[IBD0=k>eP3gmoL0mno_02d0moOg403oool000h0oooo<@3gmoL01`3gknl0mmJm0?O>
]@3g_KD0mmJm0?Nm]@3ge[d00P3ge/H01@3W]I`0ijF<0<j<J`3WYH`0gYb40080gZF<00D0ikfU0=K6
]@3_c[D0mkfe0>o>]@060?OF_@<0mmK61`3gg/h0103gimh0mmk>0?OWgP3gimh50?ONcP080?OFaP3g
g/h0mmJm0?OF_@3g_KD0klje0>nm[@3_aZd20>nm[@80ikFL0P3W[I@01@3WYH`0ijfD0>NeW03__JD0
mmJm00P0mmK600T0mmk>0?OFaP3gg/h0mmk>0?OWgP3gg/h0mnON0?ONcP3ge/H00P3ge[d01`3_aZd0
kkfU0>nmY@3__JD0ijfL0>NeW03W[I`00P3N[I@01@3NYH`0gZfD0=j]U03N[I@0eYb<00@0gZF<00<0
gYb40=JLQ036S7<00`3>S6/01P36S7<0cYAc0<jDL`3>U7<0eYac0=jLQ080ijF<00H0ijfD0>N]W03W
]I@0ikFL0>neY@3W]I`20>nmY@<0ikFL0P3W[I@03P3N[I@0gZF<0=jUS03W[I@0gYb<0=jUS03NW8@0
gZF<0=jLS03FYH@0gYb<0=JUQ03FW8@0eZF<0P3FW8@02@3NW8@0gZF<0=j]U03FW8`0eZF<0=jeY@36
W8@0cXa[0;EkH`0209ASBP0807=:>@1B<BT0DSTa07]SFP2<Ng<0]IbL0=k>eP3gknl]0?Ogma00oooo
000>0?oooc40moOg00<0mmk>0>o>]@3gc[D00P3ge[d02@3ge/H0mmJm0>o>]@3W]I@0klJ]0=jLQ03>
S6/0eXac0=JLS0020>NeW0050>o>]@3g_KD0klje0>o>]@3g_KD01P3ge[d30?OFaP@0mmk>00P0mnON
0?ONcP3gimh0mnON0?ONcP3gimh0mmk>0?OWgP<0mmk>0P3ge/H0103ge[d0mmK60?OFaP3_c[D20?OF
_@030>o>]@3g_KD0mlJ]00<0ikFL00d0kkfU0>NeU03W]I`0kkf]0?Nm]@3_c[D0mmJm0?OFaP3ge[d0
mmK60?OF_@3gc[D0klje0080mmJm00<0mmK60?OF_@3gg/h00P3gg/h30?OFaP040?OF_@3_c[D0klJ]
0>NeW080ijfD1P3NYH`0303FYH`0gZF<0=JUS03NYH`0eYb40=JUS03FW8@0gYb40=jLS03FYH@0eYac
0<j<J`80_HA[00H0cXac0<jDL`3FS7/0eYac0=JLQ03NW8@20=j]U0070>N]W03W]I`0ikFL0>NeW03_
_JD0ikFL0>nmY@020>NeW080ikfU00D0ikFL0=jeW03W[I@0gZfD0>NUS0020=j]U0030=jUS03NW8`0
eZF<0080gZF<00@0eYb40=JUS03FYH`0gYb40`3FYH`03@3NYH`0eZF<0=JUS03N]I`0ikfU0=JLL`3>
S6/0aXaS0:e[DP2UHdX0Q58i08A:>@1B>C400P1J@ST0101SBT80LeYB0:fDU03Wg^L/0?Ogma00oooo
000>0?ooo`80moOg00@0mno_0?Ogm`3gmoL0mno_:P3gmoL0103gknl0klje0?Nm]@3_c[D30?OF_@08
0?Nm]@3__JD0ikFL0>nmY@3FW8@0gYAc0=J<N`3NYH`20>NeW0030>nm[@3Fa[D0mkfe00D0mmJm00@0
mmK60?OF_@3ge[d0mmK60P3ge[d00`3ge/H0mmk>0?ONcP030?ONcP030?OWgP3gg/h0mnON0080mnON
1@3gg/h20?OFaP0<0?OF_@3g_KD0mmJm0?OF_@3_c[D0mkfe0>o>]@3__Jd0ikFL0>neY@3__JD0ikFL
0`3__JD01@3ge[d0mkfe0?OFaP3ge[d0mmK60080mmJm00@0mkfe0>o6[@3g_KD0klje103ge/H0103g
e[d0mmK60?OF_@3ge[d20>o6[@030>nmY@3W[I@0ijfD00<0gZF<00P0gYb<0=JLS03NYH`0gZF<0=JL
S03FYH`0eYb<0=JUQ080eYb<0P3FYH@0103FW7<0eYb40=J<N`2mQ6/20;f4H`060<j<J`3>U7/0eXak
0=JUQ03NW8`0gZfD0P3W[I@30>NeW0030>nmY@3W]I`0kkFU00H0ikFL00H0ijfL0>N]U03W[I@0gZfD
0=jLS03W[I@40=jUS0050=JUS03NYH`0gZF<0=jLQ03FYH`00P3NW8@02P3FYH`0gZF<0=JUS03N]I`0
eZF<0<J]Y@3FW8@0eXac0<j<L`3>S6/20;EcFP030:ESBP1S>C40Hd8a0080HdY200<0Nf=J0:fLY@3W
g^L0;03gmoL@0?ooo`003P3oool`0?Ogm`0?0?OWi`3_c[D0mlJ]0?Nm]@3ge[d0mlje0?O6[@3W]I`0
ikFD0>nmY@3NYH`0gYAc0=jLQ03FW7<0g[FL0080ikfU00P0klje0?Nm]@3g_KD0e/K60?OF_@3ge/H0
mmJm0?OFaP80mmJm0P3ge/H00`3ge[d0mmK60?ONcP040?ONcP040?OWgP3gg/h0mmk>0?OWgPL0mmk>
0P3ge/H50?OF_@040>o6[@3g_KD0klJ]0>o6[@D0kkfU00L0ikFL0?OF_@3ge/H0mmk>0?OFaP3ge[d0
mmK60080klje00<0mlJ]0>o6[@3g_KD00P3ge[d03P3ge/H0klje0?OFaP3ge[d0klje0?OF_@3g_KD0
kkf]0>nmY@3W[I@0gZfD0=jLS03NYH`0gYb40`3FW8`0103FYH@0eYb40=JLQ03FYH`20=JLQ00@0=JU
Q03FW8@0eYb40=JLQ03FW7<0cYAc0;f4J`2mQ6<0eW=S0<j<J`3>U7<0eYac0=jLQ03NYH`0ijfD0>N]
W0D0ikFL00<0kkfU0>NeW03W]I`01@3W]I`01`3N[I@0ijfL0=j]U03N[I@0ijfD0=jLS03N[I@00P3N
YH`01P3NW8@0gZF<0=jLQ03FYH@0eZF<0=JLQ080eZF<01@0gZF<0=JUQ03NYH`0eZF<0=jeW03N]JD0
eYb40=J<N`3FW7<0cYAk0<j<L`3>S6/0_HA[09a[DP1SBT80LeYB08akL`36[Kd0imkW0>oWib`0moOg
403oool000h0oooo<03gmoL01@3gimh0klJ]0?O6[@3gc[D0mlJ]0080ikFD00P0ijF<0>NDQ03NU7<0
gYAc0=J<L`3FW7<0gZF<0=jeW080klJ]00P0mkfe0>o>]@3_c[D0mmJm0>o>]@3ge[d0mmK60?OF_@80
mmK600<0mmJm0?OFaP3ge/H00P3ge/H40?ONcP030?OWgP3gg/h0mmk>00H0mmk>00<0mmK60?ONcP3g
e/H00P3ge/H20?OF_@030>o>]@3g_KD0mkfe0080klje00X0mlJ]0>nmY@3__JD0kkf]0?O6[@3__Jd0
kkfU0>o6[@3ge[d0mmk>0P3ge/H00`3ge[d0mkfe0?O6[@020>nm[@0C0>o>]@3ge[d0mmJm0>o>]@3g
e[d0klje0?OF_@3g_KD0klJ]0>o>]@3__JD0ikfU0>N]W03N[I@0gZF<0=JUS03NYH`0eZF<0=JLL`03
0=JLQ0050=JUS03FW8@0aYb40=JLQ03>U7/00P3FW8@0303FW7<0cYAc0<j<J`2mQ6/0_HAS0<J<H`3>
S6/0eXak0=JLQ03NW8`0gZfD0>N]U0<0ikFL00<0ikFD0>NeW03__JD01@3W]I`00`3_]JD0ikFL0>Ne
W0030>N]U0@0gZfD00<0gYb40=jUS03FYH`00P3FYH`20=jUS0030=JLQ03NW8@0gYb40080eZF<00D0
eYb<0=jeW03N]I`0aZfU0=JLL`020=JLQ0080=JLL`3>U7/0eYac0<jDN`3>S7<0U7=[09AkL`3Fa/h_
0?Ogma00oooo000>0?oooc00moOg00D0mmK60>nmY@3gc[D0mlJ]0>NUS0020=jDL`080<j4H`3FLf<0
eW][0=IkJ`3FS7<0eYb40=j]U03W]I`20>nmY@040=K6]@3g_KD0mmJm0?Nm]@<0mmJm00<0mmK60?OF
_@3ge/H00`3ge/H=0?ONcP030?OFaP3gg/h0mmk>00@0mmK60`3ge[d03@3_c[D0mmJm0?Nm]@3g_KD0
klJ]0>nmY@3__Jd0mlJ]0>o>]@3__Jd0mlJ]0>nm[@3ge[d00P3ge/H30?OF_@050>o6[@3gaZd0kkf]
0?OF_@3_c[D00P3ge[d01@3g_KD0mmJm0>o>]@3g_KD0klJ]0080kkfU00D0ikFD0>N]W03W[I@0gZF<
0=jLQ0040=JLQ0030<JLQ03>U7/0cYAk00@0cYAk00@0eYac0<jDN`3>U7<0cXa[0P2mQ6/01`36S6<0
cXa[0<j<L`3FW7<0gYb<0=jUS03N[I@0103W]I`01P3__JD0ikFL0>NeW03__JD0ikFL0>nmY@D0ikFL
0P3N[I@20>N]U0040=jUS03W[I@0gZF<0=JLS080gZF<00@0gYb40=JLS03FYH@0gYb<0`3FYH`01P3N
W8@0eYb40=jeW03FYH`0g[FL0=jeY@<0eYb400L0eXak0=JLQ03FS7/0eYb40<jDN`2mW8`0c[Fm0300
moOg403oool000h0oooo00@0mno_0?Ogm`3gmoL0mno_:`3gmoL01P3gknl0klje0?O6[@3g_KD0mlJ]
0>NUS080gYAc00P0gV]J0<j<J`3>S6/0cXa[0<j<L`3FW8@0gZfD0=jeW080kkf]00@0mkfe0>o>]@3_
c[D0mmJm1P3ge/H00`3gg/h0mmK60?OFaP020?OFaP<0mmk>0P3gimh0103Nc]H0mmk>0?ONcP3Nc]H5
0?ONcP050?OFaP3ge[d0mmK60?OF_@3_c[D00`3ge[d01@3_c[D0klJ]0?O6[@3__Jd0kkfU0080klJ]
00L0mkfe0>o>]@3_c[D0mmK60?OF_@3ge/H0mmk>0080mmK600<0mmJm0?Nm]@3_c[D00`3ge[d20?OF
aP80klje00X0klJ]0>nm[@3_aZd0kkf]0>NeW03W[I`0ijfD0=j]U03NYH`0eZF<0P3FW8@20<jDN`03
0<j<Q03>U7/0aXac0080aXac00H0cYAc0<jDN`3>U7/0cYAc0<J<L`3>S6/20;f4J`040<j<J`3>S7<0
eYac0=JLS080gZF<00@0ijfD0>N]W03W]I`0kkfU0P3W]I`20>nmY@80ikFL00H0ikfU0>NeW03W_JD0
ikFL0>N]W03W]I`20>N]U0030=jeW03N[I@0ijfD0080gZfD0P3NYH`01P3NW8@0eYb40=jUS03NW8@0
eZF<0=jLS080eYb<0P3FYH`0103FW8`0eZF<0=jeY@3N]JD30=JLL`070<jDN`3FW7<0eYac0<j<Q03F
W8@0g[FL0>ONi`0`0?Ogma00oooo000>0?ooobl0moOg00P0kmK>0?Nm]@3gc[D0mlje0>nmY@3WU8@0
gYAc0>MkJ`80eW][00H0eXac0<j<J`3>U7/0gZF<0=j]U03W[I`20>nm[@80klje00<0mmJm0>o>]@3g
e/H00P3ge[d80?OFaP<0mmk>00<0mnON0?ONcP3gg/h01`3gg/h40?OFaP0>0?OF_@3g_KD0mkfe0?O>
]@3_c[D0mkfe0?O6[@3_aZd0kkf]0?O6[@3_aZd0mkfe0>o>]@3ge[d40?OFaP80mmk>00<0mmK60?OF
_@3ge[d01@3ge/H20?OF_@80mkfe0P3_aZd00`3__JD0ikfU0>NeW0020=j]U00:0=jLS03FW8@0eYb<
0<JLQ036U7/0aXac0<JLQ03>U7/0aXac0<jDL`80aXac00`0cYAk0<jDL`3>U7<0cXa[0;f4J`3>S6/0
_HA[0<j<J`3>U7/0eXak0=jLQ03NYH`20=j]U080ikFL103__JD00`3W_JD0ikFL0>NeW0020>neY@<0
ikFL0P3W]I@01@3N]I`0ijfD0>NUS03NYH`0gZfD0080gZF<00L0gYb40=jUS03FYH`0gYb<0=JUS03F
W8@0eZF40080gZF<0100eZF<0=jUS03N[I@0g[FL0=jeY@36[JD0cYAc0=J<L`3>U7<0eXak0=JLL`3F
S7/0eYac0=JLQ036[JD0mno_<03gmoL@0?ooo`003P3oool_0?Ogm`0@0?ONcP3_c[D0mlje0?Nm]@3_
_JD0ijF<0>NDQ03FS7/0eXac0<j<J`3FS7<0_HA[0=J<L`3FYH`0gZF<0>NmY@80klJ]0P3_c[D0103g
e/H0mmJm0>o>]@3ge[d40?OFaP80mmk>0P3ge/H60?ONcP030?OWgP3gg/h0mmk>00<0mmk>0`3ge/H0
203ge[d0mmK60?OFaP3ge[d0kkf]0>o>]@3g_KD0mlJ]0P3_c[D0203gaZd0kkf]0>o>]@3g_KD0klje
0?OF_@3_c[D0mmK61`3gg/h60?OFaP<0mmJm00<0klje0>o6[@3__Jd00P3__JD20>N]U080gZF<0`3F
W8@40<jDN`090<J<L`2mQ6/0cXa[0<J<L`3>U7<0aXac0;f4J`3>S6/0aXac0080cXa[00D0eXak0=JL
L`3FW8@0gZF<0=j]U0020>N]U0040>N]W03W]I`0ikFL0>nmY@80ikFL00@0kkfU0>NmY@3W_JD0ikfU
0`3W]I`0103W[I`0ijfD0>N]W03W[I@20=j]U0090=jUS03N[I@0gZF<0=jLQ03FW8`0gZF<0=jLQ03F
W8@0gYb<00@0eYb4103FYH`01`3N]I`0g[FU0=J<L`3>S6/0cYAc0=J<L`3FS7/00`3FW8@00`3N]I`0
mnOW0?Ogm`0_0?Ogma00oooo000>0?ooo`030?Ogm`3gknl0moOg02/0moOg00H0kmK>0?O>]@3g_KD0
mlje0?O6[@3W]I`20>NDQ080gYAc00L0eW][0;f4J`3>S7<0eXak0=JUS03N]I`0kkfU0080klJ]0P3_
c[D00`3ge[d0klje0?OFaP020?OF_@030?OFaP3gg/h0mmK60080mmk>0P3ge/H;0?ONcP80mmK600<0
mmJm0?OFaP3ge/H00P3g_KD20?OF_@040?Nm]@3_c[D0klje0>o>]@80kkf]00H0mlJ]0>o>]@3g_KD0
klJ]0>o>]@3g_KD40?OFaPH0mmk>1@3ge/H0103ge[d0klje0>o>]@3gaZd20>nmY@80ikFL00<0ijF<
0=jUS03FYH`00P3FW8@40<jDN`<0aXac00P0cXa[0<J<L`36S7<0aXac0<jDL`3>U7/0cYAc0<jDN`80
eYb40P3N[I@00`3W[I@0gZfD0>N]U0040>NeW0030>NmY@3__JD0ikfU00<0kkfU0P3W_JD01`3W]I`0
ijfL0>N]U03W]I`0gZfD0>N]U03N[I@0103NYH`01P3FW7<0gYb<0=JUS03NW8`0eYb40=jLS080eYb4
0P3FW8`0103FW8@0gZF<0=JUS03N]I`20=jeY@<0cXa[00P0eXac0=JLQ03FW8@0eYb40=JUS03N]I`0
kmK>0?ooobl0moOg403oool000h0oooo;@3gmoL01`3ginL0klJ]0?Nm]@3_c[D0mmK60?O>]@3_]JD0
0P3WYH`02@3WU8@0gYAc0;f4J`36S6<0cXac0<JLQ03N[I@0ikFL0>nm[@020>o6[@040?Nm]@3_c[D0
klje0?OFaP80mmJm0P3ge/H00`3gg/h0mmK60?OFaP020?OFaPX0mmk>00@0mmK60?ONcP3ge/H0mmJm
0`3ge/H20?OF_@080?Nm]@3_c[D0klje0?Nm]@3_c[D0mlJ]0?Nm]@3_aZd20>o>]@040?O6[@3_c[D0
mlJ]0>nm[@H0mmK60P3gg/h70?OFaP80mmJm00<0mkfe0>o>]@3_]JD00P3__JD0103W[I@0gZF<0=jU
S03NYH`30=JLQ080cYAk00D0aXac0<jDL`36S7<0cYAc0<J<L`020<jDL`80cYAk00@0eXak0=JLL`3F
W8@0gYb4103N[I@00`3N]I`0ijfD0>N]W0020>NmY@070>neY@3__JD0kkfU0>neY@3W_JD0kkfU0>Ne
W0020>nmY@80ikFL00`0ijfD0=jeW03N[I@0ijF<0=j]U03NYH`0gZfD0=jLS03NYH`0eYb40=JUQ03N
YH`70=JLQ00<0=JUS03FYH@0eZF<0=jeW036[JD0g[FL0<jDL`3FS7<0cYAc0=J<L`3FW7<0eYb40`3F
YH`00`3Fa/H0moOg0?Ogm`0^0?Ogma00oooo000>0?ooobd0moOg00L0mmk>0?Nm]@3gaZd0mlje0?OF
aP3g_KD0kkFU0080ijF<00T0iiB40=jDL`3>S7<0_HA[0<j<L`3FW8@0gZfD0>NeW03__Jd00`3_c[D0
103ge[d0mmK60>o>]@3ge[d30?OFaP040?ONcP3ge/H0mmK60?OFaP<0mmk>00<0mmK60?ONcP3ge/H0
0P3ge/H00`3gg/h0mmK60?OFaP020?OFaP<0mmJm00<0klje0?OFaP3ge[d00P3_c[D01P3g_KD0mmJm
0>o>]@3g_KD0klje0>o6[@@0kkfU00<0klje0>nm[@3_aZd00`3ge/H0103ge[d0mmK60?OFaP3gg/h2
0?OFaP030?ONcP3ge/H0mmK600<0mmK600D0klje0?OF_@3ge[d0klje0?O6[@020>NeW0030>N]U03N
YH`0gZF<00<0eYb400H0aYb40<jDN`3>U7/0cYAk0<jDL`36U7/30<jDN`040=JLQ03>U7/0eYb40=JU
Q080eYb400@0eZF<0=jUS03N[I@0gZfD0P3W[I`01P3N]I`0ijfL0>NmY@3__JD0ikfU0>nmY@<0ikFL
0P3__JD0103W]I`0ikfU0>NeW03W]I@20>NeW0040>N]U03N[I@0gZF<0=j]U080gZF<00@0eZF<0=jU
S03FW8`0gZF<0P3FW8@00`3FYH`0eYb40=JLQ0030=JLQ0030=jUS03FW8`0g[FL0080g[FU00<0eXak
0=JLL`3FS7/00P3FW7<01@3NW8`0eZF<0=JUS03FW8@0g[FU0300moOg403oool000h0oooo00@0mno_
0?Ogm`3gmoL0mno_0P3gmoL00`3gknl0moOg0?Ogm`0S0?Ogm`0C0?OWi`3ge[d0mlJ]0?O6[@3g_KD0
mmK60?OF_@3gaZd0ijfL0>NUS03WU8@0gYAc0<j<J`2mQ6/0cXac0<JLQ03N[I@0ikfU0>nm[@020?Nm
]@80klje00<0mmJm0?OFaP3ge[d00`3ge/H30?ONcP<0mmK60`3gg/h00`3ge[d0mmK60?OFaP040?OF
aP080?OF_@3ge/H0mmJm0?OF_@3_c[D0mkfe0>o>]@3g_KD20>o>]@040?Nm]@3_c[D0klJ]0>o6[@80
kkf]0`3__JD0103_aZd0kkf]0?Nm]@3_c[D30?OFaP030?OF_@3ge/H0mmK600T0mmK600/0mmJm0?OF
aP3gc[D0kkf]0>nmY@3W[I@0gZfD0>N]U03NYH`0eZF40=J<N`020=JLQ0L0cYAk00<0eXak0=JLS03F
W8@00P3FW8@00`3NYH`0eYb<0=jUS0020=j]U0030>N]W03N]I`0ikFL00<0ikFL0P3W_JD01P3__Jd0
kkfU0>nmY@3W]I`0kkfU0>NmY@<0ikFL00d0ijfL0>NeU03W[I@0gZfD0>N]U03N[I@0gZF<0=j]U03N
YH`0gYb<0=jLQ03FYH`0gYb40080eYb400<0eYb<0=JUS03FW8@00P3FW8@0103FW8`0eZF<0=JUS03N
]I`20<J]Y@030=JLQ03FW7<0eZF40080eYb40P3FYH`0103FW8`0eYb40=jUS03ginL_0?Ogma00oooo
000>0?ooob`0moOg00D0mmk>0?O>]@3__JD0kkfU0?O>]@020?OFaP060?O6[@3WYH`0gYAc0=jLQ03N
U7<0cXa[0P36S7<0103FW8@0gZfD0>NmY@3_aZd20>o>]@040?OF_@3g_KD0mmK60>o>]@@0mmK600D0
mmk>0?OFaP3gg/h0mmK60?ONcP080?OFaP80mmJm0P3_c[D00`3ge[d0klje0?OF_@030?OF_@080>o>
]@3g_KD0mkfe0>o>]@3__Jd0klJ]0>nm[@3_aZd20>nmY@80kkf]00<0kkfU0>o6[@3_c[D00P3ge[d0
0`3ge/H0mmJm0?OFaP020?OF_@H0mmK600H0mmJm0?OFaP3ge[d0mmJm0?OFaP3g_KD20>nmY@050>N]
U03WYH`0gZfD0=jUS03NW8`00P3FW8@00`36W8@0eYb40<jDN`040<jDN`050=JLL`36W8@0eYac0<JL
Q03FW8`00P3FW8@00`3FYH@0gZF<0=j]U0020=j]U0050>N]U03W]I`0ikfU0>NeW03W_JD00`3__JD0
1P3W]I`0ikfU0>nmY@3W]I`0kkfU0>NeW080ijfD00@0ikFD0=j]U03N[I@0gZfD0`3NYH`0203NW8@0
gZF<0=jUS03FYH`0gYb40=JLS03FW8@0eYb<0`3FW8@20=JLS00B0=JUQ03FW8`0eYb<0=jeW03N]JD0
g[FL0=JUS03FYH@0gYb40=JUS03FYH@0gZF<0=JUS03FW8@0eXak0=JLS03Fa/H0oooo;P3gmoL@0?oo
o`003P3ooolD0?Ogm`030?O_k`3gmoL0moOg01D0moOg01<0mmJm0?Nm]@3W]I@0ikFD0?OF_@3gg/h0
mmK60>neY@3WYH`0gYb40>NDQ03FS7/0aXac0;f4J`36S7<0aYb40=j]U03__Jd0klJ]00<0klje0`3g
e[d30?OFaP80mmk>00H0mmK60?ONcP3ge/H0mmk>0?OFaP3ge[d50?OFaP030>o>]@3gg/h0mmJm0080
mmJm00H0kkf]0?Nm]@3_c[D0mkfe0>o>]@3_aZd30>o>]@050>nm[@3gaZd0kkf]0>nmY@3__Jd00P3_
_JD0103_aZd0kkf]0>nm[@3g_KD20>o>]@050?OF_@3_c[D0mmK60?OFaP3ge[d00P3ge/H00`3ge[d0
mmK60?ONcP060?OFaP060?OF_@3_c[D0kkf]0>nmY@3W]I`0ijfD0P3NYH`01@3FYH@0eYb40=JLQ03>
S8@0aYb40080cYAk00@0cYAc0<jDN`3FW7<0aYb40P3FW8@07@3>S8@0eYac0=JUS03FYH@0eYb<0=jU
S03N[I@0gZF<0>N]U03N]I`0ijfL0>NmY@3W]I`0kkFU0>NmY@3_]JD0ikFL0>NmY@3__JD0ikfU0>nm
Y@3W]I`0gZfD0>N]U03N[I@0ikFL0>N]W03W]I@0gZfD0080gZF<00T0eZF<0=jUS03N[I@0gZF<0=JU
S03NW8`0eZF<0=jLQ03FYH@01@3FW8@00`3FW8`0eYb40=JUS0020=jeY@060=jeW03NW8@0gYb40=jU
S03FYH`0gYb40P3FYH`0103>U7<0eXak0=JLL`3g_KD_0?Ogma00oooo000>0?ooob`0moOg00@0mmJm
0?O6[@3W]I@0ikFD0P3ge[d00`3W_JD0ijfD0>N]W0020=jLQ0080=jDL`2mQ6/0_HA[0<J<L`3>U7/0
g[FL0>nm[@3_aZd20?Nm]@<0klje0P3ge[d30?OFaP030?ONcP3ge/H0mmK60080mmk>00<0mmK60?ON
cP3_c[D00P3ge/H30?OF_@050>o>]@3ge[d0klje0>o>]@3_aZd00`3_c[D01@3__Jd0kkfU0>nm[@3_
c[D0kkf]0080klje00H0kkf]0>nmY@3__JD0kkf]0>nmY@3__Jd50>o>]@030?OF_@3ge/H0mmK600D0
mmJm1P3ge/H0203ge[d0mmK60?OF_@3ge[d0kkf]0>nmY@3_]JD0ijfD0`3NYH`30=JLQ0030<jDN`36
U7/0cYAk0080cYAk00@0aYb40=J<N`36W8@0eYac0P3FW8@00`3FYH`0gZF<0=jLQ0020=jUS0030=j]
U03W[I`0g[FL0080ikFL0P3W_JD20>NeW0060>NmY@3__JD0ikFL0>NeW03W_JD0ikFL0P3W]I@01P3W
[I@0g[FL0>N]W03N[I@0ijfD0=j]U080gZF<0P3FYH`0103FW8@0gZF<0=JUQ03FW8@20=JLS0H0eYb4
00H0eYb<0=jeW036[JD0ijfL0<J]Y@3>U7<20=JUQ0040=jUS03FYH`0eZF40=jeW0<0eXac00<0gZfD
0?O_k`3gmoL0;@3gmoL@0?ooo`003P3oool[0?Ogm`060>oFcP3gaZd0ijF<0=jDL`3W]I`0ijF<0P3F
W8`01P3FW8@0W6]B09a[DP2eNf<0cXac0<j<J`80_HA[00@0aYb40>NmY@3__Jd0klje0P3g_KD20>o>
]@030?OF_@3ge/H0mmJm00L0mmK600<0mmk>0?OFaP3gg/h01@3ge/H20?OF_@040>o>]@3g_KD0klje
0?Nm]@80klJ]00@0klje0>nm[@3__JD0klJ]0P3__JD20>NmY@080>o6[@3__Jd0kkf]0?Nm]@3_c[D0
mkfe0>o>]@3g_KD20?OF_@030>o>]@3ge[d0klje00<0mmK600<0mmJm0?OFaP3ge[d01@3ge/H0103g
e[d0mmK60?OF_@3ge[d20?Nm]@080>o6[@3W]I`0ijfL0>N]U03NYH`0eYb<0=JLQ03>U7/20<JLQ0H0
cYAk00<0aYb40<jDN`3FW8@00`3FW8@0103NW8`0eYb<0=jLS03N[I@70>NeW00;0>NmY@3W]I`0ikFL
0>NmY@3__JD0ikFL0=j]U03W[I@0g[FL0>N]U03N]I`00P3N[I@02`3W[I@0gZfD0=j]U03N[I@0gYb<
0=JUS03NYH`0eZF<0=jLQ03FYH`0eYb<00H0eYb40`3FYH`20=jeY@050=jeW036Je80aV]B0<j<J`3N
YH`00P3N[I@01P3N]I`0eXak0<j<J`3NU7<0eXak0>o6[Bh0moOg403oool000h0oooo:P3gmoL0103g
knl0mmJm0>NeU03NU7<20>NUS0080<j<L`3N[I@0gYb<0:ecFP2LJe80[G=J09a[DP2]LeX20;EkH`05
0;f4J`3FW8@0ikfU0>o6[@3_c[D0103ge[d80?OFaP80mmk>103ge/H01`3ge[d0klje0?OF_@3_c[D0
mlje0>o>]@3ge[d00`3_c[D0103_aZd0klje0>nm[@3_aZd20>nm[@030>NmY@3__JD0kkf]0080kkf]
0`3_aZd70>o>]@060?OFaP3ge[d0mmK60?OFaP3_c[D0mmK60`3ge[d60?OFaP80mmJm0P3_c[D00`3_
_Jd0ikFL0>N]U0020=jUS080eYb400<0eYac0<jDN`3>U7/01P3>U7/00`36W8@0eYb40=JLQ0020=JL
Q080eZF<00H0gYb<0=j]U03N]I`0ijfL0=j]U03W_JD30>NeW0070>N]U03W]I`0ikFL0>NeW03W_JD0
ikFL0>NmY@020>NeW0050>N]U03W]I`0g[FL0>N]U03NYH`00`3N[I@0203NYH`0gZfD0=JLS03NYH`0
eYb40=JUS03FW8@0eYb<103FW8@20=JUQ0030=JLS03FYH`0eZF<0080g[FU00T0aZfU0:e[DP36Je80
cW=B0=JLL`3FYH@0eZF<0=jeW03FW8@00`3FS7<00`3NYH`0knOW0?Ogm`0/0?Ogma00oooo000>0?oo
obX0moOg00/0mmk>0?O>]@3WYH`0gYAc0>NDQ03>S6/0cXac0>NUS02eQ6/0Ld8a09AJBP020:ecFP07
09ASBP2UJe80YG=J0:ekJ`3FYH`0ikFL0>o6[@030>o>]@030?OFaP3_c[D0mmK600P0mmK600<0kmK>
0?OFaP3ge/H00`3ge/H0103ge[d0klje0>o6[@3_c[D20>o6[@030>nm[@3__JD0ikfU0080kkf]0140
klje0>nm[@3W_JD0klje0>o6[@3Fa[D0klJ]0>nm[@3_aZd0kkf]0>NmY@3__Jd0klje0>o6[@3_c[D0
kkf]0?OF_@020?OFaP040>o>]@3ge[d0mmK60?OF_@<0mmK600<0mmJm0?OFaP3ge/H01@3ge/H02`3g
e[d0klje0?O>]@3_aZd0kkfU0>NeW03N[I@0gZF<0=jLS03FW8@0aYb400H0cYAk00X0cYAc0<jDN`3>
S8@0eYac0=JLQ03FW8`0aYb40=JLS03NYH`0gYb<0P3N[I@02`3W[I@0ikFD0>N]W03N]I`0ikFL0>N]
W03W[I@0gZfD0>N]U03W[I`0gZfD0080ijfL00H0g[FL0>N]W03N[I@0ijfL0=j]U03W[I@70=j]U003
0=jUS03FYH`0eZF<0080eYb400<0eYac0=JLQ03FW7<00P3FW8@20=JLS0040=JUS03FW8`0gZfD0<J]
Y@80g[FL0P2eLeX00`36Je80cXAS0=JLL`020=JUS0060=JUQ03FS7/0eXac0=jDL`3FS7<0kmK>;@3g
moL@0?ooo`003P3ooolY0?Ogm`0=0?O_k`3ge[d0mlJ]0>NUS03WU8@0eXak0;f4J`3>S7<0[G=J08aJ
@P2eQ6/0[G=J09a[DP0208aJBP0709ASBP2LJe80W7=S0<JLQ03W_JD0mkfe0?OF_@020>o>]@030?OF
aP3ge[d0mmK600<0mmJm0`3ge/H0103ge[d0mmK60?OFaP3ge/H20?OF_@D0mmK6103_c[D20>o6[@03
0>o>]@3Fa[D0klJ]0080kkf]00X0ikfU0>NeW03W]I`0ikfU0>NeW03W_JD0kkf]0>NmY@3_aZd0kkf]
1P3_c[D00`3ge[d0klje0?OFaP030?OFaP040>o>]@3ge[d0mmK60?OF_@80mmK600`0mmJm0?OFaP3g
e/H0mlje0?Nm]@3_c[D0klJ]0>nmY@3W[I`0ijfD0=jUS03FW7<20=JLQ0040=J<N`3>U7/0aYAk0<J<
L`<0cYAk00D0cYAc0<JLQ03>S8@0aYb40=JLS0020=JLQ0030=jUS03FYH`0gZfD00<0gZfD00H0ikFL
0>N]W03W[I`0g[FL0>NeW03N[I@20>N]U00:0=j]U03W[I@0g[FL0>N]W03N[I@0ijfD0=j]U03W[I@0
gZF<0>N]U080gZfD00<0gZF<0=JLS03NYH`00P3N[I@00`3FYH`0gZF<0=JLS0050=JLQ0<0eYb<00L0
eZF<0=JLS03FYH`0ijfL0<J]Y@3FYH`0]G=J0080aV]B00D0cXa[0<jDN`3FYH`0eZF<0=jUS0020=JL
Q0030=JLL`3FS7<0mkfe02d0moOg403oool000h0oooo:03gmoL0403oool0knOW0?O6[@3__JD0gYAc
0>NDQ03NW8@0[F]B08aJ@P2LFT80_HA[0=JLQ02DFTX0Q59208aJBP24DT8209ASBP030:EcFP3FW8@0
ikfU0080klje0P3ge[d00`3_c[D0mmJm0?OFaP050?OFaP030>oFcP3ge/H0mmJm00T0mmK600@0mmJm
0?OFaP3ge/H0kmK>0`3ge/H00`3ge[d0mmK60?OFaP020>o>]@80ikfU0P3W]I`03P3W]I@0ijfD0>Ne
W03W[I`0ikfU0>nm[@3_aZd0kkf]0>o6[@3g_KD0mmJm0>o>]@3ge/H0klje0P3ge/H00`3ge[d0mmK6
0?OF_@020?OFaP0=0?OF_@3ge/H0mmJm0?OF_@3_c[D0mkfe0>o>]@3__Jd0kkfU0>neY@3W[I@0gZF<
0=jLQ0020=JLQ0030=JLL`36W8@0cYAk0080cYAk00D0aXac0<jDL`36U7/0cYAk0<JLQ0040=JLQ004
0=JLS03FYH`0gZF<0=jUS080gZfD0P3W[I@01`3N[I@0ijfD0=jeW03N]I`0ijfD0=jeW03W[I@00P3N
[I@30>N]U0090=jeW03W[I@0gZfD0=j]U03NYH`0gZfD0=jUS03FYH`0gZF<0080gZfD0P3NYH`01P3F
W8@0eZF<0=JUS03FW8`0eYb40=JLL`80eYb40P3FW8`03P3FYH`0eYb<0=j]U036[JD0g[FU0=jeW02e
Nf<0]G=J0<I[DP36S6<0cYAc0=JUQ03FW7<0eZF<0P3NYH`20=J<N`030=j]U03gknl0moOg02/0moOg
403oool000h0oooo:@3gmoL03@3_e/h0mlJ]0>NeU03NU7<0ijF<0<jDN`2DFTX0Ld8Y0;EcFP3FW8@0
_HA[08aJBP2<He800P24DT801P1cBT80W6]B0:EcFP36W8@0ikfU0>o6[@<0mmJm1`3ge/H20?OF_@80
mmK60P3ge[d20?OFaP030>o>]@3ge/H0mmK60080kmK>00<0mmK60?OF_@3ge/H0103ge/H01@3ge[d0
mmK60>o>]@3_c[D0mkfe0080kkf]00D0kkfU0>NeW03W[I`0ikFL0>N]W0030=j]U0040>N]W03__Jd0
klJ]0=K6]@<0klje0P3ge[d20?OFaP80mmJm103ge/H40?OF_@0@0>o>]@3__Jd0kkFU0>NeW03W[I@0
gZF<0=JUQ03FS7/0eYac0<j<Q03>U7/0cYAc0<jDN`3>U7<0aXac0<jDN`80aXac00`0aYb40=JLL`3F
W8@0eYb40<JLQ03FYH`0gZF<0=j]U03FYH`0gZF<0=j]U03NYH`20=j]U0040>N]U03N[I@0ijfL0>Ne
W080ijfL00L0gZfD0>N]U03N[I@0gZF<0>N]U03N[I@0ijfD0080gZfD0P3NYH`02`3FYH`0gYb<0=j]
U03NYH`0eZF<0=jUS03FW8`0gZF<0=JUS03FW8@0eZF40080eYb400P0aYb40=JLQ03FW8@0eYb40=JL
S03FYH`0aZfU0=jeY@80eZF<00D0]G]S0;EcFP36S6<0cXAS0<j<J`020<jDL`070=jLQ03NYH`0eZF<
0=J<N`3NU7<0gZF<0?OWgP0/0?Ogma00oooo000>0?ooobT0moOg01H0mmK60>nmY@3WYH`0gYAc0>nD
S02mQ6/0LdXi07=2<@3>U7/0_HA[0;EkH`2]LeX0aYAk08acH`2<FTX0LdY208ASDP2ULeX0eZF<0>Nm
Y@3_aZd0klje0P3ge[d00`3ge/H0klje0?OFaP030?OFaP030?ONcP3ge/H0mmK600D0mmK600<0mmJm
0?OFaP3_c[D00P3_c[D00`3ge[d0mmK60?OF_@040?OFaP030>oFcP3ge/H0mmK60080mmK600<0e/K6
0>o>]@3g_KD00`3W_JD00`3W]I`0ijfL0>N]U0030=j]U0060=jUS03N]I`0mkfe0?O6[@3ge[d0mmK6
0P3_c[D20?OFaP030?OF_@3ge/H0mmK600<0mmK600/0klje0?Nm]@3ge[d0klje0?OF_@3__JD0ikFL
0>N]W03W[I@0gZF<0=jLQ0020=JLQ0090=JLL`3>U7/0cYAc0<J<L`3>U7<0aXac0<JDN`3>U7/0aYAk
0080cYAk00<0aYb40=JLQ03FW8`00`3FYH`40=j]U0060>N]W03N[I@0ijfL0=j]U03N]I`0ijfL0P3N
[I@0103W[I@0gZfD0=j]U03NYH`40=j]U0@0gZF<0P3N[I@20=jUS0030=JUS03NYH`0eZF<0080eYb4
0P3FW8`20=JLQ0030<jDN`3FW8`0eYb<00<0eZF<0P3N]I`01@3FYH`0]G]S0:e[DP2]Je80]G=J00<0
aV]B00P0cXa[0=jLQ03NYH`0eYb<0=J<L`3NW8@0kmK>0?ooo`h0moOg00<0mno_0?Ogm`3gmoL0603g
moL00`3gknl0moOg0?ooo`0?0?ooo`003P3oool00`3gknl0moOg0?Ogm`0U0?Ogm`0@0?O_k`3ge/H0
ikFD0=jDL`3WU8@0kkFU0:EcFP1c@RT0]G=J0:ecFP1S@S40DR4H08aJ@P2DFU80S6=B0:f4J`80Q6=B
00@0Q6]J0<JLQ03W_JD0klje0`3ge[d20?OFaP030>o>]@3ge/H0mmK600<0mmJm00@0klje0?OF_@3g
e[d0mmK60P3_c[D0203Fa[D0klJ]0>o>]@3ge[d0mmK60>oFcP3ge/H0kmK>1@3ge/H02@3_e/h0e/Jm
0?OFaP3ge/H0klje0?OFaP3g_KD0e/Je0>nm[@030>NmY@030>NUS03N[I@0gZF<0080gZF<00@0gZfD
0=jUS03N]I`0kkf]0`3_c[D90?OFaP0;0?OF_@3_c[D0mmJm0>o6[@3__JD0kkFU0>NmY@3WYH`0gZF<
0=jLS03FW8@0103>U7/0103>S6/0aXac0<J<L`36S7<20<jDN`<0aYb400@0eYb<0=JLQ03FYH@0eZF<
0P3NYH`01@3FYH`0gZF<0=jUS03N[I@0gZF<00T0gZfD00L0eYb<0=jLS03FYH`0gZfD0=jUS03N[I@0
gZF<00<0gZfD00<0gZF<0=JUS03FYH`00`3FYH`01P3FYH@0eYb40=JLQ03FW8@0eZF40=JLQ0<0aYb4
00@0eYb<0=JUS036[JD0g[FL0P3FYH`00`2eNf<0YF]B0:ESBP030:EB>@030:E2<@2mFT80cW=B0080
eYac00<0eYb<0=J<L`3__Jd0;03gmoL@0?ooo`003P3ooolX0?Ogm`0E0?OWi`3gaZd0ijF<0=jDL`3W
YH`0ijfL09AJDP1cBST0]G=J09AJBP126100FS4Y0:EcFP2]Q7/0S5Y:05Y2>@24He80Q5920:EcFP36
W8@0ikfU0080klje0P3ge[d0103ge/H0klje0?OFaP3ge[d40?OFaP030?OF_@3_c[D0klJ]00<0klJ]
00H0kkf]0>NmY@3W_JD0ikFL0?OF_@3ge/H20?OF_@040=K6]@3_aZd0klje0?Nm]@80g[FU00@0g[FL
0=jeY@3N]I`0eZF<0P3N]I`01@3FYH`0g[FL0>NmY@3W_JD0ijfD0080gZfD00<0ijfD0=jUS03NYH`0
0`3NYH`01P3W]I`0klJ]0>o>]@3ge[d0mmK60?OF_@<0mmK600<0mmk>0?OFaP3ge/H00`3ge[d02@3g
_KD0klJ]0>nmY@3__JD0ikFL0=jUS03NW8@0eZF40=JLL`020<jDN`080<j<L`36S7<0_HA[0;F<L`36
S7<0cYAk0<J<L`3>U7<20<jDN`80eZF400@0eZF<0=JLQ03FYH@0eZF4103FW8@20=JUS0<0gZfD00<0
g[FL0=j]U03N[I@00`3N[I@30=JUS080gZfD00@0gZF<0=j]U03N[I@0gZfD0`3FYH`0203NYH`0eYb<
0=jUS03FYH@0eYb40=JLS03FW8@0aYb40P3FW8@00`3FW8`0eYb40=JLQ0060=JUS0050;F4J`2ULeX0
YF=:0:eJ@P2LFT800P2UDST01`2eDST0aV]B0<icDP3FW7<0gYb40=J<L`3W_JD0;03gmoL@0?ooo`00
3P3ooolX0?Ogm`0F0?OWgP3__JD0gYAc0>MkJ`3W[I`0kkf]0:ecFP2<FT80]G=J06=2<@126100Q58i
07=:>@1S@S40DS4Y06=2<@1cBT80Le9:08ASDP2mW8`0ikfU0>o>]@D0mmJm00<0klje0?OF_@3_c[D0
1@3ge/H00`3ge[d0mmK60?OF_@020>o>]@0<0>o6[@3N]I`0[HA[0<JLQ03N[I@0g[FL0=JUS03FYH@0
aYb40<JDN`3>U7/0cXb40P36U7/40<JDQ00;0<J<L`3FW8`0aXac0<j<Q03N[I@0eYb<0=j]U03NYH`0
eZF<0=jLS03NW8@00P3NYH`20=j]U0030>NmY@3Fa[D0klje00@0mmK600<0mmk>0?OFaP3gg/h00`3g
e/H02@3_c[D0mmJm0>o6[@3__Jd0ikFD0>NeW03W[I@0gZF<0=J<N`020<jDN`<0cYAc0P3>S6/01036
W7<0aXac0<JDN`36U7/40<jDN`080=JLL`3>U7/0cXb40<JLQ03>U7/0eYb<0=JLQ036W8@60=JUS007
0=j]U03N]I`0eZF<0=jeW03N[I@0eZF<0=JLS0030=j]U0030=jeW03N[I@0g[FL00<0gZfD0P3FYH`0
2P3N[I@0eZF<0=JLS03FYH`0eYb40=JUQ03FW8`0eYb40<JLQ03FW8@30=JLS00:0=JUS03N]I`0_JFL
0=JUS036W8@0]HA[0:EcFP2UHdX0W5Y20:eJ@P80YE8i00L0]E8i0;eJ@P36Je80cXAS0=jLQ03FS7/0
ijfL02`0moOg403oool000h0oooo:03gmoL05`3gg/h0ikFD0=jDL`3NU7<0ijfD0>nm[@2eNf<0Ld8a
0:ESBP12:B40@QP@07=2<@12:B40>BTQ048Y8@1B>C40Hd8a07=:@P1kHe80aYb40>NmY@3_aZd0klje
0080mmK600X0klje0?OF_@3ge/H0mmK60?OF_@3_c[D0mmJm0?OFaP3ge[d0mmK60P3_c[D01`3_aZd0
ikfU0>NeU03FYH`0aYAk0:f4J`2<FTX00P24He802@2<FTX0YG=J0:EcFP2ULeX0_HA[0:f4N`2mQ6/0
]Hac0<JDN`030<JDQ0030<JDN`3FW8`0aYAk0080_HAS00<0cYAk0=jLS03>S8@01@3FW8@0103W_JD0
kkf]0>NmY@3__Jd30>o>]@80mmK60P3gg/h00`3ge/H0mmk>0?OFaP030?OF_@060?O>]@3__JD0kkfU
0>NeW03N[I@0gZF<0P3FW8@01`3FW7<0cYAc0<J<L`36S7<0_HA[0<J<L`36U7/00P36S7<20<JLL`03
0<jDN`3>U7<0cYAk0080aYb40`3FW8`00`3FYH`0eYb<0=JUS0060=JUS0040=j]U03FYH`0gZfD0=JU
S0L0gZfD00/0g[FL0=j]U03NYH`0g[FL0=j]U03FYH`0gZfD0=JUS03FYH@0eZF<0=JUQ0020=JLQ004
0=JLL`3FW8@0eYb40=JLS080_Ib<00X0eZF<0;fUW03FYH`0g[FL0=JUS03FW8`0]Hac0:ecFP2UJe80
YF=:0P2UDST20:eJ@P070;eJ@P36Je80cXAS0=JLQ03NU7<0gZfD0?O_k`0[0?Ogma00oooo000>0?oo
obP0moOg01L0mmJm0>NeU03NU7<0ig][0>N]W03_]JD0_HA[08A:>@1c@S40@QP@034Q601J<B40<B4H
03TY8@12:B40DSTa06=2<@1SBT80LdY20<J]Y@3_aZd0klje0?OFaP030?OF_@030>o>]@3ge[d0klje
00<0mmJm00<0klje0?OFaP3_c[D00P3_c[D20>o6[@0@0=jeW03FYH@0aXac0=jeW02eQ6/0Q59208AB
>@1cBST0LdY209ASBP2LJe80[G=J0;f4J`3>S8@0_HA[09acH`80YG=J01@0W7=S09a[DP2UJe80YG=J
0;F4J`2mQ6<0]G=J0;f4J`36U7/0cYAk0=J<N`3>U7/0cXac0<jDN`3N[I@0ikFL0>NmY@3__JD0klJ]
0>o>]@80mmJm00<0mmK60?ONcP3ge/H01@3ge/H01`3ge[d0klje0>nm[@3__Jd0ikFL0>NUS03NW8@0
0P3FW7<01036W8@0cYAk0<jDL`3>S6/20<J<L`060;f4J`36W7<0aYac0;f4J`3>S6/0]Hac0`36W8@0
2P3FW8`0aYb40=JLQ036W8@0cYAk0=JLL`36W8@0eXak0=JLQ03>U7/20=JLQ0040<JLQ03FW8`0eZF<
0=JUS0<0gZfD0P3N]I`20=j]U0040=jeW03W[I`0gZfD0=j]U080eZF<00D0gZfD0=JUS03FW8@0eYb<
0=JUQ0020=JLQ0050=JUS036W8@0aYb40=JLQ036W8@00P3FW8`00`3FYH`0eYb<0=JUS0020=JUS004
0<JLQ02]Q6/0YG=J0:E[DP80[EY200<0YE8i0:eJ@P2eDST00P2mFT801@3>Q6<0eXac0=jLQ03N[I@0
mno_02/0moOg403oool000h0oooo9`3gmoL01@3gknl0klje0>NUS03WNf/0gYAc0080kkFU00L0cYAk
07=:>@1J<B408A0@048H400Y61P0<B4H0080DS4Y00P0BS4a058a:@1cBST0LdY20=JUS03_aZd0mmJm
0>o>]@80mmJm0P3ge/H00`3_c[D0mmJm0>o>]@020>o>]@030?OF_@3gc[D0mmJm0080mmK600P0mmJm
0>o>]@3_aZd0klJ]0=jeW03FYH`0g[FU0<JDN`80Q5920P1cBST0202DNg<0]IbL0<je[@3>_KD0U8B4
07=2:@1S@S40S6=B0`1J<B40101c@RT0Ld8a08aJ@P2DHdX20;EcFP0:0<I[DP2mQ6<0aXaS0;EcFP3>
LeX0cXAS0<j<J`3FW7<0gZF<0>NmY@80klje00@0mmJm0?OFaP3ge/H0mmk>1@3ge/H04@3_c[D0mmJm
0>o>]@3__JD0ikFL0>N]U03NW8@0eZF40=JLQ03>U7/0cYAc0<J<L`3>S6/0aXac0;f4J`36W7<0_HA[
0080_HAS00D0aXac0<JDN`36W8@0aYb40=JLS0070=JLQ00<0=JLL`3FW8@0eYb40=JLQ03FW7<0eYb4
0=JLL`3>U7/0eYac0<JLQ03>U7/0eZF<0`3N]I`20=j]U0030=jeW03N[I@0gZfD00<0gZfD0P3FYH`0
2@3FYH@0eYb40=JLQ03FYH`0aYb40=JUS03FW8@0eZF<0<JLQ0050=JUS0070;fUW03FW8`0eYb<0;F4
J`2ULeX0[F]B09aJ@P030:eJ@P080;EB>@2mFT80aV]B0<I[DP3FW7<0gYb40=j]U03gknl[0?Ogma00
oooo000>0?ooobL0moOg00h0mno_0>o6[@3NU7<0ig][0=jDL`3W[I`0mkfe0=JLS01S>BT0@QP@024@
40124100<B4H048Y8@80DS4Y00P0Hd8a058i<@1S@S40Nf=B0;fLS03_aZd0mmJm0?OFaP80mmJm00@0
klje0?OF_@3ge[d0klje0`3gc[D00`3_c[D0mmJm0?OFaP030?OF_@<0klje0140klJ]0<J<H`3N]I`0
gZfD0<JLQ02LJe80LdXi05Y2>@2]Q6/0]JFU0<je_@2m]Kd0Nf=J07=2:@2]Q6/0aZfU06=:@P0202TH
600905Xa:@24DST0Nc4Q07=2:@2LJe80]G]S0;EcFP2]Je80YF=:0080[EY20P2UDST01@2]FT80aXaS
0>NeU03__JD0klJ]0080mmK600D0mmk>0?OFaP3gg/h0mmK60?ONcP020?OFaP040?OF_@3_c[D0klJ]
0>neY@80ikFL00@0gZF<0=JUS03FW7<0cYAk0P3>U7<00`2eS7<0_HA[0<JLL`020;f4H`80_HA[00D0
]Hac0<JLQ03FW8`0eZF<0=JLS0090=j]U080gZF<00D0eZF<0=JLS03FYH`0eYb<0=JUQ0020=JLQ005
0<JLQ03>U7/0eZF40=JUS03N[I@00`3N]I`30=j]U0@0eZF<00@0eZF40<JLQ03FYH@0eYb40P36W8@0
1P3FW8@0aYb40;fLS02mW8`0eZF<0=JLS0<0eZF<00D0aYb40;F4J`2LLf<0[F]B0:ESBP030:eJ@P80
_EY200H0aV]B0<icFP3FS7<0eYb40=jUS03ginL[0?Ogma00oooo000>0?ooo`040?O_k`3gmoL0moOg
0?O_kb<0moOg00d0mnON0?O6[@3NU7<0ig][0=ikJ`3_]JD0mkfe0>N]W01S>C40@QP@024@400a8AP0
>BTQ00<0DS4Y00P0DSTa06=2<@1S@S40LdY20=JUS03Fa[D0mmJm0>o>]@<0mmK60P3ge[d30>o>]@09
0>o6[@3ge[d0klje0?OFaP3ge[d0klje0?OFaP3_c[D0mmK60080klje0P3>U7/03P3N]JD0g[FL0<J]
Y@36W8@0[HA[06=:@P24He80YHAk0:fDU01J@ST0Q58i0<J]Y@3>]Jd0Ng=k0P0Y61P04`1B<BT0Q58i
09AB>@2DDST0S7=S0;fUW02mW8`0]Hac0;EkH`2LJe80S5Y20:E[DP2ULeX0]G]S0<J<H`3NYH`0kkfU
0?O>]@3_c[D00P3ge/H00`3gg/h0mmK60?ONcP030?OFaP80mmJm00T0klJ]0>nmY@3W_JD0ijfD0=jU
S03NW8@0eZF40=J<N`36S7<00P3>S6/01@36W7<0_HAS0;EkH`2eNf<0_HA[0080aYAk0P3FYH`00`3N
]I`0gYb<0=j]U0020=jeW0050>NeW03W_JD0g[FU0>nm[@3N]JD00`3N]I`20=j]U0060=JUS03N[I@0
eZF<0=jUS03FYH`0eYb41@3FYH`00`3N[I@0eZF<0=j]U0040=JUS0030=jUS03FYH`0eZF<0080eYb4
00D0eZF40=JLQ03FYH@0eYb<0<JLQ0020=JLS0080;fLS03FYH`0eZF<0=JUS03FW8`0aYAk0:ekJ`2U
LeX30:ESBP<0[EY200L0[F]B0<I[DP3>LeX0eXac0=jLQ03NYH`0mno_02/0moOg403oool000h0oooo
9@3gmoL20?ooo`0;0>oFcP3W]I`0gYAc0<icDP3>Q6<0ijfD0>N]W03_]JD0YG=J058a:@12:B400P0i
:B402012:C40BS4a058a:@1B<BT0Hd8a07]SDP1cDTX0g[FL0P3_c[D30?OF_@070?OFaP3ge[d0klje
0?OF_@3_c[D0mkfe0>o>]@020?OF_@80mmK60P3ge[d0503ge/H0klje0>o>]@3_c[D0ikfU0=JUS03>
S6/0gZfD0=K6]@36U7/0_Ib<0:F4N`2ULeX0FT8i06=2<@1J<B40LeYB09B4Q02LS8`0Q7>D0P0Y61P0
4P12<CT0Le9:08aJ@P24DST0Q6]J0;fUW036[JD0]IbL09acH`2<FT80Q58i0:eJ@P3>Q6<0eYac0>Ne
U03__JD0klJ]0>o>]@80mmK600<0mmk>0?OFaP3ge/H0103gg/h00`3ge/H0mmJm0>o>]@020>nmY@05
0>NeU03NYH`0gYb40=JLL`3>U7/00P3>S6/00`2mQ6/0_HAS0;EcFP030;EcFP040;f4H`3>U7<0eZF4
0=j]U0D0g[FL00@0eYb<0=jeW03N]JD0gZfD0P3FYH`00`3N]I`0eZF<0=j]U0030=jeW0080=j]U03F
YH`0gZfD0=JLS03FYH`0eZF40<JLQ03FYH`20=j]U0<0g[FL00L0gZfD0=JUS03FYH`0aYb40=JUQ036
W8@0eZF40080aYb400@0cYAk0=JUQ036W8@0eZF40`36W8@20=JUS00:0=JLS036W8@0aYAk09acH`2U
Je80U6=:0:E[DP2UHdX0[EY20:ESBP80aV]B00H0cW=J0<j<J`3NW8@0gYb40=jUS03gknl[0?Ogma00
oooo000>0?ooobD0moOg00d0g/kF0:fLS03N]I`0mlJ]0>MkJ`3>Le80cW=J0=jLS03W[I@0ijfL0;F4
J`1S>C40>BTQ0080:APH00T0@RTQ04Xa<@0i:B40@RTQ058i<@1cBST0S7=S0=jeW03_aZd00P3_c[D2
0?OF_@040>o>]@3ge[d0mkfe0>o>]@@0mmJm00<0klje0?OF_@3ge[d00P3ge/H0603_c[D0mmJm0?OF
_@3ge[d0klje0>NmY@3N[I@0cYAk0=j]U03ge[d0klje0=j]U036W8@0aYAk09acH`1cBST0HcTY06<i
<@1kHeX0DTYJ01P@400Y61P0@RTa05Y2>@80Ld8a00/0S7=S0;FLW02UQ8@0]Hac09a[DP2UHdX0[EY2
0;f4H`3>S6/0eZF40>NeU0020>o6[@030>o>]@3ge/H0mmK60080mmK61@3gg/h03@3_c[D0mmJm0>o6
[@3__JD0ikFL0>NeU03NYH`0eYb40=JLL`3>U7<0cXa[0;f4J`2mQ6<00`2eLeX01`2ULe80S34Y08AB
>@2UHdX0]G=J0=JLQ03FYH`00P3N]I`20=JLS0050<jDN`3>S8@0aYAk0<jDN`2eS7<00P2mQ6/00`36
S7<0]Hac0<JLQ0050=JUS0060=JUQ03FYH`0eZF<0<JLQ036U7/0eZF41@3FYH`20=JUQ080eZF<00P0
eZF40<jDN`36W8@0eZF40<JLQ03>U7/0eYb40<JLQ080eZF400H0eYb<0=JUS03FYH`0aYb40<jDN`2e
S7<309a[DP80YF]B00X0YF=:0:e[DP2eLeX0cW=J0<j4H`3>S6/0eYb40=JLS03NYH`0mnOW:`3gmoL@
0?ooo`003P3ooolT0?Ogm`0?0?ooo`1[DTX0Ld8Y0>NeU03gaZd0cXAS0<icDP3>LeX0gYb40>N]W03W
[I@0eYb407=:@P0a8AP0<B4Q0080@RTQ0P1B<BT01P12:B40FS4Y06=2<@24He80gZfD0>o>]@H0mmJm
00D0klje0?OF_@3_c[D0mmJm0>o>]@030?OF_@030?OFaP3_c[D0mmJm00<0mmJm00T0mmK60>o>]@3_
aZd0ikfU0=j]U03FYH@0gZfD0>o>]@3__Jd00P3N]I`00`2eS7<0Q6=B08aJBP0206=2<@0:058a:@0Y
61P0<B4H048Q601S>BT0Ld8Y06<i:@24He80Nf=J09a[DP80[F]B0P2eLeX02P36Je80cXa[0=jUS03W
]I@0ikFL0>nm[@3_c[D0mmK60?OF_@3ge/H40?ONcP0O0?OWgP3gg/h0mmK60?OF_@3_c[D0klJ]0>nm
Y@3W]I@0gZF<0=JUQ03FS7/0cYAc0;f4J`36S6<0_HAS0;EkH`2mQ6<0]G=J0:e[DP1c@RT0NbTH07/a
8@24BST0]G]S0<J<L`36U7/0cYAk0<J<L`36S6<0_HA[0;EkH`020;F4J`80YF]B00D0[G=J09a[DP2U
LeX0]G]S0;f4J`020<JDN`040<JDQ036W8@0aYb40<JLQ0<0eZF400D0cYAk0<JLQ03FYH@0eZF<0=JU
Q0030=JUS0050=JUQ036W8@0aYAk0<JDN`3>U7/01036W8@0603FW8@0aYb40<JLQ03FW8`0aYb40=JL
S036W8@0aYAk0;F<L`2LJe80U6=:09AJBP2UHdX0YF]B09AJBP2]Je80eW=S0<j4H`3>S6/0eXak0=JL
L`3FS7/0eYb40?OWib/0moOg403oool000h0oooo0P3gmoL0103gknl0moOg0?Ogm`3gknl20?Ogm`03
0?O_k`3gmoL0moOg01P0moOg00/0mno_0;FLW0126100Ld8Y0>NeU03__JD0iiB40<icDP3FLf<0ikFD
0>nmY@020>NeW00<08ASDP0Q4100<B4H04Xa<@1B<BT0@RTQ048Y<@0i:B40DS4Y06=:@P24He80g[FL
0P3_c[D02@3ge[d0klje0>o>]@3ge[d0klje0?OF_@3_c[D0mmJm0>o>]@020?OF_@040>o>]@3ge[d0
mmJm0?OF_@@0mmK601X0mmJm0>o>]@3_c[D0klJ]0>NmY@3W]I`0eZF40=j]U03ge[d0klje0<J]Y@2e
S7<0gZfD09AcJ`24DT80Le9:08AB>@1cBST0Hd8a06<i:@1c@S40Ld8Y06=2<@2DHdX0S5Y209ASBP80
]G=J00X0aV]B0;EcFP36S6<0gYb40>NeU03N[I@0ikFL0>NmY@3_c[D0mmJm0P3ge/H60?ONcP0;0?OF
aP3_c[D0klje0>nmY@3W_JD0ikFD0=jUS03FYH@0eYac0<jDL`3>S6/00P2mQ6<04@36W7<0_HAS0;Ec
FP2eLeX0W5Y207=2:@1k<B40Q5920:f4N`2eS7<0aYAk0<JDQ02mQ6/0[HAk0:ecFP2ULeX0W6]B0080
U6=:00D0W6]B09acH`2LLf<0W7=S0:EcFP0209a[DP040:ecFP2eNf<0]Hac0<JDQ0<0aYAk00<0aYb4
0<jDN`36U7/00P36W8@20=JUQ0060<jDN`3FYH@0cYAk0=JUQ036W8@0cYAk0P36U7/00`36W8@0eZF4
0<JLQ0030<JLQ0030=JUQ03FW8`0eYb40080aYAk00D0[HA[08aJBP2DHdX0U6=:09a[DP0309ASBP08
0<J<H`3>S6/0cXa[0=jDL`3NW8@0eXac0=jLQ03ginL[0?Ogma00oooo000>0?ooob40moOg00T0oooo
0>ONi`2DNg<0FS4Y048H401J<B40gYAc0?O6[@3__JD00P3W]I`02`3gaZd0ikFL0>NeW03WYH`0Q592
024@400i:B40BS4a058a:@0i:B40@RTQ0080DS4Y00D0Hd8a08ASDP3N]JD0klJ]0>o>]@030?OF_@04
0>o>]@3ge[d0klje0?OF_@80klje00@0mlje0>o>]@3ge/H0mmJm0`3ge/H01P3ge[d0mmK60?OFaP3g
e[d0mmK60?OF_@80klje00H0ikfU0>NeW03N[I@0gZfD0>o>]@3N[I@20=jeY@0309acH`2]Q6/0]HA[
0080W6]B00<0Le9:08aJBP2LJe800P24DT80102ULe80[F]B0:f4J`2mQ6<30;EcFP<0ikFD00<0gZF<
0>NeU03__JD00P3_c[D0103ge[d0mmK60?ONcP3gg/h30?OWgP040?ONcP3ge/H0mmJm0>o6[@80kkfU
00@0ikFL0=jUS03FW8@0eXak0P3>S6/08P2mQ6/0_HAS0;f4J`2mQ6/0_HAS0;EcFP2]Je80YG=B09AB
>@2<FT80[Hb40<J][@3>_KD0e/Jm0=K6aP2m]Kd0Q6]J08AB>@1S>BT0NbTH06<i:@1c@RT0Hd8a08AB
@P2ULeX0W7=S09a[DP2DFU80Q58i08aJ@P2DHdX0]G]S0;F<L`2eQ6/20;F<L`050<JLL`2eS7<0cXa[
0<JLL`36S7<00`36U7/00`36W7<0aYAk0<jDN`030<jDN`040=JUQ036W8@0aYb40=JLQ0<0eYb<0P36
W8@01`36S7<0]Hac0;EkH`24DT80S5Y208aJBP2<He800P2<FTX02@2LJe80aXaS0=J<L`3FS7/0eYac
0=JLQ03>Q6<0gYAc0>oFcP0[0?Ogma00oooo000>0?ooob00moOg00T0oooo0>oWi`2LS8`0HcTY048Y
8@126100DR4H0=JLL`3W]I@00`3gaZd02P3__JD0ijfD0>NeU03NW8`0Q592034Q601B<BT0BS4a058i
<@0i:B42048Y8@0705Xa8@1SBT80Q6=B0=jeW03_c[D0mlje0?OFaP020>o>]@030?O>]@3_c[D0klje
0080klje00<0ikfU0>o6[@3_c[D00P3ge[d20>o>]@80mmJm0`3ge/H00`3ge[d0mmK60>o>]@020>o>
]@0?0>o6[@3W]I`0gZF<0<jDN`3FYH@0ikfU0=jeY@36W8@0g[FL0=JUQ02eS7<0YG=J09a[DP2]LeX0
W6]B0080U6=:0P2eLeX20;f4H`80]G=J00L0eYac0=jUS03W]I@0gZF<0>NUS03W]I`0klJ]0080klje
00<0mmK60?ONcP3gg/h01@3gg/h00`3ge/H0klje0>nmY@020>nmY@060>NeW03NYH`0eYac0<jDN`3>
U7<0cXa[0P2mQ6<0102eNf<0aYac0;f4J`2eNf<20;EcFP0=0:ESBP24BST0W7=S0<J]Y@3Fa[d0e/K6
0<jmaP2]U9@0HcTY07/a8@1S>BT0DR4H05Xa8@0307=2:@0906=2<@24DST0W6]B0:E[DP2DFTX0S5Y:
08AB@P2<FT80W7=S00<0[HA[00D0]HA[0:f4J`2]Q6/0[HA[0;F4J`020;f4J`050;F<L`36S7<0aYAk
0<jDN`36W8@00P3FW8@01036W8@0eYb40<JLQ036W8@20=JUS00;0=JLS03FYH`0aYAk0<J<L`2eS7<0
W7=S08AB@P24He80Nf=B08aJBP24He800P24DT800`2mQ6/0eXac0=JLL`020=jLQ0030<j4H`3FS7<0
mmK602/0moOg403oool000h0oooo00@0mno_0?Ogm`3gmoL0mno_0P3gmoL00`3gknl0moOg0?O_k`02
0?Ogm`030?O_k`3gmoL0moOg01<0moOg00T0aZf]06=2<@12:B40DR4H048H401:8AP0aXaS0>NUS03W
]I@00P3gaZd02`3W]I`0ijF<0>NUS03FW8@0S5Y:05Xa:@1B@ST0HdY2048a>@12:B40<B4H0080@RTQ
00<0HdY208aSDP3N]JD00`3_c[D20?Nm]@080>o>]@3ge[d0mmJm0>o>]@3ge[d0ikfU0>NeW03_aZd2
0>o>]@80mmJm00D0klje0?OFaP3ge/H0kmK>0?OFaP020?OF_@090?OFaP3_c[D0klje0>o>]@3_aZd0
ikFL0=jeW03FYH`0gZF<0080eZF<00<0g[FL0=j]U03FYH`00P2eS7<01036S7<0_HAS0;EkH`2eLeX2
0;f4H`80]G=J00@0aXaS0=JUQ03NW8@0gYb40`3W[I@01P3W_JD0kkf]0>o6[@3_c[D0mmJm0?OFaP80
mmk>0P3gimh0103gg/h0mmK60>o>]@3gc[D20>o6[@070>NmY@3W]I`0gZF<0=JLQ03FW7<0cYAc0<j<
J`020;f4H`0Q0;EkH`2mQ6/0_HA[0;f4H`2eLeX0[F]B0;EcFP2UJe80S5Y20:F4N`36[Jd0g/kF0;fe
_@1kHeX0Q58i0:F4N`1B<BT08A0@034Q8@12<CT0LdXi08AB@P1kHe80Hd8a07]SDP24JeX0W6]B09AJ
BP2<FT80Hd8a08ASDP2LJe80YG=J0080W7=S00X0W6]B09ASBP2ULe80[G=J0;EkH`2mQ6/0cXa[0<J<
L`3>U7/0eZF40P36W8@01@3FYH@0aYb40<JLQ03FYH@0aYb40080eZF<00H0eYb40=JUQ036U7/0]Hac
0:f4J`2LJe8208AB@P0=07=:>@24JeX0Q6=B08aJBP24DT80cXa[0=JLQ03NW8@0gZF<0<j<J`3>Le80
gW][0=K6_@0[0?Ogma00oooo000>0?ooo`80moOg00<0mno_0?Ogm`3gmoL06`3gmoL01@2eW9`0Hd8a
048Y8@1:8AP0@RTQ0080@QP@00<0FS4Q0<I[DP3WYH`00P3W]I@20<j<J`040<J<H`2UHdX0HcTa06=2
<@80DT8i00P0DS4Y03TY8@12:B40@RTQ058a:@1SBT80Q6=B0=K6]@<0klje0P3gc[D02P3_c[D0mmJm
0?OF_@3_c[D0mmJm0>NmY@3FW8@0cYAk0=j]U03W_JD20>o>]@040?OF_@3_c[D0mmK60?OF_@80kmK>
0`3ge/H01@3ge[d0mmK60>o>]@3__Jd0klJ]0080ikfU00@0ikFL0>NeU03N]I`0gZfD0P3FYH@20<jD
L`030<j<J`2mQ6<0cXa[0080eZF40P3NW8@30=jUS0050=j]U03W]I@0ikFL0>nmY@3_aZd00P3_c[D0
1`3ge[d0mmK60?OFaP3gg/h0mnON0?ONcP3gimh00P3gg/h02`3_c[D0mkfe0>o6[@3_aZd0kkfU0>Nm
Y@3N[I@0eZF<0=JLQ03>U7<0cXa[00<0_HAS0P2mQ6/04036W7<0_HAS0;EcFP2]Je80_HAS0;F4J`2e
LeX0YG=J09AcJ`2<Lf/0Nf=B0<J]Y@2mYI`0BSU:01P@400a8B420592>@0<06]BBP1cBT80LdXi07=J
DP2DQ8@0W8b<0:F4N`1kHeX0Je9:06=:@P1B@ST0HdY20P1[DTX01`1kHe80Q59209a[DP2eNf<0aYAk
0=JUQ03FYH`00`3FYH@01P36W8@0eZF40<JLQ03FYH@0aYb40=JLS0<0aYb401D0eYb40<jDN`36U7/0
[HA[0:EcFP1kHe80LdXi06]BBP1cDTX0Q58i06<i:@1S@S40S5Y20;f4J`3FYH`0gZF<0=J<L`3>HdX0
cW=B0<j4H`3_c[D0:`3gmoL@0?ooo`003P3ooolO0?Ogm`070=kFi`24JeX0DSTa05Xa:@1:8AP0@RTQ
024@4002048H400807=2:@36Je80gYAc0=jDL`2eLeX0[F]B0:EB>@1cBST205Y2>@0304Xa<@12:C40
@RTQ0080>BTQ00P0@RTQ058a:@1cBST0S7=S0>o6[@3gc[D0klje0?O>]@80klje0P3ge[d02`3_c[D0
mmK60?OFaP3ge[d0ikfU0<JDN`36S7<0gZfD0>nmY@3_aZd0klje0080mmK600<0mmJm0?OFaP3ge/H0
0`3gg/h0103_e/h0mmK60?OFaP3_c[D20>o6[@060>nm[@3W]I`0ikFL0>NeW03W]I@0gZfD0P3NYH`0
103NW8@0eZF40=JUQ03FYH@50=jLQ0050=jUS03WYH`0ikFD0>NeW03W_JD00P3_aZd0103g_KD0mmJm
0>o>]@3ge/H20?ONcP070?OWgP3gg/h0mmk>0?ONcP3ge/H0mmJm0>o>]@020>o6[@0W0>nmY@3W]I`0
gZfD0=jUS03FW8@0eYac0<J<L`36S6<0_HAS0;f4J`3>S6/0aYac0;f4J`36S6<0_HAS0:e[DP2eLeX0
]Hac0<J<L`2mQ6/0]G]S08ASDP1cBT80YHB40:fU[@12<CT0610@034Q8@1JDU80He9:07=:@P1c@S40
Hd8a07]SFP2UQ7/0U8B408akL`1cFU80DT8i00<0Hd8a00/0LdY207=2<@1kHe80W6]B0;EkH`2eQ6/0
_HAS0;f4J`3>U7<0cYAk0=JUQ0040=JUS0040=JUQ03FYH`0aYb40=JUQ080eZF<01D0aYb40=JUQ036
U7/0[HA[08aSDP1cBT80Je9:07=:@P1cBST0Je9:058i<@1S>BT0Q58i0<j<J`3FYH`0gZF<0<j<J`2m
FT80cW=B0=i[FP3Fa[D0:`3gmoL@0?ooo`003P3ooolN0?Ogm`0B0?ooo`3>]KD0LdXi06=2<@1S>C40
FS4Y048Y8@1261008A0@048H400Q4100FS4Q09AB>@2]FT80S5Y:07=2<@1c@RT0HdY20`1B>C402@12
:C40@RTQ034Q600i:B40<B4H058a:@1cBST0Q6]J0=jeY@030>o>]@80mkfe00@0klje0?O>]@3ge[d0
klje0P3ge[d02@3_c[D0ijfL0<JDN`3>S7<0gZfD0=jeW03_aZd0klje0?OF_@020?OFaP030?ONcP3g
e/H0mmk>00<0mmk>00<0mmK60>o>]@3_c[D00P3_c[D00`3W_JD0ikFL0=j]U0020>NeU080gZfD0P3N
W8@0103NYH`0gYb40=jLQ03NW8@40=jUS0050=j]U03W]I`0ikfU0>o6[@3__JD00P3_c[D01@3ge[d0
mkfe0?OFaP3gg/h0mnON00@0mmk>0P3ge[d01@3_c[D0klJ]0>nmY@3W_JD0ikFL0080gZF<00X0eZF4
0<jDN`3>S6/0aXaS0;f4H`2mQ6/0_HAS0<JLL`3>S6/0aYac0P36S6<07`2eLeX0cYAk0<jDN`36S7<0
]Hac0;EkH`2ULeX0Q58i07]SFP12<CT0610@02TH600i:CT0DSTa06=2<@1c@RT0FS4Q07=JDP2DNg<0
S7=S06=:@P1:<C40Hd8a07=:>@1kHe80Q6=B08AB>@2DHdX0[G=J0;F4J`2mQ6/00P36U7/0303>U7/0
]Hac0<j<J`3>U7<0eZF40=JUS03FYH@0aYb40=JUQ03FW8@0aYb40=JLS080eYb40P36W8@00`36U7/0
[HA[08ASDP0206]BBP0407=:>@24DT80Je9:058i<@80Hd8a00@0cXac0=JUS03NYH`0cXAS0P3>HdX0
0`3>Q6<0mkfe0?Ogm`0Z0?Ogma00oooo000>0?ooo`030?O_k`3gmoL0moOg01/0moOg00P0oooo0:fD
U01J<BT0DS4Y06<i:@1B>C40DS4Y024@4080@QP@00`0BQ08024@401:40P0@QP@08AB@P1J@ST0DS4Y
06=2<@12:C40>BTQ058i<@1B<BT403TY8@04058a:@1SBT80YG=J0=jeY@80klje00P0mkfe0>o>]@3_
c[D0klje0?Nm]@3_c[D0mmJm0?OFaP80klje00<0kkf]0=jLS036U7/00P3FYH`00`3N[I@0kkf]0>o>
]@020?OFaPD0mmk>00<0mmK60?ONcP3ge/H00`3_c[D0103__Jd0klJ]0>NeW03W]I`40=jUS0040=j]
U03NYH`0gZF<0=jLQ080gZF<00L0gYb40=jUS03W]I@0gZF<0>NeU03W]I`0kkfU0080klJ]00@0klje
0>o6[@3_c[D0mmK60P3gg/h02@3gimh0mmk>0?ONcP3gg/h0mmK60>o>]@3ge[d0kkf]0>o6[@020>Ne
W0030=jeW03NYH`0eZF<0080cYAc0P3>S6/00`2mQ6/0aYac0<J<H`020<JLL`0C0<j<J`36W7<0aYac
0<jDL`3FYH`0eZF40;F<L`36U7/0aXac09acH`1[DTX0FS4Y034Q8@0Y61P0<B4H058Q601S>BT0FS4Y
058a:@0207=BBP80FT8i00<0HdY205Y2>@24He800P24He800`2LJe80]G]S0<JLL`030;f4J`0=0<JL
L`3>U7/0eZF40<JDN`3>U7<0aYb40<jDN`3FYH@0eZF<0=JLS036W8@0eZF<0<JLQ0020=JLQ0060=JU
Q036W8@0aYAk0:EcFP1cBT80Hd8a0P1cBST03@1S@S40DS4Y058a:@1S@S40Ld8a0<jDN`3NW8`0eYb<
0<icFP2mFT80cV=:0<j4H`3_c[D0:`3gmoL@0?ooo`003P3oool20?Ogm`050?O_k`3gmoL0mno_0?Og
m`3gknl0603gmoL01`2DQ8@0DS4Y058a:@1B<BT0HcTY05Xa:@1261000`128AP020124100BQ08024@
401SBT80FT8i058a:@0i:C40@RTa0P0i:B40301B<BT0>BTQ03TY8@0i:B40@R4H058a:@1cBST0S7=S
0>o6[@3_c[D0klJ]0>o>]@<0mmJm0P3_c[D03P3ge[d0mmK60?OF_@3ge[d0klje0>N]W03NYH`0aXac
0=j]U03N]I`0eZF<0>NeW03_c[D0mmK60P3gg/h00`3gimh0mmk>0?OWgP030?ONcP0;0?OFaP3_c[D0
klje0>o>]@3__Jd0g[FU0>NeW03W]I@0gZfD0=jUS03N[I@0103NYH`0103FYH@0gZF<0=JUQ03NW8@2
0=jUS0090>NeU03W]I`0ikFL0>nmY@3_c[D0klJ]0>nm[@3ge[d0mmK600D0mmk>00H0mmK60>o>]@3g
_KD0klje0>o6[@3__JD30>NeW00;0=jeW03NYH`0eYb40<jDN`3>S6/0_HA[0<JLL`36S7<0_HA[0<JL
L`3>S6/00P3>U7<00`3>U7/0_HAS0<jDN`030=JUS00I0<jDN`2eS7<0YG=J08ASDP2<FTX0Q59207=:
>@1SBT80Hd8a05Xa:@1B>C40Hd8a048Y8@1S@S40LdXi07=:@P1kHe80W6]B08aJBP2LJe80[HA[0;Ek
H`2eQ6/0_HA[0;F<L`020<j<J`060<J<L`3>U7/0eZF40<jDN`3FW7<0eYb40P3>U7/0103FYH@0eZF<
0<JLQ03FW8@20=JUS0080<JLQ036U7/0]Hac08acH`1cBST0HdY206=2<@1J@ST206=:@P0;058a:@1c
@RT0Hd8a0<JLQ03N[I@0eYb40<I[DP3>HdX0cW=B0<j4H`3ge/H0:@3gmoL00`3gknl0moOg0?ooo`0?
0?ooo`003P3oool00`3gknl0moOg0?Ogm`0K0?Ogm`0;0>oWi`24JeX0FS4Q048Y8@1J<BT0DSTa06<i
:@126100@RTQ04XQ601B8AP00`126100101J@ST0DSTa04Xa<@12:B4203TY8@04034Q8@12:B40<B4Q
03TY8@<0@RTQ00<0LdXi08acH`3W_JD00P3_aZd00`3gc[D0klje0>o>]@040?OF_@030>o>]@3ge/H0
mmK60080klje00<0ijfL0<jDN`3>S8@00P3N[I@00`3FW8`0eZF<0>o6[@020>oFcP030?OWgP3gg/h0
mnON0080mmk>0P3_e/h00`3ge/H0klje0>o>]@020>o6[@030>NeW03N[I@0gZfD0080gZfD0100g[FL
0=jUS03NYH`0eZF40=JLL`3FS7/0eXac0<j<J`3FS7<0gYb40=j]U03W]I`0ikfU0>nm[@3W_JD0kkf]
0P3_c[D01@3ge/H0mmk>0?ONcP3ge/H0mmk>0080mmK600@0mmJm0>o>]@3_c[D0kkfU0P3W]I`03@3W
_JD0gZfD0=j]U03FYH`0gZF<0<JLQ036S7<0cXa[0;F<L`3>S6/0aYac0<jDL`3>S6/00P3>U7/02@3>
U7<0eZF40;f4H`3>U7<0eZF<0=jeW03FYH`0aYAk0:EcFP0209acH`030:EcFP24DT80Q6=B0080HdY2
01D0Q58i07]SDP1B>C40HdY208aSDP2ULeX0[HA[09ASBP2]LeX0]HA[0:f4J`2mQ6/0]Hac0<JLL`36
S7<0aYac0<jDL`36W7<0aYAk0=JUQ03FYH`00P36W8@01P3FW8@0aYb40<JLQ036W8@0eZF40=JLS080
eYb400L0aYb40<JDN`2]Q6/0Q6=B07=:>@1S@S40DSTa0080HdY200`0DSTa05Xa:@1S>BT0HcTY0=JL
Q03FYH`0cXa[0<iSBP2mFT80cW=B0=J<L`3_e/h[0?Ogma00oooo000>0?ooo`<0moOg00<0mno_0?Og
m`3gmoL0603gmoL01`3Nc]H0LeYB058a:@1J<BT0DSTa06=2<@1S>C400P12:B401P1J<BT0@RTQ034Q
601:8AP0FS4Q05Y2>@80BS4a0100>BTQ034Q8@0i:B40<B4Q03TY8@12:B40>BTQ034Q6012:B40DS4Y
07=:>@2ULeX0g[FU0>o6[@3gc[D0mkfe0P3_c[D0103ge[d0mlje0>o>]@3ge/H20?OF_@80mmK600`0
mmJm0>nm[@3NW8@0eYb<0=JUS03FW8`0aYB40<JDN`3FYH`0mkfe0>o>]@3ge/H40?ONcP0<0?OFaP3g
e[d0e/Je0>o6[@3N]JD0klJ]0=jeY@3N[I@0eZF<0=JUQ03FYH`0eZF40`3>U7/00`2mQ6/0aXaS0;Ec
FP020;EcFP060<J<H`3FS7/0eZF<0=j]U03W]I`0ikfU0P3__Jd0103_c[D0mmK60?OFaP3_e/h30?OF
aP050?OF_@3ge/H0klje0>o>]@3_aZd00P3__JD0103__Jd0ikFL0=jUS03N[I@30=JUS0060<jDN`3>
S6/0_HA[0<JLL`2mQ6/0aYac0P3>U7<01`3>U7/0cYAc0<jDL`3FYH@0cYAc0<JLL`3FYH@00P3N[I@0
1036U7/0aYb40;F<L`2]Q6/20:EcFP0>08ASDP1cDTX0S6=B09a[DP2ULeX0LeYB0:EcFP2]Q6/0YG=J
0:f4J`2eNf<0]G=J0;f4J`36S7<30<JLL`H0cYAk00D0eYb40=JUQ03FW8@0eZF40=JLQ0020<JLQ00C
0=JUQ036W8@0aYb40<JLQ036U7/0YG=J08AB@P1SBT80DSTa058a:@12<CT0DS4Y048Q6012:B40FS4Q
05Xa:@3FYH@0eYb40<j4H`020;eJ@P030<icDP3FW7<0mnOW02/0moOg403oool000h0oooo1@3gmoL0
1@3gknl0moOg0?O_k`3gmoL0mno_01@0moOg00/0[IBU058i<@1J<BT0FS4Y058i<@1J<BT0Hd8a048Y
8@1J<BT0Hd8a05Xa:@03058a:@05058i<@12:B40DSTa03TY8@0Y61P00P0a8AP0300a8B40DS4Y03TY
8@0a8AP0@RTQ05Xa:@1cBT80Q6=B0=jeW03_aZd0klje0?O>]@80klje00D0mlje0>o>]@3ge[d0mmJm
0>o>]@030?OF_@060?OFaP3ge[d0kkf]0>N]W03N]I`0eYb<0P2]Q7/01P2mQ6/0[HAk0<JDN`2]Q7/0
aYAk0:f<Q0<0]Hac00H0[G][09a[DP2<Lf<0W7=S08acH`24He8308aJBP0309ASBP2DFU80U6=:0080
S5Y200<0YF=:0:E[DP2UJe800`2]Je801P2eLeX0cYAk0=JUS03N]I`0ijfL0>NmY@<0klje103ge/H0
1@3ge[d0klje0?OF_@3_c[D0klJ]0080kkfU00L0klJ]0>NeW03W]I`0g[FL0=j]U03FYH`0eYb<0080
cYAk0P3>U7<0103>S6/0_HA[0<j<J`3>S6/20<JLL`030<jDN`3FYH@0eZF40080cYAc00<0gYb40=JU
S03FYH@00P3FYH@00`3FYH`0eZF40<JDN`020<JDN`80[HA[00T0]G]S0:ecFP2eNf<0[HA[0:EcFP2]
LeX0]G]S0<JLL`36S7<0103>U7/01@3FW7<0eYb40=JLQ03FW7<0aYb40080eYb40P3FYH@01@36W8@0
eZF<0=JLQ03FYH`0eZF400@0aYb400l0[HA[08ASDP1S@S40Hd8a058a:@1J@ST0HdY2058a:@12:B40
@R4H04XQ601c@S40eYb40;f4J`3>LeX00P2mFT800`3>Le80gZF<0?O_k`0[0?Ogma00oooo000>0?oo
o`040?O_k`3gmoL0moOg0?O_k`L0moOg00<0mno_0?Ogm`3gmoL0403gmoL0202eYJd0LdXi05Xa:@1J
<B40@RTQ048Q6012:B40BR4H0`12:B43058a:@04058i<@12:B40@RTQ04Xa<@80<B4Q00d0:APH034Q
8@1B<BT0@RTQ034Q8@0i:B40DS4Y07=:>@2LJe80eZF<0>NmY@3_aZd0klje0080mlje00<0klje0?Nm
]@3ge[d01@3ge[d00`3ge/H0klje0?OF_@020>o>]@050>N]W03FW8`0aYB40;F<L`2eQ6/00`2eS7<0
0`36U7/0[HAk0:f4N`0309AcJ`80S6=B00<0U5YB08aJBP2<FTX00P2DFU804@2LJe80U5Y:09AJBP2L
FT80U5YB09AJBP2UJe80U6=:09AJDP2]LeX0_HAS0;f4J`3>U7/0gZF<0=j]U03W_JD0klJ]0080klje
00H0mmK60>o>]@3ge/H0mmk>0>o>]@3gc[D20>o>]@070>o6[@3__JD0kkfU0>nmY@3__Jd0ikfU0>Ne
W0020=jeW00:0=JUS03FW8`0aYb40<jDN`3>S7<0aXac0;f4J`3>S6/0aXaS0;f4J`80cXa[00<0aYac
0=JUQ03FYH@00P3FYH@0103>U7/0eZF40=JUQ03FYH`30=JUQ0040<JDN`36W7<0aYac0:f4J`<0]HA[
00T0]G]S0:ecFP2]Q6/0_HA[0<jDN`36U7/0cYAk0<JLQ03>U7/00P3FW8@20<JLQ00;0=JLQ036W8@0
eYb40<JLQ03FYH@0cYAk0=JLQ03FYH`0eYb40<JLQ03FYH`00P3FW8@20<JLQ00@0<JDN`2]Q6/0Nf=B
06=:@P1B<BT0DSTa06=:@P1B@ST0>BTQ048Y8@0a8AP0@R4H08AB@P3FW8@0_HA[0<I[DP80_EY200<0
cW=B0=jUS03gknl0:`3gmoL@0?ooo`003P3ooolN0?Ogm`030;FUY@1SBT80DS4Y0080@RTQ00H0@R4H
048Y8@0a8AP0@RTQ058a:@0i:B42048Y8@80DS4Y00@0>BTQ048Y8@1:<C40>BTQ0P0a8AP02@0Y61P0
<B4Q058a:@1B<BT0@RTQ058a:@1S>BT0S6=B0=JUS0020>o6[@040>o>]@3gc[D0mlje0?OF_@80klje
00<0mlje0?OF_@3_c[D0103ge[d20?OFaP80klje00X0kkf]0=jeW03FW8`0]Hac09AcJ`2]Nf/0U7]c
0<JDN`2]S8@0]Hac0`2]Nf/00`2LLf<0W6]B09AJDP0208aSDP0;0:EcFP2DFU80U5YB09AJDP2DFTX0
S5Y:09AB>@2DFU80U5Y:0:EcFP2eNf<00P2mQ6/01P2eS7<0eYb40=j]U03W]I`0ikfU0?Nm]@80klje
103ge/H0103ge[d0klje0?Nm]@3_c[D30>o6[@040>nmY@3_aZd0kkfU0>NmY@80g[FL00P0gZfD0=JL
Q03>S8@0cYAk0<J<L`2mQ6/0_HAS0;EkH`<0_HAS00T0aYac0<J<L`3>U7<0cYAk0=JUQ03N[I@0eZF<
0=jUS03FYH`00P3FYH@20<jDN`80cYAc00L0aYac0;F4J`36W7<0cXa[0;f4J`36S7<0cYAc00<0cYAk
00<0eYb40<JLQ03FW7<00P36W8@03@3FYH@0eYb<0=JUQ036W8@0eZF40=JLQ03FYH@0aYb40<jDN`36
W8@0eZF<0<JLQ03FYH@00P36W8@0603FW8@0eZF40=JUQ02eS7<0W6]B07=:@P1B<BT0BS4a058i<@12
<CT0HdY20592>@12:B40@R4H048H402DHdX0cYAk0;f4J`2eLeX0[EY20;eJ@P36Je80gZfD0?O_kaP0
moOg00@0mno_0?Ogm`3gmoL0mno_3`3gmoL@0?ooo`003P3oool00`3gmoL0mno_0?Ogm`040?Ogm`06
0?O_k`3gmoL0moOg0?O_k`3gmoL0mno_0`3gmoL0103gknl0moOg0?Ogm`3gknl40?Ogm`030?O_k`3g
moL0moOg00<0moOg00D0]JF]06=:@P1J<BT0DS4Y04XQ6002048Y8@03048Q6012:B40BR4H00D0@RTQ
00@0>BTQ034Q601B<BT0>BTQ0P0a8B42034Q60<0DS4Y00L0DSTa06=2<@24DT80aYb40>NmY@3_aZd0
klje0080mlje00D0klje0?OF_@3ge[d0mmJm0?Nm]@030?OF_@060?OFaP3ge[d0mmK60?OFaP3gg/h0
mmJm0P3_c[D01@3__Jd0[HAk0;f4J`2]Nf/0]HA[00<0[G][00T0_HA[0:f4N`2]S8@0aYAk09AkL`2]
Nf/0W7=S0:EcFP2DFU800`2ULeX00`2UJe80U5Y:09AJDP020:E[DP050:e[DP2eLeX0_HA[0;f4J`3>
U7/00P3W[I`01@3W_JD0kkf]0>o6[@3gaZd0klje00<0mmK600H0mmJm0>o>]@3gc[D0mmJm0>o>]@3_
aZd20>nmY@80klJ]00D0ikfU0>nm[@3W[I`0g[FL0=j]U0020<JLQ0040<J<L`2eS7<0[G=J0:ecFP80
YF=:00D0[F]B0;EcFP2eNf<0cXa[0<JLL`020<jDL`030=JUQ03FYH`0eZF40080gZF<00<0eZF<0=jU
S03FYH`00P3FYH@00`3>U7/0eZF40<jDN`030=JUQ0070<JLQ03FW7<0eYb40<jDN`3FYH@0aYb40=JL
Q0020=JUQ0050<JLQ03FYH@0eYb<0=JUQ03FYH`00P36W8@02@3FW8@0cYAk0<JLQ03FYH`0eZF40<JL
Q03FW8@0eZF40=JUS0020<JDN`030:f4J`2<Lf<0HdY20080DS4Y00l0@RTQ0592>@1SBT80BS4a034Q
60128AP0@RTQ0;EkH`3>S6/0eW=S0;EcFP3>HdX0]E8i0<I[DP3NYH`0;03gmoL@0?ooo`003P3oool5
0?Ogm`030?O_k`3gmoL0moOg01H0moOg00d0aZfm06=:@P1S>BT0DS4Y04XQ6012:B40@R4H048Y8@12
8AP0@RTQ03TY8@12:B40BR4H0080@RTQ00X0>BTQ024@4012:B40@RTQ034Q8@0a8AP0<B4Q03TY8@12
:B40DSTa0P1SBT801P1cBST0Nf=B0<JLQ03N]I`0g[FU0>o6[@80klje00@0mlje0?OF_@3ge[d0klje
0`3ge[d60?OFaP80mmJm00L0mmK60>o>]@3__Jd0eZF<0=jLS03FW8`0aYB40080eYb<00<0[Hb40<JD
N`3>S8@00P3FW8`20<JDQ0040:f4N`36S7<0aYAk0:f4N`80aYAk0P2mQ6/0202mQ6<0_HA[0<j<L`3>
U7/0eYb40=jUS03W[I@0kkf]0`3_c[D00`3ge[d0klje0?OFaP040?OFaP050>o>]@3gc[D0klje0?Nm
]@3_c[D00P3__JD0103_aZd0kkf]0>NmY@3__Jd20=jeW0090=j]U03FW8`0cXb40<J<L`2mQ6/0YF]B
09aJ@P2DDST0S5Y20080W5Y200D0YF=:0;EcFP2mQ6/0aYac0<jDL`020<jDN`80eZF40140gZF<0=JU
Q03FYH@0eZF<0=jUS03FYH`0gZF<0=jLQ03FYH@0eZF<0=JUQ03FYH`0eZF40=JUS036W8@0eYb40<JL
Q0020=JUQ080eYb<00<0eZF40<JLQ03FYH`00P3FYH`02`3FW8`0eZF40<JLQ03FW7<0aYb40=JLQ03F
W8`0aYb40=JUQ03FW8`0aYb40080aYAk00@0[HA[07=:@P1S@S40DS4Y0P0i:B401`1:<C40DT8i03TY
8@0i:B40<B4H07=:>@36S7<00P2mQ6<01P2eLeX0[EY20;eJ@P3>Le80aYAk0=K6_B/0moOg403oool0
00h0oooo1`3gmoL00`3gknl0moOg0?Ogm`0C0?Ogm`040?O_k`3F_LH0Le9:05Xa:@D0@RTQ00H0>BTQ
04XQ600a8AP0<B4H048Y8@1B<BT2048Y8@05024@400i:B40@RTQ034Q600a8B400P0a8AP02P0i:B40
DS4Y06=:@P1cDTX0LdY207=BBP2eS7<0gZfD0>nm[@3_aZd20>o>]@030?O>]@3_c[D0mmJm00H0mmJm
203ge/H04P3_c[D0mkfe0<je]@3g_KD0ijfL0=jeW03N]JD0ijfL0=jeW03_]JD0c[Fe0>nm[@3N]JD0
ijfL0=jeY@3>]Jd0eZF<0>N]W080g[FL00D0g[FU0>N]W03N]I`0ijfL0>nmY@030>nm[@060>o>]@3_
_Jd0mmJm0>o>]@3ge[d0klje0`3ge/H05P3_c[D0mmJm0>o>]@3g_KD0klje0?OF_@3_c[D0mlJ]0>nm
Y@3__Jd0klJ]0>o>]@3__Jd0kkfU0>NmY@3W[I`0g[FL0=j]U03FW8`0cYAk0;f4J`2ULeX209AJBP80
S5Y200H0Q58i08aJ@P2DHdX0[G=J0;EkH`36W7<20<jDL`80eZF400H0eZF<0=jUS03FYH`0gZfD0=JU
S03NYH`30=JUS0030=jUS03FYH`0eZF400H0eZF<00<0eYb40=JUS03FYH@01P3FYH`0203FYH@0eYb<
0<JLQ03>U7/0aYb40=JUS03FW8`0aYb40P3FYH@20<JDN`0@08acH`1cBST0DSTa048Y8@0a8B40DS4Y
04Xa<@12:C40>BTQ0592>@1B<BT0S5Y:0<j<L`36S6<0_HAS0;EcFP80]E8i00@0_HAS0<j<J`2DNg<0
oooo:P3gmoL@0?ooo`003P3oool01@3gmoL0mno_0?Ogm`3gmoL0mno_00L0moOg00<0mno_0?Ogm`3g
moL03`3gmoL01@3Fc]h0Q6]J06<i<@1J<B40<B4H0080@RTQ00<0BR4H03TY8@12:B400P12:B402@1B
<BT0@RTQ048Y8@12:B40:APH034Q6012:B40<B4H048Y8@02034Q8@80>BTQ00L0@RTQ06=:@P24He80
S6=B0<JDN`3FYH`0g[FL00<0klJ]0`3_c[D50?OF_@<0mmK600@0mmk>0?OFaP3ge/H0mmk>0`3ge/H5
0>o>]@050?Nm]@3ge/H0e/K60?OFaP3Fa/H00P3ge/H03@3Fa[d0mkfe0?Nm]@3g_KD0e/Jm0>o>]@3g
_KD0mmJm0=K6aP3ge[d0mkfe0=K6aP3ge/H00P3_c[D00`3g_KD0klje0?OF_@020>o>]@D0mmK600P0
mmJm0>o>]@3gaZd0klje0?OF_@3gc[D0klJ]0>nm[@<0klJ]00h0kkf]0>NmY@3W_JD0g[FU0>N]W03N
]I`0eZF<0=JLS03>U7/0[G=J09a[DP2DHdX0Q59208AB>@<0Q4Xi00L0U6=:0:EcFP2eNf<0_HA[0<J<
L`3>U7<0eZF400<0eZF<0`3N[I@20=jUS0<0eZF<00@0eYb<0=JUQ03FYH`0eZF<0P3FW8@50=JUS003
0<JLQ03FYH`0eZF<0080aYb400X0eZF<0=JUQ03FW8@0aYb40=JLS03FYH`0eZF40<JLQ03>U7/0eZF4
0P2eS7<0102<He80HdY2058a:@12:B4203TY8@0:048Y<@0i:B40<B4Q06=:@P1B>C40W6]B0<jDL`2e
Nf<0cW=J0:e[DP80[EY200@0aV]B0;f4J`1cDTX0g]KW5`3gmoL00`3gknl0moOg0?Ogm`0?0?Ogm`03
0?O_k`3oool0oooo00h0oooo000>0?oooah0moOg00X0knOW08acJ`1S>C40HcTa048Y8@1:8AP0DS4Y
04XQ600i:B40@RTQ0P0a8AP4048Y8@06034Q600Q4100<B4H048Y8@0a8AP0>BTQ0P12:B402@1B<BT0
DSTa06=:@P1cBST0Nf=B0;F<L`2mW8`0g[FU0>NmY@020>o6[@060>nmY@3_c[D0mlje0>o>]@3ge[d0
mlje0P3ge[d40?OFaP80mmk>0P3ge/H>0?ONcP040?OWgP3gg/h0mnON0?OWgPD0mmk>00<0g/kF0?OF
aP3ge/H0103ge/H01P3ge[d0klje0?OFaP3ge[d0mmK60?ONcP80mmK600P0klje0?OFaP3_c[D0klJ]
0?Nm]@3_c[D0klJ]0>nmY@<0klJ]00<0kkfU0>o6[@3__Jd00`3W_JD02P3W[I`0g[FL0>NmY@3N]I`0
cXb40;f4J`2]LeX0YG=J09AJBP24DST208AB@P0307=:>@1c@S40LdXi0080Q59200<0S5Y:09ASBP2m
Q6/00P3>U7/70=JUS080eZF400`0aYb40=JUQ03FW8@0aYb40=JUS03FYH@0aYb40=JLQ03FYH@0aYb4
0=JUS036W8@20<jDN`050<JLQ03>S8@0aYb40<JLQ03FYH`00P3FW8`0103FYH@0aYb40=JLQ03>U7/2
09acH`0406]BBP1B<BT0@RTQ03TY8@80@RTQ0140>BTQ034Q8@1:<C40DT8i05Xa:@2<FTX0]G]S0<J<
L`2]LeX0[F]B0:EB>@2]FT80]G=J0:E[DP1B<BT0[IBD0?OWgP0Y0?Ogma00oooo000>0?ooo`030?Og
m`3gknl0moOg00<0moOg00<0mno_0?Ogm`3gknl00P3gmoL00`3gknl0moOg0?Ogm`0@0?Ogm`0A0>ON
k`2<Ng<0LdXi05Y2>@12:B40>BTQ04XQ6012:B40>BTQ034Q6012:B40@R4H03TY8@12:B40>BTQ058a
:@0a8AP00P0Q4102048Y8@0302TH6012:B40@RTQ0080DS4Y00L0HdY207=:@P1kHe80[HA[0<JLQ03N
[I@0ikfU00@0klJ]0P3gc[D30?OF_@<0mmK600<0mmk>0?OFaP3gg/h03@3gg/h00`3gimh0mmk>0?ON
cP040?ONcP030?OWgP3gg/h0mmk>00D0mmk>0`3ge/H01@3ge[d0mmK60?OF_@3ge/H0klje00<0mmK6
00X0mmk>0>o>]@3ge[d0mmJm0>o>]@3gc[D0klje0?O6[@3_c[D0kkfU1P3_aZd00`3W_JD0kkf]0>ne
Y@030>NmY@090>nm[@3FYH`0eZF<0<jDN`2mQ6/0[G=J09AJDP2<FT80S5Y:0080LdXi00T0HcTa06<i
:@1S@S40Hd8a07=:>@24DT80YG=J0;EkH`36W7<00P3FYH@0203FYH`0gZfD0=JUS03FYH`0eZF40=JU
S03FYH@0aYb40P3FYH@02@36W8@0eZF40<JLQ03FYH@0cYAk0<JLQ03>U7/0]Hac0<J<L`020;F<L`0:
0<JDN`3>U7/0eZF<0=JLS03FYH@0eZF<0<JLQ03FW8@0aYb40<jDN`80YG=J00<0LdXi058a:@0i:B40
0`12:B404@0a8B40DS4Y0592>@1B<BT0FS4Y07=:>@2]Je80cXa[0;f4J`2]Je80YE8i0:eJ@P2eNf<0
U5Y:058a:@2LS8`0g/kF02T0moOg403oool000h0oooo7@3gmoL01P3gknl0knOW0:F4N`1S@S40LdXi
05Xa:@80@RTQ00H0@R4H03TY8@0a8AP0<B4H048Y8@0i:B44048Y8@808A0@00@0<B4H048Y8@12:B40
>BTQ0P1B<BT0201B>C40FT8i07=:@P1cDTX0[HA[0<JDQ036W8@0g[FL0P3W_JD0103_c[D0mlje0?OF
_@3_c[D40?OF_@80mmK600<0mmk>0?OFaP3gg/h02`3gg/h0103gimh0mmk>0?ONcP3gimh20?ONcP80
mnON0P3gg/h30?OWgPH0mmk>00<0mmK60?ONcP3ge/H0103ge/H0103ge[d0mmK60?OFaP3ge/H30?OF
_@060>o>]@3gc[D0klje0?Nm]@3_aZd0kkfU0P3_aZd00`3__JD0kkf]0>nmY@040>NmY@040>nm[@3W
_JD0kkf]0>NmY@80g[FU00L0gZF<0<j<Q036U7/0[G=J09a[DP2<FTX0Q58i0080LdXi00X0HcTa06<i
:@1S>C40Hd8a07=:>@1S@S40Q58i0:EcFP2eS7<0aYAk0P3FYH`20=JUQ0030<JDN`3FYH@0eZF40080
eZF40`3>U7/20<J<L`0=0<JDN`2LLf<0]G]S09acH`2LJe80[G=J0;F<L`36U7/0eZF<0=JLQ036W8@0
eZF40=JLQ0020<JLQ0060<JDN`2<FTX0S5Y:06=2<@12:B40DS4Y0P0i:B402012:B40<B4Q058i<@1B
>C40BS4a048Q601c@RT0U6=:0`2mQ6<0202]Je80]G]S0;F4J`24DST0Je9:08acJ`2eYJD0g]KW:03g
moL@0?ooo`003P3oool50?Ogm`030?O_k`3gmoL0moOg01L0moOg00@0U8B406<i<@1cBST0Hd8a0P1B
<BT01@0i:B40@RTQ048Y8@0i:B40@R4H00D0@RTQ00<0:APH024@400Y61P00P12:B402P0i:B40DS4Y
058a:@1S@S40LdXi07=BBP24He80]Hac0<JLQ03FYH`30=j]U0040>nmY@3_c[D0mlje0?O>]@@0mmJm
103ge/H20?ONcP070?OFaP3gg/h0mmk>0?ONcP3gimh0mmk>0?OWgP020?ONcP80mnON00@0mmk>0?OW
gP3gimh0mmk>0P3gimh01@3gg/h0mnON0?OWgP3gimh0mmk>0080mnON00<0mmk>0?OWgP3gg/h0103g
g/h30?OFaP040?ONcP3ge[d0mmK60?OF_@80mmK600D0klje0?O>]@3g_KD0klje0?Nm]@020>o>]@<0
klJ]00L0kkfU0>o6[@3_aZd0kkf]0>nmY@3__Jd0ikfU0080kkf]0P3W_JD20=jeY@070>NmY@3N]JD0
g[FL0=JUS03FW8`0_HA[09a[DP0209AJDP0?08aJBP1cBST0Ld8a06=2<@1S>BT0HcTa06=2<@1S>BT0
Ld8a08AB>@2<FTX0]HA[0;F<L`36S7<0aYac0080aXac00<0aYAk0<jDN`36U7/00P36U7/0102eS7<0
]HA[0;EkH`2LLf<309a[DP0409acH`2mQ6/0cXb40=JUS080eYb400H0aYb40=JLS03FW8@0eYb40<jD
N`36U7/207]SDP0H05Xa:@1B<BT0@RTQ02TH6012:B40>BTQ048Y8@1B@ST0@RTa048Y8@128AP0Ld8Y
08A:>@2]FT80[F]B0;EcFP2mQ6<0]G]S0:EcFP1cBST0HdY208acH`2LS8`0kmK>:03gmoL@0?ooo`00
3P3ooolO0?Ogm`070:fDU01S@S40LdXi06=2<@1B<BT0DSTa058a:@0203TY8@0404XQ600i:B40@RTQ
034Q60<0@RTQ0100<B4H024@400Q4100<B4H03TY8@1B<BT0@RTQ04Xa<@1B<BT0HdY207]SDP24He80
W7=S0<JDN`2mW8`0gZfD0P3N]JD0103_aZd0klje0>o>]@3ge[d20?O>]@040?OF_@3ge/H0mmK60?OF
_@80mmK62P3gg/h00`3gimh0mmk>0?ONcP050?OWgP030?ONcP3gimh0mnON00@0mnON0`3gg/h00`3g
imh0mmk>0?ONcP020?ONcPD0mmK600D0mmk>0?OF_@3ge[d0klje0?O>]@020>o>]@060?OF_@3_c[D0
mlJ]0?O6[@3_aZd0mlJ]0`3_aZd00`3__Jd0ikfU0>o6[@020>nmY@030>nm[@3W_JD0ikfU00<0kkf]
0P3W_JD0203N]JD0gZfD0=j]U03FW8`0aYAk0:ekJ`2]LeX0YG=J0P2LJe800`24DT80LdXi06=2<@02
06<i<@0406=2<@1cBST0LdXi08aJBP80W6]B00H0YG=J0:ecFP2]Q6/0]G]S0;f4J`2eNf<20:EcFPH0
W6]B00D0W7=S0;f4J`36U7/0eYb<0=JUS0020<JLQ080eYb40P36W8@0103>U7/0]Hac06]BBP1[DTX2
058a:@05034Q600i:B40DS4Y034Q601B<BT00P1:<C401@1B<BT0@RTQ05Xa8@1k<B40W5Y20080YE8i
00P0W5Y209AB>@24DT80FT8i06]BBP2<Lf/0[IbU0>ONibP0moOg403oool000h0oooo1@3gmoL00`3g
knl0moOg0?Ogm`0G0?Ogm`060:fDU01SBT80Hd8a07=:@P1S@S40DSTa0P12:B40100a8AP0@RTQ04XQ
600i:B45048Y8@07034Q600Q4100:APH03TY8@12:B40DS4Y06=2<@0206=:@P0607=:>@24He80U7=[
0<JDN`36U8@0eZF<0P3N]JD00`3_aZd0klje0?O>]@040?OF_@D0mmK6203gg/h0103gimh0mmk>0?OW
gP3gg/h20?OWgP030?ONcP3gimh0mnON0080mnON0P3gg/h01@3gimh0mmk>0?OWgP3gimh0mmk>0080
mnON0P3gg/h0103gimh0mmk>0?ONcP3ge[d20?OFaP060?OF_@3gg/h0mmK60>o>]@3ge[d0mmK60P3_
c[D0103ge[d0klje0?OF_@3_c[D40>o6[@060>nmY@3_aZd0klJ]0>nmY@3_aZd0ikfU0P3__Jd01@3_
aZd0kkf]0>nm[@3_aZd0kkf]0080ikfU00l0ikFL0=jeY@3N]I`0gZfD0=JUS03FW8`0aYAk0:f4J`2]
Nf/0W7=S0:EcFP2<FTX0Q59207=:>@1c@S400`1S@S400`1cBST0Q59208AB@P0208aJBP0609a[DP2U
Le80Q6]J09a[DP2<FTX0S6=B0P2LJe803@2ULeX0U5YB09a[DP2]LeX0]HA[0<jDN`3FW8`0aYb40=JU
S03FW8`0eYb40=JLS036W8@00P3>U7/01@36W7<0]Hac07=:>@1cBST0DS4Y0080<B4H0P12:B401P0a
8B40@RTa03TY8@1:<C40>BTQ048Q6080DR4H00X0Ld8Y08`a:@1c@RT0Nc4Q07=2<@1S>BT0Hd8a06]B
BP24JeX0]JFU:@3gmoL@0?ooo`003P3ooolO0?Ogm`090;FU[@1cBST0HdY207=:@P1cBST0DSTa04Xa
<@1:8AP0<B4H0080>BTQ00<0DS4Y048Y8@0i:B400`12:B401@0a8AP08A0@02TH600a8AP0<B4Q0080
DS4Y00P0FT8i07=:@P1kHe80Nf=B09AcJ`2eS7<0aYb40=JUS080g[FL00<0ikfU0>o>]@3g_KD00P3g
e[d00`3ge/H0mmJm0?OF_@040?OFaP@0mmk>00@0mmK60?ONcP3gg/h0mnON0P3gg/h90?OWgP050?ON
cP3gimh0mnON0?OWgP3gg/h00`3gimh00`3gg/h0mnON0?ONcP030?ONcP80mmK600<0mmk>0?OFaP3g
e/H00`3ge[d01`3ge/H0mkfe0?OF_@3ge[d0klje0?OF_@3gaZd0103_aZd20>nmY@030>o6[@3__JD0
kkf]00<0klJ]00D0kkf]0>o6[@3__Jd0ikfU0>nmY@030>NmY@050>NeW03W[I`0g[FL0=j]U03FYH`0
0P3FW8`01P36U7/0]Hac0;EkH`2LLf<0W6]B08aJBP80Q5920P1c@S4207=:>@80Q5920`2<FTX309a[
DP0808aJBP2LJe80Q6]J09a[DP2LLf<0[G=J0;f4J`3>S7<20<JLQ00:0=JLS03FW8@0eYb40=JLQ036
W8@0cYAk0=JLQ03>U7/0aXac0:f4J`80HdY200d0@RTQ034Q600i:B40@RTQ03TY8@12:B40>BTQ048Y
<@12:B40>BTQ034Q60126100HaP@0080NbTH00P0Lb4@05Xa8@1S>BT0HcTY07=:>@1cDTX0U8B40>oW
ibT0moOg403oool000h0oooo7`3gmoL01P36[Kd0LdXi06=2<@1cBST0LdY206=2<@80DS4Y0P12:B43
058a:@<0@RTQ00D0DS4Y03TY8@0Y61P08A0@02TH6003058a:@0806=2<@1SBT80LdY207]SDP2LLf<0
]Hac0:f<Q03FYH@20=jeW0070>NeW03__JD0mlje0>o>]@3ge[d0mlje0?OFaP020?OF_@040?OFaP3g
g/h0mmK60?OFaP<0mmk>00L0mmK60?ONcP3gg/h0mnON0?ONcP3gimh0mmk>00l0mnON203gg/h50?OF
aP070?OF_@3_c[D0mmJm0>o>]@3ge[d0klje0?O>]@020>o>]@80klJ]00L0mlJ]0>o6[@3_aZd0klJ]
0>nm[@3__JD0klJ]00<0kkf]0`3_aZd0103__Jd0ikfU0>NmY@3W]I`20>NmY@0;0=jeY@3N]I`0g[FL
0=jeW03FW8`0eZF<0=JLS036W8@0aYAk0;f4J`2eQ6/00P2LLf<0102DFU80Q59207=:>@1S@S4207=:
>@0308AB>@1cBT80Q58i0080Q59200D0S5Y:08AB@P2<FTX0U5YB09a[DP020:ecFP040;f4J`3>U7/0
aYb40=JLQ080eYb<0`36W8@01P3FW8@0cYAk0<JLQ036S7<0]Hac0:f4J`80Hd8a00X0@RTQ03TY8@12
:B40@RTQ03TY8@12:C40@RTQ058a:@0i:B40@RTQ0P0a8AP02`122000@QP@06<H401B8AP0HcTY05Xa
:@1J@ST0HdY206]BBP3Wg^L0oooo02T0moOg403oool000h0oooo7P3gmoL00`3_inL0]JFU07=BBP03
07=:>@0606]BBP1J<B40DSTa058i<@0i:B40DS4Y0P12:B404`1B<BT0@RTQ058a:@12:B40DSTa05Y2
>@1:<C40>BTQ058a:@1B>C40DS4Y058i<@1cBST0LdY208ASDP2ULeX0]Hac0<JLQ03FYH@00P3FYH`0
1P3W_JD0ikFL0>o6[@3gc[D0mmJm0>o>]@80mmJm103ge/H01@3gg/h0mmK60?ONcP3gg/h0mmK60080
mmk>00D0mnON0?ONcP3gg/h0mnON0?ONcP050?OWgP050?ONcP3gimh0mnON0?OWgP3gg/h01@3gimh7
0?ONcP030?OFaP3ge[d0mmJm0080mmJm00<0klje0?OFaP3g_KD00P3ge[d20>o>]@030?OF_@3_c[D0
mlJ]00X0klJ]1@3__Jd0203W_JD0kkf]0>NmY@3W[I`0ikfU0>N]W03W]I`0ijfL0P3N]I`01@3N[I@0
eYb<0=JUS036W8@0aYB400<0aYAk00<0]Hac0;F4J`2eNf<00P2LJe802P2DHdX0S5Y208AB@P24DT80
LdXi08A:>@2DFTX0W6]B0:E[DP2]LeX20;f4J`0:0<jDN`36W8@0eYb40<JLQ03FW8`0eYb40<JLQ03F
W8`0aYb40=JLQ080cYAk00@0aYAk0<J<L`2]Q6/0S6=B0`1B<BT2048Y8@0803TY8@1B<BT0@RTa058a
:@1:<C40<B4Q03TY8@12:B43034Q60<0@RTQ0P1B>C40101S@S40LeYB0=K6eP3Wg^LY0?Ogma00oooo
000>0?oooah0moOg00L0g]KW0:fLS01cDTX0HdY207=:>@1cBT80Le9:0080DSTa00@0BS4a03TY8@1B
<BT0DS4Y1012:B401`1B<BT0@RTQ058i<@1:<C40DS4Y04Xa<@1B@ST00P1J@ST01`1SBT80LdY208AS
DP2ULeX0[HA[0;F<L`2mW8`00P3FYH`0103N]I`0klJ]0>nmY@3_c[D50?OF_@80mmK600@0mmk>0?OF
aP3ge/H0mmK61`3gg/h40?OWgP030?ONcP3gimh0mnON00P0mnON00<0mmk>0?OWgP3gimh00P3gg/h0
1`3gimh0mmk>0?ONcP3gg/h0mmK60?OF_@3gg/h00P3ge[d02@3ge/H0mmJm0?OF_@3ge[d0klje0?OF
_@3_c[D0mlJ]0>o>]@050>o6[@80kkfU00<0klJ]0>nmY@3_aZd01@3_aZd0103W_JD0kkf]0>NmY@3_
]JD20>NmY@030=jeY@3W[I`0ijfL00<0g[FL00h0gZfD0=JUS03FW8`0eZF<0=JLQ036W8@0eYb<0<jD
N`36S7<0]Hac0;f4J`2eNf<0W7=S0:EcFP<0W6]B00H0YG=J0:ecFP2]LeX0]G]S0<J<L`36U7/30<JL
Q0080<jDN`3FW8@0eYb40<j<Q03FW7<0aYb40=JLQ036W8@20<jDN`040<J<L`2eS7<0[HA[07]SDP<0
DS4Y1012:B404`0i:B40DS4Y034Q8@0i:B40BS4a03TY8@0Q4100<B4H03TY8@1B<BT0@RTQ058a:@1B
>C40DS4Y05Y2>@1SDTX0S7=S09b<S03Fa[d0:03gmoL@0?ooo`003P3ooolG0?Ogm`040?O_k`3gmoL0
moOg0?O_k`<0moOg00P0e/K>08acH`24He80LdXi06]BBP1cBT80Le9:06]BBP80DSTa00<0DS4Y048Y
8@1B<BT00`12:B400`1B<BT0FT8i058i<@05058a:@0906=2<@1B>C40LdXi06]BBP1kHe80Q6]J09ac
H`2eQ6/0aYb40080eZF<00T0g[FL0>NmY@3_aZd0mlje0?OF_@3_c[D0mmJm0?OFaP3ge[d0103ge/H6
0?ONcP030?OFaP3gimh0mnON0080mmk>1@3gimh00`3gg/h0mnON0?OWgP080?OWgP030?ONcP3gimh0
mmk>00<0mmk>00D0mmJm0?OFaP3ge/H0mmK60>o>]@020?OF_@080>o>]@3ge[d0mkfe0>o>]@3gc[D0
kkfU0>o6[@3gc[D20>o6[@80kkfU00@0klJ]0>nm[@3__JD0kkfU0P3__Jd30>o6[@030>nmY@3__Jd0
klJ]00D0ikfU00D0g[FU0=jeW03W[I`0ijfL0=jeW0030=j]U00:0=JUS03FW8`0eZF<0=JUS03FW8`0
aYb40<jDN`36U7/0]Hac0<J<L`H0_HA[00X0aXac0<jDN`3>S8@0eZF40=JLS036W8@0eYb40<j<Q03F
W8`0aYb40P3FW8@02@3>S8@0aYb40=JLL`36W8@0cYAk0;F<L`2mQ6/0YG=J07=:@P03058a:@80@RTQ
00D0BS4a048Y8@0i:B40>BTQ034Q8@0204Xa<@0?034Q8@0a8AP0:APH048Y8@0i:B40<B4H058a:@1:
<C40DS4Y04Xa<@1B>C40HdY207=BBP2]W8`0mno_02L0moOg403oool000h0oooo7P3gmoL0203>]KD0
Q6]J07=:>@1cBST0Je9:06=2<@1cBST0Je9:0P1S@S402P1B>C40DS4Y058a:@1B<BT0@RTQ058a:@12
:B40BR4H048Y8@1B<BT3048Y8@80DS4Y00P0DSTa06=2<@1[DTX0LdY208aSDP2LLf<0]HA[0<JDN`80
eZF<00D0gZfD0=jeW03_aZd0klJ]0?O>]@040?OF_@80mmK60`3gg/h00`3ge/H0mmk>0?ONcP020?ON
cP80mnON0P3gg/h<0?OWgP030?ONcP3gimh0mnON0080mnON1P3gg/h0103ge/H0mmk>0?OF_@3ge/H2
0?OF_@080>o>]@3ge[d0klje0?OFaP3_c[D0mkfe0>o6[@3gc[D20>o6[@<0kkfU0`3_aZd01P3__Jd0
klJ]0>o>]@3_aZd0kkfU0>nm[@80klJ]00@0kkf]0>NeW03W]I`0ikfU0`3W]I`50=jeW0030=j]U03F
YH`0eZF<0080eZF<1@3FW8`40<jDN`080<j<Q03>U7/0cXac0<jDN`36W8@0eYb<0<JLQ03FYH`20=JL
Q00?0<JLQ03FW8@0eYb40=JLQ03>S8@0aYb40=JLL`3FS7/0aYb40<j<Q036S7<0]Hac0:f4J`2LJe80
LdXi00<0DS4Y0`12:B401@0i:B40@RTQ03TY8@0i:C40BS4a0080>BTQ0P0a8B40100i:B40<B4H03TY
8@12:B43058a:@0403TY8@1[DTX0Je9:09b<S2P0moOg403oool000h0oooo3@3gmoL00`3gknl0moOg
0?Ogm`0>0?Ogm`060;FLW01kHe80LdXi06=:@P1cBST0Hd8a0P1SBT801P1B>C40HcTa05Y2>@1B>C40
DS4Y058i<@80@RTQ00D0>BTQ034Q60128AP0DS4Y05Xa:@04058a:@0805Xa:@1B>C40Hd8a07=:@P1k
He80S6=B09acH`2eQ6/20=JUQ0040=JUS03N[I@0klJ]0>o>]@@0mmJm1@3ge/H00`3gg/h0mmK60?ON
cP060?ONcP040?OWgP3gg/h0mmk>0?ONcPd0mnON0`3gg/h00`3gimh0mmk>0?ONcP020?ONcP060?OF
aP3_c[D0mmJm0?OF_@3ge/H0mmJm0P3_c[D00`3ge[d0klje0>o>]@020>o6[@040>nmY@3_aZd0klJ]
0>nmY@80kkf]1P3_aZd01P3__JD0klJ]0>o6[@3_aZd0kkf]0>NeW0<0ikfU00L0ikFL0>NmY@3W_JD0
g[FL0>N]W03N]I`0ijfL0080gZfD00@0gYb<0=j]U03FW8`0g[FL0P3FYH`01`3FW8`0eZF<0=JLS03F
YH`0eYb<0=JUS03FW8@00P36W8@01`3FW8`0eYb40=JUS03FW8@0aYb40=JLS036W8@00P3FW8@03@36
W8@0eYb<0<jDN`3FW8@0eXak0=JLQ036W8@0aYAk0<J<L`2eNf<0YG=J08ASDP1S@S400`1B<BT02@12
:B40>BTQ03TY8@0i:B40@RTQ034Q8@1B<BT0@RTa03TY8@02034Q8@09034Q600a8B40>BTQ04Xa<@12
:B40DS4Y048Y8@0a8AP0@RTQ0080HdY200<0S7=S0>oFcP3gmoL09P3gmoL@0?ooo`003P3ooolN0?Og
m`0809b<S01cDTX0LdXi07=:@P1cBST0Je9:06=2<@1SBT84058i<@0304Xa<@1S@S40@RTQ00<0@RTQ
00D0BR4H048Y8@1B>C40DSTa058a:@02048Y8@04058a:@1S@S40Hd8a06=2<@80Q6=B00@0S7=S0:f4
J`36U7/0aYAk0P3FYH`00`3__JD0klJ]0>o>]@020?OF_@050?OFaP3ge[d0mmJm0?OFaP3gg/h00P3g
e/H00`3gg/h0mmK60?ONcP020?ONcP80mnON0P3gg/h00`3gimh0mmk>0?OWgP020?ONcPT0mnON00<0
mmk>0?OWgP3ginL01`3gg/h0103ge/H0mmJm0?OF_@3_c[D20?OFaP80mmJm0P3gc[D0103_aZd0mlje
0>nmY@3__JD20>o6[@040>o>]@3_aZd0kkf]0>nmY@<0klJ]103__JD0103W_JD0kkf]0>nmY@3W]I`2
0>NmY@050>NeW03__Jd0ikfU0=jeW03W[I@00P3N]I`20=j]U080g[FL00P0gZfD0=JUS03N[I@0g[FL
0=JUS03N[I@0g[FL0=j]U080eZF<00<0eYb40=JUS03FW8`00P3FYH`01P3FW8@0aYb40=JLQ03FW8@0
eZF40=JLQ080eYb<0`3FW8@02P36W8@0eYb40<JLQ03>U7/0aXac0;F<L`2]Q6/0U6=:07=:@P1B>C44
058a:@0<03TY8@12:B40@RTQ034Q8@0i:B40@RTa058a:@0a8B40>BTQ034Q600i:B40<B4Q1012:B40
200a8AP0:APH048Y8@1SBT80Je9:06=BBP36[Jd0oooo9P3gmoL@0?ooo`003P3ooolF0?Ogm`030?O_
k`3gmoL0moOg00D0moOg00d0YHAk07]SDP1[DTX0Je9:06=:@P1cBST0HdY206]BBP1S@S40DSTa06=2
<@1J@ST0DS4Y0080@RTQ0P1B<BT00`0a8AP0@RTQ048Y8@05048Y8@08048Q6012:B40Hd8a05Y2>@1c
BT80Q6=B08aSDP2]Q6/20;F<L`070=JUQ03N[I@0ikfU0>o6[@3_c[D0mlje0?OF_@060?OFaPD0mmk>
00<0mnON0?ONcP3gg/h00P3gg/h30?OWgP030?ONcP3gimh0mmk>00X0mnON0`3gg/h01@3gimh0mmk>
0?ONcP3gg/h0mmK600@0mmJm00H0mkfe0>o>]@3ge[d0klje0?Nm]@3_c[D20>o6[@030>nm[@3__JD0
kkfU00<0klJ]00@0kkfU0>o6[@3_aZd0klJ]0`3__JD0103W_JD0kkfU0>nm[@3__JD20>NmY@030>nm
Y@3W_JD0ikfU0080ikfU00D0ikFL0=jeW03N]I`0ijfL0=jeW0030=j]U0040=jeW03N[I@0eZF<0=JU
S080gZfD103FYH`00`3FW8`0eZF<0=JUS0020=JLQ0040<JLQ03FW8@0eZF<0<JLQ0<0eYb400<0aYb4
0=JLQ036W8@00P3FW8@01`36W8@0cYAk0<jDN`36U7/0[HA[09a[DP24He800P1S@S43058a:@80>BTQ
00P0@RTQ034Q8@0i:B40@RTa04Xa<@0i:B40DS4Y034Q8@80<B4H00D0>BTQ04XQ601B<BT0@RTQ03TY
8@02024@4005058a:@1SBT80Je9:07=:>@2]U9@09`3gmoL@0?ooo`003P3ooolH0?Ogm`030?O_k`3g
moL0moOg00<0moOg00D0Q6]J07]SDP1S@S40LdY206]BBP0207=BBP80HdY20P1B>C401`1J@ST0HcTa
058i<@1B<BT0>BTQ048Y8@0i:B400`12:B400`0a8AP0@RTQ048Y8@02048Y8@80DS4Y00D0Hd8a06]B
BP1cBST0Nf=B08aSDP0209acH`040;F<L`3>U7/0ikfU0>NeW080klJ]00<0mlje0?OF_@3ge/H01P3g
e/H;0?ONcPL0mnON00<0mmk>0?OWgP3gg/h00`3gimh20?ONcP030?OWgP3gg/h0mmk>0080mmk>00<0
mmJm0?OFaP3_c[D0103ge[d20>o>]@060?O>]@3_aZd0klJ]0>o6[@3__Jd0klJ]103__JD20>o6[@0<
0>nm[@3_aZd0kkfU0>nmY@3__Jd0kkfU0>NmY@3_]JD0ikfU0>NeW03__JD0ikFL0P3W_JD02@3W]I`0
ikfU0=j]U03W[I`0g[FL0>NeW03W[I`0g[FL0>N]W0020=j]U0060=jeW03N[I@0gZfD0=jeW03N[I@0
gZF<103FYH`00`3FW8`0eZF<0=JLQ0020=JLS080eZF<00H0eYb<0=JUS03FW8`0eYb<0=JLQ036W8@3
0=JLQ0080<JLQ03>U7/0]Hac0:f4J`2ULeX0Q6=B07=:>@1B>C43058a:@80@RTQ0P0i:B40100a8B40
>BTQ058i<@0i:B4202TH6003034Q8@0a8AP0<B4Q0080>BTQ00X0<B4H048Y8@0a8AP0:APH034Q601B
>C40DS4Y06=2<@1cDTX0[Ib<9`3gmoL@0?ooo`003P3ooolN0?Ogm`0708A[FP1kHe80FS4Y07=:>@1S
@S40HdY207=:@P0206]BBP<0FT8i0P1B>C40201B<BT0BR4H048Y8@1:8AP0<B4H048Y8@1B<BT0FS4Q
0P1B<BT2048Y8@03058i<@1S@S40Hd8a0080LdY200/0LdXi08AB>@2LJe80W6]B0:f4J`2eS7<0gZfD
0>NeW03__Jd0klJ]0>o>]@020?OF_@D0mmK60P3gg/h00`3ge/H0mmk>0?OWgP030?ONcP040?OWgP3g
g/h0mnON0?OWgP80mmk>00@0mnON0?ONcP3gimh0mmk>1@3gimh00`3ginL0mmk>0?OWgP050?ONcP80
mmK60`3ge[d03@3ge/H0mmJm0?Nm]@3ge[d0mlJ]0>o6[@3gaZd0klJ]0>o>]@3__JD0kkf]0>nmY@3W
]I`0103__JD0303_aZd0kkf]0>nmY@3__JD0klJ]0>NmY@3__JD0ikfU0>nm[@3W_JD0ikFL0>nmY@80
ikFL0P3W_JD01@3N]I`0gZfD0=j]U03N[I@0g[FL00@0gZfD0P3N]I`00`3FYH`0gZfD0=jUS0040=JU
S0040=JUQ03FYH`0eYb<0=JLQ080eZF<00<0eYb40=JUS03FW8@01@3FW8@02P3>S8@0eYb40=JLQ036
W8@0aYAk0;F4J`2LLf<0YG=J07]SDP1cBST2058i<@80@RTQ00L0>BTQ034Q600a8B40<B4Q058a:@1:
<C40>BTQ0080:APH00L0>BTQ034Q600Y61P0>BTQ048Y8@0a8B40>BTQ0080<B4H00P0:APH048Y8@1B
@ST0DS4Y058i<@1cDTX0W8b<0?O_kbH0moOg403oool000h0oooo7P3gmoL00`1cDTX0Nf=B06=2<@02
06=:@P0306=2<@1[DTX0LdXi0080HdY200D0DSTa05Y2>@1J@ST0DSTa058a:@03048Y8@03034Q6012
8AP0@RTQ0080@RTQ0`1B<BT01`12:B40DS4Y06=2<@1cBT80LdXi07]SDP1cBT800P24He80102ULe80
]G]S0=JUQ03W]I@20>o6[@030>o>]@3ge[d0mmJm00L0mmK6103gg/h01P3gimh0mmk>0?OWgP3gg/h0
mnON0?ONcP80mnON00<0mmk>0?OWgP3gimh01@3gimh20?ONcP030?OWgP3gg/h0mmk>00D0mmk>0P3g
e/H0203ge[d0mmK60?OF_@3_c[D0mmJm0>o>]@3_aZd0klje0P3_aZd20>nmY@030>o6[@3__JD0kkfU
00H0kkfU0P3_aZd30>nmY@80ikFL00@0kkfU0>NmY@3W_JD0ikfU103W]I`0103N[I@0ijfD0=jeW03W
[I@40=j]U0030=jeW03N[I@0gZF<00D0eZF<00@0gZF<0=JUS03FYH`0eZF4103FYH`02036W8@0eYb<
0<JLQ03FW8@0aYb40=JLQ036W8@0eYb40P36W8@02@3>U7/0_HA[0:f4J`2ULeX0Nf=B07=:>@1J@ST0
DSTa058a:@03034Q600503TY8@0a8B40>BTQ04Xa<@1S@S400P0Y61P0200a8B40>BTQ02TH600a8B40
<B4H03TY8@0a8AP0>BTQ0P0Q41002@0a8AP0@RTQ048Y8@1B<BT0Hd8a07=BBP2UQ7/0g/kF0?ooo`0U
0?Ogma00oooo000>0?oooaX0moOg00/0mno_0?Ogm`3gmoL0moOg05Y2>@1cBST0HdY206]BBP1cBST0
HdY207=:@P0206=:@P0306]BBP1S@S40DSTa0080DSTa1@12:B400`0a8AP0@R4H048Q6002048Y8@09
058a:@12:B40DS4Y058a:@1B>C40LdY207]SDP1cBT80Q6=B0080Q58i00D0Q5920:EcFP3FYH@0gZfD
0>o6[@020>o>]@030?O>]@3_c[D0mmJm0080mmK600<0mmJm0?OFaP3gg/h0103gg/h01P3gimh0mmk>
0?OWgP3gg/h0mnON0?ONcPd0mnON203gg/h30?OFaP080>o>]@3ge[d0mmK60>o>]@3ge[d0mkfe0>o>
]@3g_KD20>o6[@80kkfU00D0klJ]0>nmY@3__JD0kkfU0>o6[@030>nmY@030>NmY@3__JD0kkfU0080
kkfU00H0ikfU0>nm[@3W_JD0ikFL0>NmY@3W[I`30>NeW080ijfD00<0g[FL0=j]U03N[I@01@3N[I@0
103N]I`0eZF<0=jUS03N[I@20=JUS0040=j]U03FYH`0gZF<0=JUS080eYb40P3FYH`0103FW8@0eYb<
0=JLQ036W8@50=JLQ080cYAk00P0aYAk0;F4J`2LLf<0YG=J07]SDP1cBST0Hd8a058a:@@0>BTQ00D0
<B4H034Q8@1B<BT0BS4a03TY8@0202TH6005034Q8@0Y61P0<B4Q034Q600Y61P00P0a8AP02`0a8B40
8A0@034Q600a8AP0@RTQ058a:@12:B40FT8i07=BBP2DLf/0c[g602H0moOg403oool000h0oooo4P3g
moL01P3gknl0moOg0?Ogm`3gknl0moOg0?O_k`D0moOg00d0knOW06=:@P1cBST0HdY207=:>@1[DTX0
Hd8a06]BBP1SBT80LdXi06]BBP1SBT80DSTa0080FT8i00D0DS4Y048Y8@12:B40@RTQ058a:@02034Q
6004048Y8@1:8AP0@RTQ048Y8@@0DS4Y00<0Je9:07=BBP24DT800`24He802024DT80W6]B0<JDN`3F
YH`0gZfD0>o6[@3gc[D0klje0P3ge[d60?OFaPH0mmk>00H0mnON0?ONcP3gimh0mmk>0?OWgP3gg/h8
0?OWgP030?ONcP3gimh0mnON00T0mmk>00D0mmK60?OF_@3ge/H0mmK60?Nm]@020>o>]@040>o6[@3_
c[D0kkfU0>nm[@80kkfU00D0klJ]0>nmY@3W_JD0kkfU0>o6[@060>nmY@040>NeW03__JD0ikfU0>Nm
Y@@0ikFL00<0gZfD0>N]U03W]I@00P3N]I`00`3W[I@0g[FL0=j]U0050=j]U0070=jUS03N[I@0eZF<
0=JUS03NYH`0eZF<0=jUS0020=JUS00>0=JUQ03FW8`0eZF<0=JUQ03FYH`0aYb40=JUQ036W8@0eYb4
0=JLS03FYH`0aYb40=JLQ036W8@20<jDN`080;F<L`2]Q6/0YG=J08ASDP1cBST0HdY2058a:@12:B45
03TY8@04058a:@1:<C40>BTQ024@40<0<B4Q0P0a8AP00`0Y61P0<B4H02TH6003034Q6009024@400i
:B40>BTQ058a:@12:B40Hd8a06]BBP2<Lf<0e/Jm02H0moOg403oool000h0oooo7@3gmoL01`3_inL0
S7=[07=JDP1S@S40HdY206]BBP1S@S400P1[DTX03@1SBT80Je9:06=:@P1J@ST0Hd8a06=:@P1B<BT0
@RTQ058a:@12:B40DS4Y048Y8@128AP00P12:B400`1:8AP0@RTQ058a:@03058a:@0406=:@P24DT80
Nf=B08AB@P80Q6=B00L0Q59209ASBP36S7<0eZF40=j]U03W_JD0klje00@0mmJm103ge/H70?ONcP<0
mnON00<0mmk>0?OWgP3gimh01P3gimh00`3gg/h0mnON0?ONcP020?ONcP030?OWgP3gg/h0mnON00D0
mmk>00@0klje0?OF_@3ge/H0klje0`3ge[d20?O6[@@0klJ]1@3__JD03P3_aZd0kkfU0>nmY@3__Jd0
kkfU0>NeW03__JD0kkf]0>NmY@3__Jd0ikFL0>NeU03W]I`0gZF<0P3W]I`01P3N[I@0g[FL0>N]U03W
[I@0g[FL0>N]U0D0gZfD00<0eZF<0=j]U03N[I@01@3FYH`0303NW8@0eZF<0=JUS03FYH`0eZF40=JU
S03FW8`0eZF40=JLS03FW8@0aYb40=JUQ080eYb400/0aYb40<jDN`36U7/0aXac0;F4J`2LLf<0W6]B
08ASDP1cBT80DSTa058a:@02048Y8@<0>BTQ00<0DS4Y04Xa<@1B<BT00P0Y61P0200a8AP0:APH034Q
600a8B40:APH034Q600Y61P08A0@0P0a8AP0100Y61P0<B4H03TY8@0i:B42058a:@0405Xa:@1cBST0
S7=S0=k>eRH0moOg403oool000h0oooo4P3gmoL0103gknl0moOg0?Ogm`3gknl40?Ogm`0:0?O_k`3g
moL0moOg0>oWi`1kHe80Le9:07=:>@1S@S40Je9:07=:>@80HdY20P1[DTX01`1SBT80FT8i058i<@1S
BT80DSTa058a:@12:B400P1B<BT01@12:B40<B4H034Q6012:B40DS4Y0080@RTQ0`1B>C40101S@S40
Je9:07=:@P1kHe8208aSDP0908ASDP2<FTX0_HA[0<jDN`3N[I@0ikfU0>o6[@3_c[D0mlje0080mmJm
0`3ge/H20?ONcP030?OFaP3gg/h0mmk>00<0mmk>00@0mnON0?ONcP3gimh0mmk>2P3gimh00`3gg/h0
mnON0?OWgP070?ONcP040?OFaP3ge[d0mmK60?OFaP80mmJm0`3_c[D30>o6[@<0kkfU00<0ikfU0>nm
Y@3__JD01P3__JD01P3W]I@0kkfU0>NmY@3__JD0kkFU0>NmY@<0ikFL00L0ikfU0>NeW03W[I`0gZfD
0=jeW03N[I@0ijfL00<0gZfD00@0gZF<0=j]U03FYH`0gZfD0P3NYH`0103FYH`0gZfD0=JUS03NYH`3
0=JUS00=0=jUS03FYH`0eZF<0=JUS03FW8@0eYb<0<JLQ03FW8@0aYb40=JLS03FW8@0aYb40<jDN`02
0<JDN`0:0<J<L`2eQ6/0YG=J08aSDP1kHe80Hd8a058i<@1B<BT0@RTQ03TY8@80@RTQ00<0DSTa05Y2
>@1B<BT0100Y61P3034Q8@80:APH00L08A0@034Q600Y61P0<B4H034Q8@0a8AP0>BTQ0080@RTQ00D0
DS4Y058i<@1[DTX0U7]c0>ONi`0V0?Ogma00oooo000>0?oooaP0moOg00<0mno_0?Ogm`3gmoL00P3g
moL01`3Fa]H0Je9:06]BBP1S@S40FT8i06]BBP1SBT800P1cBST01`1[DTX0HdY207=BBP1SBT80FT8i
06=2<@1J@ST00`1B<BT01012:B40DS4Y05Xa:@0a8AP3048Y8@08058a:@0i:B40@RTQ058i<@1J<BT0
HcTY06]BBP24DT8208ASDP0:09a[DP2DFU80]HA[0<J<L`3N[I@0ikFL0>NmY@3_aZd0klje0?OF_@@0
mmK600@0mmk>0?OF_@3ge/H0mmK61P3gg/h<0?OWgP030?ONcP3gimh0mmk>00@0mmk>0`3ge/H00`3g
g/h0mmJm0?OFaP030?OF_@050>o>]@3gc[D0klje0>o>]@3_aZd01`3__JD02P3W]I`0kkfU0>NeW03_
_JD0ikFL0>NmY@3__JD0ikFL0>NmY@3__JD20>NeW080ikfU00P0ikFL0=jeW03W[I`0ijfD0=j]U03N
]I`0gZfD0>N]U0<0gZfD0`3NYH`00`3N[I@0eZF<0=jUS0040=JUS0030=jUS03FYH@0eZF<0080eZF<
00<0eZF40=JUS03FYH`00P3FW8@00`36W8@0eYb40<JLQ0020<JLQ0090<JDN`36S7<0aXac0;F4J`2]
Q6/0S5Y:07]SDP1SBT80Hd8a00<0DSTa00@0Hd8a058i<@1B>C40@RTQ0`0a8AP3034Q8@80<B4H100Y
61P01P0a8AP08A0@034Q600i:B40<B4H03TY8@80@RTQ00D0DS4Y06=2<@1cFU80c[Fm0?ooo`0V0?Og
ma00oooo000>0?oooaD0moOg00<0mno_0?Ogm`3gmoL00`3gmoL02@3gknl0moOg0=k>eP1cBST0FT8i
06=2<@1SBT80LdXi06]BBP0406=:@P80Je9:0`1J@ST01P1B>C40DS4Y058a:@1B<BT0@RTQ058a:@<0
@RTQ0`1B<BT2048Y8@0405Xa:@1S@S40LdXi07=:@P80S5Y:00L0Q6]J08aSDP2mQ6/0aXac0=JUQ03N
[I@0ikfU0080klJ]00<0mlje0?OF_@3ge/H01@3ge/H00`3gg/h0mmK60?ONcP020?ONcP040?OWgP3g
g/h0mnON0?ONcP80mnON00<0mmk>0?OWgP3gimh01@3gimh0103gg/h0mnON0?OWgP3gimh30?ONcP@0
mmK600@0mmk>0>o>]@3ge[d0mkfe0P3ge[d01`3_c[D0mlje0>o6[@3__Jd0klJ]0>nmY@3W]I`00P3_
_JD00`3W]I`0kkfU0>NeW0040>nmY@040>NmY@3W]I`0kkfU0>neY@<0ikFL0P3W_JD20>NeW0040=j]
U03W[I`0ijfD0>N]U0<0gZfD0P3NYH`01P3N[I@0eZF<0=j]U03N[I@0eZF<0=jUS0<0eZF<00<0eZF4
0=jUS03NYH`00`3FW8@05`3FYH`0eYb40=JLQ036W8@0eYb40<JLQ03FW8@0aYb40<jDN`36U7/0cYAc
0<J<L`2eS7<0[HA[09acH`24He80LdY207=:>@1SBT80FT8i06=2<@1B>C40DS4Y0080@RTQ00<0>BTQ
034Q8@0i:B400P0a8B400`12:B40<B4H034Q8@0402TH60808A0@00/0:APH03TY8@0a8AP0<B4H03TY
8@12:B40@R4H058a:@1S@S40YHAk0>oWi`0W0?Ogma00oooo000>0?ooo`l0moOg00@0mno_0?Ogm`3g
moL0mno_103gmoL0103gknl0moOg0?Ogm`3gknl20?Ogm`090<J]_@1cBST0HdY2058i<@1J@ST0HdY2
07=:@P1SBT80LdY20080LdXi0P1[DTX206=:@P0405Y2>@1S>C40DSTa058a:@80@RTQ0P1B<BT02`0a
8AP0@RTQ058a:@12:B40DS4Y05Xa:@12:B40HdY2058i<@1S@S40Q5920080Q6=B00P0YG=J09a[DP2m
Q6/0_HA[0<jDN`3FYH@0ikFL0>o6[@80klje0P3ge[d30?OFaP030?ONcP3ge/H0mmk>00D0mmk>103g
imh00`3gg/h0mnON0?ONcP020?OWgP030?ONcP3gimh0mnON00<0mnON203gg/h0103ge/H0mmJm0?OF
_@3ge/H30>o>]@050?Nm]@3_aZd0klJ]0?O6[@3__Jd00P3__JD00`3_]JD0ikFL0>nmY@020>NeW003
0>nmY@3W]I`0ikFL00<0kkfU00D0ikfU0>NeW03W]I`0ikFL0>NmY@020>NeW0040>N]U03N[I@0ijfL
0=jeW0<0gZfD00L0ijfL0=j]U03NYH`0gZF<0=j]U03NYH`0eZF<0080gZF<00<0eZF<0=jUS03FYH`0
0`3FYH`06@3FW8`0eZF<0=JUQ03FYH@0eYb40=JUQ03FYH`0eYb<0=JUQ03FW8@0aYb40<jDN`36U7/0
aXac0;F<L`2mQ6/0]HA[0:EcFP2LLf<0Nf=B07=:@P1cBST0Hd8a058i<@1S@S400P1B>C46034Q8@05
03TY8@0a8B40<B4H02TH600Q41000P0Y61P00`0H4100:APH034Q6003034Q600702TH6012:B40<B4H
024@401B>C40Je9:0:fDU00X0?Ogma00oooo000>0?oooaD0moOg00<0mno_0?Ogm`3gmoL01@3gmoL0
3P3>]KD0Je9:07=:@P1[DTX0Hd8a07=:>@1SBT80Je9:07=BBP1[DTX0HdY206]BBP1cDTX0Je9:0P1S
BT80201J@ST0FS4Y058a:@1B<BT0@RTQ058a:@1B>C40<B4H0P1B<BT02012:B40DS4Y058i<@1B>C40
HdY207=:>@1SBT80Q5920P24He801P2LJe80Q6]J0:f4J`36S7<0cXa[0=JLQ080ikFL00L0klJ]0>o>
]@3ge[d0mmK60?OF_@3ge/H0mmk>00<0mmK60P3gg/h01@3ge/H0mmk>0?ONcP3gimh0mmk>00T0mnON
00@0mmk>0?OWgP3gimh0mmk>0P3gimh30?ONcP0;0?OFaP3gg/h0mmk>0?OFaP3ge[d0mmK60>o>]@3g
e[d0mkfe0?OF_@3_c[D00P3__JD20>o6[@80kkfU0P3W_JD00`3W]I`0kkfU0>NeW0030>NeW0030>ne
Y@3W]I`0kkfU00<0ikFL00`0ijfD0>NeW03W[I@0ijfL0=j]U03W[I@0ijfL0=jeW03W[I`0gYb<0=j]
U03NYH`30=j]U0040=jUS03FYH`0gZF<0=jUS080eZF<00h0eZF40=JUS03FYH`0eZF<0=JUQ03FYH`0
eZF40=JLS03FW8@0cYAk0=JLS036W8@0eZF<0=JLQ080aYb40100cYAk0<J<L`2eS7<0aXac0;F4J`2L
Lf<0[HA[08acH`1kHe80LdXi06=2<@1J@ST0DSTa058a:@1:<C40@RTQ0P0a8B402P0a8AP0:APH034Q
600i:B40<B4Q034Q600Y61P0610@02TH600a8B42024@4005034Q600a8B40:APH034Q600a8B400P0i
:B401@0a8AP0>BTQ058i<@1cFU80c[Fm02P0moOg403oool000h0oooo4`3gmoL00`3gknl0moOg0?Og
m`050?Ogm`030?O_k`3Wg^l0c[g600<0Je9:00<0DSTa06=:@P1SBT800P1cDTX00`1[DTX0LdXi06]B
BP0206]BBP0706=:@P1J@ST0HdY2058i<@1:<C40DS4Y048Y8@02058a:@06048Y8@1B<BT0@RTQ058a
:@1B>C40FS4Y0P1B>C400`1cBST0Je9:07=:@P0208aSDP0>08A[FP2LJe80]HA[0;F<L`36S7<0eYac
0=j]U03W]I`0klJ]0>o>]@3gc[D0mmJm0?OFaP3ge[d30?OFaPL0mmk>00<0mnON0?ONcP3gimh00`3g
imh00`3gg/h0mnON0?ONcP020?OWgP80mmk>00H0mnON0?ONcP3gg/h0mnON0?ONcP3ge/H30?ONcP<0
mmK60P3ge[d0103_c[D0klJ]0?O6[@3gaZd20>o6[@@0kkfU00<0ikFL0>nmY@3W]I`00`3__JD40>Ne
W00<0>nmY@3W]I`0ijfD0>NmY@3W[I`0g[FL0>N]U03N]I`0ijfD0=j]U03W[I@0g[FL0P3N[I@0103N
YH`0gZfD0=jUS03FW8`20=JUS0030=JUQ03FYH`0gZF<0080eZF<00<0eYb<0=JUS03FW8@00P3FYH`0
203FW8`0eZF<0=JLQ03FW8`0eYb40=JUQ036W8@0eZF40P3>U7/01036U7/0aXac0;F<L`2eQ6/20:f4
J`80YG=J00L0LdXi06=:@P1S@S40DSTa058a:@1B>C40@RTQ00<0<B4Q00H0<B4H034Q8@0a8B40:APH
034Q600a8B4402TH6003024@400a8B40>BTQ0080:APH0P0i:B43034Q6004048Y8@1B<BT0Le9:0<J]
[BP0moOg403oool000h0oooo5@3gmoL00`3gknl0moOg0?O_k`040?Ogm`080?O_k`3Fa/h0LdY207=:
>@1SBT80DSTa06=:@P1cBST206]BBP0707=:@P1SBT80Je9:06]BBP1cFU80Je9:058i<@0205Y2>@<0
DS4Y00<0@RTQ058a:@1B<BT00P1B<BT2058i<@0605Xa:@1S@S40FS4Y06=:@P1cBT80Le9:0`2<He80
2`24JeX0]G]S0;f4J`36S7<0aYb40=jUS03W]I@0kkfU0>o6[@3_c[D0mmJm00D0mmK600<0mmk>0?OF
aP3ge/H0103gg/h01@3gimh0mmk>0?ONcP3gimh0mmk>0080mnON00<0mmk>0?OWgP3gg/h0103gimh7
0?ONcP80mmK60`3ge[d00`3_c[D0mlJ]0>o6[@020>o6[@030>nmY@3_aZd0kkfU0080kkfU00/0ikfU
0>nmY@3W]I`0kkfU0>NeW03__JD0ikfU0>nmY@3W]I`0ikfU0>nmY@040>NeW00:0>N]U03N]I`0ijfL
0>N]U03N[I@0gZF<0=jLS03N[I@0ijfD0=j]U080gZF<0P3N[I@01P3FYH`0gZF<0=JLS03FW8`0gZF<
0=JUS080eYb400<0eZF40=JLQ03FYH`00P3FYH`20=JLQ00:0=JUQ036W8@0eYb40=JLQ036W8@0cYAk
0<JLQ036U7/0]Hac0;F4J`80[HA[00D0W7=S0:EcFP2<FTX0HdY206=2<@02058a:@0404Xa<@12:B40
>BTQ03TY8@80<B4Q00<0>BTa03TY8@0a8B400P0a8B401`0a8AP0:APH034Q8@0Y61P08A0@034Q8@0i
:B400P0Y61P01P0a8AP0<B4Q034Q600a8B40<B4H03TY8@80DSTa00<0Le9:0:fDU03gmoL09`3gmoL@
0?ooo`003P3ooolB0?Ogm`030?O_k`3gmoL0moOg00L0moOg00X0knOW0=K6cP1cBST0Je9:06=:@P1B
>C40Hd8a05Y2>@1[DTX0Nf=J0P1[DTX03P1cBST0He9:07=:>@1cFU80DSTa06=:@P1J@ST0DS4Y048Y
8@1B<BT0@RTQ058a:@1J<BT0DSTa0P1B<BT4058i<@0305Y2>@1cBST0Nf=B0080Q6=B00/0U5YB0:Ec
FP2]Q6/0_HA[0<J<L`3FW7<0eZF<0=jeW03W]I`0kkfU0?O6[@020?OF_@<0mmK600D0mmJm0?OFaP3g
e/H0mmk>0?OWgP020?ONcP050?OWgP3gg/h0mnON0?OWgP3gg/h00P3gimh20?ONcP80mnON00<0mmk>
0?OWgP3gg/h01`3gg/h03`3ge/H0mmk>0?OF_@3ge/H0mmJm0>o>]@3gaZd0klje0>o6[@3g_KD0klJ]
0>nmY@3_aZd0kkfU0>o6[@030>nmY@<0ikFL00<0kkFU0>NeW03__JD00P3__JD20>NeW0030>neY@3W
]I`0ikfU0080ijfL00H0ijfD0=jeW03N[I@0ijfD0=j]U03W[I@20=j]U00?0=jLS03NYH`0gZF<0=jU
S03FYH`0eYb40=JUS03NYH`0eYb40=JUQ03FYH`0eYb40=JUS03FW8@0eZF400<0eYb400D0eZF40=JL
S03FW8@0aYb40=JLQ0020<JLQ00;0<jDN`36S7<0]Hac0;f4J`2eS7<0[HA[08acH`2LJe80Nf=B06]B
BP1S@S400P1B>C40101B<BT0>BTQ048Y8@0i:B4203TY<@05048Y8@0i:B40<B4Q03TY8@0i:C400P0a
8B4202TH60<0>BTQ00D0:APH034Q8@0Y61P0<B4Q034Q600203TY8@05058a:@12:B40FT8i07=BBP36
[JD0:03gmoL@0?ooo`003P3ooolH0?Ogm`0;0?O_k`3gmoL0moOg0?Ogm`3_inL0c[Fe06=:@P1kHeX0
HdY2058i<@1S@S400P1SBT8606]BBP0507=BBP1SBT80HdY206=:@P1B>C400`12:B400`1B<BT0DSTa
058i<@02058a:@80DSTa00D0Hd8a05Y2>@1J@ST0HdY207=:>@0208ASDP0?09a[DP24JeX0]G]S0;F4
J`36S7<0cYAk0=JUS03W]I`0ikfU0>nmY@3_c[D0mlje0?OF_@3ge/H0mmJm00D0mmK60P3gg/h00`3g
imh0mmk>0?ONcP020?OWgP040?ONcP3gimh0mmk>0?ONcP80mnON00<0mmk>0?OWgP3gg/h00P3gimh4
0?ONcP80mmK600`0mmk>0?OFaP3ge/H0mmK60>o>]@3_aZd0mkfe0>o6[@3gc[D0klje0>nmY@3_aZd5
0>nmY@040>NeU03__JD0ikFL0>nmY@80ikfU0`3W]I`00`3W]I@0ikFL0>NeW0020>NeW0050=jeY@3W
[I@0gZfD0=jeW03W[I`00P3N]I`30=j]U080gZF<0P3FW8`0303NYH`0eYb<0=JLQ03FYH`0eYb40=JU
S03FW8`0eZF<0=JUQ03FW8`0eYb40=JUS080eYb400L0aYb40=JLQ03FW8@0aYb40=JLS036W8@0cYAk
0080aYAk00<0]HA[0:f4J`2ULeX00P2ULeX01@24He80LdXi06=2<@1S@S40DSTa00<0DS4Y1P0i:B42
058a:@80>BTQ00@0@RTQ048Y<@0i:B40>BTQ0P0a8B401@0a8AP0:APH034Q8@0a8B40>BTQ0080@RTQ
00H0>BTQ048Y8@1B>C40S6=B0=K6cP3ooolW0?Ogma00oooo000>0?oooa@0moOg00D0mno_0?Ogm`3g
moL0moOg0?O_k`030?Ogm`0;0?O_k`3Nc]H0Q6]J07=BBP1SBT80Hd8a058a:@1S@S40HdY207=JDP1c
DTX00P1[DTX00`1cDTX0Je9:06=:@P0206=:@P0307=:>@1B>C40DS4Y0080@RTQ00@0DS4Y058i<@1S
>C40DSTa0P1B<BT2058i<@0406]BBP1cBT80Je9:07=:@P80Q6=B00`0S7=S09AJDP2ULeX0[HA[0;Ek
H`36S7<0cYAk0=j]U03W]I`0ikfU0>nm[@3gc[D30?OF_@80mmK600<0mmJm0?OFaP3ge/H01@3gg/h0
1@3gimh0mmk>0?ONcP3gimh0mmk>00<0mnON2P3gg/h30?OFaP060>o>]@3gc[D0mlje0?O>]@3_aZd0
klje0`3_aZd30>nmY@060>NeW03W]I@0ijfD0>NeW03W]I@0ijfD0P3W]I@20>NeW0030>NeU03W]I`0
kkFU0080ikFL00<0ijfL0>NeW03W[I`00P3N[I@01@3N]I`0ijfD0=j]U03N[I@0ijfD0080gZfD0`3N
YH`01@3FW8`0gYb<0=JUS03FW8`0eZF<0080eYb<00T0eYb40=JUQ03FYH@0aYb40=JLQ03FYH@0aYb4
0=JLQ03FYH@00P3FW8@03@36W8@0cYAk0<JDN`36S7<0cXa[0;EkH`2]LeX0W7=S0:EcFP2DHdX0Nf=B
08AB@P1[DTX00P1S@S401P1:<C40DS4Y058a:@1B<BT0@RTa048Y8@80>BTQ0P1B<BT01012:C40>BTQ
058a:@12:C4303TY8@<0<B4Q00/0>BTQ058a:@0i:B40>BTQ034Q600Q4100:APH03TY8@1B<BT0Q6]J
0=k>eP0Y0?Ogma00oooo000>0?oooa80moOg00<0mno_0?Ogm`3gmoL01`3gmoL0203_inL0g/kF07=B
BP1cBT80Je9:05Y2>@1J<BT0DSTa0P1SBT80201cDTX0LeYB06]BBP1cDTX0LeYB06=:@P1[DTX0DSTa
0P1SBT800`1J<BT0@RTQ048Y8@02058a:@0305Y2>@1B>C40HcTa0080DS4Y00D0DSTa05Y2>@1cBT80
Le9:07]SDP0208ASDP0:0:EcFP24JeX0YG=J0:EcFP2eNf<0_HA[0<jDL`3FYH@0gZfD0>NeW080klJ]
00<0klje0?OF_@3ge[d00`3ge[d30?OFaP<0mmk>0P3gimh01P3gg/h0mnON0?OWgP3gimh0mmk>0?OW
gPP0mmk>0`3ge/H02P3ge[d0mmK60?OF_@3ge/H0mmJm0>o>]@3gaZd0klJ]0?O6[@3_aZd20?O6[@80
kkfU0P3W]I`00`3W]I@0ikFL0>NeU0050>NeW0030>nmY@3W[I`0kkfU00<0ikFL00X0ijfL0>NeW03N
]I`0ijfL0=j]U03W[I`0gZfD0>N]U03N[I@0g[FL0`3N[I@01@3FW8`0eYb40=jUS03FYH`0gYb<00D0
eZF<00D0aYb40=JUS03FW8@0eZF40=JLS0020=JLQ0040<JLQ03FW8@0aYb40<jDN`80aYAk0P2eS7<0
1P2eQ6/0[HA[09acH`2DHdX0Q59207]SDP80LdXi00<0Hd8a05Xa:@1B>C400P1B<BT00`12:C40DS4Y
04Xa<@02048Y<@0304Xa<@1B>C40DS4Y0080<B4Q0P0Y61P0100a8B40>BTQ03TY8@0i:B42034Q8@0:
024@400Y61P0<B4H02TH600Q4100>BTQ058a:@12:B40YHB40>oWibT0moOg403oool000h0oooo303g
moL0103gknl0moOg0?Ogm`3gknl60?Ogm`030?O_k`3gmoL0mno_00<0moOg00`0knOW0=K6cP1cDTX0
HdY206=2<@1SBT80FT8i058i<@1SBT80LdXi07=BBP1kHeX206]BBP0407=JDP1[DTX0Je9:05Y2>@80
HdY200L0FT8i048Y8@12:B40@RTQ058a:@1S@S40FT8i00@0DSTa00<0FT8i07=:>@1cDTX00`1cBT80
3@2<He80Q6]J09ASBP2ULeX0[HA[0;EkH`36S7<0eZF40=jUS03N]I`0klJ]0>o>]@3gc[D00`3ge[d5
0?OFaPD0mmk>00@0mnON0?ONcP3gg/h0mmk>0P3gimh80?ONcPD0mmK600L0mmJm0>o>]@3_c[D0mkfe
0?O>]@3_aZd0kkfU0080klJ]0`3__JD20>NeU0@0ikFL00<0kkfU0>NeU03W]I`00P3W]I`00`3W[I`0
ikFL0>NeW0030>NeW0080>N]W03N[I@0ijfL0>N]W03N]I`0ijfD0>N]W03N[I@20>N]U0040=j]U03N
W8`0gZF<0=jLS080gZF<0`3FYH`05`3FW8`0eZF40=JLS03FYH`0eYb<0=JUS03FW8@0eZF40<JLQ03F
W8@0cYAk0=JUQ03>U7/0aYb40<JDN`36S7<0_HA[0;EkH`2]LeX0W7=S08aSDP24DT80Nf=B0080LdXi
0P1S@S400`1B>C40DS4Y058a:@03048Y8@0303TY8@1B<BT0DS4Y0080@RTQ00@0@RTa034Q8@0Y61P0
:APH0P0i:B4202TH600<024@400Y61P0:APH02TH600Q4100<B4Q024@400i:B40DS4Y048Y8@1B>C40
_JFL:P3gmoL@0?ooo`003P3ooolC0?Ogm`030?O_k`3gmoL0moOg00@0moOg00/0mno_0?Ogm`3gmoL0
g/kF07]SDP1cDTX0FT8i06=:@P1J@ST0Hd8a07=:>@0206]BBP0307]SFP1SBT80LdXi0080LeYB00<0
Je9:06=:@P1S@S400P1SBT83048Y8@03058i<@1B<BT0DSTa0080FT8i00H0HcTa058i<@1B>C40Hd8a
06]BBP1kHe8207=:>@0:08acH`2<He80Q59209a[DP2ULeX0]G]S0;f4J`3>U7<0gZF<0=j]U080klJ]
00@0klje0?OF_@3_c[D0mmJm1P3ge/H30?ONcP050?OWgP3gg/h0mnON0?ONcP3gimh0203gg/h40?OF
aP030?OF_@3ge/H0klje0080mmJm00L0mlje0>o6[@3_c[D0klJ]0?O6[@3_c[D0mlJ]00<0kkfU00L0
ikFL0>nmY@3W]I`0ikFD0>nmY@3W]I`0kkFU00<0ikFL00<0kkfU0>NeU03W]I`01@3W]I`0103W[I@0
ikFL0=j]U03W[I@20=j]U0060>N]U03N[I@0gZfD0=j]U03NYH`0gZfD0P3NYH`20=JUS0080=JLS03F
YH`0eZF<0=JLS03FYH`0eYb40=JUQ036W8@50=JLQ00?0<JLQ03>U7/0aYb40<JDN`2eS7<0_HA[0:f4
J`2LLf<0YG=J08aJ@P1kHe80Q59207=:@P1cBST0FT8i00<0DS4Y00@0BS4a048Y8@0i:B40@RTQ0`0i
:B42034Q6003048Y8@1B<BT0<B4Q0080<B4Q1@0Y61P01@0H4100:APH024@400a8AP0:APH00<0@RTQ
00<0Hd8a0;FUY@3gmoL0:@3gmoL@0?ooo`003P3ooolE0?Ogm`030?O_k`3gmoL0moOg00D0moOg00L0
imkW08A[FP1kHe80LdXi06=:@P1S@S40DSTa00<0HdY200D0Le9:06]BBP1SBT80Le9:07=JDP0206]B
BP80FT8i00l0HdY2058i<@0i:B40@RTQ058a:@1J@ST0DSTa06=2<@1J@ST0HdY205Y2>@1S@S40DSTa
06=2<@1kHe800P1cBT8208aSDP80Q59200H0W6]B0;EkH`2mQ6/0cYAc0=JUQ03N[I@20>o6[@060>o>
]@3gc[D0mmJm0?OF_@3gc[D0mmJm2@3ge/H;0?ONcPD0mmK600D0mmJm0?OFaP3ge/H0mmJm0>o>]@02
0?O6[@040>o6[@3_c[D0mlJ]0>o>]@80kkfU00<0ikFL0>nmY@3W]I`0103W]I`30>NeU0<0ikFL00<0
ikFD0>NeW03W]I`00P3W[I@01`3W[I`0gZfD0>N]W03W[I@0gZfD0>N]U03NYH`00`3N[I@30=jUS004
0=JLQ03NW8@0eYb<0=jUS080eZF<00`0eYb40=JUS03FYH`0eYb40=JLS03FW7<0aYb40=JUQ036W8@0
eZF40<JLQ03FYH@30<JDN`080;F<L`2]Q6/0[HA[0:EcFP2<FT80Q6=B08AB@P1cBST206=2<@<0DSTa
0`1B<BT00`12:B40>BTQ034Q8@03034Q600>034Q8@0i:B40>BTQ058a:@0i:B40:APH01P@400Q4100
<B4H02TH600Q4100:APH024@400Y61P2034Q600603TY8@12:B40DSTa07=:>@3>]Jd0oooo:@3gmoL@
0?ooo`003P3ooolB0?Ogm`030?O_k`3gmoL0moOg00<0moOg00<0mno_0?Ogm`3gmoL00P3gmoL0103N
c]H0S7=[07=BBP1SBT8205Y2>@06058i<@1cBST0LdXi06=:@P1[DTX0Nf=B0P1[DTX03P1cDTX0Je9:
06=:@P1SBT80FT8i06=:@P1S@S40DS4Y048Y8@0i:B40DSTa06=2<@1B>C40FT8i0P1SBT80101B<BT0
DSTa06=2<@1cBST307=BBP80Nf=B00L0Q58i09a[DP2]LeX0]G]S0<jDL`3FW8@0gZF<00<0klJ]00<0
klje0?OF_@3ge[d00P3ge[d60?OFaP80mmk>00<0mmK60?ONcP3gg/h00P3gg/h40?OFaP<0mmk>00@0
mmJm0?OFaP3ge/H0mmJm0`3ge/H01P3ge[d0klje0?O>]@3_c[D0klJ]0?O>]@80klJ]00P0mlJ]0>nm
Y@3W]I`0ikFL0>nmY@3W]I`0ikFD0>N]W0<0ikFD00T0ijfL0>NeW03W]I`0ikFD0>N]U03W]I`0ijfD
0>NeU03W[I`00`3W]I`02P3W[I@0gZfD0>N]U03N[I@0ijfD0=j]U03W[I`0gZF<0=JLS03NW8`20=jL
Q0090=JLQ03NYH`0eZF<0=JLQ03FW8`0eYb40=JUQ03FW8@0eZF400H0eYb400/0aYb40<jDN`36U7/0
aXac0;f4J`2eQ6/0YG=J09a[DP2<He80S5Y:07]SDP0207=:>@0406=:@P1S@S40Hd8a058a:@H0@RTQ
1@0i:B40100a8B40>BTQ034Q8@0i:B4202TH6004034Q8@0H4100610@02TH60808A0@0P0Y61P01P0a
8AP0@RTQ058a:@1S@S40LdY20=k>eRX0moOg403oool000h0oooo503gmoL00`3gknl0moOg0?Ogm`03
0?Ogm`0<0?O_k`3gmoL0moOg0>ONi`2LS8`0Nf=B06=:@P1S@S40FT8i058i<@1J@ST0Je9:0P1SBT80
101kHe80Je9:06]BBP1[DTX206=:@P0506]BBP1J@ST0FT8i05Y2>@1B>C400`12:B402@1B<BT0Hd8a
058a:@1S@S40HdY205Y2>@1J<BT0FT8i06=:@P0208AB@P0:07=BBP1cBT80Q59208AB@P2LJe80[HA[
0:ecFP36S7<0eZF40=j]U080klJ]00<0klje0>o6[@3gaZd0103ge[d20?OFaP060?OF_@3ge/H0mmK6
0?ONcP3ge/H0mmk>0P3ge/H00`3gg/h0mmK60?OFaP040?OFaP80mmJm1@3ge/H02P3ge[d0klje0?OF
_@3ge[d0mkfe0>o6[@3g_KD0klJ]0?O6[@3_aZd30>nmY@080>NeU03W]I`0ikFL0>NeU03W]I`0ijfD
0>N]W03W]I@30>NeW0050>N]W03W]I`0ikFL0>NeU03W[I`00P3W]I`01P3W[I@0ijfL0=j]U03W[I@0
gZfD0>N]U080gZfD00T0gZF<0=jLS03NYH`0gZF<0=JLS03NYH`0eYb<0=jLQ03NW8`0103FYH`01@3F
W8`0aYb40=JLQ036W8@0eYb400<0aYb400H0cYAk0<JDN`36S7<0_HA[0:f4J`2]LeX30:EcFP0407]S
DP1c@S40LdXi07=:>@80Hd8a0P1B<BT3048Y8@80<B4H0P0i:B4202TH60H0<B4Q00<0<B4H034Q8@0Y
61P00P0Y61P02`0Q4100610@024@400Y61P0<B4Q03TY8@12:B40DSTa06=:@P1cDTX0oooo02X0moOg
403oool000h0oooo5@3gmoL00`3gknl0moOg0?Ogm`060?Ogm`0309AkL`1kHe80Le9:00<0FT8i00L0
Hd8a06]BBP1J@ST0HdY206]BBP1kHe80HdY20080Je9:00`0HdY205Y2>@1SBT80FT8i06=2<@1[DTX0
DSTa058a:@12:B40>BTQ058a:@1S@S42058i<@0406]BBP1SBT80FT8i06=2<@80LdXi00`0Nf=B07=:
@P1cBT80LdXi08AB@P2DHdX0[HA[0;f4J`36S7<0gZF<0>NeW03_aZd30>o>]@050?Nm]@3ge[d0mmJm
0?OF_@3ge/H00P3ge[d00`3ge/H0mmJm0?OFaP020?OFaP80mmJm0P3ge/H30?OF_@070?OFaP3ge[d0
mmJm0?OFaP3_c[D0mmJm0?OFaP040?OF_@80mkfe00D0mlje0>o6[@3gaZd0klJ]0?O6[@030>nmY@04
0>NeW03W[I@0ikFL0>NeU0<0ijfD0P3W]I@03`3W[I`0ikFL0>NeW03W[I@0ikFL0>N]W03W]I`0gZfD
0>NeW03W[I@0ikFD0=jUS03WYH`0gZF<0>N]U0050=j]U0030=jUS03N[I@0gZF<0080gZF<00<0eZF<
0=JUQ03FW8@0103FYH`20=JLQ0030<JLQ03FYH@0cYAk0080cYAk00<0aYAk0;F<L`2eNf<00P2]Q6/0
1P2ULeX0W6]B08aJBP24DT80LdY207=:>@<0Hd8a00<0DSTa058a:@12:B400P12:B4303TY8@04034Q
8@0i:B40>BTQ03TY8@80@RTQ0P0i:B403P0a8B408A0@034Q8@0a8B40:APH034Q600Q4100610@02TH
600Q4100<B4H034Q8@1B<BT0HcTa0P1cBST00`2eYJD0moOg0?Ogm`0Y0?Ogma00oooo000>0?oooa80
moOg00<0mno_0?Ogm`3gmoL00`3gmoL0103gknl0moOg0?Ogm`3gknl20?Ogm`030:F4N`24JeX0LeYB
0080LdXi00<0HdY2058i<@1cFU800P1J@ST01`1cBST0Nf=J06=:@P1SBT80Nf=J06=:@P1B>C400P1S
BT801@1J@ST0HdY205Y2>@0i:B40DS4Y0080@RTQ00L0DS4Y06=2<@1S@S40LdY206]BBP1J@ST0Hd8a
0080FT8i0P1cDTX0301cBT80LdXi08AB>@2<FTX0W6]B0;EkH`2mQ6/0aYb40=j]U03__JD0klJ]0>o>
]@80mmJm00<0klje0?OF_@3ge[d0103ge[d20?OFaP@0mmJm00@0mmK60?OF_@3ge[d0klje0`3ge[d2
0?OFaPD0mmJm00@0klje0?OF_@3_c[D0mlJ]0P3_aZd00`3gaZd0klJ]0>nmY@020>nmY@070>NeU03W
[I@0ikFL0>N]U03W]I@0ijfD0>NeU0030>N]U0070>NeW03W]I@0ijfD0>NUS03W[I@0ikFD0=j]U004
0>N]U080gZF<00<0g[FL0=j]U03NYH`00P3NYH`01@3N[I@0gZF<0=jUS03N[I@0gZF<0080eZF<00<0
gZF<0=JLS03FYH`00`3FYH`01@3FW8`0aYb40<JLQ036W8@0cYAk00<0aYAk0P36S7<20:f4J`0309ac
H`2LJe80S5Y:0080Q6=B00@0LdXi06=2<@1J<BT0Hd8a0P1B<BT01012:B40>BTQ034Q600a8AP203TY
8@03034Q600a8B40<B4H00D0>BTQ00L0@RTQ03TY8@0i:B40<B4Q03TY8@0Y61P0610@00<0:APH00P0
<B4H03TY8@12:B40HcTa05Y2>@1S@S40U7=[0>ONib/0moOg403oool000h0oooo5@3gmoL00`3gknl0
moOg0?Ogm`060?Ogm`0409AkL`2<Lf<0Nf=J06]BBP80FT8i00<0Hd8a06]BBP1SBT800P1J@ST207=B
BP0406=:@P1kHeX0HdY2058i<@<0HdY200<0FT8i06]BBP128AP00P1B<BT2048Y8@06058i<@1J@ST0
HdY206]BBP1SBT80DSTa0P1S@S40501SBT80LdY207=:>@1[DTX0LdXi08aJBP2LJe80[HA[0;EkH`36
W7<0eZF<0=j]U03W]I`0kkfU0>o6[@3gc[D0mmJm0?O>]@3ge[d0klje0P3ge[d0103_c[D0mmJm0?OF
aP3ge/H30?OF_@@0mmK600d0mmJm0?OFaP3ge[d0mmJm0>o>]@3gc[D0mmJm0>o>]@3ge[d0klje0?OF
_@3g_KD0mmJm0080klJ]00L0mlJ]0>o6[@3_aZd0kkfU0>NeU03__JD0ikFD0080ijfD0P3W]I`20>Ne
U0030=jUS03W]I@0ikFD00<0ikFD0P3N[I@00`3W]I@0ijfD0>N]U0020=j]U0040>NUS03W[I@0gZfD
0>NUS0<0gZF<00D0gYb40=jUS03NW8`0gYb40=jUS0020=JUS0090=jUS03FYH`0eZF<0=jUS03FW8`0
eYb40=JUQ03FW8`0eZF40080cYAk1036S7<01`2eS7<0_HA[0:EcFP2ULeX0W6]B08aJBP24He800P24
DT800`1SBT80Hd8a05Xa:@03058a:@03048Y8@0i:B40<B4H00<0<B4H00<0>BTQ034Q600i:B40200i
:B42034Q8@0<03TY8@0Y61P0:APH034Q8@0Q4100:APH03TY8@1B>C40FT8i06=2<@1cBST0]IbL;03g
moL@0?ooo`003P3oool=0?Ogm`030?O_k`3gmoL0moOg00h0moOg00L0U7]c08A[FP24JeX0Le9:05Y2
>@1SBT80FT8i0080Je9:0P1J@ST00`1[DTX0Le9:06=:@P0207=JDP0305Y2>@1B>C40FT8i00<0FT8i
00<0DS4Y03TY8@1B<BT00`1B<BT01@1J<BT0Hd8a07=:>@1SBT80FT8i0080DSTa00d0FS4Y06]BBP1[
DTX0LdY206=2<@24DT80S6=B0:EcFP2eQ6/0aXac0=JUQ03W[I@0ikFL0080kkfU0P3_c[D01@3gaZd0
mlje0?O>]@3ge[d0mlje00T0mmJm00X0mmK60?OF_@3ge/H0mmK60?OF_@3ge/H0mmJm0?Nm]@3_c[D0
mkfe0P3ge[d0103_aZd0mlJ]0>o>]@3gaZd50>nmY@040>NeW03W]I@0ikFL0>N]U080ikFD00D0ijfD
0=jUS03WYH`0gZfD0>NUS0020=jUS080ijF<0P3W]I@00`3N[I@0ijfD0=j]U0020>N]U0<0gZF<00<0
gZfD0=jUS03NYH`00P3NYH`02`3N[I@0eZF40=jLQ03FYH`0gZF<0=JUS03FW8@0gZF<0=JUS036W8@0
eYb40080aYb400@0eYb40<JLQ03>U7/0aYAk0P36S7<01P2eS7<0aXac0;F4J`2LLf<0YG=J08acH`80
S6=B00<0Q58i07=:>@1cBST00`1S@S401P1B<BT0@RTQ048Y8@12:B40<B4H02TH6080<B4H00@0<B4Q
034Q600i:B40<B4Q0P0i:B42034Q8@L0>BTQ00/0:APH024@400Q41008A0@034Q6012:B40HcTa06=2
<@1B>C40Q6=B0=JmaP0/0?Ogma00oooo000>0?oooa80moOg00<0mno_0?Ogm`3gmoL02@3gmoL01P2e
W9`0Q6]J08acJ`24JeX0HdY205Y2>@80HdY200<0Je9:06=:@P1SBT800P1[DTX0301SBT80Le9:07=J
DP1SBT80DS4Y06=2<@1[DTX0FT8i058i<@1J@ST0DS4Y048Y8@80DSTa00H0FT8i058i<@1J@ST0HdY2
07=JDP1SBT8305Y2>@0606=2<@1cDTX0Je9:06]BBP1cBST0Q6=B0P2ULeX0202eNf<0cYAk0=JUS03F
YH@0ikFD0>NeW03_aZd0klje0P3_aZd20>o>]@030?O>]@3_c[D0mlje00D0mmJm00<0klje0?OF_@3g
e[d0103ge[d02`3_c[D0mmJm0>o>]@3ge[d0klje0?O>]@3gaZd0klje0?OF_@3gc[D0klJ]00D0kkfU
0P3W[I@0203W]I`0ijF<0>NeU03NYH`0ijfD0>NUS03NYH`0gZfD0P3W[I@01@3N[I@0ijF<0=jUS03N
YH`0gZfD0080ijF<00@0gZfD0>N]U03N[I@0ijF<0`3NYH`00`3NW8@0gZF<0=jUS0030=jUS0040=jL
S03FYH`0gZF<0=jUS080eZF<00H0eYb40=JUS03FYH@0eYb<0=JUQ036W8@20<jDN`070<JLQ036U7/0
aYAk0;F<L`2eQ6/0]G]S0:f4J`020:EcFP0309a[DP24DT80Q5920080LdXi00@0Hd8a05Xa:@1B<BT0
DS4Y0`12:B44034Q600403TY8@0a8B40<B4H034Q8@80>BTQ00<0@RTQ03TY8@0i:B400`0a8B4202TH
60808A0@0P0H4100200Y61P0>BTQ058i<@1S@S40DS4Y07=:>@24JeX0g/kF;03gmoL@0?ooo`003P3o
oolN0?Ogm`050<J]_@2<Lf<0S7=S07]SFP1cFU800P1SBT800`1S@S40Le9:06]BBP0206=:@P0506]B
BP1cDTX0Je9:07=JDP1[DTX00P1J@ST206=:@P09058a:@1SBT80DSTa03TY8@12:B40DS4Y0592>@1J
@ST0LdXi0080HdY200<0LdY206=:@P1SBT800P1B>C40301cBT80LdXi07=BBP24DT80LdXi08aJBP2U
LeX0[HA[0<jDL`3FYH`0eZF40=jUS080ikFL0P3_aZd01@3_c[D0mmJm0>o>]@3_c[D0mlje0080mmJm
00d0mmK60>o>]@3gc[D0klje0?OFaP3ge[d0klje0?Nm]@3gc[D0klje0?O>]@3ge[d0mlje0080mmJm
00H0mkfe0>o>]@3gc[D0klje0>o6[@3gaZd50>nmY@080>NeW03W[I@0ikFL0>NeW03NYH`0ijF<0=jU
S03W[I@20=jUS0060>NeU03WYH`0gZF<0>N]U03NYH`0ikFD0P3WYH`00`3NYH`0gZfD0>N]U0020=j]
U0D0gZF<00<0eYb40=jLS03NYH`00P3NYH`00`3FW8@0gZF<0=JUS0020=JUQ0070=JUS036W8@0eYb<
0<jDN`3FYH@0aYb40<jDN`030<JDN`070<J<L`2mQ6/0_HA[0;EkH`2LLf<0[HA[09a[DP0208aJBP05
07]SDP1cBST0LdXi06=2<@1J<BT0101B<BT01012:B40>BTQ034Q600a8AP202TH6080<B4H00@0<B4Q
034Q600a8B40<B4Q0P0i:B401@0Y61P0<B4Q02TH600Y61P08A0@00D0610@00T08A0@048Y8@1S@S40
DS4Y058i<@1cBT80YHAk0?OWi`3oool0:`3gmoL@0?ooo`003P3ooolN0?Ogm`090=JmaP24JeX0U7=[
09AkL`1cDTX0LdXi06=2<@1J@ST0Je9:0080HdY200X0FT8i06=:@P1SBT80Le9:07=JDP1kHeX0He9:
058i<@1SBT80Je9:0P1B>C400`1J@ST0DSTa03TY8@02058a:@04058i<@1B@ST0FT8i07=:>@<0Je9:
00h0HdY2058i<@1[DTX0Je9:06=:@P1cDTX0Nf=B08AB@P2<FTX0YG=J0;F<L`3FYH@0gZF<0=j]U080
ikFL00<0ikfU0>o6[@3_aZd0103_aZd20?OF_@030>o>]@3ge[d0klje0080mmJm00h0klje0?OFaP3g
e[d0klje0?Nm]@3ge[d0klje0?O6[@3_aZd0mlje0>o>]@3gaZd0klJ]0?O6[@80klJ]0`3__Jd0103_
_JD0ikFL0>N]U03W]I`20>N]U080ijF<00<0ikFD0>N]U03NYH`00P3WYH`03`3NW8@0ikFD0=jUS03W
]I@0ijF<0=jUS03NW8@0gZF<0>NeU03W[I@0gZF<0>N]U03NYH`0gYb40=jUS0020=JUQ00;0=jLQ03F
W7<0gYb<0=JLQ03FYH@0eYb<0=JUQ03FYH`0eYb40=JUS03FW8`00`3FW8@00`3>U7/0aYb40<jDN`03
0<JDN`80]Hac00L0]HA[0:f4J`2ULeX0W6]B08aSDP2<FTX0Nf=B00<0LdXi00<0Hd8a05Xa:@1B<BT0
0P1B<BT2048Y8@80<B4H1P0Y61P3034Q8@05034Q600a8B408A0@02TH600Q41001`0H41001`0a8AP0
DS4Y058i<@1B<BT0FT8i07=:>@2eW9`0;@3gmoL@0?ooo`003P3oool@0?Ogm`030?O_k`3gmoL0moOg
00@0moOg00<0mno_0?Ogm`3gmoL0103gmoL02@3Wg^l0YHB407]SDP1kHe80LeYB07=:@P1SBT80FT8i
06=:@P0206]BBP0506=:@P1J@ST0Je9:05Y2>@1cDTX00P1[DTX205Y2>@0506=:@P1J@ST0@RTQ048Y
8@1B<BT00P1B>C401P12:B40DSTa058i<@1SBT80FT8i07=:>@80HdY200D0Nf=B07]SFP1B>C40DSTa
06=:@P0206]BBP0C07=:>@1kHe80S6=B09acH`2eNf<0aXac0=JUQ03FYH`0gZfD0=jeW03NYH`0ikFL
0>NmY@3__JD0klJ]0>o>]@3_aZd0klje0?OF_@060>o>]@040?OF_@3_c[D0klje0>o>]@80mlje0P3_
c[D03@3_aZd0mlje0>o6[@3gc[D0klJ]0>nmY@3_aZd0kkf]0>NmY@3W]I@0gZfD0>N]U03NYH`00`3N
W8@0103WYH`0gZF<0>NUS03NW8@20=jUS0030=jLQ03NYH`0gZF<0080gZF<00H0gYb40=jUS03NW8@0
ijF<0=jUS03NW8@20=jUS0030=JLQ03NYH`0gZF<0080gYb400T0eYb40=JLL`3FW8@0eYb40=JLL`3F
W8@0eYac0=JLQ03FW7<00P36W8@0103>U7/0aYb40<JDN`36U7/20<J<L`030;f4J`2eNf<0]G]S0080
YG=J0`2LJe8208AB@P0307=:>@1S@S40Hd8a0080Hd8a00X0DS4Y048Y8@12:B40@RTQ03TY8@0a8AP0
<B4Q034Q600Y61P08A0@0P0Y61P7034Q8@0302TH600Q4100610@00D0610@00<08A0@02TH600a8AP0
0P1B<BT01@1S@S40FS4Y08ASDP3Nc]H0oooo02`0moOg403oool000h0oooo7`3gmoL00`2eYJd0S7=S
08ASDP0207=BBP0306]BBP1J@ST0HdY20080Je9:00d0HdY205Y2>@1SBT80HdY206]BBP1cFU80He9:
06=:@P1S@S40HdY205Y2>@1:<C40>BTQ0080BS4a00<0DSTa058a:@1:<C400P1J@ST00`1SBT80FT8i
06]BBP0206]BBP0A07=BBP1J@ST0DSTa06=2<@1cBST0LdY207=BBP1cBST0Nf=B09a[DP2ULeX0[HA[
0<j<J`36U7/0eZF40=JUS03W]I@00`3W]I`00`3N]I`0ikfU0>o6[@020>o6[@80klje00<0klJ]0?O>
]@3_c[D01`3_c[D30>o6[@0:0>o>]@3__Jd0kkfU0>o6[@3__JD0klJ]0>nmY@3W_JD0ijfD0=jLQ0<0
gZF<00@0gYb40=jUS03NYH`0gZfD0`3NYH`0103FYH@0gYb40=JUQ03NW8@50=jUS0050=jLQ03NYH`0
gZF<0=jUS03NW8@00P3NYH`00`3FW8@0eYac0=JUQ0020=JLQ080eYac00<0eYb40<jDN`3FW8@00`3>
U7/01036U7/0cYAk0<JDN`3>U7/20<J<L`040;F<L`2]Q6/0]G]S09acH`<0YG=J0P2LJe800`24DST0
LdXi07=:>@0206=2<@80FS4Y0P12:B402P1B<BT0@RTQ03TY8@0i:B40<B4H02TH600a8AP0:APH034Q
600a8B4602TH6005034Q8@0Q41008A0@01P@400Q4100100H4100200Y61P0<B4Q058a:@1B<BT0DSTa
05Y2>@1S>BT0YHAk;P3gmoL@0?ooo`003P3ooolA0?Ogm`030?O_k`3gmoL0moOg00/0moOg00<0c[Fm
09AcJ`24He800P1cDTX00`1[DTX0HdY206=:@P0306]BBP0505Y2>@1SBT80HdY206]BBP1cFU800P1[
DTX02`1B>C40FT8i06=:@P1B>C40DS4Y048Y8@1B<BT0@RTQ058a:@1B@ST0DSTa0080FT8i00X0HdY2
06]BBP1[DTX0Je9:06=:@P1kHe80FT8i058a:@1J@ST0HdY20P1cDTX02@1[DTX0Q6=B09a[DP2ULeX0
W7=S0;EkH`2mQ6/0eZF40=j]U0020=JUS0050=jUS03N[I@0g[FL0=jeY@3W_JD0103_aZd00`3Fa[D0
klje0>o6[@020>o6[@030?O6[@3_c[D0klje00D0klJ]0P3__JD02`3_aZd0kkfU0>NmY@3_]JD0ikFL
0=j]U03FW8`0eYb40=j]U03NYH`0gYb40080gZF<00<0gYb40=jUS03NW8@00`3FYH@50=jLQ0030=j]
U03NYH`0gZF<0080gYb400L0gZF<0=JUQ03NYH`0eYac0=jLQ03FW8@0gYb400<0eYb400<0eXak0<jD
N`3FW7<00`3>U7/01@3>U7<0cYAk0<JDN`36U7/0aXac0080]Hac00<0_HA[0;EkH`2]Q6/00`2ULeX2
09a[DP0608ASDP1kHe80LdXi07=:>@1S@S40DSTa0P1J<BT3048Y8@03034Q8@0i:B40>BTQ00@0<B4H
0`0Y61P01`0Q4100:APH02TH600Y61P0610@034Q8@0Q41001P0H41001@0Q4100<B4H03TY8@1B<BT0
@RTQ0080DSTa00<0FT8i0=JmaP3oool0;@3gmoL@0?ooo`003P3oool20?Ogm`030?O_k`3gmoL0moOg
01T0moOg01L0oooo0=k>eP2DQ8@0Q6]J07]SDP1cDTX0Je9:06=:@P1cBST0Je9:07=BBP1[DTX0HdY2
06=2<@1SBTX0HdY207=JDP1[DTX0HdY205Y2>@1S@S40HdY2058i<@03048Y8@06058a:@0a8B40DS4Y
05Y2>@1:<C40FT8i0`1SBT8206]BBP0307=BBP1kHe80DT8i0080DS4Y00X0HdY207=:@P1cDTX0LdY2
08AB@P2<FTX0U6=:0:EcFP2eNf<0]Hac0P36S7<20<jDN`030<JLQ03FYH`0eZF<0080g[FU0P3N]I`4
0>o6[@0>0>NmY@3__JD0e/Je0>o>]@3W_JD0klJ]0>nmY@3_c[D0klJ]0>nmY@3W]I@0kkfU0>o6[@3_
_JD30>NmY@80gZfD00P0gZF<0<JLQ03FW8@0eYb40=jLQ03FW8@0eZF40=jUS080eYb400H0eYac0=JL
Q03FW7<0eYb40=jLQ03FYH@20=jLQ0060=JLQ03NW8@0gYb<0=jLS03NYH`0gYb40P3FW8@00`3FW7<0
eYb40=JLQ0030=JLL`080<jDN`3FS7/0cYAk0=J<N`3>U7/0aYac0<J<L`3>U7/30<J<L`80_HA[00<0
]HA[09acH`2ULeX00P2ULeX0102LJe80S5Y:08AB@P24DT8207=:>@80Hd8a00T0FS4Y05Xa8@12:B40
@RTQ034Q600i:B40@RTQ034Q600a8B400P0Y61P00`0Q4100:APH02TH600302TH600401P@400Y61P0
:APH02TH60808A0@1P0H4100100Y61P0<B4Q058a:@1B<BT2058i<@0304XQ602DLf/0moOg02h0moOg
403oool000h0oooo7`3gmoL04@3Wg^l0]JFU08acH`24He80Nf=B07=:@P1J@ST0HdY207=:>@1[DTX0
Le9:06]BBP1J@ST0He9:06=:@P1SDTX0LeYB0080He9:00@0DSTa05Y2>@1B>C40DS4Y0P0i:B42058a
:@04048Y8@1[DTX0HdY2058a:@<0FT8i0100HdY206]BBP1SBT80Le9:08A[FP1[DTX0FT8i058i<@1S
@S40LdY207]SDP1cBT80Q59208ASDP2<He80W6]B0P2ULeX20;EkH`040<J<L`36U7/0cYAk0=JUS080
gZfD0P3FYH`20=j]U080g[FU00@0g[FL0>NmY@3W_JD0g[FL0`3W_JD00`3__Jd0ikfU0>NeW0020>Ne
W00I0>nmY@3W_JD0ikfU0>NeW03N]I`0eZF<0=JLQ036S7<0cXa[0<J<L`3>U7<0cYAk0=JLL`3>S8@0
eYac0<jDN`3>S7<0eXak0=JLL`3FW8@0eYac0=JUQ03NW8@0eYb<0=JLQ0030=JLL`030=JUQ03FW8@0
eYb400<0eYb400H0eYac0=JLQ03FS7/0eXac0=J<N`3FW8@20<jDN`0A0<JLQ03>U7/0cYAk0<jDN`36
U7/0aXac0;F<L`36S7<0]Hac0;F4J`2]Q6/0]G]S0:EcFP2ULe80U6=:08AB@P24DST00P24DT801@1c
BST0Hd8a06<i:@1J<BT0DS4Y00@0@RTQ00@0<B4H034Q8@0Y61P0@QP@0P0Y61P0100a8B408A0@02TH
600Y61P2034Q8@<0:APH0`0Q410501P@400:024@400a8B40@RTQ058i<@12:B40DS4Y048Y8@1J<BT0
c[Fe0?ooobh0moOg403oool000h0oooo803gmoL02P3>_LH0U7=[08A[FP1kHeX0Le9:06=:@P1J@ST0
HdY206]BBP1cDTX506=:@P80LeYB00L0HdY205Y2>@1J@ST0Hd8a04Xa<@1B<BT0>BTQ0080DS4Y00@0
>BTQ058i<@1[DTX0Je9:1@1J@ST306]BBP0608A[FP1cDTX0HdY2058i<@1S@S40LdY20P1kHe8408AS
DP0:09a[DP2]Nf/0[G=J0;EkH`2eS7<0aYAk0;F<L`3N[I@0eZF<0<JDN`80eZF<0P3N[I@00`3FYH@0
g[FU0=j]U0020=j]U0070=jeY@3W]I`0g[FL0>NeW03N]I`0ijfD0=j]U0020>NmY@0T0>NeW03N[I@0
gZfD0=JUS036W8@0cYAc0;f4J`2eQ6/0]G]S0;f4J`2mQ6<0_HA[0<j<J`3>U7<0aXac0<j<J`3>U7<0
eXak0=JLL`3FW8@0eXak0<j<J`3FW7<0eYb40=J<N`3>U7<0cXa[0=J<L`3FW7<0eXak0=JLL`3FW8@0
eYac0=JLQ03FS7/0eYac1@3>U7/30<J<L`040<JDN`36S7<0aXac0;f4J`80]HA[00@0]G]S0:f4J`2L
Je80W6]B0P2<FTX208AB@P0507]SDP1c@S40LdXi06=2<@1B>C400P1B<BT01@12:B40@R4H048Y8@0a
8B408A0@0080<B4H200Y61P2034Q8@80:APH0P0Q410601P@400302TH600i:B40DSTa0080@RTQ00D0
DS4Y048Y8@24DT80knOW0?ooo`0^0?Ogma00oooo000>0?ooob00moOg00H0e/kN09AkL`24JeX0Nf=B
07=BBP1SBT8205Y2>@@0Je9:0P1SBT800`1SBTX0Je9:07=JDP0206=:@P0405Y2>@1B@ST0DT8i058a
:@80>BTQ00H0@RTQ058a:@0i:B40DSTa06]BBP1kHeX206]BBP80HdY20P1[DTX02P1SBT80Je9:07=B
BP1cDTX0Je9:06=:@P1S@S40LdXi07=:@P1cDTX208ASDP0309AJDP2LLf<0]G]S0080W7=S0P2eS7<0
0`36U7/0_Ib<0<JDN`020<JDN`0@0=j]U02mW8`0eZF40<JLQ03FYH`0_Ib<0<JLQ03FYH`0gZfD0=JU
Q03NW8@0gZfD0=jeW03N[I@0eZF<0>NeW080g[FL00/0gZfD0=JLS036U7/0aYAk0:ekJ`2eNf<0]HA[
0;EkH`2]LeX0]HA[0;f4J`020;f4H`030;f4J`3>S6/0cXac0080cYAc00H0cYAk0=J<L`3>S7<0cYAc
0<jDN`3>U7<20<j<L`80cYAc00T0cYAk0=JLQ03>U7/0eXak0<jDN`3FW7<0cYAk0<jDL`3>S7<00`36
S7<00`3>S6/0_HA[0<J<L`020<J<L`040;F<L`2mQ6/0]HA[0;EkH`80W7=S00H0W6]B08aJBP2<FTX0
S5Y208AB@P24DST207=:>@80Hd8a0P1B<BT3048Y8@04034Q60124100<B4H034Q8@80<B4H100Y61P2
024@40<0:APH100Q410501P@400:02TH600i:B40DS4Y058a:@12:B40DS4Y048Y8@1B>C40U7]c0?O_
kbl0moOg403oool000h0oooo803gmoL01`3Wg^l0[IBD08aSDP1kHeX0Nf=B06]BBP1J@ST00P1SBT80
101[DTX0LeYB06]BBP1B@ST306=:@P0?07=JDP1SBT80HdY205Y2>@1B<BT0Hd8a04Xa<@1B<BT0@RTQ
03TY8@12:B40DS4Y048Y8@1:<C40FT8i0080LeYB00D0Nf=J07=JDP1J@ST0Je9:06=:@P0606]BBP<0
LdY200D0Le9:08ASDP24JeX0Q6]J08acH`0309acH`060<JDN`2]Q7/0aYb40;F<L`36S7<0]Hac0P36
U7/20;F<L`030=JUQ036U7/0aYb400@0aYb400D0eZF<0=j]U03FW8`0eZF40=j]U0020=jeW0090<JL
Q036U7/0aYAk0;f4J`2]Q6/0YG=J0;EkH`2LLf<0W6]B0080[G=J0P2eNf<0202mQ6/0]G]S0;f4J`3>
S6/0cXac0<j<J`2mQ6/0cXa[0`3>S7<01@3>U7<0cXac0<jDL`3>U7<0cXac0080cYAc00l0cYAk0<jD
L`36S7<0cXa[0<jDL`36S7<0cXa[0<J<L`2mQ6/0cXa[0<J<L`2eS7<0_HA[0;F<L`2mQ6/00P2eNf<2
0:f4J`0709a[DP2DHdX0S5Y:08aJ@P24DT80LdY208AB>@0207=:>@0305Xa:@1B<BT0FS4Q00<0DS4Y
00<0@RTQ03TY8@0a8AP00P0a8AP00`0a8B40<B4H02TH600302TH60<08A0@0P0Y61P2024@40H0610@
00X08A0@034Q8@12:B40BS4a048Y8@1:<C40DS4Y048Y8@1cBT80c[F]<03gmoL@0?ooo`003P3ooolQ
0?Ogm`070=K6gP2UQ7/0S7=S07]SDP1cDTX0HdY206=2<@0206=:@P80Je9:0P1SBT8205Y2>@0606=:
@P1cFU80Je9:06=:@P1:<C40@RTQ0P1B>C401`1B<BT0>BTQ048Y8@1B>C40DT8i05Y2>@1B>C400P1J
@ST03@1B>C40FT8i07=JDP1cFU80He9:07=BBP1SBT80FT8i06=:@P1cFU80Je9:07=BBP1cFU800P1k
He801`1kHeX0Q6=B08ASDP2<FTX0Q6=B08aSDP2ULeX00P2]Q6/00`2DLf/0W7=S09acH`020:f4J`03
0;F<L`2]Q6/0]G]S0080W7=S0P2]Q6/01`2LLf<0]HA[0;F4J`36S7<0aYAk0=JUS02mW8`00P36U7/0
0`36W8@0_HA[09acH`0209acH`0309a[DP2DFU80W6]B0080YG=J00@0S7=S0:EcFP2ULeX0W6]B0P2U
LeX0102eLeX0_HAS0;f4H`2mQ6<20<J<H`030;f4J`36S6<0aXac0080cXa[00L0aXac0<j<J`3>S6/0
aXac0;f4J`2mQ6<0]G]S0080_HA[00<0_HAS0;f4J`2mQ6/00`2mQ6/01@2eNf<0]HA[0;EcFP2eQ6/0
]G]S0080YG=J0P2LJe801@2ULeX0Q6=B07]SDP24DST0LdY200<0Hd8a00D0FS4Y058a:@12:B40DS4Y
048Y8@02058a:@80>BTQ00@0<B4H02TH600Y61P0<B4H0`0Y61P3024@40`0610@00D0<B4Q058a:@1B
<BT0@RTQ04Xa<@02048Y8@0307=BBP2eW9`0mno_0300moOg403oool000h0oooo8@3gmoL01`3Fa]h0
YHAk08acH`1kHe80Le9:06=:@P1S@S400P1SBT8206]BBP80HdY20P1J@ST01P1SBT80LeYB06]BBP1S
BT80BS4a048Y8@80DSTa00L0DS4Y03TY8@12:B40DSTa0592>@1J@ST0DSTa0080FT8i00d0DSTa05Y2
>@1cFU80LeYB06=BBP1cDTX0HdY205Y2>@1SBT80LeYB06]BBP1cDTX0LeYB0080Nf=B00L0Nf=J08AS
DP24He80S5Y:08ASDP2<He80YG=J0080[HA[00<0U7=[09acH`2LLf<00P2]Q6/00`2eS7<0[HA[0;Ek
H`0209acH`80[HA[00L0W7=S0;F4J`2eQ6/0aXac0<JDN`3FYH`0_Ib<0080aYAk00<0aYb40;f4J`2L
Lf<00P2LLf<00`2LJe80U5YB09a[DP020:EcFP0408acH`2ULeX0YG=J09a[DP80YG=J00@0]G=J0;f4
H`2mQ6<0_HAS0P36S6<00`2mQ6/0aXaS0<J<L`020<j<J`070<J<L`3>S6/0cXa[0<J<L`2mQ6/0_HAS
0;EkH`020;f4J`030;f4H`2mQ6/0_HA[00<0_HA[00D0]G]S0;F4J`2eLeX0]HA[0;EkH`020:EcFP80
W6]B00D0YG=J08ASDP1kHe80Q58i07=:@P0306=2<@0505Xa:@1B<BT0@RTQ058a:@12:B400P1B<BT2
03TY8@04034Q600Y61P0:APH034Q60<0:APH0`0Q410<01P@4005034Q8@1B<BT0DS4Y048Y8@1:<C40
0P12:B400`1cDTX0]IbL0?O_k`0`0?Ogma00oooo000>0?ooob40moOg00T0mno_0:f<Q02DLf/0Q6]J
07=JDP1[DTX0HdY205Y2>@1cBST00P1[DTX01P1SBT80FT8i06=:@P1J@ST0HdY207]SFP80Je9:00H0
DT8i058a:@1B<BT0DSTa04Xa<@0i:B42058a:@0306=2<@1J@ST0HdY20080FT8i00@0HdY206=:BP1[
DTX0Nf=J0`1cFU801P1cDTX0Je9:06=:@P1kHeX0LeYB06=:@P80LeYB00H0Nf=J07=JDP1kHe80Nf=B
08ASDP2<He8209acH`0808acH`2LJe80YG=J09AcJ`2LLf<0U7=[0:f4J`2ULeX208acH`0;0:EcFP2L
Lf<0[HA[0:EcFP2LLf<0YG=J0:f4J`2eS7<0aYb40=JUQ036U8@00P2eS7<20:f4J`0A09acH`2LJe80
W6]B08A[FP2LJe80Q59208aSDP2<FTX0U6=:08aJBP2<He80U6=:0:EcDP2]LeX0]G=J0:ecFP2eLeX0
0P2mQ6<01`2eNf<0_HAS0;f4J`2mQ6<0_HA[0<j<J`2mQ6/00P2mQ6<30;f4J`030;EkH`2]LeX0]G]S
0080]G]S00<0]G=J0;EkH`2eQ6/00`2eNf<01`2]LeX0[HA[09acH`2ULeX0W6]B08aSDP2<FTX00P24
DT802024DST0Ld8a06=2<@1J<BT0Hd8a05Xa:@12:B40DS4Y0P12:B400`128AP0@RTQ048Y8@03034Q
60D0:APH0`0Q410;01P@4005024@401B<BT0DS4Y03TY8@1:<C400P12:B400`1B<BT0U7=[0>oFcP0a
0?Ogma00oooo000>0?ooob80moOg00D0c[Fe09AkL`2<Lf<0Le9:06]BBP0306=:@P0506]BBP1cDTX0
HdY206=:@P1SDTX00P1J@ST207=JDP0606=:@P1J@ST0@S4i03TY8@1B<BT0DSTa0P1B<BT01012:B40
DSTa06=:@P1J@ST206=BBP0405Y2>@1[DTX0LeYB06=BBPD0Je9:00D0Le9:06]BBP1cFU80Nf=J07=J
DP0207]SFP0408A[FP1kHe80Q6=B08A[FP80S7=S00h0Q6]J0:EcFP2LJe80Q6]J0:EcFP2<Lf<0YG=J
08acH`2ULeX0W6]B0:EcFP2<Lf<0YG=J09acH`80YG=J00L0W6]B0:f4J`2ULeX0[HA[0;F<L`36W8@0
]Hac00<0W7=S00<0[G][09acH`24JeX00`2<He802@1kHe80Q59208ASDP2<FTX0S6=B08AB@P2<FTX0
[G=J0:EcFP020:e[DP030:ecFP2eNf<0]G=J0080]G]S00<0_HAS0;f4J`2mQ6<00P2mQ6/00`2eQ6/0
_HA[0;F4J`020;EkH`80[G=J0P2ULeX01P2]LeX0YG=J0:ecFP2LLf<0YG=J09acH`<0YG=J00D0W6]B
08aSDP2<FT80Q59208AB>@0606=2<@03058a:@1J<B40DS4Y0080@RTQ00D0>BTQ048Y8@12:B40<B4H
034Q8@0302TH6007034Q8@0a8AP08A0@01P@400Q4100610@024@400:01P@400302TH601:<C40@RTQ
0080@RTQ00@0>BTQ048Y8@1B>C40]JFU<P3gmoL@0?ooo`003P3ooolR0?Ogm`060=K>gP2LS8`0U7]c
07=JDP1[DTX0LdXi0`1SBT8206]BBP0>05Y2>@1SDTX0He9:0592>@1SBT80Nf=B06=BBP1J@ST0DSTa
058a:@0i:B40DS4Y05Y2>@1:<C42058i<@0>05Y2>@1S@S40Je9:06]BBP1cFU80He9:06]BBP1cFU80
Nf=J06]BBP1JDU80Je9:06=:@P1cDTX207]SFP80Q6]J00T0Nf=J07=JDP1cFU80Nf=B08aSDP24JeX0
YG=J08aSDP1kHe800P24JeX00`2<Lf<0Q6=B08aSDP0308aSDP0408ASDP2<He80S6=B08aJBP<0W6]B
00<0S5Y:0:EcFP2ULeX00`2ULeX01`2]Q6/0W7=S0:EcFP24JeX0YG=J09acH`24JeX00`24He802@24
DT80Nf=B08AB@P1kHe80S5Y208ASDP24DT80W6]B09ASBP0209a[DP030:ecFP2ULe80[F]B00<0[G=J
00L0]G=J0;EkH`2eQ6/0]G]S0:f4J`2]LeX0[HA[00H0YG=J00H0W6]B0:EcFP2ULeX0YG=J09a[DP2<
He8309a[DP0408aSDP24DT80Nf=B08AB@P80LdXi0P1S@S4305Xa:@80DS4Y0P12:B401P128AP0<B4H
03TY8@12:B40:APH034Q6080:APH00@08A0@02TH600Y61P0:APH0P0Q410;01P@400502TH600i:B40
@RTQ048Y8@1:<C400P0i:B400`1J<BT0HcTa0=k>eP0b0?Ogma00oooo000>0?ooob80moOg00H0imk_
0<J]_@2UQ7/0Nf=J07]SDP1[DTX406=:@P0306]BBP1SBT80FT8i00<0HdY20P1[DTX205Y2>@0504Xa
<@1B<BT0@RTa058a:@1J@ST00P1B>C40101SBT80Je9:06]BBP1[DTX307=JDP0306]BBP1kHeX0Nf=J
0080Nf=J00@0FU9B06=BBP1kHeX0Nf=B0`1kHeX02@2<Lf/0Nf=J08A[FP24He80Q6]J08acH`1cDTX0
Q6]J0:EcFP0308ASDP80Nf=B00D0LdY207]SDP2<He80LdY208AB@P0308ASDP0608aJ@P1kHe80S6=B
09ASBP2LJe80S6=B0P2LJe800`2ULeX0S6=B08aSDP0208ASDP0708aSDP1kHe80LdY207]SDP24DT80
Nf=B08AB@P0207=:@P0508aJBP24DT80Q59208aJ@P24DT800P2DHdX01P2ULe80YF]B0:ESBP2ULe80
[F]B0:ecFP<0YG=B0P2ULeX309a[DP030:EcFP2LJe80W6]B00L0W6]B0P2<FTX0102LJe80S5Y208AB
@P24DT8307=:>@80Hd8a00H0FS4Y05Xa8@1B<BT0DS4Y048Y8@1:8AP2034Q6080>BTQ00<0<B4H02TH
600Y61P00P0Y61P2024@400302TH600H4100610@00/0610@00/0:APH034Q8@1B<BT0>BTQ058i<@12
:B40>BTQ058a:@1J<BT0Q6]J0?O_k`0b0?Ogma00oooo000>0?ooob<0moOg00<0imkW0:fLY@24JeX0
0P1cDTX04P1SBT80LdXi06=:@P1SBT80Je9:06=:@P1J@ST0HdY206=BBP1SBT80He9:07=JDP1SBT80
FT8i058i<@12:B40>BTQ0592>@80DSTa0P1J@ST306]BBP0607=JDP1kHe80LeYB07]SFP1cFU80Je9:
0P1cFU801@1kHeX0LeYB06=:@P1cFU80Nf=J0080S7=S0P24JeX02@24He80S6=B08acH`24JeX0Q6=B
08A[FP2<He80Nf=B08AB@P0207=:@P0=07=BBP1cBST0Le9:08acH`1cBST0Q6=B07]SDP24DST0LdY2
07]SDP24DT80Q6=B08AB@P0308ASDP0508aSDP24He80Q6]J07]SDP1cDTX00P1kHe800`24He80Le9:
07=BBP0207=BBP0708AB@P1cBT80LdY206=2<@24DST0Q59208AB>@0208AB@P0308ASDP2<FT80S5Y2
00<0W6]B00@0U6=:09a[DP2LJe80W6]B0P2DHdX02P2<FTX0Q6=B08aJBP2LJe80U6=:08aJ@P24He80
S5Y208aJBP2DHdX208aSDP80S5Y:0`24DT80101kHe80LdXi07=:>@1S@S4205Xa:@07058a:@1J<B40
DS4Y058a:@1B>C40@RTQ03TY8@03034Q6006034Q8@0a8AP0<B4H024@400Y61P0<B4H0P0Y61P01@0H
4100:APH024@400H41008A0@00P0610@00<08A0@02TH6012:B400P1B<BT00`12:B40<B4Q048Y8@02
06<i<@030:f<Q03gmoL0moOg0340moOg403oool000h0oooo8`3gmoL00`3Wg^l0aZf]08acJ`0207=B
BP0406]BBP1SBT80HdY206=:@P80Je9:00T0HdY205Y2>@1SBT80HdY:06=:@P1cFU80HdY205Y2>@1B
>C400P1B<BT00`12<CT0DSTa05Y2>@0305Y2>@80HdY200D0LeYB07]SFP24JeX0Q6]J07]SFP0207=J
DP0306]BBP1cFU80Je9:0080HdY200P0Je9:07=BBP1[DTX0Je9:07]SDP24He80S6=B08acH`80Le9:
00d0Nf=B07=BBP1kHe80Q6=B06=:@P1cBST0HdY207=:>@1cDTX0Nf=B06]BBP1cBT80LdXi00<0Nf=B
00P0LdY207]SDP1cBT80Q59207]SDP24DT80Nf=B08ASDP<0Nf=B00@0LeYB07=BBP1cDTX0LdY20P1c
BST00`1SBT80LdY206]BBP0207=:>@0406=2<@1cBST0LdXi08AB@P80Q58i00<0Q59208AB>@24DT80
0P24DT800`2<FT80S5Y:08ASDP0208AB@P0808AB>@24DT80Q59208ASDP2<FT80Q59207]SDP24DT83
07=:>@0308AB@P24DST0Q6=B0080Q59200@0Nf=B07=:@P24DST0LdXi0`1S@S401`1J<BT0DS4Y05Xa
:@1B<BT0@RTQ058a:@128AP00P0i:B401@0a8AP0:APH034Q600a8AP0>BTQ00<0:APH00@08A0@02TH
600Q41008A0@2P0H4100300Q4100:APH03TY8@1B<BT0>BTQ058a:@0a8B40>BTQ06<i<@1J<BT0HcTa
0<je]C<0moOg403oool000h0oooo8`3gmoL01P3gknl0g]KW0:fDU02<Lf/0LeYB07=BBP@0HdY20P1[
DTX01P1SBTX0FT8i06=BBP1SDTX0HdY207=JDP80HdY200P0FT8i058i<@12:B40DSTa06=BBP1[DTX0
He9:06=:@P80LeYB0`1kHeX01@1cFU80Je9:07=BBP24JeX0Nf=B0080LeYB0P1SBT803P1cDTX0LeYB
07]SDP1kHe80Q6=B07]SDP24JeX0Le9:07]SDP2<He80Nf=B07=:>@24DT80Le9:0P1cBST0201J@ST0
HdY207=BBP1[DTX0FT8i07=:>@1SBT80LdY20P1cDTX01P1S@S40HcTY07=BBP1cBT80LdXi07=:@P80
Nf=B00D0LdXi06=2<@1SBT80LdY207=JDP0306=:@P08058a:@1J@ST0Hd8a06=2<@1J@ST0LdXi05Y2
>@1S>BT606=2<@80LdXi00<0Ld8a07=:>@1c@S400P1cBST00`1c@S40LdXi07=:>@0307=:>@0705Y2
>@1S@S40Hd8a06=2<@1cBST0Hd8a06<i:@0306=2<@0807=:>@1S@S40Hd8a06=2<@1B>C40HcTY05Xa
:@1J<B42048Y8@0704XQ6012:B40@RTQ03TY8@12:B40<B4Q034Q600302TH6080<B4H0P0a8B4402TH
6080610@00<08A0@01P@400H41001@0H41003@0Y61P0<B4Q048Y8@0i:B40@RTQ058i<@0a8B40DS4Y
058i<@1S>BT0LdXi0<je]@3oool0<`3gmoL@0?ooo`003P3ooolT0?Ogm`050>oWi`2]U9@0YHAk07]S
FP1cDTX00P1[DTX02@1SBT80FT8i06]BBP1[DTX0He9:05Y2>@1SBT80He9:06=:@P0207=JDP80HdY2
00L0FT8i0592>@1B>C40Je9:07=JDP1kHeX0Je9:0080LeYB1@1kHeX00`1cFU80Je9:07=JDP0207]S
FP0407=JDP1[DTX0HdY207=:@P80Le9:00h0Nf=B08A[FP24JeX0Je9:07=:@P1kHe80Je9:07=:>@1[
DTX0LdXi05Y2>@1SBT80Hd8a05Y2>@80HdY20P1J@ST05P1S@S40HdY206]BBP1cDTX0HdY205Y2>@1c
BST0Nf=B06]BBP1S@S40Je9:07=:@P1cDTX0HdY2058a:@1B>C40HdY207=:>@1SBT80FT8i058i<@1B
<BT2058i<@0405Xa:@1B>C40Hd8a058a:@80FS4Y00P0Hd8a05Xa:@1S@S40LdXi06=2<@1cBST0Hd8a
05Xa:@D0Hd8a00<0FT8i06=2<@1S@S400`1S@S40101S>BT0Hd8a07=:>@1J<BT206=2<@80FS4Y00D0
HcTY06=2<@1S@S40Hd8a05Xa:@02058a:@D0@RTQ00@0<B4H048Y8@12:B40<B4H100Y61P0100a8B40
:APH034Q6012610202TH60808A0@00D0610@024@400H4100610@024@400301P@4080:APH00H0<B4Q
048Y8@0i:B40@RTQ04Xa<@12:B42058a:@0405Xa:@1S>C40[HAk0?O_kc@0moOg403oool000h0oooo
903gmoL0103Wg^L0aZf]09B4Q02<Lf/207=BBP0406=:@P1cBST0HdY205Y2>@80Je9:00D0HdY2058i
<@1SBT80He9:06=:@P0206]BBP80HdY20`1J@ST00`1[DTX0S7=S07]SFP0207]SFP0407=JDP1kHeX0
Q6]J08acJ`<0Nf=J00D0LeYB06]BBP1cDTX0HdY205Y2>@0206]BBP<0LdY200`0[HA[08ASDP1SBT80
Q59206]BBP1cBST0Je9:07=:>@1[DTX0FT8i06=2<@1SBT8205Y2>@0<06=:@P1B>C40FT8i058i<@1c
BST0HdY206]BBP1J@ST0Le9:058a:@1[DTX0Le9:0P1SBT801P1[DTX0HdY207=:>@1SBT80FT8i0592
>@@0FT8i0P1B<BT4058i<@@0DS4Y101J<BT206=2<@0305Xa:@1S@S40Hd8a00<0Hd8a00<0HcTY06=2
<@1B<BT00P1S@S401@1S>BT0DS4Y05Xa:@1J<BT0Hd8a00<0FS4Y00H0DSTa05Xa:@1B<BT0Hd8a05Xa
:@1S@S42058a:@03058i<@12:B40>BTQ0080@RTQ00@0>BTQ034Q6012:B40>BTQ100Y61P01P0a8AP0
:APH02TH600Y61P08A0@02TH6080610@00<08A0@01P@400H41001@0H4102034Q8@0;048Y<@12:B40
>BTQ04Xa<@12:B40<B4Q05Xa:@1[DTX0HdY209acH`3Fa]h0=@3gmoL@0?ooo`003P3oool70?Ogm`03
0?O_k`3gmoL0moOg01X0moOg00d0mno_0=K6eP2]U9@0U7]c07]SFP1cDTX0Je9:06=:@P1[DTX0FT8i
06=:@P1[DTX0HdY:0080FT8i00<0He9:06=:@P1SDTX00`1[DTX206=:@P0305Y2>@1B@ST0Le9:00@0
Nf=J0P1cFU801`1kHeX0Q6]J08acJ`1kHeX0Le9:06]BBP1SBT800P1[DTX207=BBP0806]BBP1cBT80
Nf=B08acH`1cDTX0LdY207]SDP1SBT8207=:>@0308AB@P1[DTX0DSTa0080HdY20P1J@ST0101SBT80
FT8i06=:@P1B<BT206=:@P80Je9:00D0HdY205Y2>@1B<BT0Je9:07=:>@0206=:@P0907=BBP1J@ST0
DSTa058i<@1S@S40DSTa04Xa<@1B>C40DS4Y0080DSTa00<0@RTQ058a:@1B<BT01@1B<BT01`12:B40
DS4Y058a:@1J<B40FS4Y06=:@P1J<BT00P1B<BT206=2<@@0DS4Y0P1J<BT0101B>C40DS4Y058a:@1B
<BT205Xa:@@0DS4Y00<0FS4Q058a:@1B<BT00P1B<BT2048Y8@0404XQ6012:B40>BTQ034Q6080>BTQ
00<0<B4H03TY8@0a8B400`0Q41000`0Y61P0<B4Q024@400402TH60808A0@1P0H41001@0Q4100>BTQ
03TY8@12:B40>BTQ0080DS4Y0P0i:B401@1B>C40Le9:07=:@P3>]Jd0oooo03D0moOg403oool000h0
oooo9@3gmoL0403Nc]H0aZf]0:fLS02DNg<0Le9:06]BBP1SBT80Je9:06=:@P1S@S40HdY206]BBP1S
BT80DT8i06=:@P1SDTX206=:@P0505YBDP1kHeX0LeYB06]BBP1JDU800P1J@ST01`1[DTX0Nf=J07]S
FP2<Lf<0Nf=J06=BBP1cFU801@1kHeX02@2<Lf<0Nf=J07]SFP1cFU80Le9:07]SDP1[DTX0Le9:08A[
FP0207=:>@80Je9:00H0LdXi06=:@P1cDTX0Je9:058i<@1cBST406=:@P050592>@1J@ST0DT8i05Y2
>@1SBT800P1[DTX02P1B>C40HdY2058a:@1B>C40Je9:06=:@P1S@S40HdY205Y2>@1S@S43058i<@03
04Xa<@1B<BT0DSTa00<0BS4a00<0@RTQ058a:@12:B40101B<BT2048Y8@06058a:@12:B40@RTQ05Xa
:@1B>C40@RTQ0P1B<BT2058i<@@0DS4Y00<0@RTQ058a:@1J<BT00P1B<BT01@12:B40DS4Y058a:@1B
<BT0@RTQ00<0DS4Y00<0@RTQ058a:@1B<BT00P12:B40100a8AP0@RTQ03TY8@0i:B42034Q600402TH
600i:B40<B4Q02TH60808A0@0`0Y61P0100H41008A0@024@400Y61P701P@400502TH600a8B40@RTQ
048Y8@0i:B400P1B<BT2034Q8@05058a:@1J<BT0LdY20:f4N`3gknl0=P3gmoL@0?ooo`003P3ooolU
0?Ogm`080>ONi`3>]KD0W8b<09B4Q01kHe80Je9:07=BBP1[DTX406=:@P0406]BBP1SBT80HdY207=J
DP<0HdY200L0Je9:07]SFP1cFU80LeYB07]SFP1[DTX0DT8i0080FT8i00<0Je9:07]SFP1kHeX0101c
FU8406]BBP0>07=BBP1[DTX0Je9:06]BBP1cDTX0Q6]J08AB@P1S@S40HdY206]BBP1cBST0HdY205Y2
>@1SBT8505Y2>@80HdY200/0Hd8a05Y2>@1J@ST0DS4Y06]BBP1S@S40HdY2058a:@1SBT80Hd8a04Xa
<@0206=:@P80FT8i00T0DSTa04Xa<@1B<BT0BS4a058a:@0i:B40DS4Y058i<@1:<C400`12:B40100i
:B40@RTQ048Y8@1B<BT2048Y8@06058a:@0i:B40DS4Y048Y8@0i:B40@RTQ0P1B<BT00`12:B40DS4Y
058a:@04058a:@04048Y8@1B<BT0DS4Y048Y8@D0DS4Y0P12:B401@1B<BT0@RTQ048Y8@12:B40BR4H
0080@RTQ00<0<B4H048Q600a8AP00`0a8AP0100a8B40<B4H02TH600a8AP2024@400801P@400Y61P0
:APH024@400Y61P0610@02TH600Q410201P@4004024@400H4100610@01P@4080:APH0`0i:B402@1B
<BT0DSTa03TY8@0a8B40DS4Y048Y8@1kHe80[IBD0=K6cP0g0?Ogma00oooo000>0?ooobD0moOg00D0
imkW0=K6cP2eYJD0]JFU08acJ`0206]BBP0306=:@P1cBST0Je9:0080HdY200T0LeYB06=BBP1B@ST0
Je9:05YBDP1SBT80FT8i06=:@P1SDTX0101kHeX01`2<Lf/0Je9:06]BBP1J@ST0HdY207=JDP1[DTX0
0P1cFU800`1[DTX0HdY205Y2>@02058i<@0<06=:@P1[DTX0Le9:07=BBP1cBT80Q6=B06]BBP1S@S40
LdXi06]BBP1cBST0LdY21P1SBT803@1B@ST0FT8i06=BBP1J@ST0DT8i06=:@P1:<C40Le9:05Y2>@1B
@ST0FT8i04Xa<@1SBT800P1:<C40101B@ST0FT8i058a:@1:<C43058a:@03048Y<@1B<BT0@RTa00<0
@RTQ0P0i:B401@12:B40>BTQ048Y8@12:B40DS4Y00<0@RTQ00L0>BTQ058a:@12:B40>BTQ048Y8@1B
<BT0>BTQ00@0@RTQ00D0>BTQ058a:@12:B40>BTQ058a:@02048Y8@03058a:@12:B40@RTQ0080DS4Y
1012:B401@0a8AP0@RTQ048Y8@12:B40>BTQ00<0<B4H00T08A0@02TH600a8AP0<B4Q034Q600a8B40
:APH024@400H41000P0Y61P0100a8B408A0@024@400H410202TH60@0610@0P0Y61P203TY8@80BS4a
00P0DSTa03TY8@0a8B40@RTQ058a:@1:8AP0YHB40=K6cSP0moOg403oool000h0oooo9P3gmoL01P3W
g^L0e/K>09b<S02DNg<0S7=S07=BBP<0HdY200T0LdXi06=:@P1J@ST0Je9:07=JDP1SBT80He9:06]B
BP1SDTX00`1J@ST00`2<Lf<0Nf=J08acH`0307]SFP0808acH`24JeX0HdY2058i<@1SBT80LeYB05YB
DP1cFU8307]SFP0807=JDP1SBTX0HdY206=:@P1cBT80Nf=B05Xa:@1B>C4206=:@P0306=2<@1J@ST0
Hd8a0080HdY201L0DT8i05Y2>@1SBTX0DT8i06=:@P1[DTX0DS4Y0592>@1SBT80DT8i058i<@1[DTX0
DS4Y06=2<@1:<C40DS4Y058i<@1:<C40DT8i03TY8@1:<C40DS4Y034Q8@02058a:@0303TY8@12:C40
@RTa00X0>BTQ00D0@RTQ03TY8@12:B40@RTQ058a:@04048Y8@05058a:@12:B40DS4Y048Y8@1B<BT0
0P0i:B403@0a8AP0DS4Y034Q601B<BT0>BTQ034Q601:8AP0DS4Y048Y8@1B<BT0<B4Q03TY8@12:B40
0`0i:B401@0a8AP0@RTQ048Y8@0i:B40<B4H0080:APH0P0Q4100100Y61P08A0@02TH600Y61P201P@
4004024@400H41008A0@02TH60<0610@00<08A0@01P@400H41000P0Y61P203TY8@07034Q8@12:B40
>BTQ03TY8@0Y61P0@RTQ058i<@02048Y8@030:f<Q03_inL0moOg03P0moOg403oool000h0oooo2@3g
moL00`3gknl0moOg0?Ogm`0J0?Ogm`090?O_k`3Nc]H0c[g60:F4Q02DLf/0Nf=J06]BBP1J@ST0HdY2
0080Je9:0P1SBT802P1cFU80DSTa05Y2>@1J@ST0HdY206=BBP1B@ST0DSTa05YBDP1cFU8707]SFP0:
06=:BP1B@ST0DT8i05Y2>@1cFU80Nf=J08acJ`2<Lf<0Nf=J07]SDP80HdY20P1cBT800`12:B40Hd8a
06=:@P0405Y2>@03058i<@1SBT80DSTa00@0HdY200P0Je9:058a:@1B>C40@RTa06=:@P12:C40Je9:
0592>@80BS4a00/0DS4Y048Y<@0i:B40DS4Y048a>@12:C40BS4a058a:@0i:B40@RTa048Y8@0403TY
8@05034Q8@0i:B40>BTQ034Q600a8B40100i:B401P12:B40>BTQ048Y8@12:B40>BTQ034Q60@0@RTQ
00D0<B4H058a:@12:B40@RTa03TY8@02034Q60<0>BTQ0P0a8AP00`1:8AP0@RTQ048Y8@02034Q8@03
048Y8@0i:B40<B4H0080<B4Q00<0<B4H048Y8@0i:B400P0a8B40100i:B40<B4Q02TH600Q410302TH
60808A0@00D0:APH01P@400H4100610@02TH600301P@4003024@400Y61P0<B4Q00<0>BTQ00/0@RTQ
058i<@0a8B40<B4Q048Y8@1B<BT0@RTQ06<i<@2<He80g/kF0>oWi`0i0?Ogma00oooo000>0?ooo``0
moOg00<0mno_0?Ogm`3gmoL0603gmoL02P3Wg^L0g]KW0<jmaP2]U9@0U7]c06]BBP1SBT80FT8i06=:
@P1[DTX206=:@P0306=BBP1SBT80DT8i0080HdY200H0Je9:06=BBP1J@ST0FT8i06=:@P1[DTX307=J
DPD0Nf=J00D0LeYB07]SFP1cFU80HdY205Y2>@0206=:@P0305Y2>@1SBT80LdXi0080Je9:00L0@RTQ
05Xa:@1S@S40FT8i06=2<@1SBT80FT8i00@0DSTa0P1SBT800`1J@ST0HdY2048Y<@02058a:@0505Y2
>@1:<C40Hd8a06=:@P12:C400P0i:B401`1B<BT0BS4a034Q601:<C40DS4Y048a>@1B<BT00P0i:B40
1012:B40>BTQ03TY8@12:B4203TY8@06034Q8@0a8AP0>BTQ034Q600a8B40<B4H0P0i:B401`0a8B40
>BTQ03TY8@0i:B40@RTQ034Q600i:B400`12:B401P0a8AP0>BTQ048Y8@1B<BT0>BTQ034Q8@80<B4H
00<0@QP@03TY8@0a8AP00P0a8AP203TY8@05048Y8@0a8AP0<B4Q048Y8@0a8B400P0Y61P02P0a8B40
>BTQ03TY8@0a8B40<B4H03TY8@0a8B40<B4H02TH600Q410202TH600301P@400Q41008A0@00@0610@
0P0Y61P0100H4100:APH034Q8@0i:B42034Q8@03048Y8@1B>C40>BTQ00@0DS4Y00D0HcTa08acH`2]
W;D0moOg0?O_k`0i0?Ogma00oooo000>0?ooobP0moOg00D0g/kF0=kFi`3>_Lh0W8b<07=:@P0306=:
@P<0Je9:00@0HdY206]BBP1SBT80FT8i0`1SBT801@1SDTX0FT8i0592>@1B@ST0HdY20080Je9:0P1c
FU8407]SFP0307=JDP1[DTX0He9:0080He9:00L0Je9:05Y2>@1SBT80Je9:07=BBP1cBST0DS4Y00<0
DSTa0`1SBT80101J@ST0BS4a04Xa<@1B@ST405Y2>@0:048a>@1B<BT0@RTa058a:@1B@ST0DS4Y06=:
@P1B<BT0BS4a03TY8@80@RTa00<0DS4Y034Q8@0i:B400P12:C401@1B<BT0>BTQ03TY8@0i:B40<B4Q
00<0>BTQ0`0a8B42034Q6004034Q8@0a8AP0>BTQ03TY8@80<B4Q00@0>BTQ048Y8@0a8B40<B4H0`0i
:B402`12:B40<B4H03TY8@1B<BT0>BTQ02TH600i:B40<B4H02TH600a8AP0>BTQ0080<B4H00P0@RTQ
03TY8@12:B40<B4Q034Q600i:B40<B4H034Q8@80:APH0P0i:B400`0a8AP0<B4Q034Q6002034Q8@80
:APH00D0610@02TH600Y61P0:APH024@400401P@4080:APH0P0a8B401`0i:B40<B4Q034Q8@12:B40
DSTa03TY8@0a8B400P12:B40101B<BT0FS4Y08AB@P2mYI`l0?Ogma00oooo000>0?ooobP0moOg00l0
mno_0>ONi`3Nc]H0aZf]07]SDP1[DTX0FT8i07=:>@1SBT80Je9:07=JDP1[DTX0He9:06]BBP1B>DX0
0P1J@ST00`1SBT80HdY:05Y2>@0207=JDP@0He9:00L0HdY206]BBP1kHe80S7=S07]SFP1cFU80FU9B
0080Nf=J01D0LeYB05YBDP1J@ST0FT8i06=2<@1SBT80FT8i048Y8@1B>C40DS4Y058i<@1J@ST0LdXi
06=:@P1J@ST0BS4a058a:@1:<C40FT8i058i<@1B@ST00P1J@ST204Xa<@06058a:@12<CT0@RTa05Y2
>@0i:B40BS4a0P0i:B402012:B40@RTa034Q8@0i:B40<B4Q058a:@1:<C40DS4Y0`0i:B401@0Y61P0
<B4Q034Q8@0a8B40@RTH0080<B4Q00@0<B4H02TH600Y61P0<B4Q0`0i:B401@12:B40>BTQ03TY8@0Y
61P0<B4H00<0>BTQ00T0<B4Q034Q6012:B40@RTa034Q8@0Y61P0>BTQ034Q8@0a8AP00P0i:B42034Q
6080@RTQ0P0a8AP00`0a8B40:APH02TH600302TH6080<B4Q1@0Y61P301P@4003024@400H4100610@
00<0610@00/08A0@02TH600Y61P0<B4Q03TY8@0a8B40<B4H048Y8@1B>C40<B4H03TY8@03058a:@03
05Y2>@1cBT80[IBD0080moOg00<0knOW0?Ogm`3gmoL0>03gmoL@0?ooo`003P3oool00`3gknl0moOg
0?Ogm`0V0?Ogm`060>ONk`3Nc]H0e/KF08A[FP1kHe80HdY20P1J@ST206]BBP0506=:@P1[DTX0LeYB
06=BBP1J@ST00P1SBT801@1SDTX0HdY:06=:@P1[DTX0Nf=J0080LeYB00P0He9:06=:BP1SBT80FT8i
06=:@P1cFU80Nf=J07=JDP80Nf=J00L0S7=[07=JDP1SBT80HdY2058i<@1J@ST0Hd8a00@0DS4Y0200
DSTa05Y2>@1SBT80FT8i04Xa<@1B<BT0BS4a06=:@P12<CT0DSTa06=:@P1J@ST0BS4a048a>@1:<C40
DT8i048Y8@1:<C40>BTQ048Y8@12<CT0>BTQ048Y8@12:C40DS4Y034Q8@0i:B40<B4Q03TY8@1:<C40
@RTa03TY<@80<B4Q00<0:APH034Q8@0a8B400P0a8B400`0Y61P0<B4Q02TH600202TH60D0>BTQ0P0a
8AP00`0Y61P0<B4H03TY8@0203TY8@05034Q8@0a8AP0DS4Y03TY8@0Q41000P0a8B4202TH600303TY
8@0a8B40:APH0080>BTQ00<0<B4Q034Q600a8B400P0Y61P2034Q8@80:APH00P08A0@02TH600Y61P0
:APH01P@400Y61P0610@024@4080:APH100H4100100Q4100:APH02TH600a8AP3034Q8@0504Xa<@1J
@ST0BS4a048a>@1J@ST00`1B>C40101cBT80U7]c0>oWi`3gmoL20>oWicX0moOg403oool000h0oooo
:P3gmoL01`3Nc]H0e/K>09b<S02<Lf/0Je9:06=:@P1J@ST0101SBT8207=JDP0506=BBP1SBTX0He9:
07=JDP1SBTX00P1B@ST00`1SBT80He9:06=BBP0207=JDP0;07]SFP1JDU80FT8i0592>@1SBT80HdY:
06=:@P1SDTX0Nf=J07=JDP1B@ST00P1J@ST0101S@S40DSTa048Y8@12:B42058a:@80DSTa0P1J@ST0
4P1:<C40DS4Y04Xa<@1J@ST0DT8i04Xa<@1J@ST0DT8i03TY8@1B<BT0BS4a058i<@12:B40>BTQ0592
>@0i:B40BS4a048Y<@80>BTQ00L0@RTQ02TH600a8B40<B4Q02TH600i:B40@RTQ0080>BTQ0P0a8B40
0`0Y61P0<B4Q034Q8@02034Q8@06034Q600Y61P0:APH024@400Y61P0<B4Q0P0a8AP203TY8@03034Q
8@0Y61P0:APH0080:APH00D0<B4H034Q8@0a8B40<B4H058a:@0202TH600603TY8@0a8B40:APH034Q
600i:B40<B4H0`0a8B4:02TH600801P@400Y61P0:APH02TH600Q4100610@02TH600Q410301P@4003
02TH600a8B40<B4H00<0<B4Q00D0:APH048Y8@1B<BT0>BTQ058a:@02048Y8@06034Q601cBST0LdXi
09acH`3Nc]H0moOg0P3_inLk0?Ogma00oooo000>0?ooobX0moOg00T0mno_0=kFi`2UQ8@0U7=[07]S
DP1cDTX0HdY205Y2>@1cBST00`1SBT800`1cFU80Nf=J06=BBP0206=:@P0407=JDP1SBTX0FT8i05Y2
>@80He9:00<0LeYB07]SFP1cFU800P1cFU802P1SDTX0FT8i05Y2>@1SBTX0LeYB07]SFP1cFU80FT8i
06=:@P1J@ST2058i<@04048Y8@1B<BT0BS4a048Y8@80DS4Y00d0Hd8a05Y2>@1:<C40DS4Y04Xa<@1B
>C40BS4a058a:@12:C40BS4a048Y8@0a8AP0BS4a0080@RTQ00D0<B4Q058i<@12:C40>BTQ048Y<@02
03TY8@80<B4Q00@0:APH034Q8@0a8B40<B4Q0P0i:B400`12:B40>BTQ034Q8@0202TH6003034Q8@0Y
61P0<B4Q00D0:APH0P0a8B40100i:B40<B4Q03TY8@0i:B4502TH6003034Q600a8B40<B4Q0080>BTQ
00<0:APH034Q8@0i:B400P0Y61P2034Q8@03034Q600Y61P0<B4Q00@0:APH00@08A0@02TH600Y61P0
:APH0`0Q4100100H41008A0@01P@400H4102024@40<0610@00<0:APH034Q8@0a8B400P0a8B4202TH
600804Xa<@1B<BT0<B4Q048Y8@0i:B40<B4H03TY8@1B<BT208A[FP050<je_@3gmoL0moOg0>oWi`3g
knl0>`3gmoL@0?ooo`003P3oool00`3gmoL0mno_0?Ogm`0Y0?Ogm`070;FU[@2UQ8@0U7]c07]SFP1c
FU80HdY205Y2>@0206]BBP0906=:@P1J@ST0HdY207=JDP1SBTX0HdY20592>@1SBT80He9:00D0HdY2
0P1cFU801@1JDU80He9:05Y2>@1B@ST0FT8i0080DT8i00X0@S4i058a:@1B@ST0Je9:06=2<@1B>C40
@RTQ058a:@0i:B40<B4H0`12:B403P1B@ST0DSTa04Xa<@1B<BT0@RTa04Xa<@1B<BT0@RTa04Xa<@1B
@ST0DS4Y034Q600i:B40DSTa0P0i:B401P1B<BT0<B4Q034Q8@1B<BT0<B4Q02TH6080>BTQ00L0<B4Q
02TH600a8B40<B4Q03TY8@0a8B40>BTQ0080<B4Q200Y61P00`0a8B40:APH02TH6004034Q8@0303TY
8@0a8B408A0@00D0:APH0`0a8B4202TH6080>BTQ0P0Y61P02P0a8B40:APH02TH600a8B40610@02TH
600Q4100610@024@400Y61P901P@400302TH600a8B40<B4Q00<0<B4Q0P0Y61P02`0a8AP0@RTQ058a
:@0i:B40DS4Y03TY8@0a8AP0DS4Y05Y2>@2<FTX0W6]B0080e[g600<0moOg0>oWi`3_inL0?@3gmoL@
0?ooo`003P3oool/0?Ogm`0:0>ONi`2eYJd0YHAk09AcJ`24JeX0LeYB06=:@P1J@ST0Je9:07=BBP80
HdY200@0Je9:07=JDP1SDTX0FT8i1P1SBT80201SDTX0DT8i06=:@P1SBT80He9:06]BBP1SDTX0HdY2
0P1B@ST0101:<C40DS4Y058i<@1SBT82058i<@0703TY8@1B<BT0@RTQ03TY8@1:8AP0@RTQ034Q6003
04Xa<@80@RTQ00H0BS4a048Y<@12:B40BS4a058i<@1B>DX2034Q8@06058a:@12<CT0<B4Q048Y8@12
:C40<B4Q0P0i:B401@0Q4100<B4Q03TY8@0a8B40:APH0080<B4Q0`0i:B400`0a8B40:APH02TH6004
02TH6080<B4Q00<0:APH034Q8@0Y61P00`0Y61P303TY8@03034Q8@0Y61P0:APH00<0:APH1@0a8B42
02TH6006048Y<@0i:C40<B4Q02TH600a8B408A0@0P0Y61P2024@4080610@00<08A0@01P@400H4100
1@0H41001`0Y61P0<B4Q034Q8@0a8B40>BTa03TY8@0a8B400P0Y61P01@0a8B40@RTa03TY8@0a8B40
DS4Y0080>BTQ00D0DS4Y06=2<@24DT80W6]B0:EcFP040>oWich0moOg403oool000h0oooo;@3gmoL0
1`3Fc]h0[IBD09AkL`2<Lf/0Nf=J06]BBP1SBT800`1[DTX0201SBT80DT8i06=:@P1cFU80HdY206]B
BP1SBTX0DT8i101SBT800`1cFU80Je9:06=BBP020592>@0:06=:@P1B>C40@S4i048Y<@0i:B40DS4Y
06=2<@1cBT80FT8i058i<@80@RTQ00H0>BTQ034Q8@0a8AP0@RTQ03TY8@1B<BT204Xa<@0>048Y8@0i
:B40@RTQ048Y8@0i:B40@RTa03TY8@1SBTX0>BTQ034Q600i:B40DT8i02TH600a8B4203TY8@06034Q
600i:B40<B4Q034Q8@0i:B40<B4H100Y61P0100i:B40<B4Q02TH600a8B4402TH6003034Q8@0Y61P0
:APH0080<B4Q0P0Y61P3034Q8@0803TY8@0a8B40<B4Q034Q8@0H4100:APH01P@400Y61P2034Q8@09
02TH600a8B40<B4Q034Q8@0Y61P0<B4Q048a>@12:C40<B4Q0080:APH00<0610@024@400H41000`0H
41000`0Q4100610@01P@400301P@400302TH600a8B40>BTQ00@0>BTQ0P0Y61P01P0a8B40>BTQ034Q
8@0i:B40<B4Q058a:@80@RTQ00H0DSTa07=:>@24DT80Q6=B09a[DP2LLf<20>oWi`030>ONi`3gmoL0
moOg03d0moOg403oool000h0oooo;@3gmoL0203gknl0c[Fm0:F4Q02DNg<0Q6]J07]SDP1[DTX0FT8i
0P1[DTX0201cFU80HdY205Y2>@1SDTX0HdY206=BBP1[DTX0Nf=J0`1SDTX206]BBP0405YBDP1cFU80
LeYB07=JDP<0HdY:00D0DT8i048Y<@1B<BT0HdY206]BBP02058i<@05058a:@12:B40>BTQ03TY8@0a
8AP00P0i:B42048Y8@0=04Xa<@1B<BT0>BTQ03TY8@12:B40>BTQ048Y8@0i:B40DT8i048Y<@0Y61P0
>BTQ04Xa<@0202TH6006034Q600i:B40:APH034Q8@0i:B40:APH0`0a8B40100Y61P0<B4Q02TH600Y
61P3034Q8@L0:APH00<0<B4Q02TH600a8B400P0Y61P2034Q8@0303TY8@1B<BT0@S4i0080<B4Q00@0
610@02TH600Y61P0610@100a8B40200i:B40>BTa02TH600Y61P0<B4Q03TY<@0Y61P08A0@200H4100
0`0Q4100:APH02TH6002034Q8@0303TY8@12:C40>BTQ00<0<B4Q00@0<B4H034Q8@0a8B40>BTQ0`1B
<BT00`12:B40FS4Y06=2<@0207=:>@0408aJ@P2ULeX0W7=S0<J][@80mnON@03gmoL@0?ooo`003P3o
ool^0?Ogm`080>ONi`2]YKD0U8B408aSDP24JeX0Nf=B05Y2>@1SBT8206]BBP0706=:@P1J@ST0HdY2
07=JDP1SBTX0FT8i06]BBP0207]SFP0407=JDP1SDTX0Le9:06]BBP<0HdY20P1SDTX0101SBT80@S4i
04Xa<@1B<BT206=:@P0306=2<@1B<BT0@RTQ0080@RTQ00<0>BTQ034Q8@0i:B400P0a8AP00`12:B40
BS4a04Xa<@0203TY8@03034Q8@0i:B40>BTQ0080>BTQ00L0@S4i02TH600a8B40@RTQ034Q8@0a8AP0
:APH0080<B4Q0P0Y61P00`0a8B40:APH034Q8@02034Q8@0302TH600a8B40610@00@0<B4Q00<0:APH
01P@400H41000P0Y61P0100a8B40:APH034Q8@0a8B4202TH6080<B4Q00<0>BTa048a>@1B@ST00P12
<CT00`0a8B40:APH02TH600202TH60D0<B4Q00@0>BTQ034Q8@0Y61P0:APH0P0i:B42034Q8@80:APH
00@08A0@02TH600a8B40:APH0P0a8B40100i:B40>BTa03TY8@12:C42034Q8@0602TH600i:B40<B4Q
034Q8@0i:B40DS4Y0P1:<C42048Y8@09058a:@1S@S40LdXi07=:>@24DT80S7=S09a[DP2]S8@0g/kF
0480moOg403oool000h0oooo;`3gmoL0203Wg^L0aZf]09B4Q02<Lf/0Nf=J06]BBP1J@ST0HdY20P1[
DTX01@1SDTX0FT8i06=BBP1SDTX0HdY:00<0FT8i00<0He9:07=JDP1JDU800P1SDTX05@1SBTX0HdY2
06=:BP1J@ST0DSTa0592>@12:C40>BTQ06=:@P1[DTX0HdY2058a:@0i:B40BS4a048Y8@0a8B40<B4H
03TY8@0a8AP0<B4Q03TY8@03048Y8@0703TY8@0a8B40>BTQ034Q600i:B40<B4H048Y8@0202TH6007
034Q8@0i:B40<B4Q034Q600Y61P0>BTQ034Q8@0202TH60<0<B4Q0P0Y61P00`0a8B40:APH02TH6003
034Q8@P0:APH0P0a8B402P0Y61P0<B4Q034Q8@0a8B40@S4i058iBP12<CT0HdY2048a>@0a8B4402TH
60D0<B4Q00@0>BTQ03TY<@0i:B40<B4Q0P0i:B401@12:B40>BTa03TY8@0i:B40<B4Q00<0>BTQ0P0a
8B402@0i:B40@RTa034Q8@0a8AP0<B4Q02TH600i:B40<B4Q03TY8@0204Xa<@04048Y8@0a8B40@RTQ
058i<@<0Hd8a00H0Q59209a[DP2ULeX0U7=[0<J]Y@3Wg^M20?Ogma00oooo000>0?oooc00moOg00`0
knOW0:fU]@2UQ7/0S6=B07]SFP1[DTX0HdY206]BBP1SBT80Je9:06=BBP1SBT8206=BBP0306]BBP1J
DU80FU9B0080DT8i0`1kHeX01P1[DTX0HeYS07=JDP1SFV<0HdY:05Y2>@80DS4Y00@0Je9:06=:@P1S
BT80DSTa0`12:B400`0i:B40<B4H034Q8@0203TY8@03034Q600i:B40@RTQ00<0>BTQ0P0a8B401`0a
8AP0<B4Q034Q8@0a8B40:APH034Q6012:C400P0a8B400`0Y61P0<B4H034Q8@02034Q8@80:APH0P0a
8B4202TH6003034Q8@0H4100:APH00<0<B4Q0P0H410402TH60<0<B4Q0P0Y61P02`0a8B40>BTQ034Q
8@1B@ST0FU9B048a>@1kHeX0DSU:03TY8@0a8B40:APH00<0<B4Q0P0Y61P3034Q8@0503TY8@0i:C40
>BTQ03TY<@0i:B400`0i:C4303TY8@06034Q8@1B<BT0@S4i058a:@0i:B40<B4Q0P0Y61P02P0i:B40
DSTa058a:@1B<BT0@RTQ034Q8@0a8AP0DS4Y06=2<@1cBST206=2<@0608AB>@2DHdX0YF]B09a[DP2]
S8@0e/kN@`3gmoL@0?ooo`003P3ooola0?Ogm`0;0?O_k`3>_Lh0YHB409AcJ`24JeX0LeYB06]BBP1S
DTX0HdY206]BBP1SBT800P1J@ST306=BBP<0LeYB00D0FU9B07=JDP1cFU80Nf=J06=BBP0207=JDP04
06=BBP1B@ST0DT8i06]BBP80HdY200H0FT8i04Xa<@12:B40DS4Y048Y<@0i:B44034Q8@0702TH600i
:B40@RTQ03TY8@0a8B40<B4H034Q8@02034Q6008034Q8@0i:B40:APH02TH600a8B40>BTQ034Q8@0Y
61P2034Q8@80:APH00<0<B4Q02TH600a8B401@0Y61P01P0H4100:APH034Q8@0i:B40<B4Q02TH6080
610@100Y61P00`0a8B40>BTQ034Q8@03034Q8@0=03TY<@1B@ST0Jf=[05YBH`12<CT0HdY206=JH`1J
DU80>BTa034Q8@12<CT0@RTa03TY8@02034Q8@0402TH600a8B40<B4Q02TH60@0<B4Q00<0>BTQ048Y
<@12:C400P0i:B44034Q8@05048Y8@1B@ST0DT8i05Y2>@1B<BT00P0i:B40301B>C40Hd8a06=2<@1B
>C40DS4Y06=2<@1cBST0Nf=B08aJBP2LJe80S7=S0<je]DD0moOg403oool000h0oooo<`3gmoL0103>
_LH0U7=[09AcJ`24JeX207=JDP0406=:BP1SDTX0He9:06]BBP80HdY20P1[DTX02@1SDTX0HdY207]S
FP1kHeX0LeYB06=BBP1SBT80DT8i05Y2>@020592>@80DS4Y00H0Je9:07=BBP1J@ST0FT8i058i<@1B
<BT4048Y8@03034Q8@0a8AP0<B4H0080<B4Q00<0@RTQ03TY8@0a8B400P0a8AP01P0a8B40<B4H034Q
600a8B40>BTa024@4080>BTQ00<0<B4Q02TH600Y61P00P0a8B401@0Y61P0<B4Q034Q8@0Q4100<B4Q
00<0:APH00H0<B4Q01P@400Y61P0:APH034Q8@0i:C4202TH60<0610@00P08A0@02TH600a8B40<B4Q
048a>@0i:C40>BTQ03TY>@80<B4Q00H0FTYJ07]SFP1[Hf/0FTYJ048a>@1SBT8206=BBP04048a>@1B
@ST0@RTa0592>@80@S4i00@0>BTa034Q8@0a8B40:APH1`0a8B40100Y61P0>BTQ058a:@1:<C42058i
<@0806=2<@1B>C40<B4H034Q8@1B<BT0DSTa06=2<@1B>C42058a:@80Hd8a00H0LdXi08aJBP2LJe80
W7=S0<J][@3ooom50?Ogma00oooo000>0?oooc<0moOg00D0mno_08acN`2DLf/0U7]c08A[FP0207=J
DP80Je9:00<0He9:06=:@P1J@ST00P1B@ST0101SBT80DT8i06=BBP1SDTX607=JDP80HdY:00@0DT8i
06=:@P1cFU80Hd8a0P1J@ST3058a:@0303TY8@12:B40>BTQ0080:APH00D0<B4Q034Q600i:B40@RTQ
03TY8@03034Q8@0402TH600a8B40<B4H03TY8@80:APH00@0>BTQ034Q8@0a8B40:APH0P0a8B401@0Q
4100:APH034Q8@0Y61P0<B4Q00<0:APH00H0<B4Q02TH600Y61P0:APH034Q8@0i:B4402TH6080610@
0`0Y61P03P12:C40DSU:048a>@12<CT0BSU:03TY>@1B@ST0FU9B06=JH`1kHeX0FU9B048Y<@1B<BT0
@RTa0P12<CT00`1B@ST0@S4i048a>@020592>@80@RTa00<0>BTQ03TY<@0i:B400P0a8B4203TY8@0=
048Y8@1B<BT0BS4a05Xa:@1B>C40FT8i058a:@1:<C40@RTQ058a:@1S>C40DSTa06=2<@02058a:@<0
Hd8a00H0LdXi08AB@P2LJe80W6]B0:fDU03gknm60?Ogma00oooo000>0?oooc@0moOg00@0e/KF0:F4
Q02<Lf<0S7=S0P24JeX00`1kHeX0FU9B06=BBP0206=:@P80FT8i00H0DT8i058i<@1J@ST0HdY:06=B
BP1[DTX306=BBP0707=JDP1kHeX0LeYB06]BBP1SBT80Je9:06=:@P0205Y2>@04058i<@1:<C40DSTa
058a:@80@RTQ0P0Y61P0100a8AP0:APH034Q8@12:B4203TY8@80<B4H00<0<B4Q034Q600a8B400P0a
8B40100Y61P0<B4Q03TY8@0a8B4202TH6007034Q8@0Y61P0610@02TH600a8B40:APH034Q8@0302TH
6003034Q8@0Y61P0:APH00<0<B4Q00@0:APH01P@400Y61P0:APH0`0H410202TH600:034Q8@1SDTX0
DT8i048a>@1SBT80@S4i048Y<@1SBT80HeYS07]SFP80HeYS00T0DT8i048Y<@12:C40@RTa058a:@0i
:C40DS4Y048Y<@1:<C400P12<CT01012:C40>BTQ048Y8@1:<C45058i<@05048Y8@0i:B40@RTQ058i
<@1B<BT01P1B>C402@1[DTX0LdXi07=:>@1kHe80Q6=B08aJBP2DFU80[IBD0?O_k`170?Ogma00oooo
000>0?oooc@0moOg00L0oooo0=k>eP2<Lg/0S7=S09AcJ`24JeX0Nf=J00<0LeYB00H0He9:06=:@P1S
BT80FT8i0592>@1SBT8306=BBP0406=JH`1kHeX0Nf=J07]SFP80He9:00P0LeYB05YBDP1SBT80FT8i
06=2<@1SBT80DT8i05Y2>@80DSTa0P12:B400`0i:B40:APH02TH6002034Q8@<0>BTQ00P0:APH034Q
8@0a8AP0:APH034Q600Y61P0>BTQ02TH6080<B4Q00<0>BTQ02TH600Y61P00P0a8B4302TH60<0<B4Q
1P0Y61P2034Q8@P0:APH0P0H41000`0a8B40FU9B05YBDP03058iBP80@S4i00P0He9:07]SFP1kHeX0
Jf=[07=JDP1kHeX0LeYB05Y:FP80HdY:00@0DSU:06=:BP1[DTX0LeYB0`1SBTX00`1J@ST0DT8i058a
:@0203TY8@05034Q600i:B40DS4Y058i<@1J@ST00`1B>C4305Y2>@0:06]BBP1cBT80LdXi07=:@P24
DT80S5Y:08ASDP2]S8@0mno_0?ooodL0moOg403oool000h0oooo=P3gmoL01@3F_LH0YHB408acH`2D
Lf/0Q6]J00@0LeYB0P1[DTX206=:@P0305Y2>@1SBT80FU9B00@0LeYB00<0FU9B07]SFP1[Hf/00P1k
HeX0101[DTX0HdY205Y2>@1SBT8205Y2>@06058i<@1B@ST0DSTa048Y8@12:C40>BTQ0P0Y61P2034Q
8@05048Y8@0i:B40<B4H02TH600i:B400P0a8B40100a8AP0>BTQ02TH600Y61P2034Q8@80:APH00<0
<B4Q02TH600a8B400`0Y61P2034Q8@D0:APH100a8B4602TH600C034Q8@0Y61P0:APH02TH600a8B40
HdY206=BBP1JDU80He9:058iBP1:>DX0@S4i048Y<@12<CT0HdY20592>@1SBT80FU9B07]SFP0207=J
DP<0Je9:0P1SBT802@1J@ST0DSTa048Y<@12:B40>BTQ058a:@1B>C40FT8i07=:>@0406=:@P0707=:
>@1SBT80HdY206=:@P1[DTX0LdXi06=2<@0207=:>@0408AB@P2<FTX0U6=:0=k>eTT0moOg403oool0
00h0oooo=`3gmoL01@3Fc]h0W8bL08acH`24JeX0Nf=J0080Je9:01<0He9:06]BBP1[DTX0Je9:06=B
BP1J@ST0DT8i06=:@P1SDTX0Je9:05YBDP1cFU80FU9B06]SJ`1kHeX0Nf]k06]SJ`1kHeX0LeYB00<0
FT8i00T0DT8i06=2<@1B>C40DSTa04Xa<@1B<BT0BS4a034Q8@0Y61P00P0a8B40100i:B40BS4a048Y
8@0a8B42034Q6080<B4Q00@0<B4H02TH600Y61P0<B4Q0P0i:B4502TH600401P@400Y61P0<B4Q034Q
8@H0:APH100a8B400`0Y61P0610@02TH600202TH600903TY8@0a8B40<B4Q034Q8@0Y61P0<B4Q03TY
<@1JDU80DSU:0080HdY20P1JDU801P1B>DX0DT8i04XiBP0i:C40>BTQ034Q8@<0>BTQ00@0BS4a0592
>@1B>C40DSTa1`1J@ST00`1SBT80Je9:06=:@P0506=:@P0307=:>@1S@S40Hd8a0080Hd8a00D0LdY2
08aJBP2LJe80W6]B09AkL`1:0?Ogma00oooo000>0?ooocT0moOg00<0knOW0:fDU01kHe800P1kHeX0
0`1cFU80Je9:06]BBP0206=:@P<0Je9:00D0LeYB06]BBP1cFU80FU9B07=JDP0307]SFP0608akL`1k
Jg/0Nf=J07=JDP1B>C40FT8i0P1B>C4305Y2>@06058i<@1B<BT0DSTa05Y2>@12:B40<B4Q0P0i:B40
101:<C40@RTQ03TY8@0i:B42034Q8@0403TY8@12:B40:APH02TH60@0<B4Q0P0Y61P01P0a8B40:APH
02TH600Y61P0<B4Q03TY8@<0:APH00<0<B4Q02TH600a8B401P0a8B400`0Y61P0<B4Q034Q8@02034Q
8@0703TY8@12<CT0@RTa048Y<@0i:C40<B4Q048Y<@0406=:@P0904Xa<@1B>C40FT8i06=BBP1SBT80
Je9:07=JDP1JDU80He9:0080Je9:00@0LeYB06=BBP1SDTX0HdY20P1B@ST01`1SBT80FT8i06=:@P1B
@ST0FT8i0592>@1B>C400`1B<BT206=2<@0707=:>@24He80W6]B08ASDP2<FTX0YHAk0=JmaP1;0?Og
ma00oooo000>0?oooc/0moOg00@0U7=[08aSDP1kHe80LeYB0P24JeX01@1kHeX0He9:06=:@P1SDTX0
Je9:0080LeYB0P1kHeX00`1cFU80Nf=J06]SJ`0207]SFP0408acJ`1kHeX0Nf=J06=2<@<0DSTa00D0
FT8i058i<@1B>C40DSTa058a:@0204Xa<@0506=:@P1B>DX0>BTQ048Y8@1B@ST00P1:<C42048Y8@07
034Q8@12:C40>BTQ03TY8@0Q4100:APH03TY8@02034Q8@80:APH00<0<B4Q03TY8@0a8B400P0Y61P2
034Q8@80:APH00@0<B4Q03TY8@0a8B40>BTa100a8B401P0i:C40<B4Q034Q8@0i:B40>BTa048a>@<0
<B4Q00/0@RTa0592>@1B@ST0@RTa03TY>@12:C40HdY205YBDP1SBTX0>BTa034Q8@0203TY8@04048Y
<@0i:B40>BTQ048Y<@80>BTQ00@0DS4Y03TY8@0a8B40<B4Q0`1:<C401@12:B40DS4Y0592>@1J@ST0
DSTa0080DS4Y00<0FS4Y06=2<@1cBST00P24DT801P2LJe80Q6=B09AJDP2DNg<0g/kF0?oood/0moOg
403oool000h0oooo>`3gmoL0102]W;D0U7=[08acH`1cFU8206]BBP0407=JDP1cDTX0Je9:06=BBP80
HdY200<0Je9:05YBDP1kHeX00`1kHeX01P2<Lf<0S7=[09B4Q02LS8`0U8B406]BBP@0DSTa0P1J@ST0
201B>C40BS4a058a:@1B<BT0BS4a06=:@P1J@ST0BS4a101B@ST02`1:<C40@RTQ03TY8@0i:B40@S4i
03TY8@0Y61P0>BTQ034Q8@0i:B40<B4Q0080:APH00/0<B4Q048Y<@0a8B40:APH034Q8@0i:B40<B4Q
02TH600a8B40@RTa048Y8@0203TY<@0;034Q8@0i:B40>BTa03TY<@1B@ST0>BTQ034Q8@0i:B40@RTa
04XiBP0i:C400P0a8B40100i:B40@RTa048a>@1B@ST203TY<@0703TY8@1B@ST0He9:06=:BP12<CT0
@RTa034Q8@0203TY8@0=034Q8@12:B40BS4a048Y<@1B<BT0BS4a058i<@1B<BT0@RTQ058a:@1B>C40
FT8i06=2<@02058a:@80Hd8a00T0Ld8a07]SDP1cBT80Q59208ASDP2<He80S5Y:09AkL`3Nc]H0C@3g
moL@0?ooo`003P3oooll0?Ogm`030;FU[@2DNg<0S7=S0080LeYB00<0Je9:06=:@P1[DTX00`1[DTX2
06=BBP0907=JDP1JDU80Nf=J07]SFP2<Lf/0S7]c09B4Q02UQ7/0S7=k0080Je9:00<0FT8i05Xa:@1B
>C40101B>C43058a:@0304Xa<@1B>C40FT8i00D0FT8i00P0DT8i048Y8@1:<C40@RTa06=:BP0i:C40
<B4Q058a:@H0<B4Q0P0i:B40400a8B40@RTa03TY8@0a8B408A0@034Q8@1:<C40DSU:048a>@0i:B40
<B4Q048a>@0i:C40@RTa05YBDP0i:B42048Y<@0306=:@P1JDU80DSU:00D0@S4i0`0i:C4203TY8@@0
DT8i0P1:<C40101J@ST0DT8i0592>@1B@ST2058i<@05058a:@1B>C40HdY205Y2>@1S@S400P1B<BT2
06=2<@0:07=:@P1cBST0Je9:07=:>@24DT80S5Y:08aSDP24He80[IBD0=k>eTh0moOg403oool000h0
oooo1`3gmoL00`3gknl0moOg0?Ogm`0c0?Ogm`060=K6cP2DQ8@0S6=B08aSDP1kHeX0LeYB0P1SBT83
06]BBP80HdY200H0LeYB05YBDP1kHeX0Nf]k08acH`2<Lf/208akL`0407][N`1kHeX0LeYB05Y2>@80
DSTa00H0HcTa058a:@1:<C40DSTa04Xa<@1B<BT304Xa<@0405Y2>@1SBT80FT8i0592>@80HdY200L0
@S4i0592>@12:B40FU9B06=JH`0a8B40>BTQ0080@RTa00H0:APH034Q8@12:C40DS4Y03TY<@1:<C42
048Y<@0703TY8@12<CT0>BTQ034Q8@0Y61P0DT8i058iBP02048a>@0D048Y<@1JDV<0BSU:048Y<@1J
BUX0@S4i04Xa<@12:C40HdY206]SJ`1SFV<0Je9:05Y:FP1JDU80FT8i0592>@1:>DX0BS4a048a>@1:
<C42048Y<@06048a>@1J@ST0HdY:06=:@P1B>C40DT8i0`1B>C400`1S@S40FT8i06=:@P02058i<@06
05Y2>@1SBT80LdY207=BBP1cBT80LdXi0P24DT801`2LJe80S7=S08aSDP24He80]JFU0?O_k`3oool0
CP3gmoL@0?ooo`003P3oooln0?Ogm`030=K6gP2]S8@0[Hb40080S7=S00X0Je9:06=:@P1J@ST0FT8i
06=:@P1SDTX0Je9:05YBDP1kHeX0Jf=[0`2<Lf/208akL`0609B4Q02<Lf/0Q6]J07]SFP1SBT80DT8i
0P1B>C42058a:@07058i<@1:<C40DS4Y058a:@1B@ST0DS4Y05Y2>@0306=:@P0W06=:BP1J@ST0DT8i
0592>@0i:B40LeYB05Y:FP0a8B40@RTa048Y8@0i:B40:APH034Q8@1:<C40DT8i048a>@1B@ST0@RTa
04XiBP12<CT0DT8i04XiBP12<CT0DT8i06=JH`1B@ST0FU9B048a>@1B@ST0Ng=k059:FP1[DTX0Nf]k
06=JH`12:C40>BTa03TY8@1SBT80FU9B0080Nf=J00H0FU9B06=:BP1SBTX0HdY:06=:@P1J@ST306=:
@P0505Y2>@1SBT80HdY205Y2>@1S@S400P1J@ST306=:@P0@06=2<@1[DTX0Le9:07]SDP1cDTX0Je9:
07=:>@1SBT80Nf=B08AB@P2<He80YG=J08aSDP24He80S5Y:0?O_ke00moOg403oool000h0oooo?`3g
moL20=K>gP030:fDY@2DQ8@0Nf=J0080Je9:00H0HdY205Y2>@1SBT80HdY206]BBP1cFU8207]SFP80
S7=[00P0U8B409b<S02DQ8@0S7]c06=JH`1cFU80Nf=J06]BBP80HdY200`0FT8i058i<@1:<C40DS4Y
058i<@1B@ST0DSTa048Y<@1B<BT0DSTa05Y2>@1SBT8206]BBP80HdY:00/0DT8i048Y<@1SDTX0BSU:
034Q8@12:B40@S4i03TY<@0Y61P0>BTQ048Y<@020592>@0K058iBP1B@ST0FU9B0592>@1SDTX0FTYJ
058iBP1[Hf/0FU9B058iBP1[DTX0DT8i058iBP1[Hf/0DSU:0592>@2<Lf/0Nf]k06]BBP1:>DX0@S4i
04Xa<@1B@ST0HdY:06=:@P1SBTX0HdY20080FT8i00<0HdY205Y2>@1J@ST00P1J@ST806=:@P0506]B
BP1cDTX0Q59207]SDP1cDTX0101cBST01`24DT80W6]B08aSDP24DT80LdXi07=BBP2eW9`0D@3gmoL@
0?ooo`003P3ooom10?Ogm`060>ONk`3>_Lh0S7=S08A[FP1kHe80Je9:0P1SBT803@1B@ST0FT8i07]S
FP1SFV<0LeYB07]SFP2<Nh@0U8B408acJ`2DQ8@0W8b<09B4Q02<Lf/00P1kHeX01`1cFU80Je9:06]B
BP1cFU80Je9:05Y2>@1:<C400P1J@ST04P1B<BT0BS4a04Xa<@1J@ST0LeYB06=:BP1cFU80HdY:06]B
BP1cFU80FT8i058a:@1kHeX0BSU:058i<@12:B40FT8i048a>@80<B4Q00@0DS4Y058iBP1JDU80HdY:
0P1B>DX01@1SDTX0Jf=[06]SJ`1kLg/0Jf=[0080FU9B00@0HeYS06=:BP1B@ST0Nf]k0P1JDU803@1[
Hf/0FU9B07]SFP1kHeX0FTYJ05YBDP1SBTX0He9:06]BBP1SBTX0FT8i058iBP1SBT800`1[DTX207=B
BP80Je9:0P1cFU8207=:@P0507=BBP24DT80LdXi06=:@P1S@S400`1cBST01024DST0Q59209a[DP24
He8207=:>@0308acJ`3>]Kd0moOg0540moOg403oool000h0oooo00<0mno_0?Ogm`3gmoL0@03gmoL0
2`3Fc]h0c[Fm09B4U02<Lf/0Q6]J07]SDP1cFU80Le9:08A[FP1kHeX0LeYB00@0Nf=J00<0S7=[07]c
N`2DNg<00P2DQ8@03@2<Ng<0Nf=J08A[FP1cFU80Q6]J08acJ`2<Lf<0S7=[08A[FP1kHeX0LeYB06]B
BP1SBT800P1B@ST206]BBP0=06=:BP1kHeX0Nf=J07]SFP1cFU80HdY207=JDP1[Hf/0HeYS05YBDP1S
BTX0Nf=J058iBP02034Q8@0:06]SJ`1SFV<0HdY206=BBP1JDU80He9:05YBDP1[Hf/0Nf=J07]cN`80
Jf=[00`0Nf=J05Y:FP1SBTX0HdY:05Y2>@1SBT80Je9:07]SFP1cFU80He9:06=:BP1[DTX206=:@P03
06]BBP1SBT80HdY20080Je9:0P1SBT80101cBST0HdY206=:@P1cBST206=2<@80HdY20P1cBST308AB
@P0908ASDP2<FTX0U6=:08aJBP1kHe80FT8i07]SDP2mYI`0mno_05@0moOg403oool000h0oooo0`3g
moL00`3gknl0moOg0?Ogm`0n0?Ogm`090>ONk`3Fa/h0[IBU09AkL`2<Lg/0Nf=J07=JDP1kHeX0LeYB
0080Je9:00T0LeYB05YBDP1cFU80S7=[08acN`2DQ8@0Ng=k08acJ`2<Ng<00P2<Lf/02`2DNg<0S7]c
08acJ`2<Lf/0S7]c08acJ`2<Lf<0S7]c08acJ`1kHeX0LeYB0080HdY:0P1[DTX00`1JDU80Nf=J07]S
FP0207][N`0?07=JDP1kHeX0Jf=[08akL`1SFV<0FU9B07=SL`1SBTX0@S4i048Y<@1kHeX0FTYJ0592
>@1B>DX0DT8i0080HdY:00X0FU9B07]SFP1kJg/0Jf=[07=JDP1SDTX0Je9:07=JDP1[DTX0FU9B0P1S
BT801@1[DTX0Le9:07=JDP1cFU80Nf=B00@0Le9:0P1cBT800`1cBST0HdY206=2<@0307=:>@80Je9:
00@0LdXi08AB@P1kHe80Q6=B0P2<FTX0202LJe80YG=J09ASBP1kHe80Q59207=:>@2DLf/0c[FmEP3g
moL@0?ooo`003P3ooom50?Ogm`090>ONk`3Wg^L0aZfm0;FUY@2UQ8@0U7]c07]SFP1cFU80Nf=B00<0
LeYB00<0Nf=J08acJ`2<Ng<00P2<Ng<0102<Lg/0W8b<09b<S02<Lf/209AkL`0908acJ`24JeX0S7]c
09AkL`2<Ng<0S7=[08A[FP2<Lf/0S7]c0080S7=[00L0Nf=J06]BBP1[DTX0Je9:07=JDP1[Hf/0S7]c
0080Nf]k00<0Nf=J07][N`1kLg/00P1kHeX0101[Hf/0HeYS048Y<@1B<BT206=:@P80DT8i00P0DSTa
05Y2>@1JDU80LeYB07]SFP2<Ng<0HeYS06=:BP<0Je9:00<0Le9:06]BBP1cFU800P1[DTX00`1SBT80
He9:06=:@P0306=:@P0306=2<@1J@ST0Hd8a00<0Hd8a00`0HdY206]BBP1cBT80Le9:08AB@P1cDTX0
Q6=B08aJBP24He80S6=B09a[DP2<He8208AB@P0507=:>@1J@ST0Le9:0=K6gP3oool0EP3gmoL@0?oo
o`003P3ooom80?Ogm`060=K6gP2eYJd0U7]c06]SJ`24JeX0LeYB0P1kHeX207=JDP80S7=[00@0S7]c
09B4Q02<Lf/0S7]c0P2<Lf/00`2<Ng<0S7=[08acJ`0208A[FP80S7=[0P2<Ng<00`2<Lf/0S7]c08ac
J`0308acJ`0306=JH`1kHeX0Nf=J0080LeYB00H0S7]c08acJ`1kLg/0Jf=[07=JDP1kHeX207]cN`09
06]SJ`1JBUX0HdY:058iBP1B@ST0DSU:05Y2>@12<CT0BS4a0080DSTa00@0FT8i06=:@P1kHeX0S7=[
0`1[DTX00`1SBT80Je9:07=:>@0305Y2>@@0Hd8a00/0FT8i06=2<@1S@S40FT8i07=:>@1cBT80Le9:
08AB@P1cDTX0Nf=B08aJBP0208ASDP0;08aJBP2<He80S5Y:0:EcFP24He80Q59207=:>@1J@ST0LdY2
09AcJ`3Fa]H0F03gmoL@0?ooo`003P3ooom90?Ogm`0;0>ONk`2m]Kd0W8b<08acJ`1kHe80LeYB07]S
DP1cFU80Nf=J06=BBP1kHeX00`2<Lf/00`2<Ng<0S7=[09B4Q00708acJ`0308akL`2<Lf/0S7=[0080
U7]c00D0U7=[08acJ`2UQ7/0U7]c08akL`0208acJ`80LeYB00`0S7]c08acN`2<Ng<0S7]c06=JH`1k
HeX0S7]c08AcQ01[Hf/0LeYB06=:BP1[DTX206=:BP0405Y2>@1B@ST0BS4a048Y<@80BS4a00@0DSTa
06=:@P24JeX0LeYB1@1SBT801`1J@ST0Hd8a06=:@P1cBST0HdY206]BBP1cBST00`1cBT80101cDTX0
LdY208AB@P1cBT8208aJBP<0S6=B00D0YG=J08aSDP2LJe80Q6=B07=:>@0205Y2>@0408ASDP2LS9`0
knOW0?oooeP0moOg403oool000h0ooooB`3gmoL00`3>_LH0[IBU08acN`0207]SDP0;06]SJ`1kHeX0
LeYB07]SFP2<Lf<0Jf=[08akL`2<Lg/0U8B409b<S02<Lg/00P2<Ng<0102DQ8@0S7]c08akL`2<Lf<2
08akL`0408A[FP2<Lf/0S7]c09B4Q080U7]c00T0U8B40:F4N`2<Ng<0S7=k09AkL`1kJg/0S7]c08ac
N`2<Lf/00P2DQ8@02@1kJg/0LeYB08acJ`2<Ng<0Nf]k07]SFP1SFV<0Je9:058iBP0306=:BP<0FT8i
00@0DT8i06=:@P1SBT80LeYB0P1kHeX02P1cFU80Le9:06=:@P1cDTX0Je9:07=:>@1[DTX0LdY208AB
@P1kHe8207=BBP0C08aJBP1cDTX0Nf=B08ASDP2<He80Q6]J08acH`2ULeX0W7=S08acH`2ULeX0S6=B
08AB@P1S>C40HdY208aSDP2UQ8@0e/K>0?ooo`1J0?Ogma00oooo000>0?oood/0moOg00H0oooo0?O_
k`3Fa]H0[IBU09B4Q02<Lf<208A[FP80LeYB0P1kHeX208acJ`0:08acN`1kLg/0S7=[08acH`1kHeX0
S7=k09b<S02DQ8@0S7=[09AcJ`80S7]c00L0S7=[08akL`2<Ng<0S7=[09AkL`2LS8`0U7]c0080YHAk
0P2DNg<208acJ`0809AkL`2DQ8@0U8B408acN`2<Lf/0S7]c08acJ`1kHeX208acJ`0408A[FP1kHeX0
Nf=J07]SDPD0LeYB00<0Jf=[07]SDP1cFU800P1cDTX01`1cFU80Nf=B07=BBP1kHe80LdY207=BBP1k
He800P1cDTX0102<FTX0Q6]J08A[FP24JeX209acH`070:ekJ`2LLf<0U7=[09acH`2ULeX0S7=S08AB
@P0207=:>@0508ASDP2]U9@0e/KN0?Ogm`3oool0F`3gmoL@0?ooo`003P3ooomA0?Ogm`060>ONk`2L
S9`0Jf=[07=BBP1B@U80LeYB0P1[DTX00`1SFV<0Nf=J07]cN`020:fDU00;09B4Q02<Lg/0U8B409b<
S02UQ7/0U8B40:F4N`2LS8`0U8B409AkL`2<Ng<00P2<Lf/00`2<Ng<0U7]c0:F4N`0709AkL`0408ac
H`2DLf/0YHAk09b<S0<0U7]c00@0S7=[08A[FP24JeX0Q6]J0P2<Lf/03@2<He80S7=S08aSDP2<He80
U5YB08A[FP2DFU80W6]B08A[FP2<He80W6]B08A[FP2LLf<0102DLf/20:ekJ`030:f4J`2DNg<0[HA[
0080S7=S00T0[HA[07=BBP1cBT80HdY207=:@P24He80YHB40<jmaP3oool0G`3gmoL@0?ooo`003P3o
oomC0?Ogm`040=K6eP2]U:D0W8b<06]SJ`@0LeYB0P2<Lf/209b<S00309B4Q02LS8`0W8b<00<0W8b<
0P2]U9@01`2DQ8@0U7]c09AkL`2DNg<0S7=[08akL`2DQ8@0102DNg<01@2DQ8@0YHB40:f4N`2LS8`0
U8B40080U7=[0P2DNg<00`2DQ8@0U7=[09AcJ`0208acH`80Q6]J0P2<Lf<208A[FP0308acH`24JeX0
Q6]J0080Q6]J00D0S7=S09AcJ`2]Nf/0U7]c0:f4J`040;F<L`0>0:F4N`2]Q6/0]Hac0:f4J`2ULeX0
S6=B07]SDP1cDTX0Q6=B08aSDP2UQ8@0e[g60?O_k`3ooomP0?Ogma00oooo000>0?ooo`030?O_k`3g
moL0moOg0580moOg00H0imkW0;fe_@2]W;D0[Ib]08akS02<Ng<208akS00>0:fDU02eW9`0YIBU0;FL
W036]LH0]Jfm0;FLW02]U9@0]IbL0:fLY@2eW9`0YHB40:F4N`2DQ8@20:F4N`80U7]c00@0Nf=J08ak
L`2DNg<0U7]c0P2UQ7/0102UQ8@0YHAk0:F4N`2LS8`40:F4N`<0U7]c00<0U7=[0:F4N`2<Lf<00P2D
Lf/208acH`80U7=[0P2DNg<01`2]Nf/0YHAk0:F4N`2UQ7/0[HA[09AkL`2<Lf<00P24JeX208acH`@0
Le9:00H0Q59208acH`2<Lg/0c[Fm0?Ogm`3ooomR0?Ogma00oooo000>0?oooeT0moOg00@0imk_0>ON
i`3Wg^l0knOW0P3Fc]h02`3Ne^L0e/KF0>ONk`3Ne^L0a[G60;FU[@3>_KD0_KFm0:fLY@2]YKD0]IbL
0080[IBD0`2DQ8@0102UQ7/0U7]c09AkL`2<Ng<408acJ`0309AkL`2eS7<0YHB40080[Hb40`2UQ7/0
102DNg<0U7=[09AkL`2DNg<409AcJ`0609AkL`2]Nf/0U7=[09acH`2<Lf<0U7=[0P2<Lf<00`24JeX0
S6=B08A[FP0208acH`0307]SDP1cDTX0Le9:0080Le9:00D0S6=B09AcJ`3Nc]H0mno_0?ooo`1T0?Og
ma00oooo000>0?oooeh0moOg00H0mno_0>ONk`3Wg^l0knOW0?Ogm`3Fa]H20<JeaP050=k>eP2m]Kd0
imkW0<JeaP2eYJd00`2]U9@01@2eW9`0YHB409AkL`2DNg<0YHAk0080U7=[00D0S7]c08acJ`1kJg/0
Q6]J08akL`0209AkL`050:F4N`2DNg<0YHAk0:F4N`2DNg<00P2<Lf/00`2DLf/0S7=[08acJ`0209Ac
J`<0S7=S0P2DLf/01@2<Lf<0Q6]J08A[FP24JeX0Q6=B0080Q6]J00P0S5Y:08ASDP24JeX0U7]c0:fD
Y@2]W;D0e/K>0?ooofH0moOg403oool000h0ooooH@3gmoL0103_inL0imk_0>ONi`3Ne^L20=K6eP08
0=kFi`3Fc]h0knOW0>ONk`3Fa]H0]JF]0:fDU02]U:D20:fDU0040:f<Q02LS8`0YHAk09AkL`80YHAk
0P2DLf/02`2<Lf/0U7]c08akL`2<Lf/0U7]c0:F4Q02UQ7/0W8b<0:F4N`2DNg<0S7]c0080U7]c00@0
U7=[08acH`2DLf/0U7]c0P2DLf/208acH`0408A[FP1kHeX0LeYB07]SDP80Le9:00@0S7=[09B4U036
[Kd0e/KNJP3gmoL@0?ooo`003P3oool20?Ogm`030?O_k`3gmoL0moOg05d0moOg00@0mno_0>oWi`3g
moL0imk_0P3_inL0403Wg^l0mno_0?Ogm`3_inL0e/kN0=K6eP3Fa/h0c[g60;FU[@2LS9`0[IBD0:fD
Y@2eYJD0W8bL0:f<Q02DQ8@209AkL`0509AcJ`2DNg<0YHAk09AkL`2<Ng<00`2DNg<01@2LS8`0YHAk
09AkL`2DNg<0U7=[00<0S7=[00@0U7=[08acH`1kHeX0Q6=B0P1cFU8208A[FP0408acN`2]U:D0e/KN
0?O_kf`0moOg403oool000h0ooooL`3gmoL01P3Wg^l0imkW0=K6gP3Fa/h0e[g60:fL]@80]JF]00L0
]IbL0:fDU02]U9@0[Hb409B4U02UQ8@0[Hb40080S7=k0`2DQ8@02P2]U9@0W8bL0;FLW02]U:D0c[Fe
0=k>eP3Fc]h0mno_0>ONk`3gknma0?Ogma00oooo000>0?ooo`040?O_k`3gmoL0moOg0?O_k`80moOg
00<0mno_0?Ogm`3gmoL0H03gmoL00`3gknl0moOg0?O_k`0=0?Ogm`050?O_k`3Wg^l0imkW0>ONi`3N
e^L00P3>_LH01`3Fa]H0g/kF0=k>eP3Fa]h0imkW0>oWi`3Wg^l0N`3gmoL@0?ooo`003P3ooomm0?Og
m`030?ooo`3gmoL0moOg0880moOg403oool000h0ooooO@3gmoL00`3gknl0moOg0?Ogm`220?Ogma00
oooo000>0?ooool0moOg0`3gmoL@0?ooo`003P3ooooo0?Ogm`<0moOg403oool000h0oooo0`3gmoL0
0`3gknl0moOg0?Ogm`3l0?Ogma00oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo001U0?ooo`900000
D@3oool2@00006H0oooo001W0?ooo`03@000003oool0oooo0500oooo00=000000?ooo`3oool0H`3o
ool005T0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool00P3oool0
0d000000oooo0?ooo`040?ooo`03@000003oool0oooo00T0oooo0T0000030?ooo`9000000P3oool3
@00000<0oooo0T0000020?ooo`=000003@3oool3@00000070?oood000000oooo@000003ooom00000
0?ooo`04@0000080oooo0d0000020?ooo`900000H@3oool005X0oooo00=000000?ooo`3oool00`3o
ool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool01`3oool00d000000oooo
@000000@0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom000000P3oool01D000000
oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom000003`3oool02D000000oooo0?oood00
0000oooo@000003ooom000000?ooo`03@0000080oooo00I000000?ooo`3ooom000000?oood00001S
0?ooo`00FP3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool0
0d000000oooo0?ooo`090?ooo`03@000003oool0oooo00h0oooo00=000000?ooo`3oool00P3oool0
14000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool014000000oooo
0?oood00000?0?ooo`08@000003oool0oooo@000003ooom000000?oood0000030?ooo`04@000003o
ool0oooo@0000080oooo00=000000?oood0000000T00001Q0?ooo`00FP3oool2@00000<0oooo0T00
00040?ooo`=000002@3oool2@0000140oooo00=000000?ooo`3oool00`3oool2@00000<0oooo00=0
00000?ooo`3oool00P3oool2@0000080oooo1400000<0?ooo`9000000P3oool2@00000030?oood00
0000oooo0080oooo0T0000030?ooo`=0000000@0oooo@000040000100000H@3oool005X0oooo00A0
00000?ooo`3ooom000004`3oool00d000000oooo0?ooo`0@0?ooo`03@000003ooom0000000P0oooo
00=000000?ooo`3oool0SP3oool005T0oooo1D0000020?ooo`03@000003oool0oooo00h0oooo0d00
000@0?ooo`=000001`3oool2@00001T0oooo00=000000?ooo`3oool0M03oool00?l0oooo8@3oool0
0?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-14.3105, -6.40135, 0.991711, 
  0.991711}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.5.1 Monochrome sketch",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "We compute a magnitude distribution of the color characteristic vectors as \
well as an inner product distribution between the unit directional and \
characteristic vectors of Fig. 5. Further we compute both of the image data.",
    
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
vectMagG=ListDensityPlot[vectMag=vectorMag3D[sample],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->\"By vector magnitude\",
\tDisplayFunction->Identity];
innerProG=ListDensityPlot[innerPro=innerPro3D[sample],
\tPlotRange->All,Mesh->False,Frame->False,
\tPlotLabel->\"By inner product\",DisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[46]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["Figure 6 shows the monochrome images. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{vectMagG,innerProG}],
\tImageSize->{400,200},
\tPlotLabel->\"Fig.6. Monochrome images\"];\
\>", "Input",
  CellLabel->"In[48]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -74 0 ]
[.5 .48869 74 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.6) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Monochrome) show
171.000000 12.812500 moveto
(images) show
207.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -59 0 ]
[.5 1.0125 59 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(By) show
81.000000 12.812500 moveto
(vector) show
123.000000 12.812500 moveto
(magnitude) show
177.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAD2CFD7D7D7
D7DAD7DADADADADAE0E0E0DADAE0E0E0E0E0E0E0E0E0E0E0
E0DAE0E0E0E0DADADADADACFD7CFCFCFCFCFC9C0C9C9C9C0
BBBBC0B7BBB2BBBBB2B2B2B2B2B2B2B2B2B2B2B2B2B2B2AD
B2A9B2B2ADA7A9A9A7A9A8A7A9A9A9A7A7A79DA4A9A9E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0CFD7D7D7D7
D7DADADADADADAE0E0E0E0E0E0DAE0E0E0DADADAE0E0E0DA
E0E0E0DAE0DADAD7CFDADACFCFCFCFCFCFCFC9C9C9C9C0C0
BBBABBBBC0B2B2B2B2B2B7B2B2B2ADB2B2B2B2B7B2ADADB2
B2B2ADADADA9ADA9A9ADA9A9A9A7A9A9A9A7A4A79DC6F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F1F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CFD2D7D7D7
D7D7DAD7DAD7DAE0DAE0E0DADADAE0E0E0E0E0DADAE0E0DA
E0DAE0E0DADADADADADACFCFCFCFC9C9C9C0C0C9C0C0C0C0
C0BBBBBBB2B2B2B2B2B2B2B2B2B2ADB2B2B2B2B2B2B2ADB2
B2ADADA9A9ADA9ADA9A7A9A7A9A9A7A7A9A79DA9A9DAF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0CFD7D7D7DA
D7D7DADAD7DAE0E0E0E0DADADAE0E0E0DAE0DADAE0DADAE0
DADADADADAD7CFCFCFCFCFCFC9C9C0C9C0C0C0C0C0BABBB7
BBB7B7B7B7B2B2B2ADB2ADADB2B2B2B2B2B2B2B2B2A9B2AD
B2ADADADA9A9ADA9A9A9ADA9A7A9A7A7A7A4A7A9B7EBF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F1F7F7F7
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CFD7D7D7D7
DAD7D7DAD7DAE0E0E0E0DADADAE0E0E0E0DADAE0E0E0DADA
D7DADADACFCFCFCFCFCFC9C9C9BAC9C0C0BAC0C0B7C0B8B7
B2B2B2B2B2B2A9B2A9B2ADB2B2B2B2B2B2B2ADB2B2B2B2B2
ADB2A9B2ADA9ADA9A9A9ADA9A9A9A9A7A7A79DA9C4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0CFD7D7D7D7
D7D7DADADADADADADADADADADADAE0DADADADAE0DADADAD7
DADACFCFCFCFCFC9C9C9C9C9C9C6C6BAC0BBC0B7B8B7B7B2
B2B2B2B2B2B2B2B2A9ADADA9ADB2ADB2ADA9ADB2B2B2B2A9
ADB2ADADA9ADA7A9A9ADA9A9A7A9A9A9A9A7A7B2DAF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F1F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0CFD2D7D7D7
D7D7DADADADAE0DADADADADAE0DADADADADADADADADAD7DA
CFCFD7D7CFCFCFCFC2C9C2C6C0BAC0C0BAC0B7B7B7BAB7B7
B7A9B2B2B2B2B2B2B2B2A9A9ADA9A9B2A9ADADA9B2ADADB2
A9A9ADADA9A8A9A8ADA9A9A7A9A7A9A9A7A9A4B7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F1F7F7F7F7F7F1F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F1F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CFCFD7D7DA
D7DAD7DADADAE0DADADAE0DAE0E0DADADADADADADADACFDA
CFD7C8CFCFCFC2C9C6C6C6C0C0C0C0B7B8B7B2B7B2B2B7B7
B7B7BAA9A9ADA9B2ADA9ADA9A9ADADA9ADA9B2ADB2A9ADB2
B2ADA9ADA9ADA9ADA9ADADA9A9ADA7A9A9A7A9C4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F1F7F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACFCFD7D7D7
D7D7D7DADAD7DADADADADADAE0DAD7DADADADACFDACFC8D7
CFCFC4CFC2C6C0C0C0B7B8C0B8B2B7AAB2AAB7AAB7B2B7B7
B7B7B7A6B7A9BAA9B2A9A9A9A9A9A9A9A9A9A9B2A9ADADB2
A9ADADADA7ADB2B2A9ADA9A9A9ADA9A9A9A7B7E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAD2D7D7D7D7
D7D7DADADADADAE0DADADADADADAD7DADAD7CFDACFDACFCF
CCCFCFCCC6C6C6C6C6C6C0B8B8C0B8B8B2B2AAB2AAB2AAB7
B2B7AAB7B7B7A9BAB7A9ADA9A9A9A9A9A9A9ADA9ADA9A9A9
B2B2B2A9ADADA9A9ADA9A9A9A9A7A9A9A9A9C6F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F1F7F7F7F1F7F7F1F7F7F7F7F7F7F1F7
F7F1F7F1F7F7F1F7F7F7F1F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACFD7D7D7D7
DAD7D7D7DAE0E0DADAD7DADADADADACFDACFDACFDAD7D7D7
C8CFCCCFCCCCCCCFC6CFC6C1C4C1BBC0B8B8B8AAAAB2AAB2
AAB2B2B2B2AAB7A9A6B7ADB7A9A9A9A9A9A9A9A9A9A9B2AD
ADADADB2A9A9ADA9A9A9A9A7A9A7A9A9A9A7C4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACFD7D7D7D7
DADAD7D7DADADADADADADADAD7DAD7CFDADADACFD7C8C8CF
CCD7CFD7CCCFCCCFCCCCCFCCC6C4C4C1C1BBB8B2AAB2B6AA
B2B2C0B8B7B8AAAAADA9A6B7BAB7A9A9A9A9A9A9A9A9A9B2
A9A9ADADADA9ADADA9A9ADA9A9A9A9A9A9A9DAF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1DACFD2D7D7D7
DAD7D7DADAD7DAD7DADADADADAD7DADADACFCFCFD7CFCFCF
DAD7D7CFDADAD7D7CFD7CCC6CCC9C6C1BBBBB8B8B6B2AAB2
B8B8C1B8B8B8B7B2AAAAA9A9A9B2BAB7A9A7A9A9A9A9A7A9
A9A9A8A9A9ADA9A9B2ADA9A9A9A9A9B2A9B2E8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1CFCFD7D7D7D7
D7D7D7DADADAD7DAD7DAD7DACFD7DACFCFCFDACFC8D7DAD7
CFDAD7DADAD7D7D7DAD7CCCFCFCFC6C4C4C4C1BBB6B6B6B6
B8C1C0C0C0B8B8B8B2AAAAAAA6A6A9B2B7A9A9A9B2A9A9A9
B2ADA7ADB2A9A9ADA9A9A9A7A9A9A9A9A9BAE8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D7CFD7D7DAD7
DAD7DADADADADAD7CFDAD7D7DADADACFCFCFCFDACFDADAD7
DADADADADADADADACFCCD7CFCCCDC6C4C6C6C4C1C0B8C0B8
B8BBC1C1C6C1C1C0B8B6AAB2ADAAA6A6A6BAA9A9A9B2B2A9
A9A9A9A9ADADA9A9ADA9A7A9A9A9A9A9A9C6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F1F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCFCFD7D7D7D7
D7D7DAD7DAD7D7D7CFDADAD7CFDADACFCFCFE0DAE0DAE0DA
E0DAE0DADADAD7DAD7DAD7D7D7CFC4C6C4C9C9C9C6BBC4C4
C0BBB8C1BBC1C4BBC1BBB8AAADADB2AAB2ADA9BAB7B2A9A9
A9A9A9ADA9ADA7ADA9ADA9ADA7A9A9A9B2D3FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCFD2D7CFD7D7
D7DADAD7D7DAD7CFDADACFCFDACFDACFDADADADADADADADA
E0E0E0DAE0DADADADADADAD7CFCCC9C9C6C4C9C6C4C4C0C6
C4C1C1C0B8C1C1BBC4B8B8B6AAAAB6B2AAA6A9B2BABAB2B2
A9A9B2A9ADA9ADA9ADA9A9A9A9A7A9B2B7E8F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCFD2D7D7D7DA
D7D7D7DADADACFDACFDACFDAD7DAD7DAD7DAE0E0DAE0E0DA
E0E0E0E0E0DADAD7DADADADAD7D2CCC9C9C6C6C9C6C4C1C4
C6C4BBC1C0C4C1C1BBC1B6B6B6B2AAB2AAADA6A6A9BABAB2
A9A9A9ADA9B2A9B2A9ADA9A7A9B2A9A9B6E8F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F1F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CFD7D7D7D7D7
D7DAD7D7CFCFDADACFD7DAD7DAD7DADADADADAE0E0E0E0DA
E0E0E0E0DADADADAE0DAE0DAE0DACFCCCDCFCDC6CFC6C6C4
C6C6C6C4C1C4C1BBC1BBB8B6B8B8AAB6AAAAB2AAB2A9B7BA
B7A9A9A9B2A9B2ADADA9B2ADA9A9B2B2CCF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACFCFD7D7D7DA
D7DAD7DACFDACFCFD7D7D7DAD7DADADAE0E0E0E0E0E0DAE0
E0E0DAE0DADAE0E0E0E0E0E0DADAD7D7CFCCCFCFCDC6C9C6
C4CFC6C6C1C4C1BBC4BBB8B8B6B6B2AAB2ADB2A6AAA9B2AD
B7A9A9B2ADB2B2A9A9A9B2A9A9A9B2A9C4F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAD2D7D7D7D7D7
D7CFCFCFDADACFD7D7DADAD7DADADADADADAE0E0E0E0E0E0
DAE0DAE0DADAE0E0E0E0E0E0DADADAD7D7CCD7CCC9CFCFCD
C6C9C4C4C4C4C1C1BBBBB8B6B8B8B6AAB2ADAAADADA9B2A9
BAB7B2ADA9A9ADB2A9ADA9A9A9A9B2B2DAF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACFD7D7D7D7D7
D7CFDADACFDAD7D7D7DADADADADADADAE0DAE0E0E0E8E0E0
DADAE0E0DAE0E0E0E0E0E0E0E0D7DADAD7D7CFD7CFCCCFCF
CCC9C6C4C9C6C4BBBBB8BBB8B6B6B6B6B1AAADAAAAADADA6
B7B2ADB2ADA9A9B2B2A9ADA9B2A9B2B2D3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F1F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAD7D7CFD7CFD7CF
CFCFCFDADAD7DAD7DAD7DAE0DADAD7E0E0E0E0E0E0E0E0E0
DADADADAE0E0E0E8E0E0E0E0DADADAD7DAD7D7D7CFCFCCCF
CCC9C4C4C4C1BBC1C1B6B6B8B6B6B8B6B6B6AAADADADAAAD
A9B7A9B7B7B2A9A9A9ADB2A9A9A9B2B7E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8BACFD2D7D7D7D7DA
CFDAD7DADADAD7DADADADADADADADAE0DAE0E0E0E0E0E0E0
DADAD7E0DAE0E0E0E0E0E0E0E0DADADADAD7DAD7CCD7CFCD
CFC9C6C6C4C1C0C1C4B8B6B8B6B6B6B6B2ADAAADB2AAADA9
B2B7B7A9ADBAB7ADA9ADA9B2A9A9B2BAF1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F1F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2B0BACFCFD7D7DACFDA
DAD7DADAD7DADADAD7DADADADAD7DADAE0DAE0DADAE0E0DA
E0D7DADAE0E0E0E0E0DAE0E0DAE0E0E0DADAD7D7D2CCCFC9
CDC9C9C4C4C4C4BBC4BBB8BBB8B6ADB8B6B6B2B1ADADADAA
A9A9B7A4A9B7BAADADA9B2A9A9B2B2B6E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E5AD87C0D7D7D7DADACFCF
D7DADADADADADADADADADADADADAE0DAE0DAE0DADAE0E0DA
DADADADAE0E0E0E0E0E0DADADAD7DADADADAD7CFD7D2CCC9
C9C4CFC9C4BBC4BBC1B8B8B8B7B6B2B6B2B6B2ADADAAADAD
A4B2B2B2B2A9A9B7A9A9A9B2B2A9B2C6F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7A46373C9CFD7DADACFDAD7
DADADAE0DADADADADADADADADADADAE0DAE0E0E0DAE0DADA
DADADADADAE0E0E0DAE0E0E0D7DADADADAD7DAD7D7CFD7C9
CDC6C9C4C4C4C1BBC1BBB8B8B6B8B6B6B6B6B6B6B2B2ADAD
A9A9B2B2A9A9A9B7B7A9B2B2B2A9B2CFF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7CD4F3B83C9CFDADACFD7DAD7
DADADADADAE0DADADADADAE0DADAE0E0DAE0E0DADAE0DADA
DADADADADAE0E0DADADADADAD7DADADADADADAD7CFCCCFC9
C9C6C9C4C4C1C0C1C0BBBBB6B8B6B2ADB2B6B2B2B2ADADAD
A4A9ADB2B2B2A9A9BABAA9B2B2B2ADC8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7DC6C2E438BCFD7DACFD7D7DADA
DADAE0DADADADAE0DADADADADAE0DADAE0DADADADAE0DADA
D7DAD7DAE0DADADADADAD7DADADADADAD7DACFD7D7CFCDC9
C6C9C4C9C4C0C4C0C1C0BBBBB9B2B6B2ADBBB6B1B2ADB2AD
ADADA9B2A9A9B2A9B7B6BAB2B2B2B2DAF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFF187302E3B72D7C8D7DADADAD7DA
DADADADADADADADADAE0DADADADAE0DAE0DADADADADAE0D7
D7DADADADAE0DADADADADACFDACFD7D7D2D7D7CFD2D2C9C9
C9C9C4C6C9C4C4C4C0C4BBB8BBB8B2B6B2BBB2ADB6ADB2AD
ADADA9ADA9A9A9A9A9B7BABAB2B2A9DAF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F1F7F1
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F79E4B3B2C1E62BADAD7DADADAD7DADA
DADAE0DADADAE0DAE0DAE0DADADADAE0DADAE0DADADADADA
DADADAE0E0E0E0DADADAD7CFCFD2C9CDCFC9CFC6C9C9C9C4
C4BBC4C4C0C4BBBBC4BBBBB8B6B2B6B6B6B7B8B2ADB2ADB2
A8A8A9ADA9A7A9A9B2A9A9B7C6BAB2E8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7FF4B48431E30B6DAD7DAD7DAD7DADADA
DADAE0DADADAE0E0DAE0DADADADADADADAE0DADADADADAE0
E0E0DADAE0DAE0DADADADAD7CDC9C9C9C4C4C4C1C4C4C4C4
C4C4BBBBBBC4BBC4BBBBC0B6B2B6B2B2ADB9B2B8B6ADADA8
A7A9A8A9ADA7A9ADA9B2A9B2BAC2B7E8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F1F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F1F7F1F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7FFCA4B432C30B2DADADADAD7DAD7DADADA
E0E0E0DADAE0DADAE0DAE0DADAE0DADADADADADAE0DAE0DA
E0E0DAE0DADADADAD7D7D7D7CCC9C9C4C4C4C4BBBBC4C4C4
C4C4C4C4C4C0C4C0C0BBBBB8B2B6B6B2B6B8B2B6B2ADADAD
A7ADA7ADA9ADA7A9A9A9A9A9A9BAC4EBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E8774B3B3BADDAD7D7DAD7DADADADAE0DA
E0DADADAE0DADADADAE0DADADADADADADADADADADADADAE0
E0E0E0E0E0DADADAD7DADACFCFC9C9C4C9C4C9C4C0C1C4C4
C0BBBBBBBBC4BBBBBBBBB7B6B9B2B2B6B2B7B6B2B2ADADA8
A9A7A8A9A7A7A9ADA9A9A9A9A9B7BAF1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F1F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1953948489DDADACFDADAD7DADADADADADA
DAE0E0E0DADADADADADADADADAD7DADADADADADADADAE0E0
E0E0E0DAE0DADADADAD7D7D7CFC4C4C4C9C4C4C4C4C4BBBB
C4C4C0C0C4BBBBBBBBB6B6B6B2ADB9B2B6B9B2B2B1ADADA9
ADA7A9A9A7A9A7A9A7ADB2A9B2B2B7EBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7FFB54B394B95DADACFDAD7DADADADAE0DADADA
DAE0E0DAE0DADADADADADADADAD7DAE0DADADADADADAE0E0
E0E0E0E0DAD7DAD7D7D7CCC9C4C4C4C4C4BBC4C4C4BBC4BB
C0BBC0BBBBBBBBBBBBB2B2ADB6B2ADB2B2ADB6B2ADB2ADAD
A9A7A7ADA7A7ADA7A9ADA9A9B2A9B7C4F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1F7F7F1F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFE25D393B83DADACFD7D7D7D7DADADADAE0DAE0
DADADADADADADADADADADADADAD7DADADADADADADAE0E0E0
E0E0E0E0DADAD7CCCFCFCDC9C6C4C4C4C4C4BBBBBBBBBBC4
BBBBBBBBBBBBB9B2B9B8B6B2B2ADB2ADADADADB9ADADADAD
ADA8A7A9ADA7A9A9A9A9ADA9B2A9B2BADAF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFB6433B315AE0DADAD7DADADADADAE0E0DADAE0DA
E0DADAE0DAD7D7DADADAD7D7DADADADADADAE0DADAE0DAE0
DADADADAD7DAD7CFCCCFCCC6C6C1C1B8B8B8B8B8B8B6B6B6
B6B6B6B6B2B6B2B6B2B1ADADB2ADADADADA9ADADB2ADADA7
ADADADA9A9ADA7A9A9A9ADB2A9A9B2B2B7C4E8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F1F7F7F7F7F7F7F1F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E8773B43489CDACFD7DAD7DAD7DADADADADAE0DADA
DADADADADADAD7D7D7D7D7D7DADAD7D7DADADADAE0E0E0DA
DADADADADACFD7DACFCCCCCCC1C1B8B8B8B8B8B8B8C1B6B8
B8B8B6AAB6B2B6B2ADB2ADADADADADADADADA9ADADADADA7
ADA7A7ADADA9A8ADA8A9ADA9B2ADADB7A9B7DAF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFB53943488DDADAD7DADADADADADADADADADADAE0E0
DADADADADADAD7D7D7D7D7DAD7D7DAD7DADADADADADAE0DA
DADADADADAE0CCCCCCCCB0B0B0B0AAAAA2A8A2AAB0B6AAB0
B6B6B6B6B1B2ADADADADADA9ADADADA9A9ADA7ADADADADAD
A9A7ADA9ADA9A9A9A8A7A9ADA9A9ADA9B7B7C6E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7773B436CDAE0DADAD7DADAD7DAD7DADADADAE0E0DA
DADADADADADAD7D7D7D7D7D7DAD7DADADADAE0DAE0E0DADA
DADAE0DADACCCCCDB0B0CCB8B0B0A2A2A2A2A2A2A2B0A2A2
A29DAAB1B6B6B2AAADA8ADADADA8A9ADA8A7A4A7A7B2ADAD
ADADA9ADADADADADA7A7ADA9A8B2A9B2A9B7A9CFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F1F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7E55A314FC6DACFD7DADADADADADADADAD7DAE0E0DADA
DADADADAD7DAD2D7D7D7D7D7D7D7DADADADAE0DAE0DADAE0
DADADAE0DACCCCCCC4CDB0B0B0A2A2A2A297A2A2A8A2A2A2
97A2A29D9DAAAAB1AAADADA9ADADA8A8A9A4A7A7ADADADAD
A9ADA9ADADADA9A9A9A8A9ADA9ADADB2B2B2B7BAD3F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7B94B3B8DE0DADADAD7D7DADADADAD7DADADADAE0DADA
DADADADADAD7D7CCCFD2D7D2D7D7DADADAE0DADADADADADA
E0DAE0CCCCCCCCCCCCCCB0B0B0A2A2A2A2A2A2A2B0A2A2A2
A297A2A2A29DA29BAAAAADADA9A9A9A7A7A0A7A7A9A7ADB2
ADADADADADADADADA7ADADA7A9ADA9B2A9B2B7A9C6E8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7773163CFE0CFD7DADAD7DAD7DADAD7D7D7E0DADADADA
DAD7D7D7D7D2DAD2D2D7D7D7CCD7DADADADADAE0DAE0DAE0
DACCCCCCCCCCE8CCCCCDCDC1B0A2A0A2A2A2A2AAB0A2A2A2
A2A297A2A2A297A29DAAAAADADADADADA49BA4A7A8A9ADAD
A9B2ADADADB2B2ADADA7ADADA9A9ADB2B2A9B2B7B7C8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C8953B83DAE0D7CFDAD7DADADADADAD7D7DAE0DADADADADA
DAD7D7D7D2CFD2CFD2D7D7CCD2D7DADADADADADADADACCCC
CCCCD3CCCCCCCCB0B0A2A2A0A09C9C8F8F978FA2A2A29CA0
97A097A0A2A2A2A29D93A2A6A4AAA7ADA7A4A7A0A4A8ADAD
ADADADB2ADADB2ADADADADA7A8ADA9ADB2A9ADB2B2B7C2F7
F7E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFD3
808930BAE0CFD7D7D7DAD7DAD7D7DAD7D7D7DADADADADADA
DADAD7D7D2C9C9D2D2D7D2C9D7D7DADADAE0E0DADACCCCCC
CCE0CCE0CCCDB8AAA0A09C8F8F8F8F8F8F9C9C9C9CA09C9C
8F8F979797979797A2A29DA8A8AAA9A8A9A0A4A4A7A7ADAD
ADADB2B2B2ADB2ADB1ADADA7A8A9ADA9B2ADB2B2A9B7BAF1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F189
5D546CE0CFD7D7D7D7DADAD7D7D7D2D7DADADADADADADADA
DAD7D7D7D2CDC4CFD2CDCDC9D2D7DADAE0E0DADACCCCCCCC
CCCCCCCCC1AAAAA08F8F8F878F8F8F8F8F8F8F8F8F8F8F8F
8F8F8F8F8F979797A293939D9BA4AAA9A8A4A4A0A4A7A7A9
A8ADADADADADB2ADADB2ADA7ADA9A9ADA9ADADA9B2A9B7E2
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB66C
5D2CCFDAD7D7DAD7DAD7D7D7D7D7D2D2D7DADADADADADADA
DAD7D7CCD2C9C4C9D2C9CDC9CDD7DAE0E0DACCCCCCCCCCCD
CCC1B8B0B0A09C97979BA89B879DA29797937F938F8F878F
8F878F878F8F8F97979D9D939D9DA6AAA7A0A4A09DA0A7AD
ADADADADB2ADADB6ADADADADA7A8B2A9B2ADA9B2B2B2B7DA
E5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC8954
392CE0DACFD7D7D7D7DAD7D7D7D7D7D2D7E0DADADADADADA
D7D7D7CFC9C4C4C4C4C4C4C4D7D7DAE0DADACCCDCDCDCDB8
B0B0AAA2A0979D9BAABAB8B881B9CCBAB7AA7DB8B8A8938F
87877F87878F8F8F979793939D9D9DAAA9A4A79BA0A4A7A8
A7A7ADADADADB1B6ADADB2ADADA9A9B2ADB2ADADB2B2B2BA
E8E2F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFE2896F43
205EDACCD7D7D7DAD7D7D7D7CFD2D2D2DADADADADADADADA
D7D2D7D2CDC4C4C4BBC4C4CFD7E0DAE0CCCCCDC1C1B8B0AA
A2A08F93A29BB9DAC4DAC8C4A6D3C4CCB9BA97B9B9BABA97
6C8F8A877F8F878F8F939393939D9D9BA4A4A09BA0A4A7A8
A8ADA8B2B6B2B2B2B2B6B2ADA9ADADADB2B2ADADB2B2A9B2
C2E2E8E5F1E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F1F7F7F1F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B6744B2C
308DDAD7D7D7D7DADADAD7D7D7CDCDD2DADAE0DADADAE0DA
D2D2D2C9C9C4B9B9B9B9C4D2DAE0DACCCDC1B0B6B6B0A09C
877F6C8FAD93B8C8C8DAC8B9B9CAB9B9C6B9A4C4C4CCB99B
749AA68A6C5B7F878F878F9393939D9D9DA7A4A7A4A0A7A7
A8A7ADADB2B9B9B2B2B2ADADA8A9ADB2ADB2ADA9B2B2A9B2
B7E2E5F1E5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E88974482C
4BB6CFD7D7D7D7D7DADAD7D7D2CDC9D2DAE0DAE0DADADADA
D7CCC9CDC4C4B9B9B1B1C4D7E0E0CCB8B8B0B0B0B0A07474
7F8787878FAA97979AA09A93A4A6A9ADADBAA6B9C2B9C2A6
8AA6AD98815E5E8187878F93939D939D9BA4A4A09BA0A4A7
A8ADADB2B2ADB2B9BBB9B2ADA8ADADB2B2B2ADB2B2B2B2B7
B7C8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5B59E74392C
9DDAD7D7D7D7DAD7DADAD7D2C9CDC4C9E0DADADADAD7D7DA
CDC9CDC4B9B1A8A1A8C4D7DACCB6A2AAA2A09081432B93CF
B8908FAAAAAA9797C1E8EBF1E8DADAB89C8FAA9D978F8981
88A6A4A49A8070796C647F87878997939B9DA4A4A09DA0A7
A8ADADB2B2BBBBB9B9B9B9B2ADADADB2B2B2ADA9ADADB2B2
B2C6C8DCE8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CA89A75D204B
CCDAD7D7D7DAD7DAD7D7D7CDCDCDCDCFDADADADADADADADA
C9CDC4BBB1B1A8A8ADC9DACDB197978163899BB7C493CFE8
E8C4C6E0E0CCB6A2E8F1F1EBE8E8DAE8C8CFD3DAE0C8C69D
93818A9C9A86797975635E747F7F8F81939DA4A0A49DA7A8
A9ADADB2B9BBC4BBBBB9B9B2ADADADB2B2ADB2B2ADADA9B2
B2ADCFD3DCC4E8F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A48089392C8B
DAD7D7D7DADAD7D7D7D2D2CDC4C4C4D7DADADADADAE0DAD7
CDC4BBB1B1A8A1A0B1C9C1978F87561864B7C6E8E0D2E8E8
E8E8F1F1F1F1E8C4EBF1F1F1E8E8E0E8CFDADAE8DADADADA
C8A26C817D70728B805B485E747F818F8F9DA8A4A09DA0A7
A8ADADB9BBBBC0C4BBBBB9B9ADADB2B2A9B2B2ADB2A9B2B2
B2B7C2EBF7DCCDD3E2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79574542A43BA
DAD7D7DAD7DADAD2D7D7CDCDC4CDCDDADADADAE0DADADAD7
C9C4B9B1A8A195A8ADB68F7F6C56505BB7CFDAE8E0DAE8E8
E8EBEBEBF1F1E8E0EBF1F1F1E8E8E8E0CFDAE8DADADADADA
DAB77F897F6C70808043485556747F7F89979BA4A4A0A4A0
A9ADADB2B9BBBBC4C4B9B9B2ADADB2ADB2B2ADADADB2B2B2
B2B7C6DCF1F1F7CDD3F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F1F7F7F1F7F7F1F7F7F7F1F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77448432C55DA
CFD7D7D7DADAD7D7D7D7D2CDC4C4D7DADADADADADADADAD7
CDC4B1B1A195909D9A876C56494B638AC4DAE0E0E8E8E8E8
E8E8EBF1F1E8E8E0EBF1F1EBE8E8E8DACFDAEBE8E8E8DADA
DABAC0C4AD9B6C64614B2E394256747481979AA4A7A4A0A7
A8ADADB1BBB9C4C4BBC4BBB9B9ADADB2ADADB2A9ADA9B2B2
B2B2BACFDCF1F1F1E8E5F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E8F7E8F7E8F1F1F7F7F7F7F7F7E56F36312C6CE0
D7CFDAD7D7D7D7D7D7D2C9CDCDC9D7DADADADADADADADAD7
C4B9B1A8A19095896C5E49433D5B75B7DAD7E8E8E8E0E8E8
DAE8E8EBF1E8DADAE8F1F1F1E8E8E0CFC4DAEBDAE8DAE8DA
DAC9C8DADADAAD5B564B363D201B566C7F81939AA4A4A0A4
A7ADADB2B9C4BBC4C4BBC4B9ADADADADB2B2B2ADADADB2B2
B2B2B7C2DACDF1E5F1F1E5F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7E8F7F7F7F1F7F1F7E5E5F1F7F1F7F7CD804839309DE0
D7D7DAD7DADAD7DAD7D2CDCDC4D2D7D7DADADAE0E0DAD7D7
BBB9B1A1958F955E5649433D40637DB8BBCFE8E8DAE0EBE8
D7E8E8EBF1E8DAD7E8F1F1F1E8E8DACDB8DAEBE8E8E8DADA
DAC6C8DAC8DADA9A647480241B001B566C817F979DA4A4A0
A4ADADB2B9BBC4C4C4C4BBBBB9B2B2B2A9B2B2A9ADADB2A9
ADB2B7BABB9EC4CACDDCF1E5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5D3955D312C6CDAD7
DADADADAD7D2D7D7D2C9CDCDCFD2C9CDDADADADAE0DAD2CD
B1A1A8A1909599495E5E4B43365E9A97B1CCB6AACDE0E0CD
CDD7E8E8E8D7C1C6D7EBEBEBE0DACDC1B8B6CFDAE8DADADA
C0ADDADADAC8DAC4BAB7CF8B50804F0418647474899DADA0
A7ADADB9BBC4C4C9C4C4C4BBB9B6B9B2B2ADA9A9ADA9ADAD
B2B2B2C0C29E4F80A7C4D3E2E8F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFDC743B2A2C98DACF
CFD7D7D7D7D7D7D7D7CDC9CDD7CDC4C4DADADAE0DADAD7CD
B190A89A8F959D74746C5E49436CA097AAB1A1AAC4D7D7CC
C1CDE0E8E8CDB6CCD7DAE8E0D7CDB6B0B8C1C4D7DADADADA
B6A0CFC8DAD7CFC9A9BABAB79CA99C5043565E6C8197A4A4
A4A8ADB2B9C4C4C9C9C4C0C4BBB2ADB2B2B2ADA9A8ADADB2
ADB2B2B7C2B695BBBBBBC4D3DCF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F1F7F7F1F7F1F7
F7F1F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7D39E48202C3BBADACC
D7CCDAD7D7D7D7CDCDCDC4D2CFCDC4CDDADADADADAD7D7C4
A190A89A909AADA8A297895E566C9393A1A2A1AAB1BBD7CC
B1B6D7D7D7B6B8CCCCCFCFCCB1AAA0A0AAB0B8C4C9CFCFC0
A197BBD7D7CFCFB2A9BABAB29CA9B2806C40565E6C8F9BA7
A0ADADADBBC0C4C9C4C4C4BBBBB9B2ADA9ADA7ADA7A9ADAD
ADB2B7B7BAC8CDD3C8CAC4BBC1E5F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7DCC4803B1B151B4ACFC8CC
D7D7D7D7D7D7D7D2C9C4C4D7D2C4C4C4DADADADADADACFC4
AA8795A8A1A7B6C0B8B8B6B0978F8F97A0A0A0A0A1AAB8AA
AA9CB1B6B1A0B1B8C1CCCCB88F8F978F97A0AAB1B1B6B6A8
8F89B1CFCFCFBBA0B7BABAB2A9AD9C8B754B3D495E74979D
A4A8ADADBBC4C4C9C9C4C4BBBBB9ADB2ADA9A9A7A4A8ADAD
ADB2B7B7BAC4DCE2CDCAC1CACACDE5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E5CD9E5439362A131375CFD7CF
D7D7DAD7DAD2CFCDCDC4CDD2C9C4B9CDDADADADADAD7D2C4
A88795ADADB6BBCCCFCCCFC6C1C1B8B0B8B8B0B0B0A2A2A0
A2A297A2A2A2A2A2A2A8A2A297A29797938F8F979AA0A197
908F95C0C9C0AD95B2B7C9B2A9B2B2988143363D445E819A
A0A9A8ADB9C0C4C4C4C4C4BBB9B6B9B2A9A7A8A7A4A7ADAD
B2B2B7B7B7C4E5E5E5E5C1C1D3CDE8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1CD6C43201B2C2C1B209AE0DACF
D7D7D7DAD7D7CDC4CDC4C9CCCDC4B6CFD7D7DADAD7DACCCD
B18990ADBBC0C1CFCFD7DADAD7D7D7D7CCCCC6C6C1C1C1B8
B8B0C1C1B8B0B8B0B0B0B0B8AAA2A8A29797978F8F878989
8F8F8FADB7AD95899AB7C9A99BA9A98B80432B3636496490
9DA8A7ADB9C4C4C4C9C4C4C4B9B9B2ADADA8A7A7A9A4A7AD
B2A9B2B7B7C6F7F7F1F1D3CDCDE8DCE5F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7892A201318202C202CB7DACFD7
DAD7DAD7D2D2CDCDC4C9CCC9C4BBBBD2D7DAD7D7CFD7D2C9
B19087ADC0C9C9D2D7DADADADADAE0DADADADADAD7CCCCCC
CCC6CCCCCCC1C1B0C6B0B0B0B0B0B0B0A2A2A29393897F81
8181899AA49A818195B2BAA78FA4A67981432B1F2B364B6C
9DA4ADADB1BBC4C4C4C9C4C4B9B9B2ADB2A9A7A8A7A7A7AD
A9ADB2B7B7C6C4E8F7F7DCE5E8D3CDE8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E2E2CD312004132C392C1E75DADACCD7
D7D7D7D7D7D7C9CDC9CFCCC9C9C4C9D2D7D7DAD7D7CFCDC4
B6AA9090B6C4C6DAE0DADAE0E0DAE0E0DAE0E0DADADAE0E0
E0E0E0E0E0C8CCD7CCC8CCCCC6C6C6C6C1B8B8B0A2A2979D
A29393938F8181818195A09581747D6C5E43171F364B504B
64A0A4A4B6B9C4C4C4C9C4C4BBB9ADADADA9A9A0A4A4A7A9
ADB2ADB2B7BA845A9EC8DCE8E2DCD3E2E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E2E2B62020202030372E2483DAD7DACF
D7D7D7D7D7D2CDC9C9CCCFD2C9CFD2CFD7D7D7CFD7CCC4C4
B1B1A190ADC0CFD7DAE0DAE0DAE0DADADADADADADADAE0E0
E0E0DAE0DADAE0DADAD7D7CDD2D2CDC4C9CCC9B6B6B0AAA2
A29DA2A293978F8F8F8F9788816C6C6C5E402B2B424B4B49
4B9DA0A0ADB9BBC4C4CFC4BBB9B6B2B2ADADA7A4A4A0A7AD
ADB2B2B2B7C6954B77C8DCE5E5F7E5E5E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7D3B5891B13302C30201B2E9CDAD7CFD7
D7DACCD7D2D2CFC9CCCCCFCCCFCCCFD2D7D7CCD7CCCFC9C4
B6B1A89595B9C6D7DADAE0E0E0E0DADADADAE0DADADADADA
E0E0E0DADADADAE0D7C9D2C9C4CDC4CDC4CDC9C4B9BBBBB6
B6B0AAA8A8A29D9DA29A93938F8F8181746C565B56646C6C
5E959DA7ADB9C4C4C4C9C4C4B9B9B2B2ADA9A7A0A4A4A4A9
ADB2ADB2B2BAA45A4877E8F7F1F7E8F7E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7DC89741320373B39201B3BC6DACFD7CC
D7CFD7D7CFD2C9CCCFD7CFD7CFD7CCCCD7D7D7CFD7D7CCC6
B6B1AAA190A8BBD7DADADADADADADADADADAE0DADADAE0DA
DADADAE0D7DADAD7D7CDC9CDC4C4C4C4C4C4C4C4C4C4C4B6
B8B6B6B1AAAAA8A8A8A8A89D9D9D9B9D9DA09A8F908F817D
818F9BA4ADB9C4B9C4C9C4BBC4B9ADADA9A8A7A4A0A0A0AD
ADA9B2B2B2BAAD4F4F4A89E8FFE8F7F7E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E25D39396C87A6937D435DCFDAD7D7D7
D7D7D7D7D2CCCFCCD7CCD7CFD7D7CFD7CFD7D7D7CFCDCFC4
B6B1B1A8A1A1BBC9CFDADADADAE0DAE0DADAE0DADADADADA
E0DADADAE0DADADAD7CFCDC9C4C4C4C4BBC4C4BBC4C4BBB9
B6B2B1B2ADADA8A8A4A8A8A8A8A4AAA8A49B9D9A9A939593
908895A0A8B9C0B9C4C9C4BBBBB9ADADA9A9ADA7A7A4A0A7
A8B2B2A9B2BAB07474845E9EF7F7E8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7DC5D2CB7CCD7D7C4BBA18BDADAC8D7D7
CFD7D7D2CFD2D7CFCCD7D7D2D2D7D7CFD7D7D7D7CCCFCDCD
BBB6B1B1A195A8C6C9D7DAD7DADADAE0E0E0DAE0DADADAE0
DADADADAE0DADAD7D7D7CDC4C4C4C4C4C4C4C9C4C4C4BBBB
B6B6ADADA4A7ADA8ADA4A4A4A8A4A7A4A4A4A8A4A49D9B99
9B9799A0A0B9C4B9C4C4C4C4BBB9ADADA7A7A8A4A4A7A4A8
ADADADB2A9B7B68080959E95C4F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1DC545EDAD7D7CFCCC4BBC4DACFCFCFDA
D7CCD7CFD2CCCFCCD7CCD7C9CCDADAD7D7DAD7CCD7D7CFC9
BBB6B1B1A8A1A1C0C9CCCFDADADAE0DAE0DAE0DADADADADA
DAE0E0E0E0E0DAD7CCD2C4C4C4C4B9BBC4C4C4C4BBBBBBB6
B6B2ADA8A7ADA9A8A4A0A7A6A7A4A4A4A4A4A7A7A4A0A4A0
9BA0A4A7A0B1C0B9BBC9C4C4B9ADADADADA7A7A4A7A4A0A7
ADADB2A9B2B2AD545DA7C1C4C4F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E2B663B7D7D7D7D7D7CCC6C2DAD7D7D7D7
D7CFCCCCCCCFD7D7D7D7D7CCD7D7D7D7D7D7D7D7D7D7CCCF
C1B9B1B1AAA8A1B9C9CFD7DADAE0E0DADADADAE0DADAD7DA
DAE0DAE0E0E0DAD7D7CFCDC4B9C4B9C1C4C4C4C4C4BBB9AD
ADADADA9A7A4A09DA4A09BA0A09BA7A7A0A0A4A4A4A4A7A4
A0A7A7A49AB9BBA8C4C4C4BBB9B6ADA7A7A7A6A7A4A4A4AD
ADA9ADA8B2B7AD545495C4CDD3F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1DCA4CCCFD7DADAD7DADACFCFDAC8CFCFD7
CFD7CCD7D7D7DAD7DAD7DADAD7D7DADAD7DAD7D7D7D7CFCD
C4BBBBB6B1B1A8A8B9C4CFD7D7D7E0E0E0E0E0DAE0E0DADA
DADADAE0E0E0E0D7D2D2C4C4C4B9B9B9BBC4C4BBB9B9B9B9
B6ADADA4A7A0A49B9B9B95999B9999999BA09BA09DA4A4A4
A0A0A7A0A8B9B9A1C4C4BBBBB2B9A8ADA4A4A4A4A0A4A7AD
ADADA9A9A9A9B631156FBBE2F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1E8CACFD7CCD7DADAD7DAE0D7CFCFD7D7D7D7
CCD7D7D7D7D7DADAD7DAD7D7DAD7DADADADAD7DAD7DACCCF
CDC4C1B6B1B1B1A1B1BBC4CFD7DAE0E0E0E0E0E0DAE0DADA
D7DADADAE0E0E0DAD7CFCDC9BBBBB9B1B9BBB9B9B9B1ADAD
ADA7A4A4A4A49B9B9B9B99999999979999999A99A0A0A0A4
9DA49BA0B9B9A895B9BBB9B9B9B2ADADA7A0A4A0A4A4A7A9
ADADA9ADA9B7A42C2C5D89CAF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7DCC2D7D7D7D7DADAD7D7E0CFCFDACFC8D7CC
CFD7D7D7D7D7D7D7DADADADADADADADAE0DADADADAD7CCD2
C9C6C4BBB6B1B1B1A8B1C4C9CFD7DAE0E0E0DADAE0E0DAD7
DAD7D7E0E0E0DADAD7CCCFCFC4B6B1A8B1ADB6B2B9ADADAD
A7A8A4A09D9A9B9999979B9797999997999799999799999A
99A09DA8B2A8A0B1BBBBB9B6B6ADA8A7A4A4A4A0A4A7A7A8
A7A9B2ADA9A9A431315D80C4E5F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E2C2CFD7DAD7D7DAD7DADACFCFDACCD7DAD7
D7D2D7DAD7D7DADADADADADAE0DADADAE0DAE0DADAD7CFCC
CDCDBBBBBBB9B1A8A8B9BBC4C9CFDAE0E0E0E0E0E0DADADA
DADADADADADADADADAD7C9C1BBB8B2B6B2B2ADADA8A8A7A8
A4A0A49B9D9B9799979999999B9B979999999B9799979995
9999A0A8A8A8A8B2B6B9B6B9ADA7A7A9A0A4A4A4A0A4A4A7
ADADA9B2A6B7AD2A2C4795B0E2F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7D3CCD7D7DAD7D7D7D7D2CDC0CFCFD7CFD7D7
CCCCD7D7D7D7DADADADAE0E0E0E0E0E0E0DAE0DADADAD7D7
CCC9C4C4BBB1B1B1A1A8B9C4C4CCDADAE0E0E0E0E0E0DADA
DADADAD7D7D7DAC8CFCFC6BBB6B2B8B8B8BBB2A8A8A8A8A4
A0A4A09D99979B97979B999799979B9B9B9A999999999593
9995A7A8A8A8B6B6B2B9ADB6ADADA8A0A4A7A4A0A4A7A4A7
A9A9ADA9A9A9A420131B434780F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7E8CFCFD7D7DAD2D2D2D2C4BBBBCFDAD7D7CFD7
CFD7CCD7D7DADAD7DADAE0E0E0E0E0E8E0E0DAE0DADAD7CC
D2C9CDC4C4B9B1A1B1A8B1B9C4CFDADADAE0E0E0E0E0E0E0
D7D7D2D7CFD7CCD7CCCFC6C4B8B6B7B2B7B8B89DA0A8A8A0
A49DA0999797999B9799999999979BA09B99999999999795
99A0A8A8ADB1B6B9B6B6ADB2ADADADA4A4A4A7A4A4A4A7A8
A8A8A9A9B2B79E1E151B2C4395F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E8C8D2D2D7DADACCC9CDCDB9B9BBD7CFC8D7D7CC
D2D7D7D7DADADADAE0DAE0E0E0E8E0E0E0E0E0E0E0D7D7D7
CCCDC9C4C4BBB6B1B1A8B1B9C4CFDADADAE0E0E0E0E0DAD7
CCC9CDCCCFCFD7CFD7CFCDC6BBB8B6B7B6AAB2A49A9DA7A4
A9A4A49997979799999B9B999B9BA09BA09B999999999997
95A8A8B1B6B6B9BBB6ADB1ADADADA9A7A4A7A4A7A4AAA7A8
A9A9A9B2B2A99C20151B2439BBF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7DACFD7D7D7D7E0D7D7C4B6BBB2C6CFD7C8CCD7CF
CCDADADADADADADAE0E0E0E0E8E8E8E0E0E0E0E0E0DADADA
D7D2CCCDC4BBBBB1B1A1B1A8B1C1D7DAE0E0E0E0E0DACCCF
D7DAD7DAD7DACFD7D7CCCDC9C6BBC4B8B7B6B7B2A69B9797
9D9B99958A9597999D9B9B9D999BA4A0A0A09B9A99999AA0
A8B6B6BBB8B9BBB6B1B2B6ADADADADADA4A0A7A4A4ADA4A9
A9A4ADA9B2B7953643434792CDF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E8D7D7DAD7D7DAE0DACFC4B1B9B2C0D7CCCFD7D7CC
D7D7D7D7DADADADAE0E0E0E0E0E0E0E8E0E8E0E0E0E0DAD7
CFCCC9CFC4C4B9B1B1B1A8B1B1B9CFDAE0E0E0E0DAD7D7DA
DAD7D7DAD7D7D7D7DACFD7C6C9C4C4BBBBB2B2B2B2B2A495
8A9797959595979B9B99999B9B99A09D9D99A09B999AA0A8
ADBBBBBBB9B8B9B6ADB6ADADADADADA7A4A4A4A4A4A9A0A7
A8A7A9A6A9AD872C2A436DE8F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E8D7D7D7D7DADAE0D7C4B6BBB6ADC0CFD7D7D7CCCF
D7D7D7D7DAE0DAE0E0E0E0E0E0E8E8E8E0E0E0E0E0E0E0DA
D7CCCFCDC6C4C4B8B1B1B1A8B1B9CCD7DAE0E0DADADADAD7
DADADADADADADADADAD7CCD7C9C6C4C0B8B6B2AAA9ADB2A6
9B8F8F958A8F959797979B99999D9B9BA09D9BA0A4A8ADB1
B6BBBBBBB8BBBBB6B6B2B2ADADADADA8A4A4A4A7A9A4A4A9
A9A4A9A9A9B777202C436F9EA7DCF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E0D7CCD7CCDAE0E0C9BBB9BBB1B2C6CCC8CFCFD7D7
CCD7D7D7DADAE0E0E0E0E0E8E0E0E8E0E0E8E0E0E0DADAD7
D7CFD2C6CDC9C4B9B9B1B1B1B1B1C9CCDAE0DADAE0DADADA
DADAE0DADADAE0E0DADAD7CFC6C9C6C4BBB8B7B2ADADADB2
ADA69B8F97978A95979B99999B9BA09BA49B9DA0A8A8B2B6
B6BBC0B9BBBBBBBBADB6B6ADADADADA4ADA4A7A8A4A9A4AA
A7A9A9A6A9B7832C202C313143B0E5E5F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1D7D7D7CCD7DAE0DAC4BBB1BBB2BBC9CFCFDACCD7D7
D7D7DADADADADAE0E0E0E0E0E8E0E8E8E8E0E0E0E0E0DADA
DAD7CCC6CFCDC6C1BBB6B1B1B1B1C4C9CFDADADADAE0DADA
DADAE0DADAE0E0E0E0DADADACCC6C9C1BBBBB8B2B2A9B2A9
ADADB2A4A0A79B93959997979B999DA09BA0A0A8A8B6B6BB
BBBBC4C4BBBBB6B9B6B2ADADADADA8A7ADA8A4A7ADA4A4A7
A8A6B2A9B2AD6C30302C202C2C5D9ECAE2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7E8CFD2D7D7D7DAE0CFB9A8A8B9ADC0C9CFCFCCCFD7CC
D7DAD7DADADAE0E0E0E0E0E0E0E0E8E0E8E0E0E0E0E0E0DA
D7CCCFD7CCC9CDC4C4C1B6B1B1B1BBC4CCD7DAE0E0DADADA
DADADADAE0E0E8E0E0DADAD7CFC6C4C4BBB8B8B6B2B2ADA9
ADA9ADADA9ADA8A08A8A93939599999B9DA0ADADADB6BBBB
BBC4BBB9BBBBBBBBB6ADB1ADADADA8ADADA7A4A8A4A7A8A4
A7A4A9B2B7BA8B554848302013396F95D3F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1D7D2CCD7CCD7DADABBB195B1A8ADC0C2CFCCCFD7D7D7
D7D7D7DADADAE0E0E0E0E0E0E0E8E0E8E8E0E0E0E0E0DAE0
D7D7CCCFC6C9C6C6BBBBB6B6B1B6BBC4D7DADADADADADADA
DAE0DAE0E0E8E0E8E0DAD7D7C9C4C4C4B8BBB8B2B2ADB2B2
B2A6ADADADADA8A49395959593999999A0A8B1B1B6B8B9BB
C1BBC4C4BBBBBBB6B6B2ADADB6AAADA8ADAAA7AAA7A4A9A4
A8ADB2A6A9BA9D95816464482C315D749ED3F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E0CFD2D7D7DAD7CFB9C9A8959AA6BBCFCCCFCFCCD7D7D7
D7D7D7DADADAE0E0E0E0E8E0E8E8E0E8E0E8E0E0E0DADAD7
DADACFD7D7CFCCCDBBBBBBC4B9BBC6CCCFD7DAD7DAD7D2CF
D7D7DAD7E0E0E0DADADAD7CFC9BBB6B6ADADADADADADA9AD
A9ADA4A9A4A8AAA7A0958A8A97999DA0A4A8B2B2B8BBBBBB
C4BBC4BBBBC0C0BBB7B6B2B1B2B2ADAAA9ADADA4A9A9A8A9
A9ADA9A9B7C0A0958F746C5350313939435495E2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1CFCCCFD7D7D7CCC4BBC4A4A19DADBBC6C2CCD7D7D7D7D7
DAD7D7DAD7D7DAE0E0E0E0E0E8E0E8E8E8E0E0E0E0E0DADA
D7CCD7D7CFCCCFC6BBC1C4BBC4C4C4D7CCDAD7DAD7D7CCC9
CCCFDADADADAD7DAD7D7C9C9C4B6B6ADADADAAA6ADADA6A9
A6A7A6A6A7A7A0A49D8A8888959B9DA7AAB2B6B6BBBBBBC4
BBC1BBBBBBBBBBBBB8B6B6B2AAB6ADADADADA9ADADA8A9A8
A9ADA9B7A9ADA49A97957D7D6C393B43435D9EE2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EBCFCDCCD7D2CDBBB9C4ADA1A8A0B7C0CFCCCCC8D7DAD7DA
D7D7DADAD7DAE0E0E0E0E0E8E0E0E8E0E0E0E0E0E0E0DADA
D7D7D7D7D7C9CCC9C9C4C4C4C4C4BBD7DAE0DAD7DACFCFCD
C9CCD7D7DACFDAD7CFD7CCC6C4B6B2AAADA8A6A6A6A7A4A4
A9A4A4A7A4A4A4A0998A888F9599A0A8ADB6B8BBBBBBBBBB
C4BBBBBBBBBBBBBBB2B8B2B2B6AAB2ADADA8ADA8A7A9A4A9
ADA7ADA9B7BAA49DA09B97958A6C435474B6E2E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E8C9CDD2CDB9B9B1AAA1A19AA0ADB7C9CCCFCFD7CFD7DAD7
DADAD7DADADADAE0E0E0E0E8E0E0E0E0E0E0E0E0DAE0DADA
DAD7D7CFCCCCCFCFCDC4C4C6CDC6C4C9D7E0DADAD7CCCDC6
C6CFD7D7CFD7CFD7CCC9CFC4C0B8B2ADA9ADA9A0A4A4A4A9
A49DA49BA4A4A099958A888F959DA4AAB2B6BBBBBBB9BBC4
BBBBBBBBBBC1BBBBB6B6B6B2B2B2B2A8ADA9A9A9ADADA4A8
A9A9A6B7B7ADA0A4A4A09BA09B977277CAF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
DAC4D2CDB1A1A1908F93939AA4B2BBC4C2CCD7CCD7D7D7DA
D7DADADADAE0E0E0E0E0E0E0E0E0E0E0E0E0DAE0E0DADADA
DAD7D7D7CFD7CCCCC9C4C6CDCFC6CDC6D7DADAD7D7D7C9CD
C6D7CFD7D7CCD7CFCCC9C4C4B9B8B6ADA8A4A4A4A49D9B9B
9B9B9B9BA09B99958A8A8F9597A0AAADB2BBBBBBBBC4BBBB
C4BBC4BBBBBBBBBBB2B2B6B6ADB6ADA6ADADA8A6A7AAA9A9
A8A4B7A9B7BAA4A4A49DA49DA49B9CBBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
CFCDCCCDB1A1A18F95959597A4B2B7C6CCCFCFD7DADADADA
DADAE0DADADADAE0E0E0E8E8D3E0E0D3E0E0E0E0E0DAD7DA
D7CFD7D7D7CFC9CDC6C4C9C9CCCFCFDAD7DAE0DADAD7CCCF
D7D7D7DADACFCFC9C6C9C6BBB8B6B2ADA9A4A49B9B9B9B93
9393999B9B9993958A8A9597A0A6ADADB6B8BBC4BBBBC4C4
BBBBC0BBC0BBB8BBB6B6B7B2B6B2B2ADADA8A4ADA8A9AAA6
A9A9A6A9BABAA0A0A09BA0A09BA4B7E2F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DA
CCD2D2C4AAA19C93939A959BADB2B8C6CFCFD7CFDAD7D7DA
DADADADADADADAE0E0E0E8E0E0E0E0E0E0E0E0E0DADADADA
D7CCCCD2CFCCCDC9C6CDC9CCCFD7DADADADAE0E0DAD7D7DA
DADADADAD7D7CCCCC9C9C4C0BBB2B2AAA4A69D98939D9B93
9993939B9999958A958A959B9DA8ADB2B2BBBBC4C4C4C4C0
BBBBC1C1BBBBBBB9B9B7B6B1ADB2ADADA8ADA9AAA9A4A7AD
A9ADB2B7BAAD999A999DA09DA0A4ADF1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0
CFD2CCC4B1AA9D9A959A8A9AA9ADC0C9CFCFDAD7CFD7DADA
DADAE0E0DADAE0E0E0E0E0E0E8E0E0E0E0E0DADADAD7DADA
D7C6CFCCCDCFCFCDC6CFCCCFD7CFDAE0E0E0E0E0E0E0DADA
DADADADAD7D7D7CFC9C6C4C4B6B6ADADA4A4A49B9B9B9B93
8A959399938A959395959DA0A4ADB2B6B6B8BBBBC4BBBBC4
C0C0C0BBBBBBB8B6B8B6B2B2ADB2ADA8A6ADA8A4AAA4A4A4
A9A9A9A9B7BA9A95999A9DA4A4A4B7EBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAD2
CCD2CDBBAAAAA1A1938A979DA9B7C4C9CFCFD7CFDAD7D7DA
E0DAE0E0DADAE0E0E0E0E0E0E0E0E0E0E0DADAD7DADACCCC
D7D7CCCFCFCFC6C6CDCFCCC9CFCCDADADADAE0E0E0E0E0E0
DADADADADAD7CFCFCDC4C4BBBBB1ADA9A4A49B9B9B9B9393
9395939393999B999BA4A4B2B2B6B2B6BBBBBBBBC0C4C0C4
C4C4C0C0BBB8B6BBB2B6B2ADADADADA0AAA9AAA4AAA4A4A6
A4ADA9B7BABA9595959AA4A4A4A9B7DAFFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBC9CC
CFDAD2C1B1B1AAA18A8F979DB2BBC6C9CCCFCFDAD7D7DADA
E0DADADADAE0E0E0E0E0E0E0E0E0E0DAE0DAD7DADADAD7D7
CCCFCFCCCFCDCCC9CFCFCDCFCDC6DADADADADADAE0E0DADA
DADADADADAD7D7CCCFC1C4C4B6ADADADA4A4A49B9B939993
999399999B9B9DA0A4A8B2B2B2B2B7B6B8C0C0C1C4C4C1C0
C4BBC4C4BBBBB6B7B2B1B2ADB2AAADA4A7ADA4A4A4A4A4A4
A9A7A9B7ADB7999A999AA0A4A9A9A9C8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0CCCD
D2DACCC1B1B1AAA1978A97A4B2BBC6CFCFD7DACFD7DADADA
E0DADADAE0E0E0DAE0DADADAE0DADADADAD7D7D7CFDAD7CF
CFCCD7CFCCCFC9C4C4C4C4CFC6C9DADADAD7DADAE0DADAE0
DADADADADACFD7D7CFCDBBBBB6ADADA4A4A49D9B9B9B9998
9B9B9BA49BA4A7A4A4A9ADB2B2B8B8B7B8C0C4C0C4BBBBBB
C4C4BBC0BBB9BBBBB6B2ADB2ADADA9ADA6ADA4A4A9A4A4A4
A4ADA6B7BABA9DA09DA0A0AAA9A9A4BAF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBD7CDCD
CCDAD7CDB8B1AAA1958A979DB2C0C6CCCFCFD7DAD7DADADA
E0E0E0DADADAE0E0E0D7DADADADADADAD7DAD7D7CFCCCFCC
CFCFCCCFC9C9C6C6C4C4C4C9C6CCCFDADADAD7DADADADADA
DADADADADADAD7DAD2C6C4B6B2B6ADA79DA4A49B9B9B9B9B
9B9B9DA6A4A4A4ADA6ADB2B2B8B7BBBBBBBBC0C0C6C4C4BB
C4C0BBBBBBB8B9B6B2B6B2ADB2ADAAA8A9A8A4A4A6A9A4A4
A6A9A9B7ADADA4A0A7A4A4A9A9A6A4ADEBF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0D2C4C4
D2DADACDB1A1A8A1959393A4B2C0C9CFD7CCDACFDADADADA
E0DAE0DAE0DADADADADADADADAD7D7CFCFD7CFD7D7D7D7CF
CCCCCFC6C9C6C9C4C4C6C6C4C9CFD7D7DAD7DAD7D7DADADA
DADADAD7DAD7D7DACCC4C4B6B1B2ADAAA4A49DA49B9B9B9B
9BA09DA09DA6A4A4A7ADB2B2B2B6BBC0BBC0C4C4C4BBC0C4
BBC4BBB6B6B9B2B2B2ADADADA8ADADA9A8A6A4A6A4A4A4A6
A7A6A6B7BAB7A9A7A8A9A7ADA9A49DA6C8FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7CCB9B9
D7E0DAC1B1A8AA9D938A939DB2C6C9CFCFD7D7D7DADADAE0
E0DAE0DAE0DAD7DADADADADACFE0D7D7D7C6CCCFCCCFC9CF
CFCFC6CDC6C4C6C4C4C9C6C6CCCFCFD7CFDADAD7DADAD7DA
E0DADADADADADAD7CFC6C4BBB6ADADA7A4A49B9D9B9B999B
A09DA4A49BA0A9A7A6ADB2ADB6B7B8C0BBC1C0C1BBC0C4C0
C4BBB2B6B2BBB8B9B2ADADA9ADB2ADA9AAA9A8A7A4A4A4A4
A6A4A9BABAB7A8A8ADA9A8A9A9999DA0CCF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7CDB9B9
D7D7C0B6B8A8A8A18A8A939BB7C6C9CCCFCFCFD7D7DADADA
E0DADAE0E0DAE0CFDADAD7D7D7CFD7CFCFC9CFCFCFC6C4C6
CFC6CFCFC6C4C4C6C4C6CFCFCFCFCFD7DADAD7D7D7D7D7DA
DADADADADAD7DAD7D7C6C4C1B6ADADADA4A4A49B989B9B9B
9D9D9DA0A4A4A9ADA8ADADB2B8B7BBBBC0C0BBBBC0C4BBBB
C0BBB9B9B6B7B8B2B6B2ADADA9A9A4ADA7A4A6A6A4A4A4A4
A4A6B7ADB8AD99A7A7ADA9A7B79A9A9AB2F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACDB1A1BB
B1A6A6A46C6C8197958A8A9DC0C6CFCCCFCFD7DAD7DADADA
DADADADAE0DAE0DADADADADAD7D7CFCCCFCCC9C9CFC6C4C9
C4C4C0C0C9C6C6CCCFCCCFCCD7D7CFD7CFDADADAD7DAD7DA
DADADADAD7DAD7D7CCCCC9BBB8B6ADA6A49B9D9D9B9B9B9B
9B9B9D9BA4A4A4A4AAA6AAB2BBBBBBBBBBBBBBC0BBBBC0C4
BBB2B6B7B6B7B2B2B6B2B2B2AAA9ADA9A8A9A6A4A4A4A4A4
A9A9A9BABAB7818195ADB2B2B79D95A19DC9F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D7B9A1B1B1
97B2AA796C796C7981818AA4C0C9CFD7D7D7DADADADADADA
DADAE0E0DADADADAD7CFD7CFD2CFD7CFCFCFC9CFC6C9C6C6
C0C4C6C6C6C9C9C9CFCFCFCFCFCFCFDAD7DADACFDAD7D7D7
DADADADADADAD7D7CFCFC6BBB6ADADA4A4A09B9B9B9B9B9B
9B9B9DA4A4A4A4A9A9AAB2B7B8B2C0BBBBBBB6BBBBBBC0BB
C0BBBBB6BBB7B6ADB2B2B2ADB2A6ADA4A9A4A6A4A4A4A4A7
A6A9A9BABAAD748187A0A7A9B7A49A9A9AADE8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0D2B1A1AA95
97B1864361797964707580A9BBC9CFCFDACFDADADADADADA
DADADADADADADADADAD7CFC9CFC9C9C6C4C0C6C6CFC6C0CF
C9C2C9C6C9C6C0C6CFC9CFC6D7DADACFD7DAD7DADADAD7DA
DADADADADADAD7CFD2C9C4BBB2ADAAA49D9B9B9B9B9B9B99
9B9BA0A4A69DA6ADAAB2B2B6B9B8B7BBB8B6B2B6B8B2B8B8
B7B8B2B8B2B6B2B2B2B2B2B2B2ADA9A9A4A4A0A4A0A4A4A6
A9A6B2ADB7B77D7D8190A0A9A9A79D9AA19ADAF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D7CDB1AA9D8A
97795B86796C5D5D646C739DC0CCD7CFDAD7DAD7D7D7DADA
DAD7DADADAD7D7DADADADADACFCFCFCFC9C9CFC2C9C6C6C0
BBBBC0BBC0C6C0C9C6CFCFCFCFCFCFD7CFDADADADACFD7DA
D7DADAD7DADAD2CCCFC9C4B8B6ADA0A4A49D9B98939B9B9B
999D9B9DA6A4A4ADA9B2B2B2B2BBB8B8B7BBB2B6B6B2B6B7
B8B2B6B2B6ADB6B2B2ADA6ADB2B2A9ADA6A4A4A4A4A4A6A6
A9A6A9B8ADA97D8181959BA9A9ADA4A4A09ACCF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFE8CDC4A1AAA874
5B638AA461555D55646475A4C0CFCFD7CFD7DADADADADADA
DADAD7DADADADADADADADADAD7DADADADADADAD7DADACFCF
C0C0BBBBB9B6BBB8C0C6C9C6C9CCD7CFDACFDADAD7DAD7DA
DAD7DAD7D7CFCCCFC6C4C1B6ADA8A4A4A09D9B9B9B939998
9B9DA4A4A4A4A6A9ADADB2B2B6B6B2B6B7B7B6B7B6B2B2B6
B6B6B7B6B2B2ADB2ADA9ADB2B2ADADA4A9A9A6A4A0A4A4A6
A9A6B2ADBAB7817D818F99A7A0A9ADAD9D9DB2F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DACDB9A1B19B61
427DA48A5D6255554A6C759DC0C9D7D7DADADADADADADAD7
D7DADAD7D7DADACFDADADADADAD7DADADADADAD7DACFCFCC
C6C6C4BBB8BBB8B2B2B2B8C6C9C2CFCFCFD7D7DADAD7D7DA
DADADAD7D7D7D7CFC6C1BBB6ADA79DA09B9B999B99939B93
939DA0A4A49DA9ADB2A9ADB2ADB2B2B6B2B8BBB8B8B2B6B2
ADB6B2B6B2B2ADADA9AAB2ADA9ADA6ADA9A4A7A4A49DA4A4
A6A9ADBAA9A9817D8F90959999A8ADA99DA1ADE8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DAC4B1A1B08A48
439B8A8179986C5D4A5E75A9C0C9CFD7DACFDADADADAE0DA
DADADADADADAD7DACFCFCFD7DAD7DADADADADADADADADAC8
CFCCC0C0C0BBB8B6B2B2B2ADB7CCCDD7DACFCFDADAD7DADA
DADADACFCCD7CFD7C4BBB8B6ADA8A4A4A09B99939993989B
989B9B9DA4A6A9A9A9B2B2B2B2B8B2B8B2B7B8B2B2B6B2B2
ADB2B2B2B2ADADADADB2B2ADADA9ADA9A4A4A6A6A4A49BA6
A9A9A9B7B7A98174747D81818195A8ADA69AA8DAFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1DAB9A1AAC17542
7D793B245B6362835E5E639DC0CFD7D7DADACFDADAD7D7D7
CFD7D7DACFCFC2C9CFD7DADADADADADADADADADAC4DADACF
DACCC2C6C0C0C0B1B2ADADADB2ADB7C6CFCFCFDADADADADA
DADADADAD7CFD7C9C4C1C0B1ADAAA49B9B9B9B959393939B
9B9D9D9DA6A4A7A9ADADA9ADADB2ADB2B2B2B2B2B2B2B2B2
A6AAA9B2ADB2ADB2B2B2ADA9A9A9A9A9A7A4A4A4A7A49D9D
A6A9ADB7A9A981706C6464645E7487A0A0A69AC6F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCDB1A1B1B86348
7D61183075875D395E55759DC0CFCFD7DACFDAD7DADADADA
D7CFC9C9C9C9C6C0C0BBD7DAD7D7C2C9CFCCBABAB7BAB7A9
B7B7A9B7C0C0B6B2B2B6ADADADADADBBC9CFD7DAD7DADADA
E0DADAD7D7D7CCC9C4C4BBADA8A7A09B9B97938A8B939B93
999B9BA7A7A9A4A7A7A4A4A4A4A9A9B2B2B2B7B2B2B2B2B2
A9A9A9B2B2ADB2B2B2A9A9A9ADA6ADA7A4A6A49DA4A4A6A4
A9A9A9A9A9A986756C6C6364646C8187A0A89AC0F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8C4A19CB8C6795B
7D3B1853483B2C3B4A4F5E9CC0CFD7D7D7D7CFD7CFDADADA
DADAD7DAD7CFCFC9B7839DB2B7A9A79D989B9B98989A9A9A
9A93A6939BB2A6B2ADA9AAA8ADADB2B2C0C2CFDADADADAE0
DAE0DADADACFD7C9C6B9BBB6AD9D9B9B9999999595989398
989B9B9B9BA09B9B9D9BA6A49DA9A9A9A9A9A9B2B7A9B7B2
A9A6B2B2B2B7B2B7B2B2B2A9A9B2A9A6A9A4A7A6A49DA4A6
A6A9B7A4A99D86756C636C64646C748190A89DB8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E0B9A1A1B6C68143
6C201843201B20313B4A5A9DC0C9CFDACFD7DADAD7CFD7DA
D7DACFCFC9C0B9A998835D5E5E5D7575758A878A8B989A9A
9A98A69888889BAA9BA4A4A4A4A4C0C6C0C6CFCFCFDADAE0
E0DAE0DAD7D7D7D2C4C4BBB2ADA4A4A09993938A93989393
98989B999B9D9DA6A6A6A9A6A9A9A9A9A9A9A9B2A9B2A9B2
B2B2B2B2B2B2B7B2ADB7B2A9B2A9A7A9A7A4A4A0A4A4A69C
A9A4A9B7A9A68B79706C64646C6C748190A4A1B2F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D7B9A19CB8C18A50
4318132E131B20313B434AADC9CFDAD7D7CFD7CFD7D7D7CF
DACFCFCFC9C9B7A793B7865553484A646C798A9B8A737575
736C707586887D8A989B9D9B979BB2BBC0C4C9CFD7D7DAE0
DADADADADADAD7CFC6C6BBB1A8A0A09D9B999593938A9898
8A958B9D9D9DA69DA49D9BA09D9DA49BA4A49DA6A9A9B2B2
B2B7B7B2B2B7B8B2B2A9A9B2A9A4A6A7A4A4A99D9DA49DA6
A9A6A9A9A99D8375706C6C646C6C7474909AA8B2F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1CFB19CA1C1C19B48
2E04180C132C2C2A2C484AA9C9D7CFD7DADACFD7CFCFCFD7
D2D7DADAD7CFC9C9B7A9BA9855554848779EB6BB80423B62
2E2E2E42435B647D7D81888F7D899095A0ADC0CFCFD7DADA
E0DADADADADACFD7CFC4BBB6A8A7A49B999395938A988A88
8893989D9DA6A4A4A4A4A4A4A4A0A4A4A4A0A4A09BA09D9B
A9B7B7B7B2B2B7B2B2B2B2B2A9A9A7A4A4A99DA9A4A99DA9
A9A9A9A4A6A6867574636C6C6C6C748181A0A8B2F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1C9A19CA1B8CCA637
18041713202C2C3B313B5A9CC9D7DAD7CFD7D7CFD2D2D2CF
D7DAD7D7D7CFCFCFC98FB7B29D6C483983A4BBB55D4283AD
430C0C305340426C817D746C6C6C64646C8FB9C4C9DADAE0
DAE0DAE0DADAD7CFC9C1BBBBADA9A09B99998B8A9888888A
8A8B9DA6A9A6B2B2B2B2B2B2B2B2B2ADADA9A6A9A6A7A4A4
9D9BA7A9B2B7B7B7B2B2B2A9A9A9A9A79DA7A49D9DA49D9C
A9A6A9A9A99D8673746C6C6C6C747481899AA4ADEBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CDA19C97C1CCB839
1804131B2C2C2C313B3B4AA9C2D7CFDADAD7D7CFCFCFC9D7
CFDAD7CFDACFDACFCF9B9BBAB7AD9D83435E84953953ADB6
6D0C0C2C535B5B6CA49C8B816C5B7075818FADC4D2CFDADA
E0DAE0DADADAD7D7C9C4C0B6ADA8A79D939595988881818A
9898A9A9B7AAB2B7B7BBC0BAC6BAB7B7B7B2B2A9B2A9ADA9
A4A9A9A9A9A9B2A9B2A9A9A9A9ADA9A9A4A4A7A4A7A69DA6
9CA9A9A9A69880756C6C6C6C6C6C7481899AA8ADF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFDABBA18790B6B8C175
2C201B1B242A2C2C3B5A4FB7CFCFD7D7DAD7CFD7CFCCCFD7
D7DADAD7D7DACFCFCFC0A995B2C2989C8475393B2E548089
7A0C0C294F5B5363A4AD9E735B536C90A0B9C4C9CFDADAE0
DADAE0E0E0E0DAD7CFC4C4B9ADA8A09B95958A887D7D7D7D
8899A7B2B7B7B7B7B7A6B7BAB2A9A9B7A9B2B7B7B7B2A9B2
A6A9A79DA9B2B2B7B7B7B2A9A99DA79DA79D9D9BA79DA79D
9DA9A9A69D98737064706C6C6C81818995A8A8ADF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7D395B7CD9C8789AAB6B886
391B0C0C202A1B2031486CB7C9CFCFD7CFD7CCCFD7D7D7D7
CFD7D7DADACFD7D7D7CFC0B29BB2D7CFB29D98734837395D
44000C243943436C9E878B6C6C6C8895A7B9C9C9CFDADADA
DAE0E0E0E0E0CFD7C9C4BBB9ADA4A099958A887D7D7D734B
536C7DA4A9B7B7A6A69B9B989B8B8A8A938B9DA9A9A9A9A9
A7A9A99D98A7A9A9A9A9A9A7A7A9A9A79B9DA79D9BA49DA7
A6A9A99D9B8B6C6C6C70706C747D899095A4A6ADEBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FF4B42B9CD908789A8B8B6A4
4A131520202C2C20303B5EB2CFD7D7D7D7D7CFD7CFD7CFD7
D7D7DACFD7D7D7D7DACFC9C0B2A7B2CFC6B7B78B5E5D3B3B
2C0C131B3742375E5D6C74747D7D8195ADB9BBC6CFDAD7DA
E0E0E0E0E8E0DAD7CFC9C4B9ADA79D998A8F8881887D7442
3D40508193989B938F8A8186867070796C75818A98989A9D
9D9DA7A7A79B9DA7A9A7A9A9A9A79D98989B9D9D9D9DA49D
A69DA69D988B6C64616C7061748F90959DA09DA4EBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F19E1842B9C4AA878FB9C4BBBB
5E04132A2C20241B2C435EB7CFCFD7CFD7CFD7CFD7CFD7D7
CFD7D7D7DADADADAD7CFCFC9C0BBA7B2D7CFAD8BB272554F
53483B3743423B645B647D7D817D8FA8B9B2BBC0CFD7DADA
E0E0E0E0E0E0DACFCFC4C0B9ADA7A09995888898887D7D63
424055878B989A8A8779756C64646C737373756C6C79818B
9A9898989D9B989D9DA7A79BA79BA79D9B98989DA79D9D9D
A7A6A49898835D64646C6464648F9595A1A89AA8EBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFE27730182EA1CDC4BBBBCDBBBBB1
55041B2A2C1B202C2C3B5EBAC9CFD7D7CFD7CFD7CFCFD2CF
DAD7DADADAD7DADAD7DAD7CFCFC0BBB2B2CFB2BABA738386
6C6C4F5D6C5555737483887D7D7DB9B9B9ADB9C4CFCFD7DA
E0E0E8E8E8E0DAD7C9C4C4BBADA49D95958A888A8A887D74
735B5B8DB0BBC4C8B56353373D37423B5575736C63535B64
818B868B8B988B95989398989898989B9B9B9BA79D9DA4A6
A69D9D938B81555B5D625D5D6C8F9A9DA0A490A1DAF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7FFE88937201824A0B9CDCDCDC4B6B9AA
55132C2A311B20202E435EB7CFD2DACFD2CFCFCFCFC0C9CF
D7D7CFCFD7D7DADADAD7DACFCFCFC9BBAD9BA7C0BA9DB7A7
8B756C796C64647D7D88887D7DA0ADB9ADB1BBC9CFCFDAE0
E0E0E0E0E0E0DACFC4C4C4BBADA09B9995888881988A817D
7D6C5073ADC4C8C195374037242E4242423B536C70615D55
5B7383838386838383868A8A8B93989B9DA4A49DA49D9DA9
A6A998938B73555E5A5D5E55558A9AA0A8A8909ADAF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7B03B202418208FB1B9CDCDBBB1B1A4
5D30364329201320204362BACFCFCFCCCFD7D7CFD7C0BBC9
CFCFD7D7CFDADADADAD7D7DACFCFCFC9BBB7A9ADA9A9B7B2
A98B8B9388817D88887D7D8FA7A8A8B6B6B6C0C6C9CFD7DA
E0E0E8E8E0DACFD2C9C9C0BBADA4A099958888818A8A887D
747D705B84B0D3B55D53842C04152948555A3B5A636C615B
3B5E6C7573736C647379818A95939BA79D9DA79D9DA79DA9
A4A7988B836C555548635E5D5595A4A8AD958797C4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F79E3B20202018182E81B1B9B995958F6C
393B36362C1B20202C435EC2CFCFCFD2CFD7D7CFD7C0A49B
B2C0CFCFD7CFDAD7DADADADADAD7DACFC6C9C0C0BBB9B7B2
A7A79999958895A7A7A8A8ADADADB2B9BBC4C9CFCFD7DADA
E0E8E0E8E0E0CFCCC9C9C4C0B2A9A499958888888A8A9888
7D7488867D75726F5AADA435001536364B4A48548089845D
4B4336434B4B5A556C8198A7A9A7A7A79DA79DA79DA69D9D
A49B9883755A484B4F53373B5B8AA9AD9A818790CFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7DC63313020200418184281A1A17D746448
39392A24201B1B202C486CC9D2CFD2CFD7D7CFDADAD7C098
93B2C4C9CFDADAD7DADAE0E0E0DADADACFC9C9C6BBBBBBB9
B2ADADA8A7A7A7A8A8A8A8A8ADB1B9BBC0C9C9CCD7CFDAE0
E0E8E0E0E0DAD7CFC9C9C4BBB2ADA4A0938F888A95988A8F
88747D8B938A815E4A87A429001547484A433B5D84807454
363B3B3B4A435A6C8186888A999BA7A9A9A9A9A7A99DA7A9
9DA79883624A4B4A484B31375395A9AD9574878FC2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFB9483B393020180418042E5B6C5D434243
3131312420131B132C4863BACFCFCFCCCFD2D7CFD7D7CFB8
9897B2B7C9CFD7DADAE0DAE0E0E0E0DACFCFCFCFC0BBB2B9
B9B2B2A8A8ADA8A8A8ADADADADB2BBC0C9C4CFCFD7CCDAE0
E8E0E0E0E0D7D7CFC9C4C0BBADADA79B958F888A88989598
8F8F7D9B9B938B8175535D29000C23313B422E54776C432A
3B485A5E536479868A98989B8B9599A7A9A79DA7A49DA6A4
9D9D98835E4B4B48554B313B3B97A9AD90818190CCF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FF95302C37312C0418181B041B1855392C3B
241B312C1B1B1B1B2C4375BACFCFCCCFCFCCCFD7DACFCFC6
AA98A9A9B2C6CFDADAE0E0E0E0E0DAE0DACFCFCFC6C9BBBB
ADADADADB2ADADA8ADADA8ADB9ADB9BBC4C9C9CFC9CFDAE0
E0E8E0E0E0DACFD7C6C9BBBBB7ADA9999995958A988F9898
95989899A9A78B9893734B30150C132437302C4F4F393943
395E5E5E6C81988A8A8A989BA798999D9BA7A9A69DA99DA4
A79D98754A3B48483B2C2C3B439BAAA689748190CFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7802C2C2C3730181B1B1B171B0443392C20
241B1B2C1B1B1B1B2C486CC9CFC9CFD7D7CFCFD7DAD7D7CF
B8AD93B2B7A9BBCFDAE0E0E8E0E8E0E0E0DACFCFCFC6BABB
B9B2ADB2ADADADADA7ADA7A8ADADB9BBBBC4CFC9C6D7DAE0
E0E0E0E0DACFCCCFC9C4BBBBBBB7ADA49B958A98938A9895
99999B889BA9A9A99B8B755E5D5548433B30313B203B484A
5A6C5D6C8381868A8B9595939BA79BA0A49B9BA7A99DA4A9
9D988B6C48433B3943432C423B9DB2A481818790DAF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E8632E203031371820202418181839312A20
1B1B1520151B202020486CC0C9C9D2CFD7D7D7D7CFDADACF
CFB89B9BB2B2A6A9C9DADAE8E0E8E0E0DADADACFCFC9C9BB
B2B2B2B2B7ADADA7A09D9A959AA8B2BBC0C6C0C6CFCFDAE0
E0DAE0DADAD7CFCFC4BBBBC0B2B2A9AD9D93958B95989995
9B9B99A78899A9B7A99875737375555E4343535A31436275
83647986838A8B989398999898A7A99D9DA49D9D9DA7A6A4
9D98835E483B31434331303737A4A9958174879ADAF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7D3542C30313B392020302013202E392A2A1B
151B151B201B13202C4875BAC9D2CCCFD7D2CFDAD7D7DADA
D7C6A8A6A9A69A98A9CCCFDAE0E0E0E0DAD7C2C9BAC9BAB2
A9A7A9A79B9B9B8A8F7D7D7D8F9DA9B2BBC0C6C6CFDADADA
DADADAD7DACFCFC9C4C4C6BBADB2A9A9A99B958A988A9899
999B9999A79998A7B2B2989D8B8375755E4F626C75547583
7583817D8A939898989B9B9B9B9B9BA4A7A4A7A49D9DA79D
9D98755543312C292C1B202E30A7A490747487A0EBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F79B31303031303B20303B302C2C2C3120311B
0C1313152C1B1320304A5EB7C9CFD2CFD2CFD7D7CFD7D7D7
DAD7C6B8B7A687878A879887988D8B8B8B806C6C736C5E5D
5D5D6463645B5B6C70707474747D9BA9B7B8C0CFCFCFDADA
DADAD7CFD7CFC9C4C4C9BBBBB7B2A9A69B9B9999958A9595
98989BA7A79999A8A9A7A7A7A9A798989883838179818375
798198939B9B9B9BA0A4A4A09DA4A4A7A79DA9A4A9A79D9D
9D835E3B3B2C39432C201B2043A48A89747487ADF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7A748302E201B20202020202C2C2C3120202A
15150C152C20151B2C486CA9C0C9CFD2CFCCD7D7D7D7D7D7
DACFD7CFCFB8A69A8B868B8B8B9887877272726262635D5D
63636C616163636170646379888A9BADB2C0C9CFCFDACFDA
E0CFD2CFCFC9C4C4C4C6C0BBB7B7A9A69D9B97938A958F8A
959598A7A7A7A79BA7A7A9A7A7A798989883868686817983
8A9B989B9D9BA4A49D9DA49DA49DA79BA4A9A49DA9A4A49D
98835A432C3143361B20131B55A48A81747487ADF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7A4432C20201B2013202C1B20202C2C1B202A
1B13130C152C2C202C3762A9C9C9CFD2D7CFCFD2D7CFD7D7
D7D7DADACFCFC6B7A68B728077988D8B808080736C636262
75636363615D5B636175818A8A8BA4B2BBC0CCCFCFDADADA
DAD7CFCCCFC9C9C9C4C9C4C0B7B7B2A49B9B938A88818888
889893999BA7B2A9ADA9A7A79B9B9999988698958A93999B
9B9BA49DA09D9DA7A6A79DA7A4A79D9B9DA99DA79D9DA4A7
8B6C4A2C2A31294336201B18649B8A7D6C7481B2F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F1F7F7F1F7F1F7F7F7F1F7F7F1F7F7F7F7
F1F7F7F7F7F7A743302C2020201B202020202020201B132C
1B151513132C2C2C313B559DC0C9CFD2CFD7D7D7CCD7D7D7
DAD7DADAE0D7CFCFC6878A80868080808A878D9877807375
637575757061637070747D8A8A9BB8B8C0C6C9CDCFDADADA
D7CFD2D7CFC9C4C4C9C9C0C6B8B7B29D9D938B79796C6C74
7D8195989999A7A9A7ADADA9ADA9A7A79BA79BA7A7A79DA0
A49BA79DA4A7A79DA7A6A7A99D9DA49B9DA9A79DA4A7A998
836C432C2C2036432A131B2081958F7D816C81ADF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7B643372C20201B201B201B202020201B0420
201513151B20314343485A9DB7BAC9CFD2D7D7CFD7D7D7DA
DADADADADAD7D7DACFC6A9AAA69AA6A68D989BA6A69A9A87
93988798988A8A888A979BA4ADB6C6CFCFCFD7CFDADADADA
DACFD2CFCCCFC4C4C9C6C0C6B7B7B2A69B938A70635B5B63
636C7D8A98999B9BA7A7ADA7A7A9ADA9ADA8A7A9A7A9A7A9
9DA49DA7A7A6A6A79DA9A9A9A6A79DA09DA4A69DA7A69D98
834A3B2C1B1B2A361B1B13489388887D6C748798C4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1C44F3020202020201B201313202C2020041B
20131513131B2C434F4A4F8BB2C6C9CFD2CFD7D7D7D7D7D7
D7DADADADADADADADACFCCB9CCB8B7BAB8B7C1B9C6BAB8BA
B6A9B8B7B7BAB8B7B8C4C6C6C6CFC6D7CFD7CFDADADACFD7
CFCCCFD7CFCDC4C6C9CFC6C4C0B8B7B2A69B8A7561615B5B
535B647981989999A7A7A9ADA9B2A9ADA9A9A9ADA9A7A9A9
A9A9A9A9A4A9A7A9A9A9A9A9A9A7A69D9B9DA9A69DA7A798
6C483120152C2A241B362C5D978F887D6C6C889577FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7D363392E132020201B2020202C2020200C13
20132015151B1B20435E6298A9B7C9C9CFCFCFD7D7D7D7D7
DADADAE0DADAE0DADADACFCFCFCFCFCCDAC8DAC8DADAC4CC
CCCCC4CFCCD7C8D7CCC8DACFCFCCCFD7CFCFDADADADADAD7
CFCDCFD7D2C9C6C9C9C9C6C0C0BAB8B7A9A69B796C645553
5050506475818A9399A7A9A9A9B2B2B2ADADA9A9A9A6A7A9
A9A4A4A9A9A9A9A99DA9A99D9DA9A7A49DA6A9A79D9BA78B
62432C201B1B241B1543316C998189746C6C818A4FDCF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E86F393920202C201B201313202020201304
1320131B20202C3143485A8B9CBAC0C9C4CFD2CFD7D2D7D7
DADADADAE0E0DADAE0E0E0E0E0E0E0E0E0E0E0E0E0E0E8E0
E8E8E0E0E0E0E0D3DADADADADADAD7CFDAD7DAE0DADACFDA
CFC9CCCFC9C4C9C9C9C4C9C6C0C0C0B8B7C0B79B8A797561
53555548434855555D648A9B9BA9A9A9A9A9A9A9A7A79DA7
A49DA9A79DA4A79DA99D9B9B9D9B9D9DA9A6A6A79DA49B73
4B2C201B20201B152A36305D81937974646C7D702C95E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E5744839201B20201B13201B1B201B2C1304
0420200C20202C2C434A5A839DB2C0C9C9C9D2D2D7D7D7DA
DADAE0DAE0E0E0E0E0E0E0E0E0E0E0E0E0E0E8E0E0E0E0E0
E0E8E0E0E0E0E0E0E0DADADAD7DAD7DACFDADADAE0CFD7D7
CFD2CFCDCFC4C9C9C9C9C9C9C0C6C1C0C0C0C6A9A99B8A79
635B5D484839373B3B4855758198A7A7A9B2A9A9A7A9A79D
A7A79DA79DA79B9D9B8B938B8B989BA9A6A7A99DA49D9B75
482C1B202020152C362C304874958A74646C81612C89D3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1E8843B483020201B1B1313201B2020202004
041320201B2C2C31394A4F839A9DB7C0CFD2D7CFD7D7D7D7
DADAE0DAE0E0E0E0E0E0E0E0E0E0E0E0E8E0E0E8E0E0E8E8
E0E0E8E8E8E0E0E0E0E0E0DAE0DADADADADAD7DADADAD7D7
D7CFD2CFCCC9C4C9C9C4C6C4C0C0C0C0C6C0C6C0BABAAD9B
98796C5D5348483937393B483B53758B98A9A9A7A798A7A7
A7A79B9B9B9393987381736C798B98A9A49DA7A49D9D985D
3B202C1B1B201531312A1B4264888888748186534B6FA4DC
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F78039483B2C2C1B20201B1B20202020200C
040C20201B2C2C3B484F5E8B9DA9B2B2C4CFD2D2D7D7D7D7
DADADADAE0E0DAE0E0E0E8E0E8E0E0E8E8E0E8E8E0E8E8E0
E8E8E8E0E8E8E0E8E0E0E0E0E0DADADAE0D7DAD7DADACFD2
CCCFCCCFCFC9C9C9C4C9C9C6C4C6C0C6C6C0C0BABAC0BAB7
A9A68A6C63635D48433B37393B3743535D868B9398939398
9B9898988B8681736C6C6C738A9BA9A4A49DA6A4A49B985A
302C200C201B203624201B42506C747D88817548436C89DA
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7953B483B2C312C1B1B201B201320202013
0404131B2C202A2C435A5E73989CB2BAC9CFCFD7D2D2D7DA
DAD7DADAE0E0E0E0E0E0E0E0E0E0E8E0E0E8E8E8E8E8E0E8
E8E8E8E8E8E0E0E0E8E0E0E0E0DADADADADAE0D7D7CFD2CF
CFD7CFCDCDC9CDC9C9C9C6C0C9C4C4C6C0C0C6C6C6C0C0BA
B2B2A6988079756C6C55483B39393B48485D6C6C75798381
8A8175756C6C6C6C6C6C738A98A6A99D9DA4A49D9D9B8B4B
2C2C131B2C132C2A2A2C202E40636464635B55394B6F9EE2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F795433B4A3B3120201320201B2020202020
13040C1B202C3B4343485E72989AA9BAC9CFD2D7D7D7D7DA
DADADADAE0E0E0E0E0E0E0E0E8E0E8E0E8E8E0E8E8E8E8E0
E0E8E0E8E8E0E8E8E0E0E8E0E0D7DADAD7E0DACFD7DACFCF
D7CFD7CFC9C9C9C9C4C9C9C4C9C0C6C6C9C6C6C9C6C0C0BB
BAB7B2A9A698838073755D5548433B3B3B4855555D5D6C73
636C5D626C6C75636C79869BA69DA9A6A4A69D9B9B988B48
2C1313202015241B2A1B1B2424424B424043373B4B63A4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7A748434A48312A20131B1B2C201B202020
13040C13152C2C394A5A5A728B9DA9B7C0CFCCD7D7DAD7D7
DADADADAE0E0E0E0DAE0E0E8E0E0E8E8E8E8E8E8E8E8E8E0
E8E8E8E0E8E8E8E0E8E0E0E0E0DADAE0DADAD7D7D7DACCD7
D7CFD7CDC9C9C9C9C4C4C9C4C6C9C9C9C6C9C6C0C4C0C0C0
BBB8B7B2A9A6A6988B81736C5D55554343484855555D5D5D
6C6C6C5D6C636C73798A979D9DA6A4A4A49D9BA49B938343
20131B201B201B24201B13182B3D3D362E3737484F80E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7B6483B484A3B2C2C20202C2C2C2020202C
1B0C040C2C2C2C3B434A5A738B8DA7B7BBC4D2CFD7D2DAD7
D7DAE0DADAE0E0E0DAE0E0E8E0E8E0E8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8E0E0E0E0E0E0E0E0DADADADADAD7CFD7CFD7
CFD2CFCFC9C9CDC9C9C9C6C4C9C6C6C6C9C9C9C6C0C0BBC0
C0BAB7B7B7A6A9A69D988A8673736355483B4848534A5355
555D555D636C79798A9B9DA4A6A69D9D9DA49B9D938B833B
201B20201B24202C1B20131314182B24373039434BE2FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E8A44F4848484B2E31311B2C20202C202C20
31392A1B2C312C31484A5E758B9DA7A9C0BBC9D2D7CFD7D7
DADADADAE0DAE0E0DAE0E0E8E0E0E8E0E8E8E8E8E8E0E8E8
E8E0E8E8E8E8E8E0E0E0E0E0E0E0DAD7D7D7D7CFDACCD7D7
CFCFD7CFCDC9C9C9C9C9C9C9C9C9C9C6C6C6C6C6C0C6C0B8
C0B8BBB8B7B7B2A6A99D9A9898988B86816C6C645B555548
50616C70798A8A9B9DA49DA6A49DA69DA49B9B989383622C
2C20201B2C242C2A151B2013131320202031313B54CDE2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7DC954F43484A4F31312A1B2C2C202020202C
20312A2C2A363939434A5E75838B9CA9B7C9C4CFD7D7D7D7
D7DADAE0DADADAE0E0E0E0E0E0E0E8E8E8E8E0E8E8E8E8E8
E8E8E8E8E8E0E8E8E0E0E8E0E0E0DAD7E0D7D7DAD7D7D7CF
D7CFCDCFC9C9C9C9C9C4C4C9C4C9C9C9C9C9C9C0C6C0C1C0
C0BAB8B8B7B7B7B2A9A6A9A49DA69B938B8A8173756C6C6C
7579798193989D9D9D9BA4A49BA09DA49D9B9B938B835A2C
2C202020201B2C151B2A1B04131B2C202C312C39486C89C4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F1F7F7F7CA6C5E484B4A4F4B31312C202C2020202C39
312C2C2C2C2C3B31484B5A6373869DA9B7C0C9D2D7CFD7DA
D7DADADADAE0E0E0E0E0E0DAE8E8E0E0E8E8E8E8E8E0E8E8
E8E8E8E8E8E8E8E8E0E8E0E0E0E0D7DADADACFD7D7CFD7CC
CFD2C4C9D2C9C9C4C4C9C6C4C4C6C6C9C9C9C4C6C9C0C0C0
C0C0BAB7B8B8B7B2B2B2A9A6A9A9A69D9B988B938A8A8A8A
8A8A939B9BA7A69DA49BA69DA4A49B9DA09D9B8B8A754A2C
2C20202A201B1B152A2A15130C201B132C2A2C2A31434F95
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7B96348484B3B484B3B3B312C2C2C202C2020
202C2020202C2C313B4B4A62738698A9B2B7C9C9D2D7D7D7
D7DADAE0E0E0DAE0E0E0E0E8E8E0E0E8E8E8E8E8E8E8E8E8
E8E8E8E0E8E8E8E8E0E0E0E0E0E0DAE0D7DAD7D7CFD7CFDA
CFCCC9D2C9C9C4C4C4C9C9C9C6C9CFC9C4C6C9C9C6BBBBC0
BBBBBBB7B7B7B7B7B2A9A9A9A9A6A6A6A6A69B9B9B9B9B9B
979B9DA69DA9A4A49DA4A4A49B9DA09D9D9B938B836C482C
2C2020201B201B202A1B1B15151B131B202C2C2C1B4B4B89
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F79E5A4843483B4343313939312C3120201B13
1B2C302C2C2C2C30313B4A5A627386A7A9B2C9CFD7D7D7D7
DADADADADAE0DAE0E0E0E0E0E0E0E8E0E0E0E8E8E8E8E8E8
E8E8E8E8E8E8E8E0E0E0E8E0E0E0E0DACFD7D7DAD7CFCFD7
CFCFC9C9C4C9C9C4C6C6C9C9C9C9C9C9C4C9C9C9C6BBC0C0
C0BBC0C0B7B8B7B8B2B2AAB2A6B7A9A9A6A9A6A9A6A9A49D
9DA6A4A9A49DA69DA4A49DA69BA49DA49D989381755E3B2C
2C201B1B1B20152C241B151513151B2A202C20132043436C
DAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7894F484A484B3B43313131312A3B20202020
202031312C20202C3B3B3B5E5E6C8398A9A9C4C9CFD7D7DA
D7D7DAE0DADAE0DAE0E0E0E8E8E0E0E8E0E8E0E0E8E8E8E8
E8E8E8E8E8E0E8EBE0E0E0E0E0E0E0DAD7D7CFDADAD7D7D2
D2C9D2C4C4C9C9CFC9C6C4C9C9C9C4C4C4C4C0C6C4BBC0C0
BBC6C0B7B6B7B7B2B2B7B7B2A9B2B7A9B2B7B2A9A9A4A9A6
A9A9A49DA4A4A7A4A6A6A4A4A49DA49D9B938B83644A312C
2C2C1B2020151B242C151B131B1520202020130C20434B48
B0FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7845A4B4B4348434B3B313B392C20202C2C13
202020202020201B203B394A5E62838BA7B2C0C9CFD2D7DA
DADADADADAE0E0E0E0E0E8E0E0E0E0E8E8E8E0E8E0E8E8E8
E8E8E8E8E8E8E8E0E0E0E8E0E0E0DAD7D7D7D7CCCFD7CFCC
CFC9C9C6C4C4C9C9C9C4C9C9C9C4C4C4C0C4C6C4C0C0C4C0
C0C0C0BBB7B7B8B7B2B2B2B7B2A9A9B2B2A9A9A9A9A6A9A9
A4A49DA4A99DA4A4A49DA49DA4A49D9B9B98836C5E3B3B2C
2C1B1B20151B242A1B2C1513131B202C201B04042C434B48
95F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7635A3B4A4B4F4F434331313939312C1B201B
20202013202020202C2C3B4B485A62738B9BC0BBC9C9D2D7
DADADADADADADAE0E0E0E0E0E0E0E0E0E0E0E8E8E8E8E8E8
E8E0E8E0E8E8E8E0E0E8E0E0E0E0D7DACFD7D7D7D7CFCFD2
C9C9C9C6C9C4C4C4C4C9C9C6C9C4C4C6C4C0C1C0BBC4BBC0
C0BBC0B2B8B7BBB8B7B8B2B2B7B2B2B7B2ADA9A9A9A9A6A9
A4A6A6A9A9A6A9A6A6A49DA4A4A49D9B8B83755E48312C2C
20201B1B151B311B0C0C1513151B1B1320130C13312C3B4F
95F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7635A30483B434A4B4B39393931312C202020
13202C2E2C2C2020313B3B4A4A48536C838BB2BBC6C9CFD7
D7DADADADADAE0E0DAE0E8E0E0E0E8E0E8E8E0E0E8E0E8E0
E8E8E8E8E8EBE0E8E0E0E0E0E0DADAD7D7D7DAD7CCD7CDC9
CDC9CFC4C6C4BBC4C4C4C4C9C6C4C4C9C0C4C0C6C0BBC4BB
BBC0C0B7B2B2B2B7B2B2B2B2B7B7A9B2ADA9A9A9A9A7A9A6
A4A9A9A4A9A4A4A4A4A4A49BA4A49D988673755A48313120
1B1315152C2A1B0C0C1B130C1B20151B13130C20362C314F
89F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F74F5A3B43433B4B484343313939312C202020
131B2020202C2C2C202C3B4A485A4A5E7381A7B9C9C9CFD7
D7DADADADADADADAE0E0E0E0E8E0E8E0E8E0E8E8E0E8E8E8
E8E8E8E8E0E0E8E0E0E0E0E0E0E0DADAD7DAD7CFD7CFC9CF
C9C9C4C4C9C4C4C4C4C4C4C4C4C9C9C4C4C4BBBBC4C0C0C0
BBBBBBBBB2B6B7B6B2B2B2B2B7B2ADA9A9A9A9A9ADA9A9A7
A9A9A9A99DA69DA49DA49DA49D9D9B8A83755A4839312C13
131B151B2A3B0C0C151B0C15131B131B04041320202C3B4F
84D3FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F73948434B48434A43434B3B31313120202020
20131B1B20202C202C2C314A5A4A5E535575A7B2C9CFCFD2
CFD7DADAD7DAE0E0E0E0E0E8E0E8E0E8E0E8E8E8E8E8E8E8
E8E8E8E8E8E8E0E0E0E0E0E0E0E0DADADACFD7DACFD7CCCF
CCC9C9C4C4C9C4C4C4C9C4C4C4C0C4C4C4C4C0C6C0BBC0B8
BBBBBBB6B6B7B2B2B2B2B2B2B2B7A9ADB2A9A9B2A9ADA9A4
A4A9A9A4A6A49DA4A4A4A4A49B9B988673755A483B2C1B1B
1B13152C2A1B0C0C150C15130C131315041313202C20394F
72C1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1
F7F7F7F7F7E8434843484B3B4B43484B433139392C202020
2C1313202020202C2C2C2C4B4F555E5E556C98A9B2C9D2CF
D7D7DADADADADADAE0E0E0E0E0E0E8E0E8E0E8E0E8E8E8E8
E8E8E8E8E0E8E8E0E0E0E0E0E0E0E0E0DAD7DADACCCFCFC9
CFC4C6C4C4C9C4C0C4C9C4C4C4C4C4C4BBC4C0C0BBBBBBBB
B2B6B9B7B7B6B7B2B2B2B2B2B2ADB2A9A9ADA9ADA9A9A7A6
A9A7A99DA79DA4A6A99DA49D9B9B8B83755E48432C201B1B
1B1B2C2A1B0415151513130C130C131313041B1B2C203B4B
6CC4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7E86F543B434B3B4B4B434B43393B432C202C20
2C201B202020202C2C2C2C43555A555E556493A7B2C0CFD7
D7D7D7DADADADAE0E0E0E0E0E0E0E8E8E8E0E8E8E8E8E8E8
E8E8E0E8E0E0E0E8E0E8E0E0E0E0E0CFD7DACFD7D7D7CDCD
C9C9C9C9C4C4C4C4C4C9C4C4C6C4BBC4C6C0C6BBB9BBADBB
BBB2B7B6B6B7B6B2B2B2B2B2A9B2B2A9A9A9A9A9A8A9A9A9
A7A9A6A7A6A49DA7A4A49D9B989386736C5E4A312C20201B
1B2C2A2C0C0C130C13150C130C0413130C131B1B2C2C3048
6CD3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7
F7F7F1F7F7E85A4F483B4B4843434B4B43393143312C202C
2C201313202C20203131313B4B4A5A625E5D8A9BB2C0C9CF
D2D7D7DADADAE0E0DAE0E0E0E0E0E8E0E8E0E8E8E8E8E8E8
E8E8E8E8E0E8E8E0E0E0E0E0E0E0DAD7DADAD7D7CFCFCFC9
C9C9C4C4C4C0C4C4C4C4C4C4C4C4B9C4C0C4C1C0BBBBBBC0
BBB8B2B7B2B8B2B2B2ADB2A9B2ADADA9B2A9ADA9A9A9ADA9
A9A9A4A69DA49DA6A49D9B9898938675625A3B312C201B20
31392C0C0C0C0C1515150C0C04130C1315131B20202C314B
77E2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7CD4B4B3B394B4348484B434F43393B392C2C2C
202C30132020202C1B203130374B555E6C638693B2BBC0C9
CFD7DADADADAE0D7DADAE0E0E0E0E0E0E8E8E8E8E8E8E8E8
E8E8E8E8E0E8E0E0E0E0E0DADADAE0D7DAD7D7D7CFD2CFCF
C9C4C4C4C4C4C4C4BBC4BBC4BBC0C4BBC0C4BBBBC0C0BBB7
B8B6B2B7B2B6B2B2B2ADADADB2A9ADA9A9A9A9ADA7A9A9A9
A7A9A9A4A49DA49D9D9D98939386835D5A433B3131313B31
2013131315151513130C0C0C0C1304131B131B20202C3B54
BBFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F1F7D348393B43484B434343434B4B393939312C2C
2C202C2020202C2C2C2020303B484A5D63628A93A7B2C0C9
C9D2D7DADADADADADAE0DAE0E0E0E8E0E8E0E8E8E0E8E8E8
E8E8E8E8E0E8E8E8E0E0E0DADADADAE0CFD7CCD7D7CFD2C9
C6C9C4BBC4C4BBC4BBC4C4C4C4C0BBC4C1BBBBBBC0C0BBBB
B2B8B6B6B2B2B2ADADB2A9B2B2A9ADA9A9A9A7ADADA4A4A4
A9A4A49DA49DA49D9B9899938B83735E4A4843393B312C20
1B151B15152013150C0C0C0C04040C1B13131B201B2C3B84
E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F1
F7F7F1F7F7B648433139434A434A48484B4B43433939312C
20202C2C13202C202C302043313B555E756C8A8A9BA7BBC9
CFCFD7D7DADADAE0DAE0E0E0E0E0E0E8E8E8E8E0E8E0E8E8
E0E8E8E8E8E8E0E0E0E0E0E0E0E0DAD7D7DACFCFCFCCC9C9
CDC6C4C4C1BBC4BBBBC4BBBBC4C4C4C0BBBBBBC0BBBBB6B2
B8B7B2B2B2B8B2ADADB2ADA9ADADA9ADA9A9A9A9A6A9A7A7
A4A7A9A6A7A49D9B98938B8A8675735A4A483B313B313115
151515151B15130C040C0C000C131313130C201304314B95
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7B94B4A4B3B48434B4F4B434B4F4B434339302C
2C202C31132C2C202C3131434843555E6C63839395A4BBBB
C9CFD7DAD7DAE0DADADAE0E0DAE0E0E8E0E8E8E8E8E8E8E8
E8E8E0E8E8E0E8E8E0E0E0DAE0E0DAD7DACFD7CCD7CFC4C4
C9C9C4C4C0C0BBC4BBBBBBBBC1BBC4BBBBBBB6BBB6B8B2B6
B8B7B8AAB2ADB2B2B2ADA9ADADA9A9A7A9A9A9A7A9A7A6A4
9BA69DA9A49D9D9B938B938673836C5A483B39312C2A2015
130C131B15130C000C15040413150C13151B1B131B3154BB
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F1E5C14B4B4B3143434F4F4B484B4B4B433943312A
2C202C2C202C202C31303131484B4A62636C868B93A0B2BB
C9CFD2D7DAD7DADADAE0E0E0E0E0E0E0E8E0E8E8E8E8E0E8
E0E8E8E0E0E8E0E0E8E0DAE0E0E0DADADAD7D7CFC9CDCDC9
C9C4C4C4C4BBC4BBC4C4C4BBBBBBBBC4BBB6C0B8B7B6B7B6
B2B6B7B2B2ADB2ADA6A9A9A7A9ADA9A9A6A9A4A9A9A6A9A4
A6A4A79DA79B9B98938B868383757548433B312C31201515
1315150C13150C0C0C0C04151B0C0C1B1B131313202C4FB0
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1
F7F7F7F7F1CA4A48433143484B4B4A434B4B544B3139392C
2C2C202C2C2C2C3131303B30434A4F626263818A939DADB9
C4C9CFD7DADADADADAE0DADAE0E0E0E0E8E0E0E8E0E8E8E0
E8E0E8E8E8E8E0E0E0E0E0E0E0DADAD7D7D7CFCDC9C9C9C4
C9C4C4C4C0C4BBC4BBC4C0C4BBC0C4BBBBBBBBB6B7B8B6B2
ADAAB2B6B2ADADB2B2A9ADA6A6ADA9A4A4A7A4A9A9A9A4A4
A79DA4A49D9B9D988B86838373755D433B2C2C2A201B1B15
201B151515130C150C04151B0C0C13151315131B31314F95
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7E8CA484B43313B394B5D4B4B484848543143392C
202C202C30312C2C3131313139485A5E6375838A93A0A9B7
BBC4CDD7D7DADADAD7DADAE0E8E0E0E8E0E8E8E0E8E8E0E0
E8E8E0E8E0E0E0E0E0E0E0E0DAE0D7DAD7CFCDCFC9CCC9C4
C9C4C9C4C4C4BBBBBBC1BBC4C4C4BBBBC1BBC0B8B8B6B7B2
B6B2B6B2B2AAADADADA9A4A9ADA4A7A9A4A9A4A7A4A4A4A7
A6A49DA49D9D9B938B8A8B836C6C5A4B3B31312C1B201B20
201B151B2015150C0C1B1B1B0C150C15131B1B2C20394FAD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7E8B9435D43313B43434B4B4B4B4B4B4F43434331
2020202C31312C2C31313B393943485E6C638186939BA9BB
C0C4CFD2D7DAD7DADADADADAE0E0E8E0E0E8E8E0E8E0E0E8
E8E0E8E0E8E8E0E0E0E0DADAE0DADADACFC9CCC9D2CFC4C9
C4C4C4C4C4B9C4BBC4C0C0BBBBBBB9BBBBBBBBBAB6B2B7B8
B7B7B2B2B2ADADA6A6ADA6A4A9A4A9A6A9A7A6A4A9A4A49D
A4A49DA69D9B989886837575755E483B3B312C2C2C1B1B1B
1B1B2C2C1B1B20241B1B1515130C15151B20201B203162CA
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F1F7F7F7F1D3634F433B2C3B43544F4B4B4F4B4343434831
2C20202C3139312C2C31314B4A4B4A5E6C63758381939BB2
BBC0C6D2D7D7D7DADAD7DADAE0E0E0E0E0E8E0E0E8E0E8E8
E8E0E0E0E0E0E0E0E0E0E0DADADACFD2D2D2C9CFC9C9C9C4
C4C4BBB9B6BBB9B6B9B9BBBBB9BBC1BBBBB8BBB8B2B2B7B6
B2B2B6B2B2ADADADA6AAA9A6A9A6A6A4A7A79DA4A79DA4A7
A4A49D9B98939581797375645A554B3B3B2A2C2C2C24201B
2C2C241B2C241B1B1B1515151B2C1B1B13040C1B2C63D3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7E8D34F4A4B39303143434F544B4F54434B314343
3020202C2C3931392C2C31394A4F5A5E75637575818A99A7
B2BBC9C9CFD7D7D7D7D7DADADAE0E0E0E8E8E0E8E8E8E0E8
E0E0E0E0E0E0E0E0DADADAD7DAD7DAD7CFCDC9CDC9CDCDC4
C4BBBBB9BBB9BBBBBBBBBBC4B8C4BBBBBBB8BBB7B8B2B8B2
B6B2B7B2B2B2A6A4ADA9AAA9A9A9A9A99DA9A4A7A6A4A49D
A49D9B98988B8B86837364555A48483B30312C2C242C2A24
2A312C15150C0C151B1B1B1515040C130C041B2C2087E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F1F7
F1F7F7F7E8CA4F433B43393143484F5D4B4B544B4B394343
392020202C3B393131313139484F4A4A62636475838193A7
ADB7C9CFD2D7D7D7DADADADADAE0E0E0E0E0E8E0E0E0E8E8
E0E0E0E0E0E0E0E0DADADADADAD7CFCFCCD2C9C4C9C9C4C4
C4B9B9BBBBBBBBC4B9BBBBBBB8BBBBBBBBBBB8B2B8B8B7B6
B8B2B6B6B2AAADAAADADA9A9A9A6A7A6A9A6A9A4A79DA49B
A79B9D98938A81797362555A48483B3B312C2C2020201B2C
202024150C0C1B1B0C0C040C0C0C0415041B2C2031A4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F1F7F7D35A4F3943393B484B4B5D434854544B433B43
43202020312C3139393931313B4B5A486C62556C75818A99
ADB2C9C9CFD7CFD7DADADADADADAE0E0E0E8E0E8E0E8E0E0
E0E0E0E0E0E0DADADADAD7DACFD7D7D2C9CFC9CDCFCDC4C4
C4BBC4BBB9C4BBC1BBBBBBC4B9BBBBBBBBBBBBB6BBB2B6B2
B2B6B2B2B2ADB2ADADA9A9A6A9A9A6A9A4A79DA4A4A4A4A4
9D9B9D988B8A8373755B5A554A48392C2C2C2A201B201B1B
1313202C1515150C0C0C0C0C000C04130C2020203BA4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7E2635A48433B314343434F4B434F544B4B3939
43311B202C39313B3943393B313B5A4A626255556C818A99
A7B2C9C9CFD2D7D7D2D7DADADADADADADADADAE0E0E0E0E0
E0E0E0E0E0E0DADADADADAD7DADAD7CFCDCDC9CFCDCFC4C4
BBC4BBBBBBBBBBB9B9B9BBBBBBB9BBBBB6B6B8B2B8B6B2B6
ADB2B2B2ADADADA4A8A6ADA9A9A4A9A9A4A6A09DA79DA79D
A79898988B8383755B5E55483B3B3131312C2C2C201B1513
13151B1B2C1B0C0004130C040C040C13131B203148B6FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F1F7F7F7F7D36F4F433939314848434B5A4B4B4F4B434339
433B2C201B313B313943432C313B484F4F5A5A536C798199
A4ADC9C9C9CFD7D7D7D7DADADADADADAE0E0DAE0E0E0E0DA
DADADAE0E0E0D7DADAD7DADADAD7CFD2CFC9D2C9C9CDC4BB
BBC4BBB9B8B9B9B9B8BBBBB9B6BBB6B9B8BBBBBBB6B2B6B2
B6B2B8ADA6AAA8A8A4ADA9A4A6A4A7A4A7A4A4A4A4A4A49D
9B98938A86756C625D5A4848433B3B2C2020202020201B1B
1B1B151B151B0C0C1500000C04040C0C13202C3B4AD3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F1F7F7E2895A433B3931394B43435A4B4B4B43434B39
3939312020202C3B2C3B4339303943554F4A55556C837993
A7B2C9C9CFC9CDD7D7D7D7DADAD7DADAE0DAE0DADAE0DADA
DADADADAD7D7DADADADADAD7CFD7D7CCC9CCC9CDC9C4C4C4
B9BBBBB9BBB6B8B9BBBBBBB8BBBBB9B8BBBBB6B8B2B6B2B6
B2B2ADAAADADA6ADA6A8AAA9A9A9A9A69DA49DA49D9D9D9B
98938A83797575755A4348483B3B2C2C20202013131B1B0C
15151515151513150C0C0C0400040C151B2031434FFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7775A4F3939393B4B39434B5A434B4B433943
393B4B312C201B2C3B31314B43393B485A4A4A485564838A
93ADBBC9CFCFCFCCD7D7D7DAD7D7DAD7DADADAD7D7DADAD7
D7D7DAD7D7DACFD7DAD7D7D7D7CCCCD2C9CDC9CDC4C4C4BB
B6BBB9B6B6B6B9B9B8BBBBB6BBB8BBB2BBB6B9ADB1ADB6B2
B2B2B2B2ADB2ADADADA9A7A4A9A9A9A9A4A49DA79B9B9B98
8B818383756C5D554A483B3B3B312C2020201B1B1B151B1B
20201B1B150415150C1304000C0413152C394848A4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F1F7F7F1F7F784635448484331543939485D43435D433143
433943391B2C20202C3B3B4A4B393B394F4F4A48535D6C81
8A9DB2C4C9CFD7D7CFD7D7D7D7D7D7DADAD7D7D7D7DAD7D7
CFD7D7D7DADAD7D7D7D7D7CFD7CFCDC9C9CDC9C4C4C4B9B6
BBB6B9B6B9B6B6B6BBB9B6B1B6B9B2B6B6B6B6ADADB7B2AD
ADADB2ADADB2ADA9A9ADA6A9A9A9A9A69D9D9D9B98989893
938383736C5D5E5E483B303B2C2C201B13131B1B1315131B
1B1B1B201B1B151B0C000C0C0C131B2039393B72E2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7776C5D4B39393B4B4339394F4F435D433143
4343394B1B2C2C20203139434B43313B434A484B485D6C83
8198A9B2BBC4C9D2D7D2D7CFD7D7CFD7DADAD7D7D7DADADA
DAD7DAD7D7CFD2D7CFD7CFD7CCD7C9C9CDC9C9C4B9C4B9B6
B6BBBBB9B9ADB9B9B9B9B9B2B2B9B6B6B2B2B1B6B2B1ADAD
ADA8ADAAA8ADA9A9ADA9A9ADA6A4A7A6A79B9B939393938B
8A75756C5D5E5555433B302C2C2C201B131313131B131B1B
1B1B1B1B1B1B15151B0C0C15040C1B31393B489EF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F77763634F3943394B4B39394B4F4354543931
393939392C1B2C2C2C2C303B48433931304B4B4A3B556275
8693A7B6BBC4C4CFCFCDD2D2D7D2D7D7D7D7D7D7D7D7D7DA
D7DADAD7DAD7CCCFCCD7D7C9CDCFCDC4C4C4C4C4BBB9BBB6
B9B9B6ADB1B2B1ADADB1B1B9B9B2B6B2B6B6ADADADB2ADAD
ADADB2A7A8A9ADA9A4ADA99DA49D9DA49D9B9893938B9386
73756C62625348483B3B3B2C202020130C131315131B151B
15151B1B1B1B1B1B1B0C0404041320393B315EC4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F79E636F63433943434B43434B4B434F54432C
3B4B3931392C20313139313943544339393B4F4B4B485E75
75819BA9A7B9BBC9CFC9C9CFCFD2CFD2D7D7D7D7D7CFD7D7
D7D7D7D7CFD7CFD7CFD2CDCFD7D2C9C4C4C4C4C4B6B6BBB1
B9ADB6B1ADB2B6B6B2B1ADADB2B1B1B2B6B2B1ADADADA8AD
ADADADADAAA9ADADA9A9A4A9A7A6A79D9B9B9D98988B8681
8375756C555548483B302C2C202020131313131B1513151B
201B1B1515150C0C040400000C1B313B2C4863D3F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7B66C6C5D5443433B4F4B43434B4F4B544B39
3943432C43311B202C36394843434A4331314A484F55485D
758399A9A7ADBBBBC9C9CFD7CFCFD2D7D7DACFD2CFDAD7CF
CCD2CFD2D7D2D7D7CCCFD2CFC9CDC4C4C4C4C4BBB6BBBBAD
B1ADB6ADADB9B1ADB6ADB9B1B1ADB2B6B2B2ADADADADADA4
AAADADADA4ADA9A7A7A99DA69BA79D9B989898938A8A8173
836C5D5D5A48483B302C2C2C2C201B13130C0C1313151315
1B1B0C150C0C04000000000004203B2C314A84EBFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C46372774F483B394B43433943434F545D48
31434B313139311B2C2C313639484B4B43314B4B434F5A55
5D758BA7ADB2BBBBC0C9C9C9C9C9C9D7D7CFD7CFD7D7CFDA
D7CFCCD7CFCDC9D2CFCDC9CDC9C9C6C6C6C4BBB6BBB6B6B1
B1B9B6ADB1B1A8B9ADB9B1ADA8ADB9B6ADB6ADA8ADA7A7A8
A0AAA4A7A6A7A9A4A9A6A4A4A49B9D9B9898988B8B868375
6C625D5A4848483B302C2C2C202013130C0C0C0C0C0C1515
1315040C0400000000000000132C312C39489EF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F1
F7F7F7F7F7F7E5875A5A544A4339434B4B43394B394F4B4B
3939433920202C3131203131433948435A5D3131434B4B48
5A62738193A7A9B2B7ADBBC0C4C9CFC9CFD7CFCFCFCFCFCF
D7CFCFCFD2D2CFCFC9D2C9D2C9C4C9C6C0B9B2B6ADA8A8A8
B1ADB1A8ADADA8ADADADADA8ADA8B1ADA8ADADA4ADADA8A8
A4A0A4A4A0A4A0A4A09D9D9B9D989893938A818175756C6C
6C5555483B3B3B3B2C2020201B1315130C040C0C15151515
15150C04000000000000040C132C2C3B305ED3FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7A76C5E4F4F4B39434B4B433943434B5448
433B43392A1B2A2A312C2A393943394B4B4F39313B484A4F
485A6C75839598A7A9B9BBBBBBB7C0C9C9C9CFCFC9D2CFCF
CFCFCFCFCFCFC9C9C9CFC6C4C9C4C9C4C0B6A8ADADADA8AD
ADB2ADADADA7A8A7A8ADADADADADA8ADADADA8ADADA4A0A7
A4A4A0A0A49BA49B9B9B989B989B93938B8381737575756C
6C5348483B3B303020202C201B1B130C130C13150C0C0C0C
0C1504040004000000000C152C2C31393784F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7BB725E4F4F4B43434B4B4B3943434B544B
4B313943312C202C202C36313939434B4B435A392C39434F
4F4B5E6C7573818AA7B2A9A9ADB2B7BAC0C9C9C9C9C2CFC9
C9C9CDCFCFC9C9C9C9C9C4C4C9C4C0C1BBB2A6A4B2ADA8AD
ADA8ADA8A7A7A7A8A8A8A8A8B2ADADA8A8ADA7ADA0A8A4A8
A4A4A49D9BA09B9B9B999B9898938B8B8A81837575756C6C
5E5A48483B313030202020151B1B131313130C0C0C040C0C
00150400000000000004131B2C20313139C4FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFD380635A4F4B43484B4F4B433B4543544B
43393B43312020202C152C392A3943434B4B4F5A362C2C43
4A4F4A555D6475818B93939B9B9DA9A9BABAB7B7C9C9C9C9
C0C4C2CFC0C9C4CFC9C4B9C4C9C4C0C0C0B2B2AD9DA4A4A8
A4A7ADA4A4A0A4A0A4A8A7A8A8A4A8AAAAADA8A4A4A0A4A4
A0A0A09B9D9B9D9B98939B9393938A8A86737575756C5D55
5548483B3B302E2020131B2013150C0C040C0C0C0C0C000C
0C04040000000000000C152C2C31312072F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E5A46C5E5A4A3943484B4F4B3948434854
48483139312C1B1B2C2C204B432C3939434B434F634B3931
3B4A5A4A555E626C7575818193989BA9B2B2A9A9B2B2BABA
B7C0C0B7C0C0C0C6C0BBBBBBC4C0C0BBB7A9A4939593999B
A09BA09B979DA0A4A0A7A8A6A4A0A0A0A7A4A4A4A4A4A0A4
9D9A9DA49B9B9D9B9B9B98938B938B868381757364555355
55483B37302C2020202013150C180C0C15040C0C15150C0C
040404000000000004152031202C2030B9FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7C172635D4F4339434B4F434343434354
544339393B2A2C1B2C2C1B314B4B393939394B4B4B634F43
313B4A5A5A5E5E5E5E6C8079818B988BB2A998A9A9B2B2A7
BAB2B2B2BABBB7BBB7B6B2C0C0BBB2B2A99D998A86818A88
8A95999395999DA0A49D95A0A49D99959AA09DA0A4A0A49D
A09B9B9B9B9B9393939893938A868681836C6C5D5D55555A
43483B312C2C201B20150413130C0C0C0C0C0C0C0C15150C
04040000000000000C1B3120202C2055E8FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7D377635A4F4339394B4B4B4B4343454B
5443433936362C1B1B202C1B314B5D4B43434B4B434B4F4F
4B433B484A4F5E5E63738173738B8B989C989898B29CA79D
A99C9DA9B2A7A8B2B7B2A9BBB7B7B2A69898808186817986
8A88888A959799999B9A97999B99979799999BA49B9D9BA0
9B9997939393958A9393938B8A868173736C5D5D5B555348
483B3B2C2C2020201317131513130C0C0C0C04040C0C0C04
040400000000000C1B2C2C202C203177F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E595625D5A4B3943434B544B36434343
544343392C3B2A2C201B202C202A39545D54394B434B4B4B
4B4B4B4A4A4A4F5E63636C73737398879D8B938B98988B8B
A7989D9D9D9D9DA9B2A6A7B2B7B79D98988A837581736C79
7981818A818A9597958A95979797999799999799999B9993
95999395938A95938B8A8B8A818183836C645D5B554A5348
48302C2E2C2C2C201B13131315130C0C0C0C0404040C0C04
0000000000000415202A202A2C204AB6F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D0846C5A4F433B43434B4B43433939
43544B432A2031312C1B20313639313931395454484F4339
43544B4F545A5A5D5E5E5D5E6275838372737383838B8381
737383837386869398A99C98989D8A7373736C636C75756C
75756C75757D8888888F8F8A8F939595939595938A88818A
8A888A8A8A8A8A81867D868175756C6C755E5A534A3B3B3B
302C202C202C2C1B1B130C0C130C0C0C0404040000000000
000000000000152C2C202A20204F9EF1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F18D7263544B4339484B4B43394339
435D4B4B362C2C312A1B2C2C3B39433943454B5D5454544F
4B435D544354545D545A5A5E6273736C6C7572737283756C
6C757383757375838B9DA79A8B8B8383736C6C636C55625D
645D626473797D797D888881888A888A958A88888A8A8A81
798181817D8186818181798373756C625D555553433B303B
30202C20201B20201313130C0C0C0C0C0404040000000000
0000000000042C2C1B2A20202C72DAF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7B9776C4F4B4343434B4F43434839
3954544339291B2C312C2C2031433948394B54484B4B4B4B
4B4F4B545D545D5D635A5E636C6C63756C63756C756C756C
756C757375756C8375838B9D8B7373738073636262625A55
5E5D62555D7975747479817D8181888A888A8A868A868181
797975757975797375737575756C625B55533B3B3B3B3B3B
2C2E2C20201B202013150C0C0C1513040004000400000000
00000000000C2A2020201B2031A4F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7D38977544B484343434B4B394848
36435A4839312C1B2C392A3131393B4B54484B545D4B474B
434F5D5D63635D54545A626375625A63636C5E626262625E
62625D6C6C6C5D7575757575837375637573635E5E5E555A
555A5B5E556C646C6C7973747979797D8186818379837575
757575756C7575756C626C6C6C62555A5548483B3B303030
2C2C20201B131B200C130C0C040C0C0C0404000000000000
000000000C1B20202A1B1B3039D3F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7E5B6845D5A4B434343434B433943
43434B4B39392A2C242C393131434B4B5454544B5D5D5D5D
47485D5A5D5D5D6F5D635E636C4F63755E5E5E5A5A4A5A62
4A555E5E5E5B5A62646C626C6C7562625E5E625A4A5A555A
554A4A5D55555B55646473706C73747973737375756C6C6C
756C6C6C6C6C6C6C6C6C5D5D6C5B55554848483B3B302E2C
2C202013131B1B130C0C0C0C04040C000000000000000000
0000000C152C1B31201B2C3063F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E29E634F4F434843434B433943
48434854433931201B36313139394B4B545A545D544B5454
5D5443545D6C6C63635E626C635E63625A554A4A4F484F6C
485E5A534A5A555E555E5E5E625E635A4F5A5A5E4F4F4F4F
554A4A3B53555355555E5B5B6C6C6C646C6C6C64645D5E5D
6C645B5E5B5D6462625D5D5555555A48483B30302C2E2C2C
31201B131313151313040C130C0C000C0400040000000000
0000040C202C2C20152039398DF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E5B06F4F4F4B4343434B4B4339
434543544339312C2C29313939393943545D63635D54544B
544B43434B4F4B4B5A5E626C4F4F5A4F5A5E434843484F5A
4B4A485A5A5A4A5A4A555A555A5E5A5A5A544F4F4A484843
4A4B48483B484855535355535555555B5D5E55555355555E
5B555A5548484855535E55555A4A53483B3B3B302C302C20
2C1B1B1B130C13131B0C0C0C040C04040000000000000000
00040C1B2C1B2C151B393039B9F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1DC956F544F434343434B4B45
3948484354434339312031484B4843545D5D5D544B4F635A
545443434F545A5A5E5A634F5A625A48554F484839434F4B
3948434A4F4F3B374F4A484A5A5A483B434A544343432C39
3B3B394839373B3B3B3B3B3B484843484348484348484848
48393B3B3B483B373B3B3B483B3B3B3137302E2020202020
1B2015130C0C0C131315150C0C0C0C000004000000000000
0C15201B2031152C313748B9FFF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E895845D4F4B4B43394B4B48
39434843545443433936314B545D4B545D5D5D5D5D544B54
5D5D544B434A4F4F5A63634B4A5A4B484B4839433B394343
39393B434B4F4339485A4B3B4B4A4F432C3143484339312C
313130313B2C30303B303B483B483B303B3B3B3B3B393B3B
3B3B3B373B48303B3B3030373B3B3B302C2C202020202013
2020130C0C0C0C150C13180C0C040400040000040000000C
15201B202A202C2C303987F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E2B0806F4F4F434843394B4B
43314348434B4B43433939394B6C5D5D545D636F5D5D5D54
4B4F43394B4B4A4A4A835E43554B484B484B393B43393943
31393148434B394F2C4B4F43434B4348433936393939392C
2C313131312C2C2C2C303030303B3B303B3B3B3B3B373B2C
3B3B372C30303B30303031302C3B303B2C2C31201B20201B
13201B0C0C0C0C130C0C0C040C0000040000000000000015
24201B2A2015304B4373D0F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1CD95775D4F4B434B39434B
4539394843484B4B4B434339364F5D5D5D54545D636F5D4F
4B434B4B4F4F4B4A5A6C4F4A5A434848554B314343393943
39432C43434B4B43392C4B4843434F3931313B312A312C31
31202C2C2C2C2C2C2C202C2C2E3043302C2C3B3B2C2C2C2C
3030312C2C2C30302C2C2C2C2E2C2C2C2C202020201B131B
1B131B150404040C15040C0C0C0C0404000000000000041B
201B2C2C1B1B314F4AB6FFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7D3B095774F4B434B433B43
4B433643484343475D544B4739394B5D6C5D48545D5D5D5D
5D6C5D5D544F5A4B4F6348484B4B48434F4B314843434343
36393639434B4B31432C314B433B43393B3131312A2C312A
2A2A202C202C2C2C2C20202C20203031202C2C31312C2C2C
2C202C302C2C202C2C2C202C2C2C202C2C202013201B1B13
130C1B150C04040C0C0C0004040C000000000000000C1520
1B2C2C15152C304A87F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E2B989805A4B4F4B434343
434B4343544343434B5D54545D4B36394B5D5D545454544B
4B4B4B4F4B4B4B4F63553B434B4843394339393939394343
3B39392C4B3B432C433B2A43433939312A2C2A2C1B2C312A
2020201B20202C20202C1B2C201B202C2C202C2C2C2C2C2C
202C2C202C2C2C2C2C20202C202020202020131B13131313
15130C130404000C0C040C000C040000040000000C0C1B1B
2C311B152C205A95CAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E2CAA4A46F4B4B43484B43
435448364B47433943485D5D5D5D6F4B3943544B54544B43
393131434B4F4F4A5E4B3B484B484A434343434343363948
3936432A4F3936392A432A2A36392C2A2C2C2C242C242020
201B1B201B20202C2020201B2C201B202C1B202020201B2C
201B2C20202C20202C2C20202020132020201B131313040C
131513150C04000C0C150404000C0C000000000C0C1B1B2A
311B15202C2087CAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2CA89776C4F43434348
43394B5443484B483939396C5D6C5D5D6C63433143544754
5D5D5D544543434A5A303143433B393B434336394536434B
2C364336314B2C3B2A2C312A361B2A2C152C2C1B24241B1B
1B1B1B1B1B1B1B1B201B20202C202020202C202C202C1B1B
132C132C1B13202C202C151B201B1B1B1320201B130C0C04
040C040C0C00000400040C0000000400000C0C1B1B15201B
0C203120208DE8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D3C187725D4B39434B
4B4343543139394348363147545D5D5D5D5D5D4536363954
5D6F6C5D5A43434A4A203B4339393939314331434343434B
2C312443244B362A2A2C241B2C29242A2C1B24201B1B1B1B
151B1B13151B1B1B1B201B20201B1320202020132C20241B
13131B1B1B13132020201515201B13151513201B15151B15
0C040C0C0C04040C0000000C000000040C151B1B1B203115
202C203962D3E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2DCC195774B433943
4B434348433643434B483939434B54545D5D5D5D5D545D54
433943433943484B4B20303B393B43393131313143433943
242C2C392A3B43241B1B2C2A132A2C292C1B1B201B1B201B
1B15131B1315131B1B151B1B1B20131B202020131B202C1B
151313181B1313131B1B20131520150C0C151B1B15131B15
130C040C0C000404000000000C0C000C151B151520311B2C
2C2C396CA4F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3DCC4894A434343
4B4B4B434B433943434348393636434B54545D5D5D5D544B
4848484B39434B4F482C313131434343392A2A3639393939
292C242C362C432C2A1B24242C151B24242C1B1B1B151B1B
1B151515131315131B1B15151B2015131B1B1B20131B2C1B
0C1B130C131B1313201B2015131B13150C0C1B1B13151315
150C0C000C0C0C04000000000C0C15151B151520311B1520
2C3055A4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1E2D3B05A4B3948
434B544B484B3939394345395454484848434B5A6C5D5447
5D5D544739393B433920312C31394843392A2C2A39313639
392A2A2C2924391B2A1B1B2024151B152C2A2C1B1B1B0C15
15151E1515130C0C151B1B1B201B1B0C131B1B1B15132024
150C1B15131B1B131320201313150C0C0C0C0C15150C0C0C
0C0C000000040000000000040C0C151B15132031131B2C2C
394A95F7F7E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5D3CD635A4339
394B4B434B54483943434845434B5D544845433943545D54
5D5D6F54434331393B2C2C2C2C313943392A2C2A43293143
392A292A36202A1B20291B20242C151B151B2A242015150C
151515150C150C0C0C1B1B1B1B1B13130C131B1B1B15132C
1B0415150C0C1B150C1B1B1513150C0C15150C0C040C0C0C
000C00040C0C00000000040C0C131515152A392A29393131
4A77E8F7E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3CA896F4B43
3943434343545448454854453636434854545D4739364345
43485D543639393B3120202C2C313139392A2C2A39362A39
361B2C2A31201B361B2A241B1B200C15150C1B201B1B1515
0C15151515130C0C040C1513131B1B150C0C0C0C13151513
2C0C0C1B150C131B131515150C0C0C0C0C0C0C0C0C0C000C
0C0C04000C040000000C15131515150C202C1B2C20201348
73D3F7E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1DC87725A4F
433948434343545D4843435445393948545D545454483939
45545D543943393131202C2A202C2C3B392A2C2A312A2C24
2A20132A20201531241B241B1B15150C1515151B1B201B15
0C0C150C150C0C0C0C0C15151B151B1B0C0C0C0C0C131515
1B1B0C151B0C0C1515130C150C0C0C0C040C0C0C04040400
04000004040000000C151515150C0C2A2C15201B131B2C63
BBF7F7E8F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A787775D
5443394B4B43394354454336434843434343545447483936
393636292C364B3B31202C1B1320202036312A2C242A2C24
2A362C131B311B1B2C15152C150C1B1B150C15151B151B15
150C0C0C0C0C0C0C0C150C0C151515151B15040C0C0C0C0C
1515150C0C1B1B0C0C150C0C15000C0400040C0000000000
000000000C15151515150C0C13202C1B2C1B132C395D6CC4
F7E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2A78472
635443394B4F43434B544839434343434348364343484B48
4336362A2C314331311B2C201B2020132A2A2A20202A2420
2A313915152C29152024151B1B04151B150C15151B1B1B15
0C0C0C0C0C0C15150C150C0C0C0C1B1B1B150C0C0C0C0C15
151515150C0C2420150C15040C0C04040000040000000000
00000C151515201B150C0C15241B152C1B1B2C3B556C75E8
E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D39577
6F5D4B434B4B4B43364354434B4536434343544B48363643
3129241B2C3B4A393120201B1513201B2C2A2A201B20201B
241B451B131B360C151B1B131B15151B130C0C0C0C1B150C
150C0C0C0C150C0C15150C0C1515151B151515000C000C15
150C1515150C152924150C0C000400000000040000000000
0C151B1B1B1B1B0C0C151B151B152C20203148555E6C73E8
E2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1BB87
77635A4B394B4B5443394843484B5D48484B4B4754545445
454536242C434B31312C201B1B131B1B20202A2C1B1B201B
201B36240C1B2A0C0C131B0C151B0C1515150C150C0C1515
150C0C0C0C0C0C0C150C150C0C15151B2C291515000C0C00
151515151B200C0C15200C040000000000000000040C0C15
151B241B1515151315151B2C2C2C20303B48485B7573B0E8
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2A7
8062635A39434B4B4339435445394B5D54484F4B43434348
4843292A2C43433B2C2020201B151B1313202A2A1B1B151B
1B1B1B290C152015130C15150C0C150C1515150C15001515
15150C00000C0C150C15150C0C15152029362929150C0C0C
0C15151515151B150C0C1B1B15150C0C040C150C15151B20
1B2415150C1B15151B2C2A2A20202C3B4848556C6C8DD3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2
B0806F5D4B39434B4B483948484539394854474848454345
393136241B434B432C1B2A2015131B13151B2020201B151B
131B13200C0C151B15130C1B150C0C1515150C0C150C0C15
15150C0C0C0C0C0C0C0C15150C1515152939294329150C0C
0C0C15151515151B201B151B1B20201B1B151B1B1B15151B
241513150C1B151B2A2A201520313B3B3B556C7572ADE2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E8A784625D4B434B434B484348484B4736365D5D5D4B5354
5345392C2C4B4343312020201B13151B1B131B201B1B1B15
15131515150C132415150C131515150C0C15150C0C15000C
15151500000C0C0C0C1515150C0C151B153647295D391B15
0C1515150C0C1515151B201B201B2020201B1B1B152C292C
1B150C0C1B312C2C2015132C3B483B3B5364706C8DD3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1C4877263544B48434B43393948485454544754545D48
54544836364B4343392A202C241B151515150C1B201B1513
151313151B0C0C151B150C15150C0C150C150C0C0C0C0C00
0C151B150C00000C0C0C0C151B1515151520365C4D294353
47201529241B15150C15150C151515151B24241B1B151515
15203636392C1B1B313B3B312C3B485A5D6C6CB9F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7C172726354544548484B43434B48435D5D54484336
3936362C2C4B4F3939312C202020201513131515201B1513
131513131520041B1B150C0C15150C151504150C0C0C1500
0C0C15200C0C000000040C151529201B231515475D5C4729
4348482936243629292015150C151515151515150C1B2C2A
31313B3113152C313B312C2C3B3B485D6C73B0FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F17472776354544B4B484339364336484854545454
545445453643543B39392C2C2C1B201B0C0C15131B201B15
15150C15131B0C0C1B15150C1515040C150C150C0C0C150C
0C0C151B0C0C0C0C00000C0C0C2439292935233647535D47
242C242929362929363624241B201B15151B1B202C2A3031
392C2A202C39313B2C2C3B3B3B48556C6C95F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7CD876C6C63635D474843433936313945484B4848
48545D544B434B433939312A312C20200C0C130C15201B1B
131315131515150C151B150C0C150C000C150C150C0C0C15
0C0C1515150C000C0C0000000C0C1548362943292443535D
5353362424242C202C242A2929241B202A3131313131201B
20312C3131313131314B48485A5E5D6395F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFD3746C72635D5454544843393643484848535D
5D5D4848544743393B433639313120201B0C0C15151B1B1B
0C15130C130C1B0C15151B0C0C15150C0C0C1515150C0C0C
0C0C0C15150C0C0C0C0C0C0C0C0000154747393939292948
5D5D5C545D5447454539454B5445454539362C1B1B131B2C
31393131313939394B4A484A555D5E8DF1FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C4876C7263545454544B4343394347545454
54475D5C5D5D4B433943393931363120241B0C0C1515201B
130C1B1515131B0C0C15150C0C150C150C0C0C15150C0C0C
0C0C151515150C0C0C0C0C0C150C0C0C1543484748393529
2429433643475D54544B4B4B4343393124201B2C31394843
434343484343434B483B4848555D64D3F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D38F6C635D4B4B484B4B48393643484B47
54475C5D6B5C5D54393939363B31312A2C2A150C15151B2A
201513131515130C0C151B1B0C0C0C0C0C000C15150C0C0C
0C0C0C151515150C000C0C0C1B1515150C15204739434347
47393635201B151B1B1B2A36313139393939393939434B43
4343434343483B3B3B3B4A5D6C6C77F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E8955A5D5D544B43434B4B4B544B54
47545D5D5D746B5D5431393131393939312C313920151B1B
2A201B1B15151B200C0C151515150C0C150C0C0C151B0C0C
0C150C151515151515150C151515151B2924242015244343
43432A313948434B5447484B4B5448484336364339433639
36312C2C2C3B3B485E6C5E5D84C4F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F772625A54635D4843484B54545D
5D545D5C5D5D6F5D5D3B313131393131312C2A2A43391B20
362A2A202015241B1B040C1B15150C0C151B150C0C15150C
0C151B1520151515152015151B2029151515243636242324
43474520151B1B241B1B241B1B2C1B15152A2A2A202C3639
312C2C303B4855556C5E6377D3FFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7A4726C544B544F4B4843434B47
5D5D5D5D6C6F8089804B313131313939312A2C2C2A43392A
363636362A201B1B291B0C1B151B150C0C1524150C151B15
0C1524202020151B2020361B151B24352015151B24293620
201B3648452924151B1B15202A242C2A312C202C31393B2C
2C3B3B435A4A555E625D77D3F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7A7776C544B434B4B4B4B4848
54475D5D6F748084744B4B393031313131312C2C2C2A3139
393939393936202A244520152C1515151515151B1B15241B
1504152A39291B15292024471B2424434739292929292920
20201B1B363636362A2A3936363631312C3143393B2C2C3B
3B4A484B48555D625E95D3F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7CA80625D5443434B4B4B43
4354475D6B6C6F74746B5D54393131392C2A312A2C2A2A2A
3943393643432936204753151B24240C15242C202A24241B
291B150C36392929244D352447292A24435C534B47473936
352A292A24242939454331363131313B3943313139434A4F
4A4855556C6C625EA4F1FFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7D08D6C6C4B4339394348
4B475D5C6F6F6F7474806F635D433631312C2C312A2C2C36
2C39434343453936361B54471524201B0C152A3629362435
293635293653364729366D444B6B5324201B43475D5D4745
45454339434343394343393B39394343433B4B4F5A4F4B48
435A556275625E5DF1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D39B805D4B4B433943
434B545D5D6F6F8089807453545D4B434339312A2C313631
242C3139434B4B454536244835152029200C1B2436363936
47364847395C47394B36395C39366F6B4B35292A36454345
433939433939393943434343434343434B4F555A4F484848
48556C6255484F9EF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5C46C635A4B4343
36395D53545D7A806F8089806F5D5D544B4B544B392A3939
2C2A2A39544554454B54392C5D353120392915152C394745
3939485C5C6D5C47475345366B47475C475D5D474745484B
453939434B4B4B4F4F4B4B54544A4A4F5548433B48484853
556C5E48486FBBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3BB866F635A
544F635D545D5D5D5D6F6D778080745D6354636F6C6F635D
544B4336364B4B455D5D5D5443545C5347455D3915155C53
43484748475C5D6D5C5C5D47454539434B5D5448454B4343
4B43434B4B4343484343483B3B434348485555555E5D645D
5A395AA4F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5CA9B7774
5D545D544B4B5447546F74806D6F746F6F77746F6F746F6C
746F5D5445454B4B475D5D6B6B545D5C745347624529245D
473639364545475D6B5C54484B544B4743434B4F54545A4F
4F4F4F4A4A48433B4848484B4B48555A5E5D5D6C75645A55
4872BBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E2B6A4
87775D545A5454545D6F7474747489896F77776F63747774
6F636F746F6F5D4B4B4B545C746B6B5D6B6D5D5D5C53242C
43433636313947545D7453454B4B4B4F4B544B4B43484343
43433B393B3B3B3B434B4A4F554F5E5D5E626C6255554839
4FD0FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D0
A7775C63545D5D54546F6F74806F746F6F746F6F63636F6F
74746F746F6F6F6F535D5D5454746F6D5C545D6D6D5C4745
39363939292A313139435D6F4B4B4B434B483939393B3B3B
3B393B3B39484A4F554F5A5D5E5E5D625D755E5548394A72
CDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E5B5896F5A545A545D485D6F6F6F746F806F6F6F6F6F6F6F
746F6F7777726F8477746F6F545474747474535D74745C54
454B454539362A242A2A314363544343434343393B434843
4B484A4A4A4F4A554A5D5D62626275626C5E4839395E8FE8
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7C19B745A5A5C5D545D6C5C747480897474748074746C
7474636F7480777780847474776B74746F80806B546F746B
5D534B39454545393939364343545D5D544F434F4B484B4A
555A4F4F5D4F5A5E62636C75736C75625539436287CAFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF1CD9B806C636354545D5D6F6F746D6F6C5D748980
6F7274746F74746F778977848477776F6F778080746F746F
5D6F6F635D5D5A54545454545C5A544F4F545A4F5A4A4F5A
4F4F5D636363737380737273756C5548485E95D0F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E58F5C4F3E544B4B535D6D9595807480
89848084898077746F6F747784777777777777776C728489
7777776F6363636F6F626C62626363636C63626C63737272
727280808377836C6C834F4A434A5E87C1FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7CD9B895C545454546F6F89898089
898989899595807777776F74807777777780878789807272
77778072726C6C63636C6C63636C636363636C728077838B
8B8B8B84838B8375625A4F5E6287C4F1FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E2B5A4A17D747D7D959E989E
BCAF9E959E9E9E878480848477775D747777848487848489
8484848477777772846C72726C6C72727777808484848377
6C63636C6C4F4F4F4F556C74BBF7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E2E5E8D3D3DCCD
E5DCBCA7BBB59EA79E9595808080847777746F6F6F6F778B
878D8D8484847772777772727272778072736C726C6C6362
636C6C5A4F4F4F4F6272D3F1FFF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1E5E5
E8F7CDBCBCD3B5E2BCA79595959E877777847272746F6B63
74777784778484776F6F726F6F72726C6C6C72726C636363
5E63635D5E63779BA4CAFFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E8E5E2DCCDCDDCD3E8E5CDA7959B95958D89847784847272
6F77746F778784898477747777726C727772726C6C635D54
5A4F4F6F86B6D0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1E8F7E5E8E8E5F1F7E8D3CDCAC1A78F959BA48F8D8077
77727784777477777789847777726F6F6F726C5D5E545463
63749BD0F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E2D0CAC4A4
A7A79E95958D86878D7474808080958F9E9BB9D3D3F1E5F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F1E5E2E2DCC1C1CDD3D3D0E2E8E5F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -50 0 ]
[.5 1.0125 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(By) show
81.000000 12.812500 moveto
(inner) show
117.000000 12.812500 moveto
(product) show
159.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9D0CDD6D6D6
D6D9D6D9D9D9D9D9DFDFDFD9D9DFDFDFDFDFDFDFDFDFDFDF
DFD9DFDFDFDFD9D9D9D9D9CDD6CDCDCDCDCDC8BFC8C8C8BF
B8B8BFB5B8AFB8B8AFAFAFAFAFAFAFAFAFAFAFAFAFAFAFAA
AFA7AFAFAAA4A7A7A4A7A3A4A7A7A7A4A4A49BA1A7A7E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFCDD6D6D6D6
D6D9D9D9D9D9D9DFDFDFDFDFDFD9DFDFDFD9D9D9DFDFDFD9
DFDFDFD9DFD9D9D6CDD9D9CDCDCDCDCDCDCDC8C8C8C8BFBF
B8B8B8B8BFAFAFAFAFAFB5AFAFAFAAAFAFAFAFB5AFAAAAAF
AFAFAAAAAAA7AAA7A7AAA7A7A7A4A7A7A7A4A1A49BC4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F1F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CDD0D6D6D6
D6D6D9D6D9D6D9DFD9DFDFD9D9D9DFDFDFDFDFD9D9DFDFD9
DFD9DFDFD9D9D9D9D9D9CDCDCDCDC8C8C8BFBFC8BFBFBFBF
BFB8B8B8AFAFAFAFAFAFAFAFAFAFAAAFAFAFAFAFAFAFAAAF
AFAAAAA7A7AAA7AAA7A4A7A4A7A7A4A4A7A49BA7A7D9F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFCDD6D6D6D9
D6D6D9D9D6D9DFDFDFDFD9D9D9DFDFDFD9DFD9D9DFD9D9DF
D9D9D9D9D9D6CDCDCDCDCDCDC8C8BFC8BFBFBFBFBFB8B8B5
B8B5B5B5B5AFAFAFAAAFAAAAAFAFAFAFAFAFAFAFAFA7AFAA
AFAAAAAAA7A7AAA7A7A7AAA7A4A7A4A4A4A1A4A7B5EBF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F1F7F7F7
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CDD6D6D6D6
D9D6D6D9D6D9DFDFDFDFD9D9D9DFDFDFDFD9D9DFDFDFD9D9
D6D9D9D9CDCDCDCDCDCDC8C8C8B8C8BFBFB8BFBFB5BFB5B5
AFAFAFAFAFAFA7AFA7AFAAAFAFAFAFAFAFAFAAAFAFAFAFAF
AAAFA7AFAAA7AAA7A7A7AAA7A7A7A7A4A4A49BA7C4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFCDD6D6D6D6
D6D6D9D9D9D9D9D9D9D9D9D9D9D9DFD9D9D9D9DFD9D9D9D6
D9D9CDCDCDCDCDC8C8C8C8C8C8C4C4B8BFB8BFB5B5B5B5AF
AFAFAFAFAFAFAFAFA7AAAAA7AAAFAAAFAAA7AAAFAFAFAFA7
AAAFAAAAA7AAA4A7A7AAA7A7A4A7A7A7A7A4A4AFD9F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F1F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFCDD0D6D6D6
D6D6D9D9D9D9DFD9D9D9D9D9DFD9D9D9D9D9D9D9D9D9D6D9
CDCDD6D6CDCDCDCDC1C8C1C4BFB8BFBFB8BFB5B5B5B8B5B5
B5A7AFAFAFAFAFAFAFAFA7A7AAA7A7AFA7AAAAA7AFAAAAAF
A7A7AAAAA7A3A7A3AAA7A7A4A7A4A7A7A4A7A1B5F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F1F7F7F7F7F7F1F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F1F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CDCDD6D6D9
D6D9D6D9D9D9DFD9D9D9DFD9DFDFD9D9D9D9D9D9D9D9CDD9
CDD6C8CDCDCDC1C8C4C4C4BFBFBFBFB5B5B5AFB5AFAFB5B5
B5B5B8A7A7AAA7AFAAA7AAA7A7AAAAA7AAA7AFAAAFA7AAAF
AFAAA7AAA7AAA7AAA7AAAAA7A7AAA4A7A7A4A7C4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F1F7F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9CDCDD6D6D6
D6D6D6D9D9D6D9D9D9D9D9D9DFD9D6D9D9D9D9CDD9CDC8D6
CDCDC4CDC1C4BFBFBFB5B5BFB5AFB5A6AFA6B5A6B5AFB5B5
B5B5B5A3B5A7B8A7AFA7A7A7A7A7A7A7A7A7A7AFA7AAAAAF
A7AAAAAAA4AAAFAFA7AAA7A7A7AAA7A7A7A4B5E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9D0D6D6D6D6
D6D6D9D9D9D9D9DFD9D9D9D9D9D9D6D9D9D6CDD9CDD9CDCD
CACDCDCAC4C4C4C4C4C4BFB5B5BFB5B5AFAFA6AFA6AFA6B5
AFB5A6B5B5B5A7B8B5A7AAA7A7A7A7A7A7A7AAA7AAA7A7A7
AFAFAFA7AAAAA7A7AAA7A7A7A7A4A7A7A7A7C4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F1F7F7F7F1F7F7F1F7F7F7F7F7F7F1F7
F7F1F7F1F7F7F1F7F7F7F1F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9CDD6D6D6D6
D9D6D6D6D9DFDFD9D9D6D9D9D9D9D9CDD9CDD9CDD9D6D6D6
C8CDCACDCACACACDC4CDC4BFC1BFB8BFB5B5B5A6A6AFA6AF
A6AFAFAFAFA6B5A7A3B5ADB5A7A7A7A7A7A7A7A7A7A7AFAA
AAAAAAAFA7A7AAA7A7A7A7A4A7A4A7A7A7A4C4F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9CDD6D6D6D6
D9D9D6D6D9D9D9D9D9D9D9D9D6D9D6CDD9D9D9CDD6C8C8CD
CAD6CDD6CACDCACDCACACDCAC4C1C1BFBFB8B5AFA6AFB3A6
AFAFBFB5B5B5A6A6AAA7A3B5B8B5A7A7A7A7A7A7A7A7A7AF
A7A7AAAAAAA7AAAAA7A7AAA7A7A7A7A7A7A7D9F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D9CDD0D6D6D6
D9D6D6D9D9D6D9D6D9D9D9D9D9D6D9D9D9CDCDCDD6CDCDCD
D9D6D6CDD9D9D6D6CDD6CAC4CAC8C4BFB8B8B5B5B3AFA6AF
B5B5BFB5B5B5B5AFA6A6A7A7A7AFB8B5A7A4A7A7A7A7A4A7
A7A7A3A7A7AAA7A7AFAAA7A7A7A7A7AFA7AFE8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1CDCDD6D6D6D6
D6D6D6D9D9D9D6D9D6D9D6D9CDD6D9CDCDCDD9CDC8D6D9D6
CDD9D6D9D9D6D6D6D9D6CACDCDCDC4C1C1C1BFB8B3B3B3B3
B5BFBFBFBFB5B5B5AFA6A6A6A3A3A7AFB5A7A7A7AFA7A7A7
AFAAA4AAAFA7A7AAA7A7A7A4A7A7A7A7A7B8E8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D6CDD6D6D9D6
D9D6D9D9D9D9D9D6CDD9D6D6D9D9D9CDCDCDCDD9CDD9D9D6
D9D9D9D9D9D9D9D9CDCAD6CDCACAC4C1C4C4C1BFBFB5BFB5
B5B8BFBFC4BFBFBFB5B3A6AFAAA6A3A3A3B8A7A7A7AFAFA7
A7A7A7A7AAAAA7A7AAA7A4A7A7A7A7A7A7C4F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F1F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCDCDD6D6D6D6
D6D6D9D6D9D6D6D6CDD9D9D6CDD9D9CDCDCDDFD9DFD9DFD9
DFD9DFD9D9D9D6D9D6D9D6D6D6CDC1C4C1C8C8C8C4B8C1C1
BFB8B5BFB8BFC1B8BFB8B5A6AAAAAFA6AFAAA7B8B5AFA7A7
A7A7A7AAA7AAA4AAA7AAA7AAA4A7A7A7AFD3FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCDD0D6CDD6D6
D6D9D9D6D6D9D6CDD9D9CDCDD9CDD9CDD9D9D9D9D9D9D9D9
DFDFDFD9DFD9D9D9D9D9D9D6CDCAC8C8C4C1C8C4C1C1BFC4
C1BFBFBFB5BFBFB8C1B5B5B3A6A6B3AFA6A3A7AFB8B8AFAF
A7A7AFA7AAA7AAA7AAA7A7A7A7A4A7AFB5E8F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCDD0D6D6D6D9
D6D6D6D9D9D9CDD9CDD9CDD9D6D9D6D9D6D9DFDFD9DFDFD9
DFDFDFDFDFD9D9D6D9D9D9D9D6D0CAC8C8C4C4C8C4C1BFC1
C4C1B8BFBFC1BFBFB8BFB3B3B3AFA6AFA6AAA3A3A7B8B8AF
A7A7A7AAA7AFA7AFA7AAA7A4A7AFA7A7B5E8F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F1F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CDD6D6D6D6D6
D6D9D6D6CDCDD9D9CDD6D9D6D9D6D9D9D9D9D9DFDFDFDFD9
DFDFDFDFD9D9D9D9DFD9DFD9DFD9CDCACACDCAC4CDC4C4C1
C4C4C4C1BFC1BFB8BFB8B5B3B5B5A6B3A6A6AFA6AFA7B5B8
B5A7A7A7AFA7AFAAAAA7AFAAA7A7AFAFCAF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9CDCDD6D6D6D9
D6D9D6D9CDD9CDCDD6D6D6D9D6D9D9D9DFDFDFDFDFDFD9DF
DFDFD9DFD9D9DFDFDFDFDFDFD9D9D6D6CDCACDCDCAC4C8C4
C1CDC4C4BFC1BFB8C1B8B5B5B3B3AFA6AFAAAFA3A6A7AFAD
B5A7A7AFAAAFAFA7A7A7AFA7A7A7AFA7C4F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9D0D6D6D6D6D6
D6CDCDCDD9D9CDD6D6D9D9D6D9D9D9D9D9D9DFDFDFDFDFDF
D9DFD9DFD9D9DFDFDFDFDFDFD9D9D9D6D6CAD6CAC8CDCDCA
C4C8C1C1C1C1BFBFB8B8B5B3B5B5B3A6AFAAA6AAAAA7AFA7
B8B5AFAAA7A7AAAFA7AAA7A7A7A7AFAFD9F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9CDD6D6D6D6D6
D6CDD9D9CDD9D6D6D6D9D9D9D9D9D9D9DFD9DFDFDFE8DFDF
D9D9DFDFD9DFDFDFDFDFDFDFDFD6D9D9D6D6CDD6CDCACDCD
CAC8C4C1C8C4C1B8B8B5B8B5B3B3B3B3ADA6AAA6A6AAAAA3
B5AFADAFAAA7A7AFAFA7AAA7AFA7AFAFD3F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F1F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9D6D6CDD6CDD6CD
CDCDCDD9D9D6D9D6D9D6D9DFD9D9D6DFDFDFDFDFDFDFDFDF
D9D9D9D9DFDFDFE8DFDFDFDFD9D9D9D6D9D6D6D6CDCDCACD
CAC8C1C1C1BFB8BFBFB3B3B5B3B3B5B3B3B3A6AAAAAAA6AA
A7B5A7B5B5AFA7A7A7AAAFA7A7A7AFB5E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8B8CDD0D6D6D6D6D9
CDD9D6D9D9D9D6D9D9D9D9D9D9D9D9DFD9DFDFDFDFDFDFDF
D9D9D6DFD9DFDFDFDFDFDFDFDFD9D9D9D9D6D9D6CAD6CDCA
CDC8C4C4C1BFBFBFC1B5B3B5B3B3B3B3AFAAA6AAAFA6AAA7
AFB5B5A7ADB8B5AAA7AAA7AFA7A7AFB8F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F1F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2B0B8CDCDD6D6D9CDD9
D9D6D9D9D6D9D9D9D6D9D9D9D9D6D9D9DFD9DFD9D9DFDFD9
DFD6D9D9DFDFDFDFDFD9DFDFD9DFDFDFD9D9D6D6D0CACDC8
CAC8C8C1C1C1C1B8C1B8B5B8B5B3AAB5B3B3AFADAAAAAAA6
A7A7B5A3A7B5B8ADAAA7AFA7A7AFAFB5E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E5AD86BFD6D6D6D9D9CDCD
D6D9D9D9D9D9D9D9D9D9D9D9D9D9DFD9DFD9DFD9D9DFDFD9
D9D9D9D9DFDFDFDFDFDFD9D9D9D6D9D9D9D9D6CDD6D0CAC8
C8C1CDC8C1B8C1B8BFB5B5B5B5B3AFB3AFB3AFAAAAA6AAAA
A1AFAFAFAFA7A7B5A7A7A7AFAFA7AFC4F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7A46271C8CDD6D9D9CDD9D6
D9D9D9DFD9D9D9D9D9D9D9D9D9D9D9DFD9DFDFDFD9DFD9D9
D9D9D9D9D9DFDFDFD9DFDFDFD6D9D9D9D9D6D9D6D6CDD6C8
CAC4C8C1C1C1BFB8BFB8B5B5B3B5B3B3B3B3B3B3AFAFAAAA
A7A7AFAFA7A7A7B5B5A7AFAFAFA7AFCDF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7CD4D3980C8CDD9D9CDD6D9D6
D9D9D9D9D9DFD9D9D9D9D9DFD9D9DFDFD9DFDFD9D9DFD9D9
D9D9D9D9D9DFDFD9D9D9D9D9D6D9D9D9D9D9D9D6CDCACDC8
C8C4C8C1C1BFBFBFBFB8B8B3B5B3AFAAAFB3AFAFAFAAAAAA
A1A7AAAFAFAFA7A7B8B8A7AFAFAFADC8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7DC6B294289CDD6D9CDD6D6D9D9
D9D9DFD9D9D9D9DFD9D9D9D9D9DFD9D9DFD9D9D9D9DFD9D9
D6D9D6D9DFD9D9D9D9D9D6D9D9D9D9D9D6D9CDD6D6CDCAC8
C4C8C1C8C1BFC1BFBFBFB8B8B5AFB3AFAAB8B3ADAFAAAFAA
AAAAA7AFA7A7AFA7B5B5B8AFAFAFAFD9F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFF1862C293971D6C8D6D9D9D9D6D9
D9D9D9D9D9D9D9D9D9DFD9D9D9D9DFD9DFD9D9D9D9D9DFD6
D6D9D9D9D9DFD9D9D9D9D9CDD9CDD6D6D0D6D6CDD0D0C8C8
C8C8C1C4C8C1C1C1BFC1B8B5B8B5AFB3AFB8AFAAB3AAAFAA
AAAAA7AAA7A7A7A7A7B5B8B8AFAFA7D9F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F1F7F1
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F79D4A39291B5FB8D9D6D9D9D9D6D9D9
D9D9DFD9D9D9DFD9DFD9DFD9D9D9D9DFD9D9DFD9D9D9D9D9
D9D9D9DFDFDFDFD9D9D9D6CDCDD0C8CACDC8CDC4C8C8C8C1
C1B8C1C1BFC1B8B8C1B8B8B5B3AFB3B3B3B5B5AFAAAFAAAF
A3A3A7AAA7A4A7A7AFA7A7B5C4B8AFE8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7FF4A44421B2CB5D9D6D9D6D9D6D9D9D9
D9D9DFD9D9D9DFDFD9DFD9D9D9D9D9D9D9DFD9D9D9D9D9DF
DFDFD9D9DFD9DFD9D9D9D9D6CAC8C8C8C1C1C1BFC1C1C1C1
C1C1B8B8B8C1B8C1B8B8BFB3AFB3AFAFAAB5AFB5B3AAAAA3
A4A7A3A7AAA4A7AAA7AFA7AFB8C1B5E8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F1F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F1F7F1F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7FFCA4A42292CAFD9D9D9D9D6D9D6D9D9D9
DFDFDFD9D9DFD9D9DFD9DFD9D9DFD9D9D9D9D9D9DFD9DFD9
DFDFD9DFD9D9D9D9D6D6D6D6CAC8C8C1C1C1C1B8B8C1C1C1
C1C1C1C1C1BFC1BFBFB8B8B5AFB3B3AFB3B5AFB3AFAAAAAA
A4AAA4AAA7AAA4A7A7A7A7A7A7B8C4EBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E8774A3939ADD9D6D6D9D6D9D9D9D9DFD9
DFD9D9D9DFD9D9D9D9DFD9D9D9D9D9D9D9D9D9D9D9D9D9DF
DFDFDFDFDFD9D9D9D6D9D9CDCDC8C8C1C8C1C8C1BFBFC1C1
BFB8B8B8B8C1B8B8B8B8B5B3B5AFAFB3AFB5B3AFAFAAAAA3
A7A4A3A7A4A4A7AAA7A7A7A7A7B5B8F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F1F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1953844449BD9D9CDD9D9D6D9D9D9D9D9D9
D9DFDFDFD9D9D9D9D9D9D9D9D9D6D9D9D9D9D9D9D9D9DFDF
DFDFDFD9DFD9D9D9D9D6D6D6CDC1C1C1C8C1C1C1C1C1B8B8
C1C1BFBFC1B8B8B8B8B3B3B3AFAAB5AFB3B5AFAFADAAAAA7
AAA4A7A7A4A7A4A7A4AAAFA7AFAFB5EBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7FFB54A384A95D9D9CDD9D6D9D9D9D9DFD9D9D9
D9DFDFD9DFD9D9D9D9D9D9D9D9D6D9DFD9D9D9D9D9D9DFDF
DFDFDFDFD9D6D9D6D6D6CAC8C1C1C1C1C1B8C1C1C1B8C1B8
BFB8BFB8B8B8B8B8B8AFAFAAB3AFAAAFAFAAB3AFAAAFAAAA
A7A4A4AAA4A4AAA4A7AAA7A7AFA7B5C4F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1F7F7F1F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFE25C383980D9D9CDD6D6D6D6D9D9D9D9DFD9DF
D9D9D9D9D9D9D9D9D9D9D9D9D9D6D9D9D9D9D9D9D9DFDFDF
DFDFDFDFD9D9D6CACDCDCAC8C4C1C1C1C1C1B8B8B8B8B8C1
B8B8B8B8B8B8B5AFB5B5B3AFAFAAAFAAAAAAAAB5AAAAAAAA
AAA3A4A7AAA4A7A7A7A7AAA7AFA7AFB8D9F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7FFB542392F59DFD9D9D6D9D9D9D9D9DFDFD9D9DFD9
DFD9D9DFD9D6D6D9D9D9D6D6D9D9D9D9D9D9DFD9D9DFD9DF
D9D9D9D9D6D9D6CDCACDCAC4C4BFBFB5B5B5B5B5B5B3B3B3
B3B3B3B3AFB3AFB3AFADAAAAAFAAAAAAAAA7AAAAAFAAAAA4
AAAAAAA7A7AAA4A7A7A7AAAFA7A7AFAFB5C4E8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F1F7F7F7F7F7F7F1F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E8773942449AD9CDD6D9D6D9D6D9D9D9D9D9DFD9D9
D9D9D9D9D9D9D6D6D6D6D6D6D9D9D6D6D9D9D9D9DFDFDFD9
D9D9D9D9D9CDD6D9CDCACACABFBFB5B5B5B5B5B5B5BFB3B5
B5B5B3A6B3AFB3AFAAAFAAAAAAAAAAAAAAAAA7AAAAAAAAA4
AAA4A4AAAAA7A3AAA3A7AAA7AFAAAAB5A7B5D9F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFB53842448CD9D9D6D9D9D9D9D9D9D9D9D9D9D9DFDF
D9D9D9D9D9D9D6D6D6D6D6D9D6D6D9D6D9D9D9D9D9D9DFD9
D9D9D9D9D9DFCACACACAAAAAAAAAA4A49BA39BA6AAB3A6AA
B3B3B3B3ADAFAAAAAAAAAAA7AAAAAAA7A7AAA4AAAAAAAAAA
A7A4AAA7AAA7A7A7A3A4A7AAA7A7AAA7B5B5C4E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F77739426BD9DFD9D9D6D9D9D6D9D6D9D9D9D9DFDFD9
D9D9D9D9D9D9D6D6D6D6D6D6D9D6D9D9D9D9DFD9DFDFD9D9
D9D9DFD9D9CACACAAAAACAB5AAAA9B9B9B9B9B9B9BAA9B9B
9B98A4ADB3B3AFA6AAA3AAAAAAA3A7AAA3A4A1A4A4AFAAAA
AAAAA7AAAAAAAAAAA4A4AAA7A3AFA7AFA7B5A7CDF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F1F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7E5592F4DC4D9CDD6D9D9D9D9D9D9D9D9D6D9DFDFD9D9
D9D9D9D9D6D9D0D6D6D6D6D6D6D6D9D9D9D9DFD9DFD9D9DF
D9D9D9DFD9CACACAC4CAAAAAAA9B9B9B9B8E9B9BA39B9B9B
8E9B9B9898A4A6ADA6AAAAA7AAAAA3A3A7A1A4A4AAAAAAAA
A7AAA7AAAAAAA7A7A7A3A7AAA7AAAAAFAFAFB5B8D3F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7B84A398CDFD9D9D9D6D6D9D9D9D9D6D9D9D9D9DFD9D9
D9D9D9D9D9D6D6CACDD0D6D0D6D6D9D9D9DFD9D9D9D9D9D9
DFD9DFCACACACACACACAAAAAAA9B9B9B9B9B9B9BAA9B9B9B
9B8E9B9B9B989B98A6A6AAAAA7A7A7A4A49AA4A4A7A4AAAF
AAAAAAAAAAAAAAAAA4AAAAA4A7AAA7AFA7AFB5A7C4E8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7772F62CDDFCDD6D9D9D6D9D6D9D9D6D6D6DFD9D9D9D9
D9D6D6D6D6D0D9D0D0D6D6D6CAD6D9D9D9D9D9DFD9DFD9DF
D9CACACACACAE8CACACACABFAA9B989B9B9B9BA6AA9B9B9B
9B9B8E9B9B9B8E9B98A6A6AAAAAAAAAAA198A1A4A3A7AAAA
A7AFAAAAAAAFAFAAAAA4AAAAA7A7AAAFAFA7AFB5B5C8F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C8953980D9DFD6CDD9D6D9D9D9D9D9D6D6D9DFD9D9D9D9D9
D9D6D6D6D0CDD0CDD0D6D6CAD0D6D9D9D9D9D9D9D9D9CACA
CACAD3CACACACAAAAA9B9B9898929283838E839B9B9B9298
8E988E989B9B9B9B988C9BA3A1A6A4AAA4A1A49AA1A3AAAA
AAAAAAAFAAAAAFAAAAAAAAA4A3AAA7AAAFA7AAAFAFB5C1F7
F7E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFD3
80892CB8DFCDD6D6D6D9D6D9D6D6D9D6D6D6D9D9D9D9D9D9
D9D9D6D6D0C8C8D0D0D6D0C8D6D6D9D9D9DFDFD9D9CACACA
CADFCADFCACAB5A498989286838386838392929292989292
83838E8E8E8E8E8E9B9B98A3A3A6A7A3A79AA1A1A4A4AAAA
AAAAAFAFAFAAAFAAADAAAAA4A3A7AAA7AFAAAFAFA7B5B8F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F189
5C536BDFCDD6D6D6D6D9D9D6D6D6D0D6D9D9D9D9D9D9D9D9
D9D6D6D6D0CAC1CDD0CACAC8D0D6D9D9DFDFD9D9CACACACA
CACACACABFA4A4988683837A838383838383838383838683
83838383838E8E8E9B8C8C9898A1A6A7A3A1A19AA1A4A4A7
A3AAAAAAAAAAAFAAAAAFAAA4AAA7A7AAA7AAAAA7AFA7B5E2
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFB56B
5C29CDD9D6D6D9D6D9D6D6D6D6D6D0D0D6D9D9D9D9D9D9D9
D9D6D6CAD0C8C1C8D0C8CAC8CAD6D9DFDFD9CACACACACACA
CABFB5AAAA98928E8E98A3987D989B8E8E8C718C86837A83
837A837A8383868E8E98988C9898A3A6A49AA19A9B9AA4AA
AAAAAAAAAFAAAAB3AAAAAAAAA4A3AFA7AFAAA7AFAFAFB5D9
E5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DC8953
3829DFD9CDD6D6D6D6D9D6D6D6D6D6D0D6DFD9D9D9D9D9D9
D6D6D6CDC8C1C1C1C1C1C1C1D6D6D9DFD9D9CACACACACAB5
AAAAA49B988E9898A6B8B5B577B8CAB8B5A677B5B5A38C86
7A7A717A7A8383838E8E8C8C989898A6A7A1A4989AA1A4A3
A4A4AAAAAAAAADB3AAAAAFAAAAA7A7AFAAAFAAAAAFAFAFB8
E8E2F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFE2896E42
1E5CD9CAD6D6D6D9D6D6D6D6CDD0D0D0D9D9D9D9D9D9D9D9
D6D0D6D0CAC1C1C1B8C1C1CDD6DFD9DFCACACABFBFB5AAA4
9B98868C9B98B8D9C4D9C8C4A3D3C4CAB8B892B8B8B8B892
6586867D71837A86838C8C8C8C989898A1A19A989AA1A4A3
A3AAA3AFB3AFAFAFAFB3AFAAA7AAAAAAAFAFAAAAAFAFA7AF
C1E2E8E5F1E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F1F7F7F1F7F7F7F7F7F1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5744A29
2C8CD9D6D6D6D6D9D9D9D6D6D6CACAD0D9D9DFD9D9D9DFD9
D0D0D0C8C8C1B5B5B5B5C1D0D9DFD9CACABFAAB3B3AA9892
7A715F86AD8CB5C8C8D9C8B8B8CAB8B8C4B8A3C4C4CAB898
6E98A3866553717A867A868C8C8C989898A4A1A4A19AA4A4
A3A4AAAAAFB5B5AFAFAFAAAAA3A7AAAFAAAFAAA7AFAFA7AF
B5E2E5F1E5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E889744729
4AB5CDD6D6D6D6D6D9D9D6D6D0CAC8D0D9DFD9DFD9D9D9D9
D6CAC8CAC1C1B5B5ADADC1D6DFDFCAB5B5AAAAAAAA986868
717D7A7D86A48E8E9598958CA1A3A7ADADB8A3B8C1B8C1A3
86A3AD957D5050777A7A868C8C988C9898A1A19A989AA1A4
A3AAAAAFAFAAAFB5B8B5AFAAA3AAAAAFAFAFAAAFAFAFAFB5
B5C8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5B59D743829
9BD9D6D6D6D6D9D6D9D9D6D0C8CAC1C8DFD9D9D9D9D6D6D9
CAC8CAC1B5ADA39AA3C1D6D9CAB39BA49B988977321D8CCD
B58983A4A4A48E8EBFE8EBF1E8D9D9B59286A49892868077
83A3A3A3987D6B746559717A7A80928C9898A1A19A9B9AA4
A3AAAAAFAFB8B8B5B5B5B5AFAAAAAAAFAFAFAAA7AAAAAFAF
AFC4C8DCE8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CA89A75C1E4A
CAD9D6D6D6D9D6D9D6D6D6CACACACACDD9D9D9D9D9D9D9D9
C8CAC1B8ADADA3A3AAC8D9CAAD8E8E775C8098B5C48FCDE8
E8C1C4DFDFCAB39BE8F1F1EBE8E8D9E8C8CDD3D9DFC8C498
8C77869A98837474715C5068717186778C98A19AA198A4A3
A7AAAAAFB5B8C1B8B8B5B5AFAAAAAAAFAFAAAFAFAAAAA7AF
AFADCDD3DCC4E8F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A48089382989
D9D6D6D6D9D9D6D6D6D0D0CAC1C1C1D6D9D9D9D9D9DFD9D6
CAC1B8ADADA39A9AADC8BF8E837A47125FB5C4E8DFD0E8E8
E8E8F1F1F1F1E8C1EBF1F1F1E8E8DFE8CDD9D9E8D9D9D9D9
C89B5F77776B71897D534450687177868698A3A19A9B9AA4
A3AAAAB5B8B8BFC1B8B8B5B5AAAAAFAFA7AFAFAAAFA7AFAF
AFB5C1EBF7DCCDD3E2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79574532942B8
D9D6D6D9D6D9D9D0D6D6CACAC1CACAD9D9D9D9DFD9D9D9D6
C8C1B5ADA39A8FA3AAB386715F474A53B5CDD9E8DFD9E8E8
E8EBEBEBF1F1E8DFEBF1F1F1E8E8E8DFCDD9E8D9D9D9D9D9
D9B5718071626B7D7D3E445047687171809298A1A19AA19A
A7AAAAAFB5B8B8C1C1B5B5AFAAAAAFAAAFAFAAAAAAAFAFAF
AFB5C4DCF1F1F7CDD3F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1F7F1F7F7F1F7F7F1F7F7F7F1F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F77447422950D9
CDD6D6D6D9D9D6D6D6D6D0CAC1C1D6D9D9D9D9D9D9D9D9D6
CAC1ADAD9A8F8998957A5F47393E5C86C4D9DFDFE8E8E8E8
E8E8EBF1F1E8E8DFEBF1F1EBE8E8E8D9CDD9EBE8E8E8D9D9
D9B8BFC4AD9862595C3E29353B476868779295A1A4A19AA4
A3AAAAADB8B5C1C1B8C1B8B5B5AAAAAFAAAAAFA7AAA7AFAF
AFAFB8CDDCF1F1F1E8E5F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E8F7E8F7E8F1F1F7F7F7F7F7F7E56E352F296BDF
D6CDD9D6D6D6D6D6D6D0C8CACAC8D6D9D9D9D9D9D9D9D9D6
C1B5ADA39A898F805F5039322F5371B5D9D6E8E8E8DFE8E8
D9E8E8EBF1E8D9D9E8F1F1F1E8E8DFCDC1D9EBD9E8D9E8D9
D9C8C8D9D9D9AD53473E262F1E0F475F71778C95A1A19AA1
A4AAAAAFB5C1B8C1C1B8C1B5AAAAAAAAAFAFAFAAAAAAAFAF
AFAFB5C1D9CDF1E5F1F1E5F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7E8F7F7F7F1F7F1F7E5E5F1F7F1F7F7CD8047382C9BDF
D6D6D9D6D9D9D6D9D6D0CACAC1D0D6D6D9D9D9DFDFD9D6D6
B8B5AD9A8F868F504739322F355F77B5B8CDE8E8D9DFEBE8
D6E8E8EBF1E8D9D6E8F1F1F1E8E8D9CAB5D9EBE8E8E8D9D9
D9C4C8D9C8D9D998596E7D1D0F000F475F77719298A1A19A
A1AAAAAFB5B8C1C1C1C1B8B8B5AFAFAFA7AFAFA7AAAAAFA7
AAAFB5B8BB9DC4CACDDCF1E5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5D3955C2F296BD9D6
D9D9D9D9D6D0D6D6D0C8CACACDD0C8CAD9D9D9D9DFD9D0CA
AD9AA39A898F953950503E322650958EADCAB3A4CADFDFCA
CAD6E8E8E8D6BFC4D6EBEBEBDFD9CABFB5B3CDD9E8D9D9D9
BFAAD9D9D9C8D9C4B8B5CD894A7D4D03125968688098AA9A
A4AAAAB5B8C1C1C8C1C1C1B8B5B3B5AFAFAAA7A7AAA7AAAA
AFAFAFBFC19D4D80A7C4D3E2E8F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFDC7439292995D9CD
CDD6D6D6D6D6D6D6D6CAC8CAD6CAC1C1D9D9D9DFD9D9D6CA
AD89A395898F9868685F50393262988EA4AD9AA4C1D6D6CA
BFCADFE8E8CAB3CAD6D9E8DFD6CAB3AAB5BFC1D6D9D9D9D9
B39ACDC8D9D6CDC8A7B8B8B59AA79A4A3E47505F7792A1A1
A1A3AAAFB5C1C1C8C8C1BFC1B8AFAAAFAFAFAAA7A3AAAAAF
AAAFAFB5C1B595BBBBBBC4D3DCF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F1F7F7F1F7F1F7
F7F1F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7D39D471E2939B8D9CA
D6CAD9D6D6D6D6CACACAC1D0CDCAC1CAD9D9D9D9D9D6D6C1
9A89A3958995AAA39B8E8050475F8C8C9A9B9AA4ADB8D6CA
ADB3D6D6D6B3B5CACACDCDCAADA49898A4AAB5C1C8CDCDBF
9A8EB8D6D6CDCDAFA7B8B8AF9AA7AF7D683547505F8698A4
9AAAAAAAB8BFC1C8C1C1C1B8B8B5AFAAA7AAA4AAA4A7AAAA
AAAFB5B5B8C8CDD3C8CAC4BBC1E5F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7DCC480391B151B47CDC8CA
D6D6D6D6D6D6D6D0C8C1C1D6D0C1C1C1D9D9D9D9D9D9CDC1
A47D8FA39AA4B3BFB5B5B3AA8E86838E989898989AA4B5A4
A492ADB3AD98ADB5BFCACAB586838E838E98A4ADADB3B3A3
8680ADCDCDCDB89AB5B8B8AFA7AD9A89713E2F3950689298
A1A3AAAAB8C1C1C8C8C1C1B8B8B5AAAFAAA7A7A4A1A3AAAA
AAAFB5B5B8C4DCE2CDCAC1CACACDE5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E5CD9D53383529121271CDD6CD
D6D6D9D6D9D0CDCACAC1CAD0C8C1B5CAD9D9D9D9D9D6D0C1
A37D8FAAAAB3B8CACDCACDC4BFBFB5AAB5B5AAAAAA9B9B98
9B9B8E9B9B9B9B9B9BA39B9B8E9B8E8E8C86868E95989A8E
89868FBFC8BFAA8FAFB5C8AFA7AFAF957D3E262F36507795
9AA7A3AAB5BFC1C1C1C1C1B8B5B3B5AFA7A4A3A4A1A4AAAA
AFAFB5B5B5C4E5E5E5E5C1C1D3CDE8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F1CD6B421E1B2929181E98DFD9CD
D6D6D6D9D6D6CAC1CAC1C8CACAC1B3CDD6D6D9D9D6D9CACA
AD8089AAB8BFBFCDCDD6D9D9D6D6D6D6CACAC4C4BFBFBFB5
B5AABFBFB5AAB5AAAAAAAAB5A69BA39B8E8E8E86837D8080
868686AAB5AA8F8095B5C8A798A7A7897D3E1D2626395989
98A3A4AAB5C1C1C1C8C1C1C1B5B5AFAAAAA3A4A4A7A1A4AA
AFA7AFB5B5C4F7F7F1F1D3CDCDE8DCE5F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F789291E12121E291E29B5D9CDD6
D9D6D9D6D0D0CACAC1C8CAC8C1B8B8D0D6D9D6D6CDD6D0C8
AD897DAABFC8C8D0D6D9D9D9D9D9DFD9D9D9D9D9D6CACACA
CAC4CACACABFBFAAC4AAAAAAAAAAAAAA9B9B9B8C8C807177
77778095A19577778FAFB8A489A1A3747D3E1D121D263E62
98A1AAAAADB8C1C1C1C8C1C1B5B5AFAAAFA7A4A3A4A4A4AA
A7AAAFB5B5C4C4E8F7F7DCE5E8D3CDE8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E2E2CD2F1E03122935291B71D9D9CAD6
D6D6D6D6D6D6C8CAC8CDCAC8C8C1C8D0D6D6D9D6D6CDCAC1
B3A48989B3C1C4D9DFD9D9DFDFD9DFDFD9DFDFD9D9D9DFDF
DFDFDFDFDFC8CAD6CAC8CACAC4C4C4C4BFB5B5AA9B9B8E98
9B8C8C8C86777777778F9A8F77687762503E0F12263E4A3E
599AA1A1B3B5C1C1C1C8C1C1B8B5AAAAAAA7A79AA1A1A4A7
AAAFAAAFB5B883599DC8DCE8E2DCD3E2E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E2E2B51E1E1E1E2C32291D80D9D6D9CD
D6D6D6D6D6D0CAC8C8CACDD0C8CDD0CDD6D6D6CDD6CAC1C1
ADAD9A89AABFCDD6D9DFD9DFD9DFD9D9D9D9D9D9D9D9DFDF
DFDFD9DFD9D9DFD9D9D6D6CAD0D0CAC1C8CAC8B3B3AAA49B
9B989B9B8C92868686869283745F5F6250351D1D3B3E3E39
3E989A9AAAB5B8C1C1CDC1B8B5B3AFAFAAAAA4A1A19AA4AA
AAAFAFAFB5C4954A77C8DCE5E5F7E5E5E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7D3B58918122C292C1E18299AD9D6CDD6
D6D9CAD6D0D0CDC8CACACDCACDCACDD0D6D6CAD6CACDC8C1
B3ADA38F8FB5C4D6D9D9DFDFDFDFD9D9D9D9DFD9D9D9D9D9
DFDFDFD9D9D9D9DFD6C8D0C8C1CAC1CAC1CAC8C1B5B8B8B3
B3AAA6A3A39B98989B958C8C868677776862475347595F62
508F98A4AAB5C1C1C1C8C1C1B5B5AFAFAAA7A49AA1A1A1A7
AAAFAAAFAFB8A3594477E8F7F1F7E8F7E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7DC8974121E3239351E1839C4D9CDD6CA
D6CDD6D6CDD0C8CACDD6CDD6CDD6CACAD6D6D6CDD6D6CAC4
B3ADA49A89A3B8D6D9D9D9D9D9D9D9D9D9D9DFD9D9D9DFD9
D9D9D9DFD6D9D9D6D6CAC8CAC1C1C1C1C1C1C1C1C1C1C1B3
B5B3B3ADA6A6A3A3A3A3A398989898989898958689867777
778998A1AAB5C1B5C1C8C1B8C1B5AAAAA7A3A4A19A9A9AAA
AAA7AFAFAFB8AD4D4D4789E8FFE8F7F7E8F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E25C38386886A38F773E59CDD9D6D6D6
D6D6D6D6D0CACDCAD6CAD6CDD6D6CDD6CDD6D6D6CDCACDC1
B3ADADA39A9AB8C8CDD9D9D9D9DFD9DFD9D9DFD9D9D9D9D9
DFD9D9D9DFD9D9D9D6CDCAC8C1C1C1C1B8C1C1B8C1C1B8B5
B3AFADAFAAAAA3A3A1A3A3A3A3A1A6A3A1989895958C8F8C
89838F9AA3B5BFB5C1C8C1B8B8B5AAAAA7A7AAA4A4A19AA4
A3AFAFA7AFB8B07474835C9DF7F7E8F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7DC5C29B5CAD6D6C1B89A89D9D9C8D6D6
CDD6D6D0CDD0D6CDCAD6D6D0D0D6D6CDD6D6D6D6CACDCACA
B8B3ADAD9A8FA3C4C8D6D9D6D9D9D9DFDFDFD9DFD9D9D9DF
D9D9D9D9DFD9D9D6D6D6CAC1C1C1C1C1C1C1C8C1C1C1B8B8
B3B3AAAAA1A4AAA3AAA1A1A1A3A1A4A1A1A1A3A1A1989895
9892959A9AB5C1B5C1C1C1C1B8B5AAAAA4A4A3A1A1A4A1A3
AAAAAAAFA7B5B58080959D95C4F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1DC535CD9D6D6CDCAC1B8C1D9CDCDCDD9
D6CAD6CDD0CACDCAD6CAD6C8CAD9D9D6D6D9D6CAD6D6CDC8
B8B3ADADA39A9ABFC8CACDD9D9D9DFD9DFD9DFD9D9D9D9D9
D9DFDFDFDFDFD9D6CAD0C1C1C1C1B5B8C1C1C1C1B8B8B8B3
B3AFAAA3A4AAA7A3A19AA4A3A4A1A1A1A1A1A4A4A19AA19A
989AA1A49AADBFB5B8C8C1C1B5AAAAAAAAA4A4A1A4A19AA4
AAAAAFA7AFAFAD535CA7C1C4C4F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E2B562B5D6D6D6D6D6CAC4C1D9D6D6D6D6
D6CDCACACACDD6D6D6D6D6CAD6D6D6D6D6D6D6D6D6D6CACD
BFB5ADADA4A39AB5C8CDD6D9D9DFDFD9D9D9D9DFD9D9D6D9
D9DFD9DFDFDFD9D6D6CDCAC1B5C1B5BFC1C1C1C1C1B8B5AA
AAAAAAA7A4A19A9BA19A989A9A98A4A49A9AA1A1A1A1A4A1
9AA4A4A195B5B8A3C1C1C1B8B5B3AAA4A4A4A3A4A1A1A1AA
AAA7AAA3AFB5AD535395C4CDD3F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F1DCA3CACDD6D9D9D6D9D9CDCDD9C8CDCDD6
CDD6CAD6D6D6D9D6D9D6D9D9D6D6D9D9D6D9D6D6D6D6CDCA
C1B8B8B3ADADA3A3B5C1CDD6D6D6DFDFDFDFDFD9DFDFD9D9
D9D9D9DFDFDFDFD6D0D0C1C1C1B5B5B5B8C1C1B8B5B5B5B5
B3AAAAA1A49AA19898988F9598959595989A989A98A1A1A1
9A9AA49AA3B5B59AC1C1B8B8AFB5A3AAA1A1A1A19AA1A4AA
AAAAA7A7A7A7B52F156EBBE2F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1E8CACDD6CAD6D9D9D6D9DFD6CDCDD6D6D6D6
CAD6D6D6D6D6D9D9D6D9D6D6D9D6D9D9D9D9D6D9D6D9CACD
CAC1BFB3ADADAD9AADB8C1CDD6D9DFDFDFDFDFDFD9DFD9D9
D6D9D9D9DFDFDFD9D6CDCAC8B8B8B5ADB5B8B5B5B5ADAAAA
AAA4A1A1A1A198989898959595959295959595959A9A9AA1
98A1989AB5B5A38FB5B8B5B5B5AFAAAAA49AA19AA1A1A4A7
AAAAA7AAA7B5A329295C89CAF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7DCC1D6D6D6D6D9D9D6D6DFCDCDD9CDC8D6CA
CDD6D6D6D6D6D6D6D9D9D9D9D9D9D9D9DFD9D9D9D9D6CAD0
C8C4C1B8B3ADADADA3ADC1C8CDD6D9DFDFDFD9D9DFDFD9D6
D9D6D6DFDFDFD9D9D6CACDCDC1B3ADA3ADAAB3AFB5AAAAAA
A4A3A19A9B95989595929892929595929592959592959595
959A98A3AFA39AADB8B8B5B3B3AAA3A4A1A1A19AA1A4A4A3
A4A7AFAAA7A7A32F2F5C80C4E5F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E2C1CDD6D9D6D6D9D6D9D9CDCDD9CAD6D9D6
D6D0D6D9D6D6D9D9D9D9D9D9DFD9D9D9DFD9DFD9D9D6CDCA
CACAB8B8B8B5ADA3A3B5B8C1C8CDD9DFDFDFDFDFDFD9D9D9
D9D9D9D9D9D9D9D9D9D6C8BFB8B5AFB3AFAFAAAAA3A3A4A3
A19AA198989892959295959598989295959598929592958F
95959AA3A3A3A3AFB3B5B3B5AAA4A4A79AA1A1A19AA1A1A4
AAAAA7AFA3B5AD29294795B0E2F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7D3CAD6D6D9D6D6D6D6D0CABFCDCDD6CDD6D6
CACAD6D6D6D6D9D9D9D9DFDFDFDFDFDFDFD9DFD9D9D9D6D6
CAC8C1C1B8ADADAD9AA3B5C1C1CAD9D9DFDFDFDFDFDFD9D9
D9D9D9D6D6D6D9C8CDCDC4B8B3AFB5B5B5B8AFA3A3A3A3A1
9AA19A989592989292989592959298989895959595958F8F
958FA4A3A3A3B3B3AFB5AAB3AAAAA39AA1A4A19AA1A4A1A4
A7A7AAA7A7A7A31E121B424780F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7E8CDCDD6D6D9D0D0D0D0C1B8B8CDD9D6D6CDD6
CDD6CAD6D6D9D9D6D9D9DFDFDFDFDFE8DFDFD9DFD9D9D6CA
D0C8CAC1C1B5AD9AADA3ADB5C1CDD9D9D9DFDFDFDFDFDFDF
D6D6D0D6CDD6CAD6CACDC4C1B5B3B5AFB5B5B5989AA3A39A
A1989A9592929598929595959592989A989595959595928F
959AA3A3AAADB3B5B3B3AAAFAAAAAAA1A1A1A4A1A1A1A4A3
A3A3A7A7AFB59D1B151B294295F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E8C8D0D0D6D9D9CAC8CACAB5B5B8D6CDC8D6D6CA
D0D6D6D6D9D9D9D9DFD9DFDFDFE8DFDFDFDFDFDFDFD6D6D6
CACAC8C1C1B8B3ADADA3ADB5C1CDD9D9D9DFDFDFDFDFD9D6
CAC8CACACDCDD6CDD6CDCAC4B8B5B3B5B3A6AFA19598A4A1
A7A1A195929292959598989598989A989A98959595959592
8FA3A3ADB3B3B5B8B3AAADAAAAAAA7A4A1A4A1A4A1A6A4A3
A7A7A7AFAFA79A1E151B2438BBF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7D9CDD6D6D6D6DFD6D6C1B3B8AFC4CDD6C8CAD6CD
CAD9D9D9D9D9D9D9DFDFDFDFE8E8E8DFDFDFDFDFDFD9D9D9
D6D0CACAC1B8B8ADAD9AADA3ADBFD6D9DFDFDFDFDFD9CACD
D6D9D6D9D6D9CDD6D6CACAC8C4B8C1B5B5B3B5AFA3989292
9898958F868F9295989898989598A19A9A9A98959595959A
A3B3B3B8B5B5B8B3ADAFB3AAAAAAAAAAA19AA4A1A1AAA1A7
A7A1AAA7AFB5953542424792CDF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E8D6D6D9D6D6D9DFD9CDC1ADB5AFBFD6CACDD6D6CA
D6D6D6D6D9D9D9D9DFDFDFDFDFDFDFE8DFE8DFDFDFDFD9D6
CDCAC8CDC1C1B5ADADADA3ADADB5CDD9DFDFDFDFD9D6D6D9
D9D6D6D9D6D6D6D6D9CDD6C4C8C1C1B8B8AFAFAFAFAFA18F
8692928F8F8F92989895959898959A9B98959A9895959AA3
AAB8B8B8B5B5B5B3AAB3AAAAAAAAAAA4A1A1A1A1A1A79AA4
A3A4A7A3A7AD862929426EE8F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E8D6D6D6D6D9D9DFD6C1B3B8B3AABFCDD6D6D6CACD
D6D6D6D6D9DFD9DFDFDFDFDFDFE8E8E8DFDFDFDFDFDFDFD9
D6CACDCAC4C1C1B5ADADADA3ADB5CAD6D9DFDFD9D9D9D9D6
D9D9D9D9D9D9D9D9D9D6CAD6C8C4C1BFB5B3AFA6A7AAAFA3
9889898F86898F9292929895959898989A98989AA1A3AAAD
B3B8B8B8B5B8B8B3B3AFAFAAAAAAAAA3A1A1A1A4A7A1A1A7
A7A1A7A7A7B5771E29426E9DA7DCF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7DFD6CAD6CAD9DFDFC8B8B5B8ADAFC4CAC8CDCDD6D6
CAD6D6D6D9D9DFDFDFDFDFE8DFDFE8DFDFE8DFDFDFD9D9D6
D6CDD0C4CAC8C1B5B5ADADADADADC8CAD9DFD9D9DFD9D9D9
D9D9DFD9D9D9DFDFD9D9D6CDC4C8C4C1B8B5B5AFAAAAAAAF
AAA398899292868F9298959598989A98A198989AA3A3AFB3
B3B8BFB5B8B8B8B8AAB3B3AAAAAAAAA1AAA1A4A3A1A7A1A6
A4A7A7A3A7B580291E292F2F42B0E5E5F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1D6D6D6CAD6D9DFD9C1B8ADB8AFB8C8CDCDD9CAD6D6
D6D6D9D9D9D9D9DFDFDFDFDFE8DFE8E8E8DFDFDFDFDFD9D9
D9D6CAC4CDCAC4BFB8B3ADADADADC1C8CDD9D9D9D9DFD9D9
D9D9DFD9D9DFDFDFDFD9D9D9CAC4C8BFB8B8B5AFAFA7AFA7
AAAAAFA19AA4988F8F9592929895989A989A9AA3A3B3B3B8
B8B8C1C1B8B8B3B5B3AFAAAAAAAAA3A4AAA3A1A4AAA1A1A4
A3A3AFA7AFAD6B2C2C291E29295C9DCAE2F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7E8CDD0D6D6D6D9DFCDB5A3A3B5AABFC8CDCDCACDD6CA
D6D9D6D9D9D9DFDFDFDFDFDFDFDFE8DFE8DFDFDFDFDFDFD9
D6CACDD6CAC8CAC1C1BFB3ADADADB8C1CAD6D9DFDFD9D9D9
D9D9D9D9DFDFE8DFDFD9D9D6CDC4C1C1B8B5B5B3AFAFAAA7
AAA7AAAAA7AAA39A86868F8F8F959598989AAAAAAAB3B8B8
B8C1B8B5B8B8B8B8B3AAADAAAAAAA3AAAAA4A1A3A1A4A3A1
A4A1A7AFB5B8895044442C1E12386E95D3F7F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1D6D0CAD6CAD6D9D9B8AD8FADA3AABFC1CDCACDD6D6D6
D6D6D6D9D9D9DFDFDFDFDFDFDFE8DFE8E8DFDFDFDFDFD9DF
D6D6CACDC4C8C4C4B8B8B3B3ADB3B8C1D6D9D9D9D9D9D9D9
D9DFD9DFDFE8DFE8DFD9D6D6C8C1C1C1B5B8B5AFAFAAAFAF
AFA3AAAAAAAAA3A18F8F8F8F8F9595959AA3ADADB3B5B5B8
BFB8C1C1B8B8B8B3B3AFAAAAB3A6AAA3AAA6A4A6A4A1A7A1
A3AAAFA3A7B89B8F7D5F5F44292F5C749DD3F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7DFCDD0D6D6D9D6CDB5C8A38F95A3B8CDCACDCDCAD6D6D6
D6D6D6D9D9D9DFDFDFDFE8DFE8E8DFE8DFE8DFDFDFD9D9D6
D9D9CDD6D6CDCACAB8B8B8C1B5B8C4CACDD6D9D6D9D6D0CD
D6D6D9D6DFDFDFD9D9D9D6CDC8B8B3B3AAAAAAAAAAAAA7AA
A7AAA1A7A1A3A6A49A8F86869295989AA1A3AFAFB5B8B8B8
C1B8C1B8B8BFBFB8B5B3AFADAFAFAAA6A7AAAAA1A7A7A3A7
A7AAA7A7B5BF9A8F896E654D4A2F3838425395E2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1CDCACDD6D6D6CAC1B8C1A19A98AAB8C4C1CAD6D6D6D6D6
D9D6D6D9D6D6D9DFDFDFDFDFE8DFE8E8E8DFDFDFDFDFD9D9
D6CAD6D6CDCACDC4B8BFC1B8C1C1C1D6CAD9D6D9D6D6CAC8
CACDD9D9D9D9D6D9D6D6C8C8C1B3B3AAAAAAA6A3AAAAA3A7
A3A4A3A3A4A49AA1988683838F9898A4A6AFB3B3B8B8B8C1
B8BFB8B8B8B8B8B8B5B3B3AFA6B3AAAAAAAAA7AAAAA3A7A3
A7AAA7B5A7ADA195928F777765353942425C9EE2F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EBCDCACAD6D0CAB8B5C1AA9AA39AB5BFCDCACAC8D6D9D6D9
D6D6D9D9D6D9DFDFDFDFDFE8DFDFE8DFDFDFDFDFDFDFD9D9
D6D6D6D6D6C8CAC8C8C1C1C1C1C1B8D6D9DFD9D6D9CDCDCA
C8CAD6D6D9CDD9D6CDD6CAC4C1B3AFA6AAA3A3A3A3A4A1A1
A7A1A1A4A1A1A19A958683868F959AA3AAB3B5B8B8B8B8B8
C1B8B8B8B8B8B8B8AFB5AFAFB3A6AFAAAAA3AAA3A4A7A1A7
AAA4AAA7B5B8A1989A98928F8668425374B5E2E8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E8C8CAD0CAB5B5ADA49A9A959AAAB5C8CACDCDD6CDD6D9D6
D9D9D6D9D9D9D9DFDFDFDFE8DFDFDFDFDFDFDFDFD9DFD9D9
D9D6D6CDCACACDCDCAC1C1C4CAC4C1C8D6DFD9D9D6CACAC4
C4CDD6D6CDD6CDD6CAC8CDC1BFB5AFAAA7AAA79AA1A1A1A7
A19BA198A1A19A958F8683898F98A1A6AFB3B8B8B8B5B8C1
B8B8B8B8B8BFB8B8B3B3B3AFAFAFAFA3AAA7A7A7AAAAA1A3
A7A7A3B5B5AD9AA1A19A989A98927177CAF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
D9C1D0CAAD9A9A89868C8C95A1AFB8C1C1CAD6CAD6D6D6D9
D6D9D9D9D9DFDFDFDFDFDFDFDFDFDFDFDFDFD9DFDFD9D9D9
D9D6D6D6CDD6CACAC8C1C4CACDC4CAC4D6D9D9D6D6D6C8CA
C4D6CDD6D6CAD6CDCAC8C1C1B5B5B3AAA3A1A1A1A19B9898
989898989A98958F8686898F929AA6AAAFB8B8B8B8C1B8B8
C1B8C1B8B8B8B8B8AFAFB3B3AAB3AAA3AAAAA3A3A4A6A7A7
A3A1B5A7B5B8A1A1A198A198A1989ABBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
CDCACACAAD9A9A838F8F8F92A1AFB5C4CACDCDD6D9D9D9D9
D9D9DFD9D9D9D9DFDFDFE8E8D3DFDFD3DFDFDFDFDFD9D6D9
D6CDD6D6D6CDC8CAC4C1C8C8CACDCDD9D6D9DFD9D9D6CACD
D6D6D6D9D9CDCDC8C4C8C4B8B5B3AFAAA7A1A1989898988F
8F8F959898958F8F86868F929AA3AAAAB3B5B8C1B8B8C1C1
B8B8BFB8BFB8B5B8B3B3B5AFB3AFAFAAAAA3A1AAA3A7A6A3
A7A7A3A7B8B89A9A9A989A9A98A1B5E2F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9
CAD0D0C1A49A928C8C958F98AAAFB5C4CDCDD6CDD9D6D6D9
D9D9D9D9D9D9D9DFDFDFE8DFDFDFDFDFDFDFDFDFD9D9D9D9
D6CACAD0CDCACAC8C4CAC8CACDD6D9D9D9D9DFDFD9D6D6D9
D9D9D9D9D6D6CACAC8C8C1BFB8AFAFA6A1A39B958F9B988F
958F8F9895958F868F868F9898A3AAAFAFB8B8C1C1C1C1BF
B8B8BFBFB8B8B8B5B5B5B3ADAAAFAAAAA3AAA7A6A7A1A4AA
A7AAAFB5B8AD959595989A989AA1ADF1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DF
CDD0CAC1ADA498958F958695A7AABFC8CDCDD9D6CDD6D9D9
D9D9DFDFD9D9DFDFDFDFDFDFE8DFDFDFDFDFD9D9D9D6D9D9
D6C4CDCACACDCDCAC4CDCACDD6CDD9DFDFDFDFDFDFDFD9D9
D9D9D9D9D6D6D6CDC8C4C1C1B3B3AAAAA1A1A1989898988F
868F8F958F868F8F8F8F989AA1AAAFB3B3B5B8B8C1B8B8C1
BFBFBFB8B8B8B5B3B5B3AFAFAAAFAAA3A3AAA3A1A6A1A1A1
A7A7A7A7B5B8958F959598A1A1A1B5EBF7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9D0
CAD0CAB8A4A49A9A8C869298A7B5C1C8CDCDD6CDD9D6D6D9
DFD9DFDFD9D9DFDFDFDFDFDFDFDFDFDFDFD9D9D6D9D9CACA
D6D6CACDCDCDC4C4CACDCAC8CDCAD9D9D9D9DFDFDFDFDFDF
D9D9D9D9D9D6CDCDCAC1C1B8B8ADAAA7A1A1989898988F8F
8F8F8F8F8F95989598A1A1AFAFB3AFB3B8B8B8B8BFC1BFC1
C1C1BFBFB8B5B3B8AFB3AFAAAAAAAA9AA6A7A6A1A6A1A1A3
A1AAA7B5B8B88F8F8F95A1A1A1A7B5D9FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBC8CA
CDD9D0BFADADA49A8689929BAFB8C4C8CACDCDD9D6D6D9D9
DFD9D9D9D9DFDFDFDFDFDFDFDFDFDFD9DFD9D6D9D9D9D6D6
CACDCDCACDCACAC8CDCDCACDCAC4D9D9D9D9D9D9DFDFD9D9
D9D9D9D9D9D6D6CACDBFC1C1B3AAAAAAA1A1A198988F958F
958F95959898989AA1A3AFAFAFAFB5B3B5BFBFBFC1C1BFBF
C1B8C1C1B8B8B3B5AFADAFAAAFA6AAA1A4AAA1A1A1A1A1A1
A7A4A7B5ADB5959595959AA1A7A7A7C8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFCACA
D0D9CABFADADA49A928692A1AFB8C4CDCDD6D9CDD6D9D9D9
DFD9D9D9DFDFDFD9DFD9D9D9DFD9D9D9D9D6D6D6CDD9D6CD
CDCAD6CDCACDC8C1C1C1C1CDC4C8D9D9D9D6D9D9DFD9D9DF
D9D9D9D9D9CDD6D6CDCAB8B8B3AAAAA1A1A19B9898989595
989898A198A1A4A1A1A7AAAFAFB5B5B5B5BFC1BFC1B8B8B8
C1C1B8BFB8B5B8B8B3AFAAAFAAAAA7AAA3AAA1A1A7A1A1A1
A1AAA3B5B8B8989A989A9AA6A7A7A1B8F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBD6CACA
CAD9D6CAB5ADA49A8F86929BAFBFC4CACDCDD6D9D6D9D9D9
DFDFDFD9D9D9DFDFDFD6D9D9D9D9D9D9D6D9D6D6CDCACDCA
CDCDCACDC8C8C4C4C1C1C1C8C4CACDD9D9D9D6D9D9D9D9D9
D9D9D9D9D9D9D6D9D0C4C1B3AFB3AAA498A1A19898989898
989898A3A1A1A1AAA3AAAFAFB5B5B8B8B8B8BFBFC4C1C1B8
C1BFB8B8B8B5B5B3AFB3AFAAAFAAA6A3A7A3A1A1A3A7A1A1
A3A7A7B5ADADA19AA4A1A1A7A7A3A1AAEBF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFD0C1C1
D0D9D9CAAD9AA39A8F8F8FA1AFBFC8CDD6CAD9CDD9D9D9D9
DFD9DFD9DFD9D9D9D9D9D9D9D9D6D6CDCDD6CDD6D6D6D6CD
CACACDC4C8C4C8C1C1C4C4C1C8CDD6D6D9D6D9D6D6D9D9D9
D9D9D9D6D9D6D6D9CAC1C1B3ADAFAAA6A1A19BA198989898
989A9B9A9BA3A1A1A4AAAFAFAFB3B8BFB8BFC1C1C1B8BFC1
B8C1B8B3B3B5AFAFAFAAAAAAA3AAAAA7A3A3A1A3A1A1A1A3
A4A3A3B5B8B5A7A4A3A7A4AAA7A198A3C8FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CAB5B5
D6DFD9BFADA3A4988F868F9BAFC4C8CDCDD6D6D6D9D9D9DF
DFD9DFD9DFD9D6D9D9D9D9D9CDDFD6D6D6C4CACDCACDC8CD
CDCDC4CAC4C1C4C1C1C8C4C4CACDCDD6CDD9D9D6D9D9D6D9
DFD9D9D9D9D9D9D6CDC4C1B8B3AAAAA4A1A1989B98989598
9A9BA1A1989AA7A4A3AAAFAAB3B5B5BFB8BFBFBFB8BFC1BF
C1B8AFB3AFB8B5B5AFAAAAA7AAAFAAA7A6A7A3A4A1A1A1A1
A3A1A7B8B8B5A3A3AAA7A3A7A795989ACAF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CAB5B5
D6D6BFB3B5A3A39A86868F98B5C4C8CACDCDCDD6D6D9D9D9
DFD9D9DFDFD9DFCDD9D9D6D6D6CDD6CDCDC8CDCDCDC4C1C4
CDC4CDCDC4C1C1C4C1C4CDCDCDCDCDD6D9D9D6D6D6D6D6D9
D9D9D9D9D9D6D9D6D6C4C1BFB3AAAAAAA1A1A19895989898
9B989B9AA1A1A7AAA3AAAAAFB5B5B8B8BFBFB8B8BFC1B8B8
BFB8B5B5B3B5B5AFB3AFAAAAA7A7A1AAA4A1A3A3A1A1A1A1
A1A3B5ADB5AD95A4A4AAA7A4B5959595AFF1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9CAAD9AB8
ADA3A3A168687D928F86869BBFC4CDCACDCDD6D9D6D9D9D9
D9D9D9D9DFD9DFD9D9D9D9D9D6D6CDCACDCAC8C8CDC4C1C8
C1C1BFBFC8C4C4CACDCACDCAD6D6CDD6CDD9D9D9D6D9D6D9
D9D9D9D9D6D9D6D6CACAC8B8B5B3AAA3A1989B9B98989898
98989B98A1A1A1A1A6A3A6AFB8B8B8B8B8B8B8BFB8B8BFC1
B8AFB3B5B3B5AFAFB3AFAFAFA6A7AAA7A3A7A3A1A1A1A1A1
A7A7A7B8B8B577778FAAAFAFB5988F9A98C8F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D6B59AADAD
92AFA674687468747D7D86A1BFC8CDD6D6D6D9D9D9D9D9D9
D9D9DFDFD9D9D9D9D6CDD6CDD0CDD6CDCDCDC8CDC4C8C4C4
BFC1C4C4C4C8C8C8CDCDCDCDCDCDCDD9D6D9D9CDD9D6D6D6
D9D9D9D9D9D9D6D6CDCDC4B8B3AAAAA1A19A989898989898
98989BA1A1A1A1A7A7A6AFB5B5AFBFB8B8B8B3B8B8B8BFB8
BFB8B8B3B8B5B3AAAFAFAFAAAFA3AAA1A7A1A3A1A1A1A1A4
A3A7A7B8B8AD6E777D9AA4A7B5A1959595AAE8F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFD0AD9AA48F
92AD833E5C74745F6B717DA7B8C8CDCDD9CDD9D9D9D9D9D9
D9D9D9D9D9D9D9D9D9D6CDC8CDC8C8C4C1BFC4C4CDC4BFCD
C8C1C8C4C8C4BFC4CDC8CDC4D6D9D9CDD6D9D6D9D9D9D6D9
D9D9D9D9D9D9D6CDD0C8C1B8AFAAA6A19B98989898989895
98989AA1A39BA3AAA6AFAFB3B5B5B5B8B5B3AFB3B5AFB5B5
B5B5AFB5AFB3AFAFAFAFAFAFAFAAA7A7A1A19AA19AA1A1A3
A7A3AFADB5B5777777899AA7A7A498959A95D9F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D6CAADA49886
92745683746859595F68719BBFCAD6CDD9D6D9D6D6D6D9D9
D9D6D9D9D9D6D6D9D9D9D9D9CDCDCDCDC8C8CDC1C8C4C4BF
B8B8BFB8BFC4BFC8C4CDCDCDCDCDCDD6CDD9D9D9D9CDD6D9
D6D9D9D6D9D9D0CACDC8C1B5B3AA9AA1A19898958F989898
959B989BA3A1A1AAA7AFAFAFAFB8B5B5B5B8AFB3B3AFB3B5
B5AFB3AFB3AAB3AFAFAAA3AAAFAFA7AAA3A1A1A1A1A1A3A3
A7A3A7B5ADA77777778F98A7A7AAA1A19A95CAF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFE8CAC19AA4A36E
565C86A15C5059505F5F71A1BFCDCDD6CDD6D9D9D9D9D9D9
D9D9D6D9D9D9D9D9D9D9D9D9D6D9D9D9D9D9D9D6D9D9CDCD
BFBFB8B8B5B3B8B5BFC4C8C4C8CAD6CDD9CDD9D9D6D9D6D9
D9D6D9D6D6CDCACDC4C1BFB3AAA3A1A19A9B9898988F9595
989BA1A1A1A1A3A7AAAAAFAFB3B3AFB3B5B5B3B5B3AFAFB3
B3B3B5B3AFAFAAAFAAA7AAAFAFAAAAA1A7A7A3A19AA1A1A3
A7A3AFADB8B57D77778995A49AA7AAAA9898AFF1F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9CAB59AAD985C
3B77A186595F50504768719BBFC8D6D6D9D9D9D9D9D9D9D6
D6D9D9D6D6D9D9CDD9D9D9D9D9D6D9D9D9D9D9D6D9CDCDCA
C4C4C1B8B5B8B5AFAFAFB5C4C8C1CDCDCDD6D6D9D9D6D6D9
D9D9D9D6D6D6D6CDC4BFB8B3AAA4989A98989598958F988F
8F9B9AA1A19BA7AAAFA7AAAFAAAFAFB3AFB5B8B5B5AFB3AF
AAB3AFB3AFAFAAAAA7A6AFAAA7AAA3AAA7A1A4A1A19BA1A1
A3A7ADB8A7A77D7789898F9595A3AAA7989AAAE8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D9C1AD9AAA8644
3E98867D74956B59475C71A7BFC8CDD6D9CDD9D9D9D9DFD9
D9D9D9D9D9D9D6D9CDCDCDD6D9D6D9D9D9D9D9D9D9D9D9C8
CDCABFBFBFB8B5B3AFAFAFAAB5CACAD6D9CDCDD9D9D6D9D9
D9D9D9CDCAD6CDD6C1B8B5B3AAA3A1A19A98958F958F9598
9598989BA1A3A7A7A7AFAFAFAFB5AFB5AFB5B5AFAFB3AFAF
AAAFAFAFAFAAAAAAAAAFAFAAAAA7AAA7A1A1A3A3A1A198A3
A7A7A7B5B5A77D6E6E777777778FA3AAA395A3D9FFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D9B59AA4BF713B
7774391D565F5F805C5C629BBFCDD6D6D9D9CDD9D9D6D6D6
CDD6D6D9CDCDC1C8CDD6D9D9D9D9D9D9D9D9D9D9C4D9D9CD
D9CAC1C4BFBFBFADAFAAAAAAAFAAB5C4CDCDCDD9D9D9D9D9
D9D9D9D9D6CDD6C8C1BFBFADAAA6A1989898988F8F8F8F98
989B9B9BA3A1A4A7AAAAA7AAAAAFAAAFAFAFAFAFAFAFAFAF
A3A6A7AFAAAFAAAFAFAFAAA7A7A7A7A7A4A1A1A1A4A19B9B
A3A7ADB5A7A77D6B6559595950687D9A9AA395C4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EBCAAD9AADB55F44
775C122C718659385C50719BBFCDCDD6D9CDD9D6D9D9D9D9
D6CDC8C8C8C8C4BFBFB8D6D9D6D6C1C8CDCAB8B8B5B8B5A7
B5B5A7B5BFBFB3AFAFB3AAAAAAAAAAB8C8CDD6D9D6D9D9D9
DFD9D9D6D6D6CAC8C1C1B8AAA3A49A9898928F86898F988F
959898A4A4A7A1A4A4A1A1A1A1A7A7AFAFAFB5AFAFAFAFAF
A7A7A7AFAFAAAFAFAFA7A7A7AAA3AAA4A1A3A19BA1A1A3A1
A7A7A7A7A7A7837165625C59595F777D9AA395BFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8C19A92B5C47456
7739124D44392939474D5C9ABFCDD6D6D6D6CDD6CDD9D9D9
D9D9D6D9D6CDCDC8B5809BAFB5A7A49B9598989595989898
988FA38F98AFA3AFAAA7A6A3AAAAAFAFBFC1CDD9D9D9D9DF
D9DFD9D9D9CDD6C8C4B5B8B3AA9898989595958F8F958F95
95989898989A98989B98A3A19BA7A7A7A7A7A7AFB5A7B5AF
A7A3AFAFAFB5AFB5AFAFAFA7A7AFA7A3A7A1A4A3A19BA1A3
A3A7B5A3A79B8371655C6259595F687789A398B5F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DFB59A9AB3C47D3E
651E123E1E1B1E2F3947599BBFC8CDD9CDD6D9D9D6CDD6D9
D6D9CDCDC8BFB5A79580595C5C5971717186868689959898
9895A395838398A698A1A1A1A1A1BFC4BFC4CDCDCDD9D9DF
DFD9DFD9D6D6D6D0C1C1B8AFAAA1A19A958F8F868F958F8F
95959895989B9BA3A3A3A7A3A7A7A7A7A7A7A7AFA7AFA7AF
AFAFAFAFAFAFB5AFAAB5AFA7AFA7A4A7A4A1A19AA1A1A39A
A7A3A7B5A7A389746B6559596262687789A19AAFF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6B59A92B5BF864A
3E121229121B1E2F394247ADC8CDD9D6D6CDD6CDD6D6D6CD
D9CDCDCDC8C8B5A48FB583504D44475F6874869886717171
71686B7183837786959898989298AFB8BFC1C8CDD6D6D9DF
D9D9D9D9D9D9D6CDC4C4B8ADA39A9A9B98958F8F8F869595
868F899B9B9BA39BA19B989A9B98A198A1A19BA3A7A7AFAF
AFB5B5AFAFB5B5AFAFA7A7AFA7A1A3A4A1A1A79B9BA19BA3
A7A3A7A7A79B80716B626259625F68688995A3AFF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1CDAD929ABFBF9844
2903120B12292929294447A7C8D6CDD6D9D9CDD6CDCDCDD6
D0D6D9D9D6CDC8C8B5A7B89550504444779DB5BB803B395F
2929293B3E565F77777783897780898F9AAABFCDCDD6D9D9
DFD9D9D9D9D9CDD6CDC1B8B3A3A4A198958F8F8F86958683
838F959B9BA3A1A1A1A1A1A1A19AA1A1A19AA19A989A9B98
A7B5B5B5AFAFB5AFAFAFAFAFA7A7A4A1A1A79BA7A1A79BA7
A7A7A7A3A3A383716E5C6262625F6877779AA3AFF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1C89A929AB5CAA332
12030F121E2929392F39599AC8D6D9D6CDD6D6CDD0D0D0CD
D6D9D6D6D6CDCDCDC889B5AF9B68443880A4BBB55C3B80AD
420B0B2C4D353B687D776E65626259596289B5C1C8D9D9DF
D9DFD9DFD9D9D6CDC8BFB8B8AAA79A989595898695838386
86899BA3A7A3AFAFAFAFAFAFAFAFAFAAAAA7A3A7A3A4A1A1
9B98A4A7AFB5B5B5AFAFAFA7A7A7A7A49BA4A19B9BA19B9A
A7A3A7A7A79B83716E656262626868778095A1AAEBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E8CA9A928EBFCAB535
1203121B2929292F393947A7C1D6CDD9D9D6D6CDCDCDC8D6
CDD9D6CDD9CDD9CDCD9898B8B5AD9B80425C8395384DADB5
6E0B0B294D53536BA39A897D68566B717D89AAC1D0CDD9D9
DFD9DFD9D9D9D6D6C8C1BFB3AAA3A4988F8F8F95837D7D86
9595A7A7B5A6AFB5B5B8BFB8C4B8B5B5B5AFAFA7AFA7AAA7
A1A7A7A7A7A7AFA7AFA7A7A7A7AAA7A7A1A1A4A1A4A39BA3
9AA7A7A7A3957D716565656262626E778095A3AAF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFD9B89A7D89B3B5BF71
291E1B1B2429292939594DB5CDCDD6D6D9D6CDD6CDCACDD6
D6D9D9D6D6D9CDCDCDBFA78FAFC1959A8371383929538089
7A0B0B294D564D62A3AD9D71564D62899AB5C1C8CDD9D9DF
D9D9DFDFDFDFD9D6CDC1C1B5AAA39A988F8F868377777777
8395A4AFB5B5B5B5B5A3B5B8AFA7A7B5A7AFB5B5B5AFA7AF
A3A7A49BA7AFAFB5B5B5AFA7A79BA49BA49B9B98A49BA49B
9BA7A7A39B95716B5F6B6562657777808FA3A3AAF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7D395B5CA927D80A6B3B583
351B0B0B1E291B1E2F446BB5C8CDCDD6CDD6CACDD6D6D6D6
CDD6D6D9D9CDD6D6D6CDBFAF98AFD6CDAF9B95714432355C
44000B24383E3E6B9D8689686562838FA4B5C8C8CDD9D9D9
D9DFDFDFDFDFCDD6C8C1B8B5AAA19A958F86837777776E3E
4D6577A1A7B5B5A3A3989895988986868F899BA7A7A7A7A7
A4A7A79B95A4A7A7A7A7A7A4A4A7A7A4989BA49B98A19BA4
A3A7A79B98896868686B6B656E7780898FA1A3AAEBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FF4A3BB5CA897D80A3B5B3A1
4712151E1E29291E2C395CAFCDD6D6D6D6D6CDD6CDD6CDD6
D6D6D9CDD6D6D6D6D9CDC8BFAFA4AFCDC4B5B5895C593939
290B1218323B325C5C686E6E7777778FAAB5B8C4CDD9D6D9
DFDFDFDFE8DFD9D6CDC8C1B5AAA498958689837D83776E3B
2F354A7D8F95988F89867D83836B6B7468717D869595989B
9B9BA4A4A4989BA4A7A4A7A7A7A49B9595989B9B9B9BA19B
A39BA39B9589685F5C656B5C6E86898F989A98A1EBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F19D123BB5C1A47D86B5C1B8B8
5C031229291E241B29425CB5CDCDD6CDD6CDD6CDD6CDD6D6
CDD6D6D6D9D9D9D9D6CDCDC8BFB8A4AFD6CDAD89AF71504D
4D4439323E3B395F565F7777777789A3B5AFB8BFCDD6D9D9
DFDFDFDFDFDFD9CDCDC1BFB5AAA49A958F8383958377775C
3B35508689959886867471685F5F68717171716868747D89
989595959B98959B9BA4A498A498A49B9895959BA49B9B9B
A4A3A1959580595F5F685F5F5F898F8F9AA395A3EBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFE2772C12299ACAC1B8B8CAB8B8AD
50031B29291B1E2929395CB8C8CDD6D6CDD6CDD6CDCDD0CD
D9D6D9D9D9D6D9D9D6D9D6CDCDBFB8AFAFCDAFB8B8718083
68684D596850506E6E8083777777B5B5B5AAB5C1CDCDD6D9
DFDFE8E8E8DFD9D6C8C1C1B8AAA1988F8F8683868683776E
6E53568CB0BBC4C8B5624D322F323B39507171685F4D565F
7D8983898995898F958F959595959598989898A49B9BA1A3
A39B9B8F897D5056595F5959688995989AA1899AD9F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7FFE889321E121D9AB5CACACAC1B3B5A6
501229292F1B1E1E29425CB5CDD0D9CDD0CDCDCDCDBFC8CD
D6D6CDCDD6D6D9D9D9D6D9CDCDCDC8B8AA98A4BFB89BB5A4
89716874685F5F7777838377779AAAB5AAADB8C8CDCDD9DF
DFDFDFDFDFDFD9CDC1C1C1B8AA9A98958F83837D95867D77
77654A71ADC4C8C1953235321D293B3B3B394D686B5C5950
567180808083808080838686898F95989BA1A19BA19B9BA7
A3A7958F8971505C59595C505086959AA3A38995D9F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7B0391E1D121B89ADB5CACAB8ADADA1
592C3542291E121E1E425FB8CDCDCDCACDD6D6CDD6BFB8C8
CDCDD6D6CDD9D9D9D9D6D6D9CDCDCDC8B8B5A7AAA7A7B5AF
A789898F837D778383777789A4A3A3B3B3B3BFC4C8CDD6D9
DFDFE8E8DFD9CDD0C8C8BFB8AAA19A958F83837D86868377
6E776B5683B0D3B55C4D8329031529445059395962685C56
395C68717171685F6E747D868F8F98A49B9BA49B9BA49BA7
A1A495898068505044625C59508FA1A3AA8F7D8EC4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F79D391E1B1E12122977ADB5B58F8F8965
35393535291B1E1E29425CC1CDCDCDD0CDD6D6CDD6BFA198
AFBFCDCDD6CDD9D6D9D9D9D9D9D6D9CDC4C8BFBFB8B5B5AF
A4A495958F838FA4A4A3A3AAAAAAAFB5B8C1C8CDCDD6D9D9
DFE8DFE8DFDFCDCAC8C8C1BFAFA7A1958F83838386869583
776E83837771716E59ADA335001535354A4744538089835C
4A4235424A4A5950687D95A4A7A4A4A49BA49BA49BA39B9B
A19895807159444A4D4D32395686A7AA95747D89CDF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7DC622F2C1B1E0312123B779A9A776E5944
383829241E1B1B1E29446BC8D0CDD0CDD6D6CDD9D9D6BF95
8FAFC1C8CDD9D9D6D9D9DFDFDFD9D9D9CDC8C8C4B8B8B8B5
AFAAAAA3A4A4A4A3A3A3A3A3AAADB5B8BFC8C8CAD6CDD9DF
DFE8DFDFDFD9D6CDC8C8C1B8AFAAA19A8F8983868F958689
836E77898F867D5C4786A42900154747473E395C83807453
35393939473E59687D8383869598A4A7A7A7A7A4A79BA4A7
9BA495805F474A47444A2F324D8FA7AA8F687D83C1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFB84439352C1E12031203295362593E3B42
2F2F2F241E121B12294462B8CDCDCDCACDD0D6CDD6D6CDB5
9592AFB5C8CDD6D9D9DFD9DFDFDFDFD9CDCDCDCDBFB8AFB5
B5AFAFA3A3AAA3A3A3AAAAAAAAAFB8BFC8C1CDCDD6CAD9DF
E8DFDFDFDFD6D6CDC8C1BFB8AAAAA4988F89838683958F95
89897798988F897D714D5C29000B232F393B2953776B4229
3944595C4D5F748386959598898F95A4A7A49BA4A19BA3A1
9B9B95805C4A4A44504A2F393992A7AA89747489CAF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FF952C29322F290312120F030F1250382939
241B2F291B1B1B1B294271B8CDCDCACDCDCACDD6D9CDCDC4
A695A7A7AFC4CDD9D9DFDFDFDFDFD9DFD9CDCDCDC4C8B8B8
AAAAAAAAAFAAAAA3AAAAA3AAB5AAB5B8C1C8C8CDC8CDD9DF
DFE8DFDFDFD9CDD6C4C8B8B8B5AAA795958F8F8695899595
8F959595A7A489958F714A2C150B121D322C294D4D383842
385C5C5C687D958686869598A495959B98A4A7A39BA79BA1
A49B957147394444392929393E98A6A380687489CDF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F780292929322C121818180F0F0342382920
241B1B291B1B1B1829446BC8CDC8CDD6D6CDCDD6D9D6D6CD
B5AA8FAFB5A7B8CDD9DFDFE8DFE8DFDFDFD9CDCDCDC4B8B8
B5AFAAAFAAAAAAAAA4AAA4A3AAAAB5B8B8C1CDC8C4D6D9DF
DFDFDFDFD9CDCACDC8C1B8B8B8B5AAA1988F86958F86958F
9595988398A7A7A79889715C59504442392C2F391E394447
59685968807D8386898F8F8F98A4989AA19898A4A79BA1A7
9B95896B444239384242293B399BAFA177747D89D9F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E862291E2C2F32121E1B1D121212382F291E
1B1B151E151B1E1E1E446BBFC8C8D0CDD6D6D6D6CDD9D9CD
CDB59898AFAFA3A7C8D9D9E8DFE8DFDFD9D9D9CDCDC8C8B8
AFAFAFAFB5AAAAA49A98958F95A3AFB8BFC4BFC4CDCDD9DF
DFD9DFD9D9D6CDCDC1B8B8BFAFAFA7AA9B8F8F898F95958F
989895A48395A7B5A79571717171505C42424D592F425F71
805F7483808689958F95959595A4A79B9BA19B9B9BA4A3A1
9B95805C44392F42422F2C3232A1A78F74687D95D9F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7D353292C2F39351E1E2C1E121B293829291B
151B151B1E1B121E294471B8C8D0CACDD6D0CDD9D6D6D9D9
D6C4A3A3A7A39895A7CACDD9DFDFDFDFD9D6C1C8B8C8B8AF
A7A4A7A498989886897777778998A7AFB8BFC4C4CDD9D9D9
D9D9D9D6D9CDCDC8C1C1C4B8AAAFA7A7A7988F8695869595
95989595A49595A4AFAF959B898071715C4D5F6871537180
71807D77868F959595989898989898A1A4A1A4A19B9BA49B
9B957150422F292929181E292CA4A18968687D9AEBF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F79B2F2C2C2F2C391E2C392C2929292F1E2F1B
0B121215291B121E2C475CB5C8CDD0CDD0CDD6D6CDD6D6D6
D9D6C4B5B5A3868686869586958C8989897D686B716B5C59
59595F5F5F5656656B6B6E6E6E7798A7B5B5BFCDCDCDD9D9
D9D9D6CDD6CDC8C1C1C8B8B8B5AFA7A3989895958F868F8F
959598A4A49595A3A7A4A4A4A7A495959580807D747D8071
747D958F989898989AA1A19A9BA1A1A4A49BA7A1A7A49B9B
9B805C3939293842291E181B3EA1868068687DAAF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7A7442C291E181E1B1E1E1E2929292F1E1E29
15150B15291E151B294468A7BFC8CDD0CDCAD6D6D6D6D6D6
D9CDD6CDCDB5A39889838989899586867171715F5F5F5959
5F5F685C5C5C5F5C6B5F5F74838698AAAFBFC8CDCDD9CDD9
DFCDD0CDCDC8C1C1C1C4BFB8B5B5A7A39B98928F868F8986
8F8F95A4A4A4A498A4A4A7A4A4A4959595808383837D7480
869895989B98A1A19B9BA19BA19BA498A1A7A19BA7A1A19B
95805942292F42351B1E121850A1867768687DAAF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7A442291E1E181E121E291B1E1E29291B1E29
1B12120B1529291E29325FA7C8C8CDD0D6CDCDD0D6CDD6D6
D6D6D9D9CDCDC4B5A389717D77958C897D7D7D71685F5F5F
715F5F5F5C59535F5C717D868689A1AFB8BFCACDCDD9D9D9
D9D6CDCACDC8C8C8C1C8C1BFB5B5AFA198988F86837D8383
83958F9598A4AFA7AAA7A4A4989895959583958F868F9598
9898A19B9A9B9BA4A3A49BA4A1A49B989BA79BA49B9BA1A4
89684729292F2942351E18125F988677626877AFF1F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F1F7F7F1F7F1F7F7F7F1F7F7F1F7F7F7F7
F1F7F7F7F7F7A7422C291B1E1E181E1B1E1E1E1E1E1B1229
1B151512122929292F39509BBFC8CDD0CDD6D6D6CAD6D6D6
D9D6D9D9DFD6CDCDC486867D837D7D7D86868C95777D7171
5F7171716B5C5F6B6B6E77868698B5B5BFC4C8CACDD9D9D9
D6CDD0D6CDC8C1C1C8C8BFC4B5B5AF9B9B8F89747465656E
777D8F959595A4A7A4AAAAA7AAA7A4A498A498A4A4A49B9A
A198A49BA1A4A49BA4A3A4A79B9BA1989BA7A49BA1A4A795
806B4229291E35422912181E7D8F8677745F77AAF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7B54232291B1E181E181E1B1E1B1E1E1B031E
1E1512151B1E2F424244599BB5B8C8CDD0D6D6CDD6D6D6D9
D9D9D9D9D9D6D6D9CDC4A7A6A398A3A38C9598A3A3989886
8F95869595868683869298A1AAB3C4CDCDCDD6CDD9D9D9D9
D9CDD0CDCACDC1C1C8C4BFC4B5B5AFA3988F866B5C53565C
5C65778695959898A4A4AAA4A4A7AAA7AAA3A4A7A4A7A4A7
9BA19BA4A4A3A3A49BA7A7A7A3A49B9A9BA1A39BA4A39B95
804739291B1B29351B1B12448F83837762687D95C4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1C44D2C1E1E1E1E1E1B1B12121E291E1E031B
1E121512121B29424D474D89AFC4C8CDD0CDD6D6D6D6D6D6
D6D9D9D9D9D9D9D9D9CDCAB8CAB5B5B8B5B5BFB8C4B8B5B8
B5A7B5B5B5B8B5B5B5C1C4C4C4CDC4D6CDD6CDD9D9D9CDD6
CDCACDD6CDCAC1C4C8CDC4C1BFB5B5AFA39886715C5C5656
4D565F747D959595A4A4A7AAA7AFA7AAA7A7A7AAA7A4A7A7
A7A7A7A7A1A7A4A7A7A7A7A7A7A4A39B989BA7A39BA4A495
6B442F1E152929241B352959928983775F5F838F77FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F1F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7D3623529121E1E1B1B1E1E1E291E1E1E0B12
1E121E15151B1B1E425C5F95A7B5C8C8CDCDCDD6D6D6D6D6
D9D9D9DFD9D9DFD9D9D9CDCDCDCDCDCAD9C8D9C8D9D9C4CA
CACAC4CDCAD6C8D6CAC8D9CDCDCACDD6CDCDD9D9D9D9D9D6
CDCACDD6D0C8C4C8C8C8C4BFBFB8B5B5A7A39874685F504D
4A4A4A5F717D868F95A4A7A7A7AFAFAFAAAAA7A7A7A3A4A7
A7A1A1A7A7A7A7A79BA7A79B9BA7A4A19BA3A7A49B98A489
5F42291E1B1B241B15422F68957D806E626277864DDCF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E86E35351E1B291B1B1E12121E1E1E1E1203
121E121B1E1E292F424459899AB8BFC8C1CDD0CDD6D0D6D6
D9D9D9D9DFDFD9D9DFDFDFDFDFDFDFDFDFDFDFDFDFDFE8DF
E8E8DFDFDFDFDFD3D9D9D9D9D9D9D6CDD9D6D9DFD9D9CDD9
CDC8CACDC8C1C8C8C8C1C8C4BFBFBFB5B5BFB5988674715C
4D5050443E445050595F869898A7A7A7A7A7A7A7A4A49BA4
A19BA7A49BA1A49BA79B98989B989B9BA7A3A3A49BA19871
4A291E1B1E1E1B1529352C597D8F746E5962776B2995E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F1F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E57444381E1B1B1E1B121E181B1E1B291203
031E1E0B1E1E2929424759809BAFBFC8C8C8D0D0D6D6D6D9
D9D9DFD9DFDFDFDFDFDFDFDFDFDFDFDFDFDFE8DFDFDFDFDF
DFE8DFDFDFDFDFDFDFD9D9D9D6D9D6D9CDD9D9D9DFCDD6D6
CDD0CDCACDC1C8C8C8C8C8C8BFC4BFBFBFBFC4A7A7988674
5F56594444353239394450717D95A4A4A7AFA7A7A4A7A49B
A4A49BA49BA4989B98898F89899598A7A3A4A79BA19B9871
44291B1E1E1E152935292C446E8F866E59627D5C2989D3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1E88339442C1E1E181B12121E1B1E1E1E1E03
03121E1E1B29292F38474D80989BB5BFCDD0D6CDD6D6D6D6
D9D9DFD9DFDFDFDFDFDFDFDFDFDFDFDFE8DFDFE8DFDFE8E8
DFDFE8E8E8DFDFDFDFDFDFD9DFD9D9D9D9D9D6D9D9D9D6D6
D6CDD0CDCAC8C1C8C8C1C4C1BFBFBFBFC4BFC4BFB8B8AA98
957468594D44443532353944394D718995A7A7A4A495A4A4
A4A49898988F8F95717D7168748995A7A19BA4A19B9B9559
391E291B1B1E152F2F29183B5F8383836E7D834D4A6EA4DC
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F78035443929291B1E1E1B181E1E1E1E1E0B
030B1E1E1B292939444D5C899BA7AFAFC1CDD0D0D6D6D6D6
D9D9D9D9DFDFD9DFDFDFE8DFE8DFDFE8E8DFE8E8DFE8E8DF
E8E8E8DFE8E8DFE8DFDFDFDFDFD9D9D9DFD6D9D6D9D9CDD0
CACDCACDCDC8C8C8C1C8C8C4C1C4BFC4C4BFBFB8B8BFB8B5
A7A386685F5F59443E39323539323E4D5983898F958F8F95
9895959589837D71686868718698A7A1A19BA3A1A1989559
2C291E0B1E1B1E35241E183B4A626E77837D7144426B89D9
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F795394439292F291B1B1B1B1E121E1E1E12
0303121B291E292942595C71959AAFB8C8CDCDD6D0D0D6D9
D9D6D9D9DFDFDFDFDFDFDFDFDFDFE8DFDFE8E8E8E8E8DFE8
E8E8E8E8E8DFDFDFE8DFDFDFDFD9D9D9D9D9DFD6D6CDD0CD
CDD6CDCACAC8CAC8C8C8C4BFC8C1C1C4BFBFC4C4C4BFBFB8
AFAFA3957D7471686850443935353944445968687174807D
867D7171686868686868718695A3A79B9BA1A19B9B98894A
2929121B2912292929291E29355C59595C5350384A6E9EE2
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F795423947392F1E1E121E1B1B1E1E1E1E1E
12030B1B1E29394242445C719598A7B8C8CDD0D6D6D6D6D9
D9D9D9D9DFDFDFDFDFDFDFDFE8DFE8DFE8E8DFE8E8E8E8DF
DFE8DFE8E8DFE8E8DFDFE8DFDFD6D9D9D6DFD9CDD6D9CDCD
D6CDD6CDC8C8C8C8C1C8C8C1C8BFC4C4C8C4C4C8C4BFBFB8
B8B5AFA7A395807D71715950443E3939394450505959686E
6268595F6868715F68748398A39BA7A3A1A39B9898958944
2912121E1E15241B291B181D1D3B3E3B353E32394A62A4F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7A7444247442F291B121B1B291E1B1E1E1E
12030B121529293847595971899BA7B5BFCDCAD6D6D9D6D6
D9D9D9D9DFDFDFDFD9DFDFE8DFDFE8E8E8E8E8E8E8E8E8DF
E8E8E8DFE8E8E8DFE8DFDFDFDFD9D9DFD9D9D6D6D6D9CAD6
D6CDD6CAC8C8C8C8C1C1C8C1C4C8C8C8C4C8C4BFC1BFBFBF
B8B5B5AFA7A3A395897D71685950503E3E44445050595959
68686859686268717486929B9BA3A1A1A19B98A1988F8042
1E121B1E1B1E1B241E1B12121D2F2F26293232444D80E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7B5443944473929291E1E2929291E1E1E29
1B0B030B2929293942475971898CA4B5B8C1D0CDD6D0D9D6
D6D9DFD9D9DFDFDFD9DFDFE8DFE8DFE8E8E8E8E8E8E8E8E8
E8E8E8E8E8E8DFDFDFDFDFDFDFDFD9D9D9D9D9D6CDD6CDD6
CDD0CDCDC8C8CAC8C8C8C4C1C8C4C4C4C8C8C8C4BFBFB8BF
BFB8B5B5B5A3A7A39B95868371715F50443944444D474D50
505950595F68747486989BA1A3A39B9B9BA1989B8F898039
1E1B1E1E1B241E291B1E121206121D1D322C38424AE2FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E8A44D4444444A292F2F1B291E1E291E291E
2F38291B292F292F44475C71899BA4A7BFB8C8D0D6CDD6D6
D9D9D9D9DFD9DFDFD9DFDFE8DFDFE8DFE8E8E8E8E8DFE8E8
E8DFE8E8E8E8E8DFDFDFDFDFDFDFD9D6D6D6D6CDD9CAD6D6
CDCDD6CDCAC8C8C8C8C8C8C8C8C8C8C4C4C4C4C4BFC4BFB5
BFB5B8B5B5B5AFA3A79B9895959589837D68685F56505044
4A5C686B748686989BA19BA3A19BA39BA19898958F805F29
291E1E1B29242929151B1E1212121E1E1E2F2F3953CDE2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7DC954D4244474D2F2F291B29291E1E1E1E29
1E2F29292935383842475C7180899AA7B5C8C1CDD6D6D6D6
D6D9D9DFD9D9D9DFDFDFDFDFDFDFE8E8E8E8DFE8E8E8E8E8
E8E8E8E8E8DFE8E8DFDFE8DFDFDFD9D6DFD6D6D9D6D6D6CD
D6CDCACDC8C8C8C8C8C1C1C8C1C8C8C8C8C8C8BFC4BFBFBF
BFB8B5B5B5B5B5AFA7A3A7A19BA3988F89867D7171686868
7174747D8F959B9B9B98A1A1989A9BA19B98988F89805929
291E1E1E1E1B29151B291B03121B291E292F2938476B89C4
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1
F7F7F1F7F7F7CA6B5C444A474D4A2F2F291E291E1E1E2938
2F2929292929392F444A596271839BA7B5BFC8D0D6CDD6D9
D6D9D9D9D9DFDFDFDFDFDFD9E8E8DFDFE8E8E8E8E8DFE8E8
E8E8E8E8E8E8E8E8DFE8DFDFDFDFD6D9D9D9CDD6D6CDD6CA
CDD0C1C8D0C8C8C1C1C8C4C1C1C4C4C8C8C8C1C4C8BFBFBF
BFBFB8B5B5B5B5AFAFAFA7A3A7A7A39B9895898F86868686
86868F9898A4A39BA198A39BA1A1989B9A9B988986714729
291E1E291E1B1B15292915120B1E1B12292929292F424D95
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7B86244444A39444A39392F2929291E291E1B
1E291E1E1E29292F394A475F718395A7AFB5C8C8D0D6D6D6
D6D9D9DFDFDFD9DFDFDFDFE8E8DFDFE8E8E8E8E8E8E8E8E8
E8E8E8DFE8E8E8E8DFDFDFDFDFDFD9DFD6D9D6D6CDD6CDD9
CDCAC8D0C8C8C1C1C1C8C8C8C4C8CDC8C1C4C8C8C4B8B8BF
B8B8B8B5B5B5B5B5AFA7A7A7A7A3A3A3A3A3989898989898
92989BA39BA7A1A19BA1A1A1989B9A989B988F8980684429
291E1E1E1B1E1B20291B1B15151B121B1E2929291B4A4A89
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F79D594442443942422F35382F292F1E1E1B12
18292C292929292C2F3947595F7183A4A7AFC8CDD6D6D6D6
D9D9D9D9D9DFD9DFDFDFDFDFDFDFE8DFDFDFE8E8E8E8E8E8
E8E8E8E8E8E8E8DFDFDFE8DFDFDFDFD9CDD6D6D9D6CDCDD6
CDCDC8C8C1C8C8C1C4C4C8C8C8C8C8C8C1C8C8C8C4B8BFBF
BFB8BFBFB5B5B5B5AFAFA6AFA3B5A7A7A3A7A3A7A3A7A19B
9BA3A1A7A19BA39BA1A19BA398A198A19B958F7D715C3929
291E1B1B1B1E1529241B151512151B291E291E121E42426B
D9F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7894D4447444A39422F2F2F2F29391E1E1E1E
1B1E2F2F291E1E293939395C5C6B8095A7A7C1C8CDD6D6D9
D6D6D9DFD9D9DFD9DFDFDFE8E8DFDFE8DFE8DFDFE8E8E8E8
E8E8E8E8E8DFE8EBDFDFDFDFDFDFDFD9D6D6CDD9D9D6D6D0
D0C8D0C1C1C8C8CDC8C4C1C8C8C8C1C1C1C1BFC4C1B8BFBF
B8C4BFB5B3B5B5AFAFB5B5AFA7AFB5A7AFB5AFA7A7A1A7A3
A7A7A19BA1A1A4A1A3A3A1A1A19BA19B988F89805F472F29
29291B1E1E151B2429151B121B151E1E1E1E120B1E424A47
B0FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7
F7F7F7F7F7F783594A4A4244424A392F3938291E1E292912
1E1E1E1E1E1E1E181E3938475C5F8089A4AFBFC8CDD0D6D9
D9D9D9D9D9DFDFDFDFDFE8DFDFDFDFE8E8E8DFE8DFE8E8E8
E8E8E8E8E8E8E8DFDFDFE8DFDFDFD9D6D6D6D6CACDD6CDCA
CDC8C8C4C1C1C8C8C8C1C8C8C8C1C1C1BFC1C4C1BFBFC1BF
BFBFBFB8B5B5B5B5AFAFAFB5AFA7A7AFAFA7A7A7A7A3A7A7
A1A19BA1A79BA1A1A19BA19BA1A19B98989580685C393929
291B1B1E151B24291B291512121B1B291E1B030329424A44
95F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7625939474A4D4D42422F2F38352F291B1E1B
1E1E1E121E1E1E1E2929394A44595F718998BFB8C8C8D0D6
D9D9D9D9D9D9D9DFDFDFDFDFDFDFDFDFDFDFE8E8E8E8E8E8
E8DFE8DFE8E8E8DFDFE8DFDFDFDFD6D9CDD6D6D6D6CDCDD0
C8C8C8C4C8C1C1C1C1C8C8C4C8C1C1C4C1BFBFBFB8C1B8BF
BFB8BFAFB5B5B8B5B5B5AFAFB5AFAFB5AFAAA7A7A7A7A3A7
A1A3A3A7A7A3A7A3A3A19BA1A1A19B988980715C442F2929
1E1E1B1B151B2F1B0B0B1512151B1B121E120B122F29394D
95F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F762592C443942474A4A3838382F2F291B1E1B
121E292929291E1E2F39394747444D688089AFB8C4C8CDD6
D6D9D9D9D9D9DFDFD9DFE8DFDFDFE8DFE8E8DFDFE8DFE8DF
E8E8E8E8E8EBDFE8DFDFDFDFDFD9D9D6D6D6D9D6CAD6CAC8
CAC8CDC1C4C1B8C1C1C1C1C8C4C1C1C8BFC1BFC4BFB8C1B8
B8BFBFB5AFAFAFB5AFAFAFAFB5B5A7AFAAA7A7A7A7A4A7A3
A1A7A7A1A7A1A1A1A1A1A198A1A19B9583717159442F2F1E
1B12151529291B0B0B1B120B1B1E151B12120B1E35292F4D
89F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F74D59394242394A4442422F38382F291E1E1E
12181E1E1E2929291E2939474459475C6E7DA4B5C8C8CDD6
D6D9D9D9D9D9D9D9DFDFDFDFE8DFE8DFE8DFE8E8DFE8E8E8
E8E8E8E8DFDFE8DFDFDFDFDFDFDFD9D9D6D9D6CDD6CDC8CD
C8C8C1C1C8C1C1C1C1C1C1C1C1C8C8C1C1C1B8B8C1BFBFBF
B8B8B8B8AFB3B5B3AFAFAFAFB5AFAAA7A7A7A7A7AAA7A7A4
A7A7A7A79BA39BA19BA19BA19B9B988680715944382F2912
121B151B29390B0B151B0B15121B121B0303121E1E29394D
83D3FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F73844424A44424742424A392F2F2F1E1E1E1E
1E1218181E1E291E29292F4759475C4D5071A4AFC8CDCDD0
CDD6D9D9D6D9DFDFDFDFDFE8DFE8DFE8DFE8E8E8E8E8E8E8
E8E8E8E8E8E8DFDFDFDFDFDFDFDFD9D9D9CDD6D9CDD6CACD
CAC8C8C1C1C8C1C1C1C8C1C1C1BFC1C1C1C1BFC4BFB8BFB5
B8B8B8B3B3B5AFAFAFAFAFAFAFB5A7AAAFA7A7AFA7AAA7A1
A1A7A7A1A3A19BA1A1A1A1A1989895837171594439291B1B
1B121529291B0B0B150B15120B1212150312121E291E384D
71C1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F1
F7F7F7F7F7E8424442444A394A42444A422F3838291E1E1E
2912121E1B1E1E292929294A4D505C5C506895A7AFC8D0CD
D6D6D9D9D9D9D9D9DFDFDFDFDFDFE8DFE8DFE8DFE8E8E8E8
E8E8E8E8DFE8E8DFDFDFDFDFDFDFDFDFD9D6D9D9CACDCDC8
CDC1C4C1C1C8C1BFC1C8C1C1C1C1C1C1B8C1BFBFB8B8B8B8
AFB3B5B5B5B3B5AFAFAFAFAFAFAAAFA7A7AAA7AAA7A7A4A3
A7A4A79BA49BA1A3A79BA19B98988980715C4442291E1B1B
1B1B29291B0315151512120B120B121212031B1B291E394A
6BC4F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7E86E5339424A394A4A424A42383942291E291E
291E181E1E1B1E29292929425059505C505F8FA4AFBFCDD6
D6D6D6D9D9D9D9DFDFDFDFDFDFDFE8E8E8DFE8E8E8E8E8E8
E8E8DFE8DFDFDFE8DFE8DFDFDFDFDFCDD6D9CDD6D6D6CACA
C8C8C8C8C1C1C1C1C1C8C1C1C4C1B8C1C4BFC4B8B5B8AAB8
B8AFB5B3B3B5B3AFAFAFAFAFA7AFAFA7A7A7A7A7A3A7A7A7
A4A7A3A4A3A19BA4A1A19B98958F8371685C472F291E1E1B
1B2929290B0B120B12150B120B0312120B121B1B29292C44
6BD3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7
F7F7F1F7F7E8594D44394A4442424A4A42382F422F291E29
291E12121E291E1E2F2F2F394A47595F5C598698AFBFC8CD
D0D6D6D9D9D9DFDFD9DFDFDFDFDFE8DFE8DFE8E8E8E8E8E8
E8E8E8E8DFE8E8DFDFDFDFDFDFDFD9D6D9D9D6D6CDCDCDC8
C8C8C1C1C1BFC1C1C1C1C1C1C1C1B5C1BFC1BFBFB8B8B8BF
B8B5AFB5AFB5AFAFAFAAAFA7AFAAAAA7AFA7AAA7A7A7AAA7
A7A7A1A39BA19BA3A19B9895958F83715F59392F291E1B1E
2F38290B0B0B0B1515150B0B03120B1215121B1E1E292F4A
77E2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7CD4A4A39384A4244444A424D42383938292929
1E292C121E1E1E291B1E2F2C324A505C685F838FAFB8BFC8
CDD6D9D9D9D9DFD6D9D9DFDFDFDFDFDFE8E8E8E8E8E8E8E8
E8E8E8E8DFE8DFDFDFDFDFD9D9D9DFD6D9D6D6D6CDD0CDCD
C8C1C1C1C1C1C1C1B8C1B8C1B8BFC1B8BFC1B8B8BFBFB8B5
B5B3AFB5AFB3AFAFAFAAAAAAAFA7AAA7A7A7A7AAA4A7A7A7
A4A7A7A1A19BA19B9B9B958F8F8380595942392F2F2F392F
1E12121215151512120B0B0B0B1203121B121B1E1E293953
BBFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F1F7D344383942444A424242424A4A3838382F2929
291E291E1E1E2929291E1E2C39444759625F868FA4AFBFC8
C8D0D6D9D9D9D9D9D9DFD9DFDFDFE8DFE8DFE8E8DFE8E8E8
E8E8E8E8DFE8E8E8DFDFDFD9D9D9D9DFCDD6CAD6D6CDD0C8
C4C8C1B8C1C1B8C1B8C1C1C1C1BFB8C1BFB8B8B8BFBFB8B8
AFB5B3B3AFAFAFAAAAAFA7AFAFA7AAA7A7A7A4AAAAA1A1A1
A7A1A19BA19BA19B9895958F8980715C47444238392F291E
1B151B15151E12150B0B0B0B03030B1B12121B1E18293983
E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F1
F7F7F1F7F7B544422F384247424744444A4A424238352F29
1E1E2929121E291E292C1E422F39505C7168868698A4B8C8
CDCDD6D6D9D9D9DFD9DFDFDFDFDFDFE8E8E8E8DFE8DFE8E8
DFE8E8E8E8E8DFDFDFDFDFDFDFDFD9D6D6D9CDCDCDCAC8C8
CAC4C1C1BFB8C1B8B8C1B8B8C1C1C1BFB8B8B8BFB8B8B3AF
B5B5AFAFAFB5AFAAAAAFAAA7AAAAA7AAA7A7A7A7A3A7A4A4
A1A4A7A3A4A19B98958F8986837171594744392F392F2F15
151515151B15120B030B0B000B121212120B1E12032F4A95
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7B84A474A3944424A4D4A424A4D4A4242382C29
291E292F1229291E292F2F424442505C6862808F8FA1B8B8
C8CDD6D9D6D9DFD9D9D9DFDFD9DFDFE8DFE8E8E8E8E8E8E8
E8E8DFE8E8DFE8E8DFDFDFD9DFDFD9D6D9CDD6CAD6CDC1C1
C8C8C1C1BFBFB8C1B8B8B8B8BFB8C1B8B8B8B3B8B3B5AFB3
B5B5B5A6AFAAAFAFAFAAA7AAAAA7A7A4A7A7A7A4A7A4A3A1
98A39BA7A19B9B988F898F8371806B594439382F29291E15
120B121B15120B000B15030312150B12151B1B121B2F53BB
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F7F1E5C14A4A4A2F42424D4D4A444A4A4A4238422F29
291E29291E291E292F2C2F2F444A475F626883898F9AAFB8
C8CDD0D6D9D6D9D9D9DFDFDFDFDFDFDFE8DFE8E8E8E8DFE8
DFE8E8DFDFE8DFDFE8DFD9DFDFDFD9D9D9D6D6CDC8CACAC8
C8C1C1C1C1B8C1B8C1C1C1B8B8B8B8C1B8B3BFB5B5B3B5B3
AFB3B5AFAFAAAFAAA3A7A7A4A7AAA7A7A3A7A1A7A7A3A7A1
A3A1A49BA49898958F8983808071714442392F292F1E1515
1215150B12150B0B0B0B03151B0B0B1B1B1212121E294DB0
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F1
F7F7F7F7F1CA4744422F42444A4A47424A4A534A2F383829
29291E292929292F2F2C392C42474D5F5F627D868F9BAAB5
C1C8CDD6D9D9D9D9D9DFD9D9DFDFDFDFE8DFDFE8DFE8E8DF
E8DFE8E8E8E8DFDFDFDFDFDFDFD9D9D6D6D6CDCAC8C8C8C1
C8C1C1C1BFC1B8C1B8C1BFC1B8BFC1B8B8B8B8B3B5B5B3AF
AAA6AFB3AFAAAAAFAFA7AAA3A3AAA7A1A1A4A1A7A7A7A1A1
A49BA1A19B989B958983808071715942392929291E1B1B15
201B151515120B150B03151B0B0B12151215121B2F2F4D95
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7E8CA444A422F39384A5C4A4A444744532F423829
1E291E292C2F29292F2F2F2F3844595C5F7180868F9AA7B5
B8C1CAD6D6D9D9D9D6D9D9DFE8DFDFE8DFE8E8DFE8E8DFDF
E8E8DFE8DFDFDFDFDFDFDFDFD9DFD6D9D6CDCACDC8CAC8C1
C8C1C8C1C1C1B8B8B8BFB8C1C1C1B8B8BFB8BFB5B5B3B5AF
B3AFB3AFAFA6AAAAAAA7A1A7AAA1A4A7A1A7A1A4A1A1A1A4
A3A19BA19B9B988F898689806B68594A392F2F291B1E1B20
1E1B151B2015150B0B1B1B1B0B150B15121B1B291E384DAD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7E8B8425C422F3942424A4A4A4A4A4A4D4242422F
1E1E1E292F2F29292F2F39383842445C68627D838F98A7B8
BFC1CDD0D6D9D6D9D9D9D9D9DFDFE8DFDFE8E8DFE8DFDFE8
E8DFE8DFE8E8DFDFDFDFD9D9DFD9D9D9CDC8CAC8D0CDC1C8
C1C1C1C1C1B5C1B8C1BFBFB8B8B8B5B8B8B8B8B8B3AFB5B5
B5B5AFAFAFAAAAA3A3AAA3A1A7A1A7A3A7A4A3A1A7A1A19B
A1A19BA39B98959583807171715C4439392F2929291B1B1B
1B1B29291B1B1E241B1B1515120B15151B1E1E1B1E2F5FCA
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F1F7F7F7F1D3624D4239293942534D4A4A4D4A424242442F
291E1E292F352F29292F2F4A474A475C6B5F71807D8F98AF
B8BFC4D0D6D6D6D9D9D6D9D9DFDFDFDFDFE8DFDFE8DFE8E8
E8DFDFDFDFDFDFDFDFDFDFD9D9D9CDD0D0D0C8CDC8C8C8C1
C1C1B8B5B3B8B5B3B5B5B8B8B5B8BFB8B8B5B8B5AFAFB5B3
AFAFB3AFAFAAAAAAA3A6A7A3A7A3A3A1A4A49BA1A49BA1A4
A1A19B98958F8F7D7471715F59504A393929292929241E1B
2929241B29241B1B1B1515151B291B1B12030B1B2962D3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7E8D34D474A382C2F42424D534A4D53424A2F4242
2C1E1E2929382F3529292F38474D595C716271717D8695A4
AFB8C8C8CDD6D6D6D6D6D9D9D9DFDFDFE8E8DFE8E8E8DFE8
DFDFDFDFDFDFDFDFD9D9D9D6D9D6D9D6CDCAC8CAC8CACAC1
C1B8B8B5B8B5B8B8B8B8B8C1B5C1B8B8B8B5B8B5B5AFB5AF
B3AFB5AFAFAFA3A1AAA7A6A7A7A7A7A79BA7A1A4A3A1A19B
A19B98959589898380715F50594444392C2F292924292924
292F2915150B0B151B1B1B1515030B120B031B291E86E8F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F1F7F7F7F7F7F7F1F7
F1F7F7F7E8CA4D423942382F42444D5C4A4A534A4A384242
381E1E1E2939382F2F2F2F38444D47475F625F71807D8FA4
AAB5C8CDD0D6D6D6D9D9D9D9D9DFDFDFDFDFE8DFDFDFE8E8
DFDFDFDFDFDFDFDFD9D9D9D9D9D6CDCDCAD0C8C1C8C8C1C1
C1B5B5B8B8B8B8C1B5B8B8B8B5B8B8B8B8B8B5AFB5B5B5B3
B5AFB3B3AFA6AAA6AAAAA7A7A7A3A4A3A7A3A7A1A49BA198
A4989B958F867D74715F5059444439392F29291E1E1E1B29
1E1E24150B0B1B1B0B0B030B0B0B0315031B291E2FA3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7
F7F7F1F7F7D3594D38423839444A4A5C424453534A423942
421E1E1E2F292F3838352F2F394A59446B5F5068717D8695
AAAFC8C8CDD6CDD6D9D9D9D9D9D9DFDFDFE8DFE8DFE8DFDF
DFDFDFDFDFDFD9D9D9D9D6D9CDD6D6D0C8CDC8CACDCAC1C1
C1B8C1B8B5C1B8BFB8B8B8C1B5B8B8B8B8B8B8B3B8AFB3AF
AFB3AFAFAFAAAFAAAAA7A7A3A7A7A3A7A1A49BA1A1A1A1A1
9B989B958986807171565950474438292929291E1B1E1B1B
12121E291515150B0B0B0B0B000B03120B1E1E1E39A4F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7E262594442392F4242424D4A424D534A4A3838
422F1B1E29382F39384238392F3959475F5F5050687D8695
A4AFC8C8CDD0D6D6D0D6D9D9D9D9D9D9D9D9D9DFDFDFDFDF
DFDFDFDFDFDFD9D9D9D9D9D6D9D9D6CDCACAC8CDCACDC1C1
B8C1B8B8B8B8B8B5B5B5B8B8B8B5B8B8B3B3B5AFB5B3AFB3
AAAFAFAFAAAAAAA1A3A3AAA7A7A1A7A7A1A39A9BA49BA49B
A495959589808071565C504439392F2F2F2929291E1B1512
12151B1B291B0B0003120B030B030B12121B1E2F44B5FFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F1F7F7F7F7D36E4D4238382F4444424A594A4A4D4A424238
4239291E1B2F392F384242292F39444D4D59594D68747D95
A1AAC8C8C8CDD6D6D6D6D9D9D9D9D9D9DFDFD9DFDFDFDFD9
D9D9D9DFDFDFD6D9D9D6D9D9D9D6CDD0CDC8D0C8C8CAC1B8
B8C1B8B5B5B5B5B5B5B8B8B5B3B8B3B5B5B8B8B8B3AFB3AF
B3AFB5AAA3A6A3A3A1AAA7A1A3A1A4A1A4A1A1A1A1A1A19B
98958F868371685F59594444423939291E1E1E1E1E1E1B1B
1B1B151B151B0B0B1500000B03030B0B121E293947D3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7
F7F7F1F7F7E289594239382F384A4242594A4A4A42424A38
38382F1E1E1E2939293942382C3842504D4750506880748F
A4AFC8C8CDC8CAD6D6D6D6D9D9D6D9D9DFD9DFD9D9DFD9D9
D9D9D9D9D6D6D9D9D9D9D9D6CDD6D6CAC8CAC8CAC8C1C1C1
B5B8B8B5B8B3B5B5B8B8B8B5B8B8B5B5B8B8B3B5AFB3AFB3
AFAFAAA6AAAAA3AAA3A3A6A7A7A7A7A39BA19BA19B9B9B98
958F868074717171593E4444393929291E1E1E12121B1B0B
15151515151512150B0B0B0300030B151B1E2F424DFFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F777594D383838394A38424A59424A4A423842
38394A2F291E1B29392F2F4A4238394459474744505F8086
8FAAB8C8CDCDCDCAD6D6D6D9D6D6D9D6D9D9D9D6D6D9D9D6
D6D6D9D6D6D9CDD6D9D6D6D6D6CACAD0C8CAC8CAC1C1C1B8
B3B8B5B3B3B3B5B5B5B8B8B3B8B5B8AFB8B3B5AAADAAB3AF
AFAFAFAFAAAFAAAAAAA7A4A1A7A7A7A7A1A19BA498989895
897D80807168595047443939392F291E1E1E1B1B1B151B1B
1E1E1B1B150315150B1203000B03121529354444A4F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F1F7F7F1F7F78362534444422F533838445C42425C422F42
423842381B291E1E293939474A3839384D4D47444D59687D
869BAFC1C8CDD6D6CDD6D6D6D6D6D6D9D9D6D6D6D6D9D6D6
CDD6D6D6D9D9D6D6D6D6D6CDD6CDCAC8C8CAC8C1C1C1B5B3
B8B3B5B3B5B3B3B3B8B5B3ADB3B5AFB3B3B3B3AAAAB5AFAA
AAAAAFAAAAAFAAA7A7AAA3A7A7A7A7A39B9B9B989595958F
8F80807168595C5C44392C3929291E1B12121B1B1215121B
1B1B1B1E1B1B151B0B000B0B0B121B1E35383971E2F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7
F7F7F7F7F7F7776B5C4A3838394A4238384D4D425C422F42
4242384A1829291E1E2F38424A422F394247444A44596880
7D95A7AFB8C1C8D0D6D0D6CDD6D6CDD6D9D9D6D6D6D9D9D9
D9D6D9D6D6CDD0D6CDD6CDD6CAD6C8C8CAC8C8C1B5C1B5B3
B3B8B8B5B5AAB5B5B5B5B5AFAFB5B3B3AFAFADB3AFADAAAA
AAA3AAA6A3AAA7A7AAA7A7AAA3A1A4A3A498988F8F8F8F89
86717168595C505042392C2929291E1B121212121B121B1B
1B1B1B1B1B1B15151B0B0B15030B1B2F3839449DF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F77762624D3842384A4A38384A4D425353382F
38383838291B292929292C394442382F2C4A4A4739505F71
838FA4B3B8C1C1CDCDCAD0D0D6D0D6D6D6D6D6D6D6D6D6D9
D6D9D9D6D9D6CACDCAD6D6C8CACDCAC1C1C1C1C1B8B5B8B3
B5B5B3AAADAFADAAAAADADB5B5AFB3AFB3B3AAAAAAAFAAAA
AAAAAFA4A3A7AAA7A1AAA79BA19B9BA19B98958F8F898F83
71716B5F5F4D4444393939291E1E1E120B121215121B151B
15151B1B1B1B1B1B1B0B030303121E35392F5CC4F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7
F7F7F7F7F7F79D626E62423842424A42424A4A424D534229
394A382F38291E2F2F382F384253423838394D4A4A445C71
717D98A7A4B5B8C8CDC8C8CDCDD0CDD0D6D6D6D6D6CDD6D6
D6D6D6D6CDD6CDD6CDD0CACDD6D0C8C1C1C1C1C1B3B3B8AD
B5AAB3ADAAAFB3B3AFADAAAAAFADADAFB3AFADAAAAAAA3AA
AAAAAAAAA6A7AAAAA7A7A1A7A4A3A49B98989B959589837D
8071716850504444392C29291E1E1E121212121B1512151B
1E1B1B1515150B0B030300000B1B2F39294462D3F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7B56B6B5C534242394D4A42424A4D4A534A38
38424229422F1B1E29353844424247422F2F47444D504459
718095A7A4AAB8B8C8C8CDD6CDCDD0D6D6D9CDD0CDD9D6CD
CAD0CDD0D6D0D6D6CACDD0CDC8CAC1C1C1C1C1B8B3B8B8AA
ADAAB3AAAAB5ADAAB3AAB5ADADAAAFB3AFAFAAAAAAAAAAA1
A6AAAAAAA1AAA7A4A4A79BA398A49B989595958F86867D71
80685959594444392C292929291E1B12120B0B1212151215
1B1B0B150B0B030000000000031E39292F4783EBFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C46271774D4439384A42423842424D535C47
2F424A2F2F382F1B29292F3538444A4A422F4A4A424D5950
597189A4AAAFB8B8BFC8C8C8C8C8C8D6D6CDD6CDD6D6CDD9
D6CDCAD6CDCAC8D0CDCAC8CAC8C8C4C4C4C1B8B3B8B3B3AD
ADB5B3AAADADA3B5AAB5ADAAA3AAB5B3AAB3AAA3AAA4A4A3
9AA6A1A4A3A4A7A1A7A3A1A1A1989B989595958989838071
685F5959444444392C2929291E1E12120B0B0B0B0B0B1515
1215030B030000000000000012292F2938449DF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F1
F7F7F7F7F7F7E586595953474238424A4A42384A384D4A4A
383842381E1E292F2F1E2F2F42384442595C2F2F424A4A44
595F717D8FA4A7AFB5AAB8BFC1C8CDC8CDD6CDCDCDCDCDCD
D6CDCDCDD0D0CDCDC8D0C8D0C8C1C8C4BFB5AFB3AAA3A3A3
ADAAADA3AAAAA3AAAAAAAAA3AAA3ADAAA3AAAAA1AAAAA3A3
A19AA1A19AA19AA19A9B9B989B95958F8F867D7D71716868
6850504439393939291E1E1E1B1215120B030B0B15151515
15150B03000000000000030B122929392C5CD3FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7A76B5C4D4D4A38424A4A423842424A5347
42394238291B29292F2929383842384A4A4D382F3944474D
44596871808F95A4A7B5B8B8B8B5BFC8C8C8CDCDC8D0CDCD
CDCDCDCDCDCDC8C8C8CDC4C1C8C1C8C1BFB3A3AAAAAAA3AA
AAAFAAAAAAA4A3A4A3AAAAAAAAAAA3AAAAAAA3AAAAA19AA4
A1A19A9AA198A1989898959895988F8F89807D7171717168
684D444439392C2C1E1E291E1B1B120B120B12150B0B0B0B
0B1503030003000000000B1529292F383283F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7
F7F7F7F7F7F7F7BB715C4D4D4A42424A4A4A3842424A534A
4A2F38422F291E291E29352F3838424A4A4259382938424D
4D4A5C6871717D86A4AFA7A7AAAFB5B8BFC8C8C8C8C1CDC8
C8C8CACDCDC8C8C8C8C8C1C1C8C1BFBFB8AFA3A1AFAAA3AA
AAA3AAA3A4A4A4A3A3A3A3A3AFAAAAA3A3AAA4AA9AA3A1A3
A1A1A198989A989898959895958F8989867D807171716868
5C594444392F2C2C1E1E1E151B1B121212120B0B0B030B0B
00150300000000000003121B291E2F2F38C4FFF7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFD38062594D4A42444A4D4A42394442534A
423839422F1E1E1E29152938293842424A4A4D5935292942
474D4750595F717D898F8F98989BA7A7B8B8B5B5C8C8C8C8
BFC1C1CDBFC8C1CDC8C1B5C1C8C1BFBFBFAFAFAA9BA1A1A3
A1A4AAA1A19AA19AA1A3A4A3A3A1A3A6A6AAA3A1A19AA1A1
9A9A9A9898989898958F988F8F8F86868371717171685950
50444439392C291E1E121B1E12150B0B030B0B0B0B0B000B
0B03030000000000000B1529292F2F1B71F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E5A46B5C59473842444A4D4A3847424753
47472F382F291B1B29291E4A42293838424A424D624A382F
39475947505C5F6871717D7D8F9598A7AFAFA7A7AFAFB8B8
B5BFBFB5BFBFBFC4BFB8B8B8C1BFBFB8B5A7A18F8F8F9598
9A989A9892989AA19AA4A3A3A19A9A9AA4A1A1A1A1A19AA1
989598A198989B989898958F898F8983807D716E5F504D50
504439322C291E1E1E1E12150B120B0B15030B0B15150B0B
030303000000000003151E2F1E291E2CB8FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7C171625C4D4238424A4D424242424253
534238383929291B29291B2F4A4A383838384A4A4A624D42
2F394759595C5C5C5C687D747D899589AFA795A7A7AFAFA4
B8AFAFAFB8B8B5B8B5B3AFBFBFB8AFAFA79B9586837D8683
868F958F8F95989AA1988F9AA198958F959A989AA19AA198
9A98989898988F8F8F958F8F8683837D8068685959505059
3E44392F29291E181E150312120B0B0B0B0B0B0B0B15150B
03030000000000000B1B2F1E1E291E50E8FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7D37762594D4238384A4A4A4A4242444A
534242383535291B1B1E291B2F4A5C4A42424A4A424A4D4D
4A423944474D5C5C5F717D71718989959A959595AF9AA49B
A79A9BA7AFA4A3AFB5AFA7B8B5B5AFA395957D7D837D7483
868383868F9295959895929598959292959598A19898989A
9895928F8F8F8F868F8F8F8986837D717168595956504D44
44393929291E1E1E120F121512120B0B0B0B03030B0B0B03
030300000000000B1B29291E291E2F77F1F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E5955F5C594A3842424A534A35424242
53424238293929291E1B1E291E2938535C53384A424A4A4A
4A4A4A4747474D5C62626B71717195869B898F8995958989
A4959B9B9B9B9BA7AFA3A4AFB5B59B95958680717D716874
747D7D867D868F928F868F9292929592959592959598958F
8F958F8F8F868F8F898689867D7D8080685F595650474D44
442C29292929291E1B12121215120B0B0B0B0303030B0B03
00000000000003151E291E29291E47B5F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7D0836B594D423942424A4A42423838
42534A42291E2F2F291B1E2F35382F382F385353474D4238
42534A4D5359595C5C5C595C5F718080717171808089807D
717180807183838F95A79A95959B86717171685F6871716B
717168717177838383898986898F8F8F8F8F8F8F86837D86
868386868686867D8377837D71716868715C594D47393939
2C291E291E29291B1B120B0B120B0B0B0303030000000000
0000000000001529291E291E1E4D9DF1F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F18C7162534A4238444A4A42384238
425C4A4A3529292F291B29293938423842444A5C5353534D
4A425C534253535C5359595C5F71716B687171717180716B
6B71718071717180899BA498898980807168686268505F59
5F595F5F6E7477747783837D838683868F8683838686867D
747D7D7D777D837D7D7D74807171685F5950504D3E392C39
2C1E291E1E181E1E1212120B0B0B0B0B0303030000000000
00000000000329291B291E1E2971D9F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7B8776B4D4A4242424A4D42424738
3853534238291B292F29291E2F423847384A53474A4A4A4A
4A4D4A535C535C5C62595C626B6B62716862716B716B7168
716B7171717168807180899B897171717D71625F5F5F5950
5C595F505974716E6E747D777D7D83868386868386837D7D
74747171747174717171717171685F56504D393939393939
2929291E1E1B1E1E12150B0B0B1512030003000300000000
00000000000B291E1E1E1B1E2FA4F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7D38977534A444242424A4A384747
35425947382F291B2938292F2F38394A53474A535C4A474A
424D5C5C62625C5353595F62715F5962626B5C5F5F5F5F5C
5F5F59686868597171717171807171627171625C5C5C5059
5059565C50685F6868746E6E747474777D837D8074807171
7171717168717171685F6868685F505950444439392C2C2C
29291E1E18121B1E0B120B0B030B0B0B0303000000000000
000000000B1B1E1E291B1B2C35D3F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7E5B5835C594A424242424A423842
42424A4A383829292429382F2F424A4A5353534A5C5C5C5C
47475C595C5C5C6E5C625C626B4D62715C5C5C595947595F
47505C5C5C56595F5F685F6868715F5F5C5C5F5947595059
50474759505056505F5F6E6B656E6E746E6E6E7171686868
7168686868686868686859596856505044444439392C2929
291E1B12121B1B120B0B0B0B03030B000000000000000000
0000000B15291B2F1E1B292C62F1F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E29E624D4D424442424A423842
4742475342382F1E1B352F2F38384A4A5359535C534A5353
5C5342535C6B6B62625C5F6B625C625F595047474D444D6B
445C594D4759505C505C5C5C5F5C62594D59595C4D4D4D4D
504747394D504D50505C56566868685F6868685F5F595C59
685F565C56595F5F5F5959505050594444392C2C29292929
2F1E1B121212151212030B120B0B000B0300030000000000
0000030B1E29291E151E35358CF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7E5B06E4D4D4A4242424A4A4238
4244425342382F2929292F3838383842535C62625C53534A
534A42424A4D4A4A595C5F6B4D4D594D595C424442444D59
4A4744595959475947505950595C595959534D4D47444442
474A4444394444504D4D504D50505056595C50504D50505C
56505950444444504D5C505059474D443939392C292C291E
29181B1B120B12121B0B0B0B030B03030000000000000000
00030B1B291B29151B352C35B8F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F1DC956E534D424242424A4A44
38474742534242382F1E2F474A4742535C5C5C534A4D6259
535342424D5359595C59624D595F5944504D444438424D4A
384442474D4D39324D474447595944394247534242422938
39393844383239393939393944443E443E44443E44444444
4438393939443932393939443939392F322C291E1E1B1E1E
1B1E15120B0B0B121215150B0B0B0B000003000000000000
0B151E1B1E2F15292F3244B8FFF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E895835C4D4A4A42384A4A47
384247425353424238352F4A535C4A535C5C5C5C5C534A53
5C5C534A42474D4D5962624A47594A444A44384239384242
383839424A4D423844594A394A474D42292F424442382F29
2F2F2C2F39292C2C392C39443944392C3939393939383939
3939393239442C39392C2C323939392C29291E1E1E1E1E12
1E1E120B0B0B0B150B12120B0B030300030000030000000B
151E1B1E291E29292C3586F1F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E2B0806E4D4D424442384A4A
422F4247424A4A42423838384A6B5C5C535C626E5C5C5C53
4A4D42384A4A474747805C42504A444A444A383942383842
2F382F44424A384D294A4D42424A42444238353838383829
292F2F2F2F292929292C2C2C2C39392C3939393939323929
393932292C2C392C2C2C2F2C29392C3929292F1E1B1E1E1B
121E1B0B0B0B0B120B0B0B030B0000030000000000000015
241E1B291E152C4A4271D0F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1CD95775C4D4A424A38424A
4438384742474A4A4A424238354D5C5C5C53535C626E5C4D
4A424A4A4D4D4A47596B4D4759424444504A2F4242383842
38422942424A4A4238294A4442424D382F2F392F292F292F
2F1E292929292929291E2929292C422C2929393929292929
2C2C2F2929292C2C2929292929292929291E1E1B1E1B121B
1B121B150303030B15030B0B0B0B0303000000000000031B
1E1B29291B1B2F4D47B5FFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7D3B095774D4A424A423942
4A423542474242475C534A4738384A5C6B5C47535C5C5C5C
5C6B5C5C534D594A4D6244444A4A44424D4A2F4442424242
35383538424A4A2F42292F4A42394238392F2F2F29292F29
29291E291E292929291E1E291E1E2C2F1E29292F2F292929
291E292C29291E2929291E2929291E29291E1E121E1B1B12
120B1B150B03030B0B0B0003030B000000000000000B151E
1B29291515292C4786F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E2B88980594A4D4A424242
424A4242534242424A5C53535C4A35384A5C5C535353534A
4A4A4A4D4A4A4A4D625039424A4442384238383838384242
393838294A394229423929424238382F292929291B292F29
1E1E1E1B1E1E291E1E291B291E1B1E29291E292929292929
1E29291E29292929291E1E291E1E1E1B1E1E121812121212
15120B120303000B0B030B000B030000030000000B0B1B1B
292F1B15291E5995CAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7E2CAA4A46E4A4A42444A42
425347354A47423842475C5C5C5C6E4A3842534A53534A42
382F2F424A4D4D475C4A39444A4447424242424242353847
383542294D38353829422929353829292929292429241E1E
1E1B1B1E1B1E1E291E1E1E1B291E1B1E291B1E1E1E1E1B29
1E1B291E1E291E1E29291E1E1E1E121E1E1E1B121212030B
121512150B03000B0B150303000B0B000000000B0B1B1B29
2F1B151E291B86CAF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2CA89776B4D42424244
42384A5342474A473838386B5C6B5C5C6B62422F42534753
5C5C5C5344424247592C2F4242393839424235384435424A
293542352F4A293929292F29351B29291529291B24241B1B
1B1B1B1B1B1B1B1B1E1B1E1E291E1E1E1E291E291E291B1B
122912291B121B291E29151B1E1B1B1B121E1E1B120B0B03
030B030B0B00000300030B0000000300000B0B1B1B151E1B
0B1E2F1E1E8CE8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1D3C186715C4A38424A
4A4242532F38384247352F47535C5C5C5C5C5C4435353853
5C6E6B5C59424247471E3942383838382F422F424242424A
292F2442244A35292929241B29292429291B241E1B1B1B1B
151B1B12151B1B1B1B1E1B1E1E1B121E1E1E1E12291E241B
12121B1B1B12121B1E1E15151E1B121515121E1B15151B15
0B030B0B0B03030B0000000B000000030B151B1B1B1E2F15
1E291E355FD3E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2DCC195774A423842
4A424247423542424A473838424A53535C5C5C5C5C535C53
423842423842444A4A1E2C39383942382F2F2F2F42423842
24292938293942241B1B292912292929291B1B1E1B1B1E1B
1B15121B1215121B1B151B1B1B1E121B1E1E1E121B1E291B
151212121B1212121B1B1E12151E150B0B151B1B15121B15
120B030B0B000303000000000B0B000B151B15151E2F1B29
2929356BA3F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3DCC48947424242
4A4A4A424A423842424247383535424A53535C5C5C5C534A
4747474A38424A4D44292F2F2F4242423829293538383838
2929242935294229291B242429151B2424291B1B1B151B1B
1B151515121215121B1B15151B1E15121B1B1B1E121B291B
0B1B120B121B12121E1B1E15121B12150B0B1B1B12151215
150B0B000B0B0B03000000000B0B15151B15151E2F1B151E
292C50A3F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1E2D3B0594A3844
424A534A474A3838384244385353474747424A596B5C5347
5C5C534738383942381E2F292F38444238292929382F3538
382929292924381B291B1B1E24151B152929291B1B1B0B15
15151B1515120B0B151B1B1B1E1B1B0B121B1B1B15121E24
150B1B15121B1B12121E1E1212150B0B0B0B0B15150B0B0B
0B0B000000030000000000030B0B151B15121E2F121B2929
384795F7F7E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5D3CD62594238
384A4A424A53473842424744424A5C534744423842535C53
5C5C6E5342422F3839292929292F38423829292942292F42
38292929351E291B1E291B1E2429151B151B29242015150B
151515150B150B0B0B1B1B1B1B1B12120B121B1B1B151229
1B0315150B0B1B150B1B1B1512150B0B15150B0B030B0B0B
000B00030B0B00000000030B0B1215151529382929382F2F
4777E8F7E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3CA896E4A42
3842424242535347444753443535424753535C4738354244
42475C53353838392F1E1E29292F2F383829292938352938
351B29292F1E1B351B29241B1B1E0B15150B1B1E1B1B1515
0B15151515120B0B030B1512121B1B150B0B0B0B12151512
290B0B1B150B121B121515150B0B0B0B0B0B0B0B0B0B000B
0B0B03000B030000000B15121515150B1E291B291E1E1244
71D3F7E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1DC8671594D
423844424242535C4742425344383847535C535353473838
44535C533842382F2F1E29291E292939382929292F292924
291E12291E1E152F241B241B1B15150B1515151B1B1E1B15
0B0B150B150B0B0B0B0B15151B151B1B0B0B0B0B0B121515
1B1B0B151B0B0B1515120B150B0B0B0B030B0B0B03030300
03000003030000000B151515150B0B2929151E1B121B2962
BBF7F7E8F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A786775C
5342384A4A42384253444235424742424242535347473835
3835352929354A392F1E291B121E1E1E352F292924292924
293529121B2F1B1B29151529150B1B1B150B15151B151B15
150B0B0B0B0B0B0B0B150B0B151515151B15030B0B0B0B0B
1515150B0B1B1B0B0B150B0B15000B0300030B0000000000
000000000B15151515150B0B121E291B291B1229385968C4
F7E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2A78371
625342384A4D42424A534738424242424247354242474A47
42353529292F422F2F1B291E1B1B1E122929291E1E29241E
292F3815152929151E24151B1B03151B150B15151B1B1B15
0B0B0B0B0B0B15150B150B0B0B0B1B1B1B150B0B0B0B0B15
151515150B0B2420150B15030B0B03030000030000000000
00000B151515201B150B0B15241B15291B1B2939506871E8
E8E8F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D39577
6E5C4A424A4A4A42354253424A4435424242534A47353542
2F29241B293947382F1E1E1B15121E1B2929291E1B1E1E1B
241B441B121B350B151B1B121B15151B120B0B0B0B1B150B
150B0B0B0B150B0B15150B0B1515151B151515000B000B15
150B1515150B152924150B0B000300000000030000000000
0B151B1B1B1B1B0B0B151B151B15291E1E2F44505C6871E8
E2F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1BB86
7762594A384A4A5342384742474A5C47474A4A4753535344
4444352429424A2F2F291E1B1B121B1B1E1E29291B1B1E1B
1E1B35240B1B290B0B121B0B151B0B1515150B150B0B1515
150B0B0B0B0B0B0B150B150B0B15151B29291515000B0B00
151515151B200B0B15200B030000000000000000030B0B15
151B241B1515151215151B2929291E2C394444567171B0E8
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2A7
805F625938424A4A4238425344384A5C53474D4A42424247
4742292929424239291E1E1E1B151B12121E29291B1B151B
1B1B1B290B151E15120B15150B0B150B1515150B15001515
15150B00000B0B150B15150B0B15152029352929150B0B0B
0B15151515151B150B0B1B1B15150B0B030B150B15151B20
1B2415150B1B15151B2929291E1E29394444506B688CD3F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E2
B0806E5C4A38424A4A473847474438384753474747444244
382F35241B424A42291B291E15121B12151B1E1E1E1B151B
121B121E0B0B151B15120B1B150B0B1515150B0B150B0B15
15150B0B0B0B0B0B0B0B15150B1515152938294229150B0B
0B0B15151515151B201B151B1B1E201B1B151B1B1B15151B
241512150B1B151B29291E151E2F39393950687171ADE2F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E8A7835F5C4A424A424A474247474A4735355C5C5C4A5353
53443829294A42422F1E1E1E1B12151B1B121B1E1B1B1B15
15121515150B122415150B121515150B0B15150B0B15000B
15151500000B0B0B0B1515150B0B151B153547295C381B15
0B1515150B0B1515151B201B201B2020201B1B1B15292929
1B150B0B1B2F29291E151229394439394D5F6B688CD3F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1C4867162534A47424A42383847475353534753535C47
53534735354A424238291E29241B151515150B1B1E1B1512
151212151B0B0B151B150B15150B0B150B150B0B0B0B0B00
0B151B150B00000B0B0B0B151B1515151520355C4D294253
47201529241B15150B15150B151515151B24241B1B151515
151E353538291B1B2F39392F2939445959686BB8F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7C171716253534447474A42424A47425C5C53474235
38353529294A4D38382F291E1E1E1E15121215151E1B1512
121512121520031B1B150B0B15150B151503150B0B0B1500
0B0B15200B0B000000030B151529201B231515475C5C4729
4247472935243529292015150B151515151515150B1B2929
2F2F392F1215292F392F2929393944596871B0FFF7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F17471776253534A4A474238354235474753535353
535344443542533938382929291B1E1B0B0B15121B1E1B15
15150B15121B0B0B1B15150B1515030B150B150B0B0B150B
0B0B151B0B0B0B0B00000B0B0B2438292935233547535C47
2429242929352929353524241B201B15151B1B1E29292C2F
3829291E29352F3929293939394450686895F1F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7CD866B6B62625C4747424238352F3844474A4747
47535C534A424A4238382F292F291E1E0B0B120B151E1B1B
121215121515150B151B150B0B150B000B150B150B0B0B15
0B0B1515150B000B0B0000000B0B1547352942292442535C
53533524242429202924292929241B1E292F2F2F2F2F1E1B
1E2F292F2F2F2F2F2F4A4444595C595F95F1F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFD3746B71625C5353534742383542474747535C
5C5C474753474238394235382F2F1E1E1B0B0B15151B1B1B
0B15120B120B1B0B15151B0B0B15150B0B0B1515150B0B0B
0B0B0B15150B0B0B0B0B0B0B0B0000154747383838292947
5C5C5C535C5347444438444A534444443835291B1B121B29
2F382F2F2F3838384A47444750595C8CF1FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7C4866B7162535353534A4242384247535353
53475C5C5C5C4A42384238382F352F1E241B0B0B15151E1B
120B1B1515121B0B0B15150B0B150B150B0B0B15150B0B0B
0B0B151515150B0B0B0B0B0B150B0B0B1542474747383529
2429423542475C53534A4A4A4242382F241E1B292F384442
424242444242424A4439444450595FD3F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D38E6B625C4A4A474A4A47383542474A47
53475C5C6B5C5C5338383835392F2F292929150B15151B29
1E1512121515120B0B151B1B0B0B0B0B0B000B15150B0B0B
0B0B0B151515150B000B0B0B1B1515150B15204738424247
47383535201B151B1B1B29352F2F38383838383838424A42
424242424244393939394759686877F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7E895595C5C534A42424A4A4A534A53
47535C5C5C746B5C532F382F2F3838382F292F381E151B1B
291E1B1B15151B1E0B0B151515150B0B150B0B0B151B0B0B
0B150B151515151515150B151515151B2924242015244242
4242292F3847424A5347474A4A5347474235354238423538
352F2929293939445C685C5983C4F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7715F5953625C4742474A53535C
5C535C5C5C5C6E5C5C392F2F2F382F2F2F29292942381B1E
3529291E1E15241B1B030B1B15150B0B151B150B0B15150B
0B151B1520151515152015151B2029151515243535242324
42474420151B1B241B1B241B1B291B15152929291E293538
2F29292C39445050685C5F77D3FFF7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7A3716B534A534D4A4742424A47
5C5C5C5C6B6E8089804A2F2F2F2F38382F29292929423829
35353535291E1B1B291B0B1B151B150B0B1524150B151B15
0B15241E2020151B2020351B151B24352015151B24293520
201B3547442924151B1B151E292429292F291E292F383929
2939393E5947505C5F5977D3F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7A7776B534A424A4A4A4A4747
53475C5C6E748083744A4A382C2F2F2F2F2F292929292F38
3838383838351E2924442015291515151515151B1B15241B
1503152938291B15292024471B2424424738292929292920
20201B1B353535352929383535352F2F292F423839292939
3947444A4450595F5C95D3F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7CA805F5C5342424A4A4A42
4253475C6B6B6E74746B5C53382F2F3529292F2929292929
38423835424229351E4753151B24240B152429202924241B
291B150B35382929244D352447292924425C534A47473835
352929292424293844422F352F2F2F3938422F2F3842474D
47445050686B5F5CA4F1FFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7D08C6B6B4A4238384247
4A475C5C6E6E6E7474806E625C42352F2F29292F29292935
2938424242443835351B534715241E1B0B15293529352435
293535293553354729356E444A6B5324201B42475C5C4744
4444423842424238424238393838424242394A4D594D4A44
4259505F715F5C59F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D39B805C4A4A423842
424A535C5C6E6E8089807453535C4A4242382F29292F352F
24292F38424A4A444435244735151E29200B1B2435353835
47354747385C47384A35385C38356E6B4A35292935444244
423838423838383842424242424242424A4D50594D444444
4450685F50444D9DF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5C46B62594A4242
35385C53535C7A806E8089806E5C5C534A4A534A38293838
29292938534453444A5338295C352F1E3829151529384744
3838475C5C6E5C47475344356B47475C475C5C474744474A
443838424A4A4A4D4D4A4A535347474D504442394444444D
50685C44446EBBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D3BB866E6259
534D625C535C5C5C5C6E6E778080745C6253626E6B6E625C
534A4235354A4A445C5C5C5342535C5347445C3815155C53
42474747475C5C6E5C5C5C47444438424A5C5347444A4242
4A42424A4A4242444242443939424244445050505C595F59
593859A3F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5CA9B7774
5C535C534A4A5347536E74806E6E746E6E77746E6E746E6B
746E5C5344444A4A475C5C6B6B535C5C745347624429245C
473538354444475C6B5C53474A534A4742424A4D5353594D
4D4D4D47474442394444444A4A4450595C595968715F5950
4471BBF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E2B5A4
86775C53595353535C6E7474747489896E77776E62747774
6E626E746E6E5C4A4A4A535C746B6B5C6B6E5C5C5C532429
424235352F3847535C7453444A4A4A4D4A534A4A42474242
4242393839393939424A474D504D5C595C5F685F50504438
4DD0FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D0
A7775C62535C5C53536E6E74806E746E6E746E6E62626E6E
74746E746E6E6E6E535C5C5353746E6E5C535C6E6E5C4744
3835383829292F2F38425C6E4A4A4A424A44383838393939
393839393844474D504D59595C5C595F59715C5044384771
CDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E5B5896E595359535C475C6E6E6E746E806E6E6E6E6E6E6E
746E6E7777716E8377746E6E535374747474535C74745C53
444A44443835292429292F42625342424242423839424442
4A444747474D47504759595F5F5F715F685C4438385C8EE8
FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7C19B7459595C5C535C6B5C747480897474748074746B
7474626E7480777780837474776B74746E80806B536E746B
5C534A38444444383838354242535C5C534D424D4A444A47
50594D4D594D595C5F626B71716B715F5035425F86CAFFF7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7FFF1CD9B806B626253535C5C6E6E746E6E6B5C748980
6E7174746E74746E778977838377776E6E778080746E746E
5C6E6E625C5C5953535353535C59534D4D53594D59474D59
4D4D5962626271717D717171716B5044445C95D0F7FFF7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7E58E5C4D3E534A4A535C6E9595807480
89838083898077746E6E747783777777777777776B718389
7777776E6262626E6E5F6B5F5F5F625F68625F6862717171
71717D7D8077806B6B804D4742475C86C1FFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7CD9B895C535353536E6E89898089
898989899595807777776E74807777777780868689807171
77778071716B6B62626B6B62626B626262626B717D778089
89898983808980715F594D5C5F86C4F1FFF7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E2B5A3A17D747D7D959D989D
BCAF9D959D9E9D868380838377775C747777838386838389
8383838377777771836B71716B6B717177777D8383838077
6B62626B6B4D4D4D4D506B74BBF7FFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E2E5E8D3D3DCCD
E5DCBCA7BBB59EA79D9595808080837777746E6E6E6E7789
868C8C8383837771777771717171777D71716B716B6B625F
626B6B594D4D4D4D5F71D3F1FFF7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F1E5E5
E8F7CDBCBCD3B5E2BCA79595959D867777837171746E6B62
74777783778383776E6E716E6E71716B6B6B71716B626262
5C6262595C62779BA3CAFFF7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E8E5E2DCCDCDDCD3E8E5CDA7959B95958C89837783837171
6E77746E778683898377747777716B717771716B6B625C53
594D4D6E86B5D0F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F1E8F7E5E8E8E5F1F7E8D3CDCAC1A78E959BA48E8C8077
77717783777477777789837777716E6E6E716B5C5C535362
62749BD0F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E5E2D0CAC4A3
A7A79D95958C86868C7474808080958E9D9BB8D3D3F1E5F1
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F1F7F7F1F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F1F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7
F1E5E2E2DCC1C1CDD3D3D0E2E8E5F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7FFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F1F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[48]:=",
  ImageSize->{400, 190.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`009@3oool?0?Ogm`030?7al@3gmoL0moOg0200moOg
00@0f][J0=;BdP3GemL0emOG103Jf]X20>3Ph0030=[JfP3Ph>00h>3P00P0h>3P0P3Jf]X02P3?cll0
emOG0<o?c`3?cll0bLW90<30`039bLT0`<300;^k^`2g]kL20;^k^``0/[:b00@0YjNW0:VYZ@2YZJT0
YjNW0P2YZJT0102WYjL0WIfM0:BTY02YZJTU0?Ogmb@0oooo3`3gmoL00`3alO40moOg0?Ogm`0P0?Og
m`040=WIf@3@d=00e]KF0=KFeP@0fMWI0P3Ogml00`3IfMT0gmoO0=oOg`080=oOg`80fMWI00X0cLg=
0=KFeP3=cLd0cLg=0<S8b02o_kl0b<S80;no_`2h^;P0]KFe0P2h^;P<0:n_[`040:BTY02WYjL0YjNW
0:BTY080YjNW00@0Y:BT09^KV`2QXJ40YjNW9@3gmoLW0?ooo`009@3oool40?Ogm`030?7al@3gmoL0
moOg00P0moOg00<0lO7a0?Ogm`3alO404@3gmoL00`3alO40moOg0?Ogm`0<0?Ogm`030>SXj03?cll0
emOG00<0emOG0`3Jf]X00`3Ph>00f][J0=[JfP020>3Ph080f][J103Ph>030=[JfP80clo?0P39bLT0
1030`<00bLW90<30`030`<020;^k^`X0/[:b00@0[Jf]0;:b/P2][Jd0ZJVY0P2][Jd20:NWY`060:VY
Z@2WYjL0ZJVY09fMW@2YZJT0f][J9@3gmoLT0?ooo`@0moOg00<0lO7a0?Ogm`3gmoL0203gmoL00`3a
lO40moOg0?7al@0A0?Ogm`030?7al@3gmoL0moOg00`0moOg00<0j>SX0<g=c@3Fe]H00`3Fe]H30=WI
f@030=oOg`3IfMT0fMWI0080gmoO0P3IfMT40=oOg`<0fMWI0P3=cLd20<S8b0040;no_`38b<P0_kno
0;no_`80^;Rh2P2_[jl0102ZZZX0[jn_0:ZZZP2WYjL20:ZZZP80Y:BT00H0YjNW0:BTY02WYjL0Vi^K
0:NWY`3IfMTU0?OgmbL0oooo000U0?ooo`80moOg00<0lO7a0?Ogm`3gmoL01@3gmoL00`3alO40moOg
0?7al@0U0?Ogm`030>SXj03?cll0emOG0080emOG00@0f][J0=OGe`3Ph>00h>3P0P3Jf]X20>3Ph005
0=[JfP3Ph>00h>3P0=[JfP3GemL00P3Jf]X30<o?c`<0bLW91030`<00102g]kL0/[:b0;:b/P2b/[82
0:VYZ@030:f][@2b/[80/[:b00D0/[:b00<0[Jf]0:VYZ@2b/[801P2YZJT00`2WYjL0WIfM0:VYZ@0V
0?Ogmb@0oooo0P3gmoL00`3alO40moOg0?Ogm`050?Ogm`030?7al@3gmoL0lO7a02D0moOg00<0j>SX
0<g=c@3Fe]H00P3Fe]H0103IfMT0e]KF0=oOg`3Ogml20=WIf@80gmoO00D0fMWI0=oOg`3Ogml0fMWI
0=KFeP020=WIf@<0cLg=0`38b<P40;no_`040;Fe]@2_[jl0[jn_0:n_[`80YjNW00<0ZZZZ0:n_[`2_
[jl01@2_[jl00`2ZZZX0YjNW0:n_[`060:NWY`030:BTY02KVi/0YjNW02H0moOg9`3oool002D0oooo
1`3gmoL00`3alO40moOg0?Ogm`0<0?Ogm`030?7al@3gmoL0lO7a01T0moOg00<0h>3P0<o?c`3GemL0
0P3GemL90=[JfP040>3Ph03Jf]X0f][J0=[JfP<0clo?1039bLT00`36a/H0`<300<30`0020;Ng]`D0
/[:b00<0ZJVY0:f][@2YZJT00P2b/[80102YZJT0/[:b0;:b/P2b/[840:f][@040:VYZ@2][Jd0ZJVY
0:NWY`80ZJVY00<0YjNW0;:b/P3gmoL0703gmoL00`3alO40moOg0?Ogm`020?Ogm`040?7al@3gmoL0
moOg0?Ogmb@0oooo1`3gmoL00`3alO40moOg0?Ogm`0<0?Ogm`030?7al@3gmoL0lO7a01T0moOg00<0
gmoO0<g=c@3Fe]H00P3Fe]H90=WIf@040=oOg`3IfMT0fMWI0=WIf@<0cLg=1038b<P00`34a<@0_kno
0;no_`020;Fe]@D0[jn_00<0YjNW0:ZZZP2WYjL00P2_[jl0102WYjL0[jn_0:n_[`2_[jl40:ZZZP04
0:NWY`2ZZZX0YjNW0:BTY080YjNW00<0Y:BT0:n_[`3gmoL0703gmoL00`3alO40moOg0?Ogm`020?Og
m`040?7al@3gmoL0moOg0?OgmbL0oooo000U0?ooo`030?7al@3gmoL0moOg00L0moOg00<0lO7a0?Og
m`3gmoL00`3gmoL00`3alO40moOg0?Ogm`0O0?Ogm`030>SXj03?cll0emOG00@0f][J00D0h>3P0=[J
fP3Ph>00f][J0>3Ph0040=[JfP80clo?00D0b<S80<o?c`3?cll0bLW90<K6aP030<30`0040;Rh^02b
/[80]kNg0;:b/P80]kNg0`2YZJT20:f][@090:VYZ@2][Jd0ZJVY0:VYZ@2][Jd0/[:b0:f][@2b/[80
ZJVY00@0[Jf]0P2YZJT0102WYjL0ZJVY0:VYZ@34a<@A0?Ogm`030?7al@3gmoL0moOg00@0moOg00<0
lO7a0?Ogm`3gmoL02`3gmoLT0?ooo`030?7al@3gmoL0moOg00L0moOg00<0lO7a0?Ogm`3gmoL00`3g
moL00`3alO40moOg0?Ogm`0O0?Ogm`030>SXj03=cLd0e]KF00@0fMWI00D0gmoO0=WIf@3Ogml0fMWI
0=oOg`040=WIf@80cLg=00D0b<S80<g=c@3=cLd0b<S80<C4a0030;no_`040;Fe]@2_[jl0]KFe0:n_
[`80]KFe0`2WYjL20:ZZZP090:NWY`2ZZZX0YjNW0:NWY`2ZZZX0[jn_0:ZZZP2_[jl0YjNW00@0ZZZZ
0P2WYjL0102TY:@0YjNW0:NWY`34a<@A0?Ogm`030?7al@3gmoL0moOg00@0moOg00<0lO7a0?Ogm`3g
moL02`3gmoLW0?ooo`009@3oool60?Ogm`030?7al@3gmoL0moOg02T0moOg00<0f][J0=;BdP3GemL0
0P3GemL80=[JfP070=OGe`3Jf]X0clo?0<o?c`3<c<`0clo?0<c<c0030<K6aP<0^;Rh00@0/[:b0:ZZ
ZP2b/[80/[:b102g]kL00`2YZJT0]kNg0:f][@050:VYZ@060:f][@2YZJT0/[:b0;:b/P2YZJT0[Jf]
1P2YZJT00`36a/H0moOg0?Ogm`0?0?Ogm`030?7al@3gmoL0moOg00<0moOg00<0lO7a0?Ogm`3gmoL0
103gmoL20?7al@040?Ogm`3alO40moOg0?7al@<0moOg903oool60?Ogm`030?7al@3gmoL0moOg02T0
moOg00<0fMWI0=3@d03Fe]H00P3Fe]H80=WIf@070=KFeP3IfMT0cLg=0<g=c@3:b/X0cLg=0<[:bP03
0<C4a0<0]KFe00@0[jn_0:JVYP2_[jl0[jn_102e]KD00`2WYjL0]KFe0:ZZZP050:NWY`060:ZZZP2W
YjL0[jn_0:n_[`2WYjL0ZZZZ1P2WYjL00`34a<@0moOg0?Ogm`0?0?Ogm`030?7al@3gmoL0moOg00<0
moOg00<0lO7a0?Ogm`3gmoL0103gmoL20?7al@040?Ogm`3alO40moOg0?7al@<0moOg9`3oool002D0
oooo00<0moOg0?7al@3gmoL01P3gmoL0103alO40moOg0?7al@3alO4U0?Ogm`060=[JfP3?cll0emOG
0=OGe`3Jf]X0emOG1P3Jf]X0203?cll0f][J0<o?c`3GemL0b<S80<c<c03?cll0emOG0P3?cll20<c<
c0040<K6aP34a<@0`L710;Rh^080/[:b00L0ZZZZ0;:b/P2h^;P0]kNg0:ZZZP2][Jd0YZJV0080]kNg
1P2YZJT20:f][@030:VYZ@2][Jd0ZJVY00@0ZJVY00<0f][J0?Ogm`3gmoL09@3gmoLT0?ooo`030?Og
m`3alO40moOg00H0moOg00@0lO7a0?Ogm`3alO40lO7a9@3gmoL01P3IfMT0cLg=0=KFeP3Fe]H0fMWI
0=KFePH0fMWI00P0cLg=0=WIf@3=cLd0e]KF0<S8b03:b/X0cLg=0=KFeP80cLg=0P3:b/X01034a<@0
`L710;no_`2e]KD20:n_[`070:JVYP2_[jl0]KFe0;Fe]@2VYZH0ZZZZ0:>SX`020;Fe]@H0YjNW0P2Z
ZZX00`2WYjL0ZZZZ0:NWY`040:NWY`030=WIf@3gmoL0moOg02D0moOg9`3oool002D0oooo103gmoL0
0`3alO40moOg0?Ogm`0D0?Ogm`030?7al@3gmoL0moOg01@0moOg00<0f][J0<o?c`3GemL00P3GemL6
0=[JfP0:0=OGe`3Jf]X0clo?0<o?c`3GemL0clo?0=[JfP3GemL0clo?0=[JfP80emOG00@0a/K60<c<
c036a/H0^k^k0P2h^;P20;:b/P<0^;Rh00L0]kNg0:ZZZP2YZJT0ZJVY0;:b/P2g]kL0YjNW0080ZJVY
00L0YjNW0:VYZ@2XZ:P0ZJVY0:f][@2YZJT0[Jf]00@0ZJVY00<0j>SX0?Ogm`3gmoL02`3gmoL00`3a
lO40moOg0?Ogm`030?Ogm`030?7al@3gmoL0moOg0140moOg903oool40?Ogm`030?7al@3gmoL0moOg
01@0moOg00<0lO7a0?Ogm`3gmoL0503gmoL00`3IfMT0cLg=0=KFeP020=KFePH0fMWI00X0e]KF0=WI
f@3=cLd0cLg=0=KFeP3=cLd0fMWI0=KFeP3=cLd0fMWI0P3Fe]H01034a<@0b/[:0<C4a02h^;P20;Fe
]@80[jn_102e]KD01P2VYZH0YjNW0:NWY`2_[jl0]KFe0:BTY080YjNW00L0Y:BT0:NWY`2SXj<0YjNW
0:ZZZP2WYjL0ZZZZ00@0YjNW00<0j>SX0?Ogm`3gmoL02`3gmoL00`3alO40moOg0?Ogm`030?Ogm`03
0?7al@3gmoL0moOg0140moOg9`3oool002D0oooo<P3gmoL00`3GemL0clo?0=OGe`020=OGe`<0f][J
00@0clo?0=OGe`3GemL0f][J0P3?cll00`3Jf]X0clo?0=[JfP050=[JfP030<c<c03?cll0c<c<0080
a/K600h0a<C40<71`@2h^;P0^;Rh0;^k^`31`L40a/K60<71`@2h^;P0ZZZZ0;:b/P2ZZZX0YZJV0;Zj
^P80ZJVY00D0/[:b0:VYZ@2YZJT0ZJVY0:f][@060:VYZBP0moOg903ooolb0?Ogm`030=KFeP3=cLd0
e]KF0080e]KF0`3IfMT0103=cLd0e]KF0=KFeP3IfMT20<g=c@030=WIf@3=cLd0fMWI00D0fMWI00<0
b/[:0<g=c@3:b/X00P34a<@03P31`L40_kno0;Fe]@2e]KD0^;Rh0;no_`34a<@0_kno0;Fe]@2VYZH0
[jn_0:JVYP2SXj<0^;Rh0P2WYjL01@2_[jl0YjNW0:NWY`2WYjL0ZZZZ00H0YjNW:03gmoLW0?ooo`00
9@3oool>0?Ogm`030?7al@3gmoL0moOg0240moOg00D0clo?0=;BdP3?cll0emOG0=[JfP030=OGe`03
0=[JfP3?cll0clo?0080clo?103Jf]X20>3Ph0@0f][J01L0emOG0<o?c`39bLT0a/K60<W9b@36a/H0
a<C40<K6aP31`L40`<300;Rh^031`L40a<C40;Rh^02f][H0ZZZZ0;:b/P2VYZH0/[:b0;Zj^P2b/[80
ZJVY0;:b/P070:VYZ@030;Ng]`3gmoL0moOg02H0moOg903oool>0?Ogm`030?7al@3gmoL0moOg0240
moOg00D0cLg=0=3@d03=cLd0e]KF0=WIf@030=KFeP030=WIf@3=cLd0cLg=0080cLg=103IfMT20=oO
g`@0fMWI00P0e]KF0<g=c@38b<P0a<C40<S8b034a<@0`L710<C4a080_kno00d0]KFe0;no_`31`L40
]KFe0;>c/`2VYZH0[jn_0:>SX`2_[jl0^;Rh0:n_[`2WYjL0[jn_00L0YjNW00<0]KFe0?Ogm`3gmoL0
9P3gmoLW0?ooo`009@3oool00`3alO40moOg0?Ogm`040?Ogm`030?7al@3gmoL0moOg02P0moOg00X0
clo?0=OGe`3GemL0emOG0=[JfP3GemL0clo?0=[JfP3?cll0f][J0P3GemL20=[JfPH0h>3P103Jf]X0
103Ph>00clo?0<g=c@3=cLd20<K6aP030<C4a036a/H0a<C400<0`L7100@0^;Rh0;Jf]P2h^;P0][Jf
0P2ZZZX00`2b/[80]kNg0;Ng]`030:VYZ@060:f][@2YZJT0[Jf]0:VYZ@2b/[80c<c<:03gmoLT0?oo
o`030?7al@3gmoL0moOg00@0moOg00<0lO7a0?Ogm`3gmoL0:03gmoL02P3=cLd0e]KF0=KFeP3Fe]H0
fMWI0=KFeP3=cLd0fMWI0<g=c@3IfMT20=KFeP80fMWI1P3Ogml40=WIf@040=oOg`3=cLd0b/[:0<[:
bP80a<C400<0`L710<C4a031`L400`2o_kl0102e]KD0/k>c0;Fe]@2c/k<20:JVYP030:n_[`2e]KD0
]KFe00<0YjNW00H0ZZZZ0:NWY`2ZZZX0YjNW0:n_[`3:b/XX0?OgmbL0oooo000U0?ooo`030?Ogm`3a
lO40moOg02l0moOg00@0d];B0=OGe`3GemL0emOG0P3?cll01@3Jf]X0clo?0=OGe`3Jf]X0emOG00<0
f][J0`3Ph>020=[JfP030>3Ph03Jf]X0h>3P0080h>3P0P3Jf]X20=OGe`040<c<c03?cll0cLg=0<W9
b@80a<C400H0`L710;^k^`2h^;P0][Jf0;Rh^02ZZZX30:f][@070;:b/P2j^[X0/[:b0:f][@2YZJT0
/[:b0:f][@020:VYZ@030;:b/P3Jf]X0moOg00X0moOg00<0lO7a0?Ogm`3gmoL06P3gmoLT0?ooo`03
0?Ogm`3alO40moOg02l0moOg00@0d=3@0=KFeP3Fe]H0e]KF0P3=cLd01@3IfMT0cLg=0=KFeP3IfMT0
e]KF00<0fMWI0`3Ogml20=WIf@030=oOg`3IfMT0gmoO0080gmoO0P3IfMT20=KFeP040<[:bP3=cLd0
b/[:0<S8b080`L7100H0_kno0;Rh^02e]KD0/k>c0;Fe]@2VYZH30:ZZZP070:n_[`2h^;P0[jn_0:ZZ
ZP2WYjL0[jn_0:ZZZP020:NWY`030:n_[`3IfMT0moOg00X0moOg00<0lO7a0?Ogm`3gmoL06P3gmoLW
0?ooo`009@3ooolb0?Ogm`070<o?c`3GemL0emOG0=OGe`3?cll0f][J0<o?c`020=OGe`D0f][J0`3P
h>000`3Jf]X0h>3P0>3Ph0050>3Ph00:0=[JfP3GemL0clo?0=OGe`3<c<`0clo?0<W9b@34a<@0bLW9
0<C4a080^k^k00<0^;Rh0;Jf]P2f][H00`2ZZZX01P2][Jd0]kNg0:f][@2b/[80ZJVY0;:b/P80ZJVY
0P2b/[800`3Cdm<0moOg0?Ogm`0V0?Ogmb@0oooo<P3gmoL01`3=cLd0e]KF0=KFeP3Fe]H0cLg=0=WI
f@3=cLd00P3Fe]H50=WIf@<0gmoO00<0fMWI0=oOg`3Ogml01@3Ogml02P3IfMT0e]KF0<g=c@3Fe]H0
b/[:0<g=c@38b<P0`L710<S8b031`L420;Rh^0030;Fe]@2c/k<0/k>c00<0YZJV00H0ZZZZ0;Fe]@2]
[Jd0[jn_0:NWY`2_[jl20:NWY`80[jn_00<0dm?C0?Ogm`3gmoL09P3gmoLW0?ooo`009@3oool80?Og
m`030?7al@3gmoL0moOg00<0moOg00<0lO7a0?Ogm`3gmoL0803gmoL0102j^[X0d];B0=OGe`3GemL4
0=[JfP030=OGe`3Jf]X0f][J0080f][J1@3Ph>000`3Jf]X0emOG0>3Ph0050>3Ph0<0f][J0P3GemL0
203=cLd0bLW90<K6aP34a<@0`<300<C4a02f][H0^;Rh0P2f][H20:f][@060;:b/P2][Jd0/[:b0;Ng
]`2YZJT0^[Zj0P2][Jd0102b/[80ZJVY0;:b/P3alO490?Ogm`030?7al@3gmoL0lO7a01`0moOg903o
ool80?Ogm`030?7al@3gmoL0moOg00<0moOg00<0lO7a0?Ogm`3gmoL0803gmoL0102h^;P0d=3@0=KF
eP3Fe]H40=WIf@030=KFeP3IfMT0fMWI0080fMWI1@3Ogml00`3IfMT0e]KF0=oOg`050=oOg`<0fMWI
0P3Fe]H0203:b/X0b<S80<C4a031`L40_kno0<71`@2c/k<0]KFe0P2c/k<20:ZZZP060:n_[`2ZZZX0
[jn_0;Fe]@2WYjL0^;Rh0P2ZZZX0102_[jl0YjNW0:n_[`3alO490?Ogm`030?7al@3gmoL0lO7a01`0
moOg9`3oool002D0oooo0P3gmoL00`3alO40moOg0?Ogm`0[0?Ogm`060:f][@30`<00emOG0=OGe`3J
f]X0clo?303Jf]X0103Ph>00f][J0=[JfP3Jf]X30>3Ph0@0f][J00H0emOG0<o?c`3Bd]80bLW90<C4
a039bLT20<C4a0030<71`@2h^;P0^;Rh00<0][Jf0`2][Jd01P2TY:@0/[:b0;:b/P2YZJT0]kNg0:VY
Z@<0/[:b3`3gmoL00`3alO40moOg0?Ogm`0G0?Ogmb@0oooo0P3gmoL00`3alO40moOg0?Ogm`0[0?Og
m`060:f][@2o_kl0e]KF0=KFeP3IfMT0cLg=303IfMT0103Ogml0fMWI0=WIf@3IfMT30=oOg`@0fMWI
00H0e]KF0<g=c@3@d=00b<S80<71`@38b<P20<71`@030;no_`2e]KD0]KFe00<0/k>c0`2ZZZX01P2Q
XJ40[jn_0:n_[`2WYjL0]KFe0:NWY`<0[jn_3`3gmoL00`3alO40moOg0?Ogm`0G0?OgmbL0oooo000U
0?ooo`030?7al@3gmoL0moOg00`0moOg00<0lO7a0?Ogm`3gmoL07@3gmoL00`3=cLd0>c/k0<W9b@02
0=[JfP80emOG1P3Jf]X0103Ph>00f][J0>3Ph03Ph>060=[JfP050>3Ph03Jf]X0f][J0=[JfP3GemL0
0`3Jf]X0103GemL0c<c<0<W9b@36a/H20<C4a080`<3000D0^k^k0;Jf]P2f][H0[Jf]0;Jf]P020;:b
/P030:f][@2TY:@0[Jf]0080/[:b00D0ZJVY0;Zj^P2b/[80/[:b0:f][@0@0?Ogm`030?7al@3gmoL0
moOg01H0moOg903oool00`3alO40moOg0?Ogm`0<0?Ogm`030?7al@3gmoL0moOg01d0moOg00<0cLg=
03Ti>@38b<P00P3IfMT20=KFePH0fMWI00@0gmoO0=WIf@3Ogml0gmoO1P3IfMT01@3Ogml0fMWI0=WI
f@3IfMT0e]KF00<0fMWI00@0e]KF0<[:bP38b<P0a<C40P31`L420;no_`050;Rh^02c/k<0/k>c0:ZZ
ZP2c/k<00P2_[jl00`2ZZZX0XJ6Q0:ZZZP020:n_[`050:NWY`2h^;P0[jn_0:n_[`2][Jd0403gmoL0
0`3alO40moOg0?Ogm`0F0?OgmbL0oooo000U0?ooobh0moOg00L0g=cL06a/K013@d<0clo?0=[JfP3?
cll0emOG00P0f][J00<0h>3P0=[JfP3Jf]X00`3Jf]X20=OGe`L0f][J00@0emOG0<o?c`3GemL0clo?
0`39bLT20<C4a0030<71`@2k^k/0^k^k0080/[:b00L0^k^k0;6a/@2b/[80/[:b0:f][@2YZJT0/[:b
0080ZJVY00@0][Jf0;:b/P2b/[80/[:b:@3gmoLT0?ooobh0moOg00L0g=cL06][J`12@T80cLg=0=WI
f@3=cLd0e]KF00P0fMWI00<0gmoO0=WIf@3IfMT00`3IfMT20=KFePL0fMWI00@0e]KF0<g=c@3Fe]H0
cLg=0`38b<P20<71`@030;no_`2h^;P0^;Rh0080[jn_00L0^;Rh0:f][@2_[jl0[jn_0:ZZZP2WYjL0
[jn_0080YjNW00@0]KFe0:n_[`2_[jl0[jn_:@3gmoLW0?ooo`009@3oool20?7al@H0moOg00<0lO7a
0?Ogm`3gmoL00`3gmoL00`3alO40moOg0?7al@0L0?Ogm`0409jNWP0k>c/0;2`/069RHP<0f][J00<0
emOG0=[JfP3Jf]X00P3Jf]X30>3Ph080f][J00<0h>3P0=[JfP3Jf]X0103Jf]X20>3Ph080f][J0P3?
cll04@39bLT0clo?0<o?c`36a/H0bLW90<C4a02k^k/0a<C40<30`02k^k/0a<C40;^k^`2h^;P0/[:b
0;Jf]P2g]kL0/[:b0080[Jf]00@0Z:RX0:VYZ@2][Jd0YjNW0P2YZJT00`2g]kL0a/K60;:b/P0Y0?Og
mb@0oooo0P3alO460?Ogm`030?7al@3gmoL0moOg00<0moOg00<0lO7a0?Ogm`3alO40703gmoL0102M
WId0>CTi02TY:@1OGel30=WIf@030=KFeP3IfMT0fMWI0080fMWI0`3Ogml20=WIf@030=oOg`3IfMT0
fMWI00@0fMWI0P3Ogml20=WIf@80cLg=0140b<S80<g=c@3=cLd0a<C40<S8b031`L40^;Rh0<71`@2o
_kl0^;Rh0<71`@2h^;P0]KFe0:n_[`2c/k<0]KFe0:n_[`020:ZZZP040:>SX`2WYjL0ZZZZ0:BTY080
YjNW00<0]KFe0<C4a02_[jl0:@3gmoLW0?ooo`009@3oool30?Ogm`80lO7a4`3gmoL00`3alO40moOg
0?Ogm`0A0?Ogm`040?ooo`1;Bd/0;2`/030`<080f][J00D0emOG0=[JfP3Jf]X0f][J0>3Ph0030=[J
fP80h>3P00<0f][J0>3Ph03Jf]X00P3Jf]X30>3Ph0040=[JfP3Ph>00f][J0=[JfP80emOG00D0c<c<
0<W9b@34a<@0a<C40;^k^`060<C4a0090<30`02k^k/0^;Rh0;Jf]P2b/[80^;Rh0;Jf]P2b/[80[Jf]
0080YjNW0P2][Jd40:VYZ@030<C4a03gmoL0moOg02L0moOg903oool30?Ogm`80lO7a4`3gmoL00`3a
lO40moOg0?Ogm`0A0?Ogm`040?ooo`1:BTX0:BTY02`/;080fMWI00D0e]KF0=WIf@3IfMT0fMWI0=oO
g`030=WIf@80gmoO00<0fMWI0=oOg`3IfMT00P3IfMT30=oOg`040=WIf@3Ogml0fMWI0=WIf@80e]KF
00D0b/[:0<S8b031`L40`L710;Rh^0060<71`@090;no_`2h^;P0]KFe0;>c/`2_[jl0]KFe0;>c/`2_
[jl0ZZZZ0080Y:BT0P2ZZZX40:NWY`030<C4a03gmoL0moOg02L0moOg9`3oool002D0oooo00<0moOg
0?7al@3gmoL01P3gmoL00`3alO40moOg0?Ogm`0P0?Ogm`0509FEU@18B4P0WIfM0=[JfP3?cll01@3J
f]X20>3Ph0D0f][J00<0emOG0=[JfP3Jf]X00P3Jf]X30>3Ph0<0f][J0P3GemL00`3?cll0a<C40<W9
b@030<C4a0040;^k^`34a<@0`<300<C4a080^k^k0P2f][H01@2][Jd0/[:b0;Vi^@2b/[80/K6a0080
[Jf]102YZJT0102][Jd0ZJVY0;:b/P2g]kLH0?Ogm`030?7al@3gmoL0moOg00h0moOg903oool00`3g
moL0lO7a0?Ogm`060?Ogm`030?7al@3gmoL0moOg0200moOg00D0UIFE04A4A02KVi/0fMWI0<g=c@05
0=WIf@80gmoO1@3IfMT00`3Fe]H0fMWI0=WIf@020=WIf@<0gmoO0`3IfMT20=KFeP030<g=c@31`L40
b<S800<0`L7100@0^;Rh0<71`@2o_kl0`L710P2h^;P20;>c/`050:ZZZP2_[jl0]KFe0:n_[`2][Jd0
0P2ZZZX40:NWY`040:ZZZP2WYjL0[jn_0;Fe]AP0moOg00<0lO7a0?Ogm`3gmoL03P3gmoLW0?ooo`00
9@3oool50?Ogm`030?7al@3gmoL0moOg02<0moOg00D0h^;R03Ti>@23Ph<0f][J0<o?c`020=OGe`80
f][J0P3Ph>070=[JfP030=OGe`3Jf]X0f][J0080f][J103Ph>001@3Jf]X0c<c<0<o?c`39bLT0a/K6
0080a<C40`2k^k/01034a<@0^k^k0;^k^`2k^k/20;Vi^@030;Jf]P2b/[80[Jf]0080[Jf]00L0^KVi
0:f][@2][Jd0[Jf]0:NWY`2YZJT0YjNW00<0ZJVY0P2b/[800`3Jf]X0moOg0?Ogm`0V0?Ogmb@0oooo
1@3gmoL00`3alO40moOg0?Ogm`0S0?Ogm`050>;RhP0h>3P0P8200=WIf@3=cLd00P3Fe]H20=WIf@80
gmoO1`3IfMT00`3Fe]H0fMWI0=WIf@020=WIf@@0gmoO00D0fMWI0<[:bP3=cLd0b<S80<C4a0020<71
`@<0^;Rh00@0`L710;Rh^02h^;P0^;Rh0P2e]KD00`2c/k<0[jn_0:ZZZP020:ZZZP070;Fe]@2ZZZX0
ZZZZ0:ZZZP2TY:@0YjNW0:BTY0030:NWY`80[jn_00<0fMWI0?Ogm`3gmoL09P3gmoLW0?ooo`009@3o
oolZ0?Ogm`060?ooo`13@d<0<C4a0>3Ph03Jf]X0emOG0P3Jf]X20>3Ph0<0f][J00@0h>3P0=[JfP3G
emL0f][J0P3GemL:0=[JfP80clo?0P36a/H01031`L40^;Rh0;Rh^02h^;P40;Jf]P<0/[:b102][Jd0
0`2YZJT0[Jf]0;:b/P030:f][@090:VYZ@2][Jd0ZJVY0:VYZ@2b/[80ZJVY0;:b/P2g]kL0j>SX02L0
moOg903ooolZ0?Ogm`060?ooo`12@T80;bl_0=oOg`3IfMT0e]KF0P3IfMT20=oOg`<0fMWI00@0gmoO
0=WIf@3Fe]H0fMWI0P3Fe]H:0=WIf@80cLg=0P34a<@0102o_kl0]KFe0;Fe]@2e]KD40;>c/`<0[jn_
102ZZZX00`2WYjL0ZZZZ0:n_[`030:ZZZP090:NWY`2ZZZX0YjNW0:NWY`2_[jl0YjNW0:n_[`2e]KD0
j>SX02L0moOg9`3oool002D0oooo1@3gmoL00`3alO40moOg0?Ogm`0Q0?Ogm`040?ooo`2e]KD0@d=3
08f=S@P0f][J00@0h>3P0=[JfP3Jf]X0f][J0`3GemL00`3Jf]X0emOG0=OGe`030=[JfP050>3Ph03J
f]X0f][J0=[JfP3Ph>000P3<c<`20;2`/0060:ZZZP2RXZ80XZ:R0:ZZZP2f][H0/;2`0P2f][H01`2a
/K40[Jf]0:f][@2][Jd0ZJVY0:f][@2YZJT0102][Jd00`2YZJT0[Jf]0:VYZ@020:VYZ@070:NWY`2]
[Jd0ZJVY0:f][@2g]kL0a/K60>SXj00V0?Ogmb@0oooo1@3gmoL00`3alO40moOg0?Ogm`0Q0?Ogm`04
0?ooo`2e]KD0@T9208b<S0P0fMWI00@0gmoO0=WIf@3IfMT0fMWI0`3Fe]H00`3IfMT0e]KF0=KFeP03
0=WIf@050=oOg`3IfMT0fMWI0=WIf@3Ogml00P3:b/X20:ZZZP060:BTY02KVi/0Vi^K0:JVYP2c/k<0
ZZZZ0P2c/k<01`2][Jd0ZZZZ0:ZZZP2ZZZX0YjNW0:ZZZP2WYjL0102ZZZX00`2WYjL0ZZZZ0:NWY`02
0:NWY`070:BTY02ZZZX0YjNW0:ZZZP2e]KD0a<C40>SXj00V0?OgmbL0oooo000U0?ooo`80moOg00D0
lO7a0?Ogm`3gmoL0moOg0?7al@0R0?Ogm`050>GUi@1JFUX0Cdm?0=[JfP3GemL0103Jf]X00`3GemL0
f][J0>3Ph0030=[JfP030=OGe`3Bd]80emOG00<0emOG0`3Jf]X01@3Ph>00f][J0=[JfP3Jf]X0h>3P
0080c<c<00<0cLg=0;2`/02`/;001`2RXZ8209fMW@80ZZZZ00H0[Jf]0:VYZ@2][Jd0Z:RX0:BTY02W
YjL20:f][@80ZJVY0P2][Jd0202YZJT0Z:RX0:f][@2YZJT0[Jf]0;:b/P2g]kL0^[Zj9P3gmoLT0?oo
o`80moOg00D0lO7a0?Ogm`3gmoL0moOg0?7al@0R0?Ogm`050>GUi@1IFET0CDe=0=WIf@3Fe]H0103I
fMT00`3Fe]H0fMWI0=oOg`030=WIf@030=KFeP3@d=00e]KF00<0e]KF0`3IfMT01@3Ogml0fMWI0=WI
f@3IfMT0gmoO00<0b/[:0P2ZZZX709^KV`80V9RH0P2VYZH01P2ZZZX0YjNW0:ZZZP2SXj<0XJ6Q0:BT
Y080ZZZZ0P2WYjL20:ZZZP080:NWY`2SXj<0ZZZZ0:NWY`2ZZZX0[jn_0;Fe]@2h^;PV0?OgmbL0oooo
000U0?ooobT0moOg00H0MgMg034a<@3?cll0clo?0=[JfP3GemL20=[JfP80emOG00<0h>3P0=[JfP3J
f]X00`3GemL00`3Jf]X0d];B0=OGe`020=OGe`80f][J00@0h>3P0=[JfP3Jf]X0f][J103<c<`0103=
cLd0`L710;2`/02PX:020::RXP030:ZZZP2RXZ80XZ:R00<0XZ:R00<0UiNG09fMW@2ZZZX00`2][Jd0
1@2KVi/0YjNW0:RXZ02][Jd0ZJVY0080[Jf]00H0/[:b0:f][@2WYjL0[Jf]0:VYZ@2][Jd20;:b/P03
0;Ng]`38b<P0moOg00/0moOg00<0lO7a0?Ogm`3gmoL05P3gmoLT0?ooobT0moOg00H0MgMg02l_;`3=
cLd0cLg=0=WIf@3Fe]H20=WIf@80e]KF00<0gmoO0=WIf@3IfMT00`3Fe]H00`3IfMT0d=3@0=KFeP02
0=KFeP80fMWI00@0gmoO0=WIf@3IfMT0fMWI1@3:b/X00`2o_kl0ZZZZ09RHV00209^KV`030:JVYP2K
Vi/0Vi^K00<0Vi^K00<0SXj>09RHV02VYZH00`2ZZZX01@2HV9P0Y:BT0:>SX`2ZZZX0YjNW0080ZZZZ
00H0[jn_0:ZZZP2TY:@0ZZZZ0:NWY`2ZZZX20:n_[`030;Fe]@38b<P0moOg00/0moOg00<0lO7a0?Og
m`3gmoL05P3gmoLW0?ooo`009@3oool60?Ogm`030?7al@3gmoL0moOg01l0moOg00H0b<S803/k>`23
Ph<0h>3P0<o?c`3GemL30=[JfP030=OGe`3Ph>00f][J0080f][J0P3GemL30=;BdP030=OGe`3<c<`0
emOG00@0f][J0P3<c<`01@3Cdm<0c<c<0<c<c02`/;00XZ:R0080X:2P00<0W9bL08n?S`2?Shl00P2R
XZ830:2PX080XZ:R00P0WIfM0::RXP2VYZH0ZZZZ0:f][@2TY:@0X:2P0:BTY0<0[Jf]00d0/[:b0:f]
[@2][Jd0[Jf]0:NWY`2XZ:P0ZJVY0;:b/P2][Jd0/[:b0;Ng]`3gmoL0j>SX02<0moOg903oool60?Og
m`030?7al@3gmoL0moOg01l0moOg00H0b<S803Ti>@20P800gmoO0<g=c@3Fe]H30=WIf@030=KFeP3O
gml0fMWI0080fMWI0P3Fe]H30=3@d0030=KFeP3:b/X0e]KF00@0fMWI0P3:b/X01@3Cdm<0b/[:0<[:
bP2ZZZX0Vi^K0080V9RH00<0TY:B08>3P`23Ph<00P2KVi/309RHV080Vi^K00P0V9RH09^KV`2SXj<0
YZJV0:ZZZP2QXJ40VYZJ0:6QX@<0ZZZZ00d0[jn_0:ZZZP2ZZZX0ZZZZ0:BTY02SXj<0YjNW0:n_[`2Z
ZZX0[jn_0;Fe]@3gmoL0j>SX02<0moOg9`3oool002D0oooo1@3gmoL00`3alO40moOg0?7al@0O0?Og
m`040?7al@1MGEd0K6a/0>3Ph080emOG00@0f][J0=OGe`3GemL0d];B1@3Jf]X20=OGe`090=;BdP34
a<@0d];B0<g=c@39bLT0emOG0=[JfP3Ph>00f][J00D0c<c<00@0ZZZZ0:2PX02?Shl0QhN72P2?Shl0
2`2GUiL0XZ:R09>CT`2MWId0Y:BT0:VYZ@2TY:@0X:2P0:BTY02WYjL0Z:RX00@0[Jf]00<0/[:b0:NW
Y`2][Jd00P2YZJT0102][Jd0ZJVY0:VYZ@3Rh^8T0?Ogmb@0oooo1@3gmoL00`3alO40moOg0?7al@0O
0?Ogm`040?7al@1LG5`0Jf][0=oOg`80e]KF00@0fMWI0=KFeP3Fe]H0d=3@1@3IfMT20=KFeP090=3@
d031`L40d=3@0<[:bP38b<P0e]KF0=WIf@3Ogml0fMWI00D0b/[:00@0Y:BT09RHV023Ph<0NWYj2P23
Ph<02`2>SXh0Vi^K08b<S02HV9P0XJ6Q0:NWY`2QXJ40VYZJ0:6QX@2TY:@0Xj>S00@0ZZZZ00<0[jn_
0:BTY02ZZZX00P2WYjL0102ZZZX0YjNW0:NWY`3Rh^8T0?OgmbL0oooo000U0?ooo`030?Ogm`3alO40
moOg00<0moOg00<0lO7a0?Ogm`3gmoL07P3gmoL01029RHT0>CTi0>3Ph03Jf]X20=OGe`030=[JfP3G
emL0emOG0080emOG103Jf]X00`3GemL0clo?0<W9b@040<C4a0030=OGe`3Ph>00f][J00<0cLg=00h0
/;2`0:ZZZP2RXZ80UiNG09^KV`2j^[X0^;Rh0861P@3<c<`0]kNg07emO@2h^;P0Z:RX08n?S`<0QhN7
00T0Shn?09NGU`2CTi<0Ti>C09fMW@2ZZZX0Y:BT09^KV`2PX:000P2WYjL30:f][@050;Jf]P2][Jd0
[Jf]0:f][@2YZJT00`2][Jd00`2b/[80^[Zj0>;RhP0S0?Ogmb@0oooo00<0moOg0?7al@3gmoL00`3g
moL00`3alO40moOg0?Ogm`0N0?Ogm`0408V9R@0h>3P0gmoO0=WIf@80e]KF00<0fMWI0=KFeP3Fe]H0
0P3Fe]H40=WIf@030=KFeP3=cLd0b<S800@0`L7100<0e]KF0=oOg`3IfMT00`3:b/X03P2ZZZX0Y:BT
09^KV`2>SXh0V9RH0;Rh^02e]KD0MgMg0<[:bP2e]KD0MgMg0;Fe]@2SXj<0QXJ60`1jNWX02@23Ph<0
SXj>08b<S02<S8`0V9RH0:JVYP2QXJ40V9RH09ZJVP020:BTY0<0ZZZZ00D0/k>c0:ZZZP2ZZZX0ZZZZ
0:NWY`030:ZZZP030:n_[`2h^;P0h^;R02<0moOg9`3oool002D0oooo1@3gmoL00`3alO40moOg0?7a
l@020?Ogm`030?7al@3gmoL0moOg01T0moOg00@0][Jf04];B`0`<300f][J0P3GemL20=[JfP80emOG
00<0cLg=0=[JfP3Ph>000`3Jf]X00`3Bd]80bLW90<W9b@020;Vi^@050<C4a03Bd]80h>3P0<c<c031
`L400P2f][H01`2PX:00QhN706a/K02?Shl0Ti>C0<S8b03Jf]X00`2i^KT02@36a/H0Y:BT0<C4a03<
c<`0Vi^K09ZJVP2:RXX0K6a/07moO`0208n?S`80Ti>C00H0WIfM0:NWY`2WYjL0Y:BT0:NWY`2XZ:P2
0:f][@050;Vi^@2b/[80/[:b0:f][@2XZ:P00`2][Jd01P2YZJT0/[:b0;:b/P3Rh^80lO7a0>GUiB40
moOg903oool50?Ogm`030?7al@3gmoL0lO7a0080moOg00<0lO7a0?Ogm`3gmoL06@3gmoL0102e]KD0
BTY:02`/;03IfMT20=KFeP80fMWI0P3Fe]H00`3:b/X0fMWI0=oOg`030=WIf@030=3@d038b<P0b<S8
0080]KFe00D0`L710=3@d03Ogml0b/[:0;no_`020;>c/`0709RHV01jNWX0GemO08J6QP2<S8`0b<S8
0=WIf@030;Rh^0040<C4a02SXj<0a<C40<[:bP80V9RH00<0QXJ606EUI@1aLG400P26QXH208b<S006
09RHV02TY:@0Y:BT0:6QX@2TY:@0Xj>S0P2ZZZX01@2e]KD0[jn_0:n_[`2ZZZX0Xj>S00<0ZZZZ00H0
YjNW0:n_[`2_[jl0h^;R0?7al@3UiNDQ0?OgmbL0oooo000U0?oooaX0moOg00<0lO7a0?Ogm`3gmoL0
203gmoL0102e]KD0WYjN03Ti>@2MWId40=OGe`050=[JfP3Bd]80bLW90<C4a03Ph>000P3Jf]X01@3G
emL0f][J0<W9b@34a<@0^KVi0080Z:RX00X0emOG0=[JfP2f][H0ZZZZ0:2PX021PH40@d=309>CT`2h
^;P0Shn?0P2ZZZX05@2GUiL0j>SX0?7al@3Xj>P0f][J09bLW02ZZZX0WIfM08n?S`21PH40YZJV0:BT
Y02JVYX0L71`06a/K01oOgl0QhN708V9R@2CTi<0WIfM0:BTY0020:2PX0040:RXZ02][Jd0/[:b0;^k
^`80^KVi00/0/[:b0:f][@2][Jd0/[:b0:f][@2YZJT0[Jf]0;:b/P36a/H0g=cL0>SXj00Q0?Ogmb@0
oooo6P3gmoL00`3alO40moOg0?Ogm`080?Ogm`040;Fe]@2MWId0>3Ph09^KV`@0e]KF00D0fMWI0=3@
d038b<P0`L710=oOg`020=WIf@050=KFeP3IfMT0b<S80<71`@2e]KD00P2SXj<02P3Fe]H0fMWI0;>c
/`2TY:@0V9RH07MgM`0b<S80S8b<0;Fe]@23Ph<20:BTY00:08j>SP3Xj>P0lO7a0>SXj03IfMT0TY:B
0:BTY02HV9P0QXJ607MgM`80Xj>S00T0V9RH06][J`1UIFD0LG5a07YjNP20P800S8b<09RHV02QXJ40
0P2JVYX0102SXj<0ZZZZ0:n_[`2h^;P20;Fe]@0;0:n_[`2ZZZX0ZZZZ0:n_[`2ZZZX0YjNW0:ZZZP2_
[jl0a<C40=cLg03Xj>P08@3gmoLW0?ooo`009@3oool00`3alO40moOg0?Ogm`040?Ogm`030?7al@3g
moL0moOg01/0moOg00@0RHV90:NWY`0P8200c<c<0P3GemL20=[JfP040=OGe`3=cLd0cLg=0<g=c@D0
f][J02/0cLg=0;^k^`2a/K40Z:RX0:f][@3Jf]X0cLg=09NGU`21PH40RHV90;Ng]`34a<@0clo?0>SX
j036a/H0h>3P0<c<c02RXZ80lO7a0>_[j`3Xj>P0f][J0<S8b03Cdm<0f][J0<S8b02MWId0PH6109bL
W02JVYX0NGUi07EeM@1NGUh0M7Ad07moO`21PH40WIfM0:2PX02TY:@0YjNW0:VYZ@2][Jd0/[:b0080
^k^k00@0^KVi0;:b/P2][Jd0[Jf]0`2b/[801P2][Jd0/[:b0:f][@3Cdm<0g=cL0>SXj200moOg903o
ool00`3alO40moOg0?Ogm`040?Ogm`030?7al@3gmoL0moOg01/0moOg00@0RHV90:NWY`0N7Qh0b/[:
0P3Fe]H20=WIf@040=KFeP3:b/X0b/[:0<[:bPD0fMWI02/0b/[:0;Rh^02][Jd0Xj>S0:ZZZP3IfMT0
b/[:08j>SP1gMgL0P8200;Fe]@34a<@0cLg=0>SXj034a<@0gmoO0<[:bP2KVi/0lO7a0>_[j`3Xj>P0
fMWI0<S8b03Cdm<0fMWI0<S8b02HV9P0MgMg09ZJVP2HV9P0M7Ad075aL@1@D500J6QX075aL@1gMgL0
V9RH09ZJVP2QXJ40Y:BT0:NWY`2ZZZX0[jn_0080^;Rh00@0]KFe0:n_[`2ZZZX0ZZZZ0`2_[jl01P2Z
ZZX0[jn_0:f][@3Cdm<0g=cL0>SXj200moOg9`3oool002D0oooo9@3gmoL01@1dM7@0E5AD04=3@`3J
f]X0emOG0080f][J00D0d];B0=OGe`3=cLd0a<C40<g=c@020=[JfP0?0>3Ph03Jf]X0emOG0<C4a02a
/K40Z:RX09FEU@2][Jd0Shn?07moO`1FEUH0Fe]K0<o?c`3Xj>P0h>3P0080j>SX0P3[jn/0103alO40
h>3P0?7al@3alO420>SXj0030<o?c`3Xj>P0f][J0080f][J00X0]kNg08V9R@1oOgl0L71`0820P018
B4P0EEEE07AdM01oOgl0UiNG0`2TY:@0202YZJT0[Jf]0;:b/P2k^k/0a<C40;Vi^@2b/[80[Jf]0P2b
/[820:f][@80/[:b00D0]kNg0=cLg03alO40moOg0=?Cd`0O0?Ogmb@0oooo9@3gmoL01@1dM7@0De=C
0492@P3IfMT0e]KF0080fMWI00D0d=3@0=KFeP3:b/X0`L710<[:bP020=WIf@0?0=oOg`3IfMT0e]KF
0<71`@2][Jd0Xj>S08n?S`2ZZZX0QXJ6075aL@17AdL0De=C0<g=c@3Xj>P0gmoO0080j>SX0P3[jn/0
103alO40gmoO0?7al@3alO420>SXj0030<g=c@3Xj>P0fMWI0080fMWI00X0]KFe0820P01aLG40Jf][
07emO@14A4@0D51@06QXJ01aLG40TY:B0`2QXJ40202WYjL0ZZZZ0:n_[`2h^;P0`L710;Fe]@2_[jl0
ZZZZ0P2_[jl20:ZZZP80[jn_00D0]KFe0=cLg03alO40moOg0=?Cd`0O0?OgmbL0oooo000U0?oooad0
moOg0`3Xj>P02P3alO40moOg0?Ogm`3gmoL0iNGU03Hf=P0a<C40K6a/0=OGe`3Jf]X30=OGe`040=;B
dP3=cLd0cLg=0=OGe`@0f][J00/0emOG0;Vi^@2XZ:P0XJ6Q09FEU@1/K6`0BDU904=3@`1KFe/0]kNg
0=OGe`030>SXj0050=[JfP3Xj>P0jn_[0>SXj03Jf]X00P3alO40103Xj>P0h>3P0<C4a03[jn/30=[J
fP0@0<W9b@3Jf]X0f][J0:f][@1FEUH0=SHf03dm?@0K6a/0K6a/0861P@2JVYX0Y:BT0:2PX02WYjL0
[Jf]0;:b/P80a<C400@0^k^k0;Vi^@2][Jd0[Jf]0P2b/[820:f][@80/[:b00H0`/;20=[JfP3alO40
lO7a0>GUi@3alO4M0?Ogmb@0oooo7@3gmoL30>SXj00:0?7al@3gmoL0moOg0?Ogm`3UiND0=CDe02l_
;`1[Jf/0e]KF0=WIf@<0e]KF00@0d=3@0<[:bP3:b/X0e]KF103IfMT02`3Fe]H0]KFe0:>SX`2JVYX0
Shn?05mOG`0i>CT0<S8b05=CD`2e]KD0e]KF00<0j>SX00D0fMWI0>SXj03[jn/0j>SX0=WIf@020?7a
l@040>SXj03Ogml0`L710>_[j`<0fMWI0100b<S80=WIf@3IfMT0[Jf]04M7A`0V9RH0;bl_00l?3`1O
Gel0MgMg09FEU@2QXJ40VYZJ0:BTY02ZZZX0[jn_0P31`L40102h^;P0]KFe0:ZZZP2ZZZX20:n_[`80
ZZZZ0P2_[jl01P31`L40fMWI0?7al@3alO40iNGU0?7alAd0moOg9`3oool002D0oooo6P3gmoL00`3a
lO40moOg0?Ogm`060?Ogm`040>GUi@2EUID0<C4a02`/;0@0f][J00H0d];B0=OGe`39bLT0cLg=0<o?
c`39bLT40=[JfP0?0<g=c@2QXJ40XJ6Q092@T02IVIT0GUiN04];B`13@d<0GUiN09NGU`3<c<`0ZZZZ
0<g=c@3Ph>00cLg=0080j>SX00P0emOG0<K6aP3[jn/0jn_[0>3Ph03=cLd0^;Rh0<o?c`<0f][J01@0
[Jf]0=[JfP3Jf]X0f][J0;Zj^P3?cll0Rh^;0820P00410@0I6AT07AdM029RHT0[Jf]0:NWY`2][Jd0
^KVi0<C4a039bLT0a<C40;^k^`80^KVi00`0/[:b0:VYZ@2YZJT0ZJVY0:f][@2b/[80`<300<;2`P1?
Cdl0YjNW0=?Cd`3Rh^8M0?Ogmb@0oooo6P3gmoL00`3alO40moOg0?Ogm`060?Ogm`040>GUi@2EUID0
;bl_02TY:@@0fMWI00H0d=3@0=KFeP38b<P0b/[:0<g=c@38b<P40=WIf@0?0<[:bP2JVYX0VYZJ08V9
R@2EUID0D51@03hn?P0b<S80D51@08j>SP3:b/X0Y:BT0<[:bP3Ogml0b/[:0080j>SX00P0e]KF0<C4
a03[jn/0jn_[0=oOg`3:b/X0]KFe0<g=c@<0fMWI01@0ZZZZ0=WIf@3IfMT0fMWI0;Rh^03=cLd0RHV9
07emO@030`<0FEUI06QXJ020P800ZZZZ0:BTY02ZZZX0]KFe0<71`@38b<P0`L710;Rh^080]KFe00`0
[jn_0:NWY`2WYjL0YjNW0:ZZZP2_[jl0_kno0<71`@1=CDd0YjNW0=?Cd`3Rh^8M0?OgmbL0oooo000U
0?ooo`030?Ogm`3alO40moOg0200moOg00H0oooo07AdM00Z:RX0;2`/0=[JfP3?cll40=OGe`80cLg=
0200emOG0<C4a03Jf]X0f][J0>3Ph03Jf]X0cLg=092@T02JVYX0Shn?09fMW@1dM7@0GUiN04U9B@1/
K6`0UiNG0;6a/@2ZZZX0a<C40=OGe`31`L40h>3P0>SXj03=cLd0c<c<0=[JfP3Ph>00emOG0;Jf]P2h
^;P0a<C40=OGe`80f][J00`0X:2P0<S8b03Jf]X0clo?0:VYZ@2j^[X0]kNg0:VYZ@1@D500EUIF06a/
K021PH420:BTY0040:f][@2b/[80a<C40<W9b@80a<C400H0^k^k0:f][@2b/[80[Jf]0:VYZ@2][Jd2
0;:b/P060;Ng]`32`/80UIFE0;^k^`34a<@0dm?C3P3gmoL00`3alO40moOg0?Ogm`0<0?Ogmb@0oooo
00<0moOg0?7al@3gmoL0803gmoL01P3oool0M7Ad02TY:@0Y:BT0fMWI0<g=c@@0e]KF0P3:b/X05`3F
e]H0`L710=WIf@3IfMT0gmoO0=WIf@3:b/X0RHV909FEU@29RHT0V9RH06QXJ01@D500>CTi069RHP2>
SXh0[Jf]0:BTY031`L40e]KF0;no_`3Ogml0j>SX0080b/[:00L0fMWI0=oOg`3Fe]H0/k>c0;Fe]@31
`L40e]KF0080fMWI00`0VYZJ0<S8b03IfMT0cLg=0:NWY`2h^;P0]KFe0:NWY`1:BTX0AdM705mOG`1g
MgL20:6QX@040:ZZZP2_[jl0`L710<S8b080`L7100H0^;Rh0:ZZZP2_[jl0ZZZZ0:NWY`2ZZZX20:n_
[`060;Fe]@31`L40UIFE0;^k^`34a<@0dm?C3P3gmoL00`3alO40moOg0?Ogm`0<0?OgmbL0oooo000U
0?ooob80moOg00H0g=cL0820P00K6a/06a/K04Y:BP38b<P40=OGe`050=;BdP34a<@0emOG0=;BdP34
a<@0103Jf]X02P34a<@0QhN70:RXZ02QXJ40][Jf0;Rh^02f][H0/;2`08n?S`2GUiL20:2PX00:0:6Q
X@2h^;P0ZZZZ0;6a/@2f][H0X:2P0;Rh^03<c<`0^;Rh08n?S`80UiNG00D0ZZZZ0;6a/@2f][H0Z:RX
08V9R@020<o?c`0;0;^k^`2g]kL0^[Zj0;:b/P2][Jd0Rh^;04];B`19BDT0GUiN09NGU`2TY:@00P2]
[Jd00`34a<@0bLW90<C4a0020;^k^`80[Jf]00`0ZJVY0:NWY`2XZ:P0[Jf]0;:b/P2g]kL0^[Zj0=cL
g03=cLd0`L710<[:bP3=cLdL0?Ogmb@0oooo8P3gmoL01P3Lg=`0P82001/K6`0K6a/0AdM70<S8b0@0
e]KF00D0d=3@0<71`@3Fe]H0d=3@0<71`@040=WIf@0:0<71`@1mOGd0Xj>S09ZJVP2c/k<0]KFe0;>c
/`2ZZZX0QXJ608j>SP80V9RH00X0VYZJ0;Fe]@2TY:@0[Jf]0;>c/`2HV9P0]KFe0<[:bP2e]KD0QXJ6
0P2>SXh01@2TY:@0[Jf]0;>c/`2SXj<0P8200080cLg=00/0^;Rh0;Fe]@2h^;P0[jn_0:f][@29RHT0
?Shn03Ti>@1@D500TY:B0:6QX@020:ZZZP030<71`@38b<P0`L710080^;Rh0P2ZZZX0302WYjL0Y:BT
0:>SX`2ZZZX0[jn_0;Fe]@2h^;P0g=cL0<g=c@31`L40b/[:0<g=cA`0moOg9`3oool002D0oooo803g
moL0203alO40cLg=04=3@`0K6a/0;2`/020P802JVYX0f][J0P3GemL0203Jf]X0emOG0<C4a034a<@0
c<c<0<g=c@2f][H0emOG0`3Jf]X01P3=cLd0RHV90:f][@2k^k/0`L710<o?c`80f][J0P3GemL01@3<
c<`0a/K60<71`@31`L40^;Rh0080`L710`2`/;000`2h^;P0ZZZZ0:RXZ00209NGU`0908n?S`27QhL0
RHV908n?S`2][Jd0]kNg09FEU@2JVYX0bLW90080ZJVY00P0Rh^;04=3@`0f=SH0=SHf06ATI02MWId0
YjNW0:f][@@0a<C400<0^KVi0;:b/P2][Jd00P2WYjL00`2TY:@0[Jf]0:VYZ@020;Ng]`060?Ogm`3a
lO40dm?C0<g=c@3Xj>P0iNGU6`3gmoLT0?ooob00moOg00P0lO7a0<g=c@12@T806a/K02TY:@0N7Qh0
V9RH0=WIf@80e]KF00@0fMWI0=KFeP31`L40`L710P3:b/X00`2c/k<0e]KF0=WIf@020=WIf@060<[:
bP20P800ZZZZ0;Rh^02o_kl0cLg=0P3IfMT20=KFeP050<[:bP34a<@0_kno0;no_`2e]KD00P2o_kl3
0:ZZZP030;Fe]@2VYZH0Xj>S0080SXj>00T0QXJ607emO@20P800QXJ60:ZZZP2e]KD0Shn?09FEU@38
b<P00P2WYjL02029RHT0?Shn02HV9P0V9RH0FEUI09RHV02TY:@0ZZZZ1031`L400`2e]KD0[jn_0:ZZ
ZP020:BTY0030:6QX@2ZZZX0YjNW0080]KFe00H0moOg0?7al@3Cdm<0cLg=0>SXj03UiNDK0?OgmbL0
oooo000U0?ooo`/0moOg00<0lO7a0?Ogm`3gmoL04@3gmoL0103Rh^80cLg=034a<@0410@202`/;003
07EeM@3Jf]X0c<c<00@0emOG00<0cLg=0<o?c`39bLT00P39bLT03@3GemL0f][J0=OGe`3?cll0a<C4
0:ZZZP2@T900][Jf0<K6aP3Ph>00f][J0>3Ph03Jf]X00P3Ph>020=[JfP@0h>3P00@0b<S80=OGe`38
b<P0c<c<0P36a/H01@31`L40^;Rh0;2`/02RXZ80WIfM0080Ti>C00`0Shn?0861P@21PH40X:2P09FE
U@1dM7@0K6a/04=3@`0O7al0=SHf051@D01TI6@20:BTY0050;Vi^@34a<@0bLW90<C4a02k^k/00P2]
[Jd0102YZJT0X:2P0:BTY02YZJT20;:b/P070;Ng]`24Q8@0WYjN0=cLg03Xj>P0g=cL0>;RhP0K0?Og
mb@0oooo2`3gmoL00`3alO40moOg0?Ogm`0A0?Ogm`040>;RhP3=cLd0;bl_00<30`80:BTY00<0LG5a
0=WIf@3:b/X0103Fe]H00`3:b/X0cLg=0<S8b0020<S8b00=0=KFeP3IfMT0e]KF0<g=c@31`L40Y:BT
08V9R@2c/k<0a<C40=oOg`3IfMT0gmoO0=WIf@020=oOg`80fMWI103Ogml01038b<P0e]KF0<S8b03:
b/X20<C4a0050;no_`2e]KD0ZZZZ09^KV`2HV9P00P2<S8`03026QXH0MgMg07MgM`2JVYX0Shn?06QX
J01RHV80?Shn018B4P0V9RH0BTY:05UIF@80XJ6Q00D0]KFe0<71`@38b<P0`L710;Rh^0020:ZZZP04
0:NWY`2JVYX0XJ6Q0:NWY`80[jn_00L0]KFe08>3P`2MWId0g=cL0>SXj03Lg=`0h^;R01/0moOg9`3o
ool002D0oooo2`3gmoL00`3alO40moOg0?Ogm`0A0?Ogm`030=?Cd`29RHT06a/K0080<30`00T06a/K
09bLW03Jf]X0clo?0=OGe`3<c<`0emOG0=;BdP39bLT00P3<c<`20<o?c`060=OGe`3<c<`0emOG0<o?
c`34a<@0/K6a0P2EUID00`36a/H0f][J0>3Ph0020>3Ph0D0f][J0P3Ph>020=[JfP030>3Ph039bLT0
bLW900<0a<C400D0bLW90<C4a02k^k/0][Jf0;2`/0020:RXZ00H09fMW@2RXZ80Ti>C09>CT`2?Shl0
PH6106a/K01KFe/0EUIF06a/K01NGUh0WIfM0:NWY`2i^KT0a<C40<W9b@34a<@0^KVi0;:b/P2][Jd0
YjNW0:2PX02TY:@0ZJVY0`2b/[800`2TY:@0B4Q80>SXj00N0?Ogmb@0oooo2`3gmoL00`3alO40moOg
0?Ogm`0A0?Ogm`030=?Cd`29RHT061PH0080;2`/00T061PH09ZJVP3IfMT0cLg=0=KFeP3:b/X0e]KF
0=3@d038b<P00P3:b/X20<g=c@060=KFeP3:b/X0e]KF0<g=c@31`L40[Jf]0P2?Shl00`34a<@0fMWI
0=oOg`020=oOg`D0fMWI0P3Ogml20=WIf@030=oOg`38b<P0b<S800<0`L7100D0b<S80<71`@2h^;P0
/k>c0:ZZZP020:>SX`0H09RHV02KVi/0S8b<08b<S026QXH0MgMg069RHP1CDe<0AdM705mOG`1@D500
V9RH0:BTY02e]KD0`L710<S8b031`L40]KFe0:n_[`2ZZZX0Y:BT09ZJVP2QXJ40YjNW0`2_[jl00`2S
Xj<0A4A40>SXj00N0?OgmbL0oooo000U0?oooal0moOg00P0g=cL07AdM00C4a<0=cLg03Ti>@0K6a/0
a/K60=[JfP@0emOG00H0d];B0<c<c03GemL0emOG0<o?c`3<c<`20=OGe`070<o?c`3GemL0a/K60;6a
/@2QXJ40T92@0;^k^`080=[JfP060>3Ph03Jf]X0f][J0>3Ph03Jf]X0emOG0P3=cLd60<C4a080][Jf
00<0/K6a0:ZZZP2XZ:P00P2XZ:P309fMW@030:2PX02?Shl0T92@0080PH6100h0Vi^K0:BTY02i^KT0
^KVi0<W9b@2k^k/0a<C40:f][@2YZJT0YjNW0:BTY02PX:00[Jf]0:VYZ@80/[:b00<0[Jf]04m?C`29
RHT00P3Xj>PL0?Ogmb@0oooo7`3gmoL0203Lg=`0M7Ad018B4P0b<S80=CDe01PH6034a<@0fMWI103F
e]H01P3@d=00b/[:0=KFeP3Fe]H0cLg=0<[:bP80e]KF00L0cLg=0=KFeP34a<@0[Jf]09ZJVP29RHT0
^;Rh00P0fMWI00H0gmoO0=WIf@3IfMT0gmoO0=WIf@3Fe]H20<[:bPH0`L710P2c/k<00`2][Jd0YZJV
0:>SX`020:>SX`@0V9RH00H0QXJ608V9R@1gMgL0MgMg09RHV02QXJ420;Fe]@0:0<S8b02h^;P0`L71
0:ZZZP2WYjL0Y:BT0:6QX@2JVYX0ZZZZ0:NWY`80[jn_00<0[Jf]04e=C@29RHT00P3Xj>PL0?OgmbL0
oooo000U0?ooo`030?Ogm`3alO40moOg0080lO7a00<0moOg0?7al@3gmoL05`3gmoL01P3Lg=`0;2`/
0;Ng]`3GemL0a<C40:6QX@80f][J00<0emOG0<o?c`3GemL00P3Bd]80103?cll0emOG0=;BdP3Bd]84
0=OGe`0:0<o?c`3=cLd0][Jf0;6a/@2QXJ40Z:RX0<W9b@3Jf]X0emOG0=[JfP<0h>3P1P3Jf]X20=OG
e`@0a<C400L0bLW90<C4a034a<@0^k^k0;Jf]P2][Jd0Y:BT0080[Jf]1`2TY:@209^KV`0409VIV@2P
X:00^KVi0;Vi^@80a<C400h0^k^k0:f][@2WYjL0Z:RX0:BTY02WYjL0Z:RX0:f][@2b/[80ZJVY0;Jf
]P20P800WYjN09FEUAd0moOg903oool00`3gmoL0lO7a0?Ogm`020?7al@030?Ogm`3alO40moOg01L0
moOg00H0g=cL02TY:@2e]KD0e]KF0<71`@2JVYX20=WIf@030=KFeP3=cLd0e]KF0080d=3@00@0cLg=
0=KFeP3@d=00d=3@103Fe]H02P3=cLd0b/[:0;>c/`2][Jd0VYZJ0:>SX`38b<P0fMWI0=KFeP3IfMT3
0=oOg`H0fMWI0P3Fe]H40<71`@070<S8b031`L40`L710;Rh^02c/k<0ZZZZ0:6QX@020:ZZZPL0XJ6Q
0P2HV9P0102EUID0VYZJ0;Fe]@2e]KD20<71`@0>0;Rh^02ZZZX0Y:BT0:>SX`2QXJ40Y:BT0:>SX`2Z
ZZX0[jn_0:NWY`2e]KD0P82009fMW@2EUIDM0?OgmbL0oooo000U0?oooal0moOg00<0][Jf0;Ng]`3G
emL00P3GemL00`36a/H0f][J0=OGe`020=OGe`80c<c<00@0clo?0=OGe`3GemL0c<c<1P3GemL02@3?
cll0^KVi0;6a/@2ZZZX0XJ6Q0<W9b@3GemL0f][J0>3Ph0020=[JfP030>3Ph03Jf]X0emOG0080f][J
0P3Ph>000`3GemL0clo?0<C4a0020;Vi^@<0a<C400`0^k^k0:f][@2][Jd0ZJVY0:NWY`2PX:00Y:BT
09^KV`2PX:00Vi^K0:NWY`2PX:020:BTY00F0:NWY`2PX:00YjNW0:BTY02i^KT0Z:RX0<C4a02k^k/0
^KVi0:f][@2WYjL0YZJV0:NWY`2TY:@0[Jf]0:VYZ@2XZ:P0/[:b0:f][@1DE5@0a<C40<g=c@L0moOg
00<0lO7a0?Ogm`3gmoL04`3gmoLT0?oooal0moOg0P2e]KD30=KFeP030<C4a03IfMT0e]KF0080e]KF
0P3:b/X0103=cLd0e]KF0=KFeP3:b/X60=KFeP090<g=c@2e]KD0[Jf]0:BTY02JVYX0b<S80=KFeP3I
fMT0gmoO0080fMWI00<0gmoO0=WIf@3Fe]H00P3IfMT20=oOg`030=KFeP3=cLd0`L710080]KFe0`31
`L40302h^;P0ZZZZ0:ZZZP2WYjL0Y:BT09ZJVP2QXJ40V9RH09ZJVP2HV9P0Y:BT09ZJVP80XJ6Q01H0
Y:BT09ZJVP2TY:@0XJ6Q0;Fe]@2SXj<0`L710;Rh^02e]KD0ZZZZ0:BTY02SXj<0Y:BT0:6QX@2ZZZX0
YjNW0:>SX`2_[jl0[Jf]05=CD`34a<@0cLg=1`3gmoL00`3alO40moOg0?Ogm`0C0?OgmbL0oooo000U
0?oooah0moOg00@0j>SX0<o?c`3<c<`0emOG0P3Jf]X01@3GemL0clo?0=OGe`3GemL0c<c<00<0emOG
0P3Jf]X01@3GemL0f][J0=[JfP3Jf]X0emOG0080f][J00<0clo?0<C4a02f][H00`2a/K400`34a<@0
clo?0=[JfP030>3Ph080f][J00P0emOG0=[JfP3Jf]X0h>3P0=[JfP3?cll0bLW90;^k^`@0^KVi00<0
/K6a0:f][@2WYjL00P2TY:@209^KV`H0VIVI0P2PX:001P2MWId0Vi^K0:2PX02i^KT0UIFE0;^k^`80
^KVi00H0[Jf]0:NWY`2TY:@0X:2P0:BTY02YZJT20:f][@050:VYZ@2TY:@0;2`/08V9R@3:b/X07@3g
moLT0?oooah0moOg00@0j>SX0<g=c@3:b/X0e]KF0P3IfMT01@3Fe]H0cLg=0=KFeP3Fe]H0b/[:00<0
e]KF0P3IfMT01@3Fe]H0fMWI0=WIf@3IfMT0e]KF0080fMWI00<0cLg=0<71`@2c/k<00`2][Jd00`31
`L40cLg=0=WIf@030=oOg`80fMWI00P0e]KF0=WIf@3IfMT0gmoO0=WIf@3=cLd0b<S80;Rh^0@0]KFe
00<0[Jf]0:ZZZP2TY:@00P2QXJ4209RHV0H0UIFE0P2JVYX209RHV00409ZJVP2e]KD0Shn?0;Rh^080
]KFe00H0ZZZZ0:BTY02QXJ40VYZJ0:6QX@2WYjL20:ZZZP050:NWY`2SXj<0:BTY08V9R@3:b/X07@3g
moLW0?ooo`009@3ooolN0?Ogm`0;0=cLg03GemL0emOG0=OGe`3Jf]X0emOG0<o?c`3Jf]X0clo?0=OG
e`3?cll0103GemL40=[JfP0=0>3Ph03Jf]X0f][J0=OGe`3Bd]80a/K60;^k^`2f][H0/K6a0:RXZ034
a<@0bLW90=OGe`020>3Ph0050=[JfP3Ph>00f][J0=[JfP3GemL00P3Ph>00103Jf]X0c<c<0<o?c`34
a<@20;6a/@0<0;Jf]P2b/[80[Jf]0:f][@2XZ:P0X:2P09fMW@2KVi/0VIVI09^KV`2GUiL0VIVI0P2G
UiL01@2IVIT0UiNG09VIV@2IVIT0WIfM0080Z:RX00D0/K6a0;^k^`2f][H0][Jf0:RXZ0020:BTY00:
0:2PX02WYjL0Z:RX0:VYZ@2][Jd0ZJVY0:BTY00a<C40P8200<C4a1d0moOg903ooolN0?Ogm`0;0=cL
g03Fe]H0e]KF0=KFeP3IfMT0e]KF0<g=c@3IfMT0cLg=0=KFeP3=cLd0103Fe]H40=WIf@0=0=oOg`3I
fMT0fMWI0=KFeP3@d=00a<C40;Rh^02c/k<0[Jf]0:>SX`31`L40b<S80=KFeP020=oOg`050=WIf@3O
gml0fMWI0=WIf@3Fe]H00P3Ogml0103IfMT0b/[:0<g=c@31`L420:f][@0<0;>c/`2_[jl0ZZZZ0:ZZ
ZP2SXj<0VYZJ09^KV`2HV9P0UIFE09RHV02BTY80UIFE0P2BTY801@2EUID0TY:B09FEU@2EUID0V9RH
0080Xj>S00D0[Jf]0;Rh^02c/k<0/k>c0:>SX`020:6QX@0:09ZJVP2TY:@0Xj>S0:NWY`2ZZZX0YjNW
0:>SX`0_;bl0P8200<C4a1d0moOg9`3oool002D0oooo7P3gmoL00`3Cdm<0emOG0=[JfP020=OGe`03
0=;BdP30`<00clo?0080emOG00@0c<c<0=OGe`3GemL0emOG0P3Jf]X50>3Ph080f][J00X0emOG0<W9
b@34a<@0^k^k0;6a/@2QXJ40^KVi0<C4a03<c<`0f][J0`3Ph>030=[JfP80emOG00@0b<S80<o?c`2k
^k/0][Jf0P2h^;P00`2b/[80Z:RX0:RXZ0020:BTY00509fMW@2IVIT0Vi^K09NGU`2IVIT00P2GUiL0
1`2KVi/0VYZJ09VIV@2IVIT0UIFE09VIV@2WYjL00P2XZ:P01@2f][H0^KVi0;Jf]P2][Jd0Z:RX0080
Y:BT00<0X:2P0:NWY`2WYjL00`2YZJT01@2TY:@04a<C04=3@`17AdL0lO7a01`0moOg903ooolN0?Og
m`030=?Cd`3Fe]H0fMWI0080e]KF00<0d=3@0;no_`3=cLd00P3Fe]H0103:b/X0e]KF0=KFeP3Fe]H2
0=WIf@D0gmoO0P3IfMT02P3Fe]H0b<S80<71`@2h^;P0[Jf]09ZJVP2e]KD0`L710<[:bP3IfMT30=oO
g`<0fMWI0P3Fe]H01038b<P0cLg=0;Rh^02c/k<20;Fe]@030:n_[`2SXj<0Xj>S0080XJ6Q00D0V9RH
09FEU@2HV9P0TY:B09FEU@0209:BTP0709RHV02EUID0UIFE09FEU@2?Shl0UIFE0:BTY0020:>SX`05
0;>c/`2e]KD0/k>c0:ZZZP2SXj<00P2QXJ400`2JVYX0Y:BT0:BTY0030:NWY`050:>SX`0B4Q80@T92
04M7A`3alO40703gmoLW0?ooo`009@3ooolM0?Ogm`0<0>SXj03Bd]80emOG0=[JfP3<c<`0cLg=0;Vi
^@2k^k/0clo?0<S8b03GemL0d];B0P3GemL30=[JfPH0h>3P0P3GemL0103=cLd0a<C40<C4a02f][H2
0;6a/@030;Vi^@3?cll0f][J00<0h>3P00@0f][J0<c<c03=cLd0c<c<0`3?cll01`36a/H0^k^k0;Jf
]P2f][H0/[:b0:BTY02MWId00P2TY:@01P2IVIT0UiNG09NGU`2IVIT0Vi^K09VIV@<0Vi^K0`2IVIT0
1@2EUID0Z:RX0;6a/@2f][H0^k^k00<0[Jf]00L0ZJVY0:BTY02TY:@0YjNW0:ZZZP2XZ:P0ZJVY0080
/[:b00@0W9bL01DE5@0T92@0>CTi7@3gmoLT0?oooad0moOg00@0j>SX0=3@d03Fe]H0fMWI0P3:b/X0
1P2e]KD0^;Rh0<g=c@38b<P0e]KF0=3@d080e]KF0`3IfMT60=oOg`80e]KF00@0b/[:0<71`@31`L40
/k>c0P2][Jd00`2e]KD0cLg=0=WIf@030=oOg`040=WIf@3:b/X0b/[:0<[:bP<0cLg=00L0a<C40;Rh
^02c/k<0/k>c0:n_[`2QXJ40V9RH0080XJ6Q00H0UIFE09:BTP2BTY80UIFE09RHV02EUID309RHV0<0
UIFE00D0Shn?0:>SX`2][Jd0/k>c0;Rh^0030:ZZZP070:NWY`2QXJ40XJ6Q0:BTY02VYZH0Xj>S0:NW
Y`020:n_[`0409ZJVP0E5AD092@T03Ph>1d0moOg9`3oool002D0oooo703gmoL02`3Xj>P0emOG0=[J
fP3GemL0h>3P0=[JfP34a<@0^KVi0<30`03<c<`0clo?00@0emOG0P3Jf]X80>3Ph00:0=OGe`3<c<`0
clo?0<C4a02i^KT0/K6a0:RXZ02a/K40^KVi0=[JfP80h>3P00D0f][J0=OGe`3Jf]X0emOG0=[JfP02
0=OGe`050<o?c`36a/H0bLW90<C4a02k^k/00`2b/[803`2EUID0UiNG09FEU@2EUID0UiNG09^KV`2I
VIT0Vi^K09VIV@2MWId0VIVI09^KV`2IVIT0X:2P0:f][@020;^k^`030;Rh^02f][H0][Jf00<0[Jf]
0`2TY:@02@2YZJT0YjNW0:NWY`2VYZH0ZJVY08N7Q`0Z:RX0KFe]0>SXj00M0?Ogmb@0oooo703gmoL0
2`3Xj>P0e]KF0=WIf@3Fe]H0gmoO0=WIf@31`L40]KFe0;no_`3:b/X0cLg=00@0e]KF0P3IfMT80=oO
g`0:0=KFeP3:b/X0cLg=0<71`@2e]KD0[Jf]0:>SX`2][Jd0]KFe0=WIf@80gmoO00D0fMWI0=KFeP3I
fMT0e]KF0=WIf@020=KFeP050<g=c@34a<@0b<S80<71`@2h^;P00`2_[jl03`2?Shl0TY:B08n?S`2?
Shl0TY:B09RHV02EUID0V9RH09FEU@2KVi/0UIFE09RHV02EUID0VYZJ0:ZZZP020;Rh^0030;Fe]@2c
/k<0/k>c00<0ZZZZ0`2QXJ402@2WYjL0Y:BT0:BTY02SXj<0YjNW08J6QP0Y:BT0KVi^0>SXj00M0?Og
mbL0oooo000U0?oooa`0moOg00d0h>3P0=OGe`3GemL0f][J0>3Ph039bLT0^KVi0;6a/@36a/H0b<S8
0<o?c`3GemL0c<c<0080emOG00H0f][J0>3Ph03Ph>00j>SX0>3Ph03Xj>P30>3Ph0070=[JfP3GemL0
clo?0<K6aP3=cLd0a<C40;Vi^@030;6a/@040<c<c03Ph>00f][J0>3Ph080f][J00H0h>3P0=[JfP3J
f]X0h>3P0=[JfP3?cll20<K6aP0:0;^k^`2g]kL0/[:b0:f][@2b/[80YZJV08n?S`2GUiL0RXZ:09NG
U`80VIVI0`2KVi/01P2PX:00Z:RX0;:b/P2f][H0`<300;Vi^@80^k^k00<0][Jf0:f][@2][Jd00P2]
[Jd02@2WYjL0Z:RX0:VYZ@2ZZZX0ZJVY0:JVYP2YZJT0Ph>3020P8002034a<@030;2`/03UiND0moOg
01X0moOg903ooolL0?Ogm`0=0=oOg`3Fe]H0e]KF0=WIf@3Ogml0b<S80;Fe]@2][Jd0a<C40<S8b03=
cLd0e]KF0<[:bP020=KFeP060=WIf@3Ogml0gmoO0>SXj03Ogml0j>SX0`3Ogml01`3IfMT0e]KF0<g=
c@34a<@0b/[:0<71`@2e]KD00`2][Jd0103:b/X0gmoO0=WIf@3Ogml20=WIf@060=oOg`3IfMT0fMWI
0=oOg`3IfMT0cLg=0P34a<@02P2h^;P0]KFe0:n_[`2ZZZX0[jn_0:>SX`29RHT0TY:B08J6QP2BTY82
09FEU@<0V9RH00H0VYZJ0:>SX`2_[jl0/k>c0;no_`2e]KD20;Rh^0030;>c/`2ZZZX0ZZZZ0080ZZZZ
00T0Y:BT0:>SX`2WYjL0YZJV0:NWY`2SXj<0YjNW0820P00N7Qh00P0_;bl00`2`/;00iNGU0?Ogm`0J
0?OgmbL0oooo000U0?ooo`P0moOg00<0lO7a0?Ogm`3gmoL04@3gmoL20=OGe`090<c<c03Jf]X0f][J
0<C4a02a/K40/[:b0<W9b@3?cll0f][J0080emOG0`3Jf]X30>3Ph0<0j>SX0`3Ph>001P3Jf]X0emOG
0<K6aP3?cll0a/K60;^k^`<0/K6a00<0bLW90=[JfP3Jf]X00`3Jf]X0103Ph>00f][J0>3Ph03Ph>02
0=[JfP050<c<c039bLT0^k^k0;Rh^02b/[800P2YZJT01@2][Jd0Y:BT0:2PX02KVi/0UIFE0080UiNG
00<0VIVI0:2PX02PX:000P2XZ:P01`2f][H0^k^k0<C4a034a<@0^k^k0;Vi^@2b/[800P2][Jd03`2X
Z:P0[Jf]0:BTY02WYjL0Y:BT0:NWY`2VYZH0ZJVY0;:b/P1/K6`0<30`020P800/;2`0GEeM0<[:bP0K
0?Ogmb@0oooo203gmoL00`3alO40moOg0?Ogm`0A0?Ogm`80e]KF00T0b/[:0=WIf@3IfMT0`L710:f]
[@2_[jl0b<S80<g=c@3IfMT00P3Fe]H30=WIf@<0gmoO0`3Xj>P30=oOg`060=WIf@3Fe]H0a<C40<g=
c@34a<@0^;Rh0`2][Jd00`38b<P0fMWI0=WIf@030=WIf@040=oOg`3IfMT0gmoO0=oOg`80fMWI00D0
b/[:0<S8b02h^;P0]KFe0:n_[`020:NWY`050:ZZZP2QXJ40VYZJ09RHV02?Shl00P2BTY800`2EUID0
VYZJ09ZJVP020:>SX`070;>c/`2h^;P0`L710<71`@2h^;P0]KFe0:n_[`020:ZZZP0?0:>SX`2ZZZX0
XJ6Q0:BTY02QXJ40Y:BT0:>SX`2WYjL0[jn_06][J`0/;2`07QhN02TY:@1LG5`0b/[:01/0moOg9`3o
ool002D0oooo6`3gmoL01P3alO40d];B0<c<c03<c<`0f][J0;^k^`80/K6a00@0[Jf]0<;2`P3<c<`0
clo?0`3GemL20=[JfPD0h>3P00<0j>SX0>3Ph03Ph>000P3Ph>001@3GemL0clo?0<K6aP36a/H0^k^k
00<0][Jf00<0a<C40=[JfP3Jf]X0103Jf]X01`3Ph>00j>SX0>SXj03Jf]X0emOG0<W9b@34a<@00P2h
^;P0102b/[80[Jf]0;:b/P2VYZH20:f][@040:RXZ02CTi<0UIFE09FEU@80VIVI00D0Z:RX0;6a/@2f
][H0^KVi0<71`@020<C4a0050;^k^`2f][H0/[:b0:f][@2f][H00P2][Jd03P2WYjL0ZZZZ0:BTY02T
Y:@0[Jf]0:JVYP2YZJT0WIfM0861P@1TI6@0B4Q8034a<@1dM7@0dm?C6P3gmoLT0?oooa/0moOg00H0
lO7a0=3@d03:b/X0b/[:0=WIf@2h^;P20:f][@040:ZZZP31`L40b/[:0<g=c@<0e]KF0P3IfMT50=oO
g`030>SXj03Ogml0gmoO0080gmoO00D0e]KF0<g=c@34a<@0a<C40;Rh^0030;>c/`030<71`@3IfMT0
fMWI00@0fMWI00L0gmoO0>SXj03Xj>P0fMWI0=KFeP38b<P0`L710080]KFe00@0[jn_0:ZZZP2_[jl0
Xj>S0P2ZZZX0102SXj<0Shn?08n?S`2?Shl209FEU@050:>SX`2][Jd0/k>c0;Fe]@2o_kl00P31`L40
1@2h^;P0/k>c0:n_[`2ZZZX0/k>c0080ZZZZ00h0Y:BT0:JVYP2QXJ40XJ6Q0:ZZZP2SXj<0YjNW09^K
V`1mOGd0GemO04A4A00_;bl0M7Ad0=?CdaX0moOg9`3oool002D0oooo6`3gmoL20<o?c`80emOG0P34
a<@0102TY:@0WIfM0;^k^`32`/830=OGe`040=[JfP3GemL0f][J0=OGe`<0h>3P0`3Xj>P30>3Ph003
0=[JfP3<c<`0emOG0080clo?00D0^k^k0<C4a02k^k/0a<C40=OGe`020=[JfP030=OGe`3<c<`0c<c<
00@0f][J00h0emOG0<W9b@34a<@0][Jf0:f][@2ZZZX0YZJV0:f][@2YZJT0YjNW0:JVYP2WYjL0X:2P
09fMW@80R8R800@0Vi^K0:NWY`2b/[80][Jf1`2k^k/00`2f][H0/[:b0:ZZZP020:f][@090:VYZ@2]
[Jd0Z:RX0:RXZ02][Jd0]kNg0:VYZ@2TY:@0UiNG0080OGem00@0>CTi04=3@`1MGEd0h^;R6@3gmoLT
0?oooa/0moOg0P3=cLd20=KFeP80`L7100@0XJ6Q09RHV02h^;P0`L710`3Fe]H0103IfMT0e]KF0=WI
f@3Fe]H30=oOg`<0j>SX0`3Ogml00`3IfMT0b/[:0=KFeP020<g=c@050;Rh^031`L40^;Rh0<71`@3F
e]H00P3IfMT00`3Fe]H0b/[:0<[:bP040=WIf@0>0=KFeP38b<P0`L710;>c/`2ZZZX0YZJV0:>SX`2Z
ZZX0YjNW0:BTY02SXj<0Y:BT09ZJVP2HV9P208>3P`0409RHV02TY:@0[jn_0;>c/`L0^;Rh00<0/k>c
0:n_[`2VYZH00P2ZZZX02@2WYjL0ZZZZ0:>SX`2SXj<0ZZZZ0;Fe]@2WYjL0XJ6Q09:BTP0207MgM`04
03De=@12@T80G5aL0>;RhQT0moOg9`3oool002D0oooo6`3gmoL03039bLT0d];B0<g=c@2i^KT0ZZZZ
0:6QX@2JVYX0[Jf]0<W9b@3?cll0emOG0<o?c`80f][J00<0emOG0=[JfP3Jf]X00P3Ph>000`3Xj>P0
h>3P0>3Ph0040>3Ph0070=[JfP3GemL0clo?0<c<c03?cll0cLg=0<C4a0020<K6aP060<W9b@3Ph>00
f][J0=OGe`3=cLd0a/K6103GemL01039bLT0a<C40<30`02b/[820:VYZ@0=0:2PX02TY:@0ZJVY09fM
W@2KVi/0Y:BT0:2PX02EUID0R8R808n?S`2MWId0ZZZZ0;Jf]P060;^k^`030<71`@2k^k/0][Jf00<0
/[:b00H0[Jf]0:VYZ@2YZJT0[Jf]0:RXZ02YZJT20;Ng]`060:2PX02TY:@0Vi^K0:2PX02GUiL0MgMg
6`3gmoLT0?oooa/0moOg00`0b<S80=3@d03:b/X0]KFe0:BTY02JVYX0UIFE0:ZZZP38b<P0cLg=0=KF
eP3=cLd20=WIf@030=KFeP3IfMT0fMWI0080gmoO00<0j>SX0=oOg`3Ogml0103Ogml01`3IfMT0e]KF
0<g=c@3:b/X0cLg=0<[:bP31`L400P34a<@01P38b<P0gmoO0=WIf@3Fe]H0b/[:0<C4a0@0e]KF00@0
b<S80<71`@2o_kl0[jn_0P2WYjL03@2JVYX0XJ6Q0:NWY`2KVi/0V9RH0:6QX@2JVYX0Shn?08>3P`29
RHT0V9RH0:JVYP2c/k<01P2h^;P00`2o_kl0^;Rh0;>c/`030:n_[`060:ZZZP2WYjL0YjNW0:ZZZP2S
Xj<0YjNW0P2e]KD01P2JVYX0XJ6Q09RHV02JVYX0TY:B07MgMa/0moOg9`3oool002D0oooo6`3gmoL0
2@34a<@0cLg=0;6a/@2QXJ40Shn?09>CT`2JVYX0/[:b0<C4a0020<c<c0<0emOG0P3Jf]X70>3Ph004
0=[JfP3Ph>00f][J0=[JfP80emOG00D0clo?0<c<c039bLT0a/K60<g=c@020<K6aP0>0=[JfP3GemL0
emOG0<W9b@36a/H0clo?0=OGe`3<c<`0clo?0<W9b@34a<@0^KVi0;Jf]P2XZ:P20:BTY00;09fMW@2K
Vi/0Vi^K09^KV`2PX:00VIVI08Z:RP2?Shl0UIFE0:2PX02][Jd0102k^k/20<C4a0<0^k^k00<0/[:b
0;Jf]P2][Jd00P2][Jd01`2XZ:P0YZJV0:ZZZP2YZJT0Y:BT0:VYZ@2g]kL00`2TY:@00`2MWId0Vi^K
0;^k^`0K0?Ogmb@0oooo6`3gmoL02@31`L40b/[:0:f][@2JVYX0QXJ608b<S02EUID0[jn_0<71`@02
0<[:bP<0e]KF0P3IfMT70=oOg`040=WIf@3Ogml0fMWI0=WIf@80e]KF00D0cLg=0<[:bP38b<P0a<C4
0<[:bP020<C4a00>0=WIf@3Fe]H0e]KF0<S8b034a<@0cLg=0=KFeP3:b/X0cLg=0<S8b031`L40]KFe
0;>c/`2SXj<20:6QX@0;09^KV`2HV9P0V9RH09RHV02JVYX0UIFE08J6QP29RHT0Shn?09ZJVP2ZZZX0
102h^;P20<71`@<0^;Rh00<0[jn_0;>c/`2ZZZX00P2ZZZX20:>SX`050:JVYP2WYjL0XJ6Q0:NWY`2e
]KD00`2QXJ4209RHV0030;^k^`3gmoL0moOg01T0moOg9`3oool002D0oooo6P3gmoL02P3Jf]X0d];B
0<C4a02ZZZX0W9bL09>CT`2EUID0Vi^K0;:b/P36a/H20<o?c`030=[JfP3GemL0f][J00<0f][J203P
h>020=[JfP080<c<c03Bd]80clo?0<g=c@36a/H0bLW90<c<c03GemL20=[JfP030>3Ph03Jf]X0emOG
00<0f][J00X0emOG0<c<c039bLT0`<300;^k^`2b/[80Y:BT09fMW@2HV9P0WIfM0P2CTi<00`2KVi/0
VIVI09FEU@0209FEU@0409^KV`2XZ:P0/[:b0;^k^`<0a<C400L0^k^k0<71`@31`L40^k^k0;Vi^@2g
]kL0/K6a0080[Jf]00@0Z:RX0:VYZ@2ZZZX0Y:BT0P2][Jd0202g]kL0^[Zj09VIV@2IVIT0X:2P09fM
W@2TY:@0lO7a6`3gmoLT0?oooaX0moOg00X0fMWI0=3@d031`L40Y:BT09:BTP2<S8`0Shn?09RHV02_
[jl0a<C40P3=cLd00`3IfMT0e]KF0=WIf@030=WIf@P0gmoO0P3IfMT0203:b/X0d=3@0<g=c@3:b/X0
a<C40<S8b03:b/X0e]KF0P3IfMT00`3Ogml0fMWI0=KFeP030=WIf@0:0=KFeP3:b/X0b<S80;no_`2h
^;P0[jn_0:6QX@2KVi/0UIFE09^KV`80Shn?00<0V9RH09FEU@2?Shl00P2?Shl0102HV9P0Xj>S0:n_
[`2h^;P30<71`@040;Rh^02o_kl0_kno0;Rh^080]KFe00L0[Jf]0:ZZZP2ZZZX0Xj>S0:NWY`2VYZH0
XJ6Q0080ZZZZ00P0]KFe0;Rh^02EUID0UIFE09ZJVP2HV9P0XJ6Q0?7alA/0moOg9`3oool002D0oooo
00<0lO7a0?Ogm`3gmoL05`3gmoL20=;BdP080;^k^`2ZZZX0XJ6Q09>CT`2GUiL0WIfM0;Ng]`39bLT2
0<o?c`030=[JfP3GemL0h>3P0080h>3P00<0f][J0>3Ph03Ph>00103Ph>001@3Jf]X0emOG0=[JfP3<
c<`0emOG0080clo?00D0a/K60<g=c@3<c<`0bLW90<c<c0020=[JfP<0h>3P0`3Jf]X00`3GemL0clo?
0<C4a0020;^k^`030:f][@2TY:@0Vi^K0080Vi^K00@0Ti>C09FEU@2CTi<0Ti>C0P2KVi/0102TY:@0
/[:b0;Jf]P2f][H20;^k^`80`<3000H0a<C40<30`030`<00^;Rh0;^k^`2f][H30:f][@80ZZZZ0P2T
Y:@0102VYZH0[Jf]0;Ng]`2j^[X209FEU@80Y:BT00<0ZJVY0=[JfP3gmoL06P3gmoLT0?ooo`030?7a
l@3gmoL0moOg01L0moOg0P3@d=00202h^;P0Y:BT09ZJVP2<S8`0TY:B09RHV02e]KD0b<S80P3=cLd0
0`3IfMT0e]KF0=oOg`020=oOg`030=WIf@3Ogml0gmoO00@0gmoO00D0fMWI0=KFeP3IfMT0b/[:0=KF
eP020<g=c@050<C4a03:b/X0b/[:0<S8b03:b/X00P3IfMT30=oOg`<0fMWI00<0e]KF0<g=c@31`L40
0P2h^;P00`2ZZZX0XJ6Q09RHV00209RHV0@0Shn?0P2HV9P0102QXJ40[jn_0;>c/`2c/k<20;Rh^080
_kno00H0`L710;no_`2o_kl0]KFe0;Rh^02c/k<30:ZZZP80YZJV0P2QXJ40102SXj<0ZZZZ0;Fe]@2h
^;P208n?S`80XJ6Q00<0YjNW0=WIf@3gmoL06P3gmoLW0?ooo`009@3ooolI0?Ogm`060>3Ph03=cLd0
f][J0<71`@2a/K40ZZZZ0P2GUiL0202TY:@0^k^k0<o?c`3GemL0clo?0=OGe`3Jf]X0h>3P0P3Jf]X0
1@3Ph>00f][J0=[JfP3Jf]X0h>3P0080f][J0P3GemL01P3Jf]X0clo?0<c<c03?cll0c<c<0<W9b@80
a<C400H0clo?0<W9b@3Jf]X0emOG0=[JfP3Ph>040=[JfP080<o?c`3GemL0cLg=0;^k^`2f][H0[Jf]
0:BTY02MWId209^KV`0:09RHV02KVi/0Y:BT09^KV`2WYjL0Y:BT0:f][@2b/[80^;Rh0;Ng]`80`<30
00L0a<C40;^k^`34a<@0^k^k0<30`02i^KT0^k^k0080/[:b00<0[Jf]0:VYZ@2VYZH0102TY:@00`2]
[Jd0]kNg0;Zj^P0209fMW@040:2PX02ZZZX0ZJVY0;Zj^Q/0moOg903ooolI0?Ogm`060=oOg`3:b/X0
fMWI0;no_`2][Jd0Y:BT0P2BTY80202QXJ40^;Rh0<g=c@3Fe]H0cLg=0=KFeP3IfMT0gmoO0P3IfMT0
1@3Ogml0fMWI0=WIf@3IfMT0gmoO0080fMWI0P3Fe]H01P3IfMT0cLg=0<[:bP3=cLd0b/[:0<S8b080
`L7100H0cLg=0<S8b03IfMT0e]KF0=WIf@3Ogml40=WIf@080<g=c@3Fe]H0b/[:0;Rh^02c/k<0ZZZZ
0:6QX@2KVi/209RHV00809FEU@2HV9P0XJ6Q09RHV02TY:@0XJ6Q0:ZZZP2_[jl20;Fe]@80_kno00L0
`L710;Rh^031`L40^;Rh0;no_`2e]KD0^;Rh0080[jn_00<0ZZZZ0:NWY`2SXj<0102QXJ400`2ZZZX0
]KFe0;Rh^00209RHV00409ZJVP2VYZH0YjNW0;Rh^1/0moOg9`3oool002D0oooo6@3gmoL03@3Bd]80
a<C40=[JfP3=cLd0/K6a0:RXZ02EUID0Ti>C0:BTY030`<00clo?0<c<c03?cll00P3Jf]X20>3Ph0H0
f][J00<0emOG0<o?c`3?cll00P3GemL00`3?cll0c<c<0<K6aP020<W9b@040<C4a036a/H0a<C40<o?
c`@0emOG0`3Jf]X20=OGe`080=[JfP34a<@0][Jf0;6a/@2][Jd0Y:BT09fMW@2TY:@209^KV`80X:2P
00<0WIfM0:BTY02WYjL00P2b/[800`2f][H0`<300<30`0020<C4a0060<30`02k^k/0^k^k0;Jf]P2i
^KT0/[:b0P2][Jd01P2XZ:P0[Jf]0:RXZ02TY:@0YZJV0:BTY080YZJV00T0]kNg0;Zj^P2YZJT0Z:RX
0:NWY`2][Jd0Y:BT0:JVYP3oool06P3gmoLT0?oooaT0moOg00H0d=3@0<71`@3IfMT0b/[:0:f][@2S
Xj<208n?S`050:6QX@2o_kl0cLg=0<[:bP3=cLd00P3IfMT20=oOg`H0fMWI00<0e]KF0<g=c@3=cLd0
0P3Fe]H00`3=cLd0b/[:0<C4a0020<S8b0040<71`@34a<@0`L710<g=c@@0e]KF0`3IfMT20=KFeP08
0=WIf@31`L40/k>c0:f][@2ZZZX0XJ6Q09^KV`2QXJ4209RHV080VYZJ00<0Vi^K0:6QX@2TY:@00P2_
[jl00`2c/k<0_kno0;no_`020<71`@060;no_`2h^;P0^;Rh0;>c/`2e]KD0[jn_0P2ZZZX01P2SXj<0
ZZZZ0:>SX`2QXJ40Xj>S0:6QX@80Xj>S00T0]KFe0;Rh^02WYjL0Xj>S0:BTY02ZZZX0XJ6Q0:>SX`3o
ool06P3gmoLW0?ooo`009@3oool;0?Ogm`030?7al@3gmoL0moOg00/0moOg00H0c<c<0;Vi^@3Ph>00
`L710;6a/@2ZZZX209>CT`0309fMW@36a/H0clo?0080emOG0P3Jf]X20>3Ph0D0f][J00@0clo?0=OG
e`3GemL0c<c<103?cll0103=cLd0a/K60<K6aP34a<@20<K6aP070<o?c`3GemL0f][J0=OGe`3Jf]X0
emOG0>3Ph0030=[JfP080=OGe`36a/H0^k^k0;Jf]P2][Jd0Y:BT09^KV`2MWId209^KV`0909fMW@2T
Y:@0Vi^K0:VYZ@2VYZH0/[:b0:f][@2g]kL0`<300080`L7100T0^k^k0<C4a034a<@0/[:b0;Jf]P2k
^k/0^KVi0:f][@2YZJT00P2][Jd00`2ZZZX0Z:RX0:NWY`030:BTY080^[Zj00H0Z:RX0:f][@2XZ:P0
ZJVY09VIV@2PX:0K0?Ogmb@0oooo2`3gmoL00`3alO40moOg0?Ogm`0;0?Ogm`060<[:bP2e]KD0gmoO
0;no_`2][Jd0Y:BT0P2?Shl00`2KVi/0a<C40<g=c@020=KFeP80fMWI0P3Ogml50=WIf@040<g=c@3F
e]H0e]KF0<[:bP@0cLg=00@0b/[:0<C4a034a<@0`L710P34a<@01`3=cLd0e]KF0=WIf@3Fe]H0fMWI
0=KFeP3Ogml00`3IfMT0203Fe]H0a<C40;Rh^02c/k<0ZZZZ0:6QX@2HV9P0Vi^K0P2HV9P0202KVi/0
XJ6Q09RHV02WYjL0Xj>S0:n_[`2ZZZX0]KFe0`2o_kl02@2h^;P0`L710<71`@2_[jl0/k>c0;Rh^02e
]KD0ZZZZ0:NWY`020:ZZZP030:JVYP2SXj<0Y:BT00<0XJ6Q0P2h^;P01P2SXj<0ZZZZ0:>SX`2WYjL0
UIFE09ZJVQ/0moOg9`3oool002D0oooo603gmoL03`3Jf]X0/K6a0;^k^`2VYZH0Y:BT06a/K021PH40
UIFE08Z:RP2MWId0a/K60<c<c03?cll0f][J0=OGe`080=[JfP030=OGe`3?cll0clo?0080bLW900H0
a/K60<W9b@34a<@0`<300<W9b@36a/H20<o?c`030<c<c03GemL0emOG0080f][J0P3GemL40=[JfP06
0=OGe`3<c<`0^k^k0;Rh^02][Jd0Y:BT0P2MWId409^KV`80Y:BT0P2ZZZX02@2b/[80^k^k0;^k^`2k
^k/0`<300;^k^`30`<00^k^k0;Jf]P020;Ng]`<0/[:b00@0ZZZZ0:f][@2XZ:P0YZJV0`2TY:@01@2Y
ZJT0^[Zj0;Zj^P21PH40UIFE0080/[:b00<0WIfM0:6QX@39bLT06P3gmoLT0?oooaP0moOg00l0fMWI
0:f][@2h^;P0Xj>S0:6QX@1XJ6P0OGem08n?S`26QXH0Vi^K0<C4a03:b/X0cLg=0=WIf@3Fe]H0203I
fMT00`3Fe]H0cLg=0<g=c@020<S8b0060<C4a038b<P0`L710;no_`38b<P0a<C40P3=cLd00`3:b/X0
e]KF0=KFeP020=WIf@80e]KF103IfMT01P3Fe]H0b/[:0;Rh^02e]KD0ZZZZ0:6QX@80Vi^K102HV9P2
0:6QX@80YZJV00T0[jn_0;Rh^02h^;P0^;Rh0;no_`2h^;P0_kno0;Rh^02c/k<00P2e]KD30:n_[`04
0:JVYP2ZZZX0Xj>S0:>SX`<0XJ6Q00D0YjNW0;Rh^02h^;P0MgMg08n?S`020:n_[`0309RHV02JVYX0
b<S801X0moOg9`3oool002D0oooo5`3gmoL0303Ph>00d];B0:6QX@2EUID0/K6a04=3@`1QHF40NGUi
071`L020P800ZJVY0<W9b@80clo?203Jf]X01@3GemL0bLW90<o?c`39bLT0a<C400<0a/K600D0clo?
0<;2`P36a/H0bLW90<30`0020<o?c`030<K6aP3Jf]X0clo?00<0f][J00<0emOG0=[JfP3Jf]X00P3J
f]X01P3?cll0bLW90;^k^`2b/[80ZZZZ09fMW@<0Vi^K00<0VIVI09^KV`2TY:@00P2VYZH01@2ZZZX0
/[:b0;Jf]P2h^;P0^k^k0080][Jf0P2h^;P0102g]kL0/[:b0;Rh^02f][H40;:b/P030:VYZ@2TY:@0
X:2P0080Y:BT0P2VYZH01`2][Jd0]kNg07emO@21PH40X:2P0:VYZ@2WYjL00P2JVYXJ0?Ogmb@0oooo
5`3gmoL0303Ogml0d=3@09ZJVP2?Shl0[Jf]03hn?P1LG5`0M7Ad06][J`1mOGd0YjNW0<S8b080cLg=
203IfMT01@3Fe]H0b<S80<g=c@38b<P0`L7100<0a<C400D0cLg=0<71`@34a<@0b<S80;no_`020<g=
c@030<C4a03IfMT0cLg=00<0fMWI00<0e]KF0=WIf@3IfMT00P3IfMT01P3=cLd0b<S80;Rh^02_[jl0
YZJV09^KV`<0V9RH00<0UIFE09RHV02QXJ400P2SXj<01@2VYZH0[jn_0;>c/`2e]KD0^;Rh0080/k>c
0`2e]KD00`2_[jl0]KFe0;>c/`040:n_[`030:NWY`2QXJ40VYZJ0080XJ6Q0P2SXj<01`2][Jd0]KFe
07MgM`1gMgL0VYZJ0:NWY`2TY:@00P2EUIDJ0?OgmbL0oooo000U0?oooaH0moOg00d0oooo0<g=c@34
a<@0ZZZZ07AdM01SHf<0Y:BT065QH@1MGEd0I6AT07EeM@2TY:@0clo?0080emOG103Jf]X00`3GemL0
f][J0=[JfP030=[JfP0?0=OGe`3Jf]X0f][J0=[JfP3GemL0f][J0<o?c`30`<00^k^k0;Vi^@2k^k/0
`<300<W9b@36a/H0c<c<0080clo?00<0f][J0=OGe`3GemL00P3Jf]X0203GemL0clo?0<o?c`34a<@0
][Jf0:f][@2TY:@0X:2P0P2KVi/00`2CTi<0V9RH09fMW@020:BTY0040:JVYP2][Jd0/[:b0;:b/P80
][Jf0P2g]kL01@2f][H0/[:b0;Jf]P2g]kL0][Jf0080/[:b00H0ZJVY0;:b/P2b/[80[Jf]0:VYZ@2V
YZH20:BTY080YZJV00X0[Jf]0;Zj^P21PH40PH6109VIV@2WYjL0ZJVY0:f][@2MWId0lO7a6@3gmoLT
0?oooaH0moOg00d0oooo0<[:bP31`L40Y:BT06i^KP1LG5`0XJ6Q05aLG01IFET0GemO075aL@2QXJ40
cLg=0080e]KF103IfMT00`3Fe]H0fMWI0=WIf@030=WIf@0?0=KFeP3IfMT0fMWI0=WIf@3Fe]H0fMWI
0<g=c@2o_kl0^;Rh0;Fe]@2h^;P0_kno0<S8b034a<@0b/[:0080cLg=00<0fMWI0=KFeP3Fe]H00P3I
fMT0203Fe]H0cLg=0<g=c@31`L40/k>c0:ZZZP2QXJ40VYZJ0P2HV9P00`2?Shl0UIFE09^KV`020:6Q
X@040:>SX`2ZZZX0[jn_0:n_[`80/k>c0P2e]KD01@2c/k<0[jn_0;>c/`2e]KD0/k>c0080[jn_00H0
YjNW0:n_[`2_[jl0ZZZZ0:NWY`2SXj<20:6QX@80Xj>S00X0[Jf]0;Rh^01mOGd0MgMg09FEU@2TY:@0
YjNW0:ZZZP2HV9P0lO7a6@3gmoLW0?ooo`009@3ooolG0?Ogm`0=0<g=c@2i^KT0/K6a065QH@1mOGd0
RXZ:05eMG@1EEED0BTY:07EeM@2MWId0bLW90=OGe`040=[JfP050=OGe`3Jf]X0emOG0=[JfP3?cll0
1P3Jf]X01@3GemL0clo?0<c<c036a/H0^k^k0080^;Rh00H0/[:b0;Rh^036a/H0`/;20<o?c`3GemL2
0=[JfP030=OGe`3Jf]X0f][J0080emOG00P0clo?0<71`@2f][H0[Jf]09fMW@2KVi/0VIVI09^KV`80
Ti>C00H0WIfM0:BTY02TY:@0ZJVY0;:b/P2][Jd20;:b/P0N0;Jf]P2h^;P0^;Rh0;Rh^02f][H0[Jf]
0;:b/P2f][H0/[:b0:f][@2ZZZX0[Jf]0:VYZ@2VYZH0ZJVY0:NWY`2TY:@0WIfM0:BTY02YZJT0^[Zj
0:VYZ@21PH40Shn?09FEU@2IVIT0Z:RX0:VYZ@2QXJ40j>SX6@3gmoLT0?oooaL0moOg00d0b/[:0;Fe
]@2][Jd0G5aL07MgM`26QXH0FEUI051@D017AdL0LG5a09^KV`38b<P0e]KF00@0fMWI00D0e]KF0=WI
f@3Fe]H0fMWI0<g=c@060=WIf@050=KFeP3=cLd0b/[:0<C4a02h^;P00P2e]KD01P2_[jl0]KFe0<C4
a031`L40cLg=0=KFeP80fMWI00<0e]KF0=WIf@3IfMT00P3Fe]H0103=cLd0_kno0;>c/`2ZZZX209RH
V00509FEU@2HV9P0Shn?08n?S`2KVi/00P2QXJ400`2WYjL0[jn_0:ZZZP020:n_[`0N0;>c/`2e]KD0
]KFe0;Fe]@2c/k<0ZZZZ0:n_[`2c/k<0[jn_0:ZZZP2VYZH0ZZZZ0:NWY`2SXj<0YjNW0:BTY02QXJ40
Vi^K0:6QX@2WYjL0^;Rh0:NWY`1mOGd0RHV908n?S`2EUID0Xj>S0:NWY`2JVYX0j>SX6@3gmoLW0?oo
o`009@3ooolF0?Ogm`0>0?7al@2i^KT0XJ6Q0<71`@12@T80NGUi02@T901KFe/0HV9R05iNGP1SHf<0
WIfM0<o?c`3GemL30=[JfP070=OGe`3?cll0emOG0=[JfP3?cll0bLW90=OGe`070=[JfP030<o?c`3<
c<`0a/K60080`<3000H0/[:b0:f][@2][Jd0[Jf]0<K6aP3?cll60=[JfP060<o?c`39bLT0`L710;6a
/@2][Jd0Y:BT0P2KVi/00`2EUID0Ti>C09^KV`0209fMW@050:JVYP2WYjL0[Jf]0:VYZ@2][Jd01P2b
/[800`2VYZH0ZJVY0;:b/P030;:b/P<0ZJVY00X0YjNW0:BTY02TY:@0Y:BT09fMW@2YZJT0]kNg0:VY
Z@21PH40K6a/0P1TI6@0101dM7@0X:2P0:JVYP36a/HI0?Ogmb@0oooo5P3gmoL03P3alO40]KFe09ZJ
VP2o_kl0>c/k07AdM00M7Ad0EUIF05mOG`1LG5`0HV9R09^KV`3=cLd0e]KF0`3IfMT01`3Fe]H0cLg=
0=KFeP3IfMT0cLg=0<S8b03Fe]H01`3IfMT00`3=cLd0b/[:0<C4a0020;no_`060:n_[`2ZZZX0ZZZZ
0:ZZZP34a<@0cLg=1P3IfMT01P3=cLd0b<S80;no_`2][Jd0ZZZZ0:6QX@80V9RH0P2?Shl0202HV9P0
Vi^K09^KV`2SXj<0Y:BT0:ZZZP2WYjL0ZZZZ1P2_[jl00`2SXj<0YjNW0:n_[`030:n_[`<0YjNW00X0
Y:BT0:6QX@2QXJ40XJ6Q09^KV`2WYjL0]KFe0:NWY`1mOGd0IFEU0P1IFET0101XJ6P0VYZJ0:>SX`34
a<@I0?OgmbL0oooo000U0?oooaH0moOg00d0j>SX0:6QX@2LW9`0a/K605]KF`0k>c/0De=C04Q8B00/
;2`0BTY:05iNGP2LW9`0clo?00<0emOG00h0clo?0=[JfP3Jf]X0emOG0=[JfP3?cll0bLW908>3P`2b
/[80]kNg0:NWY`2HV9P0Vi^K09RHV080VYZJ0P2CTi<0202KVi/0YZJV0:f][@2ZZZX0Z:RX0:f][@2b
/[80`/;21P3Jf]X01P3?cll0bLW90;Vi^@2f][H0[Jf]09^KV`80VIVI00<0UIFE09RHV02HV9P0102K
Vi/00`2MWId0YZJV0:BTY0030:VYZ@040;:b/P2g]kL0]kNg0:VYZ@80/[:b0P2g]kL00`2b/[80ZJVY
0:VYZ@020:VYZ@080:NWY`2VYZH0WIfM0:JVYP2YZJT0Y:BT0:VYZ@26QXH206a/K00506ATI01/K6`0
PH610:RXZ02h^;P06@3gmoLT0?oooaH0moOg00d0j>SX09ZJVP2BTY80a<C405IFEP0i>CT0CDe=04A4
A00Y:BT0AdM705aLG02JVYX0cLg=00<0e]KF00h0cLg=0=WIf@3IfMT0e]KF0=WIf@3=cLd0b<S80820
P02_[jl0]KFe0:BTY02EUID0V9RH09FEU@80V9RH0P2?Shl0202HV9P0Xj>S0:ZZZP2VYZH0Xj>S0:ZZ
ZP2_[jl0`L711P3IfMT01P3=cLd0b<S80;Fe]@2c/k<0ZZZZ09RHV080UIFE00<0Shn?09FEU@2EUID0
102HV9P00`2KVi/0Xj>S0:6QX@030:NWY`040:n_[`2e]KD0]KFe0:NWY`80[jn_0P2e]KD00`2_[jl0
YjNW0:NWY`020:NWY`0?0:BTY02SXj<0Vi^K0:>SX`2WYjL0Xj>S0:NWY`23Ph<0IFEU069RHP1IFET0
GemO07MgM`2SXj<0]KFe01T0moOg9`3oool002D0oooo5P3gmoL03P3GemL0XJ6Q09bLW031`L40D51@
01PH600^;Rh04a<C020P800k>c/0BTY:0:f][@3?cll0emOG0P3?cll20=OGe`0D0=[JfP3?cll0clo?
0<W9b@2WYjL0]kNg05EEE@1CDe<0BTY:06a/K02:RXX0Vi^K07=cL`1eMGD0K6a/07EeM@26QXH0OGem
09RHV02MWId209^KV`040;^k^`34a<@0clo?0=OGe`D0f][J00/0clo?0<K6aP2a/K40Z:RX0:2PX02K
Vi/0UIFE09>CT`2:RXX0V9RH09FEU@0209fMW@090:JVYP2TY:@0Vi^K0:2PX02MWId0Vi^K0:BTY02V
YZH0ZJVY0080/[:b00`0]kNg0;:b/P2g]kL0/[:b0:VYZ@2b/[80ZJVY0:JVYP2TY:@0ZJVY09fMW@2T
Y:@20:JVYP80ZJVY00T0Ph>3071`L01/K6`0I6AT06a/K01dM7@0VYZJ0;:b/P3alO40603gmoLT0?oo
oaH0moOg00h0e]KF09ZJVP2BTY80_kno04Y:BP0B4Q80:BTY018B4P0N7Qh0>CTi04M7A`2][Jd0cLg=
0=KFeP80cLg=0P3Fe]H0303IfMT0cLg=0<g=c@38b<P0Y:BT0;Fe]@1@D500CDe=04M7A`1XJ6P0QXJ6
09RHV080LG5a00D0J6QX075aL@23Ph<0MgMg09FEU@0309RHV0040;Rh^031`L40cLg=0=KFePD0fMWI
00H0cLg=0<C4a02][Jd0Xj>S09ZJVP2HV9P208n?S`0308J6QP2EUID0Shn?0080Vi^K00@0Xj>S0:6Q
X@2HV9P0VYZJ0P2HV9P00`2QXJ40Xj>S0:NWY`020:n_[`0<0;Fe]@2_[jl0]KFe0:n_[`2WYjL0[jn_
0:NWY`2SXj<0XJ6Q0:NWY`2KVi/0XJ6Q0P2SXj<20:NWY`090820P01[Jf/0HV9R05UIF@1OGel0J6QX
09FEU@2_[jl0lO7a01P0moOg9`3oool002D0oooo5P3gmoL03039bLT0W9bL0:6QX@3<c<`0=cLg00@4
100C4a<0820P02`/;00a<C40FUYJ09bLW0<0emOG00<0clo?0=;BdP3Bd]800`3GemL20<o?c`0?08n?
S`2b/[80WIfM04Q8B023Ph<0^k^k0;Fe]@12@T80[Jf]00`<300`<300De=C0492@P21PH40M7Ad0080
K6a/00@0I6AT08n?S`34a<@0bLW90`3Jf]X03`3Ph>00f][J0<o?c`31`L40^k^k0:f][@2PX:00VIVI
08^;R`2:RXX0R8R808Z:RP2;Rh/0YZJV0:VYZ@050;:b/P080:f][@2YZJT0ZJVY0:JVYP2TY:@0WIfM
0:NWY`2YZJT20;Ng]`0:0;:b/P2YZJT0ZJVY0:VYZ@2MWId0Y:BT09fMW@2TY:@0W9bL0:JVYP80ZJVY
00T0QXJ607AdM01/K6`0K6a/07AdM021PH40VYZJ0:f][@3[jn/0603gmoLT0?oooaH0moOg00`0b<S8
09:BTP2JVYX0b/[:038b<P030`<04Q8B01hN7P0Y:BT0;bl_05UIF@2JVYX30=KFeP030<g=c@3@d=00
d=3@00<0e]KF0P3=cLd05@29RHT0[jn_09^KV`14A4@0P8200;^k^`2e]KD0>c/k0:f][@0;2`/0;2`/
04e=C@0k>c/0OGem06i^KP1UIFD0HV9R05UIF@29RHT0`L710<S8b0030=WIf@0?0=oOg`3IfMT0cLg=
0;no_`2h^;P0ZZZZ09ZJVP2EUID0RHV908J6QP23Ph<0QXJ608V9R@2SXj<0YjNW00D0[jn_00P0ZZZZ
0:NWY`2WYjL0Xj>S0:6QX@2KVi/0Y:BT0:NWY`80]KFe00X0[jn_0:NWY`2WYjL0YjNW09^KV`2QXJ40
Vi^K0:6QX@2JVYX0Xj>S0P2WYjL02@23Ph<0KVi^069RHP1RHV80J6QX07MgM`2EUID0ZZZZ0>_[j`0H
0?OgmbL0oooo000U0?ooo`030?Ogm`3alO40moOg01<0moOg00L0cLg=09bLW02GUiL0c<c<03Ti>@04
10@06a/K0080;2`/00H0>c/k04Y:BP2YZJT0emOG0=[JfP3GemL20<o?c`030<W9b@3?cll0emOG00<0
clo?01H0Vi^K0;Zj^P2g]kL0WIfM04=3@`24Q8@0UIFE05=CD`2f][H030`<02`/;01CDe<0Fe]K0:BT
Y02;Rh/0PH6105]KF`1eMGD0Shn?0<C4a03Bd]80f][J0P3Ph>020=[JfP0@0=OGe`34a<@0][Jf0:f]
[@2WYjL0Ti>C09FEU@2HV9P0PH6108Z:RP2HV9P0ZJVY0;Ng]`2b/[80]kNg0<30`080^[Zj00H0]kNg
0;:b/P2YZJT0/[:b0:f][@2TY:@80:VYZ@030:BTY02WYjL0Y:BT0080YZJV0P2YZJT00`2VYZH0P820
06a/K00306a/K0040861P@2JVYX0[Jf]0?7alAP0moOg903oool00`3gmoL0lO7a0?Ogm`0C0?Ogm`07
0<[:bP2BTY80SXj>0<[:bP0e=CD00`<301/K6`0202TY:@0603Ti>@17AdL0YjNW0=KFeP3IfMT0e]KF
0P3=cLd00`38b<P0cLg=0=KFeP030<g=c@0F09RHV02h^;P0]KFe09^KV`12@T80Ph>309FEU@1=CDd0
]KFe00/;2`0Y:BT0CDe=05=CD`2SXj<0RHV907emO@1FEUH0LG5a08V9R@31`L40d=3@0=WIf@80gmoO
0P3IfMT01@3Fe]H0`L710;>c/`2ZZZX0Y:BT0080Shn?00T0UIFE07emO@26QXH0UIFE0:NWY`2e]KD0
[jn_0;Fe]@2o_kl00P2h^;P01P2e]KD0[jn_0:NWY`2_[jl0ZZZZ0:6QX@P0YjNW00<0XJ6Q0:BTY02Q
XJ400P2SXj<20:NWY`040:>SX`1mOGd0IFEU06EUI@80HV9R00@0MgMg09FEU@2ZZZX0lO7a603gmoLW
0?ooo`009@3ooolE0?Ogm`0>09FEU@3=cLd0QhN708V9R@2f][H0QXJ601/K6`0<30`0820P01/K6`0a
<C40K6a/0;Ng]`3?cll20=OGe`0G0<o?c`3GemL0emOG0<o?c`3GemL0f][J0<o?c`3GemL0clo?0;:b
/P2KVi/0emOG0;:b/P2HV9P0Lg=c03Lg=`1MGEd0000002@T900i>CT0@d=309jNWP2;Rh/00P1/K6`0
102EUID0^KVi0<W9b@3?cll20=[JfP<0h>3P00L0emOG0<C4a02i^KT0[Jf]0:2PX02EUID0R8R80080
OGem00/0Bd];06a/K02TY:@0ZJVY0;Ng]`2VYZH0Vi^K09RHV02;Rh/0RXZ:08^;R`030:VYZ@040:NW
Y`2YZJT0WIfM0:NWY`80ZJVY0P2WYjL02@2YZJT0Vi^K0:NWY`2MWId0Y:BT0:NWY`2YZJT0WIfM09^K
V`0206a/K007071`L01/K6`0OGem092@T02TY:@0[Jf]0>_[j`0H0?Ogmb@0oooo5@3gmoL03P2EUID0
b/[:07emO@20P800/k>c08>3P`0K6a/02`/;01hN7P0K6a/0;bl_06][J`2e]KD0cLg=0P3Fe]H07@3=
cLd0e]KF0=KFeP3=cLd0e]KF0=WIf@3=cLd0e]KF0<g=c@2_[jl0V9RH0=KFeP2_[jl0UIFE075aL@0b
<S80G5aL0000000T92@0>3Ph03hn?P2MWId0RHV906QXJ01RHV80Shn?0;Fe]@38b<P0cLg=0080fMWI
0`3Ogml01`3Fe]H0`L710;Fe]@2ZZZX0VYZJ08n?S`23Ph<00P1gMgL02`0n?Sh0IFEU0:6QX@2WYjL0
]KFe0:>SX`2HV9P0UIFE08V9R@26QXH0RHV900<0YjNW00@0Y:BT0:NWY`2KVi/0Y:BT0P2WYjL20:BT
Y0090:NWY`2HV9P0Y:BT09^KV`2QXJ40Y:BT0:NWY`2KVi/0V9RH0080J6QX00L0Jf][06EUI@1gMgL0
RHV90:6QX@2ZZZX0jn_[01P0moOg9`3oool002D0oooo103gmoL00`3alO40moOg0?Ogm`0<0?Ogm`0?
0?7al@2NWYh0@T920<C4a027QhL0Shn?0<C4a02k^k/010@402XZ:P0/;2`092@T02`/;01NGUh0]kNg
00@0clo?0P3GemL00`3?cll0emOG0=OGe`020=[JfP0>0<o?c`39bLT0`<300:NWY`3GemL0[Jf]08^;
R`1bLW80Cdm?04Q8B00g=cL0@d=303/k>`1KFe/307emO@050:RXZ02b/[80`<300<o?c`3Jf]X0103P
h>004P3?cll0a<C40;Vi^@2][Jd0X:2P09FEU@28R8P0V9RH07emO@1SHf<0@41008N7Q`2;Rh/0VYZJ
08N7Q`1eMGD0K6a/06ATI080Lg=c0P1/K6`02021PH40VYZJ09RHV02HV9P0Vi^K09fMW@2WYjL0Vi^K
0P2WYjL00`2KVi/0V9RH09fMW@0209fMW@040:JVYP2HV9P0V9RH05eMG@<0I6AT00D0Shn?09FEU@2X
Z:P0Z:RX0>_[j`0H0?Ogmb@0oooo103gmoL00`3alO40moOg0?Ogm`0<0?Ogm`090?7al@2MWId0>c/k
0<71`@1mOGd0QXJ60<71`@2h^;P00`<30080:BTY00@092@T02TY:@1LG5`0]KFe103=cLd20=KFeP03
0<g=c@3Fe]H0e]KF0080fMWI00h0cLg=0<S8b02o_kl0Y:BT0=KFeP2][Jd0RHV9075aL@1=CDd0A4A4
038b<P0n?Sh0>CTi05IFEP<0MgMg00D0Xj>S0:n_[`2o_kl0cLg=0=WIf@040=oOg`0B0<g=c@31`L40
]KFe0:ZZZP2JVYX0Shn?08>3P`2EUID0MgMg05aLG00e=CD0QXJ608V9R@2HV9P0QXJ6075aL@1XJ6P0
GemO0P1aLG4206QXJ00807emO@2HV9P0UIFE09FEU@2HV9P0Vi^K0:BTY02HV9P20:BTY00309RHV02E
UID0Vi^K0080Vi^K00@0Xj>S09FEU@2EUID0FEUI0`1OGel01@29RHT0Shn?0:>SX`2SXj<0jn_[01P0
moOg9`3oool002D0oooo4P3gmoL01@3Xj>P0=cLg020P800T92@0^KVi0080cLg=00X0][Jf0:ZZZP0C
4a<0:RXZ034a<@0P8200;Rh^05iNGP2g]kL0d];B103?cll01`39bLT0emOG0<o?c`3?cll0emOG0=[J
fP3GemL00P3?cll04`39bLT0[Jf]0:NWY`30`<00WIfM0:NWY`1eMGD0NGUi06a/K01TI6@0OGem08R8
R01mOGd0X:2P0;Vi^@2a/K40bLW90<o?c`3Jf]X0103Ph>00603?cll0a<C40;^k^`2][Jd0Vi^K09FE
U@28R8P0PH6108Z:RP1mOGd0K6a/07=cL`2][Jd0b<S809FEU@10@400=cLg02h^;P12@T80>c/k06a/
K01`L700GEeM05]KF`80Ph>300P0QXJ608>3P`26QXH0RXZ:08^;R`2HV9P0WIfM0:BTY080WIfM0P2Y
ZJT02`2CTi<0Rh^;05EEE@1JFUX0GUiN05EEE@2:RXX0X:2P0:RXZ02JVYX0f][J01P0moOg903ooolB
0?Ogm`050>SXj00b<S807QhN01dM7@2e]KD00P3:b/X02P2c/k<0YZJV018B4P0Y:BT0;bl_01hN7P0Y
:BT0G5aL0;Fe]@3@d=040<g=c@070<S8b03Fe]H0cLg=0<g=c@3Fe]H0fMWI0=KFeP020<g=c@0C0<S8
b02ZZZX0Y:BT0;no_`2KVi/0Y:BT075aL@1dM7@0J6QX05mOG`1gMgL0Ph>307MgM`2JVYX0]KFe0:f]
[@38b<P0cLg=0=WIf@040=oOg`0H0<g=c@31`L40^;Rh0:ZZZP2HV9P0Shn?08>3P`1mOGd0QXJ607Mg
M`1UIFD0LG5a0:f][@38b<P0UIFE03De=@0b<S80:BTY03/k>`0i>CT0J6QX06][J`1IFET0EUIF0P20
P8002023Ph<0P82008>3P`26QXH0RHV909FEU@2KVi/0XJ6Q0P2KVi/20:NWY`0;08n?S`29RHT0D51@
05UIF@1LG5`0D51@08J6QP2JVYX0Xj>S09FEU@3IfMT0603gmoLW0?ooo`009@3oool00`3gmoL0lO7a
0?Ogm`020?7al@030?Ogm`3alO40moOg00X0moOg00D0/;2`020P800T92@0820P0;6a/@020<g=c@0@
0;6a/@2TY:@0<30`04=3@`0Y:BT04a<C020P801RHV80^[Zj0<o?c`3<c<`0emOG0<o?c`3GemL0^k^k
0<o?c`80emOG0P3Jf]X04@3GemL0f][J0<o?c`3?cll0^k^k0:VYZ@2][Jd0ZJVY0;:b/P2;Rh/0Ti>C
08R8R01mOGd0R8R807emO@2?Shl0Z:RX0080][Jf00@0a/K60<W9b@3GemL0h>3P0P3Xj>P02P3Jf]X0
d];B0<W9b@2k^k/0[Jf]0:2PX02EUID0R8R80861P@2:RXX207emO@0805]KF`24Q8@0dm?C05eMG@24
Q8@0;2`/01DE5@18B4P205YJFP0L06=SH`1QHF40>c/k06a/K01eMGD0Lg=c06ATI01iNGT0RXZ:09FE
U@2KVi/0WIfM0:NWY`2MWId0YjNW0:VYZ@2WYjL0Rh^;08>3P`1EEED0B4Q805iNGP1MGEd0UIFE0:RX
Z02EUID0UiNG0<C4a1P0moOg903oool00`3gmoL0lO7a0?Ogm`020?7al@030?Ogm`3alO40moOg00X0
moOg00D0/;2`01hN7P0M7Ad06a/K0:f][@020<[:bP0@0:f][@2QXJ40;2`/0492@P0Y:BT04Q8B01hN
7P1OGel0^;Rh0<g=c@3:b/X0e]KF0<g=c@3Fe]H0^;Rh0<g=c@80e]KF0P3IfMT04@3Fe]H0fMWI0<g=
c@3=cLd0^;Rh0:NWY`2ZZZX0YjNW0:n_[`29RHT0Shn?08>3P`1gMgL0Ph>307MgM`29RHT0Xj>S0080
/k>c00@0a<C40<S8b03Fe]H0gmoO0P3Xj>P02P3IfMT0d=3@0<S8b02h^;P0ZZZZ09ZJVP2?Shl0Ph>3
07emO@26QXH207MgM`0805IFEP23Ph<0dm?C05aLG023Ph<0:BTY01DE5@14A4@205UIF@04069RHP1L
G5`0>CTi06QXJ080LG5a01H0GemO07AdM026QXH0Shn?09RHV02KVi/0Y:BT09^KV`2TY:@0YjNW0:BT
Y029RHT0P820051@D014A4@0G5aL05UIF@2?Shl0Xj>S08n?S`2>SXh0a<C4603gmoLW0?ooo`009@3o
oolA0?Ogm`060=cLg00a<C40820P020P800H61P0@T920P2QXJ402@1dM7@0B4Q803Ti>@0T92@0820P
01/K6`0/;2`0K6a/0<W9b@020<o?c`0:0=OGe`3Jf]X0f][J0<30`02CTi<0a<C40<W9b@3Jf]X0emOG
0=[JfP80h>3P00P0f][J0<o?c`39bLT0a/K60;^k^`2i^KT0[Jf]0:RXZ080YjNW0`2XZ:P01P2a/K40
^k^k0<W9b@3<c<`0emOG0=[JfP<0h>3P01T0f][J0<o?c`39bLT0^k^k0;:b/P2TY:@0Ti>C08R8R02:
RXX0V9RH08n?S`1dM7@0Rh^;09>CT`21PH40BTY:0:BTY00Y:BT05ADE04Q8B013@d<0GEeM08B4Q01d
M7@0=SHf0080>c/k00H0@d=306a/K026QXH0RXZ:09VIV@2WYjL20:VYZ@0?0:NWY`2MWId0ZJVY0:NW
Y`23Ph<0HV9R04];B`18B4P0<C4a03Lg=`2EUID0[Jf]07AdM02?Shl0`/;201P0moOg903ooolA0?Og
m`060=cLg00_;bl06a/K01hN7P0B4Q80>c/k0P2JVYX02@1^KVh0A4A403Ph>00T92@07QhN01/K6`0Y
:BT0Jf][0<S8b0020<g=c@0:0=KFeP3IfMT0fMWI0;no_`2?Shl0`L710<S8b03IfMT0e]KF0=WIf@80
gmoO00P0fMWI0<g=c@38b<P0a<C40;Rh^02e]KD0ZZZZ0:>SX`80Y:BT0`2SXj<01P2][Jd0^;Rh0<S8
b03:b/X0e]KF0=WIf@<0gmoO01T0fMWI0<g=c@38b<P0^;Rh0:n_[`2QXJ40Shn?08>3P`26QXH0UIFE
08V9R@1^KVh0RHV908n?S`1mOGd0AdM70:BTY00Y:BT05ADE04M7A`0n?Sh0G5aL08>3P`1dM7@0=CDe
0080>CTi00H0?Shn06QXJ023Ph<0QXJ609FEU@2TY:@20:NWY`0?0:BTY02KVi/0YjNW0:BTY020P800
GemO04Y:BP14A4@0;bl_038b<P2?Shl0ZZZZ06QXJ023Ph<0`L7101P0moOg9`3oool002D0oooo4@3g
moL01@2EUID0;2`/034a<@0/;2`061PH00806a/K00D061PH03Ti>@0k>c/06a/K02`/;00201/K6`03
02`/;01eMGD0^[Zj0080clo?00D0c<c<0=OGe`3Jf]X0clo?0:ZZZP020:VYZ@030<K6aP3Jf]X0h>3P
0080h>3P0P3Jf]X20<o?c`050<W9b@2k^k/0[Jf]0:f][@2b/[800P2][Jd0202XZ:P0[Jf]0:f][@2k
^k/0bLW90<o?c`39bLT0f][J0`3Ph>002P3Jf]X0emOG0<W9b@2k^k/0]kNg0:VYZ@2IVIT0UIFE08Z:
RP2?Shl209RHV00909VIV@2YZJT0Rh^;09>CT`1;Bd/0<30`00`<300T92@0<30`0080Cdm?0P0i>CT2
05iNGP0G0861P@2:RXX0RXZ:09^KV`2WYjL0VIVI09^KV`2YZJT0YZJV0:VYZ@2TY:@0WIfM07EeM@1:
BTX0B4Q803/k>`0/;2`0>c/k09^KV`2VYZH0M7Ad092@T03?cll0603gmoLT0?oooa40moOg00D0UIFE
02TY:@0_;bl0:BTY018B4P0200l?3`05018B4P0h>3P0>CTi01/K6`0Y:BT00P0K6a/00`0Y:BT0LG5a
0;Rh^0020<g=c@050<[:bP3Fe]H0fMWI0<g=c@2VYZH00P2WYjL00`34a<@0fMWI0=oOg`020=oOg`80
fMWI0P3=cLd01@38b<P0^;Rh0:ZZZP2ZZZX0[jn_0080ZZZZ00P0Xj>S0:ZZZP2ZZZX0^;Rh0<S8b03=
cLd0b<S80=WIf@<0gmoO00X0fMWI0=KFeP38b<P0^;Rh0;Fe]@2WYjL0UIFE08n?S`26QXH0RHV90`2E
UID0202WYjL0RHV908n?S`1:BTX0;2`/00/;2`0M7Ad0;2`/0P1=CDd203Ph>080G5aL01L0OGem08J6
QP26QXH0V9RH0:BTY02EUID0V9RH0:NWY`2SXj<0YjNW0:6QX@2KVi/0LG5a04M7A`14A4@0>CTi02TY
:@0i>CT0V9RH0:>SX`1XJ6P0RHV90<g=c@0H0?OgmbL0oooo000U0?oooa40moOg00H0Hf=S020P800a
<C40=cLg020P800T92@201PH6005034a<@0P82006a/K020P800E5AD00P0P8200101/K6`0`<300<W9
b@3?cll20=OGe`030<o?c`3Jf]X0clo?0080Vi^K00@0/[:b0:VYZ@3Jf]X0j>SX0P3Ph>020=[JfP03
0<o?c`39bLT0^k^k0080/[:b00L0]kNg0:f][@2PX:00VYZJ09FEU@2XZ:P0^k^k0080a/K601<0clo?
0=[JfP3Ph>00h>3P0=[JfP3GemL0clo?0;^k^`30`<00/[:b0:VYZ@2MWId0UIFE08^;R`2HV9P0UIFE
09^KV`2WYjL0R8R80080ZJVY00`0MGEe07=cL`1eMGD0GUiN04=3@`1JFUX0<C4a069RHP23Ph<0NGUi
08J6QP2:RXX409RHV00B0:VYZ@2MWId0WIfM09fMW@2WYjL0Y:BT09RHV01NGUh0B4Q8034a<@13@d<0
<30`03Lg=`2TY:@0UIFE07AdM02JVYX0f][J603gmoLT0?oooa40moOg00H0HV9R01hN7P0_;bl0<S8b
01hN7P0M7Ad2018B4P0502l_;`0N7Qh06a/K01hN7P0E5AD00P0N7Qh0101[Jf/0_kno0<S8b03=cLd2
0=KFeP030<g=c@3IfMT0cLg=0080V9RH00@0[jn_0:NWY`3IfMT0j>SX0P3Ogml20=WIf@030<g=c@38
b<P0^;Rh0080[jn_00L0]KFe0:ZZZP2JVYX0UIFE08n?S`2SXj<0^;Rh0080a<C401<0cLg=0=WIf@3O
gml0gmoO0=WIf@3Fe]H0cLg=0;Rh^02o_kl0[jn_0:NWY`2KVi/0Shn?08V9R@2EUID0Shn?09RHV02T
Y:@0Ph>30080YjNW0`1aLG402@1LG5`0@T9205UIF@0_;bl0GemO0820P01dM7@0Ph>308J6QP0409FE
U@0B0:NWY`2KVi/0Vi^K09^KV`2TY:@0XJ6Q09FEU@1LG5`0A4A402l_;`12@T80;2`/038b<P2QXJ40
Shn?06QXJ02EUID0fMWI603gmoLW0?ooo`009@3ooolA0?Ogm`04034a<@0`<300<30`03/k>`80<30`
0P0/;2`02@0P82006a/K01<C4`0E5AD0;2`/01<C4`0`<300GUiN0;Ng]`030<o?c`070=OGe`3?cll0
emOG0=[JfP36a/H0^;Rh0:JVYP0308N7Q`0309RHV02;Rh/0Rh^;00<0K6a/0P1MGEd0101SHf<0I6AT
05]KF`1`L70207AdM00307emO@2YZJT0^;Rh0080clo?0P3Jf]X02@3GemL0clo?0<o?c`34a<@0bLW9
0;^k^`2g]kL0ZJVY09^KV`0209VIV@0308Z:RP2EUID0V9RH0080YjNW00<0VIVI0:VYZ@2WYjL00P2W
YjL0202HV9P0Ph>30861P@1iNGT0Ph>307UiN@2HV9P0Ti>C0P2KVi/02P2TY:@0X:2P09fMW@2TY:@0
YjNW0:VYZ@2TY:@0YjNW09fMW@23Ph<203/k>`0903Ti>@0/;2`06a/K020P802TY:@0RHV907AdM02]
[Jd0lO7a01P0moOg903ooolA0?Ogm`0402l_;`0/;2`0;2`/03Ti>@80;2`/0P0Y:BT02@0N7Qh06a/K
018B4P0E5AD0:BTY018B4P0/;2`0G5aL0;Fe]@030<g=c@070=KFeP3=cLd0e]KF0=WIf@34a<@0]KFe
0:>SX`0308J6QP0409FEU@29RHT0RHV906QXJ080Jf][0P1IFET205mOG`0705IFEP1[Jf/0KVi^06i^
KP1gMgL0YjNW0;Fe]@020<g=c@80fMWI00T0e]KF0<g=c@3=cLd0`L710<S8b02h^;P0]KFe0:NWY`2H
V9P00P2EUID00`26QXH0Shn?09FEU@020:BTY00309FEU@2WYjL0Y:BT0080Y:BT00P0UIFE0820P01m
OGd0M7Ad0820P01dM7@0UIFE08n?S`80V9RH00X0XJ6Q09ZJVP2KVi/0XJ6Q0:BTY02WYjL0XJ6Q0:BT
Y02KVi/0P8200P0i>CT02@0h>3P0:BTY01PH600K6a/0XJ6Q0820P01XJ6P0ZZZZ0?7al@0H0?OgmbL0
oooo000U0?ooo`030?Ogm`3alO40moOg00<0moOg00<0lO7a0?Ogm`3gmoL0203gmoL00`18B4P0;Rh^
01/K6`03020P8080;2`/00`0820P02XZ:P0E5AD05ADE02`/;00E5AD0;2`/06a/K02YZJT0bLW90=;B
dP3<c<`30=OGe`060=[JfP3GemL0clo?0;Rh^02JVYX0QXJ60P2;Rh/01`27QhL0LW9b079bLP1RHV80
Hf=S05eMG@1SHf<00P1QHF401`1SHf<0L71`06=SH`1iNGT0RXZ:0:f][@30`<000`3?cll03`3Ph>00
d];B0<o?c`39bLT0a<C40<K6aP2k^k/0]kNg0:VYZ@2MWId0UiNG09>CT`2EUID0RXZ:09FEU@040:NW
Y`050:VYZ@2WYjL0YjNW09RHV023Ph<00P26QXH00`1iNGT0RXZ:09RHV00209^KV`050:BTY02MWId0
WIfM0:BTY02WYjL00P2TY:@03`2MWId0Y:BT09fMW@23Ph<0@d=302`/;013@d<06a/K01<C4`0K6a/0
Y:BT0861P@1dM7@0[Jf]0?7al@0H0?Ogmb@0oooo00<0moOg0?7al@3gmoL00`3gmoL00`3alO40moOg
0?Ogm`080?Ogm`0304A4A00Y:BT061PH00<07QhN0P0Y:BT0300N7Qh0:BTY01DE5@0E5AD0:BTY01DE
5@0Y:BT0J6QX0:NWY`38b<P0d=3@0<[:bP<0e]KF00H0fMWI0=KFeP3=cLd0]KFe09RHV023Ph<208V9
R@0308J6QP1aLG40LG5a0080GemO00/0FEUI05mOG`1LG5`0G5aL05mOG`1[Jf/0GemO07AdM026QXH0
ZZZZ0;no_`030<g=c@0;0=oOg`3@d=00cLg=0<S8b031`L40a<C40;Rh^02e]KD0YjNW09^KV`2BTY80
0P2?Shl00`26QXH0Shn?0:BTY0030:BTY0050:NWY`2TY:@0Y:BT09FEU@20P8000P23Ph<00`1dM7@0
QXJ609FEU@0209RHV0050:6QX@2KVi/0Vi^K0:6QX@2TY:@00P2QXJ403`2KVi/0XJ6Q09^KV`20P800
@T9202TY:@12@T806a/K018B4P0H61P0XJ6Q07MgM`1XJ6P0ZZZZ0?7al@0H0?OgmbL0oooo000U0?oo
o`030?7al@3gmoL0moOg0080moOg00<0lO7a0?Ogm`3gmoL00P3gmoL0103alO40moOg0?Ogm`3alO43
0?Ogm`0304=3@`0/;2`0820P00D0820P00<06a/K02`/;00E5AD00P0C4a<01P0/;2`0<C4a05EEE@2M
WId0bLW90=;BdP80emOG00<0c<c<0=OGe`3Jf]X00P3Jf]X02P3GemL0clo?08N7Q`20P800QXJ60820
P02:RXX0SHf=09RHV020P80307EeM@0L071`L01SHf<0L71`07emO@2:RXX0Vi^K0;Rh^036a/H0cLg=
0<o?c`3Jf]X0emOG0=;BdP3GemL0bLW90<C4a039bLT0a/K60;Rh^02b/[80WIfM08^;R`1iNGT0K6a/
07AdM021PH40V9RH09VIV@80YjNW00<0[Jf]0:VYZ@2YZJT0102WYjL0402MWId0Y:BT0:NWY`2MWId0
YjNW09fMW@2VYZH0ZJVY09fMW@2TY:@0WIfM0:NWY`2MWId0YjNW09RHV01/K6`202`/;00803Hf=P0Z
:RX06a/K020P802EUID0OGem06a/K02][JdI0?Ogmb@0oooo00<0lO7a0?Ogm`3gmoL00P3gmoL00`3a
lO40moOg0?Ogm`020?Ogm`040?7al@3gmoL0moOg0?7al@<0moOg00<0@T9202TY:@0N7Qh01@0N7Qh0
0`0K6a/0:BTY01DE5@02018B4P0602TY:@0_;bl0D51@09^KV`38b<P0d=3@0P3Fe]H00`3:b/X0e]KF
0=WIf@020=WIf@0:0=KFeP3=cLd0QXJ607emO@23Ph<0OGem08J6QP2<S8`0UIFE07emO@<0LG5a01X0
Jf][05mOG`1[Jf/0MgMg08J6QP2HV9P0]KFe0<C4a03:b/X0cLg=0=WIf@3Fe]H0d=3@0=KFeP38b<P0
`L710<S8b034a<@0]KFe0:n_[`2KVi/0RHV907AdM01UIFD0KVi^07emO@80UIFE0P2TY:@00`2ZZZX0
YjNW0:NWY`040:BTY00@09^KV`2QXJ40Y:BT09^KV`2TY:@0Vi^K0:>SX`2WYjL0Vi^K0:6QX@2KVi/0
Y:BT09^KV`2TY:@0UIFE06][J`80:BTY00P0=CDe02TY:@0H61P07QhN08n?S`1gMgL0GemO0:ZZZQT0
moOg9`3oool002D0oooo403gmoL00`3alO40Cdm?020P8002020P800601/K6`0C4a<0820P02`/;00P
82006a/K0`0C4a<01@0/;2`0Cdm?04m?C`2;Rh/0a/K60080clo?103GemL40=[JfP070<o?c`2i^KT0
c<c<0;Ng]`2h^;P0`L710;Vi^@020;Zj^P030:VYZ@2g]kL0]kNg0080^;Rh0P36a/H00`3?cll0emOG
0=OGe`020=[JfP<0clo?00/0emOG0<g=c@36a/H0clo?0<C4a030`<00]kNg0:JVYP2:RXX0MGEe065Q
H@0205]KF`0:07UiN@21PH40VIVI0:NWY`2YZJT0[Jf]0;:b/P2][Jd0ZJVY0:f][@X0ZJVY0180YZJV
09^KV`2YZJT0YZJV0:NWY`2HV9P0B4Q8020P800E5AD0:RXZ01/K6`0/;2`0GEeM08n?S`1mOGd0K6a/
09FEU@1gMgLH0?Ogmb@0oooo403gmoL00`3alO40CDe=01hN7P0201hN7P0601/K6`0B4Q807QhN02TY
:@0N7Qh06a/K0`0B4Q801@0Y:BT0CDe=04e=C@29RHT0a<C40080cLg=103Fe]H40=WIf@030<g=c@2h
^;P0b/[:0080]KFe00D0_kno0;Rh^02h^;P0^;Rh0:NWY`040;Fe]@80a<C400<0cLg=0=KFeP3Fe]H0
0P3IfMT30<g=c@0;0=KFeP3:b/X0a<C40<g=c@31`L40_kno0;Fe]@2SXj<0QXJ6075aL@1LG5`00P1F
EUH02P1dM7@0OGem09FEU@2TY:@0YjNW0:ZZZP2_[jl0ZZZZ0:NWY`2ZZZX:0:NWY`0B0:>SX`2HV9P0
YjNW0:>SX`2TY:@0UIFE04A4A00N7Qh05ADE02TY:@0K6a/0:BTY05UIF@29RHT0MgMg05mOG`2?Shl0
MgMg603gmoLW0?ooo`009@3ooolA0?Ogm`0606m_K`0i>CT0820P02`/;00K6a/04a<C0`0P82002P04
10@0820P01/K6`0P8200;2`/04=3@`1JFUX0Rh^;0;Zj^P39bLT20<o?c`80emOG0`3Jf]X00`3Ph>00
f][J0>3Ph0080>3Ph0040>SXj03Ph>00h>3P0>3Ph0@0f][J00@0clo?0=OGe`3Ph>00f][J0P3?cll0
1P3<c<`0clo?0<C4a039bLT0a<C40<K6aP80`<300P2g]kL02P2KVi/0NGUi065QH@1EEED0B4Q804=3
@`1EEED0GEeM08Z:RP2KVi/40:VYZ@060:NWY`2MWId0Y:BT0:VYZ@2WYjL0Y:BT0P2MWId05@2KVi/0
WIfM09fMW@2YZJT0YZJV0:NWY`2TY:@0Lg=c02`/;00K6a/0820P01/K6`0Z:RX0<30`05eMG@2CTi<0
M7Ad06a/K01`L700;2`/0>SXj00G0?Ogmb@0oooo4@3gmoL01P1^KVh0=CDe01/K6`0Y:BT06a/K018B
4P<07QhN00X00`<301hN7P0K6a/07QhN02TY:@12@T80FEUI08V9R@2h^;P0b<S80P3=cLd20=KFeP<0
fMWI00<0gmoO0=WIf@3Ogml0203Ogml0103Xj>P0gmoO0=oOg`3Ogml40=WIf@040<g=c@3Fe]H0gmoO
0=WIf@80cLg=00H0b/[:0<g=c@31`L40b<S80<71`@34a<@20;no_`80]KFe00X0V9RH07AdM01LG5`0
D51@04A4A00n?Sh0D51@05UIF@26QXH0V9RH102WYjL01P2TY:@0Vi^K0:6QX@2WYjL0Y:BT0:6QX@80
Vi^K01D0V9RH09^KV`2KVi/0YjNW0:>SX`2TY:@0XJ6Q075aL@0Y:BT06a/K01hN7P0K6a/0:BTY02`/
;01IFET0Shn?06i^KP1RHV80Jf][02TY:@3Xj>P05`3gmoLW0?ooo`009@3oool00`3alO40moOg0?Og
m`020?7al@030?Ogm`3alO40moOg00T0moOg0180M7Ad03Ti>@0K6a/0820P01/K6`0P82006a/K020P
800/;2`010@4020P800<30`0820P02`/;013@d<0FUYJ08>3P`2b/[820<W9b@060=;BdP3GemL0emOG
0=[JfP3Ph>00f][J1`3Ph>001@3Xj>P0h>3P0>3Ph03Ph>00j>SX00@0h>3P1P3Jf]X01P3Ph>00emOG
0<o?c`3?cll0cLg=0<C4a0<0bLW900P0`<300<71`@30`<00a/K60:VYZ@2KVi/0NGUi05]KF`80B4Q8
00P0=cLg03/k>`1EEED0MGEe09RHV02WYjL0/[:b0:VYZ@<0YjNW00@0WIfM0:NWY`2WYjL0WIfM0`2;
Rh/00`2KVi/0YZJV0:VYZ@0209fMW@0>07EeM@0/;2`0820P020P800E5AD0=SHf030`<018B4P0UIFE
07AdM01/K6`0HF5Q02`/;03Cdm<G0?Ogmb@0oooo00<0lO7a0?Ogm`3gmoL00P3alO400`3gmoL0lO7a
0?Ogm`090?Ogm`0307AdM00h>3P06a/K00806a/K00d07QhN01/K6`0N7Qh0:BTY00<30`0N7Qh02`/;
01hN7P0Y:BT0@T9205UIF@20P800[jn_0080b<S800H0d=3@0=KFeP3Fe]H0fMWI0=oOg`3IfMT70=oO
g`050>SXj03Ogml0gmoO0=oOg`3Xj>P0103Ogml60=WIf@060=oOg`3Fe]H0cLg=0<g=c@3:b/X0`L71
0`38b<P30;no_`050<C4a02WYjL0V9RH07AdM01FEUH00P14A4@0200b<S80>CTi051@D01aLG40UIFE
0:BTY02_[jl0YjNW0`2TY:@0102KVi/0Y:BT0:BTY02KVi/308V9R@0309RHV02SXj<0YjNW0080Vi^K
00h0LG5a02TY:@0N7Qh07QhN01DE5@0e=CD0;2`/04A4A02?Shl0KVi^069RHP1LG5`0:BTY0=?CdaL0
moOg9`3oool002D0oooo4@3gmoL01P20P800B4Q802`/;00/;2`0820P01/K6`<0820P0P0<30`02P0P
82006a/K02`/;018B4P0GUiN08^;R`2YZJT0/[:b0<o?c`3Bd]820=OGe`<0f][J103Ph>000`3Xj>P0
h>3P0>SXj0030>SXj0040>3Ph03Xj>P0h>3P0>SXj0@0h>3P0P3Jf]X20=OGe`050=[JfP3?cll0c<c<
0<c<c03?cll00`39bLT05P36a/H0a<C40<30`036a/H0`<300;Zj^P30`<00]kNg0:JVYP1/K6`0Hf=S
05eMG@13@d<0=cLg03Ti>@0g=cL0De=C08J6QP2CTi<0V9RH09>CT`2KVi/209RHV00=08J6QP1cLg<0
K6a/07=cL`2:RXX0ZJVY0:BTY02VYZH0Y:BT09^KV`1JFUX0;2`/00`<3002020P800902@T900K6a/0
@T9206a/K01mOGd0PH6104Q8B013@d<0RHV901L0moOg903ooolA0?Ogm`060820P014A4@0:BTY02TY
:@0N7Qh06a/K0`0N7Qh200/;2`0:01hN7P0K6a/0:BTY04A4A01LG5`0RHV90:NWY`2_[jl0cLg=0=3@
d080e]KF0`3IfMT40=oOg`030>SXj03Ogml0j>SX00<0j>SX00@0gmoO0>SXj03Ogml0j>SX103Ogml2
0=WIf@80e]KF00D0fMWI0<g=c@3:b/X0b/[:0<g=c@030<S8b00F0<C4a031`L40_kno0<C4a02o_kl0
^;Rh0;no_`2e]KD0Xj>S06QXJ01OGel0FEUI03hn?P0b<S80=CDe038b<P1=CDd0Ph>308n?S`2EUID0
Shn?09RHV080UIFE00d0Ph>3075aL@1XJ6P0LG5a08J6QP2WYjL0XJ6Q0:>SX`2QXJ40V9RH05UIF@0Y
:BT02`/;00807QhN00T092@T01PH600k>c/0HV9R07MgM`1mOGd0A4A40492@P29RHT05`3gmoLW0?oo
o`009@3ooolA0?Ogm`0409FEU@0k>c/0>c/k034a<@80820P00h06a/K020P800P8200820P00@4100K
6a/0820P03/k>`13@d<0GUiN079bLP2JVYX0^[Zj0<o?c`<0emOG0`3Jf]X40>3Ph0<0j>SX00@0h>3P
0>SXj03Xj>P0h>3P103Xj>P02@3Ph>00j>SX0>3Ph03GemL0f][J0>3Ph03?cll0emOG0<o?c`020=OG
e`0X0<o?c`39bLT0bLW90<W9b@34a<@0bLW90<K6aP39bLT0a/K60<W9b@30`<00^k^k0;Ng]`2YZJT0
YZJV08>3P`1cLg<0GEeM05EEE@13@d<0>c/k04Q8B01EEED0GEeM06a/K01SHf<0GEeM069RHP1/K6`0
Hf=S07UiN@2KVi/0YZJV0:VYZ@2TY:@0WIfM09^KV`2HV9P0B4Q801<C4`80820P00@092@T02XZ:P0K
6a/092@T0P12@T801013@d<0>c/k04];B`2TY:@G0?Ogmb@0oooo4@3gmoL0102EUID0>CTi03Ti>@0_
;bl201hN7P0>01/K6`0N7Qh07QhN01hN7P030`<06a/K01hN7P0i>CT0@T9205aLG01aLG40V9RH0;Rh
^03=cLd30=KFeP<0fMWI103Ogml30>SXj0040=oOg`3Xj>P0j>SX0=oOg`@0j>SX00T0gmoO0>SXj03O
gml0e]KF0=WIf@3Ogml0cLg=0=KFeP3=cLd00P3Fe]H0:03=cLd0b<S80<S8b038b<P0`L710<S8b034
a<@0b<S80<C4a038b<P0_kno0;Rh^02e]KD0YjNW0:>SX`20P800LG5a05UIF@1@D500?Shn03Ti>@14
A4@0D51@05UIF@1XJ6P0HV9R05UIF@1OGel0J6QX05mOG`1dM7@0V9RH0:>SX`2WYjL0XJ6Q09^KV`2H
V9P0UIFE04A4A00B4Q8201hN7P0402@T900Y:BT061PH01dM7@80>c/k00@0?Shn03Ti>@1:BTX0Y:BT
5`3gmoLW0?ooo`009@3ooolA0?Ogm`060;Jf]P0k>c/0BTY:03/k>`0/;2`0820P0P0/;2`0100P8200
;2`/00`<300<30`202`/;00<04=3@`1JFUX0Lg=c08f=S@2g]kL0a<C40<o?c`3GemL0f][J0=OGe`3P
h>00f][J0`3Ph>000`3Xj>P0h>3P0>3Ph0080>SXj0D0h>3P0P3Jf]X00`3GemL0clo?0<o?c`030<o?
c`<0bLW900<0a<C40<W9b@36a/H00P39bLT01036a/H0`<300<30`02j^[X20;Ng]`080:VYZ@2MWId0
RXZ:08J6QP1cLg<0EEEE03/k>`18B4P205=CD`80EEEE00H0GEeM06a/K01iNGT0Vi^K0:BTY02VYZH2
09fMW@0909^KV`2MWId0Rh^;03/k>`0K6a/0820P01/K6`0P82006a/K00804a<C00H061PH02@T900`
<300@d=304];B`3ooolG0?Ogmb@0oooo4@3gmoL01P2e]KD0>CTi04M7A`0i>CT0:BTY01hN7P80:BTY
00@07QhN02TY:@0;2`/02`/;0P0Y:BT03012@T80FEUI075aL@2<S8`0]KFe0<71`@3=cLd0e]KF0=WI
f@3Fe]H0gmoO0=WIf@<0gmoO00<0j>SX0=oOg`3Ogml0203Xj>P50=oOg`80fMWI00<0e]KF0<g=c@3=
cLd00`3=cLd30<S8b0030<71`@38b<P0a<C40080b<S800@0a<C40;no_`2o_kl0^;Rh0P2e]KD0202W
YjL0Vi^K08J6QP23Ph<0LG5a051@D00i>CT0A4A40P1=CDd2051@D00605UIF@1XJ6P0M7Ad09RHV02Q
XJ40Xj>S0P2KVi/02@2HV9P0Vi^K08V9R@0i>CT06a/K01hN7P0K6a/07QhN01/K6`03018B4P0501dM
7@0/;2`0@T9204Y:BP3oool05`3gmoLW0?ooo`009@3ooolA0?Ogm`0709FEU@13@d<0BTY:04m?C`0a
<C406a/K02`/;002020P800<02`/;00a<C40;2`/02XZ:P0i>CT0@d=305iNGP1eMGD0Rh^;0:VYZ@39
bLT0clo?0`3GemL00`3Jf]X0h>3P0=[JfP040>3Ph080j>SX00<0h>3P0>SXj03Xj>P01@3Xj>P0103P
h>00j>SX0>3Ph03Ph>020=OGe`060=[JfP3GemL0emOG0=OGe`3=cLd0clo?0P39bLT00`34a<@0bLW9
0<C4a0030<W9b@<0`<3000@0^[Zj0;Rh^02g]kL0]kNg0P2YZJT03`2TY:@0YZJV09>CT`2:RXX0Lg=c
07EeM@1/K6`0MGEe07UiN@21PH40V9RH09fMW@2KVi/0Y:BT09^KV`0209fMW@0409^KV`2CTi<0Ph>3
02`/;0<0820P00X0;2`/01/K6`0K6a/010@401/K6`0P8200<C4a03Ti>@18B4P0RHV95`3gmoLT0?oo
oa40moOg00L0UIFE0492@P17AdL0CDe=02l_;`0K6a/0:BTY00807QhN00`0:BTY02l_;`0Y:BT0:BTY
03Ph>012@T80G5aL075aL@29RHT0YjNW0<S8b03=cLd30=KFeP030=WIf@3Ogml0fMWI00@0gmoO0P3X
j>P00`3Ogml0j>SX0>SXj0050>SXj0040=oOg`3Xj>P0gmoO0=oOg`80e]KF00H0fMWI0=KFeP3Fe]H0
e]KF0<[:bP3=cLd20<S8b0030<71`@38b<P0`L7100<0b<S80`2o_kl0102h^;P0]KFe0;Fe]@2e]KD2
0:NWY`040:6QX@2SXj<0Shn?08J6QP80LG5a00T0J6QX075aL@1dM7@0OGem09FEU@2KVi/0V9RH0:6Q
X@2HV9P00P2KVi/0102HV9P0Shn?0820P00Y:BT301hN7P0:02TY:@0K6a/06a/K00<30`0K6a/07QhN
02l_;`0h>3P0AdM708V9RAL0moOg9`3oool002D0oooo3P3gmoL0203alO40moOg0?Ogm`1/K6`0B4Q8
04Y:BP1?Cdl0<C4a0P0/;2`2020P800<03Ti>@0/;2`0;2`/02`/;00k>c/0B4Q805YJFP1SHf<0QXJ6
0:VYZ@30`<00d];B0`3GemL20=[JfP<0h>3P00<0f][J0>SXj03Ph>000`3Xj>P00`3Ph>00j>SX0>SX
j0030>SXj0@0h>3P0P3Jf]X30=OGe`060<o?c`34a<@0bLW90<W9b@34a<@0bLW90P34a<@01036a/H0
bLW90<C4a036a/H30<30`00:0;Ng]`2h^;P0]kNg0;:b/P2YZJT0YZJV0:VYZ@2MWId0V9RH09>CT`<0
RXZ:01H0Ti>C09^KV`2WYjL0WIfM09^KV`2MWId0Y:BT09^KV`2PX:00Vi^K08^;R`1eMGD0;2`/020P
800Z:RX0820P01/K6`0Z:RX05ADE01<C4`0P82004a<C0P0Z:RX00`0a<C40Cdm?0?7al@0F0?Ogmb@0
oooo3P3gmoL0203alO40moOg0?Ogm`1[Jf/0A4A404M7A`1=CDd0;bl_0P0Y:BT201hN7P0<03Ph>00Y
:BT0:BTY02TY:@0i>CT0A4A405UIF@1RHV80Ph>30:NWY`2o_kl0d=3@0`3Fe]H20=WIf@<0gmoO00<0
fMWI0>SXj03Ogml00`3Xj>P00`3Ogml0j>SX0>SXj0030>SXj0@0gmoO0P3IfMT30=KFeP060<g=c@31
`L40b<S80<S8b031`L40b<S80P31`L401034a<@0b<S80<71`@34a<@30;no_`<0]KFe00L0[jn_0:NW
Y`2SXj<0YjNW09^KV`2EUID0Shn?00<0QXJ601H0Shn?09RHV02TY:@0Vi^K09RHV02KVi/0XJ6Q09RH
V02JVYX0V9RH08V9R@1aLG40:BTY01hN7P0Y:BT07QhN01/K6`0Y:BT05ADE018B4P0N7Qh04Q8B0P0Y
:BT00`0_;bl0CDe=0?7al@0F0?OgmbL0oooo000U0?ooo`L0moOg00<0lO7a0?Ogm`3gmoL01`3gmoL0
2P1JFUX0@d=303/k>`13@d<0<C4a03Ti>@0/;2`0<C4a020P800C4a<402`/;007034a<@1:BTX0FUYJ
07=cL`2WYjL0/[:b0<o?c`020=OGe`<0f][J1@3Ph>000`3Xj>P0h>3P0>SXj0070>SXj0080>3Ph03X
j>P0h>3P0>3Ph03Jf]X0emOG0=[JfP3GemL20<o?c`<0bLW900<0a<C40<K6aP39bLT00P39bLT01`34
a<@0bLW90<W9b@2k^k/0`<300;^k^`30`<000P2g]kL0102b/[80ZZZZ0;:b/P2g]kL30:VYZ@050:JV
YP2TY:@0WIfM0:BTY02YZJT00P2MWId00`2TY:@0YZJV09^KV`0209fMW@0509>CT`21PH40GUiN02`/
;00P82000P0K6a/00`0E5AD092@T01DE5@0201DE5@0602XZ:P0/;2`04a<C020P8013@d<0f][J5P3g
moLT0?ooo`L0moOg00<0lO7a0?Ogm`3gmoL01`3gmoL02P1IFET0@T9203Ti>@12@T80;bl_03Ph>00Y
:BT0;bl_01hN7P0B4Q8402TY:@0702l_;`17AdL0FEUI075aL@2TY:@0[jn_0<g=c@020=KFeP<0fMWI
1@3Ogml00`3Xj>P0gmoO0>SXj0070>SXj0080=oOg`3Xj>P0gmoO0=oOg`3IfMT0e]KF0=WIf@3Fe]H2
0<g=c@<0b<S800<0`L710<C4a038b<P00P38b<P01`31`L40b<S80<S8b02h^;P0_kno0;Rh^02o_kl0
0P2e]KD0102_[jl0YZJV0:n_[`2e]KD30:NWY`050:>SX`2QXJ40Vi^K0:6QX@2WYjL00P2KVi/02P2Q
XJ40Xj>S09RHV02HV9P0Vi^K08n?S`1mOGd0G5aL02TY:@0N7Qh201/K6`0301DE5@0T92@05ADE0080
5ADE0P0Y:BT0100B4Q807QhN0492@P3IfMTF0?OgmbL0oooo000U0?ooo``0moOg00<0lO7a0?Ogm`3g
moL00P3gmoL0101JFUX0Bd];04Q8B013@d<203/k>`0402`/;00P8200;2`/01<C4`D0820P00P0>CTi
04Y:BP1RHV80Rh^;0;:b/P39bLT0clo?0=OGe`<0f][J1P3Ph>000`3Xj>P0h>3P0>SXj0060>SXj004
0>3Ph03Xj>P0h>3P0>3Ph080emOG00T0c<c<0<o?c`3?cll0clo?0<W9b@36a/H0a<C40<W9b@34a<@0
0P39bLT01034a<@0`<300<K6aP34a<@30<30`0030;^k^`2g]kL0^;Rh0080/[:b00<0]kNg0:VYZ@2b
/[80102YZJT01@2TY:@0WIfM0:BTY02MWId0Y:BT0080WIfM01D0Y:BT09fMW@2KVi/0Ph>306a/K00k
>c/0;2`/01/K6`0P82005ADE02@T900K6a/05ADE01<C4`0K6a/0;2`/01/K6`0410@0;2`/04];B`2E
UID05P3gmoLT0?ooo``0moOg00<0lO7a0?Ogm`3gmoL00P3gmoL0101IFET0BTY:04A4A012@T8203Ti
>@0402TY:@0N7Qh0:BTY018B4PD07QhN00P0>3Ph04M7A`1OGel0RHV90:n_[`38b<P0cLg=0=KFeP<0
fMWI1P3Ogml00`3Xj>P0gmoO0>SXj0060>SXj0040=oOg`3Xj>P0gmoO0=oOg`80e]KF00T0b/[:0<g=
c@3=cLd0cLg=0<S8b034a<@0`L710<S8b031`L400P38b<P01031`L40_kno0<C4a031`L430;no_`03
0;Rh^02e]KD0]KFe0080[jn_00<0]KFe0:NWY`2_[jl0102WYjL01@2QXJ40Vi^K0:6QX@2KVi/0XJ6Q
0080Vi^K01D0XJ6Q09^KV`2HV9P0P82006QXJ00i>CT0:BTY01/K6`0N7Qh05ADE02@T900K6a/05ADE
018B4P0K6a/0:BTY01/K6`030`<0:BTY04Y:BP2EUID05P3gmoLW0?ooo`009@3ooolA0?Ogm`0605YJ
FP18B4P0@d=304Y:BP1;Bd/0>CTi0P0a<C43020P800=02h^;P0/;2`0820P034a<@0k>c/0BTY:04Q8
B01/K6`0Rh^;0;^k^`36a/H0clo?0=OGe`030=[JfP@0h>3P0P3Xj>P40>3Ph0<0j>SX103Ph>001@3J
f]X0emOG0=OGe`3GemL0c<c<0080cLg=00<0clo?0<C4a034a<@00P34a<@00`39bLT0a/K60<C4a002
0<30`0050<K6aP2k^k/0^k^k0<30`02g]kL01@2b/[800`2g]kL0/[:b0:VYZ@030:VYZ@030:BTY02Y
ZJT0Y:BT00<0Y:BT01H0Vi^K0:BTY02MWId0QXJ607EeM@1JFUX0<C4a020P800C4a<05ADE02`/;00K
6a/030`<01<C4`0<30`0820P01/K6`0C4a<0820P03Hf=P0a<C40RHV95P3gmoLT0?oooa40moOg00H0
FEUI04A4A012@T80AdM704Y:BP0h>3P202l_;`806a/K00h07QhN02TY:@0Y:BT07QhN02l_;`0i>CT0
AdM704A4A01XJ6P0RHV90;Rh^034a<@0cLg=0=KFeP<0fMWI103Ogml20>SXj0@0gmoO0`3Xj>P40=oO
g`040=WIf@3Fe]H0e]KF0=KFeP<0b/[:00<0cLg=0<71`@31`L400P31`L400`38b<P0a<C40<71`@02
0;no_`050<C4a02h^;P0^;Rh0;no_`2e]KD01@2_[jl00`2e]KD0[jn_0:NWY`030:NWY`030:6QX@2W
YjL0XJ6Q00<0XJ6Q01H0V9RH0:6QX@2KVi/0Ph>3075aL@1IFET0;bl_01hN7P0B4Q805ADE02TY:@0K
6a/02`/;018B4P0;2`/07QhN01/K6`0B4Q807QhN03De=@0_;bl0RHV95P3gmoLW0?ooo`009@3ooolA
0?Ogm`0805YJFP13@d<0>c/k04];B`13@d<0<C4a03Ti>@0a<C42020P800>01/K6`0P8200820P02`/
;00P8200>c/k04Y:BP1JFUX0GUiN0861P@2i^KT0bLW90<o?c`3GemL40=[JfP80h>3P2@3Xj>P00`3P
h>00j>SX0>3Ph0030>3Ph080f][J00@0clo?0=OGe`39bLT0bLW91`34a<@01039bLT0a<C40;^k^`2k
^k/20<30`080^k^k00<0/[:b0;Ng]`2b/[800`2b/[830:VYZ@030:f][@2YZJT0ZJVY0080ZJVY00/0
YZJV0:BTY02TY:@0Y:BT09fMW@2KVi/0Ph>305YJFP18B4P0<C4a01<C4`0201/K6`0502XZ:P0<30`0
5ADE00`<300E5AD00P0K6a/01P0410@0820P020P800k>c/0Q8B40?oooaD0moOg903ooolA0?Ogm`08
05UIF@12@T80>CTi04Y:BP12@T80;bl_03Ph>00_;bl201hN7P0>01PH600N7Qh07QhN02TY:@0N7Qh0
>CTi04M7A`1IFET0G5aL07emO@2e]KD0b<S80<g=c@3Fe]H40=WIf@80gmoO2@3Xj>P00`3Ogml0j>SX
0=oOg`030=oOg`80fMWI00@0cLg=0=KFeP38b<P0b<S81`31`L401038b<P0`L710;Rh^02h^;P20;no
_`80^;Rh00<0[jn_0;Fe]@2_[jl00`2_[jl30:NWY`030:ZZZP2WYjL0YjNW0080YjNW00/0Xj>S0:6Q
X@2QXJ40XJ6Q09^KV`2HV9P0P82005UIF@14A4@0;bl_018B4P0201/K6`0502TY:@0;2`/05ADE00/;
2`0E5AD00P0K6a/01P030`<07QhN01hN7P0i>CT0Ph>30?oooaD0moOg9`3oool002D0oooo403gmoL0
1`3Xj>P0B4Q804Q8B00k>c/0Bd];04Q8B013@d<00P0i>CT2020P800401<C4`0P8200820P020P8080
;2`/00P0Bd];05EEE@1NGUh0K6a/0:VYZ@2b/[80d];B0=OGe`@0f][J0`3Ph>030>SXj0030>3Ph03X
j>P0j>SX0080j>SX00<0h>3P0>SXj03Ph>00103Ph>000`3GemL0f][J0<c<c0020<o?c`050<K6aP34
a<@0bLW90<30`039bLT00`34a<@00`2k^k/0`<300<30`0020;^k^`040;Jf]P2g]kL0]kNg0;Ng]`<0
/[:b00H0[Jf]0:VYZ@2][Jd0[Jf]0:VYZ@2WYjL20:VYZ@80WIfM00T0YZJV09fMW@2MWId0Vi^K08^;
R`1eMGD0B4Q804=3@`0P82000P0K6a/01@0Z:RX06a/K01DE5@0E5AD04a<C008030`<00H04a<C00@4
100K6a/0;2`/03/k>`1/K6`F0?Ogmb@0oooo403gmoL01`3Xj>P0A4A404A4A00i>CT0BTY:04A4A012
@T800P0h>3P201hN7P04018B4P0N7Qh06a/K01hN7P80:BTY00P0BTY:051@D01LG5`0J6QX0:NWY`2_
[jl0d=3@0=KFeP@0fMWI0`3Ogml30>SXj0030=oOg`3Xj>P0j>SX0080j>SX00<0gmoO0>SXj03Ogml0
103Ogml00`3Fe]H0fMWI0<[:bP020<g=c@050<C4a031`L40b<S80;no_`38b<P00`31`L400`2h^;P0
_kno0;no_`020;Rh^0040;>c/`2e]KD0]KFe0;Fe]@<0[jn_00H0ZZZZ0:NWY`2ZZZX0ZZZZ0:NWY`2T
Y:@20:NWY`80Vi^K00T0Xj>S09^KV`2KVi/0V9RH08V9R@1aLG40A4A40492@P0N7Qh00P0K6a/01@0Y
:BT06a/K01DE5@0E5AD04Q8B00802`/;00H04Q8B00<30`0K6a/0:BTY03Ti>@1[Jf/F0?OgmbL0oooo
000U0?ooo`h0moOg00/0lO7a0?Ogm`3Xj>P0Cdm?03/k>`18B4P0@d=304];B`13@d<0<C4a04=3@`02
02`/;004020P800C4a<0820P020P8080<C4a00T0>c/k04Y:BP1RHV80GEeM09^KV`2b/[80bLW90=;B
dP3GemL00P3Jf]X40>3Ph0P0j>SX00<0h>3P0>SXj03Ph>000`3Ph>000`3GemL0f][J0=OGe`020<o?
c`040<W9b@34a<@0a<C40<30`0@0a<C400P0^KVi0<30`031`L40`<300;^k^`30`<00^;Rh0;Ng]`@0
/[:b00<0ZJVY0:f][@2YZJT00`2YZJT01`2][Jd0ZJVY0:BTY02VYZH0Y:BT0:JVYP2MWId00P2HV9P0
1026QXH0HV9R03/k>`0a<C42020P800503Ti>@0<30`030`<00`<300E5AD00P0<30`301<C4`80820P
00<0<C4a07MgM`3gmoL05@3gmoLT0?ooo`h0moOg00/0lO7a0?Ogm`3Xj>P0CDe=03Ti>@14A4@0@T92
04Y:BP12@T80;bl_0492@P0202TY:@0401hN7P0B4Q807QhN01hN7P80;bl_00T0>CTi04M7A`1OGel0
FEUI09RHV02_[jl0b<S80=3@d03Fe]H00P3IfMT40=oOg`P0j>SX00<0gmoO0>SXj03Ogml00`3Ogml0
0`3Fe]H0fMWI0=KFeP020<g=c@040<S8b031`L40`L710;no_`@0`L7100H0]KFe0;no_`2o_kl0_kno
0;Rh^02o_kl20;Fe]@@0[jn_00<0YjNW0:ZZZP2WYjL00`2WYjL01`2ZZZX0YjNW0:6QX@2SXj<0XJ6Q
0:>SX`2KVi/00P2EUID01023Ph<0GemO03Ti>@0_;bl201hN7P0503Ph>00;2`/02`/;00/;2`0E5AD0
0P0;2`/3018B4P807QhN00<0;bl_07MgM`3gmoL05@3gmoLW0?ooo`009@3oool?0?Ogm`050?7al@3C
dm<0>CTi04=3@`1;Bd/00P13@d<01@1;Bd/0>CTi03Ti>@0a<C40;2`/00<0820P0P0/;2`02P0P8200
<30`04Q8B01MGEd0HV9R09>CT`2WYjL0`<300<W9b@3GemL30=[JfP<0h>3P203Xj>P0103Ph>00j>SX
0>3Ph03Ph>020=[JfP080>3Ph03GemL0emOG0=OGe`3Bd]80a/K60<C4a02k^k/50<C4a0080;^k^`31
`L40^k^k0;^k^`30`<00^k^k0;Rh^02f][H20;:b/P030:f][@2YZJT0/[:b00<0ZJVY0P2][Jd00`2T
Y:@0ZJVY0:BTY00309fMW@0909RHV02CTi<0Rh^;07=cL`1:BTX0@d=303Ti>@0a<C40820P00<05ADE
00/04a<C00`<300<30`030`<00@4100K6a/04a<C020P800K6a/0>c/k0>SXj00F0?Ogmb@0oooo3`3g
moL01@3alO40dm?C03Ph>012@T80BTY:0080@T9200D0BTY:03Ph>00h>3P0;bl_02TY:@0301hN7P80
:BTY00X07QhN02`/;014A4@0FEUI05mOG`2?Shl0Y:BT0;no_`38b<P0e]KF0`3IfMT30=oOg`P0j>SX
00@0gmoO0>SXj03Ogml0gmoO0P3IfMT0203Ogml0e]KF0=KFeP3Fe]H0d=3@0<C4a031`L40^;Rh1@31
`L40202h^;P0_kno0;Rh^02h^;P0_kno0;Rh^02e]KD0/k>c0P2_[jl00`2ZZZX0YjNW0:n_[`030:NW
Y`80ZZZZ00<0XJ6Q0:NWY`2QXJ400`2KVi/02@2EUID0Shn?08V9R@1aLG40AdM70492@P0h>3P0;bl_
01hN7P0301DE5@0;018B4P0;2`/02`/;00/;2`030`<06a/K018B4P0N7Qh061PH03Ti>@3Xj>P05P3g
moLW0?ooo`009@3oool@0?Ogm`040;Vi^@1:BTX0>c/k04=3@`@0Bd];00H0@d=303Ti>@0/;2`0820P
034a<@0C4a<202`/;00:034a<@13@d<0@d=305iNGP1SHf<0Ti>C09FEU@2k^k/0bLW90=OGe`@0f][J
00@0h>3P0=[JfP3Ph>00h>3P203Xj>P20>3Ph0080=[JfP3Ph>00emOG0<o?c`3<c<`0emOG0<C4a039
bLT20<C4a00=0<30`034a<@0^k^k0;^k^`31`L40a<C40;^k^`2f][H0^k^k0;Rh^02f][H0]kNg0:ZZ
ZP030;:b/P0I0:VYZ@2][Jd0ZJVY0:NWY`2YZJT0YjNW0:VYZ@2VYZH0Vi^K09fMW@2YZJT0WIfM09^K
V`2;Rh/0QXJ607=cL`1/K6`0B4Q803Ti>@0a<C40:RXZ01DE5@0<30`06a/K01DE5@0200`<308010@4
00H05ADE01<C4`0K6a/04a<C01/K6`1DE5@G0?Ogmb@0oooo403gmoL0102h^;P0AdM703Ti>@12@T84
04Y:BP060492@P0h>3P0:BTY01hN7P0_;bl04Q8B0P0Y:BT01@0_;bl0@T920492@P1LG5`0HV9R0080
Shn?00<0^;Rh0<S8b03Fe]H0103IfMT0103Ogml0fMWI0=oOg`3Ogml80>SXj080gmoO00P0fMWI0=oO
g`3Fe]H0cLg=0<[:bP3Fe]H0`L710<S8b080`L7100d0_kno0<71`@2h^;P0^;Rh0;no_`31`L40^;Rh
0;>c/`2h^;P0]KFe0;>c/`2e]KD0YZJV00<0[jn_01T0YjNW0:ZZZP2WYjL0Y:BT0:NWY`2TY:@0YjNW
0:>SX`2HV9P0Vi^K0:NWY`2KVi/0V9RH08V9R@23Ph<0LG5a06][J`14A4@0>3Ph02l_;`0Y:BT05ADE
00/;2`0K6a/05ADE00802`/;0P030`<01P0E5AD04Q8B01/K6`0B4Q806a/K05=CDaL0moOg9`3oool0
02D0oooo2P3gmoL00`3alO40moOg0?Ogm`020?Ogm`060?7al@31`L40Bd];034a<@13@d<0Cdm?0`1;
Bd/204=3@`0302XZ:P0P8200;2`/0080820P0`0a<C40201;Bd/0HV9R06a/K02;Rh/0Ti>C0;:b/P39
bLT0d];B0P3GemL00`3Jf]X0h>3P0>3Ph0020>3Ph0H0j>SX0`3Ph>002P3Xj>P0f][J0>3Ph03Ph>00
f][J0=OGe`3?cll0bLW90<g=c@39bLT20<C4a080^k^k00<0a<C40;^k^`2k^k/00P2k^k/00`30`<00
^;Rh0;Jf]P020;Jf]P<0/[:b00@0YZJV0:VYZ@2WYjL0[Jf]1@2YZJT01P2VYZH0YjNW09fMW@2KVi/0
V9RH08^;R`80Ph>300D0MGEe04=3@`0a<C40;2`/020P800201DE5@0800`<300C4a<030`<00`<3004
10@05ADE00`<300K6a/201<C4`03020P801?Cdl0moOg01H0moOg903oool:0?Ogm`030?7al@3gmoL0
moOg0080moOg00H0lO7a0<71`@1:BTX0;bl_0492@P1=CDd304Y:BP80@T9200<0:BTY01hN7P0Y:BT0
0P0N7Qh302l_;`0804Y:BP1OGel0J6QX08V9R@2?Shl0[jn_0<S8b03@d=020=KFeP030=WIf@3Ogml0
gmoO0080gmoO1P3Xj>P30=oOg`0:0>SXj03IfMT0gmoO0=oOg`3IfMT0e]KF0<g=c@38b<P0b/[:0<S8
b080`L710P2h^;P00`31`L40^;Rh0;Rh^0020;Rh^0030;no_`2e]KD0/k>c0080/k>c0`2_[jl0102S
Xj<0YjNW0:BTY02ZZZX50:NWY`060:>SX`2TY:@0Vi^K09RHV02EUID0RHV90P20P8001@1aLG40@T92
02l_;`0Y:BT07QhN00805ADE00P02`/;018B4P0;2`/02`/;00<30`0E5AD02`/;01/K6`804Q8B00<0
7QhN04e=C@3gmoL05P3gmoLW0?ooo`009@3oool@0?Ogm`040<[:bP1;Bd/0<C4a03Ti>@80Bd];0P18
B4P00`1DE5@0@d=302`/;00202`/;003030`<00/;2`0<C4a0080<C4a00T0B4Q805iNGP1eMGD0RXZ:
09>CT`2YZJT0^k^k0<g=c@3GemL00`3Jf]X0203Ph>00j>SX0>3Ph03Ph>00j>SX0>3Ph03Xj>P0h>3P
0P3Xj>P60>3Ph0030=[JfP3?cll0clo?00@0bLW90P34a<@02@2k^k/0`L710<C4a034a<@0^k^k0<71
`@30`<00^;Rh0;Jf]P040;:b/P80[Jf]00<0Y:BT0:VYZ@2TY:@00P2YZJT03`2WYjL0Y:BT0:BTY02V
YZH0WIfM0:BTY02MWId0Ti>C08Z:RP23Ph<0K6a/05YJFP0k>c/0<C4a02`/;002020P80806a/K00<0
820P01DE5@0<30`00P0K6a/201DE5@0401/K6`0/;2`0820P04m?CaL0moOg903oool@0?Ogm`040<[:
bP1:BTX0;bl_03Ph>080BTY:0P14A4@00`1CDe<0@T9202TY:@0202TY:@0302`/;00Y:BT0;bl_0080
;bl_00T0A4A405aLG01aLG40QXJ608n?S`2WYjL0^;Rh0<[:bP3Fe]H00`3IfMT0203Ogml0j>SX0=oO
g`3Ogml0j>SX0=oOg`3Xj>P0gmoO0P3Xj>P60=oOg`030=WIf@3=cLd0cLg=00@0b<S80P31`L401@2h
^;P0_kno0<71`@31`L40^;Rh0080_kno00<0]KFe0;>c/`2_[jl00`2_[jl20:ZZZP030:6QX@2WYjL0
XJ6Q0080YjNW0140Y:BT0:6QX@2QXJ40Xj>S09^KV`2QXJ40Vi^K08n?S`26QXH0P82006][J`1IFET0
>CTi02l_;`0Y:BT07QhN020P800201/K6`03020P800E5AD02`/;00806a/K0P0E5AD0100K6a/0:BTY
01hN7P1=CDdG0?OgmbL0oooo000U0?ooo`/0moOg00<0lO7a0?Ogm`3alO400P3gmoL01P3Cdm<0Cdm?
03/k>`0k>c/0@d=304m?C`80Bd];0P13@d<00`0a<C40820P02`/;002034a<@0@02`/;00a<C40Bd];
04];B`1NGUh0Hf=S08>3P`21PH40Vi^K0;^k^`36a/H0d];B0=OGe`3Jf]X0emOG0=[JfPH0h>3P00<0
j>SX0>3Ph03Ph>00103Ph>020=[JfP80d];B00`0clo?0<W9b@39bLT0a<C40;^k^`2i^KT0^k^k0;Jf
]P2i^KT0^k^k0;Vi^@31`L420;^k^`030;Rh^02b/[80][Jf00<0/[:b00<0[Jf]0:JVYP2YZJT00P2V
YZH0102TY:@0YjNW0:BTY02WYjL20:BTY00909fMW@2KVi/0Ti>C0861P@1cLg<0I6AT05YJFP1;Bd/0
>c/k0080;2`/00D092@T01/K6`0/;2`06a/K02`/;00201/K6`805ADE00H0;2`/01/K6`0410@06a/K
02`/;03Cdm<G0?Ogmb@0oooo2`3gmoL00`3alO40moOg0?7al@020?Ogm`060=?Cd`1=CDd0>CTi03Ti
>@12@T80CDe=0P1:BTX20492@P0302l_;`0N7Qh0:BTY0080;bl_0100:BTY02l_;`1:BTX0BTY:05aL
G01OGel0P82007emO@2HV9P0^;Rh0<C4a03@d=00e]KF0=WIf@3Fe]H0fMWI1P3Ogml00`3Xj>P0gmoO
0=oOg`040=oOg`80fMWI0P3@d=00303=cLd0b<S80<S8b031`L40^;Rh0;Fe]@2h^;P0/k>c0;Fe]@2h
^;P0]KFe0;no_`80^;Rh00<0]KFe0:n_[`2c/k<00`2_[jl00`2ZZZX0Xj>S0:NWY`020:>SX`040:6Q
X@2TY:@0XJ6Q0:BTY080XJ6Q00T0Vi^K09RHV02?Shl0OGem075aL@1OGel0FEUI04Y:BP0i>CT00P0Y
:BT01@0T92@06a/K02TY:@0K6a/0:BTY00806a/K0P0E5AD01P0Y:BT06a/K00<30`0K6a/0:BTY0=?C
daL0moOg9`3oool002D0oooo203gmoL0103alO40moOg0?Ogm`3gmoL20?7al@80moOg00/0b/[:04=3
@`13@d<0<C4a04=3@`1?Cdl0Bd];05ADE01;Bd/0>CTi04=3@`02020P800>02`/;00i>CT0<C4a034a
<@0i>CT0Cdm?04Y:BP1SHf<0MGEe08>3P`2CTi<0[Jf]0<W9b@3?cll20=OGe`<0f][J0P3Ph>00103X
j>P0h>3P0>3Ph03Xj>P40>3Ph0<0f][J00D0emOG0<o?c`3Bd]80a<C40<W9b@020<C4a0040;Vi^@2k
^k/0^k^k0<C4a080^k^k00X0^;Rh0;^k^`2k^k/0^;Rh0;:b/P2h^;P0][Jf0;:b/P2f][H0/[:b0P2]
[Jd20:VYZ@<0YZJV00h0Y:BT0:NWY`2TY:@0YjNW09fMW@2HV9P0RXZ:07UiN@1RHV80FUYJ04Q8B00k
>c/0<C4a02`/;080820P00L0;2`/020P800E5AD030`<01/K6`0<30`010@4008030`<00@05ADE01/K
6`0P8200<C4a603gmoLT0?ooo`P0moOg00@0lO7a0?Ogm`3gmoL0moOg0P3alO420?Ogm`0;0<[:bP12
@T80@T9202l_;`12@T80CDe=04Y:BP1CDe<0BTY:03Ph>012@T800P0N7Qh03P0Y:BT0>3Ph02l_;`0_
;bl0>3Ph04e=C@17AdL0HV9R075aL@20P800Shn?0:ZZZP38b<P0cLg=0P3Fe]H30=WIf@80gmoO00@0
j>SX0=oOg`3Ogml0j>SX103Ogml30=WIf@050=KFeP3=cLd0d=3@0<71`@38b<P00P31`L40102e]KD0
^;Rh0;Rh^031`L420;Rh^00:0;Fe]@2h^;P0^;Rh0;Fe]@2_[jl0]KFe0;>c/`2_[jl0/k>c0:n_[`80
ZZZZ0P2WYjL30:>SX`0>0:6QX@2TY:@0XJ6Q0:BTY02KVi/0UIFE08J6QP1dM7@0GemO05UIF@14A4@0
>CTi02l_;`0Y:BT201hN7P0702TY:@0N7Qh05ADE00/;2`0K6a/02`/;00<30`0200/;2`0401DE5@0K
6a/07QhN02l_;aP0moOg9`3oool002D0oooo2P3gmoL03@3alO40moOg0?Ogm`3gmoL0lO7a0?Ogm`3C
dm<0Cdm?04=3@`0k>c/0B4Q804];B`13@d<00P1DE5@204=3@`80820P0P0a<C402P0i>CT0<C4a034a
<@1;Bd/0B4Q8069RHP1/K6`0MGEe08Z:RP2][Jd20<W9b@80emOG0`3Jf]X30>3Ph080j>SX103Ph>02
0=[JfP070=OGe`3Jf]X0emOG0=;BdP3?cll0cLg=0<o?c`030<C4a0060;^k^`34a<@0`L710;^k^`34
a<@0^KVi0`2k^k/0102f][H0/[:b0;:b/P2f][H30;:b/P030:f][@2YZJT0YZJV0080ZJVY00@0YjNW
0:BTY02TY:@0Y:BT0P2MWId02@2HV9P0RXZ:07=cL`1KFe/0EEEE04Y:BP0i>CT0;2`/02XZ:P02020P
800301/K6`0C4a<0;2`/00805ADE100<30`0100C4a<0820P020P800k>c/H0?Ogmb@0oooo2P3gmoL0
3@3alO40moOg0?Ogm`3gmoL0lO7a0?Ogm`3Cdm<0CDe=0492@P0i>CT0A4A404Y:BP12@T800P1CDe<2
0492@P807QhN0P0_;bl02P0h>3P0;bl_02l_;`1:BTX0A4A405mOG`1XJ6P0LG5a08J6QP2ZZZX20<S8
b080e]KF0`3IfMT30=oOg`80j>SX103Ogml20=WIf@070=KFeP3IfMT0e]KF0=3@d03=cLd0b/[:0<g=
c@030<71`@060;Rh^031`L40_kno0;Rh^031`L40]KFe0`2h^;P0102c/k<0[jn_0:n_[`2c/k<30:n_
[`030:ZZZP2WYjL0Xj>S0080YjNW00@0Y:BT0:6QX@2QXJ40XJ6Q0P2KVi/01`2EUID0QXJ6075aL@1F
EUH0D51@04M7A`0h>3P00P0Y:BT201hN7P0301/K6`0B4Q80:BTY00805ADE100;2`/0100B4Q807QhN
01hN7P0i>CTH0?OgmbL0oooo000U0?ooo`d0moOg01`0lO7a0?Ogm`3gmoL0dm?C04m?C`0i>CT0<C4a
04Q8B013@d<0FUYJ04];B`1?Cdl0@d=303Ti>@0k>c/0820P01/K6`0k>c/0>CTi04=3@`0/;2`0>c/k
04m?C`1JFUX0De=C06a/K021PH40Y:BT0P39bLT00`3?cll0emOG0=OGe`030=[JfP040>3Ph03Jf]X0
h>3P0>3Ph080f][J0P3Ph>001P3GemL0f][J0=[JfP3Jf]X0emOG0=;BdP<0bLW900<0a<C40;^k^`2k
^k/00`2i^KT01@2k^k/0^KVi0;Jf]P2f][H0^;Rh0080^k^k0`2b/[801@2][Jd0YZJV0:RXZ02TY:@0
ZJVY00L0Y:BT00T0Vi^K09>CT`2:RXX0MGEe069RHP1JFUX0B4Q804=3@`0k>c/0100P820301/K6`0:
01DE5@0<30`05ADE0000000<30`010@400`<300P8200>c/k04Y:BQP0moOg903oool=0?Ogm`0L0?7a
l@3gmoL0moOg0=?Cd`1=CDd0>3Ph02l_;`14A4@0@T9205UIF@1:BTX0CDe=0492@P0h>3P0>CTi01hN
7P0K6a/0>CTi03Ph>012@T80:BTY03Ti>@1=CDd0FEUI04e=C@1XJ6P0OGem0:6QX@80b<S800<0cLg=
0=KFeP3Fe]H00`3IfMT0103Ogml0fMWI0=oOg`3Ogml20=WIf@80gmoO00H0e]KF0=WIf@3IfMT0fMWI
0=KFeP3@d=030<S8b0030<71`@2h^;P0^;Rh00<0]KFe00D0^;Rh0;Fe]@2c/k<0/k>c0;Fe]@020;Rh
^0<0[jn_00D0ZZZZ0:>SX`2SXj<0XJ6Q0:NWY`070:6QX@0909RHV02?Shl0QXJ6075aL@1OGel0FEUI
04A4A012@T80>CTi00@07QhN0`0K6a/02P0E5AD02`/;01DE5@0000002`/;00<30`0;2`/07QhN03Ti
>@17AdLH0?OgmbL0oooo000U0?oooa40moOg00P0FUYJ03Ti>@0i>CT0>c/k03Ti>@1;Bd/0@d=304];
B`80@d=301D0>c/k034a<@0/;2`06a/K03/k>`0a<C40Bd];03Ti>@18B4P0BTY:04Q8B01EEED0Ph>3
09>CT`2k^k/0bLW90<o?c`3<c<`0emOG0=[JfP3GemL00`3Jf]X00`3GemL0f][J0=OGe`030=OGe`06
0<o?c`3Jf]X0emOG0=OGe`3<c<`0d];B0P3=cLd20<C4a0070;Jf]P2i^KT0][Jf0;Jf]P2i^KT0^k^k
0;Jf]P030;^k^`030;Vi^@2][Jd0[Jf]00<0/[:b0`2][Jd01P2WYjL0Y:BT0:VYZ@2YZJT0Y:BT0:NW
Y`80Vi^K00H0Rh^;08>3P`23Ph<0K6a/05EEE@18B4P203/k>`0802`/;00P82006a/K01/K6`0E5AD0
6a/K020P800K6a/201DE5@0800`<300410@0000000@4100E5AD0>CTi04Q8B02TY:@H0?Ogmb@0oooo
4@3gmoL0201IFET0>3Ph03Ph>00i>CT0>3Ph04Y:BP12@T80BTY:0P12@T805@0i>CT0;bl_02TY:@0K
6a/0>CTi02l_;`1:BTX0>3Ph04A4A017AdL0A4A4051@D020P800Shn?0;Rh^038b<P0cLg=0<[:bP3F
e]H0fMWI0=KFeP030=WIf@030=KFeP3IfMT0e]KF00<0e]KF00H0cLg=0=WIf@3Fe]H0e]KF0<[:bP3@
d=020<[:bP80`L7100L0/k>c0;Fe]@2c/k<0/k>c0;Fe]@2h^;P0/k>c00<0^;Rh00<0]KFe0:ZZZP2Z
ZZX00`2_[jl30:ZZZP060:BTY02QXJ40YjNW0:NWY`2QXJ40Y:BT0P2HV9P01P29RHT0P8200820P01X
J6P0D51@04A4A080>CTi00P0:BTY01hN7P0K6a/06a/K01DE5@0K6a/07QhN01/K6`805ADE00P02`/;
00<30`0000000`<301DE5@0e=CD0A4A40:BTY1P0moOg9`3oool002D0oooo4@3gmoL01`1/K6`0Bd];
03Ti>@0k>c/0@d=303Ti>@1?Cdl01013@d<01@1;Bd/06a/K02`/;00P8200>CTi0080@d=300T0>c/k
04Y:BP1;Bd/0B4Q806a/K021PH40ZJVY0;:b/P34a<@00P3Bd]80103?cll0emOG0<o?c`3Jf]X20=OG
e`80f][J0`3GemL00`3Bd]80clo?0<o?c`020=OGe`80bLW900L0a<C40;Vi^@2i^KT0][Jf0;^k^`2i
^KT0[Jf]0080^KVi0P2b/[80402f][H0/[:b0;6a/@2f][H0/K6a0:f][@2XZ:P0ZZZZ0:RXZ02YZJT0
[Jf]0:VYZ@2][Jd0Y:BT0:JVYP2KVi/309>CT`0608Z:RP1eMGD0K6a/05iNGP1EEED0>c/k0P0/;2`0
0`0P82004a<C01<C4`0201<C4`@06a/K00P05ADE01/K6`0<30`05ADE00`<300a<C40>c/k09jNWQT0
moOg903ooolA0?Ogm`0706][J`1:BTX0>3Ph03Ti>@12@T80>3Ph04e=C@040492@P0504Y:BP0H61P0
:BTY01hN7P0h>3P00P12@T802@0i>CT0AdM704Y:BP14A4@0J6QX07emO@2WYjL0[jn_0<71`@020=3@
d0040<g=c@3Fe]H0cLg=0=WIf@80e]KF0P3IfMT30=KFeP030=3@d03=cLd0cLg=0080e]KF0P38b<P0
1`31`L40]KFe0;Fe]@2c/k<0^;Rh0;Fe]@2ZZZX00P2e]KD20:n_[`0@0;>c/`2_[jl0[Jf]0;>c/`2]
[Jd0ZZZZ0:>SX`2VYZH0Xj>S0:NWY`2ZZZX0YjNW0:ZZZP2QXJ40Xj>S09RHV0<0Shn?00H0QXJ6075a
L@1XJ6P0G5aL051@D00i>CT202TY:@0301hN7P0B4Q804Q8B00804Q8B100K6a/0200E5AD06a/K00/;
2`0E5AD02`/;02l_;`0i>CT0WIfM6@3gmoLW0?ooo`009@3ooolA0?Ogm`80Hf=S00`0>CTi04=3@`1;
Bd/0@d=304];B`13@d<0E5AD02`/;01;Bd/0<C4a03Ti>@0P8202034a<@0403Ti>@1DE5@0>CTi03/k
>`80Bd];00D0GUiN07EeM@2KVi/0ZJVY0;Vi^@020<W9b@<0clo?0`3GemL0103?cll0emOG0=OGe`3G
emL30<o?c`030<g=c@3?cll0d];B00<0a<C400d0][Jf0;^k^`2i^KT0][Jf0;6a/@2b/[80][Jf0;6a
/@2][Jd0/[:b0;6a/@2f][H0/K6a00D0[Jf]00P0ZZZZ0:f][@2YZJT0Y:BT0:VYZ@2VYZH0WIfM09^K
V`80V9RH00P0QXJ608>3P`1eMGD0K6a/05EEE@18B4P0<30`02`/;080820P0P0C4a<0100K6a/04a<C
01/K6`0K6a/201DE5@0800`<300410@000000000000K6a/0>c/k04Q8B03Cdm<I0?Ogmb@0oooo4@3g
moL2069RHP0<03Ph>012@T80BTY:0492@P1:BTX0@T9205=CD`0Y:BT0BTY:02l_;`0h>3P07QhN0P0_
;bl0100h>3P0De=C03Ph>00i>CT204Y:BP0505aLG01aLG40V9RH0:NWY`2e]KD00P38b<P30<g=c@<0
e]KF00@0cLg=0=KFeP3Fe]H0e]KF0`3=cLd00`3:b/X0cLg=0=3@d0030<71`@0=0;>c/`2h^;P0]KFe
0;>c/`2][Jd0[jn_0;>c/`2][Jd0ZZZZ0:n_[`2][Jd0/k>c0:f][@050:ZZZP080:JVYP2ZZZX0YjNW
0:6QX@2WYjL0Xj>S09^KV`2HV9P209FEU@0808>3P`20P800LG5a06QXJ01@D500A4A402`/;00Y:BT2
01hN7P804Q8B00@06a/K018B4P0K6a/06a/K0P0E5AD0200;2`/00`<30000000000006a/K03Ti>@14
A4@0dm?C6@3gmoLW0?ooo`009@3ooolA0?Ogm`0A06a/K01MGEd0@d=304=3@`1?Cdl0@d=304];B`1?
Cdl0E5AD03Ti>@13@d<0;2`/04=3@`0K6a/0;2`/03Ti>@18B4P00P13@d<04P0a<C40B4Q804m?C`18
B4P0MGEe09VIV@2YZJT0[Jf]0;^k^`39bLT0emOG0<o?c`3Bd]80emOG0<o?c`3Bd]80f][J0<o?c`80
d];B0P3GemL0103<c<`0d];B0<o?c`3=cLd20<C4a0070;^k^`2f][H0^k^k0;6a/@2f][H0[Jf]0;Vi
^@020:f][@80/K6a0P2b/[830:f][@0?0:BTY02][Jd0[Jf]0:BTY02YZJT0YjNW09fMW@2VYZH0YjNW
09^KV`2HV9P0Ti>C08Z:RP21PH40Ph>30080GEeM00<0B4Q803/k>`0/;2`00P0/;2`0100K6a/04a<C
00`<300C4a<201DE5@0401/K6`0E5AD030`<00@410<0000000D0820P02`/;01:BTX0jn_[0?ooo`0H
0?Ogmb@0oooo4@3gmoL04@1[Jf/0G5aL0492@P12@T80CDe=0492@P1:BTX0CDe=05=CD`0h>3P0@T92
02TY:@12@T806a/K02TY:@0h>3P0A4A40080@T920180;bl_04A4A01=CDd0A4A4075aL@2EUID0YjNW
0:ZZZP2h^;P0b<S80=KFeP3=cLd0d=3@0=KFeP3=cLd0d=3@0=WIf@3=cLd20=3@d080e]KF00@0b/[:
0=3@d03=cLd0b/[:0P31`L401`2h^;P0/k>c0;Rh^02][Jd0/k>c0:ZZZP2e]KD00P2ZZZX20:f][@80
[jn_0`2ZZZX03`2QXJ40ZZZZ0:ZZZP2QXJ40YjNW0:BTY02KVi/0Xj>S0:BTY02HV9P0UIFE08n?S`26
QXH0OGem0820P00205UIF@0304A4A00i>CT0:BTY0080:BTY00@06a/K018B4P0;2`/04Q8B0P0E5AD0
100K6a/05ADE00/;2`030`<30000000501hN7P0Y:BT0AdM70>_[j`3oool0603gmoLW0?ooo`009@3o
oolA0?Ogm`0308N7Q`1JFUX0BTY:0080@d=300D0Bd];03Ti>@1;Bd/0Cdm?04];B`0203Ti>@03020P
800/;2`0<C4a0080<C4a00h0>CTi04=3@`1MGEd0<C4a04=3@`1;Bd/0FUYJ07=cL`21PH40YjNW0;:b
/P2][Jd0`<300<C4a0P0clo?00/0d];B0<o?c`39bLT0bLW90=;BdP34a<@0a/K60;Vi^@2f][H0[Jf]
0:RXZ0020;6a/@0>0:RXZ02][Jd0[Jf]0:f][@2XZ:P0[Jf]0;6a/@2XZ:P0[Jf]0:BTY02][Jd0Z:RX
0:2PX02TY:@30:2PX00709fMW@2KVi/0V9RH09>CT`2:RXX0PH6107EeM@0206a/K00405EEE@18B4P0
>c/k03/k>`80820P00<06a/K01DE5@0<30`00P0<30`301DE5@0:00@41000000000000000000410@0
30`<02`/;00k>c/0GUiN0?oooaT0moOg903ooolA0?Ogm`0308J6QP1IFET0AdM70080@T9200D0BTY:
03Ph>01:BTX0CDe=04Y:BP0203Ph>00301hN7P0Y:BT0;bl_0080;bl_00h0>3Ph0492@P1LG5`0;bl_
0492@P1:BTX0FEUI075aL@1mOGd0Y:BT0:n_[`2ZZZX0_kno0<71`@P0cLg=00/0d=3@0<g=c@38b<P0
b<S80=3@d031`L40a<C40;Fe]@2c/k<0ZZZZ0:>SX`020:f][@0>0:>SX`2ZZZX0ZZZZ0:ZZZP2SXj<0
ZZZZ0:f][@2SXj<0ZZZZ0:6QX@2ZZZX0Xj>S09ZJVP2QXJ4309ZJVP0709^KV`2HV9P0UIFE08n?S`26
QXH0OGem075aL@0206QXJ004051@D014A4@0>CTi03Ti>@807QhN00<06a/K01DE5@0;2`/00P0;2`/3
01DE5@0:00<30`0000000000000000030`<02`/;02TY:@0i>CT0G5aL0?oooaT0moOg9`3oool002D0
oooo2@3gmoL00`3alO40moOg0?Ogm`050?Ogm`080;^k^`1NGUh0Cdm?04];B`13@d<0Bd];03Ti>@13
@d<204];B`03034a<@13@d<0<C4a0080820P0180=SHf034a<@0i>CT0Bd];04=3@`0i>CT0;2`/04=3
@`1?Cdl0GUiN06a/K01cLg<0RXZ:0;:b/P2YZJT0[Jf]0;Ng]`30`<020<W9b@030<;2`P39bLT0bLW9
0080clo?0P39bLT30<C4a0050<71`@2b/[80Y:BT0;:b/P2XZ:P00P2][Jd00`2XZ:P0YjNW0:RXZ002
0:RXZ0050;:b/P2][Jd0Z:RX0:NWY`2][Jd00P2XZ:P00`2TY:@0WIfM09^KV`0309^KV`0409RHV02C
Ti<0Rh^;0861P@80MGEe00T0K6a/05iNGP18B4P0B4Q8034a<@0`<300820P01DE5@0K6a/00P0C4a<2
00`<300300@4100<30`05ADE00@0000000D04a<C01/K6`0P8200<C4a0<C4a00J0?Ogmb@0oooo2@3g
moL00`3alO40moOg0?Ogm`050?Ogm`080;^k^`1LG5`0CDe=04Y:BP12@T80BTY:03Ph>012@T8204Y:
BP0302l_;`12@T80;bl_00807QhN0180=CDe02l_;`0h>3P0BTY:0492@P0h>3P0:BTY0492@P1=CDd0
G5aL06QXJ01aLG40QXJ60:n_[`2WYjL0ZZZZ0;Fe]@2o_kl20<S8b0030<71`@38b<P0b<S80080cLg=
0P38b<P30<71`@050;no_`2_[jl0XJ6Q0:n_[`2SXj<00P2ZZZX00`2SXj<0Y:BT0:>SX`020:>SX`05
0:n_[`2ZZZX0Xj>S0:BTY02ZZZX00P2SXj<00`2QXJ40V9RH09RHV00309RHV00409FEU@2?Shl0RHV9
07emO@80LG5a00T0J6QX05aLG014A4@0A4A402l_;`0/;2`07QhN01DE5@0K6a/00P0B4Q8200/;2`03
00<30`0;2`/05ADE00@0000000D04Q8B01/K6`0N7Qh0;bl_0<C4a00J0?OgmbL0oooo000U0?oooa40
moOg00D0iNGU06a/K01JFUX0BTY:04=3@`0204];B`0J03Ti>@13@d<0E5AD04Q8B00i>CT0<C4a01/K
6`0/;2`0820P04];B`0/;2`0>CTi04];B`1?Cdl0Hf=S03Ti>@0k>c/0FUYJ04Y:BP1NGUh0K6a/07Ee
M@21PH40Ti>C09^KV`2b/[820:VYZ@040;:b/P2j^[X0`<300;Ng]`<0`<300P2k^k/01P30`<00^k^k
0:VYZ@2CTi<0UIFE09VIV@80X:2P00P0Vi^K09fMW@2TY:@0YjNW0:JVYP2TY:@0X:2P0:NWY`@0Y:BT
00H0VYZJ0:BTY02KVi/0WIfM09^KV`2HV9P209>CT`0908J6QP21PH40Lg=c06ATI01CDe<0EEEE03/k
>`0g=cL0;2`/0080820P00@05ADE00`<300<30`05ADE0P0<30`00`0E5AD030`<00@4100300000006
00@4100P8200<C4a02`/;00`<300oooo6P3gmoLT0?oooa40moOg00D0iNGU06][J`1IFET0AdM70492
@P0204Y:BP0J03Ph>012@T80De=C04M7A`0h>3P0;bl_01/K6`0Y:BT07QhN04Y:BP0Y:BT0>3Ph04Y:
BP1=CDd0HV9R03Ph>00i>CT0FEUI04M7A`1LG5`0J6QX075aL@1mOGd0Shn?09RHV02_[jl20:NWY`04
0:n_[`2h^;P0_kno0;Fe]@<0_kno0P2h^;P00`2o_kl0^;Rh0:NWY`0208n?S`0309FEU@2JVYX0VYZJ
0080V9RH00H0XJ6Q0:BTY02SXj<0XJ6Q09ZJVP2TY:@40:6QX@0609FEU@2QXJ40V9RH09^KV`2HV9P0
UIFE0P2?Shl02@23Ph<0OGem06i^KP1OGel0CDe=051@D00i>CT0<S8b02TY:@0201hN7P0401DE5@0;
2`/02`/;01DE5@802`/;00<05ADE00/;2`030`<00`0000001P030`<07QhN02l_;`0Y:BT0;2`/0?oo
oaX0moOg9`3oool002D0oooo4P3gmoL01@1bLW80GEeM04m?C`0i>CT0Bd];00<0@d=300@0E5AD04=3
@`0i>CT0>c/k0P0/;2`00`0K6a/0<C4a04];B`0203Ti>@80Bd];00@0Cdm?034a<@1:BTX0FUYJ0P1N
GUh02@1/K6`0NGUi0861P@2HV9P0/[:b09RHV02YZJT0/[:b0:NWY`020;:b/P0:0;Zj^P2g]kL0]kNg
0;:b/P30`<00^k^k0;:b/P2MWId0RXZ:08J6QP80RXZ:00X0VIVI09>CT`2IVIT0X:2P09fMW@2PX:00
Y:BT09VIV@2JVYX0WIfM0P2PX:00102MWId0Vi^K09^KV`2KVi/409>CT`0308J6QP21PH40K6a/0080
GEeM00L0EEEE04=3@`0k>c/0<C4a02`/;00K6a/05ADE00804a<C100<30`00`0E5AD030`<00@41003
0000000600`<300a<C40820P02`/;01EEED0oooo6P3gmoLT0?oooa80moOg00D0LG5a05aLG01=CDd0
>3Ph04Y:BP030492@P0405=CD`12@T80>3Ph03Ti>@80:BTY00<06a/K02l_;`1:BTX00P0h>3P204Y:
BP0404e=C@0_;bl0AdM705UIF@80G5aL00T0J6QX07AdM01mOGd0UIFE0:n_[`2EUID0YjNW0:n_[`2T
Y:@00P2_[jl02P2h^;P0]KFe0;Fe]@2_[jl0_kno0;Rh^02_[jl0Vi^K08J6QP23Ph<208J6QP0709FE
U@2?Shl0UIFE09ZJVP2HV9P0VYZJ0:6QX@0209FEU@0309RHV02JVYX0VYZJ00@0V9RH102?Shl00`23
Ph<0OGem06QXJ00205UIF@07051@D00n?Sh0>CTi02l_;`0Y:BT061PH01DE5@02018B4P@02`/;00<0
5ADE00/;2`030`<00`0000001P0;2`/0;bl_01hN7P0Y:BT0D51@0?oooaX0moOg9`3oool002D0oooo
4P3gmoL01`2EUID0GEeM05YJFP0i>CT0@d=305ADE01;Bd/00`13@d<00`0i>CT0;2`/02XZ:P02020P
800602`/;00Z:RX0E5AD05ADE01;Bd/0@d=30`1;Bd/204Y:BP0;05iNGP1SHf<0Lg=c07=cL`2HV9P0
WIfM09>CT`2;Rh/0V9RH08^;R`2HV9P00`2MWId02`2b/[80YjNW0;:b/P2g]kL0V9RH08Z:RP1eMGD0
PH6106a/K01iNGT0PH610080RXZ:00@0UiNG08Z:RP2GUiL0UiNG0P2IVIT0202GUiL0VIVI09^KV`2C
Ti<0VIVI09FEU@2CTi<0UIFE0P2;Rh/0302:RXX0PH6108>3P`1TI6@0Fe]K05EEE@1CDe<0B4Q802`/
;00^;Rh0;2`/020P80804a<C00<05ADE00`<300<30`00P0410@00`0<30`010@40000000200000006
00@4100P8200820P02XZ:P0P8200][Jf6`3gmoLT0?oooa80moOg00L0UIFE05aLG01IFET0>3Ph0492
@P1CDe<0BTY:00<0@T9200<0>3Ph02TY:@0Y:BT00P0N7Qh202TY:@80De=C00<0BTY:0492@P1:BTX0
0P1:BTX204M7A`0;05aLG01RHV80LG5a075aL@2EUID0Vi^K08n?S`29RHT0UIFE08V9R@2EUID00`2K
Vi/02`2_[jl0Y:BT0:n_[`2e]KD0UIFE08J6QP1aLG40OGem06QXJ01dM7@0OGem0080QXJ600@0TY:B
08J6QP2BTY80TY:B0P2EUID01@2BTY80UIFE09RHV02?Shl0UIFE00<0Shn?0P29RHT02026QXH0OGem
0820P01OGel0EUIF051@D01=CDd0A4A40`0Y:BT0100N7Qh04Q8B018B4P0E5AD200/;2`800`<300<0
2`/;00<30`0000000P0000001P030`<07QhN01hN7P0Y:BT07QhN0;Fe]A/0moOg9`3oool002D0oooo
4P3gmoL01@3alO40LW9b06=SH`1;Bd/0>CTi0080Bd];0P0i>CT01@1MGEd0Bd];03Hf=P0/;2`0:RXZ
0080;2`/0P0i>CT01P15ADD0GEeM05ADE01DE5@0Bd];05eMG@80E5AD00`0GEeM05YJFP1NGUh0HV9R
07=cL`1/K6`0LW9b07=cL`23Ph<0K6a/07EeM@23Ph<207EeM@0<08^;R`2WYjL0VYZJ08^;R`23Ph<0
K6a/06=SH`1/K6`0HV9R06ATI01RHV80I6AT0P1iNGT01@28R8P0PH6108R8R028R8P0UIFE0080R8R8
00h0RXZ:0861P@21PH40PH6107emO@26QXH0PH6107UiN@23Ph<0MGEe069RHP1EEED0De=C04=3@`80
<30`00D0;2`/020P800K6a/0820P01<C4`0300`<308010@41P0000001@0/;2`06a/K020P800P8200
LW9b01`0moOg903ooolB0?Ogm`050?7al@1aLG40HV9R04Y:BP0h>3P00P1:BTX203Ph>00305aLG01:
BTX0=CDe00@0:BTY0P0h>3P01P14A4@0G5aL05=CD`1CDe<0BTY:05aLG080De=C00H0G5aL05UIF@1L
G5`0GemO075aL@1XJ6P2075aL@040820P01[Jf/0LG5a0820P080LG5a00P0RHV90:BTY02HV9P0RHV9
0820P01XJ6P0HV9R06QXJ0@0GemO0P1dM7@01@23Ph<0OGem08>3P`23Ph<0Shn?0080Ph>300h0QXJ6
07emO@1mOGd0OGem07MgM`23Ph<0OGem07AdM020P800LG5a05mOG`1@D500CDe=03hn?P80;2`/00D0
:BTY01hN7P0H61P07QhN018B4P0300/;2`800`<31P0000001@0Y:BT06a/K01hN7P0N7Qh0LG5a01`0
moOg9`3oool002D0oooo4`3gmoL00`29RHT0MgMg04];B`0204=3@`0604];B`0i>CT0B4Q804=3@`18
B4P0>CTi0P0/;2`02@0Z:RX0<C4a03Ti>@1;Bd/0B4Q805ADE01MGEd0AdM704=3@`0205eMG@0806=S
H`1DE5@0FUYJ06=SH`1eMGD0FUYJ06=SH`1NGUh2069RHP0505iNGP1RHV80K6a/06a/K01MGEd00`1e
MGD00`1cLg<0Hf=S07=cL`0205iNGP80EEEE00H0Fe]K05iNGP1/K6`0K6a/07UiN@1dM7@207UiN@80
PH610P23Ph<307EeM@0306a/K01eMGD0K6a/0080K6a/00<0HV9R05YJFP18B4P00P0k>c/02`0`<300
;2`/020P800P82004a<C020P800C4a<030`<00@4100<30`010@400H0000000H030`<020P800Z:RX0
6a/K030`<03Cdm<L0?Ogmb@0oooo4`3gmoL00`29RHT0MgMg04Y:BP020492@P0604Y:BP0h>3P0AdM7
0492@P17AdL0>3Ph0`0Y:BT0200_;bl0>3Ph04Y:BP17AdL0De=C05aLG017AdL0@T920P1LG5`0201R
HV80De=C05UIF@1RHV80LG5a05UIF@1RHV80G5aL0P1OGel01@1LG5`0GemO06QXJ01XJ6P0FEUI00@0
LG5a00@0HV9R075aL@1LG5`0G5aL0P1@D5001P1FEUH0G5aL06QXJ01XJ6P0M7Ad06i^KP80M7Ad0P1m
OGd20820P0<0LG5a00<0J6QX075aL@1XJ6P00P1XJ6P00`1OGel0FEUI04A4A00203Ti>@0;02`/;00Y
:BT07QhN01hN7P0B4Q807QhN018B4P0;2`/00`<300/;2`030`<01P0000001P0;2`/07QhN02TY:@0K
6a/0;2`/0=?Cda`0moOg9`3oool002D0oooo4`3gmoL00`3Rh^80WYjN04m?C`0604=3@`0405ADE013
@d<0<C4a01/K6`80<C4a00@0>CTi04];B`1JFUX0GEeM0P1DE5@01`1MGEd0@d=305ADE01/K6`0Hf=S
05iNGP1/K6`00P1SHf<0201JFUX0BTY:04Y:BP18B4P0K6a/05iNGP1CDe<0BTY:0P1EEED305iNGP80
FUYJ00H0GUiN04m?C`1?Cdl0EEEE04Y:BP0k>c/205EEE@0305iNGP1KFe/0K6a/00<0K6a/00T0I6AT
05eMG@1MGEd0I6AT05iNGP1KFe/0I6AT069RHP1MGEd00P1EEED00`18B4P0>c/k030`<00202`/;003
034a<@0K6a/04a<C00804a<C00@010@401<C4`0<30`000000P0410@40000000400`<300P8200;2`/
01DE5@80>CTi7@3gmoLT0?oooa<0moOg00<0h^;R09jNWP1=CDd01P12@T80101CDe<0@T9202l_;`0K
6a/202l_;`0403Ph>01:BTX0FEUI05aLG080De=C00L0G5aL0492@P1CDe<0Jf][069RHP1LG5`0Jf][
0080HV9R00P0FEUI04M7A`17AdL0A4A406][J`1LG5`0CDe=04M7A`80D51@0`1LG5`205UIF@0605aL
G01=CDd0CDe=051@D017AdL0>CTi0P1@D5000`1LG5`0EUIF06QXJ00306QXJ00605mOG`1IFET0FEUI
05mOG`1LG5`0EUIF0P1OGel01P1IFET0D51@051@D014A4@0>CTi02`/;080:BTY00<0;bl_01/K6`0B
4Q800P0B4Q8010030`<04Q8B00/;2`00000200<30`@0000000@02`/;01hN7P0Y:BT05ADE0P0e=CDM
0?OgmbL0oooo000U0?oooa<0moOg00@0iNGU0;2`/01?Cdl0Bd];0P13@d<0201;Bd/0>CTi04E5A@1D
E5@0@d=3034a<@0/;2`0<C4a0P0i>CT01013@d<0GEeM06=SH`1MGEd205ADE080@d=300D0Cdm?04];
B`1NGUh0K6a/04m?C`0205YJFP0504=3@`18B4P0B4Q805YJFP1:BTX00P1JFUX204Y:BP0905YJFP1E
EED0GUiN05YJFP1DE5@0Cdm?04Y:BP18B4P0BTY:00<0B4Q800<0EEEE05=CD`1CDe<00P1EEED01@1M
GEd0EEEE05EEE@1EEED0GUiN0080EEEE0P18B4P01`1CDe<0EEEE05EEE@1:BTX0B4Q803/k>`0`<300
0`0/;2`201/K6`0400`<300C4a<030`<00`<308010@41@0000001`0410@06a/K02`/;00/;2`06a/K
030`<00i>CT07@3gmoLT0?oooa<0moOg00@0iNGU0;2`/01=CDd0BTY:0P12@T80201:BTX0>3Ph04A4
A01CDe<0@T9202l_;`0Y:BT0;bl_0P0h>3P01012@T80G5aL069RHP1LG5`205=CD`80@T9200D0CDe=
04Y:BP1LG5`0Jf][04e=C@0205UIF@050492@P14A4@0A4A405UIF@17AdL00P1IFET204M7A`0905UI
F@1@D500G5aL05UIF@1CDe<0CDe=04M7A`14A4@0AdM700<0A4A400<0D51@04e=C@1=CDd00P1@D500
1@1IFET0D51@051@D01@D500G5aL0080D51@0P14A4@01`1=CDd0D51@051@D017AdL0A4A403Ti>@0/
;2`00`0Y:BT201/K6`0400/;2`0B4Q802`/;00/;2`800`<31@0000001`030`<06a/K02TY:@0Y:BT0
6a/K02`/;00e=CD07@3gmoLW0?ooo`009@3ooolD0?Ogm`070>SXj024Q8@0Cdm?04];B`13@d<0Bd];
04Q8B00204=3@`0705ADE013@d<0>CTi034a<@1;Bd/0GEeM05ADE00305eMG@0904];B`1MGEd0E5AD
04];B`1:BTX0Cdm?06=SH`1;Bd/0BTY:0080Bd];0100>CTi04=3@`0i>CT0@d=303Ti>@13@d<0Bd];
04=3@`18B4P0Bd];03/k>`1:BTX0@d=3034a<@18B4P0@d=30P0a<C400`0`<300<C4a02`/;002030`
<00304Q8B00k>c/0>c/k00<0>c/k00`0>CTi03/k>`0k>c/0=cLg03/k>`0`<300>c/k030`<00g=cL0
>c/k030`<00/;2`4020P800501<C4`0<30`030`<01DE5@0C4a<00P0<30`200@410040000000410@0
000000`<3080820P00D0:RXZ02`/;00`<300QhN70?7al@0M0?Ogmb@0oooo503gmoL01`3Xj>P0Ph>3
04e=C@1:BTX0@T9204Y:BP17AdL00P12@T801`1CDe<0@T9203Ph>00_;bl0BTY:05aLG01CDe<00`1L
G5`02@1:BTX0G5aL05=CD`1:BTX0AdM704e=C@1RHV80BTY:04M7A`0204Y:BP0@03Ph>012@T80>3Ph
0492@P0h>3P0@T9204Y:BP12@T80A4A404Y:BP0i>CT0AdM70492@P0_;bl0A4A40492@P80;bl_00<0
;2`/02l_;`0Y:BT00P0/;2`00`14A4@0>CTi03Ti>@0303Ti>@0<03Ph>00i>CT0>CTi038b<P0i>CT0
;2`/03Ti>@0/;2`0<S8b03Ti>@0/;2`0:BTY100N7Qh01@0B4Q802`/;00/;2`0E5AD04Q8B00802`/;
0P030`<0100000000`<30000000;2`/201hN7P80:BTY00<0;2`/08J6QP3alO407@3gmoLW0?ooo`00
9@3ooolD0?Ogm`0:0?7al@2EUID0GEeM04];B`13@d<0>CTi04];B`0i>CT0B4Q804=3@`80Bd];00P0
@d=303Ti>@1?Cdl0GEeM05ADE01MGEd0Hf=S05eMG@<0Bd];00X0Cdm?04Y:BP1/K6`0BTY:05YJFP18
B4P0EEEE034a<@13@d<0>CTi1013@d<01P1;Bd/0>CTi04];B`18B4P0@d=303Ti>@80<C4a00<0:RXZ
02`/;00a<C40100/;2`01@0P8200;2`/02h^;P13@d<0;2`/0080>c/k0P0/;2`0100`<300;2`/02`/
;00`<30502`/;0<0820P00L04a<C01/K6`0K6a/05ADE00@4100<30`010@4008030`<00<010@40000
000000000P00000201/K6`0502`/;00K6a/0<C4a04Y:BP3oool07P3gmoLT0?oooa@0moOg00X0lO7a
09FEU@1LG5`0BTY:0492@P0h>3P0BTY:03Ph>017AdL0@T920P1:BTX02012@T80>3Ph04e=C@1LG5`0
De=C05aLG01RHV80G5aL0`1:BTX02P1=CDd0AdM706][J`17AdL0FEUI04A4A01@D500;bl_0492@P0h
>3P40492@P0604Y:BP0h>3P0BTY:04A4A012@T80>3Ph0P0_;bl202TY:@0302l_;`0Y:BT0:BTY0080
:BTY00D07QhN02TY:@0Y:BT0@T9202TY:@0203Ti>@80:BTY00@0;2`/02TY:@0Y:BT0;2`/1@0Y:BT0
100N7Qh06a/K01hN7P0B4Q8201/K6`0401DE5@030`<02`/;00<30`802`/;00<00`<3000000000000
0P00000201/K6`0502TY:@0K6a/0;bl_04M7A`3oool07P3gmoLW0?ooo`009@3ooolE0?Ogm`040;Vi
^@20P800Bd];04m?C`80@d=300D0Bd];04=3@`1DE5@0@d=304];B`0205ADE00304];B`0i>CT0GEeM
00<0E5AD0P1;Bd/01P1?Cdl0Bd];04m?C`1EEED0@d=304];B`80@d=30`0i>CT01013@d<0>CTi02`/
;01;Bd/204=3@`0402XZ:P13@d<0>CTi034a<@80;2`/00D06a/K034a<@0P8200820P01/K6`02020P
8080;2`/0P0P820602`/;006020P800/;2`0;2`/02`/;00P8200;2`/0`0P82003@0K6a/04a<C01<C
4`0E5AD030`<01<C4`0410@030`<00@41000000030`<0000000410@00P0000001`0<30`06a/K034a
<@0E5AD0;2`/05YJFP3:b/X07`3gmoLT0?oooaD0moOg00@0^;Rh0820P01:BTX0CDe=0P12@T801@1:
BTX0@T9205=CD`12@T80BTY:0080De=C00<0BTY:03Ph>01LG5`00`1CDe<204Y:BP0604e=C@1:BTX0
CDe=051@D012@T80BTY:0P12@T8303Ph>0040492@P0h>3P0:BTY04Y:BP80@T9200@0:BTY0492@P0h
>3P0;bl_0P0Y:BT01@0K6a/0;bl_01hN7P0N7Qh06a/K00807QhN0P0Y:BT201hN7PH0:BTY00X07QhN
02TY:@0Y:BT0:BTY01hN7P0Y:BT07QhN01/K6`0N7Qh061PH0P0B4Q802P0E5AD02`/;018B4P030`<0
2`/;00<30`0000002`/;000000030`<20000000700/;2`0K6a/0;bl_01DE5@0Y:BT0FEUI0<[:bP0O
0?OgmbL0oooo000U0?oooaD0moOg00T0b/[:0:BTY01;Bd/0Bd];04Q8B013@d<0E5AD03Hf=P1;Bd/0
0P13@d<305eMG@0>04];B`13@d<0Bd];05ADE01;Bd/0>CTi034a<@13@d<0Cdm?04Y:BP1;Bd/0B4Q8
04];B`1:BTX304=3@`0603Hf=P18B4P0=SHf02XZ:P1?Cdl0=SHf0`0Z:RX01@0i>CT0:RXZ02`/;00T
92@0;2`/0080820P00T06a/K020P800P8200;2`/020P800K6a/0;2`/01/K6`0/;2`00`0P82000`0/
;2`06a/K020P8002020P800302`/;00P8200820P00<0820P0P0C4a<02P0410@04a<C01<C4`0E5AD0
10@400`<300E5AD010@40000000<30`20000000700`<300K6a/0:RXZ01/K6`0P8200;2`/08N7Q`0P
0?Ogmb@0oooo5@3gmoL02@3:b/X0Y:BT04Y:BP1:BTX0A4A40492@P1CDe<0=CDe04Y:BP020492@P<0
G5aL00h0BTY:0492@P1:BTX0De=C04Y:BP0h>3P0;bl_0492@P1=CDd0AdM704Y:BP14A4@0BTY:04M7
A`<0@T9200H0=CDe04M7A`0e=CD0:BTY04e=C@0e=CD302TY:@0503Ph>00Y:BT0:BTY02@T900Y:BT0
0P0N7Qh02@0K6a/07QhN01hN7P0Y:BT07QhN01/K6`0Y:BT06a/K02TY:@0301hN7P0302TY:@0K6a/0
7QhN00807QhN00<0:BTY01hN7P0N7Qh00`0N7Qh2018B4P0:00<30`0B4Q804Q8B01DE5@030`<02`/;
01DE5@030`<0000000/;2`80000000L02`/;01/K6`0Y:BT06a/K01hN7P0Y:BT0QXJ60200moOg9`3o
ool002D0oooo5@3gmoL03@3alO40`L71079bLP1MGEd0>CTi04];B`13@d<0E5AD034a<@0i>CT0B4Q8
034a<@17AdL00`1MGEd02P15ADD0=SHf03Ti>@1MGEd0K6a/05eMG@13@d<0BTY:020P8013@d<203Ti
>@80<C4a0P13@d<0301;Bd/0<C4a04=3@`0T92@0=SHf02XZ:P0T92@06a/K02TY:@0Z:RX06a/K020P
80806a/K00<05ADE01/K6`0C4a<00P0K6a/3020P800701<C4`0P8200820P01<C4`0P82006a/K01<C
4`0201/K6`0:01<C4`0P82005ADE01DE5@0K6a/05ADE01<C4`0K6a/05ADE01/K6`<030`<00@010@4
00`<3000000030`<0P0000002@0<30`06a/K01/K6`0P82005ADE02`/;00i>CT0HV9R0>SXj00P0?Og
mb@0oooo5@3gmoL03@3alO40`L71075aL@1LG5`0>3Ph04Y:BP12@T80De=C02l_;`0h>3P0AdM702l_
;`17AdL00`1LG5`02P14A4@0=CDe03Ph>01LG5`0Jf][05aLG012@T80AdM701hN7P12@T8203Ph>080
;bl_0P12@T80201:BTX0;bl_0492@P0T92@0=CDe02TY:@0T92@06a/K0P0Y:BT01`0K6a/07QhN01/K
6`0K6a/05ADE01/K6`0B4Q800P0K6a/301hN7P07018B4P0N7Qh07QhN018B4P0N7Qh06a/K018B4P02
01/K6`0:018B4P0N7Qh05ADE01DE5@0K6a/05ADE018B4P0K6a/05ADE01/K6`<02`/;00@00`<300/;
2`0000002`/;0P0000002@0;2`/06a/K01/K6`0N7Qh05ADE02TY:@0e=CD0GemO0>SXj00P0?OgmbL0
oooo000U0?oooaH0moOg00<0dm?C0<C4a029RHT00P13@d<02P1;Bd/0@d=304];B`0i>CT0@d=304Q8
B00i>CT0=SHf04];B`1DE5@205eMG@0705ADE018B4P0B4Q804];B`13@d<0Cdm?02`/;002034a<@04
04=3@`0i>CT0:RXZ03Hf=P80>CTi0P0/;2`00`0f=SH0@d=302XZ:P0202@T900301DE5@0T92@0;2`/
00@06a/K0P0E5AD201<C4`0401/K6`0E5AD06a/K01DE5@806a/K00D0820P01/K6`0K6a/06a/K00`<
300201<C4`80820P00D05ADE01/K6`0E5AD030`<01/K6`0201<C4`0501DE5@0<30`0000000`<3004
10@00P0000002@0<30`05ADE01/K6`0E5AD0820P01/K6`0P8200<30`0:BTY00R0?Ogmb@0oooo5P3g
moL00`3Cdm<0a<C408V9R@020492@P0:04Y:BP12@T80BTY:03Ph>012@T80AdM703Ph>00e=CD0BTY:
05=CD`80G5aL00L0De=C04M7A`17AdL0BTY:0492@P1=CDd0:BTY0080;bl_00@0@T9203Ph>00Y:BT0
=CDe0P0h>3P202TY:@0303De=@12@T80:BTY008092@T00<05ADE02@T900Y:BT0100K6a/201DE5@80
4Q8B00@06a/K01DE5@0K6a/05ADE0P0K6a/01@0N7Qh06a/K01/K6`0K6a/02`/;00804Q8B0P0N7Qh0
1@0E5AD06a/K01DE5@0;2`/06a/K00804Q8B00D05ADE00/;2`0000002`/;00<30`020000000900/;
2`0E5AD06a/K01DE5@0N7Qh06a/K01hN7P0/;2`0Xj>S0280moOg9`3oool002D0oooo5`3gmoL0403C
dm<0cLg=05YJFP0i>CT0Bd];04=3@`1;Bd/0B4Q804=3@`18B4P0ADE504];B`1DE5@0ADE503Ti>@13
@d<205eMG@0406m_K`1DE5@0@d=303Ti>@<0;2`/0P0i>CT0100/;2`0:RXZ02TY:@13@d<202XZ:P06
03Hf=P0Z:RX0820P01/K6`0P8200;2`/0P0K6a/00`0T92@0820P01DE5@0401DE5@0600`<300K6a/0
6a/K01/K6`0C4a<030`<0P0K6a/0200E5AD0;2`/00@4100E5AD030`<01/K6`0<30`06a/K0P0E5AD0
1@0<30`05ADE00`<300410@030`<0080000000@010@400`<3000000000000P0<30`201DE5@0703Ti
>@0Z:RX0>CTi034a<@1gMgL0moOg0>SXj00Q0?Ogmb@0oooo5`3gmoL0403Cdm<0cLg=05UIF@0h>3P0
BTY:0492@P1:BTX0AdM70492@P17AdL0A4A404Y:BP1CDe<0A4A403Ph>012@T8205aLG00406i^KP1C
De<0@T9203Ph>0<0:BTY0P0h>3P302TY:@090492@P0Y:BT0:BTY03De=@0Y:BT07QhN01/K6`0N7Qh0
:BTY00806a/K00<092@T020P800E5AD0100E5AD01P0;2`/06a/K01/K6`0K6a/04Q8B00/;2`806a/K
00P05ADE02TY:@030`<05ADE00/;2`0K6a/02`/;01/K6`805ADE00D02`/;01DE5@0;2`/00`<300/;
2`020000000400<30`0;2`/00000000000802`/;0P0E5AD01`0h>3P0:BTY03Ph>00_;bl0MgMg0?Og
m`3Xj>P08@3gmoLW0?ooo`009@3ooolG0?Ogm`050?7al@3Lg=`0LW9b04m?C`0i>CT00P13@d<01`1D
E5@0B4Q804=3@`1DE5@0>CTi04Q8B01MGEd00P1DE5@0300i>CT0ADE505eMG@1DE5@0@d=3034a<@0P
8200:RXZ020P800/;2`0>CTi02`/;080:RXZ00D092@T020P800Z:RX0820P01DE5@0202@T900401/K
6`0E5AD030`<01DE5@<06a/K00<030`<01DE5@0<30`00`0<30`00`0E5AD06a/K01/K6`0300`<3009
01<C4`0E5AD06a/K01DE5@0K6a/030`<01DE5@0<30`05ADE00@030`<0`0410@01000000010@40000
0000000301DE5@0300`<300/;2`0820P00806a/K00@0Hf=S0?Ogm`3Xj>P0lO7a8@3gmoLT0?oooaL0
moOg00D0lO7a0=cLg01aLG40CDe=03Ph>0020492@P0705=CD`17AdL0@T9205=CD`0h>3P0AdM705aL
G00205=CD`0;03Ph>014A4@0G5aL05=CD`12@T80;bl_01hN7P0Y:BT07QhN02TY:@0h>3P00`0Y:BT0
1@0T92@07QhN02TY:@0N7Qh05ADE008092@T00@06a/K01DE5@0;2`/05ADE0`0K6a/00`0;2`/05ADE
00/;2`0300/;2`0301DE5@0K6a/06a/K00<02`/;00T04Q8B01DE5@0K6a/05ADE01/K6`0;2`/05ADE
00/;2`0E5AD0100;2`/300<30`04000000030`<00000000000<05ADE00<02`/;02TY:@0N7Qh00P0K
6a/0101RHV80moOg0>SXj03alO4Q0?OgmbL0oooo000U0?ooo`030?7al@3gmoL0moOg01H0moOg00<0
QhN705eMG@13@d<00P1;Bd/01@0i>CT0E5AD04=3@`0f=SH0B4Q80080@d=301<0E5AD04M7A`0i>CT0
>CTi03Hf=P0Y:BT0=SHf03/k>`0P82006a/K01<C4`0P8200=SHf02XZ:P0/;2`0:RXZ02@T900f=SH0
4a<C00806a/K00L0;2`/01DE5@0/;2`030`<01/K6`0<30`05ADE00806a/K00<05ADE00`<300<30`0
0P0<30`01P0E5AD030`<01DE5@0E5AD06a/K00@410<030`<00@05ADE00`<300<30`06a/K0`0<30`0
0`00000010@400@41006000000<05ADE00T030`<01<C4`0/;2`0;2`/01<C4`0/;2`0GEeM0<C4a03X
j>P08`3gmoLT0?ooo`030?7al@3gmoL0moOg01H0moOg00<0QXJ605aLG012@T800P1:BTX01@0h>3P0
De=C0492@P0e=CD0AdM70080@T9200d0De=C04M7A`0h>3P0>3Ph03De=@0Y:BT0=CDe03Ti>@0N7Qh0
6a/K018B4P0N7Qh0=CDe00<0:BTY00<092@T03De=@0B4Q800P0K6a/01`0Y:BT05ADE02TY:@0;2`/0
6a/K00/;2`0E5AD00P0K6a/00`0E5AD02`/;00/;2`0200/;2`0601DE5@0;2`/05ADE01DE5@0K6a/0
0`<30`0;2`/0100E5AD02`/;00/;2`0K6a/300/;2`03000000030`<00`<300H000000`0E5AD02@0;
2`/04Q8B02TY:@0Y:BT04Q8B02TY:@1IFET0a<C40>SXj00S0?OgmbL0oooo000U0?oooaT0moOg00@0
dm?C07MgM`1MGEd0@d=30P1;Bd/0100f=SH0E5AD04=3@`15ADD204=3@`0>04];B`18B4P0=SHf034a
<@0T92@06a/K03/k>`0i>CT0820P01/K6`0E5AD0820P02`/;00Z:RX2020P80<06a/K00L04a<C03Hf
=P0E5AD06a/K01<C4`0E5AD06a/K00<030`<0P0E5AD200`<300401DE5@0<30`05ADE00`<30@05ADE
0P0000000`0E5AD030`<01DE5@0201DE5@0402@T900<30`030`<00@410D0000000D030`<01/K6`0K
6a/06a/K00`<300201DE5@0701/K6`0/;2`0820P04Q8B01EEED0K6a/0>SXj00T0?Ogmb@0oooo6@3g
moL0103Cdm<0MgMg05aLG012@T8204Y:BP0403De=@1CDe<0@T9204A4A080@T9200`0BTY:04M7A`0e
=CD0;bl_02@T900K6a/0>CTi03Ph>00N7Qh06a/K01DE5@0N7Qh202TY:@807QhN0`0K6a/01`0B4Q80
=CDe01DE5@0K6a/04Q8B01DE5@0K6a/00`0;2`/201DE5@802`/;00@05ADE00/;2`0E5AD02`/;100E
5AD20000000301DE5@0;2`/05ADE00805ADE00@092@T00/;2`0;2`/00`<31@0000001@0;2`/06a/K
01/K6`0K6a/02`/;00805ADE00L06a/K02TY:@0N7Qh0A4A4051@D01XJ6P0j>SX02@0moOg9`3oool0
02D0oooo6P3gmoL01@2WYjL0HV9R05YJFP0i>CT0Bd];0080@d=300D0E5AD03Ti>@1MGEd0B4Q804];
B`0204=3@`0504Q8B00Y:BT0:RXZ04=3@`0k>c/00P0P820201/K6`0301<C4`0Z:RX0:RXZ00<06a/K
00@0:BTY00`<300P82004a<C0P0E5AD200`<300301DE5@0<30`05ADE00805ADE00<030`<0000000<
30`00P0E5AD200`<300401DE5@0Y:BT0:BTY02TY:@8030`<0`0E5AD01@0K6a/030`<01/K6`0K6a/0
5ADE00<030`<00<05ADE01/K6`0K6a/00P0E5AD02P0K6a/05ADE02`/;00Z:RX0820P02`/;018B4P0
EEEE06a/K02=SHdU0?Ogmb@0oooo6P3gmoL01@2WYjL0GemO05UIF@0h>3P0BTY:0080@T9200D0De=C
03Ph>01LG5`0AdM704Y:BP020492@P0504M7A`0Y:BT0:BTY0492@P0i>CT00P0N7Qh201/K6`03018B
4P0Y:BT0:BTY00<06a/K00@0:BTY00/;2`0N7Qh04Q8B0P0E5AD200/;2`0301DE5@0;2`/05ADE0080
5ADE00<02`/;0000000;2`/00P0E5AD200/;2`0401DE5@0Y:BT0:BTY02TY:@802`/;0`0E5AD01@0K
6a/02`/;01/K6`0K6a/05ADE00<02`/;00<05ADE01/K6`0K6a/00P0E5AD02P0K6a/05ADE02TY:@0Y
:BT07QhN02TY:@14A4@0D51@06][J`2<S8`U0?OgmbL0oooo000U0?oooa/0moOg00<0YjNW069RHP1M
GEd00P13@d<01@18B4P0@d=304Q8B017AdL0=SHf0080GEeM0P1CDe<0100i>CT0;2`/04];B`13@d<2
020P800801/K6`0E5AD06a/K01/K6`0P82006a/K01DE5@0C4a<201DE5@0701<C4`0E5AD030`<01<C
4`0E5AD030`<01DE5@0200`<30040000000E5AD05ADE0000008030`<0P0E5AD01P0<30`05ADE01DE
5@17AdL0:BTY03Ti>@<05ADE00@030`<01DE5@0E5AD0820P0P0K6a/01P0P82006a/K01/K6`0E5AD0
:BTY01/K6`8030`<00@0<C4a02`/;00E5AD0;2`/0P0k>c/0101CDe<0L71`06a/K03Cdm<U0?Ogmb@0
oooo6`3gmoL00`2WYjL0GemO05aLG0020492@P0504M7A`12@T80AdM704M7A`0e=CD00P1LG5`205=C
D`0403Ph>00Y:BT0BTY:0492@P807QhN00P06a/K01DE5@0K6a/06a/K01hN7P0K6a/05ADE018B4P80
5ADE00L04Q8B01DE5@0;2`/04Q8B01DE5@0;2`/05ADE00802`/;00@0000001DE5@0E5AD000000P0;
2`/201DE5@0600/;2`0E5AD05ADE04M7A`0Y:BT0>3Ph0`0E5AD0100;2`/05ADE01DE5@0P820201/K
6`06020P800K6a/06a/K01DE5@0Y:BT06a/K0P0;2`/0100_;bl0:BTY01DE5@0Y:BT203Ti>@0404e=
C@1[Jf/0J6QX0=?CdbD0moOg9`3oool002D0oooo6`3gmoL05@3alO40QhN7079bLP1DE5@0B4Q804];
B`13@d<0>CTi04Q8B01DE5@0AdM705ADE01MGEd0E5AD04Q8B00f=SH0Bd];04=3@`0Z:RX0;2`/02@T
900201DE5@0300`<300K6a/06a/K00804a<C00L05ADE01/K6`0<30`06a/K00`<300E5AD030`<0080
5ADE100<30`00`0K6a/05ADE0000000200`<300?01DE5@0K6a/05ADE01DE5@0f=SH0G5aL02TY:@1C
De<0820P02TY:@0T92@05ADE00`<300E5AD030`<00805ADE00<092@T01/K6`0K6a/00P0E5AD203Hf
=P0902`/;00K6a/0>c/k034a<@0/;2`0B4Q805eMG@1/K6`0^KVi02H0moOg903ooolK0?Ogm`0B0?7a
l@26QXH0LG5a05=CD`17AdL0BTY:0492@P0h>3P0AdM705=CD`17AdL0De=C05aLG01CDe<0AdM703De
=@1:BTX0@T920P0Y:BT0100T92@05ADE01DE5@0;2`/201/K6`804Q8B00L05ADE01/K6`0;2`/06a/K
00/;2`0E5AD02`/;00805ADE100;2`/00`0K6a/05ADE0000000200/;2`0?01DE5@0K6a/05ADE01DE
5@0e=CD0G5aL02TY:@1CDe<0820P02TY:@0T92@05ADE00/;2`0E5AD02`/;00805ADE00<092@T01/K
6`0K6a/00P0E5AD203De=@0902TY:@0K6a/0>CTi02l_;`0Y:BT0A4A405UIF@1[Jf/0^;Rh02H0moOg
9`3oool002D0oooo703gmoL0103alO40M7Ad07MgM`1DE5@204];B`0404=3@`0f=SH0=SHf04Q8B0<0
E5AD0P15ADD00`13@d<0>c/k03Ti>@0202`/;005020P800<30`05ADE01<C4`0P82000`0E5AD01P0C
4a<030`<01/K6`0E5AD030`<01DE5@@030`<00@05ADE00`<300E5AD06a/K0P0<30`02P00000030`<
00`<300i>CT0:BTY02<S8`0f=SH0De=C04M7A`0/;2`302TY:@0?03Hf=P0T92@092@T020P800E5AD0
6a/K020P800/;2`0<30`03Ti>@0Z:RX0820P03Ti>@0k>c/0;2`/0080>c/k00<0EEEE06a/K03alO40
9`3gmoLT0?oooa`0moOg00@0lO7a07AdM01gMgL0De=C0P1:BTX01012@T80=CDe03De=@17AdL305=C
D`80A4A400<0@T9203Ti>@0h>3P00P0Y:BT01@0N7Qh02`/;01DE5@0B4Q807QhN00<05ADE00H04Q8B
00/;2`0K6a/05ADE00/;2`0E5AD400/;2`0401DE5@0;2`/05ADE01/K6`802`/;00T0000000/;2`0;
2`/0>3Ph02TY:@0S8b<0=CDe05=CD`17AdL0100Y:BT03`0e=CD092@T02@T900P82005ADE01/K6`0N
7Qh0:BTY02`/;00h>3P0:BTY01hN7P0e=CD0>CTi02TY:@0203Ti>@03051@D01XJ6P0lO7a02L0moOg
9`3oool002D0oooo7@3gmoL0103oool0M7Ad079bLP1MGEd205ADE00604=3@`0f=SH0B4Q804Q8B01C
De<0GEeM0P18B4P02@17AdL0>CTi04=3@`0i>CT0<C4a020P800K6a/030`<01DE5@0201/K6`0801DE
5@0<30`04a<C01/K6`0E5AD06a/K00`<300E5AD200`<30805ADE0`0<30`00`0E5AD030`<00`<3003
00`<300:00000017AdL0>CTi03Ti>@0Y:BT0B4Q805eMG@1DE5@0GEeM04M7A`80ADE500@0Bd];04E5
A@15ADD0=SHf0`0K6a/3034a<@80>CTi0P1:BTX00`1EEED0GUiN0?7al@0X0?Ogmb@0oooo7@3gmoL0
103oool0M7Ad075aL@1LG5`205=CD`060492@P0e=CD0AdM704M7A`1CDe<0G5aL0`17AdL0200h>3P0
@T9203Ph>00_;bl07QhN01/K6`0;2`/05ADE0P0K6a/0200E5AD02`/;018B4P0K6a/05ADE01/K6`0;
2`/05ADE0P0;2`/201DE5@<02`/;00<05ADE00/;2`0;2`/00`0;2`/02P000000AdM703Ph>00h>3P0
:BTY04M7A`1LG5`0De=C05aLG017AdL204A4A00404Y:BP14A4@0A4A403De=@<06a/K0`0_;bl203Ph
>080AdM700<0D51@05aLG03alO40:03gmoLW0?ooo`009@3ooolO0?Ogm`0308n?S`1SHf<0GEeM0080
Bd];01L0B4Q803Hf=P13@d<0Bd];05ADE01LG5`0GEeM05aLG01DE5@0>CTi03Hf=P0k>c/0<C4a02`/
;00E5AD030`<01DE5@0Z:RX05ADE01<C4`0E5AD04a<C00`<300201/K6`8030`<00<0000001DE5@0E
5AD00`0<30`201DE5@<030`<00l06a/K01DE5@0<30`0820P04M7A`13@d<0AdM703Ti>@0e=CD0820P
01DE5@0K6a/0:RXZ03Hf=P0a<C40100i>CT01@1;Bd/0@d=304=3@`13@d<0B4Q80080>c/k00<0GEeM
06a/K01gMgL0:@3gmoLT0?oooal0moOg00<0SXj>069RHP1LG5`00P1:BTX01@17AdL0=CDe0492@P1:
BTX0De=C00<0G5aL00l0De=C03Ph>00e=CD0>CTi02l_;`0Y:BT05ADE00/;2`0E5AD0:BTY01DE5@0B
4Q805ADE018B4P0;2`/00P0K6a/200/;2`030000000E5AD05ADE00<02`/;0P0E5AD300/;2`0?01/K
6`0E5AD02`/;020P8017AdL0@T9204M7A`0h>3P0=CDe020P800E5AD06a/K02TY:@0e=CD0;bl_00@0
>3Ph00D0BTY:0492@P12@T80@T9204A4A00203Ti>@0305UIF@1XJ6P0MgMg02T0moOg9`3oool002D0
oooo8@3gmoL00`1bLW80FUYJ06=SH`0204Q8B00504];B`1DE5@0GEeM05eMG@1LG5`00P1MGEd00`0k
>c/0<C4a034a<@02034a<@80:RXZ00<0>CTi020P800Z:RX00P0P82001`0T92@06a/K00`<300K6a/0
5ADE00`<300K6a/00P0<30`00`0E5AD030`<01/K6`0301DE5@07020P800E5AD06a/K02TY:@0E5AD0
92@T03Hf=P0202@T900304M7A`0P82005ADE00806a/K00@092@T01/K6`0/;2`05ADE0P0Z:RX02P0P
8200=SHf034a<@0/;2`0<30`04Q8B01EEED0GUiN07MgM`3Cdm<Z0?Ogmb@0oooo8@3gmoL00`1aLG40
FEUI069RHP0204M7A`0304Y:BP1CDe<0G5aL00@0G5aL00<0>CTi02l_;`0_;bl00P0_;bl202TY:@03
03Ph>00N7Qh0:BTY00807QhN00L092@T01/K6`0;2`/06a/K01DE5@0;2`/06a/K00802`/;00<05ADE
00/;2`0K6a/00`0E5AD01`0P82005ADE01/K6`0Y:BT05ADE02@T900e=CD00P0T92@00`17AdL0820P
01DE5@0201/K6`0402@T900K6a/0:BTY01DE5@80:BTY00X07QhN03De=@0_;bl0:BTY02`/;014A4@0
D51@05aLG01gMgL0dm?C:P3gmoLW0?ooo`009@3ooolQ0?Ogm`070:BTY01/K6`0Bd];04m?C`18B4P0
@d=304];B`0305eMG@0306m_K`29RHT0Bd];0080<C4a00H0>CTi034a<@0/;2`0;2`/04=3@`0Z:RX2
03Hf=P0402XZ:P0K6a/0:BTY00`<30806a/K00L030`<01DE5@0E5AD030`<01/K6`0<30`092@T0080
820P01<06a/K020P800K6a/05ADE02@T900P82005ADE01/K6`0Y:BT0820P01/K6`18B4P0ADE502@T
900K6a/05ADE020P800T92@0:RXZ0080;2`/00T0<C4a03/k>`0/;2`0>c/k04=3@`1:BTX0GUiN05eM
G@3Cdm<0:`3gmoLT0?ooob40moOg00L0Xj>S06][J`1:BTX0CDe=04M7A`12@T80BTY:00<0G5aL00<0
KVi^08V9R@1:BTX00P0_;bl01P0h>3P0;bl_02TY:@0Y:BT0@T9202TY:@80=CDe00@0:BTY01/K6`0Y
:BT02`/;0P0K6a/06`0;2`/05ADE01DE5@0;2`/06a/K00/;2`0T92@07QhN020P800K6a/0820P01/K
6`0E5AD092@T020P800E5AD06a/K02TY:@0P82006a/K04M7A`14A4@092@T01/K6`0E5AD07QhN02@T
900302TY:@0902l_;`0i>CT0:BTY03Ti>@0n?Sh0AdM705aLG01IFET0dm?C02/0moOg9`3oool002D0
oooo8P3gmoL0103:b/X0HV9R05ADE013@d<204];B`0;04=3@`17AdL0GEeM06a/K01dM7@0Jf][05AD
E00i>CT0<C4a02`/;00a<C400`0Z:RX06`13@d<0=SHf04=3@`0Y:BT0820P05=CD`0E5AD092@T00`<
300T92@0820P02XZ:P0T92@0:BTY01DE5@0<30`0>CTi02TY:@1=CDd092@T04M7A`0Z:RX0@d=305=C
D`1;Bd/0AdM703Hf=P0202XZ:P0:02@T900Y:BT0ADE5034a<@0f=SH0<C4a03/k>`13@d<0<C4a03Ti
>@80BTY:0P1EEED00`1/K6`0GUiN0?7al@0/0?Ogmb@0oooo8P3gmoL0103:b/X0GemO05=CD`12@T82
04Y:BP0;0492@P17AdL0G5aL06][J`1dM7@0Jf][05=CD`0h>3P0;bl_02TY:@0_;bl00`0Y:BT06`12
@T80=CDe0492@P0Y:BT07QhN05=CD`0E5AD092@T00/;2`0T92@0820P02TY:@0T92@0:BTY01DE5@0;
2`/0>3Ph02TY:@1=CDd092@T04M7A`0Y:BT0@T9205=CD`1:BTX0AdM703De=@0202TY:@0:02@T900Y
:BT0A4A402l_;`0e=CD0;bl_03Ti>@12@T80;bl_03Ph>080AdM70P1@D5000`1[Jf/0G5aL0?7al@0/
0?OgmbL0oooo000U0?ooob<0moOg00T0dm?C0820P01;Bd/0Bd];03Ti>@13@d<0E5AD05eMG@1_Kfl0
0P20P8001P1CDe<0E5AD04];B`13@d<0<C4a02XZ:P80<C4a01T0;2`/03Ti>@13@d<0Bd];04E5A@0T
92@0B4Q801DE5@0Y:BT030`<02@T900f=SH0>CTi04M7A`18B4P0AdM705aLG00i>CT0=SHf05aLG00i
>CT0Kfm_04];B`0Y:BT0:RXZ0080ADE500@0>CTi04=3@`0i>CT0>CTi1@13@d<00`1?Cdl0FUYJ04m?
C`0204Q8B00406a/K01RHV80B4Q809jNWRd0moOg903ooolS0?Ogm`090=?Cd`20P800BTY:04Y:BP0h
>3P0@T9205=CD`1LG5`0KVi^0080P8200P1CDe<0101:BTX0@T9202l_;`0Y:BT202l_;`0=02TY:@0h
>3P0@T9204Y:BP14A4@092@T04M7A`0E5AD0:BTY00/;2`0T92@0=CDe03Ph>00304M7A`0705aLG00h
>3P0=CDe05aLG00h>3P0KVi^04Y:BP0202TY:@80A4A400@0>3Ph0492@P0h>3P0>3Ph1@12@T800`1=
CDd0FEUI04e=C@0204A4A00406QXJ01OGel0A4A409fMWBd0moOg9`3oool002D0oooo9@3gmoL01@2k
^k/0QXJ606=SH`1DE5@0Hf=S00<0GEeM00@0Kfm_07MgM`20P800M7Ad0P1SHf<206m_K`0505eMG@1;
Bd/0=SHf03Hf=P1;Bd/00P1MGEd205ADE00B05=CD`15ADD0>CTi01DE5@1LG5`0@d=304M7A`18B4P0
G5aL06e]K@1LG5`0AdM704E5A@0i>CT0Bd];05ADE018B4P0Bd];0P13@d<204];B`80@d=300@0B4Q8
03/k>`13@d<0B4Q80P1EEED01@1NGUh0I6AT05YJFP1JFUX0Y:BT02l0moOg903ooolU0?Ogm`050;^k
^`26QXH0HV9R05=CD`1RHV800`1LG5`0101^KVh0MgMg0820P01dM7@2069RHP80KVi^00D0G5aL04Y:
BP0e=CD0=CDe04Y:BP0205aLG0<0De=C00D0A4A403Ph>00E5AD0G5aL0492@P0204M7A`0:05aLG01^
KVh0G5aL04M7A`14A4@0>3Ph04Y:BP1CDe<0AdM704Y:BP80@T920P1:BTX20492@P0404A4A00i>CT0
@T9204A4A080D51@00D0G5aL05mOG`1IFET0FEUI0:>SX`0_0?OgmbL0oooo000U0?ooo`030?Ogm`3a
lO40moOg0280moOg00<0iNGU0<[:bP1gMgL00P1MGEd0801DE5@0Bd];04M7A`1_Kfl0P82006e]K@1d
M7@0Kfm_07AdM01_Kfl0M7Ad06a/K01_Kfl0E5AD04E5A@1;Bd/0AdM705eMG@1[Jf/0E5AD05aLG01C
De<0HV9R04E5A@0T92@0AdM703Ti>@0f=SH0ADE505eMG@1LG5`0B4Q80P1;Bd/01013@d<0Bd];04m?
C`1DE5@204m?C`80BTY:00`0@d=304Q8B018B4P0Bd];04Q8B01JFUX0GEeM06a/K01eMGD0FUYJ04Q8
B02k^k/`0?Ogmb@0oooo00<0moOg0?7al@3gmoL08P3gmoL00`3UiND0b/[:07MgM`0205aLG00M05=C
D`1:BTX0AdM706i^KP20P800KVi^07AdM01^KVh0M7Ad06i^KP1dM7@0Jf][06i^KP1CDe<0A4A404Y:
BP17AdL0G5aL06][J`1CDe<0G5aL05=CD`1RHV80A4A402@T9017AdL0>3Ph03De=@14A4@00P1LG5`0
1`17AdL0BTY:04Y:BP12@T80BTY:04e=C@1CDe<00P1=CDd204M7A`050492@P14A4@0A4A404Y:BP14
A4@00P1IFET01@1XJ6P0LG5a05UIF@14A4@0^k^k0300moOg9`3oool002D0oooo:03gmoL02@2WYjL0
G5aL06=SH`1MGEd0E5AD06m_K`1dM7@0P82007AdM00306m_K`0406=SH`1_Kfl0M7Ad07AdM080Kfm_
00H0De=C05eMG@1DE5@0M7Ad06e]K@1DE5@206e]K@0804M7A`0i>CT0>CTi03Ti>@0Z:RX0<C4a04=3
@`1_Kfl304];B`80>CTi0P0k>c/03P0i>CT0>c/k03Ti>@1:BTX0EEEE05YJFP1MGEd0GUiN069RHP1e
MGD0EEEE04Q8B01:BTX0cLg=<@3gmoLT0?ooobP0moOg00T0YjNW05aLG01RHV80G5aL05=CD`1^KVh0
M7Ad0820P01dM7@00`1^KVh0101RHV80KVi^07AdM01dM7@206i^KP0605=CD`1LG5`0De=C07AdM01^
KVh0De=C0P1^KVh02017AdL0>3Ph03Ph>00h>3P0:BTY02l_;`12@T80KVi^0`1:BTX203Ph>080>CTi
00D0>3Ph03Ti>@0h>3P0AdM7051@D00205UIF@0705aLG01OGel0LG5a051@D014A4@0AdM70<g=c@0a
0?OgmbL0oooo000U0?ooobT0moOg00T0`L7109^KV`1JFUX0G5aL05ADE01/K6`0G5aL07AdM029RHT0
0`1dM7@01P1/K6`0M7Ad06m_K`1dM7@0MgMg0820P080M7Ad00X0Jf][07AdM020P800Jf][05ADE01d
M7@0GEeM04];B`0i>CT0ADE50P0i>CT204=3@`0C05eMG@1DE5@0@d=304m?C`18B4P0BTY:05YJFP1?
Cdl0GEeM05YJFP1RHV80K6a/07EeM@1/K6`0HV9R03Ti>@1RHV80QhN70?ooo`0b0?Ogmb@0oooo:@3g
moL02@31`L40Vi^K05UIF@1LG5`0De=C06][J`1LG5`0M7Ad08V9R@0307AdM00606][J`1dM7@0KVi^
07AdM01gMgL0P8200P1dM7@02P1[Jf/0M7Ad0820P01[Jf/0De=C07AdM01LG5`0BTY:03Ph>014A4@2
03Ph>080@T9200P0G5aL05=CD`12@T80CDe=04A4A017AdL0FEUI04e=C@80FEUI00T0GemO06][J`1a
LG40Jf][05mOG`0e=CD0GemO08J6QP3oool0<P3gmoLW0?ooo`009@3oool]0?Ogm`0708n?S`1?Cdl0
?Shn04];B`1CDe<0KFe]09FEU@020820P080Q8B400@0RHV907MgM`1_Kfl0M7Ad1@1gMgL01`1/K6`0
Q8B407MgM`1gMgL0Kfm_06=SH`1_Kfl00`1RHV801@1SHf<0K6a/069RHP1/K6`0Lg=c0080LW9b00D0
P82008>3P`23Ph<0K6a/04m?C`0204Y:BP0308N7Q`3oool0moOg03@0moOg903oool]0?Ogm`0708j>
SP1=CDd0?Shn04Y:BP1CDe<0KVi^09FEU@020820P080Ph>300@0RHV907MgM`1^KVh0M7Ad1@1gMgL0
1`1[Jf/0Ph>307MgM`1gMgL0KVi^069RHP1^KVh00`1OGel0101RHV80J6QX05mOG`1XJ6P3075aL@05
07emO@20P800P82006][J`1=CDd00P17AdL00`26QXH0oooo0?Ogm`0d0?OgmbL0oooo000U0?ooobl0
moOg00<0h^;R0:BTY01mOGd00P1mOGd209jNWP040:n_[`2EUID0WYjN09jNWP<0Q8B400D0MgMg07Ad
M01gMgL0Q8B408N7Q`0408B4Q00807MgM`1bLW80K6a/079bLP1/K6`0LW9b07MgM`20P80208B4Q004
07MgM`1SHf<0K6a/06a/K080Cdm?00<0K6a/07AdM03gmoL0=`3gmoLT0?ooobl0moOg00<0h^;R0:>S
X`1mOGd00P1mOGd209fMW@040:n_[`2EUID0WIfM09fMW@<0Ph>300D0MgMg07AdM01gMgL0Ph>308J6
QP0408>3P`0807MgM`1aLG40Jf][075aL@1[Jf/0LG5a07MgM`1mOGd208>3P`0407MgM`1RHV80Jf][
06][J`80CDe=00<0Jf][07AdM03gmoL0=`3gmoLW0?ooo`009@3ooola0?Ogm`80iNGU00H0j>SX0=?C
d`3=cLd0g=cL0:NWY`2k^k/209jNWP0509FEU@20P800P82007MgM`1dM7@00P1_Kfl00`1gMgL0QhN7
08f=S@0208B4Q00<079bLP1gMgL0LW9b079bLP1gMgL0LW9b06a/K01bLW80K6a/069RHP1/K6`0FUYJ
0P1?Cdl00`1RHV80dm?C0?7al@0h0?Ogmb@0oooo<@3gmoL20>GUi@090>SXj03Cdm<0cLg=0=cLg02W
YjL0^k^k09jNWP2MWId0UIFE0080P82000L0MgMg07AdM01^KVh0KVi^07MgM`26QXH0S8b<0080Ph>3
00`0LG5a07MgM`1aLG40LG5a07MgM`1aLG40Jf][075aL@1[Jf/0GemO06][J`1IFET204e=C@0305mO
G`3Cdm<0lO7a03P0moOg9`3oool002D0oooo=P3gmoL04P3UiND0g=cL0<g=c@3Lg=`0j>SX0<g=c@2W
YjL0Vi^K09FEU@29RHT0MgMg08B4Q01bLW80Kfm_07AdM01_Kfl0QhN708V9R@<0MgMg00X0K6a/07Mg
M`1bLW80K6a/06=SH`1DE5@0Cdm?06m_K`26QXH0d=3@>`3gmoLT0?ooocH0moOg0180iNGU0=cLg03=
cLd0g=cL0>SXj03=cLd0YjNW09^KV`2EUID0RHV907MgM`23Ph<0LG5a06i^KP1dM7@0KVi^08J6QP29
RHT307MgM`0:06][J`1gMgL0LG5a06][J`1RHV80De=C04e=C@1^KVh0QXJ60=3@d3/0moOg9`3oool0
02D0oooo@03gmoL02@3Rh^80d=3@0<C4a02WYjL0WYjN09FEU@2=SHd0QhN707AdM0020820P00409FE
U@2NWYh0^KVi0=?Cd`80lO7a?`3gmoLT0?oood00moOg00T0h^;R0=3@d034a<@0YjNW09fMW@2EUID0
S8b<08J6QP1dM7@00P20P800102EUID0WIfM0;Rh^03Cdm<20?7alCl0moOg9`3oool002D0ooooT03g
moLT0?oooi00moOg9`3oool002D0ooooT03gmoLT0?oooi00moOg9`3oool002D0ooooT03gmoLT0?oo
oi00moOg9`3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool003X0oooo0T0000100?ooo`900000N@3oool2@00002h0oooo
0d00001V0?ooo`00>`3oool00d000000oooo0?ooo`100?ooo`03@000003oool0oooo07L0oooo00=0
00000?ooo`3oool0;@3oool00d000000oooo0?ooo`1U0?ooo`00=03oool4@00000<0oooo00=00000
0?ooo`3oool02P3oool2@00000<0oooo0T0000020?ooo`=000000`3oool2@00000<0oooo0T000002
0?ooo`=000003@3oool01T000000oooo@000003ooom000000?ooo`A000000P3oool5@0000080oooo
00=000000?oood0000000T0000030?ooo`9000000`3oool3@0000080oooo0d0000020?ooo`900000
E@3oool4@00000<0oooo00=000000?ooo`3oool02@3oool3@00000030?oood00001000000080oooo
0d0000020?ooo`03@000003oool0oooo009000000P3oool3@00000d0oooo0d0000020?ooo`=00000
0`3oool2@00000<0oooo0d0000020?ooo`=0000000@0oooo@0000400001000000`3oool2@00004L0
oooo000e0?ooo`08@000003oool0oooo@000003ooom000000?oood00000;0?ooo`9000000P3oool0
0d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00I000000?ooo`3ooom000000?oo
od0000020?ooo`04@000003oool0oooo@00000h0oooo00I000000?oood000000oooo@000003oool3
@0000080oooo00I000000?ooo`3ooom000000?oood0000020?ooo`04@000003oool0oooo@00000<0
oooo00I000000?ooo`3ooom000000?oood0000020?ooo`03@000003ooom000000080oooo00=00000
0?oood000000F03oool024000000oooo0?oood000000oooo@000003ooom000002`3oool01D000000
oooo0?ooo`3ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000050?oo
o`03@000003oool0oooo00`0oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3o
oom000000080oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003o
oom0000000@0oooo00A000000?ooo`3ooom00000AP3oool003D0oooo00Q000000?ooo`3ooom00000
0?oood000000oooo@00000X0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00=00000
0?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo00=0
00000?ooo`3oool0303oool01D000000oooo@000003ooom0000000<0oooo00A000000?ooo`3ooom0
00000P3oool00d000000oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo00=000000?oo
o`3oool00P3oool01T000000oooo0?oood000000oooo@0000080oooo00=000000?oood0000000T00
001F0?ooo`08@000003oool0oooo@000003ooom000000?oood00000;0?ooo`05@000003oool0oooo
0?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom00000009000000`3oool0
0d000000oooo0?ooo`0<0?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo
@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo
@00000040?ooo`03@000003oool0oooo04L0oooo000e0?ooo`=0000000@0oooo@00004000000oooo
0T0000080?ooo`9000000P3oool00d000000oooo@0000002@0000080oooo0d0000000`3ooom00000
@0000002@00000<0oooo0T0000020?ooo`A00000303oool2@00000030?oood000000oooo0080oooo
0T0000030?ooo`M000000P3oool2@0000080oooo14000000103ooom00000@000003oool2@0000080
oooo0d000000103ooom00000@0000400001F0?ooo`=0000000@0oooo@00004000000oooo0T000009
0?ooo`9000000P3oool4@00000030?oood0000100000009000000P3oool3@0000080oooo1400000;
0?ooo`A000000P3oool4@0000080oooo0T0000030?ooo`E0000000@0oooo@00004000000oooo0d00
00000`3ooom00000@0000002@00004L0oooo000e0?ooo`04@000003oool0oooo@00001d0oooo00=0
00000?ooo`3oool0<@3oool00d000000oooo0?ooo`0:0?ooo`03@000003oool0oooo05P0oooo00A0
00000?ooo`3ooom00000A03oool00d000000oooo0?ooo`090?ooo`03@000003oool0oooo04L0oooo
000d0?ooo`A00000CP3oool00d000000oooo0?ooo`0=0?ooo`900000F@3oool4@0000100oooo00=0
00000?ooo`3oool0<@3oool2@00005D0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo002;0?ooo`900000K`3oool2@0000980oooo002=0?ooo`03@000003oool0
oooo06h0oooo00=000000?ooo`3oool0S`3oool007l0oooo0d0000030?ooo`=000000`3oool3@000
00D0oooo00A000000?ooo`3oool0oooo0T0000060?ooo`03@000003oool0oooo00L0oooo0T000000
0`3ooom00000@00000020?ooo`90000000<0oooo@000040000000P3oool00d000000oooo0?ooo`02
@0000080oooo0d0000001`3ooom00000@00004000000oooo@000003oool00d0000030?ooo`900000
00H0oooo@000003ooom000000?oood0000020?ooo`9000004P3oool3@00000070?oood000000oooo
@000003ooom000000?ooo`04@0000080oooo0d0000020?ooo`9000000P3oool2@00008T0oooo0020
0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003o
ool0oooo00L0oooo00=000000?oood0000003`3oool01d000000oooo0?ooo`3ooom000000?oood00
00000P3oool00d000000oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood00
0000103oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool2
@00000060?oood000000oooo@000003ooom000005@3oool02D000000oooo0?oood000000oooo@000
003ooom000000?ooo`03@0000080oooo00I000000?ooo`3ooom000000?oood0000060?ooo`03@000
003oool0oooo08H0oooo00200?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3oool0oooo
@00000020?ooo`03@000003oool0oooo00L0oooo00=000000?oood0000003`3oool01d000000oooo
@000003ooom000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom00000
0080oooo00=000000?oood000000103oool014000000oooo0?oood0000020?ooo`05@000003oool0
oooo0?oood0000000P3oool2@00000050?oood000000oooo@000003oool00d00000C0?ooo`08@000
003oool0oooo@000003ooom000000?oood0000030?ooo`04@000003oool0oooo@0000080oooo00=0
00000?oood0000000T0000030?ooo`03@000003oool0oooo08L0oooo00200?ooo`9000000`3oool2
@00000@0oooo0d0000090?ooo`900000403oool2@00000030?oood00001000000080oooo0T000000
0`3ooom00000@0000002@00000<0oooo0T0000020?ooo`=000000P3oool3@0000080oooo14000002
0?ooo`90000000D0oooo@00004000000oooo@00000020?ooo`=000004P3oool2@0000080oooo0T00
00000`3ooom000000?ooo`020?ooo`9000000`3oool3@00000040?oood0000100000@00000<0oooo
0T0000280?ooo`00P03oool014000000oooo0?oood00000C0?ooo`03@000003oool0oooo00l0oooo
0T0000000`3ooom00000@000000E0?ooo`03@000003oool0oooo0<X0oooo001o0?ooo`E000000P3o
ool00d000000oooo0?ooo`0?0?ooo`9000003`3oool2@00000030?oood000010000001@0oooo0T00
000Y0?ooo`03@000003oool0oooo0:00oooo003o0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.157534, -0.0238147, 
  0.00580218, 0.00580218}, {{27.125, 191.25}, {185.313, 
  21.1875}} -> {-66.2021, -12.4581, 1.77861, 1.77861}, {{207.688, 371.813}, {
  185.313, 21.1875}} -> {-387.352, -12.4581, 1.77861, 1.77861}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "At first, we compute the monochrome characteristic vectors to the both \
images in Fig.6 by the function \[OpenCurlyDoubleQuote]eigen2Dvect\
\[CloseCurlyDoubleQuote]. Second, we compute the magnitude distributions of \
the monochrome characteristic vectors by the function \
\[OpenCurlyDoubleQuote]vectorMag2D\[CloseCurlyDoubleQuote]. Consequently, we \
compute the image data reversing the black and white mode.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
monoMG=ListDensityPlot[1-vectorMag2D[eigen2DVect[vectMag]],
\tMesh->False,Frame->False,PlotRange->All,
\tPlotLabel->\"By vector magnitude\",
\tDisplayFunction->Identity];
monoIG=ListDensityPlot[1-vectorMag2D[eigen2DVect[innerPro]],
\tMesh->False,Frame->False,PlotRange->All,
\tPlotLabel->\"By inner product\",
\tDisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[49]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["Figure 7 shows the monochrome images. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{monoMG,monoIG}],ImageSize->{400,200},
\tPlotLabel->\"Fig.7. Monochrome sketches\"];\
\>", "Input",
  CellLabel->"In[51]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[.5 .48869 -80 0 ]
[.5 .48869 80 12.5625 ]
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .48869 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.7) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Monochrome) show
171.000000 12.812500 moveto
(sketches) show
219.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -59 0 ]
[.5 1.0125 59 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(By) show
81.000000 12.812500 moveto
(vector) show
123.000000 12.812500 moveto
(magnitude) show
177.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F5FBF3FFFF
FFFBFBFBFFFFFFFFF8FFFFF8FFF8FFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFF8FFFFFFFFEFF3F3FFFFFFFFF8F3F3FFFFF3
F8FFF8F2FAF3F3FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8F3F3FFF8F7FCFFFCFCFDFFFCFFFFFCFFFFF1F5F8FFA6EB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFAFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDAEEFAF7FFFF
FFFBFDFDFFFFFFFAFAFFFFFAF8FFFAFFFFFAF8F8FAFFFFFA
FAFAFAFAFAFAFAFDF4F4FFEFF7F7FFFFFFFFF8F6F6FFF6F6
F8FEF9F9F6EEF6F3F6FFFAFAFFFFFAFAFFFFFFFAFAFAF8FF
FAF7FCF8FAF9FAFCFDFAFAFDFDFDFDFDFCFDF5F5F8E0AAF1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFAFAFFFAFAFAFAFAFAFFFAFA
FAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFAFAFFFAFAFAFAFAFAFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4E1F6FAFFFF
FFFDFDFDFDFDFDF8FAFAFFFAF8FAF8FFFFFAF8FAFAFAFFF8
F8FAFAFAFFFAFFFDF4F4F4F4FFFFFAF8F8F0EFF6F6F3F6FF
FAF9FEFFF5F1FFFFFFFFFAFAFFFFF8F8FFFFFFFAFAFAFAF8
FFFAFAFCFAFFFFFFFCFBFBFDFDFDFFFCFDFCF5F4F3BBC7FF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFAFAFFFAFA
FAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFAFAFAFAFFFFFAFAFFFFFFFFFFFFFFFF
FAFAFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4E1F6FAFFFD
FDFFFBFDFFFFF7FAFAFAFAFAFFFAFAFFFAFAFAFAFAFFF8FF
FFFAFAF8FAFDF4EFEFEFF4FFFAF8F1F6F6F6FFF6F6F9F7F5
F5F6FAFAF9FAFFFFFAFAFAF8FAFFFAFAFFFFFFFFFFF7FCFF
FAF8FFFCFCFCFFFFFCFDFAFAFFFDFCFFFDFAF8F3F2B4E0FF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFAFAFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFAFAFFFFFAFAFAFAFFFAFAFAF7FA
FAFAFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4E1F3FFFFFD
FFFDFDFDFBFBF8FFFFFFF8FFFFF8FFFFFAFFFAFAFAFAFAFA
F7FDFFFFF4F1F7FFFFFFFAF8FAF0F9FFF6F9F9FFF6FDFAFB
F9F5F8F8F8FAF7F7F5F5F8FAFAFFFFFFFFFFFAFAFFF7F7FA
FFFFF9F9F7FCFAFAFFFFFAFAFDFDFDFDFFFCF8F3E1B4F4FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFA
FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFF
FFFFFAFAFAFAFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFAF7FA
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4E1F3FFFFFF
FDFDFDFDFDFDFAF8F8F8FAFFFFFAFAFAF8FAFFF8FAF8FAFD
FFFDF4EFF4FFFFFAF8F8FAFFFFF0F3EFF9F7F7F6F7F7F6F9
FAFFFFFFFFFFF7F7F3F6FAF9F5FAFAFAFAF5F9F8FFFFFFF7
F9F8F5F9F7FFFDFBFFFCFFFCFDFDFFFDFCFDF5EACBC5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEE7F6FAFFFF
FFFFFBFFFFFFFAFAFFFFFFFFFAFAFAFAFFFFFFFAFAFFFDFF
F7EFFDF3F7FFFFFAF6F8F8F7F6EFF2F7FFFEFCF6FEFEFDFA
F8F5F7FFFFFFFFFFF7F5F9FCFAF9F6F5F5FFFCF9F7FAF8FC
FAF6F9FFFAFCFCFFFCFFFCFDFFFFFDFFFDFFFCEAB7E1FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFFFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFF
FFFAFFFAFFFAFAFFFAFAFAFAFAFAFFFF
FFFAFAFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFAFAFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4E1FCF5FFFD
FDFDFFFDFFFFF8F8FFFFFAFAF8FAFAFFFFFFFFFFFFFFF4F4
EFF7F8EDF7FFF2F1F4FAFAFEFAF9F9F6F7F7F1FAFAF6FAFF
FFF2EEF4F3F5F5F7FAF5FAFCFCFFFAFAFAFFF9F7F5F5FCF8
F7F6FFFCFAFCFCFCFEFFFAFAFDFBFCFDFDFFFCDCB1FAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFAFAFFFAFAFFFAFAFAFAFFFAFAFAFAFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFAFAFFFFFFFFFFFF
FFFAFAFFFFFFFAFAFAFFFAFFFFFFFAFAFFFFFFFAFAFFFFFF
FFFAFAFFFAFFFFFAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFE3FFF3FFFD
FDFDFDFBFFFDF7FAFFFFFAFAF8FAF7FDFFFFFFF4F4F4EDEB
F1F7EBF3F2F0F0F6F5EFEBF5F7EFEEE9F0F0F7F7F7FAF8FF
FFFFFDE7F1F5F2F8FCF6FCFCFFFCFAFCFCFCF7FCFCFAFCF8
F7F9FCFCF9F9F9F5F6FAFCFCFFFAF9FDFFFCEFBFCBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFAFAFAFAFFFAFAFFFAFFFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F2F6F7FFFF
FFFFFDFDFFFDFDFAFAFFFFFFFAFAFBFBFFFDF4FFFFFFEDF4
F4FDF5F8F2FBFAF7F7EFEFFFF7F5F4F1F5F7FAFAFAF6F6F2
FAFAF2FCEFF2FDFFF0EFFCFCFFFFFFFFFFFFFCFAFAFFFAF6
FFF5F8F9FDFAF9F3FAFFFCFFFFFBFBFFFFFDDDB7F1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FAFAFAFAFFFFFFFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFAFA
FFFAFAFAFAFFFAFAFFFFFAFAFFFFFFFF
F7FAFAFAFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F2F5FFFFFF
FDFDFDFBFDFAF8FFFAFDFDFFFFFFFDF7F4F4FDFFFFF7F6F3
F2F8FDFFF7F7F7F5F7F7F1F1F1F6F5F7F1F6F0F9F7F4F4F0
F2F2F6F6F8F1FFFDE7FCF5F5F2FFFFFFFFFFFCFCFCFCF7F6
F9F8F8FCFAFAFFFCFCFCFFFDFDFCFCFFFFFDD6B9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFAFAFFFFFFFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFAFA
FFFAFAFAFAFFFAFAFFFFFAFAFAFAFFFF
F7FAFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFAFAFFFAFAFAFA
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7EFF3FFFFFF
FBFDFDFFFBFAF8FAFFFDFDFFFDFDFDF1EFF4F4EFF1EDE9ED
F2EFF4F4F4FDFDFCF7F9FAF1F6FAF6F8F7F6FDF0F7F4F7FB
FFF7F1F0F7F1FEF2FAF5EEECF1EAF2FFFFFFFFFFFFFFF7FC
F9FAFCFAF9FCFAFCFCFFFCFAFDFDFDFFFFFDC6C5FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFAFAFFFFFAFFFAFFFFFFFFFFFFFFFAFAFFFAFAFAFA
FFFAFAFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFADAEFF6FAFFFF
FBFDFDFDFDFDFDFDFDFFFFFFFDFFFFF4F4F4EFF4F3EDF5F8
F4F4F7FFFCEDEFF1F4F4F7F7FFF6F9FAF9F9FCF9F1F7F7FB
F1F6EEF3FEFEF1F0FAFCFCF1EAF0F6EAF2FDFDFFFFFFFDF5
F7FFFCF9FAFFFFFAFAF6FFFCFFFFFFF7F7F7B4DFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D6F4F6FAFFFF
FDFDFFFBFFFDFFFFFFFDFDFDF4F6FBF4EFF4F4F4F4F8F1F1
FDF7FDF6F4FDFDFFF6F6F0F9F7FAF6FAF6F3F2F6FAFBF3F3
F9F7F7F7F4F7FEF9F1F7FFFFFCF3EAF0F7EFFDFFF7F7FDFD
F7F6FAFAF6FAFCFCFAF6FCFDFDFFFFF7F7EDB7EBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFA
FAFAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4F7F3FFFDFD
FDFDFDFDFFFFFDFFF4F4FBFDF7F4FDEFFFFFF4FFEDEBFDFB
F6F4FDFDFFFDFBFBF7EFFFF6FDFCF5FCFDFCFAF7F3F5F5F5
FDF6FAFEFAF1F3F3F1F1F3F7F3F8FFF3EBFBEFFFF7FFF3F7
F7F6FBFBF7F9FCFCFFFCFDFFFDFFFFFFFFDEB9F1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D7F7F3FFFDFD
FDFDFBFDFDFDFBFDF3EFFDFDF6F4FFEFFFFFEEF3F3F3FAF7
F7FAFAFAFFFFFDFDF4EFF4F7F1F5F3FFFFFCF9F5F5F0F3F3
F1F9F9F7F7F7FDF8FDF4EEF9FAFDF5F3F3F5EFEFEAF5F7F7
FFFFFFFCFFFCF9FBFFFFFAFAFBFDFFFFF7D1BBF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFD7FCF5F7F7FF
FFFDFDFBFDFFFDF7FDF4F4F1FDFFF4EFF4EFF3FAFAFAFAFA
F8FAFAF8FAFAFDFDFDFDFDFDF7F4F6F9FAFCFAFCFAF6FAFB
FAF7F5F7F5F5FDF5F5F3FDF1F6FBF3F3FFF3FBEDFAF7EFF3
F7FFF7FAFFFFFDFDFFFFFCFCFBFFFDF7F2C2D4F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFD7FBF8F7F7FD
FDFDFBFFFBFDF4FDFFF4EFF4F7F7F7F7F7FDFAF8FAFAF8FA
F8FFFFFAFAF8FFFDFDFFFFFDF4F4F7FDFCFAFCFFFAFDFBF9
FFFAF9FAF7F4FDF9FDFCF6FDF3F1FBF7F4FBFCF3EAEFF8F8
F3FFF7FAFFFAFAFAFAFFFCFDFDF7F7F7F1B8EBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAF7FAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDD9F6FAFFFFFD
FDFDFDFDF4EFFFF4EFF1F7F7FFFFFFFDFDFDFAFAFAFAFFF8
F8FFFFFFFAFAFFFDF7FAFAFAF9F1F1FAFBF7F5FCFAF5FAFC
FCFDF4F5FCFBFCF9FFFFF5FDFDF9EFF1F1FDF9F3F4F8EFFA
EEF2FFFCFAFFFFFCF9FFFAF4FBF7FFF3DCB8F1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFAF7FAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFAFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFAFAFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFE3F7F7FFFFFD
FDFBFBFDF1F4FFEFFDF7FDFFFFFFFDFFFAF8F8FAFFFFFAFF
FAFFFAFAF8FFFAF8FAFAFAFAFFFAF4F1F5FFFFF7F9F5FCFA
FFF7F7FDFAFCFCF7F5F5FCFDFFFCF2FBFBF7F6F1F4F7EFF3
F5ECFFF7FCFCF7F5FAFCF3F5FCFFF3F7D8BDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFA
FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFAFAFAFAFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F2F6F7FFFFFD
FDF6F1F1FFF4EFF7F7FDFBFFFFFDFFFFFAF8FAFFFFFFFAFA
FAFAF8F8F8FFF8FFFFFFFFFFF8FFFDFDF7F4F4F6FAFCF5F6
F6F5F4FCFCFDFCF9FDF7FCFDFFFCF9F1F4F8FAF9F8FCF3F6
EDEFEFFCF7F6F5FCF7FCFAF7FFFFF3F7CBC5FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFA
FAFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F2F5FFFFFFFF
FFF3F4EFFFF4F4F7FFFBFFFDFDFFFFFFFAFAF8FFFFF7F7FF
F8FAFFFAF8FAFAFFFFFFFFFFFAF9FDFDFDF4FDFDF1FDFDFE
F7FBF9FDFAF9FAF9F9FDFFFAFFFCFDF3F7F6FFFFFBFFF9F3
E7F8F6FFF7FCFCF5F7FAFFFCF7F7F3FFCBD1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFAFAFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3E0F6FFF7F7F7F7
F3F7F4F4F4F7FFFDFDFFFDFAFAFFFDF9FAFAFAFFFFF7F7FF
F8FFFAF8FFFAFFF7F7FFFFFFFAF9FDFDFFFDF7F7F3FDFFFD
FCFBF9FDFAF7F4FDF7F5FAFCFCFFFDFDFBF2F6FFFBFDFDFC
F5F7F2F2F4F1F7F7F3FAF7F6F7F7F3FAC2D9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFAFFFAFAFAFFFFFFFFFAFAFAFAFFFAFAFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0E0F5FCF7F7F7F6
F4F4F1F4FFFDFFFFFDFDFDFAFAFFFDF5FAFAFFFFFFFFFFFF
F8FFFDF9FFFAFFF7F7FFFFFFFAFAFFFDFDFBFDFDF1F6F4FF
FFF9F9FCFDFCF9F9FDEFFDFCFCFFFDFDFBF6F3FBFAFAFFFF
FAF1F2FFEEFAEEF1FCFAF9FFF7FFF3F6B4F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAFAFAFFFAFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFAFAFFFAFAFFFFFFFAFAFFFAFAFAFAFFFAFAFFFAFAFA
FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEBB8CFE2FCF5FFFDF6F4
F4F7FFFDFDFDFDFDFDFDFFFFFFFDFDFAFFFFFAFAF8FAFFFA
FFF9FFF9FFFAFFFFFFFAFAFFFAFFF8F8FAFDFFFDF3FAF6FA
FAF9FCFCFDFDFBF9F6F1FAFAFAFDF6F6F9F6F2F7FFFAFDFB
F7EFF2E8F6ECFFEFFCFFFAFFF7F7F7F7B3F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFAFAFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFAFAFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEEB5A4CADEF3F7FDFDEFF4
F4FFFDFFFDFDFFFFFDFDFFFFFFFDF7FAF8F8F8F8FFF8FFF8
FAF9FDFFF8FFFFFFFFFAFFF8FAF9F5F8FAFFFBF7FCF4FCF9
FCF6F8F5FAF7F7F3F5F2FDFDFCFDF6F4F9FBFAFAFBFDFDFD
F9F5F5F0EFFAEAFBF5FCF7FFF3FFF7EBB5F1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA7CBA99EBF7FDFDF4FFF1
F4FDFFFAFAFFFFFFFFFFFFFFFFFFFAFFFFFFFAFAFAF8FAFA
FFFFFFFFFAFAFFFFFAFAFAF8F9FFFDFFFFFDFFF4F7F5FAF1
FCF6F5F5FAF7F9F5F7F5FDFFFDFEF9FBFBFBFBF6F5F6FAFF
F6F5F7FFF7F7FFECF2F2F7F7FFF3F3DCC0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFFFAFFFAFAFAFAFAFAFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD65094BF8FF8F1FDF4FDF4FB
FBFFFFFAFAFAFAFFFFFFFFFAFAFFFAFAF8F8FFFAFAF8F8FF
FFFFFFFFFFF8FFFAFAFAF8F8F7FBFFFFFFFDFDFBF7F4F4F0
FCF8FBF8FFFDFCFAFAF7FDFCFFFFF9F6F6FBFBFAFBFAFAFF
F6FAF6FAF7F3F7F2F1EFF8F7FFF7FCD7C1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE5735CED989CF1F4F4FDF7FBFD
FDFFFAFAFFFAFAFAFAFFFFFAFAFAFFF8FFFFF8FAFFF8F8FF
FDFDFDFDFAFFF8FAFFFFFDFDFDFDFFFFFDFDF4F6F7F4FFF9
FCFFFDFFFAFBFDFDFFF9FAFAFCF9FFF6FFF3F6FBFFF8FAFA
F7F6FFF5F7F3FFF7EAFBF3F4FFFFFBCEC7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFAFAFFFAFAFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F58C4FC1E7A286F8EDF7F4FBFFFD
FFFFFAFAFFFFFFFAFAFAFAFFFFFAFFFAF8F8FFFFFFFAFFF9
FDFBFDFDFAFFFAFFFFFFFDF7F4F4F4FBF7F7F6FFF5F9F8FC
FCFCF8F9FDF6FCFCFDFDF5FDFFF6FDFFF6EFF5F6F8F5F8F8
FFFFFAF6F6FFF7F7F2F3FBF8F8FFF7C0D6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFAF7F7FFFFFFFFFFFAFAFFFAFAFAFAFFFAFFFAFAFAFA
FAFFFAFAFFFAFAFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA5373EA3EDC37F92EDEDFDFFFDFFFD
FFFFFAFAFFFFFAFAFAFFFFFAFFFFFAFFFFFAFAFAFFFFFAF9
FBFDFFFAF8FAFAFAFFFFFDF1F4F7F8EEF5F3EFEEF3F3F7FA
F8F0F5FDF7F9F7F3FAFAF7FCFCF6FDFBFBF8FAF4FBFBFFFF
F8F8FCFAFAFDFDFFF7FAEAEFF2EAEFB4DFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFAFAFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFAFAFA
FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF738A9F0DAFB5E86E2FFFFFDFDFFFDFF
FFFFF8F8FFFFF8FAFFFFFFFAFFFFFFFAFAFAFFFAFFFFFFFA
F8F8FAFAFAFAFAF8FFFFFDF4F7F8F7FCF5F3F3F2F7F8F8FA
FFF7FFF3F5F6F3F7FFF7FAF6F9FFFFFAF6F5FAFFF3FBFAF8
F5FEFFFAFFF9FCFCFAFFF7EFEBFBEFB5EBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7D320F6E4E86A54DBFDFDFBFBFBFBFFFF
FAF8FAF8FFFAFFF8FFFFFFFAFFFAFAFFFFFAFAFFFAFAFAFF
FAFFF8FAFFFAFAFAFDFBFBFDF0FBFFFAFAFFFFF6F5F7FFFF
FFFFF7F3F3FAFAFAF9FAFAF6F8FAFBFBF9F4F6F8F9F5FFFA
FAF9FAFAFFFDFCFAFCF7F7F7EDE7FCBFEDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFFFAFAFAFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEE7377EDEE7C53DAFCFDFDFFFDFDFDFAFA
F8FAF8FAFAFFFAFFFAFFFFFAFFFAFAFFFFFFFFFFFAFAFAFF
FAFFFAFAFAFAFFFFFBFDFBF6F6F9FFF8FAFAFAF1F5F8FDFF
FCF6F3F3F3FAFAF5F8FAFCFAFBFDFAFFFFF9FAFFFBF8FFFA
FCFCFAFAFAF9FCFAFCFFFFFFFFEAF2BCF3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFAFAFAFAFAFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFA9C4CCCF39C5ED2F4F6FDFBFBFFFFFFFAFA
FAFFF8F8FFFAFFFFFFFAFAFFFFFDFDFFFFFFFFFFFFFFFAFA
FFFFFFFAFAF8FFFFFDFFFBF6F7F3F8FAF8F8FAFAFCFBF9F3
FAF6F5F8F5FFF7FFFFFAFAFEFBF4F7FDFFF9FAFBFFF9FFF9
FAF9FDFEFCFDFFFAFAFBF6F7F7F5F8B3F3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFAFAFFFFFAFAFAFAFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7BB55A1E8B16CC2F4FFF7FDFDFDFFFAFAFFFF
FFF8FFFAFFFAFFFFFFFFFFFFFFFBFBFAFAFFFFFFFFFFF8FF
FFFFFFFAFFF7FDFDFBFDF4EEEBF5FFFFFAF1F7FFFFF7FFF7
F5F6F9FAF5F7FFFFFFF5FAF6FAF6F9F7FBF4FAFBFAFFFAFC
FFF9FDFBF9FDFCFCFFF9F9F7F3F7F1C9CBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFAFAFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7EB5581F0B46EBAF4FDF6FDFDFDFFFFFAFFFAFA
FAFAF8FAFAFAFFFFFFFFFFFFFFFBFBFAFAFFFFFFFFFAFAFF
FFFFFFFFF8FDFFF1F1F3F5FBF9FDFFFFFFF7FFF3F3F7F7FF
FCFAFAFAFFFFFDF6F6F8F8F6F9F6FFFFF8FAF6FAF3FAFAFF
FCF9FFF9FDFAF9FBFDFCFFFCF3F3EFEDBEE2FFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFAFAFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFFFAFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7BE3B55D3DC55A7FFF4F4FBFBFBFDFAF8FAFAFFFF
FFFAFFFAFAFDFBFDFFFFFDFBFDFDFDFFFFFFFAFAFFF8FAFA
FAF8F8F8F7FDFBF1FFFDFCF8FCFAFCF4EFEFF4FCFCFAF8F1
F1F8F8F8F5F5F6FDFDF6F3F5FAF8FAFAFFFCFCF4F9FAFFFA
FAFAF8FBFCFDFCFDFFFFFAF9FFF7F3F8D7BCCBF1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFAFAFAFAFFFFFFFAFAFFFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEE6D79FFE9926DEEF4FFFFFDFDFDFFFAF8FAFAFFFA
FAFAFFFAFAFDFDFDFBFBFDFFFBFFFDFBFDFFFAFAFAFAFAFF
FAFFFFFFFDF7F6F6F1FFFDFAF8FAF7F7FFFFFFFFFFF6F4FD
FCFCFDF3F7FFFFFFF6FBF9FFFAFAFFFFFFFCFFFCFAFAFFF7
F7FAF7FDFAFFFAF9FCFEFAF9FFF6F9F8F7E4C9DFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFAFAFFFAFAFFFFFAFAFFFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7B944CAF3B46BC0F4F4FDFDFDFDFDFFFFFFFFFAFFF8
FAFFFFFFFFFFFBFFFFFFFFFDFFFBFFFDFBFFFFFFFAF8FAF8
FFFFFFFFFFF3F7EEF1FDE3D6DDE6E6EAE5E4E4E5EFEEE8F0
F6FCFDF3F8FBF9F5FAFAFAFCFCFFFFFCFAFCF9F9FFFFFFFA
FDF9FAFDFCFAFEFCFAFEFAFFFAF6FCF5FFF2D9CCF1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF76776F4D568ACFAFDFFFDFFFDFDFDFDFFFFFFFAFAFA
FAFFFFFFFFFFFBFFFFFFFFFDFFFDFBFDFDFFFAFAFAF8FFFA
FFFFFAFAFFF0ECFFE2D6FFE1F7FFF1F5F8FAFAF8F0ECEBF0
E8DFE3F2FFF9F6FAFDFAFAFCFCFAF9FFFCFAF7F7F7F8FAFF
FCF9FDFFFCFCFAFAFAFFF9FFFAF7FAFAFAF2EBBFD4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFAFAFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFFFFFFFAFAFFFAFFFAFFFAFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEE3EB1E5778FF3F1FDFDFDFFFDFDFDFDFDFDFAFAFAFA
FFFFFFFFFDFDF7FAFFFFFFFFFDFDFBFFFFFFF8F8F8FAFAFA
FAFFFAFFFAECFFFFE1DBFFE1F7F2F2FFFFF4F4FFFAF8F2FF
F4FAF6ECDEE3F1FFFBFDFAFCFCFAFCFAFCFBFFFCFAF8FAFF
FCFCFAFAFFFFFCFAFBFDFAFFFAF5F9F5F7F5F7E2C2DBFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFAFAFFFAFAFFFAFAFFFFFAFFFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFBE49D6A062EBF4F4FFFBFDFFFFFFFDFDFDFDFAFAF8FF
FFFFFFFFFDFFF9FAF1F5FAFAFAFFFBFFFFFAFFFAFAFAFFFA
FFFAFAF1E7F1FFFFF8F8D6FFFFEDFFFFFFF4F4FFF1F1FFFF
F4FFF4FAF7F8F0EBEFFDFDFCFFFAFCFEFDF5F7FFF9F9FAFA
F7FCFCFCFFFFFCFAFBFCF9FDFBFAFCF5F7F7F8F1D4CAF1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF706FE565AAEEF4FDFDFDFBFDFDFFFBFDFBF9FAFAFAFF
FFFDFBFBFBF7F9F0F9F7FAFAFAF4FBFFFFFAFAFAFAFAFAFA
FFECE7ECFFFFE3E3FFFFE2DDEEEDFDFDFFFFFFF8F1EDFFFF
FFF4FFF4FFFAFAFBF8F2FDFDFCFAFAF9F9F3F3FCFDFFF9FA
F7F9FAFFFFFAF8FAFAFFFAFAFBFCFFF5F7FFF2F7EBCECEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D09240EF5281F7ECF1FFFDFDFDFDFDFDFDFDF7FDFAFFFFFF
FFFBFFFFFAF7F4F4FCF8FFF4FAF3FBFFFFFFFFFAFAFAECE7
E7F1F9F9FFFFE3C6D6CCC3C9DBECF8EDE4E9E9E4F0F2F9F9
F4F4F1F1FDFFF4F4F7EFE7F4F4F6F9FAF5F4F4FBF7FAF9FF
FCF9FAFAFAFAFAF8FFFAFAFAFAFCFFF7FAF3F6F5F8EABFCA
FFF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DA
87BD7F679CF4F3F7F6FFFFFDFDFBFDFBFFFDF7FAFFFFFFFF
FFFDFDFFF8F6F5FAFCF8FAF0F1FAFBFFFFFAF8FAFFF1F1FF
FFECF3F3ECFFEBDBEFF0F9ECE7EAEDF3FFF0F2F1F6F9F8FB
EDECF3F6F1F0F0F0FAEFF6F4FCF9FDFCFCF6F8FAF8FCF8FF
FFFFFAFAFAFAF8F8FBFBFFF7FFFAFFFFF5F5F7FAF7F1F4B2
FAF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF584
87C0D13DEAF7F7FFFFFBFDFFFDFFF9F9FDFBFDFFFFFFFFFF
FFFDFDFFF8F5F9F0FCF8F4F6EFFAFBFFFAFAFAFAF1F1FFFF
FFECECECE1DBD9E7E5E7EAEBF7FFFFFFFFF3EDEDEDEAEAED
F3FFF7F4F4F7FFFFF0F0EEEBEFF0FAFDFFF6FBFBF8FCFAF9
F9FAFAF8F8FAF8F8FBFFFAF7FAFCFCFFFAF9FAF5FFFAEFB8
EBFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7BC72
D0CD7390F2F7FDFDFDFFFBFDFFFFF8FAF7FDFFFFFFFFFFFF
FFFBFFF4F8F5F5F3F6F5FCFBF6F4FBFAFAFAECECF1FFFFFF
FFF4E8DCDDDEEFEDF3F1E4DCF3F0E8EAF4F6EFEFFBFFF7F7
FFF7F7F7F7F7F4F7F4F8F2FFF7F8F2FCFCF7FBF9FAF4F8F9
F9FAFFFFFAFAFAFBF6FAFAFAFFFAF7FAFAF9FCFAF7F7F1C8
E8EDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE38198
CBCC0AF2F4F7FDFDFDFFFDFFFFFFFAFAF8F7FAFFFFFFFFFF
FDFDFFF1FBF1FAFAF0F0F5F5EFF5FBF8FAFAECFFFFFFFFEB
DCDDE6E9EBE7F9FAECDADDDEC7C6CAC5D0D7CEC1C8CFDEF6
F7F7F4F4F7F7FFF7F7FAF5F6F2FFF6F1FDF5F8F4FEF8F7FA
F8F7FAFFFAFAFBF5F3FFFAFAFAFAF7FFFCFFF7F9FAFFFAD7
D1F0EAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFAFAFFFAFAFFFAFFFAFFFFFFFFFFFFFF
FAFAFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E99091B4
CAD824ECFCF7FFFDFDFDFDFFF7F5F8FAF6F9FAFFFFFFFFFF
FBFAFAF5F7F5FFFFF7F7FFF5EAF7F9F8EBECF2F4EFE8DBDB
E9EBDDE2F2F3DEBBC0CEDBECB9AAF2F5EAF1BEBAFFEED4D4
D9E3EFF7F7EDF7F7F7F6FBFFF6F6FFF2F0FAFAF3F9F9FBFF
FFFAFFF8F5F5FAFBF9F5F9F8FCFFFAF9FFFAF8FFF8FFF7EF
C8DEEFEDEDF0F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFAFAFFFAFAFAFAFFFAFAFAFAFFFFFAFAFFFFFF
FAFAFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7B287C1BC
E9886CF1F4FFFFFBFDFBFDFFF7FAF8FAF4FFFAFAFFFFFAFA
F7FAFAF1F6F5F4F0F4F4F4EEF3F5F8F0ECF4E0E2EFEEE7EA
DCD4C8D8DFE8D0DBEDE3E6F0EAD2E4E8FAF3D7CDEFE9EDD1
C4C9E3E0E2CCD0EFF7F6F3FBFFF6F6FEF8F7F8F4F4FFF7FF
FFFAFFF8F6FDF6F9FFFBF6FAF9FAFCFAFFFAF8FCF5FFF3F3
EFC9F9F7FFF9F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFAFAFFFAFAFAFAFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF185BAC3D5
E069B4F6FFFFFFFDFDFFFBFFFAF4FCF5F4FAFFFFFAFFFAFA
F7F8F5FAF9FAF0FFF8F5E9E7F1FAEBDDE3E1EEF9F6EAC4C4
DDFFE3E3D9FAF0C4BDB4B4C3D5D5D9ECE4EEE3DBF3F0F5D5
CACAECD9D2D6DED6F1F7F4FAFFF6FFF6FEF1FCFAF3F9F7FC
FFFAFAFAFAF7F2FFF4F4F4FAF8FAFCF8FAFAF8F9F7FFF7F2
FAD1E1ECEDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFFFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEBDA8D1B5E0
896DDCF7FFFFFDFDFBFFFBFAF1F9F6F1EAFFFAFAFAFDFBFD
F2F1FFFAEBE9E2E2E8EAD9E9F3D1BED6E5E4DCC7885CB59F
96CBF3DCD4E5E6FFD5AA92838CAAB8D0EBD5E3EDCDC2B9B7
DFD5F8F0DCC3D9E0E6D2D3E9EEE7F3FAF7F7F8FBF7FEF8F7
FFF8FFF8FFF5EFF8FDFDF9F4F5FAFFF8FFFFF8F9F5F8FAFA
F8E5DDCEE1EBF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFA0E6ACA3EA
4AC0FBFFFFFDFFFFFFFBFDF4F9FCF6F4E7FAFFFFFFFDFBFD
EAFFFAEEECF8F2F8F3D6E5F5D6CADFD9B1BCF7D077515AAA
C9A6B3A9B2BFC9DFA8CFF5FFF6F1F1DBB1B3B1B6A0A0ABB7
E4EBD2E4F6DEE8F7F2ECE3D5EBF3E7E9E5F6F5FBFFF8F5F7
FDF9FFF8F9F6F7F4FCFDFFF6F8FFFFF8FFFAFFF5F9FFF9F7
FFEAE4EEEAD9CDF0FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0B0D888C88E
61F4FDFFFDFDFBFDFDFAF8F4F6F3F3F0F4FFFFFFFFFAFAFD
ECFAEEEDF5F6EFF5EFDAEDBBBCD4BB78AEA2BBB0C9B1A9E6
FFDBC6D1E7D6BDB8ADF5FFFAF6FFEEEED6EDF3EAF7ECE5BF
ACB6DFCFD7D4E9ECE8D8E4D2DEF5EFFFF0EFF2F7FFF8F5F7
FDF9FFF3F6FDF5FAF7FDFDF9F3FFFAFAF7FCFAFAFFF9FAF7
FFF8E0DED8CDF0D6D8EBFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7ECBCE9CF65E
AAFCFFFDFFFDFDF9FAFAF8FAF3F6F3E7FDFFFFFAFAFAFAFB
EEF5F1F3F6EFECF2EFE2C4BCD1C0C8C75E93DBDAF3F1E5FF
FFFCF9F7FAFFF3DAD6F7FFFFF3FFF7FFE1F0F1FFF1FFFFFF
EDC5ACE2F3E9F9E1F4B8ECE5DED6F3EFEEEAEEF6FBF8F8FC
F7F9FFF3F6FDFAF6F7F6FDF9F3FFF8FAFCF7FAFAFAFCF7FF
FFF8EDD2E4EAD2DBEAD8FAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFAFAFFFAFAFFFFFAFAFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5AB1CCD0CF47
EAF6FFFDFFFDFDF9FAFFF4FAF3F6F2F2FFFFFFFAFAFFFFFB
EEF5E9F8EDECEFE6EAD0B5C3C4DBF1C48BDBEEF5FFEFF1FF
FFFCFCFAFAF7F7F3EFF7FFFAF6FFFFEEEBF0E8EEEBEBF1FF
FFD0C3A6B0B7D4E8D5C3EAD6DCCCD6F0EBE5F9F2FCF8FFFC
F7F9FFF9F4FFF6F7F7FDF4F6F2F4FAFFFFF8FFF9FCF9F7FF
FFFAEBDCDDEAFADBD7EBEDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFAFAFFFAFAFAFAFAFAFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF1F1F1F1F1F0F7FAFFFFFFFFFFEE4DB5E5E8B34C
EEFFF6FDFDFBFDFFFFFAF1F9F6F5E7FBFFFFFFFFFFFFFFFB
E9EBEBF6EEEBFFF5CCBDBFD3E6E8D5A8ADECEFF3F7F7F7FF
F1F1FCF7FAF3F1F0ECF5FFFAF6FFF7E5EAE7E6EDF1F1FFF1
FFDBEFE5CDB28FB3F0E7DBF0E6BCA5E0E8E8E5EEF3FCF9F7
FCF8FFF9F4F7FDF7F7FFFFF4F4F4FFFAFFF8FAF5FCFCF5FF
FFFFF6E6E3E4DBF4FCF1FAEDFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFF
FAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF1F1F1F1F0F0F0F1F2EAEDFAFAFAFFD273ABE8F27E79
F4F7F4FBFDFBFDFDFDF8F5FCF6F8F0FDFDFFFFFAF8FAFDFD
DDF4F5EDECEDF8C7CADAE4F4FDD1D9A5DDE1E1FFF1F5F1FC
E9E9FFFBF7F3EBFDE9F3FFFFF3FFEFE9E7D7E7EDF1F1FFF1
FFE6FDE5EDEDD27EBAD8AEBADCDFA8ADD6EBEDE4F2F8FBFF
F8F5FFF8F6F4FFF7FFF7FFF6F1F3F8F8FCF7FFF5FCFFF8F7
F5FAF8F4DFC0ABCCD2D6F6FFEDFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFF1F1FFFFFAFAFAFAEEE6EDFAFAF4D79D8CACE2CC4DC4
FAFBFDFDFFF7F9FDF7F1F9FFF6F1F5EEF2FFFFFAFAF8F7F4
D5E4E8EEEBFEF59EF2E8E3F2F8C9C0D7DBDDDAAEC7ECF4DF
E2E4EEFCF6E5D8E1DDE5F7F7EEEFE4E6E9DDC8E0F1F1F1FF
E6D1DEEDEDFFEDBC99929453857D7EE78595E1DBD5E4F4F1
F7F5FFF3F6F4F7FAFAFFF7F7FCF8F8F9F7FCF5F7FAFCF7F9
F7FAFAF3F6D0A771A9C9D1E8EAF1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFF
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFECD287A2CBFB817EF4
F1F4FBFBFDFAFAFFFAF0FFFCF5FAF1F5E5FFFFFAFFFAF7F4
D8DAE7F0EBF8F6A3CEE5DEE3EDC3AEF6E0DCD3F0D3E2F4E9
F4E9E3F7FFDFDCECEBEBEEF3EBECDBE0F3F6ECE8EEF1FFFF
D3DDBCEAEDECF8ECE0F2EACB96A1A066AAB9E0E8E0E0E8F5
FAF7FAF3F6F1FFF8FAFAFCFAF4F7F4F7FFFAF7FCFCFEFCFA
FFFAFFF0F5D99790C0E9E8E1E9E1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFAFAFAFAFFFFFFFAFAFFFAFAFAFA
FFFAFAFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFDA9C64A9EDEE54B5ED
F6FDF4FDFFFFFFF5F0F5F6F3FAF5F3F6E5FFFFFAFAFDFDE9
CFDADEECF0F3E7C5BABEBFBEE0D0BDF2E7EEEFF3E4D8E3F0
E2E1D4ECE7CCEBE1F4EFE3DECFC9D1E5E7E6E9E0E5ECEFE3
C5E1C1F0EFF4F7E2DEE8FFF7DCECEF99BCE9E1E9DDD2EAF6
FAF3FAFAF1F4FCF8FAFAFCFAF7F6F4FFF5F5F5FDFAF9FCFA
FAF8FAFAF4F8C7BEE5ECF5EEDAC9EEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFAFAFAFAFFFFFFFAFAFFFAFAFAFA
FFFAFAFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAEAC687637BCCE8D345EDF1
F0F4F4FDFFFFFFF4F9F6F6E7F7F3F6F6E5FFFFFFFFFDF6E9
D3DBDEFAE7E7E3E7DDD8C79F94B7DCFAEFFDFDF6ECE4D1CD
DCE7C3CCCCC8E7E4E8F2FCE9C1D4E6ECE3E5E7E4E0DCDCD7
CDE6C7D4F3F7ECCFF4EFFFF4E7EEF1CFDEC1F4DCDBCDD7EF
FBF3FAFFECF5FCF8FAFAFFF3FFFCF2FFF7FFFBFCF7FAF9FF
FFF8F8FFFCEEE9E9E4FBF5F7EEE2D6EEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFEED2A4706CB4E0E8F6955EF4F2
F1FFFDFDFDF9F5F4F9F5F6EEF1F0F4F1E5FFFFFFFFFDF3EE
D9D0ECE0F2E9EBE8E7E1E0DCCDBEBED1DBDDE3EAEAF9E8E6
F4F6F0DDE7F1F1E5D9CEC7D0D9EAF2F7FBF0E0D9DDDFE1E0
E6F8DBC3F0F0DDD6D8F8F0E7F3F6E8D8DBB5EAEDDECFC5E3
F5F6FCFAEDF3FCFAF8FAFFF3FDFAF6F7F5FAFDFDFBFBF8FF
FAFAF8FFFDEED7F6E7DBDAF6F3F9DBE8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAD4856B7FC1E2F5E2F05E87F1F1
F3FFFDFFFFF9F5F5F6F3F5F7FAF5EDDFF0FBFDFFFDFFF2F6
D6CBF1D9F1EBF3E9FDF6EFE8E1E0D9CDD5E3DFDFE2DCD4D8
DFE6D8CBD9E6E6E6EDF0F0E6DDF2F3EBF0F6F4FFF1E5DDE3
F5FEFAC8E1E1D3DBD6E2E5D7E9E9F3D4E5A8E4EDF0D7C6C6
F0F0FDF8EFF2FCFFFAFAFFF7F4FDFBF4F9F9FFFFFCFDF7FA
F8F7F2FAFFEBC4E6EAEFCCEAF2EAF1E4EEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFA8E58AECFF4EBF3EBEF42B3EEFD
F4FDFDFFF7F8F4F6FFFCF7FFF6EEF5DDF5FDFFFBF4F4F2FA
DACBFECFE7F1F3EEF6F4FDFFFDFBF7F7F1ECE7E3E1E7F0E8
E3DFE2F0E8E1ECECE8E8FFF7F5F1F0F0E7F0F0ECFAF2F7F3
EFEBF0D9E1E1D2EAE3D5E8D9E2E3F9C7F3A8DDEFE6E2D2B9
CDF2F9FAF3ECF7FFFAFFFAFFF0FFF6F8FAF5FDFFFEFCFCF7
F9FAF5F8FFEACECBF7F7D6E8DBFAE3E5E8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEBE2D12B95D9ECE6DCEEEDA843DCEDF1
FDFDFDFDFAF8F2FCF6F5FCFBFAF1EEE7F8FDFFFDF7FFF4F1
E4D9DDE1CEECF9EBF1F9FFFAF8FAF8FAFAFAF8FAFDF1E7E4
E4DFDFE4E4E0F3DBDEE2DAD6DADFDFDFD7D9E0D8DFE2D9DA
D4D9EAF3EBDAE6FFECCED6D9D8D3BFC4DDBBCCF0E5DFE6E4
ADBEF2F3F0F6F1FFFFF8F8FFF1FDF2FAFAF6FDF8F7FBFCF9
FFF7FFF5FAF0BC6C5099DDF0FDECF1E1EBF1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE2FFCE22EFE3E0E0F1F0ED7D78FDF4FC
F7FFFFFFFFFAF2FFFCF9FFF8F7F8F0FAF5FFFDF4F7F1F5F6
E8F6DDEFCFE6F3EBF7FFFAF8FAFFFFF8FAFAF8FAFFFFF8FF
FFFFFAFAFAECE3EFF1EAECF4F7EFF2F8FBEBE5E5EBE8E6EE
FAEFEEEAECEBE5EBEBF0EFE7EBE7EDEFECD7CFE7DBE8FBF8
E499F8F9E7F3F4F7FFF3F3F7F4FAF4F8FAFCFBF6FBFBF7F9
FCF8FAFAF8F0B3ADA7A4E2F0FBE9DAEDF9EBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD6CFA543F2EBEBEFEEE0F76C93FBF6FD
F7FDF4F4FAFAF9F9FDFDFCFBFBFDFAFFF5FFF4FDFDF7F4FA
E8FBEDE5E6D2E9ECFBFAFFFAFAFAF8FFFFFFFAFAFFFFFAF8
FAFFFAFFFAFFFAFFF9EFF0F0F3F0F1FFFCF6FBEBF1F5EAE4
E4E3ECF6EAE8EBECE8E9FAF4ECDAD7E2DCC9BBBFCEDCD6CF
D89EF4F7F1EFF4F7FFF3F3F7F4FDF8FFF8FCF9F7FBFBFAF6
FCF8FAFAFAEBCD94E27E94E4EAEDE8EDF1EBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD2ABBE6AFBD8F0EEE1F9DA4ABDF4FFFD
F4F6FCF4F5FCF6FDFAF4F6F6F6F6F7F9F3FFF4FDFDF1F1F6
EAF9F3E9F2D2E1DEFBFFFAF8F8F8FAFFFFFFF8F8FFFFFAFA
FAF8F8FFF9FDFFF9F7EEFAFAF5F6F6F6F6F6F5FAF4F1F3F1
FDF7F2F0F6F7F1EFF3F1E7E9EFECE1D9CEBDA7A9B0B6D2E5
DACAF0F1F5EFF0F4F4F8F8F7FDF4F2F8F7FAFDF7FFF9F9F2
FCF9FCFAFFF4E687F2D65F90F3F3FFF1EBEBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDD62ACB9A28A77727897BD48E8F4F7F4
F4F7F7FFF5FDFBFCF4FDFDFFFFF7F1F4FDF7FFF7FFF2F7F4
EAF9F8EFE8EDDFDFECF4FFFFFFFAFAFAFAFFF8F8FFFFFAFA
FAFAFFFAFDF9FFFDFDF2FAFFF5FFFFFFF7F7FFF7F7FFF7F3
FFF9F9FBF6FBFAFFFCFCFFF4EFF2EFEDF2FBFCF2F0F4ECE1
E4F8EBEFF2EBF2F2F0F8F8F3F7F4EFFFFAFEFAF7F7F7FBF0
F8FAF7F7F7F4EF8DCABBEA729BEEFFF1F1F1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDD45C380597FA1B4AD819C70F4ECF0FF
F7F7FFFAF7FDF4F4F7FFF4F5F9FAF7FFFFF7FFFFF1FFFFF6
E7F5FBF6EEF3D8DCF7ECFDFDFDFAFAF8FAF8FFFFFAFFFFFA
FFFAFFFFF8F8FFFDFDF7F5F6FAFFFFFFF7F7FAF1F7FFF3FD
FAFBF8F9F2F5FFFAF9FAFAFAFCFAF9FAFCF7F1F0F2EEF4F6
F3EBEEF3F7E1F2F2F0FAFAF7F7FCEFFFF9FCF9F7FBFFF8F7
FAF8F8FCFFEEF7ADEEDEC2C895CDF1F1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFADD43D73ADCF4F7F0EEDCC4ADF4F2F4F6
F4FDF4F5FFFDF4F4F7FFF4F0F5F2FBF4F7FDFDF4FFF1F5FC
E8F8F9FFEDECF1D2F6F1EFF7FDFFFAFFFAFAFFFFFAFFFFFA
FAFAF8F8FAFAFAFBF4F3EBF6FFFFF4F1F7FFFAFAF7F3F7FA
FAFBF5FAF9F7FDFAF9F2FAFCFCFBFCFCFFFFFBFCFCF7F7F4
FBF9F0F1F8E1EBF2F4F5FAFFF1F1F4FFFAFAFFFBFCFFF8F7
F8FFFAFCFFF5F592C6BBD2C4CFBBFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEAC3629B80FDFFF7F1ECEEF8DEF4F3F3F6
FDF1F7F4F9FCF4F1F4F4F4EEF1F4FBFDFFFDFDF4F4FFF1FD
EAF4F6FFF3F7F8D7ECF9F4F4FFFAFAF8FAFAFAFFFAFFFDFD
FFF8FAFAFFFFF8FBF4FAF3F6F4F4F0F7F6FFFFFFF7F7FDF1
F3F5FAF9FDF9F1F1F7F9F7F2F5F3F6FBFAF9F8FBFCFBF8F8
F7F4F7FFF2DDF3E7E9F5FAF7F4F3F6FAF7FAFFFDFFFCFBF2
FAFCF7F5F2FAF480F69AC9F3EEC4FAFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAE1B5BA91DEFDFBFDFDF1EBF0E4ECEDF3F7
F7FFF4F4F0F1F4FDFDFDFDF1F4FFFDFBFDFDFDFFFFFFF1FF
EFF3F5F4F3F3EFEDDEE9ECF4FBF7F7FAF8F8F8FFFFF8F7FD
FFFAFAF8FFFFFAF7FAF9F3F6F4FFF4F7F3F7FFF7F1F4FDF4
F1F6FFF6FCF7FFF7F6F6F4F4F8F9F1ECF2FBF9F6F7F8FCFC
F9F8F8F7F9DDFDE0D2FFF7F7F6FBEDFFF9FBFCFCF8FBFCF5
FFFCFFFCF7EFFB5FB77CA0DCD3DBFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAF1D7D6CBF7F1FBFFFBFBFAEEF7F4F8EDF3F7
F1F1F4F4FFFFFBFDFFFFFFFBFFFDFBFFFDFDFBFDFDFDEFFF
F5EEF5F3F9FFF6F4E6ECECECF7FDF5FFFFFFFFFAFFFAF8FF
FDFDFFFAFAFFFFF5F7F9F3F5F5F6FDF8F5F4F1F4FDF8F1EF
F1F1F5F7FCFAFBF7FFFFF8FBFDFDFDFDFDF9FAFAFCFAF9FB
F7FAFAF7E5EEEEDACAF1F4FCF8FFF0FAF5FAFBFBFFFBFBF9
FCFFFAFCFCF2FA4AE89D9CA4CEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAE6D5EDF7F4F4FBFFFBFDF5ECF7F4FDEDF0F4
F7F1FFFFFFFFFDFBFFFDFDFBFDFDFDFFFAFAFDFDFDFFEEF9
F8F7FAF0F5FBFFEFF8ECEBF3F1F4F7FAFFFFFAF8FFFAF8FD
FFFFFBF9FAFFFAFAFBF1FFFAEBF5F5EEEEF0F3F8F9F1FBFF
FAFAFBFBF7F3F7FDFCFAFDFCFCFDFDFFFDFDFCFEF9F4F6F3
F4F4F7F3E6EDE6F1D8FDFCFDFCF3F5F8F7FAFBF9F9FCFCFD
FAF9FAF9FAF2EB57F9BDC69FC6EEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDDD5E6F7FDFDFDFDFBFDF9EBFFEFEDF6EDF1
F1FCFAFDFDFFFDFBFDFFFFFFFAFAFFFFF8F8FAFAFFFBF1FC
FAF8F1F7FAF5F8F6F6ECF0F1F5F1F4F8FFFFFAF8FAFAFAFD
FDFDFBF9F8F8FAFFFDF1F6F1EBF3F7F4F4FAFBF5F0EEF8F8
F7F7FAF6FCFDFCFCFDFFFCFCFAFAFCFFFDFDFBFCFFFFFDFB
FBF9FCF1F5F5F7EBF5FAFAFFF6F1FAFEF6FBFFFBFFF8FBFC
FAF9FAFCF5F1EC4FF8C9AEBBC2E4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD6E3EAF7FBFBFFFDFDF9F0E5F1F4FCFDF4FD
F4F3F3FDFDFFFBFFFFFFFAF8FAFAF8F8FAF8F8F8FFFDF4F1
F5FCEEF3F7F5F8F6F4E7ECF1FAF4EDFAFAFFFFFFFFFAFAFF
FFFFFFFDFBFBFDEDE9F1EEF0F4F6FFF9F9F4F1F8FAFFFFFC
F7FFFFF7FDF9FFFDFDFAFDFDFBFAFFFAFCFDFFFCFDFDFDF9
F8FBEEF7FFFFF1F1FFF8F3F4F1FAFAF8FAF8FCFBFFF8FCFB
F9FAFFFAF6F1EC43E5C885785B87FAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF1D2FAF1FFFBF7F8F8F8ECE7EDE7F4F6F7FFF7
F1F4FFF4FFFDFDFDFDFFF8FFFFFFFFF7F7FAFFFFFAFFFBF4
FAF6F9F6F7ECF8EFFFF4ECEDF4F2EDFFFAFAFFFFFFFFFAF8
F9FBF7F9F7F7F4FAF6FDF4F4F1F9FAF9F9FCF9E4F1F7FFF6
FFFCFAF8FAFDFAFDFBFAFDFDFDFCF9FBFBFDFEFFFFFFFAFC
F8F8EBFFFAF5F0FDF9FBF1F5F5FFFAF2FBFCFFF8FBFCFFFC
FEFDFAFCF7EFE946F0F5D5E49B68FAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF1D0E8FBF5FDFDEFF5F5F8E4F4FDDDFDEBF0F7FD
FAF5F4F4FDFDFFFDF7FAF8FFFFF7F7F7F7FFFAFAFAF9FDF4
FAFAFFF5FFF1F5EAEFF2F2F5F0F0EFFFFFF8FFFFFFFFFAF5
ECEEF2F3F6F7FDFDFDF6F7F6EFFAFEFBFBF2F0E2FAF2F4F7
F6F2F7F3FCFFFDFBFCFBFCFDFDFAF6FFFFF9FDFFFFFFFDFB
FDEDF7F6F1F5F8FAFAF6FBFFFAFFFCF8FCFCFFFFFCFAFBFF
FEFDFEF7F7F5E14CF2F7EDDE668CFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFDFDFEFF8FAFDF9ECEEF4E7EDF8EFE5FFEEEFF4F1
FCF2FBFBFDFFFFFFF8FAFAFFF7F7F7F7FFFFFFFFFFF5FBFB
F1F3F7F6F6F3FAF4FFEDEDF3E2E1E5FDFAFAFFFFFFFAECEF
FDECECEEEFF1FDFFF7F1FEF8F1F1F3F2FDF2F2ECE8F5F2EA
EBEFF1F0F0F3FDFCFCFDFFFDFEFDF6F7FBFBF9FDFEFFFEF8
EBDEEBEBF7FCFAFDF5FAF6F6FFFFFCF9F6FAFBFFFCF5F7FB
FEFAF9FAF7F5DD62CFC3CA9064B6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF1DDF6F4FDFFFDF5F5F6E9E8F5F4E6E9FDF6EFF4F1
F7F4FBFBFDFFFFFFF8FFFFFFF7F3F3FFF7F7F7FFFFFAFAFD
F4F4F7FBF1F7F6F3FFEFF8FFF6EEDEF4F8FFFFFFFAF7F4EF
F4FFFDFBFBFDF6F7FDEFF4F0FFF1F7F1FBF8F9FAF4E6E2F2
F0EDFAFAF5F5FDFAFDFCFCFCFDFFF4F8FBF8FDFAFDFEF9F2
F2EAF8FAFCFFFDFAF5F8FAF6FFFFFFFAF6FBFAFCFFF5F1F5
FDFBF8F9F4F1C979E6E7D45896D6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEBE7FFFDFDFDFDF8F5E7E7F5FAF3E7E4FDF1F7F4F7
F1FFFFFFFBFAFAFAFAFFFFFFFFF7F3F7F3F7F7FFFFFFFAF7
F4F4FCFCF3FDF4EDF8FFF6FFF6F5E2EFF7FAFFFAFAFDFBFF
FDFDFBFDFDFBFBFBFDF4FDFAF1F9FDF6F9F7FBF7F4F5F7E2
E2F9F4F9F5F3F8F9F9FAFCFFFCFEFCFBFDF9FCFFF5EEEBED
F1F0FFFFFCFDFCFAF6FAF9FAFFFFFFF8FBFFFFFCF9FFF8F5
FDFBFAFCFCF1B67EF5DEC17B90AAE5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE4ECF4F4F4F1FAFAE8E2F3FAF4FAE2F1F2EDF3FDF1
FDF4FFFFFBFAFFFAFFFFFFF7F7F7F7F7F7F7F7FFFFFAF8F7
FDF1FAF6FFF6FAEFF8F8FFF6F6F8DFF1F1F8FAFAFAFAFFFD
FDFFFAFAFFFFFAF8FAFDF1FDEEFFFAFAF3FAF9F2F6FCFAF9
E8DFE5F9FAF0FAF3FDFBFDFDFDFDFCFBF6F7FFFAF6FCF4F6
FBF8FAFAFFFDFFFAF5FAFAF5FFFFFFF5FAF7FCFCFCFFFAF7
FDFCFAFCFCECAC82FFDCBA816964B7E6EDFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFADBF7F4FFFFF1F8FADFEEF5F5F2F5E5F7F8EDF4F1FF
F4F4FDFBFDFFFAFAFFFFFFF7FFF7F3F7F3FFF7FFFFFAFAFD
FBF4FAF2F5FAF6F1F7F5FBFFFFFFE0F7EEEEFAFFFAFFFAFF
FFFFF8F8FFFAFAFFFAFAFDF4EBFDFFF8F5FDFCF7FAF9F9FC
F9F9EADBEAECE2F4FCF8FBFCFAFDF9FEFBFBFAF4F7F1F1F6
F8FAF5F4F6FFFAFAF3FAF6F6FFFFFAF9F5F5FFFCF9FCFAF9
FDFEF6F4F4F9A896EFF2F2EEE87774B2D8EAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF0D9F5FAF4F4FBF8EEDCE3EAEBF0EBEEF8FFF4F4F1F4
F4FDFFFDFFFFFAFAFFFFFFFFF7F7F3F7F7F3FFFFFFFFFAFA
FDF1F7F1F5FAFCF4F6F0EFFBFFFFEAF1F4EFFDFAF8FFFAFF
FFFFFAFAFAFAF7F7FFF8FFFDEFF5FCF9F5FDFDF9FBF7FCF6
FAFCF7F5F1F2EEEAF1EDF1FAF7FAFCF9FCFAF2F1F8EFFAFA
FFF7FFF1F6FFFAFAFAF6FFFBFFFFF8FAFAF8FBFBF9FAFBFF
FCFCF1FFF2F3AAA0D3DBD7FBE3B499A2B1D6FAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFADEE7FDF3F4F4FBFAD9E2DAEAF8F3E4F6F1FDFFF4F7F4
F4FDFDFBFFFFF8FFFFFFFFFFFFF7FFFFF7F3FFFFFFFFFAFF
F7F4F7F4EEFBFBF8F6F5F3FBFBFBF4F3EAF1FDFAF8FAFFFF
FFFAFAFAFAF7FFFFF7F8FDFDEFF4FDFFF1FFFDF9FBFAFFF5
F5F5F8FFFCFCF8F6E2F2F5FDFFF8FFFDFAF4EDFAF6F4FCFD
F9FDFFF1F6FFFFFAFAF6FFFBF6F6FDFFFAF9FAFAFAFFFBF9
FBF9F1FCEDEFC8B6A6BFC4B7C9DFB7C69FA5E1F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE7DCF9F8F4F4F4F6DCEEE0DDE2EEEBDDEEF2FDFFF1FFFF
FFFFFFFBFFFFF8FFFFFFF7F7F7F7F3F3F7FFF7FFFFFAFAF9
FAFBEFF4ECEFF7F7EAFFFAF1ECF5EFEEF0F4FDFDFDFDF7F1
F4F7F9F9F7F7F7F5F0FAFBF7F0F0EFECE8EDEDF3F8FAF9F5
F5FAFDF6F6F5FDFAEBF4F5F0F6F9FCF8F4F6F2FEF7FAFCFD
F5F5F3F7F7FAF8F5FAFAF6F9F8F7FAF9FCFFF9FBFCFAFCFC
FAF9F9F6EFE8D3F1EBD2EDD7D8DFD2BA8F5B559BEBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAD3ECFAF5FFFDF1ECE9EDD0EEF5EAE6E9F1F2F6F1F4FFFF
FDFDFFFBFDFBF7FAFFFFF7F7F3F7FFF7F7FFF7FFFFFAFAFD
FFF1FCF7F7F4FFF9EAF9F5FFFDF1F6ECF7EFFFFFFFFDF3F6
F1F1F4FDF9F8F5F9FDFBEFF0F5EAFAF6F6FFFDF8F9FFF8F9
F9F8F8FCFCFCF7F6F4E8F3FDEDF9FCF4F5F1F1FAF6FDFFF7
FFFDFDF7FFFAF8FAFBFDFBFBF8F7F5FDFBFCFCFAF6FCFFFF
FEFAFAF2FFE6E0EFF4DCD6D2CCBFF4F6F6E0A297E2FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F3D2FCFEF1FAF4E3EAFDF1DBFCF4E1EBEBF1F5F3F0FDFDFD
FFFDFDFDFBFDF7FAFFFFFFF7FFF7F3F7F3F7FFFFFFFFF8FF
FBF4F4FFF7F3FAF7F1F3FDF7F7FFF7DDF4ECF7FFFFF6F6FA
FFFAEFFBFDF4F7FFF4F7EEFBF9ECFBF2FDFAF8FCF9F7F7FA
FDFCFCFDFDFBFAFFF4E7FDF8F2F7FAF2F9F2F9FAFAFFFFF7
FFFDF9FFFFFFFFFFF6FBFBFBF7FFFBFAFFFAFEFEF8FCFCFC
FAFDFDF5FFECE8F3F8F3E0DCD4ADCDE7CB8976B4E6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EDD5FCFAFAE0DFE3ECDCDAEDF2FAE6EBF2FFFCF2F8F4FFFF
FFFBFFFDFDFDFAFAFFFFFFF3F3FFF7F7FFFFFFFFFAFAF8FF
FDFDFFF7F1F4FAFAF9F5FFFDF6F6F4E7EFF5F8FDFFEFFCF7
F8F7F1FFF6FDFDF6F1F3F6F4FAF0F8F6FFFEF9F8F8FCFCFA
FFF3F8F6F6FFFBF4F4EDFDF5F7F6F4F4F5F6FAFDFFFDFDF7
FFF7FFFFFFF9F9FFF5FBFBFBFBF7F7F4FAF9FCFCFAF9F5F9
FAFBFCF5F2F5E3FCF7F7F6F4E9CEAAC2877ABAE6F1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DFD7F3FFDED2DDD3D5E3ECF6F4EBF0ECF4F2F6FDFDF7FDFF
FFFDFDFDFFFAF8FAFFFFFFF7F7FFFFFFFFFFFAFAFAFFFAFF
FFFBFFF7F4F4F7FCFAF5FDF6F7F5F8FBE9F7FAFDFDF4F5FC
F9ECFFF7F7FDFDFFF4FBF8F5F4F7F9F5F9F8F5F8FBF8F4EF
EFF6F6F7F6F6F4F4F0F5FAF3F8F3F1F7F6F6FAFFFFF6F6F7
FFF7F7F7FFF9F9FFF5FAFBFBF9F9F9F3F7FCFCFCF8F9F9FA
FFFAF1FCF2F5E3FBFFF7FBFBFBF2D5AD7ED3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
D1EEF6FAD8E8FFE7FBFAFEF9EFECF5EEF6F2F6FDF1FBFBFD
FDFDFAFAFFFAF8FAFFFFF7F3F0F3FFF3F3FFFAFAFFF8FDFD
FDF4F7FFF7FFF1FDF9F9F9FBFAFAF7F0EEFBFAF7FBFDEEFA
F2EEF7F4FBEFF6F1F7FBF9F6F4FDF9F5F9F9FFF7F3F6FEF7
F3F3F7FDFBF9F7FAF0FFF4F8F4F0F2FDF5F7FDF7F7F7FFF3
FFF7F5F5FAFAFDFDF5FAFAFBFAFAF9F4F9FAF7FAF9FCFFFC
FEFAF1F1EAFDDDF9F9F6F6FAFBFFE2B8C0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1
D9FCF8F6D7EDFBEDFBF9FAF8E7F1F7EBF5FDF7FFF4FDFBFD
FFFFFAFAFFFFFFF8FFFFF3F7F0F3FFF3F3FFFFFFFAFAFDFD
FBF1F4F3F5F4FCFFF8F8F9FDFAF4F1F4FDFDF8FAFAFBF4EF
F4FBFBFDFDF6F6FCFAFCF9F5F7F7FBF6F7FCF8F3F6F7FEF3
F9F9F9F7FDFDF8F6FFF5F0F8F8F3F7FAF9F7FDF3F7F3F7FC
F5FFF7F9FFFAFDFFFCFDFFF8F8F9FAFAFAFFF6F9FBFCF9FC
FBFCF5EDEFF3DCF7F7FCFAFCFEF6EAB0EAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDA
E9F9FAEFDFEFF1F6F8F6EEEDE8F7EDEDF5FFF1F4FDF6FDFD
FFFFFAF8FAFFFAFAFFFFF7F7F7F7FFFFFFFFFAF8FAFDFDFF
FBEBF9FCFAFFFCFAF8F5FAFAF4FFF4FAF8F8FAFFFAF5F7FD
FFFFFFFFFBFFF4F4F9FCF9FCF2F9F9FAF5FDF8F3F6F7FEF3
F4F5FEF5F7EFF4F5F5F5EDF4F6EEF5F6FAF7FDF7F7F7F3FA
F7F8FAF9F9FFFDFAFDFDFAFBF9F8F8FAF9F7F9FAFAF7FCF6
F9FCF6EFEFF6D9FBFBFCFAFBF7FBEAAAF3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2DA
ECF9F8ECE3F8F0F8F1F3FCECECF1E7F5F8FFF1F4FDF6FDFD
FAFAF8FFF8FFF8FFFFFFFFFFF7F7FFFFFFFAFAFDFDFDF4EC
F4EEF5FFFCFEF7F5FFF7FCFCF1F4EDFAF8F8FAFFFFFFFAF8
FAFFFFFFFDFDF7F7FAF7FDF7F5F8F6FCF5FFF7F7FFFFF7F7
F6F5FDF9F9F4EDF6F6EEEEE9E8EDF9FAFAFAFDFFF5FAF5F6
FCFBFCFAFAFDFAFDFBFBFAFAFAFAFAF1F8FBFCF8F7F7FFFD
FCF9FCF2EFFDCEFAFBF9F5F8FFFAE8C0DCF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4CEEF
FCF1F2E5E6F5EFF7E5FBF0F7E6EDEEF9F9FDF7FDF7FDFDFD
F8F8FAF8FAFAFAFFFFFFFFFFFFFFFFFAFAF8FDFFFDFFF1F0
FFF1F6FFFDFEF8F9F6FEFCFBFCF7E7FFFFFFFAF8FAFFFAF8
FAFFFFFFFFFBF7F6FFEFFDF7F5F1FBFCF5FFF7F7FFF7FDF9
F9FBFBF6F5F7FCFAF4F3F1F2FFFBFEFBFAF9F8F7F7FCFBFD
FCF7FAFBF5FDFAFAF5FBFBF8FAFAFDEFF6FCF9FAFAFAFFFD
FCFBFBECF5F2D0F8F8F9F4FBFAFAF2CCC0F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5D9FC
F9F1EFEBE9FFF5F3E6F8F0F0E6F3EFF6FAF4F1FFF6FDFDFF
F8F8FFFFFAFAFFFAFAFAF8F8FAFAF8FAFAF7FDFDF4F4FBF7
F6FFF6F4FFFFFBF7F3F0F1F4F7FCE5FFFFFDFDFFF8FAFAFA
FAFFFFFFFFF4F7F4F6F2F5F3F1F3FFF7F7FFF8F6FFF7F9F9
F7F7F7F4F6F7F1F5FBF9F5FAFFF9F9FDFDF4FCFDFBF7F5F7
F6F7FFF6F5FDFDF9F6FBFBFFFFFAFFFAF9F7F3FFFAFAFFFF
FAFBFCEAF5F2D5F9F9F9FAF4FAFFFAD8B2FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4DEE9FF
FAEFF1E9E2F8F5F3EFEFEDF0E6EEF3F5FDF7F4F7F6FBFFFF
F8FAF8FAFAF8FAFAFAF5FDFFFAFAFFFFFDFFFDFFF3F4EFF4
FDFDF7F6FAF9F7FCFDFFFFF3F6F9F0F4FFFDFFFDFAFAFFFA
FAFFFFFFFFF4F6FDF3F6F1F5F6FAF6F5F7F8F8F6FFFFFDFB
FCFFFEF2F4F7FCFAF6F6F7FAF9FAFDFBFBF9F7FCF9F4F3F7
F3FCF5FAFAFCFDFAF6FFF6FFFFFAFBFCFCFCF6FFFAFDFAFF
FDF7FBEAF5EDE4FAF7F5F9F4FFFCFAE8A6F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5E5EBF3
F6EFFDEEDDE8F3F4EEF5F6EEE6EBF5F7F4F6EFF7F7FDFFFF
F8FAFAF8FAFAFAF8F8F9FDFFFFFDFBF4F1F4F4F7F7F1F1F4
FFFCFFFAF9FCFFFCFDFDFCFCFDF7F4F6FDFDFFFFFBFDFFFF
FFFFFFFDFDFDFDFBEFF0FDECF9FBF5F9F2F8F8FEF7FFFFFF
FFFBFCF5F5F8FDF7F9F7F8FFF9FAF9FAFAFAF7FBFBF4F6FA
FFFAF5FAF8FCF9F8FBF9F5FAF8F8FDFAFFFCFBFDFFFAFAFD
FCFDFBEAF5EFECF5F7FBF9F6FCF9F6EFB5CCF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD8EBE5F0
DFF1FAE3DFEDF7F1EFF5F6EBE6E6F6F8F7FDF4F6F4FFFFFA
FAF8F8F8F8F8FDFDFFFFFFFFF4F5F7F7F3F7F1F4F1F1EFF5
FDFCFAFEFCFAFAF9FFF9FCFDF6FAF7F7F6F7FDFBFDFDFDFD
FAFAFFFDFDFDFBFFEFF3FDEFF5FAFAF9F9FFF4F7F6FFFDFD
FBFEFBF7F7F4FAF9FDF7F8FAF9FAFBF6F8F7FDFBF6FCF7FF
FAFFEDF9FBF7F6F6F9F8FFFCFEF5FAFAFEFBFAFCFCFFFFFD
FCFCFCE7FDFCEBFEFAFCFDFAFCEEF7F5C8B9F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD2F0E3FF
D4F7E0DBF5ECFEF1E8F6F3F2DDE6FBF9FDF7F3F7FDFDFFFA
FAF8FAFFFAF8F9F5F4FFFDFBF6F7F3F7F3EFF7FDFDFAF4F4
F7F7FFF7F5FCFDFFFDF9FAF4F7FDFFF3F6F4FDFDFDFBFDFB
FAFAFFFFFFFDFDFBF7ECFCF6F3F3FFFAF6FFF7F8FAFCFDFD
FBFCF8F7FBF6F4FBF9F7FAFFF3FEFBF9FFFAF9F7FFF7FAF5
F7F5F6F8F9F8FDF9FDF6FAFCFFF6F1FAFCF9FBFEFCFFFFFF
FDFFECFBF3F3E1F1FAFDFAFFF1DEFDFACAB1FAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2D5D9D2E7
E2C1C8DFB29DB8DBEEF5F6EBD2EFF6FCFCFFF7F4FDFBFFFF
FAFAFFFAFAF8F8EEF4FFFDFBFDF7FFF4FDFAFDF8FAF4FCF9
FAF4F3EBF8FAFCF7F4F4F7FDF6F3F7F3F6F4FDFBFDFDFDFB
FFFFFFFFFDFFFFFDF4F3F6F3F5F4F6F9F6F7F4F8FAFCFFFF
FEFDFEFCF6FFFAF5FBFCF8F6F4FBFCFFFAF8FAFAFFF5FCF5
FCF1F7FCFDFEFAF9FAFAFAF8F6FFF9FAFAFBFCFDFDFFFFFF
FAF9F1FBF3F3C9D2D4E6F9F2EFD8F9F7EEA7D1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD8DDD2FFEC
DBF0F3D1C5F3F7D3DCEAF7DFD2F5F5F6F1F3F4FDFDFDFFFF
FFFFFAF8FFFAFAFAFDF4F4F4F3F5FFF4FDFDF9FAFCFAFAFC
F6FCFBF7F9FFFBFBFAFDFDFDF6F3F7F1F4F4FFF4F7FFFDFD
FDFFFFFFFDFDFBFFF1FCF7EDFAF4F6F4FDF6FDFDFEFFFFFF
FFFFFDF8F7FFFFFAFAFCF4F2F8F6F5FAFFFFFAF5FAFFF8F9
FCF1F5FCFCFBFAF9F6FBFFFAFDF6F8F6FCFCFCFCFFFFFFFC
FCFCFFE8FFF2AEF3EBD8ECF2F1DFF0F7F9CDAFF1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7DFD1E2EDE2
E5D9D397D0E4F3F7E0EAEACFDFEEF8F7F6F6F4FFFFFFFFFF
FFFFFAF7FAFFFFFFFDF4FFF1F7F7F0EEF2EDF3F6FFFAF6F5
F1FAF8FCFCFFF6F6F5FAFAF7F3F1EFFFF6FBFDF7F4FDFDFD
FDFFFFFFFFFFFBF7FAF9F4F1F5F5FDF5F8F6FBFFFFFFFFFD
FDFFFBF7FDF8F8F6FCF7F7F9FDF9F6F9FDFAF6F6FAF6F1F7
F6F6F6FBFBF8FAF9FAFFFFFAFAF3FCF9FFFAFAFAFBFBFFFC
FDFFF6F7F2F5ACF6F5DFE8F5F2EFF1FDF9F3A5DFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFADBECD4EDFBDF
F3D7A7E8BEF4E1E3ECEEEBC1D9ECF1F7EFF4F4FDFBFBFDFF
FFFDFDFFFFFDFBFDFFFDF4EBF3FAF8F5F4F5F1F6F2F6FAF7
EAEFF1F0F0F9F7F5FAFCFAF7F3F1EFFDFFF4FDFDFFF4F6FB
FDFDFFFDFDFFF7F4FAF5F8F1F7F5F2F8F8F7FEFCF6F7FFFD
FFFDFDF6F6F6F8F4FBF4FFFBF8F9FCFDFCFDF6FAFDF8F8FD
FFFAFDFDFDFAFAFBFFFAF3F3FAFAF6FCF6FDFBFBFBFBFDFD
FBFBF3F8FEEEB5FBFBE6F0EEFFFBEFF3F9F7AECBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EBD7ECCFF4F2CD
C5C3ECB5C5D9EEF7EFF7EDBFD2EDF6FFFDF6FBFDFBFBFDFF
FFFDFFFDFFFDFBFDFFFFFFFFF4F1EFEFEBE8EBE5E3E5EAEF
ECF8FFFAFAEEF0EFEFF1F5F5F5FAF6FFFDFFF4FFFDF7F6FB
FDFFFDFBFDF4F1FCFAF4F7EFF4F1F3FBFBF8FDFCF6FFF7FB
FEFBF8F4F8FDFDF7FFF9FAFFFBF9F6F9FEFCF8FAFEFAFBFA
FDFBFAFAFFF9FBF9FAF7FCF4FAFAF9FAFBF9FAFDFBFBFDFD
FBFBF3F8FEECB8FFFBE7F2EBF5F2FAF3F0FCCAB1FAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D7E1E9D5EDEEAE
CCD0BCFFACF7FAF7EDE4ECC1D2EFF5F7F6F4FDFFFFFFFFFD
FCFDFDFFFBFDFFF4F4FFFFFFFDFFFDFFFFFFFFFBFBF4F4FD
F1F7F4F7FCFCFDF6F0E6E4F1FBF7EAF7F4FDF6FDFDFFFDFB
FFFDFDFBFFF7F1F6F4FAF7F3F3F8F4F7F7FBFCFDFDF5F5F8
F6F5F8FBFFF8F5F9F7F9F7FAF9F6FBFAFBFAFBFBFDF8FBFF
F6F6FBFBFAFFF8FAF7FDF6FFF5F9F9FDF9FAFCFCFBFDF8FD
FAFFF4F8FCEABCF9ECF0F5EDF0EDF9FCEAFBE7A8F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6E6E1E2E9D3A1
E194EFDCD7C0BBE6EAD7E7BDD5F3F0F7FBF4F4FFFFFFFAF7
FBFDFFFDFBFDFDF7FFEFEFF4FDFBFBFFFFFFFFFDFDF4EFF0
FDF5F5F9F6F9FCF9FBFFF9E8DFF4F4F7F1FDF3F4FFFBFDFD
FFFFFFF4F1F4F7FFEBF4F7FAF3F8F4F7F7FBFCF9F9F6F6FB
F6F5FBF6F8F8F3FCF6FFF5FAFAF4F9F8F8F7FCF6F6FDFFFB
F8F5FBFBFBFAFAFFFCF6F7F8FCFFFCFCF7FAFCFDFDF8FEF6
FAFCFCECF1F2C6F1E3DEE3E0DDD8E7FEEFF9EBB0DAF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFADAD7DBF8DEAEA9
CAC19D83A2BEC8E8C6EBE8AED5EFF1F7FBF4FFF4FFFDF7F7
F4F4FBFDF4EFE5E3F3F7F1F4FDFDFDFFFFFFFFFFEAEAFFE9
EDF1F0F9FAFAF6F3FBFAF8FAF4E3D9DEEAF4FFEFFFFDFDFF
FFFFFFF4EFFDFFFAEBF6F5F3F6F9F8F7F6FBFDF6FBF9FBF6
FCFAFDFEF4FFFAFDFCF9F5F5F8F4F4F4F9FAF7F9FFFBFBFF
F3F3F4F7FAFFFAFAF8FAFAF7FAFCFCFCFAFCFDFCFFFCF4F6
F3FCFCEEF2F2C6EAF6E8D9D6D2C7CAD8F0FAFEB9BFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D7D1E2EDE98AC7
B0E397EFA3CFD9C7CBF6E4B8CDEBF7F7FBF4FFF7FDFDFBFB
F4FFEFE9EEF8F4FCEFE1E0FDFDFCE7E2EBEDDCD2DBDBCFC9
C9D6DBE0F4FFF5F0FFF9F6FFFAFAF5E6EBFAF7F4FDFDFFFF
FAFAFFFDFDF7FDF1F8FDF8E9F6F9F5F6FFFBF6EEF2F8F7FF
F7FCFDF5F5FBFDFAF9F5F5F5F3F1F6F5FFFFFAFAFFFFFFFF
F1FCFFF3FAFFFFFAFFF7F6FCFCFBFBFBFAFFFDF8F5FCF8F4
F3FCFCF1F2FFCAE6F6F7F7FFFAE9E1E0E7F5EDC5B6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDCFCFEAE0EA88CD
C0B8AEC0D5A99DDBD9ECD8B5CCEBF7F7FDF6FDF6F6F4FFFF
FDF4ECE9E9F0F5F1F2C1A5B7CCC7C9CDB9B5C5D1D1D2D4DF
DFD1E3E3CAD7E5F3FAF3F3F9FAFFFAF5E7EFEAF4FDFDFFFA
FFFFFAFDFBF6FDF1F9F4F6F0F1F3F3FBFDFCF9F0F1F2FCFC
FAFBFFF4EFEFF1F1F0F2F6FDF8F2FFF7F3F3EFF5FAF5F5FA
F3FCF6F7FFF8F8FAFAF7F3F7FCFAFAF8FCFCFFF5F8F8F6FF
FCFCF2F1FAF3D5E7F3F6FFF7FFF3E9ECDFE6EED0ACFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4C8D5FBDCEA96BD
C396DBB6CCCBDFE3E6ECE8A4CCEFF1F6F6F7F6F4F4FDF4FD
FDFDF4F1ECE8E5D6CBC6D1958489A3BECAD6E5E7EDF0FDFF
FFF8E7E7F4D1D9E8E8EFF7F8F6F3E7E6F0F9F0F4EFF4FFF8
FAFFFFFAFDF6F7F0F2F4F6F5F5EDF4F6F9F9F6F0F5F9F8FB
FBFCFCFDFDFBFCF4F1F1F1FAF5F3FFFFFFFFFFF3F5FAFAF5
F7F1F4FFFFFAFFFFF5F8FAF3F7FFF5FFFFF9FCF8FAF8F6F7
F4FDECFAF1F3DAE5F2F2FFF7F7F7F4EEEAE0F5DFA5FAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD8CDDDFBDCEDA7A9
E3A3F2C9CCF6F9E7F0EFE889CFF1EFF7F6FFF4F4F6F7F7F6
F7F7F4FFF8F6ECE9E4DCA4D6F0E6CED1ECE1F1EBEFE3CACA
C9C4B8BFE5FEE9CEE6F3F4F4EFEFD8EAF7F9F4FAF7F6FDF8
FAFAFAFAFDFBFDF5EFFCF1F2F4F2F9F8FAF7F9F5F6F5F6F8
F6F1F1F1FBFEF6FFF6F6EFF1F2EDF1F0F0F8F2EAF6F7FFF7
FFFAF8FAFFFAF9F7FAF9EFFFFFF2FBFCFAFCFAF3F8F8F8FE
F1F9F9F2F2F3D7E7F6F9F7F7F4FFF4F3DFE9F8EBA5F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFACFD3DEFFD3F7BC9A
DDBBF0E8E3E5EBF4EEE5F874D4F0FDF6FDF4FDFFFFF3F3FF
FBFBF1EFECF0E8D8C6E9DC98B9F2F5E3D6CDBEC7C6B5B3C2
B6A2A4AAAAADCED9E1D9DDE7DFDDD5CBCBD6E3F0F7F7FBFA
FFFAFFFFFFFFF4FFEEF7F1F4EEF7F7F7FCF7FAFDF6FAFFE9
EFF0F7EDFFF6F8F8F8F8F4F6F7F7F7F7F7FBFDFCF1EEE9E0
E7F1FFFAFAFAF9F7FFF7F3F7F3FAFBFDFCFAF8FFF1F3F1F0
FCFCFCFAF9F6D5E9FBF0F7F7F7FFF4F3ECE1F0F1A5F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7CACBEAF9D7F1C774
CFD0E4F4ECE3FFF0EFE3E88DC7ECF6F6F6F4F6FFFAFBFBFA
FCF7FFFBFDF3FAF8E8CCD2DFA1B3D9F1A9CBDCFF92BBBE88
7BD7CFC9E6F6D4C4EEFFEED8D8DDCBBDB6BBCCE9F3EDFDFA
FFFFFAFAFAFFF4FFF1F1F5FAEAF9F6F6FCF9F6F2FAFDEFFF
FDF6EFF1F0F6F4ECECECECECECE8E8EFF3F1F7F7F0F2F4F4
FAE2DFEAF5FAFAFAFAFFFFF7F7FFFDFAF8F3F4FAF1F3F1F3
F2FCFCFAF9F6D8E5FEECF7FFFFF7F7EEF7DDF1F1A6F3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0CFC3F9F9D1E8D454
D2E3E7FBE6F3FFEFFFF4DD8DCDE6F6F7F4F6FFF3FCFBF6F8
FFF4FBF7F6F1F4F4FAB0E1E8E2B28D8AF6979CC076F288CC
7A8FFFCFCBEBDBD1C3D0D5DDEAEFF6EAE0D9CBE6F0F6F4FA
FFFFFFFFFAFFFBF7F0F5F7F8EFF9F7F3F6F8F5EEFDE8F6F6
F2EDE0F3EFEFF1FAF8F5EEEFEAEAF6F4F1F1F1F6F6F4F8F5
F3F0F1FDF7EFF1F1F5F7F3F7FFFCFCFDF3F8FFF5F3F6F4F6
FCF5FCFFFCEBDDEAF8F7FFFFFFF7F7EDF4E7EFF5A2F3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F3DAD0CCE5EBC5E7F466
A1D6E4F7EDF8FEFBECE0E670D8F0FFF6FDFBF7FFF7FDFDEF
F7F4FDF4F6F7FFF4FFCAD7EEDCF4D5EAA6C0D78998D29ABE
BD6BFFD4C9F1F7E4A9F3DDDAD8E6DDDED2C5C9E3F2F7F4FA
FFFAF8FAF8F8F7FDEFF3FCEFF1F8F7F3F4FEF5ECE3F3F9F1
E4EFE9F7F1F2F1FAFFEEE5F8F1E1EAF2F2F5FAF1F1F2FAFA
F1F9FDF3F3F7F7F5F1F1EFF7FFF2F2F3F8F8F3F2F3F5FFFF
F6EDFFFCF3F0D3F0EEF6FBFFFFEAE7EAECE0F2F89EF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFDA8B9BF2C9DEF6CBF1F4A5
92E1ECEAE7F3F0EBE3D4EC7EE1FAF7F7F6F6F1F4FFF1F1F7
F7F4FBFFFBF7FDF3F3E8DAD2F9D9DDAEB1BD9591B9F0B1A7
B477F3D9D2DCE3D6AEDED6C8EDE1C9D5E6E1EBFAF8EFFFFA
FAFAFAFFFFFFEEF6EFF3F7F4EFF5F6F8F7F5F3F2F4FFF6CD
B5B3BDC9EAF2FFEFE8E3E1D3D7D6D3C8CFD4CEE2ECEFF7F7
F4FCFDEFF2E5F2EFECECEFF5FCF5F3F3FEF5F5F4F5FCFCFF
F2F3FFF3F4EDCDF7F6F2FBFBF7EAF6F0F3E7FCF7A2F3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF74C5B84E2B1E9FDD2EBFFCB
83C3F6EAECEFEFF2E8E5C98DDEF1F3F7F7F7F1F4FFF7F7F7
F7F7FDF7F4F6F7FFFDF1F0E8DAF4CFE1E1D5D6BAB8D2DBDE
CDB7ECE8DCF0F3C3BEBEDBE7EDE8E7E8E1EAEEF1F5EFFDFD
FAFAFFFFF7F7EEF6EFF5F1F4EFF5F5F8EFFAF8F2F3F4F3BF
EACDBCAAD3D7D5D9E1E0E0E0E4D4DAE0D7D4D6D3DBE6E8EC
EFEFF3F5EDFCEEF3FDFDFDFDFCFFF3EBEFFAF4F5FEF8FFFC
F6F6F3F0FAEBD3F7F1F0FBEFEAE3EBF4F3F2F5EFA0EFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAA407D455E8C0DCF7C9E3F1E8
7997EEE6EFFFF1EEE7E7D384DAF7F7F7F7F7FFFFFFFFFFF7
F7F7FDF6F4FBFBFBFFF1FAF1E8E4F6D8E9DEE6C7C3A7C8DF
D5B3B8CFD7F4F3C6F8EDE8F4F3FBECD8DBFAF6F3EFF1FFFD
F8FFFFFFF7F7F8F4F7F3F6F2EFF7F2F8EFF9F9EEEEEFF7C2
DAFCE6B8F0F2FBECF3E9E8E4D3DAF2F2F6F8F1E1CAC9D7E0
EDFAEFE9EDF3FBF0EFF5FDF1F1F1FEF0F9FFF9FAF5F5F8F8
F2F5F8EFFAE7CBF5FDF1F6F2EECCFAFBF1F4F3F09CEFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7E97E3976D056D7DCC0BBC1F6F7F5
7A85E3E3FDEBF6F7EFE4D37EE4FAF3F7FFFFFFFFFFF7F6F5
FDF6FDFBFDFDFDFFFBF6F1F1F0ECE6F1DAE1D3D6D09FDCB7
C3D3CED6C4D1E0C5E2D4DAF4FBFBC0D2EEF2F0F4EDF7F4FD
F8FFF7F3F3F7F8F4F5F3FCF3EDF5F4F4FBEFFDEFF1F2F4E4
CAC7E4B7D6C9C7B5B1B8D5BCBEC4C0BABFE1FFF4F6DEC8C6
C7E4EAEAE9EEEFEDF6EDE6EFEFF0F0F2FEFCFAF0FFF5F8F4
F6F5F4EDF2E7C4F0F4F0F0F6F5C7F2F6F4F7E6E7A5E0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F18751A7E6E655CCF4EBE6F7E7FAED
8096D6F0F9E4F9F3F3E5D37EE4F7F3F6FAFAF7F7F7F1EDF9
F1FDF6EFF4FDFBFFFDFFFFF1FFF1EAE8F5D7D2E8F9B2B6C2
C3DFD9D2ECE6EAD4F3EBFAEFFFDCC8F4F4F8EFECF3FFF1F7
FAFFF7F3F3F7F8F4EBFAFFF3ECEFF6F8FBEFFDF8EFEFF0F2
F3DDEBBDBAE6F3FCCB76D2E2ECE7E9F9EBC6BDE5F5E1F3F6
D1CDEAF6F3E9E9EBE3E7ECECEDF1FBFAFEF6F3FCFCF8F8F5
FCF6F2F4F5E5C9F4FEF8FCF7E6BDEBFAF4F6E0ECA9D6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7AE4C95EDF1F157D2E3EBFFEBECF6EA
8FACDCE6EDE9F7F2F1D7D581E0FCF3F1FAFAF3F7F7E4F5EC
F1F3FFF3FFF6FDFFFFFBFDF7F4FFFAECE3DEEAE8E5EBE2EF
D8CAD9D4D5D5D8DBEFFFEFF9D1D3F6ECF6F5EFF1F7FAF1F7
FAFFF7F3F7FAEEF7F0F8F9F5ECEFF7F9F9EDFFF6E7F1F6F3
F7F7D2F4ABBEE3E695B2AFAFCBD2D2E6ECDCF8CEE8FAF0F3
E6C7DAE5EAE7E1D9DCE9EDF7F5F8F6F0F5F8F8F3F8FCF5EE
F9FAE8F2EFDCD9F6E8E8FAF6F7ABE4F1F2EBDEEBB0C5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFAFFFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA5416EE4FBF1F8867BC7E3E3C7CFD3B6
92DDF7F3E5EDF7F2F3D5D579E7FFFFFBFBF3FFF3F3DFE2CE
C7DFE8F3FFFDF4FDFDFDFCFDF4F1F1EFEBEADEE1E4E8F2F8
F2E3E0F0EEECE9D2D3CAC2C8E0F8F4EEFAF1ECF1F5F1F4FD
F8F7FFF7F3FAEBFBF6FFF5F7EAF1F6F3F9EDFFF9F6FFF1E3
ECFFF3CDDEC98D85A2AEA36FBCE3D9EAE0EDE8E1D6D5D0D6
DAEBC5B3BFC6D6E6E0ECE0D7DBE2E8F4F1F5FFFFF5F2F2F3
F7F6EFE7E9D6DAEFF9E8D1CBE6B0DEF6F2D3F1EDB3BEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE55E8AEBEFFFE2EBE9948FC5DDC1D7C7B7
CAFDEEEAE8EEFBFBEEDBD075EEFCFCFFFAF7F7FDF4E5CCD8
E4D2E2F3F1FDF4FBFCFFF9F8F8F7FDF4EBF9F6F5F3FDFBF6
EEF3EBE7E8DBDBECFFFFFFFAFAFBF4F6F8F1FAF9F6FFF4FA
FAF3F3F7F7FAF1F4F9FFF8F6EEF5F5F4F3F3F9FDF3EDFFF6
EDEAEAF5ECDEE4E4DA91E159BAE0C4E7EBF8F0DFC3FBEAC9
D7EBF6F6EEF8E4EDD2E5EDDDDDECF4FDF3F3F3F5F5FCFFEF
FAFCEFE1DBD3F0FDFAF4D7F4D4AFD9FAE1D4EBF4AEBCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7B752D1F1E6EFE2FFEBD18085A7B9C1C3DE
E6F3F5F2F9F2F7F6E3D8D17EE7FCFCFAF4F5FCFDF4FDE7C7
DAE5D2E5E8EFF4FFFDFAFFFAFFF9F7FAEFFAF8F5EBFAF6F8
F9F4F8F4FFFAFAFFFFFAF8F8FAF9F3F8F1FCF8FAF1F1EDF8
F7FFF7FFFFF5FDF3F8FAF6F5EFFAF5F4F1F8F6FDF5EFF1F0
EFE4EBDDEDEEEED2C3EBA37AC3E6C3D4E3F4E9CBC8E6C1B3
E4EDDED0E0E1C9D1E1E8E8E7FDEFEDEFFDFDF3F5FCF1F2FB
F1F5EFE1CEE1FEFCF5F5D9F3E88EE3FAD9DDF1EFB0BBFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF37E61E1F2F5EEDDFFEBEBECA695B6D8E6E8
DFE7EAF2F0F6F7F7E1DBC790E2FFFDFFFDFBF4FFF4F6F7E7
CEECDFEFDFE2EEF4FFF8FAFAFFFFFAFFEEF4FFFFEFF1E8F6
F3F3F8F8F4F8FAFAFAFAFAFAF4F9F0F8F1FFF8FAF5F6EDF8
F7FFF7FFFFF5F6FFEFFDF3FAF1F5F9ECFAF5F1F5F1F9FAFC
F5F4E2E2F1E6E2EFD8BEE8C7CAF0E7E1E7F0E9CCD6BACBF0
EFD9E8FBEDCFC9E6FCF2F2FBEBE9FBF1EEF3F5F6F5FAFCF8
F8F5F8D6C2DCEFFCEED3E0ECF77FE7FBD5E2F2EAA8C4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF75D7AFBF4FBF4CFE8FBFCE7E8E8A3E2ECEC
E8F3EAEEE8FFFFFFE8DBC18BEAFAFDF4F3F4FDF3FBF4F3EE
D8DEF9E7F2EED8E0F4F8FFF7F7F7F1FAFAEEF4FFF7FAECFE
F1F3FAFAFFFAFFFAFFFAF8FAEEF4EFFCF7F1F8FFF7EFF4F8
FFF7F7FFFAEEF1F4EFFDEEFFFCF1F2EBF4F7F5FCF6F0EEFC
FFFBFCEFDEF4E1DCE8D6BFB7A998A6C3E5F2FBDDCCDFF1EE
E2CCF2F2DBEAE8F1FEF5F4F7EBFCF1F9F7FCEDF4F5FFFAF3
F8F0EDCEC6F1FAECFAE7E9E4FE7BE5F2D1F1ECEE9ECEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF1499CF3F2F7FFD8F7F9F6F1FDEBBAEDF0F0
F9F6F9E8E8F9FBF9F2CECB80F1FAF5FAF7F7F3F7F6F7FBF1
E9DDD6E7E3F5F6D3CEE9F7EEF3F3F3FFF9F9F4F4FFF5F0F1
F6F9FAFAF8F5FFFAF2EEEAE8E3ECEEF6FAF4F6F3FAF3F4F8
FFFAFAFAFAF4F4FDF3F1F7FAF5F5F1FAECF3F6FCF7F3F0F9
F7FCFFEAF4DEEFF2E3E1D6E9E1D8D2E2DCEBD8CFC3DBD8CC
C0E7F1D4E8F8F5EDEFF2F9F8FAECF3F5F8FEF6F5EFFDF6FC
F1F8E7CDD4F2EDF4F6EDECEAF46CEDE1D7F3EBEA9DD6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD944BCF3EFF4F6D7F8EFF4ECF6E8DCEEF9ED
F5F9F7F3F9F8F6F2F3CEC592EDF7FDFBF3FAF5F6F4F6FDF4
F1DFD1EFEDF1E8EACDCFEEE6F5F7F7FFF7FDE7EAEAEFF0E8
EEF2F2F2E4DEE6DADFD9D3D9E1E6EAEEF1F4FFFAF4F4F4FA
F7FAFAF7FDF4F7FAF3F7F1FAEAFAF3FCF2E9F8F1EEF5F0FC
FAFDFCF1EEE9EFE0FAE4C2C9CFE4D1D8CDE1E0E5BEC1CBDE
FFEEE0F9F8EFEFF2FAF7FCFCFBF3EDFAF3F8F8F3F8F5F6F6
F8F8D6CCE1E7F0E8DDD8E5E8F45CFDE1DCF2E4E09BE0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9C4CDBFBFFF4F7DAEFE3E3E0E3F3F2E5F3E5
EFF0F6F7ECEEF3EDEBD9CE8DE7F5FDFBF6F7FAF6F4F7FDFB
FFEBD0DBE9EEDEE6DAB4A69D909188878B88807F8A8A7A81
8C94989DA6A9A3BCD4DEF1F4E3D3D2E9EDF6F1F5F7F4F4FF
FFFFFDF4F4F1FAF5FAFAF6F4F1F8F3FCF1F1F8EFF5EDEDF9
FBFCFFF1F1ECFFEAF5F2ECEDE1CFC8CEBBADC1D8EED8CEFF
F5EFEADEDFECF6FBF8F3F3F6FBF6F3F4FCF5F4F9F7EFFFF5
FFE4C4C5E5E6F7E4E8EBFFECE565E2E3DCFFE4D298F3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFAFAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF846DE8FEEFE5DBE4EFDFDFF2FFFFF9E7EFF8
E0F6F8F6DFEBF1F2E7D9D694DEF1F7FFFFFAF1FFF7F7FFFF
FBF4F7DFDFD7CEDBEFFAEDF2F2FEF2FAE6E2F0F4EBECEFFE
F9F7F0F6FCFAF4F5EFF3EAEDEBE7DCE9F2F4EEF0FFF4FFF4
FAF3F3F6F7F1F5FAFFF9F1FAFAFAEFFBF1FEFAF9F0FFFBF3
F1FAF9ECFFF1ECFDF1FDFDFDFDFDE9FFFFE1FCF9F1F5F7FC
E8DBE9FAF5FEF7F3FBF8F8F7FBFFF8F7F3F8F8F3F2FAF8F8
FADDC8D6EEF4E7FCD7F2F2F2BD81DAF6E7FFE4CA9EF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8B76DEEFF1F9F9F2F2F3F2EFEEF3FBE7FBF0
E5F9F8FDDFF5E5ECEBE1C4A0D8F6F8FBF9F4F6F5FAF7F7FF
FDF6F4F4F4E9D4D0D1DFEBE3E8DCECF9E5ECECE1EBF6F9F8
E7EDF6F6FDFBF5F9F2FADCD7EEFCE0E7F1F0F1FAFFEFF4F4
FAF1FAFAFDF8FAF8FAF9F6F7F5FFF1F3F2FEF6F3F4F0EDF8
F3F2FEEBEDF4F5E9EEF9FFFDF4EFF1FEFFE3EAE8F1F0DCD6
E1EEF6F5FBFBF8F8F5F2FCFCF8F8FFF3F6F2F2FCFDF1F8F8
E8D2C3D0E7F8ECF3D8E9F2FAA09FE0EFE9F7E9C1A2F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFAFAFFFAFAFAFAFFFFFAFAFFFAFAFFFFFF
FAFAFFFFFFFF8B73E2EFF3FBFBF2F2F3F2FBFFF3EEEEF6E5
E9F5FCF6F8DDFFF3EFEFCE97CDF6F8FBF9FFF3F5FAFDF7FF
FDFDFBFFF3ECEEE6D4BCEAEEF5ECE4EEFEF3F0DCD3E3DDE6
FEFFE6E6E7ECF7EAEBEBF0EFFFEED1EAF1F4F5FAFEEFFFFF
FDF4FAF5F6F8FAF8FFFAF5FDEEFEF8E6F8F7EFE5E8E2DCDD
E8E3EDF8FCF1E7F7FBFDF9F9F0E9EBECF0E5E5EFDDDCEEF9
F6F7F1F3F8F5F1FFF6FFF6F3F4F3FCF6FDEEF3FFFCF3F3F3
D9D9C9DAFEF4F4E3E4DAF6FA81C7EFE8EEF2E7BD9EFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFAFAFFFAFAFAFAFFFFFAFAFFFAFAFFFFFF
FAFAFFFFFFFF9765E9F4EEFFFBFFFFFBFBFBFFFFFFF9E6D5
F2F3FDFFF6EAF2E8E2E7DE9CD3ECEAF7FFF5FFF7FDF4FFFD
FDFDFDFFFAF7F7F1EBB7BACACAD3D0C8E0F1E8E5CECBD0D4
D0C2D8D8CAC2C6D2DCD3D0D4D3D0D4E5E5EFEEF4F2F4FFFF
FDF1FBF9F4FDF3FFF8FCF5F7EBFEF8E7F6F2F4DFE8E0E7E4
E0DDD6E1F0FFF1EDF3FAFAF9F9FBFBF9F0F2F3F1FDFDF3F1
FAFEFCFFF5FDFEF6FFF6FCFDF3F2FCFBFCF1FBF2F3FDF5ED
E1C2CEE4EFEEE3E7D6EEFFD17DF9F1E9EEF2E1D39DCDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAB158E1E8F3FFFBFBF9F9F2F0F2F3F3FBDBDB
FBEFFFFFF6F2E7E2F3F5EEA2CEEEF0F8FBF9F7F7F7FFFFFD
FBFDFFFFFFFDFBFDF4EBD9DAD8CADDE6CFCACDD7DACFD4C5
C2D9D0C5D3C6BCBDBDBCC0C8D5DAEDECF7F7FFFDF4FFF4F4
F4F1FAFAF4FFF1FDF9F9F1FCF1F6F9EFE9ECECDEE8F9FAF7
EDE5DDD8DEE7FCFCEDFFF9FDF9F5FAFFFFFCFDFAFAFFFFFD
F3F2F2F3FCFCFCFCF3F3FFFFFCFDF5F9FBF7F5F3FFF6F5EF
CFBAE3E3E8EEF0F2E3E5D8B09FF0F9EFE8F7DEEBC571F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFAFAFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAC459C7E6ECF2FFFFF9F9F2EDE6FFF3FFDDEA
F2EDF2F2FCF5EFD6D0EEE3ABD7E2EDFAF7FCF7F7FFFFFFFF
FDFDFFFAFAFFFAFAFFF4F1E9E9E9DFE2D9D9DBDDDED9DCE9
E2D6DEE5E0DADDDCDAEEE9EAF4FAFAECF3F7FDF4FFFFF4F6
F3FCFCF3F5F8F7FAFCFAF6F9FCF5FDF9EDF1E3D5E6F4F0F5
F5F4E9D7E1DCE3EFEBF1FCFCFCF3F7F5F7FAFCFCFCFCFCFD
FFFAF8FAFAFAFDFDF3F3FFF3EEF5FCF5F7F4F3FCF2F5F4DF
C1CEDEEAF4EEEFF0F0CCE8B1B5E7F6E8EDFFDCEBB632E3FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFAFAFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD957BAF5D6F2F3F3F9F9F2EDE6F3FFFFE8F7
E3FFFFFBF3F4EEE7D8E3E5B5E1DFEDF6F8F5FCFAF7FAFAFF
FBFFFFFAFFF8FFFAFAF8EEE7E7E7E7E5EBE7E7E7E7F8E1D8
DDD7D6DFE5EAE6F1F8E8EDF4EFEDEFFFFDF1F4FAFAFFF4F7
F1FAFAF4F1F1FDFCFFFAFDF6FAF9F5F6F0E3D6C0CCD7D7DB
EFFAF9EEC7B2AFACA7A3B3DDEBE9F3F3F6FAFCFFFDFDF6F3
FAF3F7FCF3F2FAF3FFFFEDF1FEF3EEF3FAF6FCFDF1F8FCC8
BCC8DCEFFFF9FBF0F0D6ECB4BFF9F2EAEDF7E4EA9B409CF1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFAFAFFFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE858B8F0DBFBEFF3F9F6FFF0F6FBFBF2E3EA
F0E0F2F8EBFFEEFBE2F6E6BFE1DBEFF3FAF8F6FCF5FAFAFD
FDFFFAFAF8FFFAF8FAFFFFFFFFFFFFFFFFFFF7F7FFFFF7F7
F7F7F3FFFFFFFFF3F2FAFFFFFDFDFBF6FFF7FDFAFFF3FDF6
F1F9F8FFFCF3F8FFFFFAFAFCF5FAFAF7F3F6F4D2DDCBD5D6
D9EFF5E6FBF5DFD8D5D2BBB5D0D7EEFCFDF7F7FFFCFDF3FF
F8F5FDF5F1F3F7F5F3E1ECEDE7EEFAF3F6FDFCF6FCFFF6C7
C3D5EBFFFBFFF4EFDFFEF8CCC1DBE2E9E8F4E4DFA8728CD9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAED66ACFDD6EBFBFBFBF3F2F7FBF9FBF2EEE0
FFE0F2ECF0F2F3FBE9EDEEBDDCE8DBEDF5F5F1F9F5FFFFFD
FDFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFF7F7F7FFF7FFF7F3
F7F7FFF3F3F7FFFFFFFAF8FAF9F9FDFDF4F4FDFDFAF3F6FF
F7FAFFFAFFF6FFFAFFFAF9F9F6FAFAFFFAFAF7E2E3DDCCC8
BEBEDFDBE7E5E9F3FAEEE1C4AD96A3C5DDE5F7FDFDF0F0F5
F5FFF0F3F3F0E9F5D5DCE1D1DBE0EFE9F9F6F3F4FFF8FAB7
C2D4FBF3F9FBF1DCF8F3EECFC5CAF3EBDBE0E5C3D3A496AB
E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAF06399ECE5E3EEEEFBF2F0F6FFFBFFFFFFDD
F7EEE8FFF9E8FFEFE8EAEBB8E1F0E6F0E2F1F7F9F5FFFFFF
FBFFFAFAF8FFFAFAFFFFF7F7F7F7FFF7F7F3F7F7F3F7F7F7
FFF3F7F7F7F7F7F7F7FFFFFAFAF8FFFFFAF9FFFFFDFFF4F5
F3F6FBFBFDF9FAFAFAFFF9FAFAF9FAFAFAF7FAF3F9F9ECDF
DDCCC2D2E5DFDDDBEBF4FEEEF3E8BFAFABB0D1DBE6EBEAE6
ECECEFFAEFE9EAD8D3E9E9FFE1DCE1F3FAF5F2FCF8F8F9A9
C8E9FFDFEFFFF9DAF2EDF0C9DAC6DDE8F7F1F2B7EFC8C19B
D8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF648BECEEE9FBEAF3F9FFFBF9F2F2FFFFE8
EEF7E3F2F3FBF3EEE3E9EFCDD3EEE7F8E6F3FCF9FFF8FAFD
FDFDFDFFF8FFFAFAFFFFF7F7F7F7F7FFF3FFF7FFF7F7F7FF
F7FFFFF7F7F7F7F7FFF7FFFFFFF8FFFFFAF9F7F7FDF4F7FF
FBF4F4FFFDF9FCFCFAFAFCF6FBFCFBF9FAFAFAF2EEF7F9F6
EEF1D7C3C6DBDECFC8CBDFF0FFFCF4E8E7C0CACDC9D3E0E4
E2E2D6CECED6DDE9F8FFF8E1DAE3F1F2F5FFF8F6F5F6EFA4
C9FBE3F8DFEAEAF1F2F2EFD8DDD0ECE1D3C8CBC2F5C8C793
DBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF7485FAFDE1F4EEF2F6F2FBFFF7F2FFFFF2
E3F0EEEEEEFFE3E2E9E7E8E2CAFBE4EDE9F8FCF5FAF8FAFB
FFFDFDFFF8FFFFFFFFFFFFFFF7F7F3F3F7F7F7F7FFFFF7FF
F3F7F7F7FFF3F7F3FFF7F7F7FFF5FDFFFDF9FFEEF7F6F7FC
F7FFFFF5FCFCFCFCFAFAFCF6F5F5FBFDF9F5FAFCFCF7FFF7
F6F6EFE5D3CBDBE6EADFD1DBE1EDF7F3EEDEDADEDCDAD7E5
D9D5DAE1F2FFF7F3F6F3E4D7E3FAF3F3F4F6F8F7FDFBEAA1
D5E6E6F0F2E5E2EEF0F0EEECE1C0D6D5CED6D7E6E7D4B091
EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8080F3EFF1E6EDF5EDF0F9F3F2FBFBFFFF
EDEAF4EFF1E5F0E9F4E7ECE0D2EFECEAECF0FBF3FFFDFDFD
FDFFFFFFF8FFFFFFFAFAFFF7FFF7F3F7F7FFF7F7FFFFFFF3
F7F7F7FFF7F7F7F7FFF7F7F7FFF5FDFAF7F9F7F6F7FBEDF6
F7F3F3F2F9FFFFFFF8FAFAF8F9FAF6FBFFFFFCF9F7F9FFFA
F9FBF9F2F4EED8D3D9E5DBDDDAE3E1E5F4F2F2F2F7F7F0E5
F6F7F0F5EDF7EEF6E8E1E1E8F6FFF8FAFDF8F4F8F7F6E8A1
D1E3F7F2FBF9F8FFF8F0F7EEF1DDF1EAE9E8F3EEECC674AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF976DF2F0FFE3EEF3E6F2EEEFF3EFFBFFF3
E6E7FFF0E4E9FFEBEEE8EFDDDCEDE1EAF5EBF6FAF7F9FAFD
FDFDFAFAFAFAFFFFF8F8FFF3F3F7FFF7FFFFFFFFFFFFFFF7
F7FFFFF7F7FFF7F7F7F7FFFFFFFAFAFAFAFFFDFDF7F4EFF1
F7FAFAF7F9FFFCFCFAF8FDF9F9FFFBFBFFFCFCF6FDFCFAFA
FAF7FCFAF1EEFCEEE3E1D9DBD5D9DDE0EEF7F3F2F2F0EAF2
E6E3E3EEEFFFEAF2E8DCECF2F4F6F6F5F5FFF6F6EEEFED9F
D2F2F2FBF9F5F6EEF0FFF0FAE6D2D5E4F5FEF8EDF3617FEE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF19D74ECF3FDF3DDFAEEEEEBF3EEFFF3F3FF
F9D0C1D9DBFBFBEFE9F8E5DDDEEDE3EFEBFCE8FAF5F5F3FD
FDFDFAFAFAFFFAFFF8F8FFF3F3F7FFFFF7FFFFFFFFF7F7FF
FFF7F7FFFFFFF7F7FFFFFFFFFFFFF8FDFBFBFBF4FDFCFDF7
F3FCFAF7FAFCFCFCFFFFFCF9FAFCFBFCFCFBFBFCF7FAF4FD
F7F5FEFBFEEFEDF3F6EEECE7D6CBC5BEB2B0C2D1E5EEF5F5
F2EEECE0E0D6DCD8D7E5F8F4FFF6FFF6F8FEF7FBF4EDD6A0
ECEFFBFBF3F4F7F5E4F5F7F2FEFAE5F3E8EEF7EDE83CCDE9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE19A90F1FAFDF8D5FDF9E5E8F3F3F3F3F3FF
FBE6EFF0F0F4F2EFE8F8E2DFE5E5E3F1E4F6F7F0F5F7F7FF
FDFDFFFAFFFAFAFAFAFAFFF7F7FFF3F7F7FFF7F7FFF7F7FF
FFF7F7FFFFF7F7F7F7FFF7F7FFFFF8FBF7F7FFF6F7F4F4F7
FFF7F7F7FAFCFFFFFFFAF8FAFAFAFFFCFBFBFBF9FFFFFAF7
F7F5FEFDFEFFFAEFF6F3EEEBF2F0E4E9EDDFDAE1E1DBDED4
CAD2E4E8DBDFE8ECFEF8FEF8F4FBF9FDFFF6FFF6F3EDCBB8
FFEEFFFBF2EEEDE8F0EAF5E2F0F7E6F3F3EEFBEDE276758C
CDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFCB82C1E3F7FDF9E1E5F9EAFBF3EEFFFFF3E6
E5F3FBFEFEF5F1F6E8F7E6E4E0E7E3EDECEBFCF0F5F7F7FD
FDFBFFFAFAFAF8FAFFFFFFFAF5F3FFF3F7FFF7F7FFF7F7FF
FFFFFFFFFFF7F7FFF3F7FFF7FFFFF5FFF9F9F6F4FDF7F7F1
F4FAF3F4FCF7FFFAF8FFF9FCFAF9FBFCFFFFFAFBF6F5FFFF
FFF9F7FEFFFEFEF8F7F1F6F9F5F3F1ECECEAE9E1D9DAD5D5
DAE4E0D8E4EBEDF6F8F6F1F8FEF6F7F7FBFBFEEDF6E8C0C8
FFEEFFF5F5F9EFE8E9F0E5ECF7EBF3E6E3FBFBF2E0C3B388
93FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFB27EDAE9FAF0ECFAE0F0F0EFF3F3F3F3FFE3
E1F2F3EEEEF3F0F4E6EFF0E5E8E4E3EAEFF1EBF7F1FCF7FD
FDFBFFFAF8FAFAFAFFFFFFF5F1F7F7F7F7FFFFFFFFF7F7FF
FFFFFFF7F7FFFFFFF3F7F7FFFFFFF5F7F9FDF4F7F7FFFFFC
F4FBF3F1FFF7FAFAFFF8FCF9F9FAF6F9FAF9FDF9FFF0F8FA
FAF8FAFBFEFEFEFAFAF7F7FCFCFCFCF6F1EDE4EDECE7E7E7
EAEAEAECF4EEFBF8FFFEF6F8FEF4FBFDFCFBF5EDF7DEC6D6
FFEEFFF5F0FFFBF7E8F0EFF7F6EDF2FFEAF5FEFEF0D0F6A1
6FFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF928FDEFAF7EBF1F5E4F4F7F2FBFBEAF3EFF2
F2EBF2EBEEF3FFF9F4E5F1E2E6DBDAD9F5F2E2FAF1FAFFFF
FDFDFFFAF8FAF8F8FFFFFFF7F3F7F7FFF3F3F7FFFFFFFFFF
FFFFFFF7F7FFFFF7F7FFF7F7FFFFFAFFEEF4FDFDF4FFF7F1
F1FDF9F7F1FAFAFAFDFCFCFFFCFCFAFAF8F9FCFFFBEFFAFA
FAFAFAF5F6FEFEFEF7F7F7F7F6F2EEFBFCFCF1EDEDEDEFF6
F9EFF3F3F3FAF8F8FFF8F8F8F1F6FBFBF8FAF6ECE9DAC9DF
FFEEFBF9FBF9F4EBFBEEF9F9FDF7FDE8F4EEF3E3F0C4F3B1
5DE2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF70A3EBFAFAF3F7F8E6F7F3F7F8EFDFFFFBF2
F2F2EEFBFBF3EEEFF3F4F1DAFAE8E1D7EDF7DBF5F1F7FFFD
FFFBFDFAFAFAFFFFFAFFFFF7F3F7F7FFF7F7FFF3F7FFFFFF
FFFFFFFFFFF7F7F6F4FFF7F7FFFFFFF8F4F7F7F4FDF4F3FC
F9F9FCF5FAF8FFF8F5FCFCFAFFFFFAF8FAFAF5F6FAF1F8FF
FAFAF7F6F5FDFEFAF9FAF1F6F1EDF7F2F6EDEDF6FCFDFFF3
F0F3FAF7F7F8F5F5F6FCF6F8F6FEFFFFF7F5F3ECDED4CFEF
FFF3EEFBF9F9FBE9FFE9FFF9F9F9F3F4F5F3E6ECE8CEF7DE
5DAEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFF5FB8ECFCF7F7F0F0E4F4F4F1F0EDE3F3EEEE
F2FFEFE7EAF3FFF2DDE3FDD7EBF1D7E9DDF7E2F5F8F6FAFB
FDFBFDFAFAFAFAFAFAFFF7FFF3F7FFF3F7F7F3F7FFF7FFFF
FFFFFFFFFFF7F7F6F4FFF7F7FFFFFAF7FDFFF7FCEDF6F7F4
F9F5F7F2FDFAFAFAFAF9FCFAFFFAFAFFFCFCFBFCFAF9F7FC
FAF7FAF5FAFEFEF9FAFAF8FFF2FFEFFAF7F5EFF7FFF9F9FC
FDF8F3FFF3F7F5FCFDF6F8F8F8F8FFF7FEF6EBE0DAD2EDEF
FFEFEFF9F5FBF0F0F6F9EFF6F7FDF4F3F3FBE2EED5D5F3FB
7C7EF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FAFAFFFFFFFF43D4DDF0F8F3F1FCF4EAF4F6F2E6EAFBEBEA
F2FFFFF2F2FFFFFBEFECF2E8ECE5D7D3CBD7D7F5ECF5F1F7
FDFFFFFFFFFAF8FAFFFFF7F7FFFFFFF7F3F3FFF7F7F7FFFF
FFF7F7F7F7FFFFF3FFF7FFF7FFFFF5FFF6F7FFF4F1FFF7FB
FBFAFFFBFCFAFAF8F8FFFAFCFCF8FFFDFAFFF9F9F7F9FAF9
FFFAFAF0FAFEFBFCF9F7F9FAFFF2F3F2FAF5FCFFFFFCFFFC
F8FDF6F3FAF3F3FAFCF6FFFFF8FFF5FDEFE4DCDADBD0ECF0
F3F2FBFBF3F7E8F5E1DCE7FCFDF5FBEAEEF2EAEECCEDDFF3
9674FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFF2DF3CBE2F0EAF2F7F3E3F3F7F7F7F9EBFBFB
F7F2F3E2E2EEF3FFEAEFF0EAFDEFE4DDDCE7C5F5EDFCF5F5
FDFDFFFFFFFFFAFAFAFAF7F7FFFFF7F7F7F3FFF3F7F7F7F7
F7F7F7F7F7FCF6FFF7F7F7FFFFFAF9FFF6F7FDFDF4FDF7F8
FAFCFAF5FAF9F7F7FFFAF8FDFFF9FFF9F7FFFDFAF4FCFFFC
F8FFFAEEFEF7F5F8F9F7F9FFF8FAF5F2F5F7FCFFFFFDFFFF
FAFAFBFDFAF9FAFAFCFDF8FEF7FFF5FAE7E7F1DCE2DEFBF2
EFF2F2F7EFE4F9DBF0F0F6F6F3F5F8FDFBF2F6EBD8F5EFDB
A36FFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF1DF1CBE9F7FFEEFDF6F3F3F7F7F7F9EEFFFF
EDF0EFECECF3F3EEFBE3F0EBFDEFF7DBDAE7C7EAEBFCF8F3
FFFBFFFFFFFFFAF8FFFAF7F7F7F7F3F3F3F7FFF3FFFFF7F7
F7FFFFFFF7F1FCFFF7FFFFFFFFFAFAFDFDFDFFF4FDFDF1FE
FEFCF8F5F9F9F7F7FFFFFFFAF9FCF8FFF9FCF6F3F9F7F9F9
FAFAF8F9F5FBF9FBF9FFFFFFF8FAF2FAF6FCFFFFFCFAFDFC
FBFAFFFAF8F8F8F8F8F8F8FEFEF5F7ECEAE8E6D2DEE6FBDF
F0FFF9F9E4F0D3F0F6EFEEFDF6F2F1F5E6EAF7E8E9F0EFDB
B07AD9F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFF00DDE5F0F5F3EEF7FAF7E4FDF3F7EEF3FFFF
F2FBF2F9FBF3F3F3FFF3EFE2EFFDFBF7DDD2C0EBE2FAFAF6
F5F4FDFFFDFDFAF8FAFFFFF7FFFFFFFFFFFFF7FFF7F7FFFF
FFFFFFFFF7F3FFF7FFFFFFFFFFFFF8FFFDF7F6F6FDFFF1FA
FAFDFAFAFAFFFAFFFFFAFAFFFFF9F5FAFFFFF6F3F9F7FAF7
F9FFFFFAF9FAFBF9FBFFFFFFFAFFF2FFF6F7FFF7FAFFFCFA
F9FAFFFAF8F8F4F5F8F8F8F8F4FDFAE6E8F1DAE5ECEEEAED
F3FFF9E8F0E9CDFFF3F4F9F9F6F0F7F6E2F0F0EDF3FFE0E2
BF8BB7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFA
FAFFFAFAFFF102F0F8F5FFF0EEF4FAF6EDEAF7F3E5F3FFFF
F3E3F7F6FBFFF3FFF3FFFBD7EFF8E9F4F6D7BAE5DFE3F9FF
FAF7FBFFFDFDFAF8FAFFFFF7F7F7FFFFFFFFF7F7F7FFFFFF
FFFFFFFFF7F7F7F7FFFFFFFFFFFFFAF8FAF4F4FDEDF4F6FD
FDF6F9F9FFF8F8FCFCF8F8FFFFFCFCFFF7F7FBFAF4FAFAF9
F9F5FAFBFEFFFBFAFFFFFFFFFFF8F9FAF6FAFCF6F6FCFAFB
FAFCFDF2F6F6FFF6FAF7F8F8F6FFEFEAE8EAD2E8E3E3EEFF
FFF7E5EAEFD9F5F3F6F6F8F6FFFFF9FDF0FFEEF6EBEED9E5
CE88B5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFA
FAFFFFFFFFEB30D4EAF3F6E9E9F7FCF6F3EBF4F6E5EEF3F3
EEE3F0F2FFFFFFEEFFFFFFD9F0F4FBF6F2E3BEE4F2E4EDFA
F7FFFDFDFFFFFFFAFAFFFFFFFFFFF3F7F7F3F3F7F7FFFFFF
FFFFF7F7F3F7F3FFF7F7F7FFFFFFFFEEF1FFF7F4F4F1F7FC
FEF8F9F9FAFAFAFCFCF8F8FFFDFDF7F7F6F9FDF7F8FDF1F1
F6FAF9FDFEFFFFF9FFFFFFFFF7FCFAF3FFFCFCFCFAFEFDFC
FFFFFFF6F6F6FFF6FCF7FFF7FAF6E9E7E8E5E1E7E8EEFBFB
FFEFF0FFDDEEEEF6F6FFF8FFFFF0EFFFF9F7E6FFE8F3E9E1
CE76C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FFFFFAFAFFEB42DFE8FAEDEFF7F3FFF7F3F2F6ECE2EFFFFF
F3EEF2F0F2F3F3F3F2F9F9E7E5EDF5F1F2F5BDE1E6EBEFF1
F5FAFFFBFFFFFAFAFAFAFFFFFFFFF3F7F7F3F3FFFFFFFFFF
FFFFF7F7F3F7F3FFF7F7F7FFFFFFFAF1F4FDF4F7F7F3F7FC
FCFFFAF8FAFCFCFFFFFAFAFFFDFDF1F1FBFDFDF7F8FDF1EC
FAF6FEFBFBFAFAFBFFFAFAF7FFFCF8F6F7F7FCFCFEFEFCFC
FDFDF9FCF5F8F5F2FCF8F7FAFCF9EDE5ECEDD9E4F9EEFBFF
EAE1F0E1DFFFF9FDF6FDF3F9F0F9F7F9F8F8F3FBF2F3F9DB
C568D6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFAFAFFD33BF0ECF1E7F6FFF8F6F7FCEAEDF1F1F1F3F3
F3FFE1E2EDF3F3F3F9E4EFF4E4ECEDF1F5F0C6E8D9EEF1F1
F7F5FDFDFFFFF8F7F9FAFAFFFFFFF7F7F3F7F7FFFFFFFFFF
FFFFFFFFF3F3F7F7FFFFFFFAF8F8FFF7FBFDFDFFF3FCFCFA
FAFAFAFFFFFCFCFFF7F7F7F7F7F6F8FDF9FBF6F7FFF8FAF9
F6FAF8F8F8F8F8FFFFF8FAF9F5F5FCFAF7F7FCFFFBFDFCFC
FDFDFAFCF8FFFFFDF4F8FAF7F9EEEFD3E4E0DFF0FBEEDCDC
FFD8D1E5F4F3F3F9FCF6F6FFF7EFEFEFF6F6F3F9FFEEEFD9
8870E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFAFAC83FEDEFF8EFFAFCF8F5F7F1F6EBFDFDEFFBFF
F3FFEFE1F2FFF3F3EFF2EFEFF2E8F2E9EFF5C9F0DAEBF0F3
FAF1F7FDFFFFFAF9FDFAFFFAFFFFF7F7F3F7F7FFF7F7FFFF
FFFFFFFFF3F3F7F3F7FFFFF8FFFFFAFDF5F6F4F4F7FAFFF9
F7FDFAF7F7FFF7F7F3F3F7F7F7F9F9FFF8F9F7FFF8FFF8FC
FAFBF9FBF9FBFBFAF8FFF9F9FAF3FAFAFFFFFDF9FAFBF8F8
FCFCF8F3F8F5F5F5FEFAFCF7F8EEECD4ECEBF3EDF1F4F4E3
EAF2F6F6FDF5F5FFF8F9FFFFF7EEF9E7FFF7F3F9FBEBE9B2
5FBFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFA
FAFFFAFFFAB44CF0F4EDF1F7F4F8F6F8F6FFECF2F6F7F3FB
F3F3EEF3EEF2EEF3F3F2EFD9F8E8ECE9E7EACDF6E1E9E4EE
FAF9F5FDFDFFFFFAFAF8FAFAFFFFF7FFF7F7F7F7FFFFF7FF
F7F7FFFFF7F7F7F3F7FFFFFAF8F8FAF9F3F4EFF6F3F4F8F7
FBFCF9F7F9F6FFFFF7F3F7F3F7FCF6FAF7F9FFFAFFF8F5F5
FDFAF9FAFBF9F9F8FFF8F5FAF5F9FFFFFCFFFDFBF8FBF9FB
FDFDF9F3F5F5FFF7FAF7F1EEF3E9F0DFE5FCF2EDF4F0FBE3
F3F9F9F9F9FBF2F8EEF7FFF3FBEEEFF4F7F9EBF7E2D2DE94
70F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFA
FAFFFAFAFFA463F7E4EAEFFDFEF3F8F9F6FCF3F7F6F5F3F9
F3F3EEFBD8E3F3EEEEF9EFD8EDE9E0F2E5EED2F4F2EBE1F1
ECFAF3FDFFFDFAFFFAFAFAFFFAFAFFF3F7F7FFF7F7F7F7FF
F7F7F7F7FFF7FFF3F7FFFFFAFAFFF8FBFDF7FDF6F6F4F6F8
F6FBF9FFFBFAFCFFF7F7F7FFF5F6F7F6FAFFFAF5F5FAF6FF
F9FEFAF5F7F7F7FAF8FFF7FFFCFCFCFBFBFFFFFDFFFFFCFC
F4F3F5F6FCF5F8FDF6F3FFF5E8FBEDE1E6F1F1F1F4EEEDE2
FDF6F6F9FFF7F6ECFBEEF3F6EAF6F8F9FDF3EFF0EECED37C
8CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFFFAEDB95DFEFEE0E7FAF1FCFAF6F6FCFCF3F6FFEBF8
FEEEEEFBE1E3F3FFEFFBFFEDE8F9F3E7F4FFD5F0F6EBE1F6
EBF8F6F7FFFFF7FAFFFAFAFFFAFAFFF7FFFFF7FFFFFFF7F7
F7F7F7FFF3FFFFF3FFF7FAFFFAFFF8FDFDF4F7F1F6F4F6F5
FAFAFAFFFCF9FCFFFFF3F3F7F9F9F7FFF7FAFAFAFBFEFBFB
FBFAFDF1F7F8F8FAF3F5FCFBF9FFFCFDFFFCFAFCFDFCFDFA
F6F7F8FDF8F2FDFAF6F5F6EFEFFEEFD2E8F1F4F2FFF2EAF5
FCF8F6F6F3FFF4F3F3F6ECEEE8F6F6EFF5FDF3F7F0E8CD6F
A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFA
FAFFFFFAEEC84FFCF6DFE6FAF4FAFBF7F6FFF7EEE6EDF3F0
FEF3FFF3F3F3F3EFFBFFF4F4E1F7FCE0FEF5D6F5F4EFE6F0
ECF5F7F5FBFDFDFFFFF8FAF8FAFFFFFFF3F3F7F7F7F7F7FF
FFFFF7F7F3F7F3FFF7F7FAFAFFFAFAFDFBFDF7F5F9FCFBF6
FAF8FFFFFCFAFFFFFFF7FCFAF7FAF5FFF7FAF8F5FEFEFEFA
F6F3F2FEFBF8FAFFF3F6FCF9FCF8FAFAFAFAF9F8FFFCFDFA
FCF6F5F8FCF3FEF9F2F3F7FCF0F1E7C8F3E9EFF9F2EAF8F9
F4F1F9F6F6FFF4F6F6F7F6E8F6F0F9F3F5F9FDF7E1EED186
85FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFA
FAFFFFFFF0CE46FEF5E6EAF0EDEEEDF7FAFBF3FCD3EBF6EC
F3F3EEEEFBF9FBFBFBFFF4F4EBEEEEEEFCECDDF4F3EFEDED
F2F1F4F2FDFDFFFFFDF7FAFAF1F7FFF7FFFFF3FFFFF7F7F7
F3F7FFF7F7F3F7FFFFFFFFFFFAFFF9FFFDF7F5FFF9FDFDF8
F8F8FAFAFCFCF3F7F7F5F7F6F7F6FAF7F9F9FAF5FDFEFEF9
F9F2F3FFFBF6FDFAF8F6F9FBF8FDF8FCFAF9F9F9FAF8FAFC
FDF6FFF8F5FEFFF5F1FAF7F7E4F4E1E2EEECF9F9ECFFFBF7
F5F9F7F9F3F2F6FFF6EEE7F9EAF6FDF6FCF6F5E6F9ECDA88
84FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFF
FAFAFFFFEBC74DE9E4E6F0F8F3E5EEFFFCFBFBF4DCEDF6E7
EAF3F3EEF9FFF9FFF9FFF4F1F7EEE8E8F1F7DDF6F0F0EEE9
F6F6F1F5FAFBFDFDFDFDFFFAF1F7F7FFF7F3FFF3F3F7F7F7
F7F7FFFFFFF3F7FFFFFFFAF8FFFFF9FDF4F1FBFBFCF8F6FF
FFFAFAFAFFF4FDF7F7F9FAFCF3F3F4FDF9F9FAF8FDF9FAFA
FAFAFEFBFFF6FDF9F6FCF6FCF7F5F9FFFDFCFBFFFDFAFFF8
F6FDF5F4F4FEFAF9EEF6E8E5EFEFDBE0F0F0FBFBEFF3FBFA
F9FBEEE3F4F7F3E7E3F0F9F7F3FDFFF6F9F2F9F3F2E1CC6D
A1F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
F7F7FFFFF0C356F2E2ECFBE9F8ECF6FCFFFCFCF6F3FFFAE2
EEF3FFEEF9F7F3FBFBFBF4EDE7ECF7E1ECF3DCEEEEE5E9DE
F1F7F1F3F8FDFDFBFFFDFDFFF8FFF7F7FFF3F7F7F3F3F7F7
FFF3F7F7F7F3F7FFFFFFFAFAFAFAF4F1F7F6FAFDFCF5F8FF
FAFFF7F1EDF6F7F1F1F2F6FAFDFDF9F9FFFDFDFDF7FBF8FE
F9F8FEFBFFF8FFF9F9F8FAFAF9F9FCFAFAFDF5F8F9F3F8F8
F8FFF5F6F1F5F7E9E0EAF1EEDFDFE8EBFFEBFBFFFFEDF5FB
EFE8F6EDFFEDFBF5F6F9F9FFF9E2E4F7FDE4DDEFEEBB5B69
D2F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFF
FAFAFFFFF0DA50E6F7EDEEF3ECEEF2F9F7FAF9ECF7EBE8ED
E9EBFFEEFBF0F3F6F3FBFBE3EFFBEFEBE5EBE6F1F3ECEDE4
EBF1F1F6F1F7FFFDFBFDFBFFFAFAFFFFF7F7F3F7F7F7FFF7
F7F7FFFFFFFFFFFFFAF8F8F7FDFDF7F3F9F9F6F9F9FCFBF5
FFF7F7FCFCFDFFFAFAFCFDF7F4F4FDF9FFFCFCFBFAF9F7FA
FFFBF9F9FFFAF7F4FDFBFFFCFCFCFBF9F8F5F3F5FDF6F8F8
F8F8F7FAFCF2F3EEF2EFF0DFF4ECF2EBF4F3FBFFF8FFF2F0
EFFBF3E9E8DCE3EFF9F9F7F9F9DED8EEF0EEE6DFFB8D64D9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFFFAFA
FAFAFFFFEBDA48F2EEF7EDF7E6FAF1F1ECFCF5ECF7DFEBFF
EAE1FFF3F3EBF4FFF6F9FBF3E9F7F3E5D4EEEEEEEDF8E6E7
F3F0E8FAF7F5FFFFFDFBFDFFFFF8FFFFF7F3FFFFF3F3FFF7
F3FFFFFFFFFFFFFFF8FFFFFDFDFBF6F1F4FCF6F9F9FCF6F6
FFF1FCFFFDFDFDF7F6FDFFF7F4F4F7FFFFFDFFF6F9F9FAFA
F9F8F9FBFBF7F9F6F6FCFDFFFFFCFCFCF6F6FDFDFDF6F8F4
F2F2FFF9FBF0F5ECEADEE1F6F2EDF3F3EFFBFBF3F2F2ECF6
FBEBEEE4F6F6F0EFF6EAE3E8F3F3FFEEEEF0D7FBFB607BF1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFAFAFFFAFA
FAFAFAFAF1CE50E8EAF4F2F6E7F7FAE9E0F6F1F7F7ECFDF8
F6D4FFFFEAF4EEFFF3F3F7F7E8ECF4EFD4F7F1DEE9F3ECE1
EBF4E2FAF7F5F7F7FBFFFFFFFFFAFAFFFFF7FFFFF7F7FFF3
F7FFFFFFFFFFFAF8FAFFFDFDF4F6F7F6F8F6F5F9F4F9F5FF
FFF1F4F6FDF6F7F5F3FDFFF7F4FCFFFFFFFFFDF6F6F9FAFA
F8FDFFFAFBF6F7F7FDFCFCFCFCFCFDFDFDFCF6F7FCF8F8F7
FCF3FDF8F2F6F4EEFCE0F5FFEAFDECF0EFFBFEEFFBFBF9EF
E6EDEEF2DFF3F4EFF0FFF7F7F3F3F4E8EEDFF2F3DF6289FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFAFAFFD64EEBDDF5F4F7E7F5F3E5EAFCEDFAF3F7EDF6
F6D8EEFBEAF7F5F1FDF6EDF1FFE5DDE6D4F5ECE8DFE7F3EA
E7F3DEFFF8F6FCF7F9F7FDFFFFFFFAF8F8F0F0F1F7F7F7FF
FFFFFFFFFFFFF8FFFFFFFDFFF7F4FDF5F8FCF9F9FFFFF1FF
F7FFFFF7FDF6F7F9F7FCFDF7F6FFFDFFFAF8FAF6F6F7FFFF
F9F6FBFFFAFAFAF2F5F9FBF9FCFAFDFCF8FCF3FBF8F8F8F8
FCF2F9FAEEF7F8EAE7E9F8EDE6ECE8F5F9FBFEF3EFFFF5F5
F7FDF2EEF9E8F4EAF0F5F9F7FBFBFFEFF9EBFBEFD6658EF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFFFFFFD65DE2E7F1F6F1E2F8FAF1F4E8F6F7F6F7F3F6
F2ECDFF2F2E1FDFFF6F2F6F0F4F0DEF4ECEBF6F9DDE6EEE3
EEF0DAFFFAF7F5FFFAFAFBFFFFFFFFFFFAF8FAF8FFFFFFFA
F8F8F8FAFFFFF5FDFFFDFDFDFDFDF4FAFAFCFAFCF9FAF1F7
F7F3F3FDFCFCFCFDFFFDFDFDFAFDFDFAFCFAFAF6FBF9FFFF
FAF9F9F7F4F8F9F9FFFAFCF7F9FAF9FAFDFFFAF7F8F8F8F3
F5EFFBF1EEE9E5DDE6FEE8F2F2F8F4F4EEEAEEEEF3FBF5F5
F3F5FFF9EEEEEAF3E8FAE8FBFFF7F4F9F9F0EFE3E34DB0F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFF
FAFAFAFAFFD675C1E5F4FDF3E6F1F5F7E3EAFFFCF3F7F7EB
F6F6EEEAFBEEE3FBFAE9F8E7F6F1EFEEFAF3EEF9DDE5FEDA
E9F0DAFFFAFFF1F5FFFFFDFDFFFDFDFFF8FAFFFFF8FAFAFA
FFFFFFFAF5F4FAFDFFFDFDFDF4F6F7FAF6FDFAFAFCF9F6F7
F6F4F7FCFDFCFDFFFDFDFFFCFCFAFAFDFDFDFAFAF6FFFFFF
FFFBF7F1FCF8F9FAF6F8FCFAF9F9FAFAF8F8F8F8F8F5F5F7
FAF7F2EFEEEDF7EAE6E6ECFFF2F8F0F0EEFFFFF2EDF2FBF0
EFF7F9F9F9F9F3F4FFF0EDFBF3FBF4F6F0F2EAE6EB1CDAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFAFF
FFFFFAFAFFEB64C8E5EAFDF7F4E7ECF6E6FFEEF7F7F7F3F7
F6FDEAD4EAF3F2DFFFFBEAF3E2F2F6E6F6EEF5EFDBD0EAE7
E2E0E1F1F8FAFAF7F4FFFFFBFDFDFBFDF7FAFAF7FBF7FAFD
FBFBFDFDFDFDF7F4FDFDFBFDF7FDF0FAF6FBFBFBF6FAFFF7
F1FAFDFAFAFAFCFFFDFDFFFAFAFDFFF8F6FAFDF6F7F8FAFF
FBFFFAF6FAFAF4F9F9F9FFF9FAFFFFFCF3F8F5F3F2FDFDFA
EFE7EDF8EEF3E6D7D4ECF7EEF3F4EFF3F3FFFBF6F3FDF9F0
EBF1F3F7F9EEF0FDF3F9F5F3F7F6EEF6E8DFD6E89D3EF7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFFFAFAFF52D1EAE4EBEEF4DBDFF6EDE6DCF7ECE4EBEB
F6F8ECE6E6FBEFF2E3FBF0E1F8EBFCF3DDF3FBFCEEECD8E1
EEDBE1E6F5FAF7F1FDF7FFFDFDFFFDFFFDFDFBFDFFFBFDFD
F7F7FDFDFDFDF4F7FDFDFFF7F7F1FDFAF7FBFBF9F6FFF4F1
FFFFFCFCFDFDFDFCFCFFFAF5F5FCF9FAF9FAFDF1FBF9FAF6
F8F8FAFAFAF8F8FCFAFFF9FCFAFFFFFCF3F5F8F5F0FAFAF7
F6ECFEF0E8E7F2F6E7F1E8F4F0EFEFEFF2EDF6FFF7F9F9F7
FBF9FBFBF5E7EDF9EEF1F7F0F3F5E8F1DAF2F1D35BA9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFFFAFAFF52E0E6E9F1EEF4DBE7F6F1DBEDF3DADAE6E6
FFF6FFF7C7E8F3F3F3E3F4EDF7ECF4F7EAF2F8FEF8E8EAE0
F8E0E3E5E6EBEBF0FCFCFAF7F7FFF7F4FDFDFDFFFFFBFDFB
F4F6FDFDFDF4F3FAF7F7F7FFFDFDF4FCFCFFFCF8F4F4F0FC
FAFFFAFAFDF3F6FCFCFDFDF7FBF8F8FBFBFAF9FBF5F9F5FA
FFFAF5F7F9F5F7FCFCFFFBF9FBF9FAFCF6F5FDF5F6F9F9F3
F4E0ECE8E9F2F7F2E1F1EFF3F0FFEEF9F3FFF7F3FFF9F9F7
FFFFFFFBFBFFF7F9F6E3F3F6F3F0EEEAE4FDF19368EBFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFF49E8F4E3E3F6F8E7F7EBFFE3FCEEE0ECDBF6
EBF2F6EDD4FFEFF3EEF2F2EDEFF5EBFDEAE4FCFDEFDBE7DD
F2E6E4EFF5F3FAF0F6F4F5F9F5FAFCF7FDFBFDFFFFFDFBFD
FDFFFDFBFDF4FAF4F4F1F7FAF5F5F4F9F5F5F8FAF1F7F7FA
FDFCFAF1F1F8F8F1EFF1F5FFF6FFFBFBFFFAF8F6F5FBF9FF
FFFAF5F6FDFAFFFCF9FAFCF2F2F6F3F6F6F3FCF6FFF8F8F1
E7EAF7ECF4F4E9EDE6F8F4EFF3EEF3F2F0F9FFFDF9FFFDF9
F9F7F9FFFFFFF9F7F9EAF7ECEEEEEADDF4F7D57298FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFF
FFFFFFFFFFFF62C1F4DFD3FFFFF3F7ECF2ECFCF1EAFAE0E9
EEEDEDF7FBE1FBF2F9F1F5F1EFF3E5EDF2EAEFFBF0F0E3E2
EEE1D8E5E8E2F1EBFAFAF6F6F6F9F9F5FAFFFFFFFFF7F7FD
FDFDFBFDF6F6F1F4F4F5F4F6F1F5F8F5FFFFFFFFEFFAFAF4
F7F4F6F5FFFAFBF5F5FBFBF3F2F8FAFBFAFBF8FBFFFAF5FA
FFFFFAF8FAFEFAFCF7F9F7F8F4F5F2FCF7FEFBF5F9F1F6EE
F1F1F7ECEFF2EEFFEEF4ECF0EEFFFFEDF9F9FFF6F7F9F9F7
F8F3F9F9F7F7EFEAE3E6F3F9F6E7E1E2F3F2C766C1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFF
FFFFFFFFFFFF909EF6EBE1E5F6F8EBF3F7F7F7F6F7F5ECDF
F2ECF3E9E9E7E8EAEEF1FAE8F5EEF6EFF3F1DEF8FAF4F6D2
E7EDDDEAFCEDF1F1ECFAFAF1F7FCFFF7FAFDF6F5F5FDF6F7
F1F3F5F5FCFCFCF7F1FAFEFCF5F2F1FAFFFFFFF7F1FAFAEE
F4F3F3F5FBF3FDF5FAF8F8F3FBFAFBFBFFFBFAFBFFFFFAFC
F6FDFFFFF6F9FFF9F9FDF2F3F1F4F6F4FAFAF9F5F1F2F5EC
F0E5E6E3ECF1F2F3E8F0FBFFF3F3FBF0FFF9F6F0F6FFFFF7
F5FBF0F4F6F3EEF0F2F9FBFFF2E1DBFBF4D9BD60D1F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAC85F5E7D9EEF7F6E5F3F7F6EDF1F7F5F3DC
EEEBF7DBEDF6E1EFEBF6F1E8ECF5F7F7E5EDDAFCF9EDF6F2
DFD9DADEFCF5EFFFF0F6FAF0F0F8F5F0FFF6FDFAFAF6F4FD
EFFAFAF5FCF4F2F0F5FFF8F8F9FCF7FCFCFDF7F1FFFFF8F2
FBF7F6F3FBF7EEF6FDFDFBF4F5F9F3FBF6F9F5FAFAFAF7F9
FAF2F6F5F8F8FBFAFCFFF5F8F6FCF5FDFAFFFFF2F8FCF7EB
F0DEEFFDEAEDFFEEEFFAFFFFF3F3F2F7F9F9FFF9F6F4F9FD
F9F5E6EEEEF0F2FBFFFFFFFFECD5E8EFF1E39773F1F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFA
FAFFFFFFFFFFCA6EE9DADAF2F0F6EBFFF3EDFFF3F5E5EFED
E1F3EDE6ECE1EAEFEAF2EEFAF0FAEDF6F0CEEED9EBF1F0EA
E9E4D6CACFE0EAECF0E5DFEEF5FAFAF7EFFFFFF7F7F3F7F4
F6F3FDF6FAF9F7F9F7FBF6F6F6FAFDFCFAF1EDF9F5EAEBEE
F6F7F4F1F6FAF5EEF4F4F3F6FFFFEEF3F1F1F6F5F5FAFAFF
F6FAF8FCF8F8F6F8F8F1F4F4F4F3F9F5F6F1E5E7E7E3E1E7
F7E6F0E9E0EEEEF3ECEFEEEEEFF2F5FDF6F7F7FFF6F3F6FF
FDFDECFFF3FBFFFFFFFFFBF2EBDCFBF4FBD36596F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFA
FAFFFFFFFFFFEE7EAEEDF0F8F3EBF2F3FFF3F2EBF3EAFAF6
EFF6F4F2E1F4ECF9F9EEF4F5F3FFFAF5EEEAD1F7EAEFFCFB
F4E5E4EAE1DBE5E5EDFCF1FAF5ECE6F5FAF0F5FFFAF9FCFF
F7F7FFFFFCFBF7F8FAF5F3F2F5F8F8F9F9F2EEF0F6FAFAFA
F9FFFFF9FAFAFAFAF8FAFFFAFAFAFBF9FAFAFAFCF7F7F2F7
FBFBFFF9FFFBFBFBF6FBFAFBFBFEF9FBF8EFF7F1F3FFF7F7
FFDDF2F2EEFFF4EFE3F3F3F3F9F7F9F6FFF0F0F4FFF3F3F3
F3F6ECF7F9FBFBFFFFFFF2EEDFE6FBEEF5A252DAF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFF9B9FE7E9FFFAECF6F3FFF7EBF2FFF3F3F1
F6E7EDFFE5EAFBF5F4F2F5F8F7F6FFECFFF6F1D5FAE3EEF2
F8F3DEE9E9DCD6D7E0ECEEE6E9F2F1ECEDF6FAF8FAF4F2FA
F8F8FAFEFFFAFAFFFFFAF4FDF8F8F9F7F7F0EDF8F5FAF8F8
FFF8F8FAF8FAFFFFFFFAF8F8F8FAFAFFF8FAF8F8F2F9F7F7
FBFFFBFAF7FBFBF7FFFDFEFFFCF9EFF5F6F3FFEBFEFFF7F7
F2EAEAFFEEF4F4FFE8FFF3E9F8FFF3F9F9F9FFF4F6F7F7FF
F3E8E7FBFBFBFBFFFFFBEAF0E3F3EEF7F95E79F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFF7B28CDAEAF4FAF3FAF6FCFCECFDF8F9ECF3
F7E6F4F4E6EEF3F3FFF5DFFAF9F0F2F7F7F7ECEAD1FCE5DC
F2FEF0DCDCE3E1EAD9D3D9E5E9E4E4EAE8EEE7E5EDF8F6FA
F6F5F4F2F1F5FAF8FAFAEFF4F8F8FBFFFAEEF4F0F7EAF6F7
F5F9F8F5FBF7F7F7F6FCFFFFF5F1F5FDFCF9F8F9F5FCFAFC
F7F9F9F6FFFCFCFEFCF7F7F6F9FBF4FEFBE8EBF1FFF7E7E3
E6E8EDF3F3EFFDEFEFF2F2F9FBF5F0F6EFEFF9FFFFF7FBF3
F3F5EEF9FFFFFFFFFFF2EDE5EFF2EFEFB82FCCF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7D38FBBEDF0EFECF1F7F8FFF3EDEEFAEDFC
EEF0F0EDEBEEF2F9EBE9F5D7DDF6E9F2EDF7F6E8E5C4DDF5
E5ECF4FAECF0E9DFDDDADCE0E4F5EEF1EDF4EEECDFDEE3E9
ECF3FCEEEEF6F6F1F1F1F6F6F1F6FCFAF5E8EFDFE5EDEBEE
F3F4ECEDEFF4F8FFFFF7FFFFFCF7F6F2F5F7F6FCFFFBFFFB
F7F9F9FBF8FEFDFDFCF6FBF6F8F8F4FCF8EFF3FEEEDEE4F7
FFEDF3EFF3F0EFF1FFF2FBF1ECF5F0FFF3F6F7FFF6F3EAF3
F7F7FFF9FFFFFFFFFBE8ECE1F2EFEEFF5763F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEEA49CEAF6E9E9FFF1F6FAF3F3F5FAFAEA
F3F2E8F7F6EFF0EFE8FFEBCCEDDFE9FFF6EBF6F6E7FFD5E0
F8E6E0FFEEF5FCF1E5E7E7F7E5E7EFE7D7F7E5EEF7F7F8EB
EFF7EBF0F1F7F5EFEFF4F5F5F9F7F0EEEDE5EEE4EFE8E6E7
E2EBF4F2F8F7F9F8FFFBEAECFAF7F8F3ECF3F7F7FBFBFFFC
FBFAFEF7F7FFF7F2F3F6F7FBF4F5F2F5FCE8E8E6E8EEFDF8
EDF2EEF4F4FBEEFBFBF5E3EEF8FAF4FFF6F3F7FFF6F6F6F6
F4FFFBFBFFFFFFFFF2E6E4FFEFEEEEC82BB4F3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFBF84E6F4EDEEF2F6ECFCF6F3F7FFFDEE
F7E7F6F6FBF3F5E8EFEBFBFBCFE5E6D7EBF2ECFFF7DEEAF3
E0E7F8E0E6E8F0FFFBE8E6F0F0E5F3FFE0E2EEEEECF2E6EA
E2E0E1E9EFEBE6EBF9FAF3E7F5F5F5F4E5EDE2E5F9F8F3F0
FBF5EAEDF5FAFAF8F4F6F7F5F4F4FAFCF9F9FAF7FBF7F7FB
FEF9FAF6F3F3F9F6F6FBFBF8F6FAFAECEAE7F0F0FEF5FDF0
ECF7F3ECFBF3F3FBF7F6ECEEFDF9F9FFFFFFF7F4F7F6F3EE
F7FFF9FFFFFFFFF3E3DFEEEAF3FFFBA03CEBF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD780C9F5F1E7EBF6F3F7F7F7E8F3FDF6
ECE7FFF2F2F4ECF0EEFFEFFBF9D3CAEBE7E0F3EDF3F3FCFA
FCF7EDF0FDFBEBF0F9EFE0F0FFE7E4FCEAEEF2F2D8E5E9DE
DFEAFAF3E7E8F1EAF2EFF4EAF9FFE5E3F1F2E8F4EEECE9E5
E9EEF6F6F2E7F0FAF9EDF1FBFAFAFFFDFCFFFCF2F4FCFCF5
F1FAF9FDFEF6F5F5FEF4F4F6F5F5FCF0EEF0EFFEF7EEF7F0
FFE5ECF2FDF3EEF3F2FBFCFDFFFDF6FFFFFFF4FFF7F7FFF4
FBF9FBFFFFFFFBE8EBECF3FEF3EED27171FAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEE9A8FD6EDECE8FDF8F7EEF7E8F3F6F2
E5FFECEDE4EAF0F8EFEEF9EAECE3F9DCCDCDFFE3EEF3F6EC
ECF3F7FCF4ECEBF1F9F8F0E5E4EED9EADDCED7E2E9E7EAF2
D2BFD0DACDCFDFDBDBEEF4E4D6D6D2D3CBD4DDDEDFF1F6FC
F2F2E7DFE7EAE7ECECF9F8F2F0F7F9FAF9F8FAF9EFE7E0E8
F2EBEDF2F2F6F5EAEFF0F0F5EAEEE6DFF1E9F6F5EEE6E4E5
E5E4EFF1F1F3FFEBFBF3F9F6F6F6F9FFF7F4F7FBF9F2EDF2
FBFFFFFFFFFFE9D7E5FEFFFFEFDC8055BEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD87EDAE6EAEEF0FDF5F6FFF3F6FFF6
F2E0ECF7DCE9F2FBF8E9EEF2F1FBF3F3F3E9E8F3EAF2EDE2
EAF7F3EFF3E8F6F6F6F4FBFBFAE6F0E4E8F8FDEFE8E6E9E5
E9F8F1F0EAEEE5E1E9E0FDF0F3E9E5EEF0F8F8F3F3E6DAE5
E6E2E7EBEEF5F0ECECEDF6F2F2F3F0EFF6F6EFEFF6FDF6FF
ECEEF4F3EFEFF6F5FAF8F9F6EBFEF3F5E7DFF4F7EEEFF4F4
EFEFFFFFF3F2EBF2F6F7F9F9F9F9FFFFF4FFFFF9FFFFFFFF
FFFFFFFFFFFBCFE9EFFBFFF5F3A56CA2FAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFA86B5EADFF6F3F6F5F6FCF1F6F1EE
F6D8F3F3E9EDEFEAFEEAEFF3E3F4FFFAFAF1F1F6EAF3F3F6
FCF6EFF3ECECF6F6F4F4FBF6F1F3EEF6F7F3F1F9F9F0EFF3
F7FFF8F1F1FEF8E5EFD6D6EDE8E7E3E9FCECF4F5F5EFFAF2
F0F9F8F2E0E3FAF6F6EBEFF4F4F4F8FDF5F5FDFDFBFCF6F7
F3F7F0EEF4F4ECEAECECF2F1F1F8ECEEF2F5E6DDE7F7F4F4
ECF3F3EEFFF9F9FFEDFDF8F9FFF6F4F5F3FBFBFFFBFFFFFF
FFFFFFFFFFF2CDF3F2F4F0FBEA756FE2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFB797E3D0F6F6FAFFF7F3F6F3F0F1
F1E0EDE5EEEDEAFFEAF7F2F4EFEBF8EAEAEFF3FCE9EEFBFB
F7F3F1ECF0EEF4F6EDF4F7FAECF2EDE5ECFFF5E8EAEAEAE6
E6EAE7E7F4F3E7D8F1F1E5D1DDE3FEEFE3F3E9FAFAFAF1FF
FBF6F8F8FED8E8ECF4F2F5EFF2F3EEEAF1F7F6F7F0F0EEEE
F2FAFCFFF6F6FCFBF8EBEBF3F3ECE8F5F7F2EFF3FFF4EFEF
EFFDF1F3FBF2F2FBE8F6F4FFF7EEF4F5F3FBF9FBFBFFFFFF
FFFFFFFFF3E3E7F5F5F4FBEAE63BA4FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFD79DC0C8EDEDF5FFFFF7F7ECFAF0
F2F3E6F0E8F7F1F0F6EAFEF5FFEBECF0F3F3F1FFECEEE3E3
E5F6E6FDF6F6F9EBE3F0FBFAECD8F4E5EDF1F1FAF5E6E6FB
EBE4F6F2ECE9EEE4E6ECEAEAE7F0EEECECE0EDF6EBEBF4F7
F7F3E8EBF3E8E9E9E6E9EFFDF4F1F8F7F2E7E7EBF1EDE7F3
F7F7F3F3F7F7F3F3F7F5FAEAF0ECF1FAEDF2FFEEFFEFFEFB
FBF3F3F2F0FFF7F6EBF9F9FFF4F7F7F3F2F9FBFFFFFFFFFF
FFFFFFF3EADFF3EEF9F0EFEACB26DBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEEBE9DB6EFF3F1FAFAFFF3F3F2F2
FAFAF5F6E3F6EEF4EEE7FAF7F7F3ECFFF3F9F9F3F7ECECF3
F2E7F5E6F6F0E9F8F2FEFEF1FFE6EAEEE4F5E9E5EBECECE5
D4E7FAF3E8EEF9F1F1E7F1F1EEE8EDF8ECEFF7FCE8F3F2F2
F7F0FFE7E4FDF9F9F0EFE9DFEEF9F5EAEBF6F6EEE7E6EBEB
E7EEECE9E9E9EEF2F1EDF0F7E6E7FFF1F2F3E5E5ECF2FBFD
FBEAFBF0FFF7F5F6F9F5F7F9F0F4FBFFF2FBFBFBFFFFFFFF
FFFFFBF0EAE5EFF9E4F9DFF0984BFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE4A7A5D9FFF3FCFAFFF3F7EDFF
F1FDFDEAE7F2F3EEEBEEF7F7F7FFEDECECF4F3EEF0EEF7F7
EEEEECEEE4DBD3D6E5F9FAF1E0E5EAE9F2F8E4F8F5F7F5E0
D9ECE3F5EDEFEEEAEAEBF5F5F1FAF9F6F4FAF2ECEBF7F5F1
EDF6FDF3F5E4EEF2FDF3F3F5E5DEDEE9EDEBE4E3E8EDF3F7
F1E6F4F8E8E2DCE1EBF4F7F7FAF3EFEAF3F3F4F4FAFBFBF3
EFE7FBF7F7F9F6FDF7E7F7F9F0F7F0F6F3FBFBFBFFFFFFFF
FFFBF3E8DFFBEFE5FBDBEFF76583FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFEDBD8DB9DFF7F1FFFFF7F7F7ED
FDF3FAF3FFE5EBE7F1F1EDE6E8E8EEE5E5F6F9EEE6EFEFE6
F5F7ECFFF1F7F1EAECFFF6EAEDE9F2E9ECF0E6FAF0F1F1F3
DEEEF8E7EBEFE0DBE9FAEAEAEEFBE9DBD8E8FBF2F1F6E3E4
EDEAEAF1ECF0EBE3DDDFDDDDE4EDEAE4DFDDE5EAEBEEEDE5
E1DBD6D7E3F3F3E1DAD5D4E3E0DDE4DBEBF3EEE3EBEBEBF3
F2F3F8F5F0F9F9F9F7F6F3F6F7F7F7F6FBFBFBFFFFFFFFFF
F3E8E2EFEEF9F8FFDFE3EF7537C0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAE391D5CBF1F3F3F7F6ECFFF8
EDEEFAF8E7EEEEF6EDE5EEDCF3EAE5ECF3FFFFF6ECEFEFEA
FDF3E5ECFCEEEEEFF0FAF6DFEFE7E9ECF2F2EAF0F0F8EAF1
EBF1F0F1F3FCE8F3E4F4EDF3E0E9F4EBF0DCDBF3FAF6E9F7
EDF0F1E6F0F1EEEFF4F4F4F3FFF3F2E8E8F1EEF1F1ECECEE
EEF3FDFBFBEEE5F9FBF4EFE7F2FFFFEFF7F4EFF1FFFFFFF2
F7FBEFF6F9FFFFF4F8F6FCF0FFF7F4F2FBFFFBFBFBFFFFF3
EAECF9FFF0F9F4E9F9F5AD4DBFF7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE69FCED6DCFCF6FCF1F7EDFC
EDF7E8FFF3ECF3F7F6F3F6EBE5E1DEECFFF6F9ECEDF6ECF3
F3E9E5E3F6F7FCF9EECFDFD9F3FAEDFFFFFFE8F6FFF6F6F6
EBF7F6E9FCF3E8F3F0D1F4EAF4F8F7F8E4E9F5EBEEF6F7F1
FBFBFFFFF4EFFBFAEFF3F4E5E5E8F3EFEFFFFFFFFFFAFAF0
F0FFFBF0EEE5F3FFEFF4FFF9F0F0F4FFEFFFF2EFFBFBFFF2
FBF2F2EFFFFFFFF4F4F9F2EBF7F0F9FFFFFBFFFBFBFFFFE6
E7F4F9F0FFEAE3E0DCBB658AFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEABAADD8D3F1F3FCFCEBEBF7
F5E9F3F0F8F5FCF7F3EDF2F6EDC8EAFFF6FFEDE4F4ECEDEF
F6F6FCECEAFAFBFEEFCAC9E8E5E8F9FCF6F5DFF1F8F2FFF2
EBEDE9DEFAF3EDF5E0EDDCF4FAF7FCF4E6EBFAFAEEEEEFF7
F9F3EEF9F9FBFFFFFFF2EFFAFBF2F2E9F3E9F0FFF0ECECF0
EFEFF2F4FBFAF0F4FBFAF9F9FEF2EFEFF0F3EAEFFBFFF2F6
F7FBF6EFF3F4F4F0FDF3F7F7F7F3F2FBF9FFFFFFFFFFFBDE
F2F6F3EFECF8DDD6F3846FD8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFACCBAC6C6D4FAF3F3ECFDF0
FDEDF5EBFFFFF5F6EDE4ECEDEEEADCEEF0E7F0EAF0ECEDF1
E9D5D5E6EFFAF3EFEFE0D5F8EDEEF9FAECF5D9E2FAF6F2F6
F0F3EDEDF6F3FFE3F7E5E0E8F5F8ECE8F6F4F4F4F7F9FFFE
F7F3FEF3F3F3FFFFFFEEF3F3F3E9DCEDEEF3F0ECF4FBFFFF
FBEFEEFFFBFFF2EFFBFFF3F3FDFDF3F3FFEEFFF2F2F9F7FF
F3F0EEF7ECF7FFF4F6F3FBF0F4F7F0F9FBFFFFFFFFF3E8E3
FFF3EFE9E8EEEAD7C650BCF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD6C6CAE4C6F0F6F6F3F8F8
F7FFEAF3EDEDFFFBE5F7EEF0DDD7FCD4C9E8EAF0F6F3F3EC
E6DADAE9EDF6F0F4E7FAD5F2F6FCF7F1EAE8EBEFEEF2F6FF
F1FBFCF6E2F8EDDBE2E7F4DAF7F4F6EDEDEFF8F8EAEFF9F7
F5F0F5F2F2F3F3F3EEFFF2EBEEFBEBEEF2FFF3FBF9FBFFFF
F3FFF3F2F2FFF3F3FFF3F3EEF3EEF3F3EEF3F2FBFBF0F3F7
FDF6F7F3EDF7FBF0FFF7FBF7F6FFF2FFFBFBFFFFF3F3EEF8
F3EAEEE8E9F5CE987D88FAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE2CFBAD2B3D9FCF3FCF5F7
FFECEEF2E0F0FBF6EDE5F3F3F6EECAC5FFDBE4EEF7FFF7EE
ECDFD9E0F6FCFAFEE1E5E2F1F6FAFAEFF6F6F2F2F2F5F3F5
F0FAF5E4CFE5F5F2F6EEE1E7E4F5F2F0FBFEFEF9F6F6EEEB
F5FBF9FFFFFBF3FFF3F3F2F3FBEFFFEFF3EBEFEEEEEEEBEF
EEF2EFEEF3F3F3EEF3F3F3F3F3FFF2F2FFFFF2FFF7FFF0EF
F6FFF6F6EDF7F9EDFFF3F6F6F7FBF0F3FBFBFFF3F3F0F0F0
EAEFE4FBE5EE888D9DD3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEBD3C0D0CBD3DEF1FAF5FC
FAECEFE7F0FAF9EDFAEED9D9F0F0FDE6CFC4F0DBDBEEF0F6
DAC6C0D3F6F2EEF7E5CEE2E7F5EFEBEEF8FFF3F0F6EBF2ED
DEF5EDE4E6F6E6F1E9E7EDF9EFE5E9FFEAE9FFEDEFF8F5F9
F9FBFFFBFBFBF9EEF2FBFBFBEBEEFBFBF3FBF2F3F3F3EEEF
E6F0F7F2F2EAEEF3FFF3E5F4FBFBF6F6F2F2FBF2F7F9F5FF
EEEDEDEDF6F0FBF2F0E8F6F6FBF3F0F2FFF3EDE3EAF6F8F5
DAE9E8EBF39E358AD3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEAD6B4B5E4D9E5F3F6F5
F6EDF3ECD8E6E8EFF6F1F6C2DEE7F0FFF0EEE4D3FADFE0E2
F3EDE8E7E7E7FFF5EFBFEBECF6F6FDFDF1EDE9F0F6F2F3F3
D3F5E6EEE6D0D9FAEEFDF7E9E5EBF6F8EAF9EDF0FBF3F6FF
F9F9FFF7F5F9FFFFFBFFFFFBF3EFF2F2FFF3F3EEF2FFF7F6
F3E6EFEDEFF3F2E6F3F3E6F9F4F9F7F5F9F5F2F9F5F6EEE6
ECFFFFF7FFF0F9F3F2FBF2FFF3FFFBFFF2EAEEF0FFF8E4E8
F5DFFBF7B845A1EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD8DDA9AEC6D0ECFFED
F7F3FFEDE2F5F5F6F5EAE8EFE4E4ECF3F6FFFFE8D2CED0E3
ECC6BCCED5E6FAF7FEC2DFEDF6FDF6F6F3EDEDEDEDFFF6ED
D2F3F7E0DFD7F5E1EFE9F6EEF7E8F9FAFDE8F6F9F9FFFBFB
F9FFF5FFF9F7F5F7FFF8F8FBF9FFF0F0FBFFFFEDE5F2F2ED
F5FDF7F6FCF3FFF2F2F9F9F5F2F9F1F9F3F9F2FBF7FDF5F7
F6F0FFF7FFF0FBF7F2FFFFF3FFEDF3F2EEF0FFF7F8EAFBF8
E5F3EEB29362DEF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBE1EEB7B1B2F4F6F6
F3F7F3FCFCEAFCF6F7F5F6F1F5E6E0ECEEF3F6FFFFF6FFEE
F1F0F0F5EBF2F5F8FACCEEF4F1F1F8F6EDF5F7F7F0F2F6F6
DEF7F8EAFCFAE7D9EEF0EDF6EEFDE4EFF6F6EFFBFBF9F5FB
FFF7FDF9F6FDFFF9F7F9FFF7F9F9EFF9F2F9F9F7FBF2EBE8
EFF6F7F7EFFFF7FFF0FBF9EFFFF1F1F9F6F6EFFFF5FFF9F9
FDF4F7FBF3F3F0F7F9FFFFFFEDFFF0E8F0FFF9F5E4FBE4E8
F3FBD59173ABFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBE5E0B28EE8F3F5
FCF7F7EEFAFAEBF5F2F6FAEDE5D5E6F9F3EAE4EEF0F0F3F0
EEE2E7F7E9F6ECEAE9D5EEFBFBEBF5FAF2EAFEF6F0F7F6FC
EFF2F9F8F5EEDED6F0EAF6F5F3E4F7F4EEF9F0EFFFF9F6EF
F7F9F7F7FDFDF8F4F0F9F9F7F5FFF8F3F0F7FFFBF2F9E6F7
E6F9F9F0F8F3F7F7F2F7FBEFFDF6F0F4F6FFF0EFF9F9F4F4
F3F6F3F3F3F0F0F2FBFFFFFBF0FFF3F9FFF7F5E4F2E8EEE5
E6E0995BACF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAE8E8DC74E7DDFA
EEECF7EEFAF3E4F1F6F6FAF1EEECF6E7F3FAF9E2C7DBFFE9
E8FFEBD7E4F2F4EDF8E0F2FBFBF2E8F5F2EAFDFDE3E7F3F0
F6EAFFFDF5EBE5DEF0FBF1F9F9EEEFFFEFE4EFEFF5F7F4FF
F6FFF7F7F6F9F4FFF6EFFFFFFBFBF7F4FFF0F7FFF9F7F5EA
E7E8E6F9F6EFF0F5F8EAF9F2FDFCF3FFF6F3F6F6ECF3FFFF
F3F3EDFBF2F0F2FFFFFFFBF3F7F9F6F9F9EAD7F2E7D6E6F9
E0C15D9CF1F1EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEED7F582CFD0ED
F6EBF3F7F7ECF3E5F3FAEEF0F0E6D7E4FFECE2DCFBE2D5E2
E2DED8E3DDF0F3F4F7E3EEF3FFF9F7EDF6EAFDFDE3EBFAE5
F3DFF1FEF2E3F4F4E9EEF0FBF5EEDEF0F9F4E1F1F6F7F9F6
FFF6FFFFF6F9F4FFF7E8EFF5F3F7F7F6F4F9EFEAEEF9FDE9
F7D4F3F4F0F6EFFDF0F3F7F9F6F4F6FFF6F3F6FFF7F7F3F3
F3F3F0FFF0F7F2FFFFF3E8EEF4F6FDF6F1E6EBEBF4E4D5D9
BC757DFFF1F1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBD793DED3E7
EAFFF5FAFFEEEEF0E8FDEDFDE1F0F5F0EEF6FFF0E2DEF9F0
F6EEE8F3D7F3F6F6F4E7F3F5F3EFF9EEFDEAFDFDEFEFF6F1
E8E5F0E8F3EFF4D8E4F9F5F3FFF8F1FFF6F6F4F5FBFBF5F9
F3F6F6F6F6F6F9FFF7F7F3FDF6FDF9F9EEFFFFFFF9F6FDFD
E7E9F0EEFFEEF9F0F9FFF6F6F3FFFFFFF7F7FFFFF7F4F6F7
F0F0F2FFF6F3FBFFF3EAF6FDFDF6F3EADEF5F2F3E6F2F0A9
8978DBEBF7F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAE482CAD2D6
E5E5FAF5F3F7ECD8F5EEFDEAE8F6EEF5EDE0ECFFF2F3EBFC
F0E1CEC4D4E8F6E4F4E7EEEFE7E6EEE1E5F1FBFFF8F7FDF5
F7F0DAFEECEEE4E9F5E9EFF6EEF0F4EFF4F6F6F9F9F8F8F7
F6F6F6F6F6F6FFFFFFF6FFF3F0F9F9F7F6EEF3F7FFF9F4F3
F0F7F4FFEEFFEAF9F3F9F4F6FFF0F3F7F3F3F7F3F2F9F9FB
FBFBFFFBF6EAE0E0E8F6F6F3F6F3DAF0EFE3FBF0D8AFA065
6AD2EBFFF0FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFACA3D0D7
E0DEE5F7EDF6EAF6ECF9EEEBF0FAFAFFFFFAEEDDEEFAF1E5
ECF2FFEEFDF5E2E4F4E4EBEBF2F2FFF2DAF2F9F5F2F3F9F3
F3F2FAD3F9DFEDF0E8F2F0E8EEE8E6F9F7F3F3FFF7F9F9F7
F6F6FFFFFFFFF6F3F6F3F3FFF6F3F4F7F9F7ECF7FFFFFFF6
F6FFFFF6F6F0EEE7E9FFFFF3EEF0FBF7F9FBF3F2FFFFFFFF
FFFFF3E6E8F6F4F3F9F6F6F6E7F6ECF9FFEFEDD6D6CCE76A
D8F1F1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBADAEDA
EBE4E4EDECFCF6F7F0E0FAE4EDF6F2F3FFFAEEE4F5F3E3EB
E8E6EAE4EFEFE5E4F7E4F2EFF5F2F2F2E2FEFFF0FBF0F4F6
F0ECDBC7F9E5EED3ECF0F4FDF7E7EEF7F5F4F6F3EEF0F9F0
FFF6FFFFFFF6FFF3FFF6F3FFF6F3F4F9F9F9F6F0F3F3F3F3
FFF6F6FFF6F6E5F3EBE7FFF3FBF0F3F9FBFFF9F9FFFFFFFF
F3E6E2EFF7F7F7EBEEFFEEF4EFF0EFF5F2EAD3D5DCE4F459
F9F0F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDB9FB9
E7E2E7E8F6EDFFF3E1FCE4EDF5FDDFE0F8F5F3F2F7DFD5E8
EBDDDCE5EDE4EEE0F7EEF3F9F9F6F0FBEEEFF5F5EEFBFBF9
F5F5CED5E8EEE1CCF6F0F7EEF0FFF4F0F9F6F6F6F6F0F4F6
F6F3FFFFFFF6F6FFF3F6FFF6F6F6FFF7EEE1EBEAF6FFF3F0
EAF6F6FFF9ECF4E0E0FCE9F7F2FBFBFFFFFFFBFBFBF2EDE6
E8F0F0F6F9F7F7F3F4F6F7EEE3E3F5FBDFD6E8E8DFE9BB7C
F0EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAC2A1
CFDBF8E7DAEBF7F7ECF2EEF3F3F0DCFCE7F7FBF7F6E7E7F3
FCFCE1F3F8DFF7E7F4EFF3FBFBF5F5F7F0F2F0FEE9FFF8F8
FBFBE5F0D9EEEAE2F4FFF0F4FFEEF9FFF6FFF6FFFFF0E8FF
FFF6F6F3EDF3FFF6FFFFF6F3FFF3FFF3EDF6DFE3D5F0FFF3
F0F6FFFFF9F3F5EEFFE9FAE3DEE0E6EDF2F2E6E6E8ECEEEA
F3F0F9EFF0F4F9FDF7E8E4F0F3EEFFE3E8F3F2DAECE698B5
F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBAE
9CB1E0EAD9F7EDF7F7EDFAE4F3F1F9D7DDFFFAF7F9FAFDFA
F1E6F1F3EFD2F7F0E4EBF4F5F4F7F5F3FDF2F0F0F4FBF7F7
F7F7F7E8DCF6ECFBF7F6FDF4F0F6F6FFF6FFF6F6F3E8F0F6
FFFFF3F3EDF3FFF6F6F6F6F6F6F3FFF4E9ECECE6D2E2F6FF
FFF6F6FFFFFFF9FFECE6F6F9F9F3E9E6E3E8F0EFEFF9F9F4
FCF9EEFDF3EAF7F9EAF0F3E8F0EFE3F0F3EEDBDFF5B8A1D6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEB
B896C7D6E9DCF3F3F7FAEDF6FAFDF0E9FCDCECE1E2E7EFE9
E1DBEEE8EDCAFFF7E2E7F4F5F4F6F6FDF5FDF2FBFBFBF9FF
F9F9F9F5F1F6F4EEEFFDF4EFF9F6F3FFF3F6F6F6F6FFF0EA
F6FFF6F0EDF3FFFFFFF6F6FFF3F6F6F9F1DAEDFBE5B6D2EE
F6F6F6FFF6F3F6F9F3F7F7F7FAFFFAFAF8F4F9FFF9EFE1E4
F8EFF6F4F9DBDFE3FBE8E5F3D7D6EFFFE8D7E2FBE698B4EB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F1AE8D9CD2D8DDF3F6FCFAF5F5EBEDFCE9D5E0E8E8F3EEF1
F4F1E5E3F1D9F3FFEBE5F5F3EEEEF9F9F7F9F6ECFFFBF9F7
FDFCFDFDF9EEF9E7F6F9F3F4FDF6F3FFF6F3F6F6FFF6F0FF
EAF6F9E3E6FFEDF3FFF6F3F6F4EEF6F9F9DDD9E7DBC8EEB7
A8C9F4EBDEE3F4FFF6F0F3EAEAF3F3EFF3FCF3F6F9EFE1E1
E8FBD9C4CBEDEAE8F9D8C7DEF4E4FFDEDDE5F6B66C8FDBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFACC8EADF1E1E7F1EEF7F9EFEBF5F9F7EAECE8F0F3E4D8
DED7DCE3F1D9F6F0F6EEEEFFF2F9F4F5FDFCF9F4F4F9F7FC
FDFFFDFDF7F5E9E8F9F7F3F6F6F6F6F3F6F7F7F6FFFFF6E6
EDF6F0FAE9F3F3F3EDF0F7F3F9F1E8F3F0FCDDB6F9CAD8E3
DEDDBFDBF2E5E1D9DBE3F4F6FFF6FFFFF9EFEAEFEFF6E8E0
DDDFE3F8DBD3F9E4DFFFECEFF4F0EEE3EEE9BA6AC0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC969FDF0DCF0F1F2FBFFF5F6E9EBEDD8E2F0F3EADD
D7D7DEE2E4E0F1DEFDF7F1F3EEF2FBF4F3F6F6FDF1FFF5F7
FCFDF6F8FFF0E0EEF0F7F6F6F3FFECEEF6ECECF3FFFFF3E8
F3FFF3F3E6FFF3EDF3FBF0F6F3DEF0E1F0E4DCCFD8E8F3CC
F9D5D2E0F3FAFAF3F3E7DEEAE6EAF3F9FFF9F7F3E1DDEBF8
F0F5EFE3F2D3E1F0FBEFF4E9F0F3E6DAF0D57DB6F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFA76A1EFF1E7E9E6EDFCF8F6F3F6EDE8F1F1F1F1EE
EEF3EEE3E1F0ECE8F6FFEFFBFBEAF2FBE6FFF4F6F0F4F9F9
F9FCF9F9FFF9F4F6EEFFF9F3F6F6ECFBEAFFFFFFF6FFF6FF
F6FFF3F9F4F6F3F3F3F3F3EDF3E7D0E6DEFFF1F1DDD0E5F3
C5C2CFF3F8EDF4F6EAEBF4F8F0F3F5F8E8E0E1E4EEF8F5E5
DDF0F9F2EEF6F7F4F4E0DFEEDED8E8EBD5799DFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFD58596F8F5F1F6E8EEEAEDF1F3F7EDF1FDFCF7E7
E2E8F3E7FCEEFBEDF8F6EDF1F5FBEAFFEBF0F9FDF6F3FBFF
EEF8FFF6F6F6F4EEF3F9FFEEFFF3F6EAF3F6FFF6F6F6FFF6
F6FFF6F6FFF3F3F3FFF3EDEDF3F3E6B6DFDDF0EDE6F4CECB
F4F2D7C0B5B5CAD1D3DCDBD4C9C8CAC7DAF1F8EAE1DBE7F3
E7E6F2FBFFF7F3F3E3E6FBFDEAF5FFCF7094F5FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7DA7AA4EAF7EAEDFFFFF3EEEDF0FCF1FAF3F3F6
F3E8FFE2E9E8E5EDF8F4F0FCF3FAE9EFF9E7F0F6F6F9F8FB
EEFDF6F0F6F6EEEAF6F6F9EEFFF3F6FFF6FFF6F6FFF3FFFF
FFFFF6F6FFF6F6FFFFFFFFFFF6EAEDF0C4CDF5EBEBE1ECED
C1B3C6D5D5E3F6E4EBE3ECF9F3EEF3E8DDE0E2FFE4D5C2CF
E2EBEBE2E2EBF2EBF1EFF3FDEFF4F98290F5F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCD8D97E3EEEEF3F3F1F6F7F5EEF5EEEEF1F0
F2EDE1FFF1F1EEE4E3F6F6FCFAFAFAEDF2EEE0F6F3FFF3F5
E7ECF6F6FDFDF9EFFFF3F9EFF0F6F6F6F6F3F3F3FFF3FFFF
FFFFF6F6FFFFF6F6F3F3FFFFEEF0F3F3FFC8C2D9F1FAEFE1
D2DBF0F2E6C8ADA4AFB5C5D8E2E6F3F7E9DED8DEEFEDEDF5
FFFFFFFAFAFAF7EEEBF3ECEADAE3E450DBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFDB905973C6F0E6E9F6F7F5F6E3E8EEF6F6
FFFFE8FFF1F6E4E8DCE3F7F6F3FDF3EEF1F9E8CCD6F5F7F0
FBEAF1F3F9FFF9EBECF6F0F7F4F3F6FFF6EAF3F6F6F4F0FF
FFF6F6F3FFFFFFF6E8E8F6F6F4F9FFF9E6E0F0DDC8CDE1FB
FAF5ECF3EFCEBFBCB5B8CADADDD3DCEBEEF5FAF5F6F2F0E9
F0E9E2DFDFE3F3F3DAC3CEECD5A35F7FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF19C5DE9FAF4EEDAE5FCF6FCF3F7EE
E8F0F3FFFFE8F0E8F6CDFDF7FFF3F7F3F7F9FBEFF1CBE1FB
E3E9EDF0F4F5EFFBEFEEEEF4F9FFF3FFF3F4EEF6F6F0F4F6
FFF3F4F4F4F4FFFFFFF4EBF6F9F3E8F1EAE6F0EDD8E8E1D4
E1FBE3E8DAC4C4C6BCB8C7C4BBBEC0BCBBD6EFE4D9DAEFFA
F6F6FBFBEFE4E3E3D9FFF6E68782CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF61BDE5E6EEE8EDF3F9F9ECECE9
E9F6F6FFEFE8DCD3C6B8E2FFFFF7FFF3F7F8FFFDE9F1D8E2
E6F4EFE6E7EAF8F6F1DAEEEAF7F9F0F6F6F0F6E7F6F3F9F0
F6F3EFF0F4F4F4F9F3F4E7DEFFF4F1ECDDF4F0DDE0F3EDEE
DDC8D2EAC0D1EFF9F4FFF4F8F0F6F6E4DDE8F5F5F2E5EFF5
F1F4E9E5D4E8EFF6ECF0E68E7FDAF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAB79C4DCDEFFEEF6FCF6F3FAFC
E7E8E9FFE8F8EAF6EABCE5E3F7FFF7F3F7F9FBFFFEE9E8F9
F0FAFAFAF0E3E5F0F6E2C6F5EFEFF9F6F3F6F0F6EFF4EFF0
F0F7DFF3E4E5EAFFEDF6EAECCDF0F6DCD9C8D6E7F0FAF3E8
FFFAEACBD2ECEADADDEADBD6E6EAF0F8FEFFE3DDEDFAEBFF
E9E1ECEFF0F9ECF2FFCC847FDBFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAE7AA0D2E7E4F7F3F7FFFCF9
EDFBF6E9E8F6EBE7EFD5DBDBDBF7FFF7F6F8FEFBFEFDF9EF
F0F6F6FCF5F0DAE9EBCCD6C0E8F6EAEEF6F0E4EBF0E8F0F3
F0D9EDE8D1F3E2E7F0DBD1EEF6DAF8E7DDE8C6C9D2D5DEE3
E1E8EEEBF1E7EAF3EADBF4F9FAF8FAF4EDE7FFEBF4F0DAD9
E7F3F5EFDCD4EBFEBD6A90DAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD3878FCEE2D5F7F3E6ECFC
F5F6F6EAE8FBFDF8FFF0DCE4D4D2ECFDF6F9FBFEFBFFFDF4
FCE9FFF0F3FDE2F3E9EEC6BFD3EEFBEAF9E7E8F1F1F3EEEC
EDEDD5D1D4E2D5DFDDD7DFB4D8CEB2D0E1B7C2F0EEE0DCEB
E9E0DAE2DFD4D8EDF0FDEBF4F4F3EBECF4FDF1D7D0DFF6FB
F3EEF1F2DDF2F1FA5BACF5F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFD99496CCC8E5ECEBFFF1
F5FBE9F7EDEDFFEDE7F0EADFEDEED7E2E6E7F1FEFBF9F5FB
EDEAE7EBF6F6ECE7EAD5E0DAC9EEF4F5E1F4E0E4FAF3EEEE
EAEAEDDCE8D0D7FDF0E7C7EBEBC8E2B1ABCBECD9CAD2E5FC
FDF3F0FFFFF2F2F6F2FFF6F4F4F2F6FFF7EBE6EFFFEDF8FC
FAE5EEEFE8D0E2BE4FFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBA19195DDE3E8EDF6
F3E8DFFFF2E4EAEDECECF0C8CBEBEEE4ECECDACEDDF6F1F6
EAF9F9EEE3F6F5EFF9E5CFEFE8B7DCF8EFD1EFEFDEF5EEEA
FCF1E8EBD6CAD8DCF1EDE1E8F0C8D4D7D7E7BEC5DEF0FCF6
F7F0FFF2F3E6E6E3E7F1F3ECE7EDF5F1EDF9EEDDE4F8FFF5
EEDBF6DBE2E58653A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEC9737597C1CDD7
D7DBD3EFF6F3E2D1D7DCDFE6F7D8D5DFE8E6E7DBC0AAB1C8
C7CBD6F1E1EEF5EFE7ECDBC7E7EFCBB9D0E0B9AFF3D5C2E5
E5EDF1EAE2D8EFE3D3E8E6D8D8D9F2DCEEE3F6E7FDFBFBF5
FDEDF2EDF7F7F3F3F1F1F6EBDDE9F5F3F1FFE9E0DAE0DCE4
F4DFD6B73D2369C4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBC19EA0C7DE
DFF1EAF0EEECECE8E8DFFAECF6E6F2E7EADED9F3FDF8EFEB
DDCED0D5DEEFF9F9EEE9FFEFD1E2F3F6D8CEF6F0B1CBCAD0
E2F3E9E9EEE8DFD8FDF1F7E7FBEFE4EFFBE4E7F9F0EEE8E5
F3F3EEF7FEF7FAF7F8F8FAF3E9F0EDE4E2E8F4E6DCE7FDF0
E9E37A60ABFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEED3B190AF
B5C5E3F3F5EEF7F2E9DFF8F3F2F7E5DEE5F3FCF5F4EEF9F3
FDEFF9DCC9C4D4EEFBEDECE8EEDFE4F1E4E7D7E9E7CAD0C6
D9F2F5FDEFE8F2E6E8F6DEEDF8F7F7FAF2ECF3FCF1EAE6E5
EEEEE8E5E9ECF1F8F1F9FBF8F5F2E8F6FBFCEFFAE1DCE3DC
F0716FC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE4BAA7
B5CDD9F5F6FDF3F6F6DFFAFAF3F2E5DEE5F5F6F7EFEFEBF5
FFEEF3F8F8FFEDD7DBECECFFDEE8F5EDFDE2ECEFE7E5C6D5
F2EFF5FBF0EEE1D5CBBFE3DBDBFFFFF6F6F6E5E6EBEFF1F5
F5F4F8FDFFF3ECE7E3F0EFE9EEEDF1FCFCE8F6E8E5E1EDD1
6656D8F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9
AC8FA4D5E3FDF6F4F6EAD4E8EDEEF8F8EEF3FAFFF4EFF4FF
F8FAFAF5F6F6FCEACDD5E2DFE4DFE4F7E6D7E8E5EDE6D2E5
E4E7E7EEE4ECFAF2E9E3C9BBF1E6F3F7F7F5F5F6FDF6F1F1
EEEAEBEBE9EAFAF4FBF6F1F8F9FAE8ECF4F6D2D8E0E9A75D
6ED5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EEBB90AABEDFF9F9F6E8E8E8EDECFAF2E5E2F8F8EDEDF8FA
F6FAF3EBF6F6EDF0FCEEEAF8DED5DEFFFAF2D0D4F3DEEDDC
D8E9F1F2FFECE0DBE5EAF1E9DEE8ECDAE0EAF3F0E5F0F7F7
EDEBEEF9ECF0F3EAE7E5EFE5E6EBEAE4EFCBE0E3A7675294
EEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC98F7785B4D7EEEEF9E5EEE8E7EDE2E4F7F6E1E5EBE0
F3FAF1EEFFEEF3F6EEF0E7EFEBE6F2F9FAECF7EAD2E4F8F5
E8EBD2C4D0DEDFDBDADAD7DDE0E6FDEFF1FFEBEFF3EDF8EF
F8F2FDE6EAEADADFD9DEEFF8FFF4E6D0E2EE9E67587ED3F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F5D59A68473F75C4F6E6E0DFCDCEDCEDD9B9CFF7F0
ECE0EAEBE1E4F3F7FCE4E9EFF3EDFFF7F3F7F7F3EBFCEAE1
D2E3F3EBEDF6F4E6D9E1E3E3F0F5EEE6DCDFEFE5E4DCC9D4
D4CDCAD2D5DADFEEEAF8D7C9BEC3EEC8752C4395D9F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEE95577191C2EEF3F7F6E0D9D7F0EBEB
F7FBF6F6EEE7E2F3F6F3FCF7EDF0FFFFFFF7EDE9DFE1FCE2
EDFFF7EDF0EEF3FDEFFDF5F2FEF5F7FFF7F7F6EFE7E8EFE1
DBDBE3F3FCF1F1E5F2DACAEFDBB67D5F7CCAF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFD69A7B71858FA7CBD6EBD7E7DEDE
C8BFD3E7EAF3E0D8EBF0EAE5FAF7E5E4FCF7EFFBFBF7EDE2
E6EDF2EDEDF3F0EADBE6FAEFEEF7F5EAE6E3E1E4EDF2F4F1
DACCC6D2DEC2AFBED4EEECD7A0607BCBF5F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEBBA94867266666886ADA8AC
B5C0BFD7D8D9E8E7D6DDE4EEF6F3D9E0FCFCEDE1DFDFE6EC
F8F6F3F6F3EDF3F8EDEEF8FFFAF7F4F1F7F9EFE4E1DDD7D9
E9FFF3F6DDE2FFFFECD97F5A68C3F7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE4E4E8D9D0E4E6
E4EAC2D8EAE7C9B9B7D7EEEAE2DBE5EBFFF2EAFBF9FAF6D9
D5E2E1F0F3F3F3EDFCF3F9FCFBFCFAEEEBF6FEFAF7F7F7FE
FCF1F3EEF1E5D2A8988B70D9F5F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAEDE6
F1F1E0D6DAEDE5E0E7B1A5C4EEF5E9DEDAECE9EDEDE5E6EF
F4F6FCEDF0EBFDF2E2E8F8F8F3F9FAFFF3F3FAFAFAF3F9EE
F2EDE2EDD3A0807482A0D2F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F1ECF0E7D5DBE2E8E1EDD5BDB5B5BDCFE5F6E6CFD8F2E4F0
F5FCFDEDF0EFE9EAEAFBE7F2FFF8F9FBF6F9FAEAEAE6EDF9
EDDEAA75687EB3D9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAF0F1EEE8EBE8EDFAF1D9C8C2B99E7B6F849EA0A4A2AA
BEB8BED8DDD8E3EAE5FAE5FAF3EFD8CDC6C1AA74573B2731
31385E9BD8FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFEEE4D3C4BC9D
8F9DA19795A4AFA29B887A766F6D6F6F757E8FB7CCDBEDED
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FAEDE4E2D8BBB3BBC8CCCAD3E6E8EEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -50 0 ]
[.5 1.0125 50 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(By) show
81.000000 12.812500 moveto
(inner) show
117.000000 12.812500 moveto
(product) show
159.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F3FBF3FFFF
FFFBFBFBFFFFFFFFF7FFFFF7FFF7FFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFF7FFFFFFFFEFF3F3FFFFFFFFF7F3F3FFFFF3
F7FFF7F2FBF3F3FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7F3F3FFF7F7FBFFFBFBFBFFFBFFFFFBFFFFF3F7F7FFA3EB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFAFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9ECFAF7FFFF
FFFBFCFCFFFFFFFAFAFFFFFAF7FFFAFFFFFAF7F7FAFFFFFA
FAFAFAFAFAFAFAFCF3F4FFEFF7F7FFFFFFFFF7F6F6FFF6F6
F7FFF9F9F6EEF6F3F6FFFAFAFFFFFAFAFFFFFFFAFAFAF7FF
FAF7FDF7FAF9FAFDFDFAF9FBFDFDFDFDFBFDF6F6F9DFA7F1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFAFAFFFAFAFAFAFAFAFFFAFA
FAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFAFAFFFAFAFAFAFAFAFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DFF6FAFFFF
FFFCFCFCFCFCFCF7FAFAFFFAF7FAF7FFFFFAF7FAFAFAFFF7
F7FAFAFAFFFAFFFCF3F4F4F4FFFFFAF7F7F0EEF6F6F3F6FF
F9F9FFFFF5F0FFFFFFFFFAFAFFFFF7F7FFFFFFFAFAFAFAF7
FFFAFAFDFBFFFFFFFDFBFBFDFDFDFFFBFDFBF6F5F3BAC5FF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFAFAFFFAFA
FAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFAFAFAFAFFFFFAFAFFFFFFFFFFFFFFFF
FAFAFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DFF6FAFFFC
FCFFFBFCFFFFF6FAFAFAFAFAFFFAFAFFFAFAFAFAFAFFF7FF
FFFAFAF7FAFCF3EFEFEFF4FFFAF7F1F6F6F6FFF6F6F9F7F4
F4F6FBFBF9FAFFFFFAFAFAF7FAFFFAFAFFFFFFFFFFF7FDFF
FAF7FFFDFDFDFFFFFDFDFAFAFFFDFBFFFDF9FAF3F1B2E0FF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFAFAFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFAFAFFFFFAFAFAFAFFFAFAFAF7FA
FAFAFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DFF3FFFFFC
FFFCFCFCFBFBF7FFFFFFF7FFFFF7FFFFFAFFFAFAFAFAFAFA
F6FCFFFFF4F1F7FFFFFFFAF7FAF0F9FFF6F9F9FFF6FCF9FC
F9F5F7F7F7FAF7F7F5F5F7FAFAFFFFFFFFFFFAFAFFF7F7FA
FFFFF9F9F7FDFBFBFFFFFBFBFDFDFDFDFFFCFAF3DEB3F4FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFA
FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFF
FFFFFAFAFAFAFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFAF7FA
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DFF3FFFFFF
FCFCFCFCFCFCFAF7F7F7FAFFFFFAFAFAF7FAFFF7FAF7FAFC
FFFCF4EFF4FFFFFAF7F7FAFFFFF0F3EFF9F7F7F6F6F6F6F9
FAFFFFFFFFFFF7F7F3F6FAF9F5FAFAFAFAF5F9F7FFFFFFF7
F9F7F5F9F7FFFDFBFFFDFFFDFDFDFFFDFBFDF6EBC9C5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEE6F6FAFFFF
FFFFFBFFFFFFFAFAFFFFFFFFFAFAFAFAFFFFFFFAFAFFFCFF
F7EFFCF3F7FFFFFAF7F9F9F9F6EFF2F7FFFFFCF6FFFDFCFA
F7F5F7FFFFFFFFFFF7F5F9FDFBF9F6F5F5FFFDF9F7FAF7FD
FAF6F9FFFBFBFDFFFBFFFDFDFFFFFDFFFDFFFBE9B4E1FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFFFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFF
FFFAFFFAFFFAFAFFFAFAFAFAFAFAFFFF
FFFAFAFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFAFAFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DFFDF5FFFC
FCFCFFFCFFFFF7F7FFFFFAFAF7FAFAFFFFFFFFFFFFFFF3F3
EFF7FAEFF7FFF4F2F5FBFBFDFAF9F9F6F6F6F0FAFAF5F9FF
FFF1EDF3F3F5F5F7FAF5FAFDFDFFFBFAFAFFF9F7F5F5FDF7
F7F6FFFDFBFBFBFBFCFFFBFAFDFBFDFDFDFFFCD9B0FAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFAFAFFFAFAFFFAFAFAFAFFFAFAFAFAFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFAFAFFFFFFFFFFFF
FFFAFAFFFFFFFAFAFAFFFAFFFFFFFAFAFFFFFFFAFAFFFFFF
FFFAFAFFFAFFFFFAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEE2FFF3FFFC
FCFCFCFBFFFCF6FAFFFFFAFAF7FAF6FCFFFFFFF4F4F4EEEC
F1F7EDF5F4F1F0F6F5EFEAF5F6EEEEE7EFEFF6F6F6FAF7FF
FFFFFCE6F1F4F1F6FDF6FDFDFFFDFBFDFDFDF7FDFDFAFDF7
F7F9FDFDF9F9F9F5F6FBFDFDFFFBF9FDFFFBEEBCCBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFAFAFAFAFFFAFAFFFAFFFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F1F6F7FFFF
FFFFFCFCFFFCFCFAFAFFFFFFFAFAFBFBFFFCF3FFFFFFEEF5
F4FCF6FAF3FDFAF7F7EFEEFFF6F5F4F0F5F6FAFAFAF5F5F1
FAFAF1FDEEF1FCFFEEEFFDFDFFFFFFFFFFFFFDFAFAFFFBF6
FFF5F7F9FDFAF9F3FAFFFDFFFFFBFBFFFFFDDCB4F1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FAFAFAFAFFFFFFFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFAFA
FFFAFAFAFAFFFAFAFFFFFAFAFFFFFFFF
F7FAFAFAFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F1F5FFFFFF
FCFCFCFBFCFAF7FFFAFCFCFFFFFFFCF7F4F3FCFFFFF7F6F3
F2F9FCFFF6F7F7F5F6F6F1F1F1F6F5F6F0F7EFF9F6F3F3EE
F1F1F5F5F7F0FFFCE6FCF2F2F1FFFFFFFFFFFDFDFDFDF7F6
F9F7F7FDFAFBFFFDFDFDFFFDFDFBFBFFFFFDD3B8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFAFAFFFFFFFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFAFA
FFFAFAFAFAFFFAFAFFFFFAFAFAFAFFFF
F7FAFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFAFAFFFAFAFAFA
FFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6EFF3FFFFFF
FBFCFCFFFBFAF7FAFFFCFCFFFCFCFCF1EFF4F4EFF1EEEBEF
F2F1F4F4F3FCFCFBF6F9FAF0F5FAF6F9F6F6FDEFF6F3F6FC
FFF6F0EFF7EFFFF1FBF3EDECF1E9F1FFFFFFFFFFFFFFF7FD
F9FBFDFAF9FDFBFDFDFFFDFAFDFDFDFFFFFDC2C5FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFAFAFFFFFAFFFAFFFFFFFFFFFFFFFAFAFFFAFAFAFA
FFFAFAFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD9EFF6FAFFFF
FBFCFCFCFCFCFCFCFCFFFFFFFCFFFFF3F4F4EFF4F3EFF7FA
F3F3F7FFFBECEEF1F4F3F7F6FFF6F9F9F9F9FBF9F0F6F6FC
F0F7EEF3FFFFF0EEFAFCFDF1E9EEF6E9F1FDFDFFFFFFFDF4
F7FFFBF9FBFFFFFBFAF6FFFDFFFFFFF7F7F7B2DEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4F4F6FAFFFF
FCFCFFFBFFFCFFFFFFFCFCFCF4F6FBF4EFF4F4F4F5FAF1F1
FCF7FCF6F4FCFCFFF6F6EFF9F6F9F6F9F6F3F2F6F9FCF3F3
F9F6F6F6F3F6FFF9F0F6FFFFFCF3E9EEF7EEFDFFF7F7FDFD
F7F6F9F9F6FAFDFDFAF6FDFDFDFFFFF7F7ECB5EBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFA
FAFAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D3F7F3FFFCFC
FCFCFCFCFFFFFCFFF4F3FBFCF7F3FCEFFFFFF4FFEEECFCFB
F6F4FCFCFFFCFBFBF7EEFFF6FCFBF5FBFDFBFAF6F2F3F3F3
FDF6F9FFFAF1F3F3F0F0F3F6F3F9FFF3EAFBEEFFF7FFF3F7
F7F6FBFBF7F9FDFDFFFDFDFFFDFFFFFFFFDDB7F1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D6F7F3FFFCFC
FCFCFBFCFCFCFBFCF3EFFCFCF6F4FFEFFFFFEEF2F2F2FAF6
F6FAFAFAFFFFFCFCF3EFF3F7F1F3F3FFFFFBF9F5F5EFF2F3
F1F9F9F6F7F7FDF9FDF3EDF9F9FCF5F3F3F5EEEEE9F5F7F7
FFFFFFFDFFFDF9FBFFFFFAFAFBFDFFFFF7CEBAF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFD5FDF5F7F7FF
FFFCFCFBFCFFFCF7FCF4F4F1FCFFF4EFF4EFF2FAFAFAFAFA
F7FAFAF7FAFAFCFCFCFCFCFCF7F4F5F9F9FCF9FCF9F6F9FB
FAF6F5F6F5F5FDF5F5F3FDF0F6FBF3F3FFF3FBECFAF6EEF3
F7FFF7FAFFFFFDFDFFFFFDFDFBFFFDF7F1BFD5F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFD5FBF7F7F7FC
FCFCFBFFFBFCF3FCFFF4EFF4F7F7F7F7F7FCFAF7FAFAF7FA
F7FFFFFAFAF7FFFCFCFFFFFCF4F3F7FDFCF9FBFFF9FDFBF9
FFFAF9F9F6F4FDF9FDFBF6FDF3F0FCF6F3FBFDF3E9EEF6F6
F3FFF7FAFFFAFAFAFAFFFDFDFDF6F6F7F0B7EBFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAF7FAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDD7F6FAFFFFFC
FCFCFCFCF3EFFFF4EFF1F7F7FFFFFFFCFCFCFAFAFAFAFFF7
F7FFFFFFFAFAFFFCF6FAFAFAF9F0F0FAFCF7F5FDFAF4F9FB
FBFDF3F5FDFBFBF9FFFFF5FDFDF9EEF0F0FCF9F3F4F6EDFA
EDF1FFFDFAFFFFFDF9FFFAF4FBF7FFF3DBB7F1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFAF7FAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFAFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFAFAFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEE2F7F7FFFFFC
FCFBFBFCF1F4FFEFFCF7FCFFFFFFFCFFFAF7F7FAFFFFFAFF
FAFFFAFAF7FFFAF7FAFAFAFAFFFAF3F1F3FFFFF6F9F5FCF9
FFF6F6FDF9FBFBF7F5F5FBFDFFFBF2FCFCF6F5F1F4F7EFF3
F7EBFFF7FDFDF7F5FBFDF3F5FDFFF3F7D6BCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFA
FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFAFAFAFAFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F1F6F7FFFFFC
FCF6F1F1FFF4EFF7F7FCFBFFFFFCFFFFFAF7FAFFFFFFFAFA
FAFAF7F7F7FFF7FFFFFFFFFFF7FFFCFCF7F3F3F6FAFBF5F6
F6F5F3FBFBFDFBF9FDF6FBFDFFFBF9F0F3F7F9F9F9FDF3F6
EDEEEFFDF7F6F5FDF7FDFAF7FFFFF3F7C9C5FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFA
FAFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6F1F5FFFFFFFF
FFF3F4EFFFF4F3F7FFFBFFFCFCFFFFFFFAFAF7FFFFF6F6FF
F7FAFFFAF7FAFAFFFFFFFFFFFAF9FCFCFCF4FCFCF1FDFCFD
F6FBF9FDF9F9FAF9F9FDFFFAFFFBFDF3F8F6FFFFFBFFF9F3
E6F6F7FCF7FDFDF5F7FAFFFDF7F7F3FFC8D1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFAFAFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2DFF6FFF7F7F7F7
F3F7F4F4F4F7FFFCFCFFFCFAFAFFFCF9FAFAFAFFFFF6F6FF
F7FFFAF7FFFAFFF6F6FFFFFFFAF9FCFCFFFCF7F7F3FCFFFC
FBFCF9FDF9F6F3FDF7F5F9FBFBFFFDFDFAF2F6FFFBFCFCFD
F3F7F3F3F3F0F7F7F3FAF7F6F7F7F3FABFD9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFAFFFAFAFAFFFFFFFFFAFAFAFAFFFAFAFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1BFDFF5FDF7F7F7F6
F4F4F1F3FFFCFFFFFCFCFCFAFAFFFCF5FAFAFFFFFFFFFFFF
F7FFFCF9FFFAFFF6F6FFFFFFFAFAFFFCFCFBFCFCF1F6F4FF
FFF9F9FBFDFBF9F9FDEEFDFBFBFFFDFDFCF6F3FBFAF9FFFF
FAF0F1FFEFFBEDF1FDFBF9FFF7FFF3F5B2F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAFAFAFFFAFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFAFAFFFAFAFFFFFFFAFAFFFAFAFAFAFFFAFAFFFAFAFA
FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEBB8CFE2FDF5FFFCF6F3
F4F7FFFCFCFCFCFCFCFCFFFFFFFCFCFAFFFFFAFAF7FAFFFA
FFF9FFF9FFFAFFFFFFFAFAFFFAFFF7F7FAFCFFFCF2FAF6F9
FAF9FCFBFDFDFBF9F6F1FAFAFAFDF6F6F9F6F2F7FDF9FCFB
F6EFF1E9F6ECFFEEF9FFFAFFF7F7F7F5B3F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFAFAFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFAFAFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEEB5A3CBDEF3F7FCFCEFF4
F3FFFCFFFCFCFFFFFCFCFFFFFFFCF6FAF7F7F7F7FFF7FFF7
FAF9FCFFF7FFFFFFFFFAFFF7FAF9F5F7FAFFFBF7FDF4FDF9
FDF6F7F4F9F6F6F3F5F2FDFDFCFCF6F5F9FCFBF9FCFCFCFC
F9F5F5F2F1FAE9F9F2FDF7FFF3FFF7EAB5F1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA7CBA99EBF7FCFCF4FFF1
F4FCFFFAFAFFFFFFFFFFFFFFFFFFFAFFFFFFFAFAFAF7FAFA
FFFFFFFFFAFAFFFFFAFAFAF7F9FFFCFFFFFCFFF4F7F5F9F1
FDF6F5F4F9F6F9F5F7F5FDFFFDFFF9FCFCFCFCF6F5F5F9FF
F6F5F7FFF7F7FFEBF1F1F7F7FFF3F3DBBEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFFFAFFFAFAFAFAFAFAFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD65092C08FF7F1FCF4FCF3FB
FBFFFFFAFAFAFAFFFFFFFFFAFAFFFAFAF7F7FFFAFAF7F7FF
FFFFFFFFFFF7FFFAFAFAF7F7F6FBFFFFFFFCFCFBF7F4F4F0
FDF9FBF7FFFDFDF9F9F7FDFBFFFFF9F6F6FCFCFBFCFAFAFF
F6F9F6FAF7F3F7F1F1EDF6F7FFF7F9D7C0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE57358EC9A9CF1F3F4FCF7FBFC
FCFFFAFAFFFAFAFAFAFFFFFAFAFAFFF7FFFFF7FAFFF7F7FF
FCFCFCFCFAFFF7FAFFFFFCFCFCFCFFFFFCFCF4F6F7F4FFF9
FCFFFDFFF9FBFDFDFFF9F9FAFBF9FFF6FFF3F6FBFDF7FAFA
F6F6FFF5F7F3FFF7E9FBF1F3FFFFFDCDC8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFAFAFFFAFAFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F58D4DBEE3A287FAEEF7F3FBFFFC
FFFFFAFAFFFFFFFAFAFAFAFFFFFAFFFAF7F7FFFFFFFAFFF9
FCFBFCFCFAFFFAFFFFFFFCF7F4F4F3FBF6F6F6FFF5F9F7FD
FCFCF7F9FDF6FDFDFDFDF5FDFFF6FDFFF6EEF5F6F7F5F7F7
FFFFFBF6F6FFF7F7F1F1FBF6F6FFF7BED6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFFAF7F7FFFFFFFFFFFAFAFFFAFAFAFAFFFAFFFAFAFAFA
FAFFFAFAFFFAFAFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA5373DA2EEC27E93EEEEFCFFFCFFFC
FFFFFAFAFFFFFAFAFAFFFFFAFFFFFAFFFFFAFAFAFFFFFAF9
FBFCFFFAF7FAFAFAFFFFFCF1F4F6F7EDF5F3EFEEF2F3F7F9
F7EFF5FDF7F9F6F3F9F9F6FBFBF6FDFCFCF7F9F4FCFCFFFF
F7F7FBFBFBFDFDFFF7FAE9EDF2E9EEB2DEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFAFAFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFAFAFA
FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF738A6F1D9FD5C85E2FFFFFCFCFFFCFF
FFFFF7F7FFFFF7FAFFFFFFFAFFFFFFFAFAFAFFFAFFFFFFFA
F7F7FAFAFAFAFAF7FFFFFCF4F6F7F7FDF5F2F2F0F6F7F7F9
FFF6FFF3F5F6F3F6FFF6F9F5F9FFFFFBF6F4FAFFF3FCFAF7
F4FCFFF9FFF9FBFDFAFFF7EFEAFDEDB3EBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7D321F5E5E56A52DCFCFCFBFBFBFBFFFF
FAF7FAF7FFFAFFF7FFFFFFFAFFFAFAFFFFFAFAFFFAFAFAFF
FAFFF7FAFFFAFAFAFCFBFBFCEFFCFFF9F9FFFFF6F5F6FFFF
FFFFF6F3F3F9F9F9F9F9F9F5F9FBFCFCF9F3F7F9F9F5FFF9
FAF9F9F9FFFDFDFAFDF7F7F7ECE5FBBEEDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFFFAFAFAFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEF7377ECEE7B52D9FBFCFCFFFCFCFCFAFA
F7FAF7FAFAFFFAFFFAFFFFFAFFFAFAFFFFFFFFFFFAFAFAFF
FAFFFAFAFAFAFFFFFBFCFBF6F6F9FFF7F9F9F9F0F5F9FDFF
FDF6F3F3F3F9F9F5F7F9FCFAFCFDFBFFFFF9F9FFFCF7FFF9
FDFDF9F9FAF9FDFAFDFFFFFFFFE9F0BBF3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFAFAFAFAFAFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFA9D4CCAF29C5DD3F3F6FCFBFBFFFFFFFAFA
FAFFF7F7FFFAFFFFFFFAFAFFFFFCFCFFFFFFFFFFFFFFFAFA
FFFFFFFAFAF7FFFFFCFFFBF6F7F2F7F9F7F7F9F9FDFBF9F3
F9F6F5F7F5FFF6FFFFFAF9FDFBF4F7FDFFF9F9FCFDF9FFF9
F9F9FDFCFBFDFFFAFAFBF6F7F7F5F6B1F3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFAFAFFFFFAFAFAFAFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7BC55A1EAAF6AC1F4FFF7FCFCFCFFFAFAFFFF
FFF7FFFAFFFAFFFFFFFFFFFFFFFBFBFAFAFFFFFFFFFFF7FF
FFFFFFFAFFF6FCFCFBFCF4EDEAF4FFFFF9F0F6FFFFF6FFF6
F5F6F9F9F5F6FFFFFFF5FBF6FAF6F9F7FCF5F9FCF9FDFAFD
FFF9FDFBF9FDFDFDFFF9F9F7F3F7F0C7CBFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFAFAFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7EB5581EEB56FBBF4FCF6FCFCFCFFFFFAFFFAFA
FAFAF7FAFAFAFFFFFFFFFFFFFFFBFBFAFAFFFFFFFFFAFAFF
FFFFFFFFF7FCFFF0F1F3F3FCF9FDFFFFFFF6FFF3F3F6F6FF
FDF9F9F9FFFFFDF6F6F9F9F6F9F6FFFFF7FAF6F9F2FAFAFF
FDF9FFF9FDFAF9FBFDFDFFFDF3F3EFEABDE2FFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFAFAFFFAFA
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFFFAFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7BE3C53D3DD54A6FFF3F4FBFBFBFCFAF7FAFAFFFF
FFFAFFFAFAFCFBFCFFFFFCFBFCFCFCFFFFFFFAFAFFF7FAFA
FAF7F7F7F6FCFBF1FFFCFBF9FCF9FBF3EFEFF3FBFBF9F7F0
F0F7F7F7F5F5F6FDFDF5F2F5FAF7FAFAFFFDFDF4F9FAFFFA
FAF9F7FBFDFDFDFDFFFFFBF9FFF7F3F6D5BACBF1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFAFAFAFAFFFFFFFAFAFFFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEF6D77FFEA926EEEF3FFFFFCFCFCFFFAF7FAFAFFFA
FAFAFFFAFAFCFCFCFBFBFCFFFBFFFCFBFCFFFAFAFAFAFAFF
FAFFFFFFFCF7F6F6F0FFFCFAF7FAF6F6FFFFFFFFFFF6F4FD
FBFBFDF3F6FFFFFFF6FCF9FFFAFAFFFFFFFDFFFDFAFAFFF7
F7FAF7FDFBFFF9F9FBFCFBF9FFF6F9F7F7E2C8DEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFAFAFFFAFAFFFFFAFAFFFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7BA44CAF4B569C0F3F4FCFCFCFCFCFFFFFFFFFAFFF7
FAFFFFFFFFFFFBFFFFFFFFFCFFFBFFFCFBFFFFFFFAF7FAF7
FFFFFFFFFFF2F6ECF0FCDFD1D9E2E2E6DFDFDFE1ECEAE7EE
F3FBFDF3F9FBF9F5FAFAFAFDFDFFFFFDFBFDF9F9FFFFFFFA
FDF9FAFDFDFBFCFBF9FCFAFFFAF6FDF4FFF1D8CBF1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF76774F2D666ACFAFCFFFCFFFCFCFCFCFFFFFFFAFAFA
FAFFFFFFFFFFFBFFFFFFFFFCFFFCFBFCFCFFFAFAFAF7FFFA
FFFFFAFAFFEFEAFFDFD1FFDDF4FFF0F3F6F7F7F4EDE8E7ED
E3DBE1F0FFF9F6F9FCF9F9FDFDF9F9FFFBF9F6F6F7F7FAFF
FDF9FDFFFDFDFBFBF9FFF9FFF9F6FAFAFAF1EABDD3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFAFAFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFFFFFFFAFAFFFAFFFAFFFAFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEE3EB1E4798FF2F1FCFCFCFFFCFCFCFCFCFCFAFAFAFA
FFFFFFFFFCFCF6FAFFFFFFFFFCFCFBFFFFFFF7F7F7FAFAFA
FAFFFAFFFAEAFFFFDED5FFDDF4F1F1FFFFF3F3FFF7F9F1FF
F3F6F6EADDE1EFFDFCFDF9FDFDF9FDF9FDFBFFFCFAF7FAFF
FDFDFBFBFFFFFDFBFBFDF9FFF9F5F9F5F7F5F7E1C1DCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFAFAFFFAFAFFFAFAFFFFFAFFFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFBE49D5A063EAF4F3FFFBFCFFFFFFFCFCFCFCFAFAF7FF
FFFFFFFFFCFFF9F9F1F5FAFAFAFFFBFFFFFAFFFAFAFAFFFA
FFFAFAF0E6F0FFFFFAFAD1FFFFEBFFFFFFF3F3FFEEEEFFFF
F3FFF3FCFBF6EEE8F0FCFCFDFFFBFBFCFDF3F6FFF9F9FAFA
F7FDFDFDFFFFFDFBFBFDF9FDFBFBFDF5F7F7F7F1D1C9F1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF706FE664AAEDF3FCFCFCFBFCFCFFFBFCFBF9FAFAFAFF
FFFCFBFBFBF6F9EFF9F7FAFAF9F4FBFFFFFAFAFAFAFAFAFA
FFEAE6EAFFFFE1E1FFFFDFD8EAEBFDFDFFFFFFF4F0EBFFFF
FFF3FFF3FFFCF6F6F4F1FCFCFDFBFBF9F9F2F2FCFDFFF9FA
F7F9FAFFFFFAF7FAFAFFFAFAFBFDFFF5F7FFF1F7EACCCEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D0923EF25282F7ECF1FFFCFCFCFCFCFCFCFCF6FCFAFFFFFF
FFFBFFFFFAF7F4F4FDF7FFF4FAF2FBFFFFFFFFFAFAFAEAE6
E6F0F6F6FFFFE1C1D1C6BCC1D5E7F5E8DDE4E4DCEDF1F6F6
F3F3F0F0FDFFF3F3FBECE2F0F5F6F9FAF5F3F3F9F6F9F9FF
FDF9FAFAFAFAFAF7FFFAFAFAF9FBFFF7FAF3F6F4F7E7BDCA
FFF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DB
88BD7C669BF4F3F7F6FFFFFCFCFBFCFBFFFCF6FAFFFFFFFF
FFFCFCFFF7F6F5FAFDF7FAF0F1FAFBFFFFFAF7FAFFF0F0FF
FFEAF4F4EAFFEBD7EDEEF6EAE3E5ECF0FFECF0EEF3F6F5F9
EAE7F0F6F0EEEEEEF6F0F4F1FDF9FDFDFDF4F6F9F6FCF7FF
FFFFFAFAFAFAF7F7FCFCFFF7FFF9FFFFF5F5F7FAF7F0F3B1
FAF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF585
88C0CF3CEAF6F7FFFFFBFCFFFCFFF9F9FCFBFCFFFFFFFFFF
FFFCFCFFF7F5F9F0FDF7F3F6EFFAFBFFFAFAFAFAF0F0FFFF
FFEAEAEADFD7D5E2E1E3E5E7F6FFFCFCFFF0EAEAEAE5E8EC
F0FFF4EFEFF4FFFFEEF0ECE8EFF1F9FDFFF5F9F9F6FCFAF9
F9F9FAF7F7FAF7F7FCFDFAF7FAFBFDFFFAF9FAF5FFFAEEB6
EBFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7BC72
D0CC7490F1F7FCFCFCFFFBFCFFFFF7FAF6FCFFFFFFFFFFFF
FFFBFFF4F7F5F5F2F6F5FDFBF6F3FBFAFAFAEAEAF0FFFFFF
FFF4E8D9D9D8EAE9F3EAD8D1EAEADFE4EFF1ECECF6FCF6F6
FFF7F7F7F7F4F1F7F3FBEFFFF3F6F0FCFBF6F9F7F9F5F6F9
F9F9FFFFFAFAFAFCF6FAFAFAFFF9F6FAFAF9FDFAF7F7F0C6
E7EDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE38298
CCCB0AF2F3F7FCFCFCFFFCFFFFFFFAFAF7F6FAFFFFFFFFFF
FCFCFFF1FCF1F9F9EFEFF5F5EEF4FBF7FAFAEAFFFFFFFFEB
D9D9E2E4E8E4FCF5E6D3DBDDBEBBC5BDC6CFC6B8C0C4D5F1
F6F7F3F3F7F7FCF3F4F6F1F4EFFFF4F0FDF3F6F2FCFAF6FA
F7F7FAFFFAFAFCF5F3FFFAFAFAF9F6FFFDFFF7F9FAFFFAD5
D0F0EAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFAFAFFFAFAFFFAFFFAFFFFFFFFFFFFFF
FAFAFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E99191B3
C9D924EAFBF7FFFCFCFCFCFFF7F5F7FAF5F9FAFFFFFFFFFF
FBFAFAF5F6F5FFFFF6F6FFF4E9F6F9F7EAEAF1F4EFE7D8D7
E4E8DADFF3F3D5B6BCCBD9E8B0A1F1F4EAEDBAB4FBEACECC
D7E8E7EFF6ECF7F6F7F3FDFFF4F4FFF1F0F9F9F3FBF7FBFF
FFFAFFF7F5F5F9FBF9F5F9F7FDFFFBF9FFFAF7FFF7FFF7EE
C6DEEFEDEDF0F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFAFAFFFAFAFAFAFFFAFAFAFAFFFFFAFAFFFFFF
FAFAFFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7B288C1BA
E7876CF0F4FFFFFBFCFBFCFFF7F9F7FAF3FFFAFAFFFFFAFA
F6FAFAF1F6F5F4EFF3F3F4ECF2F5F7EFEBF4DDE0EFEAE2E5
D5CCC3D3D8E5C9D9EDE4E6F0E7D0E4EAFAF4D3C9EFEAEECD
C1C7DDD9E0D5D5EAF7F5EDFAFFF4F4FFF6F6F6F2F2FFF6FF
FFF9FFF7F6FDF7F9FFFCF6FAF9F9FDFAFFFAF7FDF5FFF3F3
ECC8F9F7FFF9F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFAFAFFFAFAFAFAFFFFFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF186BAC3D3
DE67B5F6FFFFFFFCFCFFFBFFFAF3FDF5F3FAFFFFFAFFFAFA
F6F7F5FAF9F9EFFFF7F3E8E6F0FAEADCE2DDEAF6F3E5BEC0
DAFDE0DFCFF5EEBAB3ACACBACDD1D6EAE5EFE2D8F3F1F7D1
C7C7EAD6CFD1DFD5F1F4EFF7FFF4FFF4FFF1FCF9F2F9F4FC
FFF9FAFAFAF7F2FFF5F5F4FAF7F9FDF7FAFAF7F9F7FFF7F1
FACFE1ECEDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFAFFFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEBEA8D1B5DE
896EDDF7FFFFFCFCFBFFFBFAF1F9F6F1E8FFFAFAFAFCFBFC
F0F1FFF9EAE8E0DFE6E9D6E8F2CEB7D1DFDEDAC37E52B494
86C2EFD5CEE1E1FFCFA3897A85A6B5D1E3C8DBE8C6B8ADAD
DCD3F6EED9B8CCDAEDD9D2E2E6DFF2FAF3F6F6F9F6FCFAF6
FFF7FFF7FFF5EEF9FDFDF9F4F4F9FFF7FFFFF7F9F5F7FAFA
F7E3DBCEE1EBF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFAFAFFFFFAFAFFFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0A0E6ACA2EA
4BBFFBFFFFFCFFFFFFFBFCF3F9FDF6F3E6FAFFFFFFFCFBFC
E8FFF9EDEBF7F2F6F0D4E4F4D3C3D9D6AFBEF6C867404FA3
C6A0A99DACB9C2D99FCDF5FFF6F1F1D9A7A7A8AF9A97A0AE
E2E5CAE0F4DDE6F7F1E6E9D5EBEEDEE4DFF4F3F9FFF9F6F6
FDF9FFF7F9F6F6F4FBFDFFF7F7FFFFF7FFFAFFF5F9FFF9F7
FFEAE3EDEADACDF0FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFAFAFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA1B0D988C68F
62F4FCFFFCFCFBFCFCFAF7F3F6F3F3EFF3FFFFFFFFFAFAFC
EBF9EDEBF4F6EDF3EED7ECB4B1CBB579B1A0B5AEC8AEA6E5
FFD9C4CFE6D4BAB1A6F5FFFAF6FFEEEED5EEF2EAF6EDE4BA
A4ADDFC2CFD1EBEAE6D3E7DCDFF6EAFFF0EAF1F6FFF9F6F6
FDF9FFF2F6FDF5F9F6FDFDF9F2FFFAFAF7FDFAFAFFF9FAF7
FFF9E0DDD9CDF1D6D9EBFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7ECBCE9CF65F
A8FBFFFCFFFCFCF9FAFAF7FAF3F6F3E5FCFFFFFAFAFAFAFB
EDF5F1F1F6EDEBF1EEE1BDB1CDBED0C55B91DAD9F3F0E3FF
FFFCF9F7FAFFF3D8D4F7FFFFF3FFF6FFDFEFF1FFF1FFFFFF
EEBE9FDEF5EAF1DFF4B4F0EEE6D5F0EAEAE5EEF6F9FAFAFC
F6F9FFF2F6FDF9F6F6F6FDF9F2FFF7FAFDF7FAFAFAFDF7FF
FFF7ECD0E4EAD3DCEAD9FAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFAFAFFFAFAFFFFFAFAFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5BB2CCCFD147
EAF6FFFCFFFCFCF9FAFFF3FAF3F6F1F0FFFFFFFAFAFFFFFB
EDF5E8F7EBEBEEE4E8C7ABBEC2DCE7C384DAEEF5FFEEF1FF
FFFCFCFAFAF6F6F3EEF7FFFAF6FFFFEEEAEFE8EDEBEBF1FF
FFCFB797A0ABD3DFCFBAEAD6E4D3D5F3E7DFF9F1FCF6FFFC
F6F9FFF9F3FFF6F6F6FDF3F6F2F4FAFFFFF7FFF9FDF9F7FF
FFFAEADBDCEAFADBD7EBEDFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFAFAFAFAFFFAFAFFFAFAFAFAFAFAFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF1F1F1F1F1F0F7FAFFFFFFFFFFEE4DB6E4E7B34B
EDFFF6FCFCFBFCFFFFFAF1F9F6F5E6FBFFFFFFFFFFFFFFFB
E8EAE9F6EBEBFFF3C3B6BCD1E7E1CCA4AAEEEEF3F6F6F6FF
F1F1FCF6FAF3F1F0EBF5FFFAF6FFF6E4E8E5E6EDF1F1FFF1
FFDAEEE5CEB086AAEBE1E0F0E5C2A6DDE6DFE1EAF0FCF7F4
FDF7FFF9F3F6FDF6F6FFFFF3F4F4FFFAFFF7FAF5FDFDF5FF
FFFFF5E6E2E3DCF4FCF1FAEDFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFF
FAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF1F1F1F1F0F0F0F1F2EAEDFAFAFAFFD274ABE7F07D79
F3F7F3FBFCFBFCFCFCF7F5FDF6F7F0FCFCFFFFFAF7FAFCFC
DBF3F3EBEBEAF5BFC5D8E1F6FDC7D7A2DBDFDFFFF1F5F0FC
E8E8FFFBF7F3EBFCE8F3FFFFF3FFEEE8E6D4E6EDF1F1FFF1
FFE4FCE6EEEED377AED0A0B1DFE1B8AFD5E6EADBF0F6F9FF
F6F5FFF7F7F3FFF6FFF6FFF6F1F2F7F7FDF7FFF5FDFFF7F7
F5FAF7F3DEC1ABCDD2D6F6FFEDFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFF1F1FFFFFAFAFAFAEEE6EDFAFAF4D79D8CACE0CC4CC4
FAFBFCFCFFF6F9FCF6F1F9FFF6F0F5EDF0FFFFFAFAF7F6F3
D2E0E6EBEBFCF191F1E6E1F0F6C1BDD7D5DAD7A9C2EAF3DD
E0E2EDFCF6E4D6E0DCE4F7F7EDEEE2E5E9DCC5DFF1F1F1FF
E5CFDBEEEEFFEEBB8F89904F7D7A78F2959AE3D5CCDFF3EF
F4F5FFF2F6F4F6F9F9FFF6F6FBF9F9F9F7FDF5F7FBFDF7F9
F7FAFAF2F6D0A670AAC9D2E8EBF1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFF
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFECD288A0CCFA817DF3
F1F3FBFBFCFAFAFFFAF0FFFDF4F9F0F5E3FFFFFAFFFAF6F3
D6D7E4EEEBF7F596CBE4DFE1EDBDA8F4DAD9CFEECFE0F3E8
F4E8E0F6FFDDDAEAEAEAEDF3EAEBD9DCF1F6EBE6EDF1FFFF
D0DAB7EAEEEDF9ECDEF1EACA939EA167ADC4DDE6DBDAE6F5
F9F6F9F2F6F1FFF7F9F9FDF9F4F7F5F7FFFAF7FDFBFCFDFA
FFFAFFEFF3D9968FC1E9E8E1E9E1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFAFAFAFAFFFFFFFAFAFFFAFAFAFA
FFFAFAFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFDB9D65A8ECF055B3EC
F6FCF3FCFFFFFFF4EFF4F6F3F9F4F3F6E3FFFFFAFAFCFCE8
CBD8DAEBEFF3E5BDB1B8B9B8DECBB9F3E4EBEDF2E0D5E2EF
E0DFD1EBE6C9EAE0F4EEE2DDCCC5CBDFE1E2E6DFE4EAEFE2
BFDBBAEEF1F4F7E1DDE6FFF6DDEEF096BADDE4E8D9CAE4F6
F9F3F9FAF1F3FDF7F9F9FDF9F6F6F4FFF5F5F4FDF9F9FDFA
FAF7FAFAF3F9C7BEE5ECF5EEDAC9EEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFAFAFAFAFFFFFFFAFAFFFAFAFAFA
FFFAFAFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAEAC687627CCDEBD544ECF0
EFF4F3FCFFFFFFF3F9F6F6E6F7F2F6F6E3FFFFFFFFFCF6E8
CED7D8FAE4E4E1E6D7D0BF948BB0DBF6EEFCFCF3E8E0CDC9
D8E1BBC9C9C1E1E2E8F1FBE8BBCCE1E8DDE2E1E1DED9DAD4
C6E3BFD1F3F7EACCF2EDFFF3E9EDF3CFDCB7F5DBD9C9CEED
FBF3F9FFEBF5FDF7F9F9FFF3FFFBF2FFF7FFFBFDF6F9F9FF
FFF7F7FFFBECE9E9E4FBF5F7EEE2D6EEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFEED2A4706CB5E1E9F69A5CF5F2
F1FFFCFCFCF9F5F4F9F5F6EDF1EFF4F1E3FFFFFFFFFCF3EC
D5C8E6DEEFE7EBE7E6E0DED7C6B5B3C8D5D6DDE6E8FAE3E0
F1F3EDD7E2EDEDDFD3C9C2C9D3E7EEF4F6F0DCD3D9DBDBDA
E4F6D6BEF0F0DBD3D4F6F0E6F3F5EAD8DAAFE3EDDECDBCDF
F3F5FDF9ECF2FDF9F7F9FFF3FDFAF6F7F5FAFBFDFBFBF7FF
FAFAF7FFFCECD7F6E7DCDBF6F3F9DCE8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFAD4856B7EC1E1F4E2F26185F1F1
F3FFFCFFFFF9F5F4F6F3F5F7F9F5ECDEEFFBFCFFFCFFF1F5
D3C3ECD5F1EAF2E8FCF6EEE7DFDED7C8D1E2DCDADDD6CDD0
D7E1D3C3D3E1E1E1EBEFEFE1D7EFF0E7F0F6F3FFECDFD9E1
F3FCF6C1E0E0D0D5CFDEE5D7E8E8F3D5E5A7D7EEEED5C0C1
EEEEFDF7EFF1FDFFF9F9FFF6F3FDFCF4F9F9FFFFFBFDF6FA
F7F7F1FAFFEAC3E6EAEFCCEAF2EAF1E5EEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFA8F58AECFF0E7F4EAEE44B2EEFC
F4FCFCFFF6F7F3F6FFFDF7FFF6EDF5DBF5FCFFFBF4F4F1F9
D7C6FDC8E6F0F3EDF6F4FCFFFCFBF6F6F0EAE6E2DFE5EFE8
E2DCDEEFE8DEE9E7E5E5FFF4F3F0EFEFE4EEEEEAF5F0F4EE
EEEBEFD3DEDECCE6DED1E7D7DFE1F9C6F1A7D1F1E9E4CCB4
C8F1F9FAF3EBF6FFF9FFF9FFEFFFF7F7FAF3FDFFFCFBFCF7
F9FAF5F7FFEACDCBF6F7D6E8DCFAE3E5E8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFAFAFFFAFAFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEBE2D12C94D9ECE8DAEFEDAB42DBECF1
FCFCFCFCFAF7F1FDF6F4FBFCF9F0EEE6F7FCFFFCF7FFF4F0
E2D5D8DDC9EAF9EAF0F9FFFAF7FAF7FAFAFAF7FAFCF0E6E2
E2DDDDE2E2DFF1D7DADFD3D1D5DADADAD1D3DAD3DEE0D3D2
CFD6E8F1E6D3E2FFE8C7D1D5D2CAB6BED3BEC5F3E7DFDCE8
A6B8F0F3F0F5F1FFFFF7F7FFF1FDF2FAFAF6FDF6F6FBFCF9
FFF7FFF4FAF0BD6C509ADEF1FDECF1E2EBF1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE2FFCE22EEE4E2E2F3F1EC7C76FCF4FB
F7FFFFFFFFFAF1FFFDF9FFF7F7F7F0FAF5FFFCF4F7F1F4F6
E6F5DAEECBE5F2EAF6FFFAF7FAFFFFF7FAFAF7FAFFFFF7FF
FFFFFAFAFAEDE3EEF0EAEDF4F7EFF2F9FBEAE4E1E6E3E3EE
FCF0ECEAEAE8E1EBEBEEEBE8E2E4E6EBE6DFCDECD5E7F4EE
DF90F6F7E6F3F3F6FFF2F2F6F4FAF5F7FAFDFBF4F9F9F6F9
FDF7FAFAF7F0B5ADA7A4E2F1FBE9DBEDF9EBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD6D0A640F2ECEDF1F0E2FA6792FBF6FC
F7FCF3F4FAFAF9F9FDFDFBFBFCFDF9FFF5FFF4FCFCF7F3F9
E6FAEBE3E4CEE7ECFBFAFFFAFAFAF7FFFFFFFAFAFFFFFAF7
FAFFFAFFFAFFFAFFF9EEF0F0F3F0F1FFFDF6FCEAF0F2E6DE
DEE1EBF1E6E8EAE6E4E6F9F5E8D5D1DFD8CAB8BCD0E1D5CB
D494F4F6EFEFF3F6FFF2F2F6F3FDF9FFF7FDF9F6F9F9F9F6
FDF7FAFAFAEACF94E17C95E5EAEDE9EDF1EBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD3ABBE68F9DCF0EEE4F7DA48BDF3FFFC
F4F6FBF4F5FDF6FCFAF3F6F6F6F6F7F9F2FFF4FCFCF1F1F6
E8F7F2E9F3CEDEDDFBFFFAF7F7F7FAFFFFFFF7F7FFFFFAFA
FAF7F7FFF9FCFFF9F6EDFAFAF5F6F6F6F6F6F5F9F4F1F3F0
FDF4F0EFF6F4EEEFF1EEE3E5EAE6DAD1C6B7A0A4ACB0CEE0
D4C2EFF0F5EFEFF4F4F7F7F6FDF4F2F7F7F9FDF6FFF7F7F0
FDF9FDFAFFF3E887F1D65D91F3F3FFF1EBEBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDE63ABB8A58A76737D9BBE48E7F3F7F4
F4F7F7FFF5FCFCFBF3FCFCFFFFF7F1F3FCF7FFF7FFF1F7F3
E8F7F6EDE5ECDBDEECF4FFFFFFFAFAFAFAFFF7F7FFFFFAFA
FAFAFFFAFCF9FFFCFCF1FAFFF5FFFFFFF6F6FFF6F6FFF6F2
FFF9F9FCF6FBF9FFFDFDFFF4EFF1EEEDF1F7FCEEEDF0E9E0
E4F4EAEEF0EAF1F1EFF7F7F3F6F3EFFFFBFCF9F6F6F4F9EE
F7F9F7F7F7F3F18DC9BAEA729CEFFFF1F1F1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDE45C1815A7EA0B2AA809C6EF4EDF1FF
F7F7FFFAF7FCF3F4F7FFF4F5F9FAF7FFFFF7FFFFF1FFFFF6
E6F4FAF6EBF4D5D9F6ECFCFCFCFAFAF7FAF7FFFFFAFFFFFA
FFFAFFFFF7F7FFFCFCF7F4F6F9FFFFFFF6F6F9F0F6FFF3FD
F9FCF7F9F1F5FFF9F9F9FBFBFDFBF9FAFDF7F1EEEFEAF1F2
EFE9EEF3F6DFF1F1EFF9F9F6F6FBEFFFF9FBF9F6FBFFF6F6
FAF7F7FDFFEDF9AEEEDEC1C796CDF1F1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFADD43D63ADBF4F7EFEED8C2ABF4F2F5F6
F4FCF4F5FFFCF3F4F7FFF4F0F5F1FBF4F7FCFCF4FFF1F4FB
E8F7F7FFEBEBF1CDF6F1EEF7FCFFFAFFFAFAFFFFFAFFFFFA
FAFAF7F7FAFAFAFBF4F2EAF6FFFFF4F1F6FFF9F9F6F3F6FA
FAFCF5F9F9F6FDF9F9F0F9FBFCFBFCFCFFFFFBFCFCF5F6F3
FBF9F0EFF6DFE9F1F3F5F9FFF1F1F4FFFAFAFFFBFCFFF6F6
F7FFFAFDFFF5F593C6BBD2C4D0BCFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEAC3629D80FCFFF7F1EBEEF6DEF3F3F3F6
FCF1F7F3F9FDF4F1F4F4F4EDF1F3FBFCFFFCFCF4F4FFF1FD
E9F3F5FFF2F6F6D2EBF9F4F3FFFAFAF7FAFAFAFFFAFFFCFC
FFF7FAFAFFFFF7FBF4F9F2F6F4F4EFF6F6FFFFFFF6F6FDF0
F3F5FAF9FDF9EFF1F9F7F6F0F2F2F6FBF9F7F6FBFCF9F6F6
F7F4F6FFEFDBF1E4E7F5F9F6F3F3F6FAF7FAFFFDFFFCF9F0
FAFDF7F3F1FAF780F69ACAF4EEC5FAFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAE1B6BB92DDFCFBFCFCF0EAF1E5EDEFF3F7
F7FFF3F4EFF1F4FCFCFCFCF0F3FFFCFBFCFCFCFFFFFFF1FF
EFF2F4F3F1F2EDEBDBE7EBF4FBF6F6FAF7F7F7FFFFF7F6FC
FFFAFAF7FFFFFAF6FAF9F2F6F4FFF4F6F2F6FFF6F1F3FDF4
F1F6FFF6FBF6FFF9F6F6F4F4F9FAF0EAF2FDF9F5F5F6FCFC
F7F6F6F6F9DAFDDCCEFFF6F6F6FCECFFF9FBFBFBF6F9FCF5
FFFDFFFBF6EFF95FB87CA1DCD3DCFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAF1D7D6CDF7F1FBFFFBFBFAEDF7F4F9EFF3F7
F1F1F4F4FFFFFBFCFFFFFFFBFFFCFBFFFCFCFBFCFCFCEFFF
F4EDF5F2F7FFF6F2E3EBEAEBF7FCF5FFFFFFFFFAFFFAF7FF
FCFCFFFAFAFFFFF5F6F9F2F5F5F6FDF7F4F4F1F3FDF7F1EF
F1F1F5F6FCF9FDF6FFFFF6FAFDFDFDFDFDF9F9F9FDF9F7F9
F5F9FBF6E3EDEDD8C6F1F4FBF9FFEFF9F5F9F9F9FFF9FBF9
FDFFFBFDFDF1FC49EA9C9CA4CEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAE6D5EFF7F4F4FBFFFBFCF5ECF7F4FCEFF1F4
F7F1FFFFFFFFFCFBFFFCFCFBFCFCFCFFFAFAFCFCFCFFECF9
F7F7FAEFF4FAFFEDF6EAE9F2F1F4F6FAFFFFFAF7FFFAF7FC
FFFFFBF9FAFFFAFAFBF1FFF9EAF5F4EDEDEFF2F9F9F1FCFF
FAF9FBF9F7F2F6FDFBF9FDFBFBFDFDFFFDFDFDFFF9F5F7F2
F3F3F6F3E4ECE4F1D5FDFBFDFBF3F4F7F6F9F9F7F7FCFCFD
F9F9FAF9FBF1ED56F7BCC6A0C6EEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDED5E8F7FCFCFCFCFBFCF9EAFFEFECF6EEF0
F1FDFAFCFCFFFCFBFCFFFFFFFAFAFFFFF7F7FAFAFFFBF1FD
F9F9F1F6FAF4F7F6F6EBEFF0F4F1F3F7FFFFFAF7FAFAFAFC
FCFCFBF9F7F7FAFFFCF0F6F0EAF2F6F2F2F9FCF5EFECF7F7
F6F6F9F5FBFBFDFBFDFFFBFBF9F9FBFFFDFDFAFBFFFFFDFA
FAFAFDF1F4F4F6E8F5F9FAFFF6F1FAFCF4F9FFF9FFF6FBFD
F9F9FAFDF5F1ED50F7C7AFBCC2E4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD6E1EBF7FBFBFFFCFCF9EEE5F1F4FBFCF4FC
F4F2F2FCFCFFFBFFFFFFFAF7FAFAF7F7FAF7F7F7FFFCF4F1
F4FDEEF3F6F4F7F6F2E4EAF1F9F3ECFAFAFFFFFFFFFAFAFF
FFFFFFFCFBFBFCEEEAF1EDEFF4F6FFF9F9F5F1F7F9FFFFFC
F6FFFFF6FDF9FFFDFDF9FDFDFAF9FFF9FBFDFDFBFDFDFDFA
F7FAECF6FFFFF0F0FFF9F3F4F1FAFAF6F9F6FCF9FFF6FCFB
F9FBFFFAF6F1ED43E5C885785D87FAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF1D1F9F1FFFBF6F7F7F7EBE6ECE6F4F6F7FFF7
F1F3FFF4FFFCFCFCFCFFF7FFFFFFFFF6F6FAFFFFFAFFFBF4
FAF6F9F6F6EBF7EDFFF2EBEBF4F1ECFFFAFAFFFFFFFFFAF7
F9FBF6F9F7F7F3FBF6FCF3F3F0F9F9F9F9FCF9E2F1F6FFF6
FFFDF9F9FAFDF9FDFAF9FDFDFDFBF7FDFDFBFFFFFFFFF9FD
F7F7E9FFF9F4EFFDF9FBF1F5F5FFF9F0F9FCFFF6F9FCFFFD
FCFBF9FDF7EFEB44F3F5D6E29C69FAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF1D0E7FBF5FCFCEEF5F5F7E3F3FDDBFCECF1F7FC
F9F5F4F4FCFCFFFCF6FAF7FFFFF6F6F6F6FFFAFAFAF9FCF4
FAF9FFF5FFF1F4E7EDF2F2F3EFEFEFFFFFF7FFFFFFFFFAF5
EAEDF1F2F6F7FCFCFCF6F6F6EEFAFFFCFCF0EFE0F9F0F4F6
F3F0F5F2FBFFFDFAFBFAFBFDFDF9F7FFFFFAFDFFFFFFFDFA
FDEDF6F6F0F5F7FAF9F6FAFDFAFFFDF7FCFCFFFFFCFAFBFF
FCFBFCF7F7F5E34AF5F7EEDE668CFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFDEDFF1F7FAFCF9EAEDF2E6EDF9EEE4FFF0F1F4F1
FDF1FBFBFCFFFFFFF7FAFAFFF6F6F6F6FFFFFFFFFFF5FBFB
F0F2F7F6F6F3FAF3FFEBEBF3E0DFE3FCFAFAFFFFFFFAEAEF
FCEAEBECEFF1FCFFF7F1FDF9F0F1F2F3FDF1F0EBE5F3F2E8
E9EEF1EEF0F3FDFBFDFDFFFDFFFDF6F6FDFDFAFDFFFFFFF9
EADCEAEAF5FBFAFDF4FBF6F6FFFFFDF9F6F9F9FFFCF5F7FB
FCF9F9FAF7F5DF63CFC4CA9064B7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF1DBF6F4FCFFFCF5F5F6E8E6F4F5E6E8FCF6F1F4F1
F7F3FBFBFCFFFFFFF7FFFFFFF6F3F3FFF6F6F6FFFFFAFAFC
F4F3F7FBF1F6F6F1FFEDF6FFF6ECDCF3F7FFFFFFFAF6F3EE
F3FFFCFBFBFCF6F7FCEEF3F0FFF0F6F1FBF7F9FAF4E5E0F0
F1EDF9F9F6F6FBF9FDFDFBFDFDFFF3FAFDF9FDFAFDFFFAF1
F0E9F7FAFBFFFDF9F5F7FAF6FFFFFFFAF6F9F9FCFFF5EFF3
FBFBF7F9F4F1CB79E4E7D35A97D6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEBE5FFFCFCFCFCF7F5E6E5F5F9F3E6E4FCF1F7F4F7
F1FFFFFFFBFAFAFAFAFFFFFFFFF6F3F6F3F6F6FFFFFFFAF6
F4F3FBFDF3FDF4EBF7FFF6FFF6F3E0EEF6FAFFFAFAFCFBFF
FCFCFBFCFCFBFBFBFCF3FCFAF1F9FDF6F9F7FCF6F3F5F6DF
E1F9F3F9F6F5F7F7F7F9FBFFFBFFFBFBFFFAFBFFF5ECE9EC
F0F0FFFFFBFDFBF9F6FAF9FAFFFFFFF7FBFFFFFCF9FFF7F3
FBFBF9FCFCF0B87DF4DDC17C90ABE5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE4EBF4F4F4F0FAFAE6E1F2F9F3FBE1F1F2EFF3FCF1
FCF4FFFFFBFAFFFAFFFFFFF6F6F6F6F6F6F6F6FFFFFAF7F6
FCF1F9F5FFF6F9EFF7F7FFF6F6F7DDF1F0F7FAFAFAFAFFFC
FCFFFAFAFFFFFAF7FAFCF0FCEDFFF9FAF2FAF9F1F6FDFAF9
E7DDE1F7FBF1FBF4FDFAFDFDFDFDFDFDF6F6FFFBF5FDF2F6
FAF7F9F9FFFDFFFAF5FAFBF5FFFFFFF5F9F6FCFDFBFFF9F7
FDFCF9FCFCEBAD82FFDCB8806864B8E6EDFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFADAF6F4FFFFF0F7FADDEEF4F4F1F4E4F6F9EEF3F1FF
F4F4FCFBFCFFFAFAFFFFFFF6FFF6F3F6F3FFF6FFFFFAFAFC
FBF4F9F2F5FAF6F0F6F4FAFFFFFFDEF7EDEEFAFFFAFFFAFF
FFFFF7F7FFFAFAFFFAFAFCF3EAFDFFF7F5FDFCF7FAF9F9FD
F9F9EAD8E9EBE1F3FDF6FAFBF9FDFAFFF9F9FBF4F6F0F0F6
F7FAF5F3F6FFFAF9F2FAF6F6FFFFF9F9F5F5FFFDF9FDF9F9
FDFCF6F4F4F7A995F1F4F3EDE77675B3D9EAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF0D7F5FAF4F4FBF7EDDAE1E8E9EFEAEEF7FFF3F4F1F4
F4FCFFFCFFFFFAFAFFFFFFFFF6F6F3F6F6F3FFFFFFFFFAFA
FCF0F7F1F5FAFCF3F6EFEEFAFFFFE8F0F3EEFCFAF7FFFAFF
FFFFFAFAFAFAF6F6FFF7FFFCEFF5FBF9F5FDFDF9FCF7FDF6
FBFDF7F5EFF0EDEBF1EEF2FBF6F9FDFAFDFBF0EFF7EEFAFA
FFF6FFF1F6FFFAF9F9F6FDFCFFFFF7F9FAF7FBFBF9FAFBFF
FDFDF0FFF1F3AA9FD4DCD9FDE5B398A2B1D6FAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFADDE6FCF2F4F4FBFAD7DFD8E9F7F2E2F6F2FCFFF4F7F4
F4FCFCFBFFFFF7FFFFFFFFFFFFF6FFFFF6F3FFFFFFFFFAFF
F6F4F7F4EDFBFBF9F6F5F2FAFAFAF3F3E9F0FCFAF7FAFFFF
FFFAFAFAFAF6FFFFF6F7FCFCEFF3FDFFF1FFFDF9FCFAFFF5
F5F5F9FFFDFDF7F6E2F3F6FFFFF7FFFDFBF4ECFBF6F4FBFD
F9FDFFF1F6FFFFFAFAF6FDFCF6F6FDFFF9F9FAFAFAFFFBF9
FBF9F0FCECEDC7B5A8C0C6BACBDEB7C69FA6E1F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE7DBF9F7F4F3F3F6DAEEDDDBE1EEEADBEFF3FCFFF1FFFF
FFFFFFFBFFFFF7FFFFFFF6F6F6F6F3F3F6FFF6FFFFFAFAF9
FAFBEEF4ECEEF6F7EAFFFAF0EBF4EEEEEFF4FCFCFCFCF6F1
F3F6F9F9F6F6F6F5F0FAFBF7F0EFEEEBE7ECECF2F7FAF9F5
F5F9FDF6F6F5FCFAEAF4F6F3F6F9FDF9F4F6F0FCF6FAFBFD
F5F5F3F6F6F9F7F4F9FAF6F9F7F6F9F9FBFFF9FBFCF9FDFD
F9F9F9F6EEE7D1EFECD3EFDADBE4D2BA8E5C559CEBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAD2EAF9F5FFFCF0EBE7ECCEECF5E7E6E7F2F4F6F1F4FFFF
FCFCFFFBFCFBF6FAFFFFF6F6F3F6FFF6F6FFF6FFFFFAFAFC
FFF0FBF7F7F4FFF9EAF9F5FFFDF1F6ECF7EFFFFFFFFCF2F6
F1F1F3FCF9F7F5F9FCFBEEF0F4E9FAF6F6FFFCF9F9FFF9F9
F9F9F9FBFBFCF6F4F2E9F4FBEEF7FDF3F3F0F0FBF6FDFFF6
FFFDFDF6FFF9F7F9FBFCFCFAF9F6F5FCFBFDFDF9F6FBFFFF
FCFBFBF1FFE6DCEDF4DBD5D2CDC5F6F6F6E0A198E2FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F3D1FBFDF1FAF3E2E9FDF1D7FDF4DEEAEAF2F7F3F1FCFCFC
FFFCFCFCFBFCF6FAFFFFFFF6FFF6F3F6F3F6FFFFFFFFF7FF
FBF4F4FFF7F2FAF7F0F3FDF6F6FFF6DBF3EAF6FFFFF6F6FA
FFFAEEFBFCF4F7FFF4F7EDFBF9EBFCF2FCF9F9FDF9F7F6F9
FDFBFBFDFDFBF9FFF3E8FBFDF1F5FBF0F9F2F9F9FAFFFFF6
FFFDF9FFFFFFFFFFF6FCFBFCF6FFFBFAFFF9FCFCF7FDFDFD
F9FDFDF4FFECE5F1F7F3DEDBD3AFCEE5CA8977B5E6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EDD3FBFAFADEDDE2E9D7D6EAF1F9E2EBF3FFFBF2FAF4FFFF
FFFBFFFCFCFCFAFAFFFFFFF3F3FFF6F6FFFFFFFFFAFAF7FF
FCFCFFF7F1F3FAF9F9F5FFFDF6F6F4E6EEF5F7FCFFEEFBF6
F9F7F1FFF6FCFCF6F1F2F6F3FAEFF9F5FFFCF9F6F6FBFCF9
FFF4FAF6F6FFF9F4F4EEFBF9F5F5F3F3F3F6F9FDFFFDFDF6
FFF6FFFFFFF9F9FFF5FBFBFCFCF6F6F2F9F9FBFBF9F9F5F9
F9FBFDF3F1F7DFFDF5F6F7F3E9CEAFC2887ABBE6F1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DED5F3FFDCCFD9CFD0E0EBF5F2E9F0ECF5F4F6FCFCF7FCFF
FFFCFCFCFFFAF7FAFFFFFFF6F6FFFFFFFFFFFAFAFAFFFAFF
FFFBFFF7F4F3F7FBFAF5FDF6F6F5F9FBE9F6FAFCFCF4F4FC
F9ECFFF7F7FCFCFFF3FCF7F4F3F6F9F5F9F7F5F7F9FAF5EE
EEF6F6F6F6F5F3F4F1F6FBF4F7F3EFF6F5F6FAFFFFF6F6F6
FFF6F6F6FFF9F9FFF5FBFCFCF9F9F9F2F7FDFBFBF9F9F9F9
FFF9F1FCF1F7DFF9FFF5F9F9F9F1D8AD7ED3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
CFECF5FAD6E5FFE2F9F6FBF7ECEBF5EEF6F4F6FCF0FBFBFC
FCFCFAFAFFFAF7FAFFFFF6F3F1F4FFF4F4FFFAFAFFF7FCFC
FCF4F7FFF7FFF1FDF9F9F9FBFAFAF6EEEDFBFAF6FBFCEDFA
F1EEF7F4FBEEF6F1F6FBF9F6F3FDF9F5F9F9FFF6F3F6FCF7
F3F3F6FDFDFAF7FAF3FFF6F7F4EEF0FCF5F7FDF6F6F6FFF3
FFF6F5F5F9F9FDFDF5FBFAFBFAFAF9F4F9F9F6F9FAFBFFFC
FFF9F1F1E9FCD9F7F7F6F6F9F9FFE1B7C0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1
D7FDF7F5D4EBF7EAF6F9FAF6E6F0F7EAF5FCF7FFF3FCFBFC
FFFFFAFAFFFFFFF7FFFFF3F6F1F4FFF4F4FFFFFFFAFAFCFC
FBF1F3F2F5F4FCFFF9F9F9FDFAF4F1F4FCFCF7FAFAFBF4EE
F3FBFBFCFCF6F6FBFAFCF9F5F6F7FCF5F6FCF9F3F6F6FCF3
FAFAFAF6FDFDF7F6FFF6F3F6F9F1F7FAF9F7FDF3F6F3F6FD
F5FFF7F9FFF9FDFFFBFCFFF7F7F9FAFAF9FFF6F9FBFDF9FC
FBFDF5ECEDF4D7F7F7FBFBFDFFF5E7AFEAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9
E7F9F9EEDBEDEDF3F6F5F0EDE6F7ECECF5FFF1F4FCF6FCFC
FFFFFAF7FAFFFAFAFFFFF6F6F6F6FFFFFFFFFAF7FAFCFCFF
FBEAF9FDF9FFFBFAF9F5FAFAF4FFF3FAF7F7FAFFFAF5F6FC
FFFFFFFFFBFFF4F3F9FCF9FDF1F9F9F9F5FDF9F3F6F6FCF3
F5F5FFF5F7F0F5F6F6F6EEF4F6EDF4F6FBF7FDF6F6F6F3F9
F6F7F9F9F9FFFDFAFDFDFAFBF9F7F7F9F9F7F9F9F9F7FCF6
F9FDF6EFEEF7D4FAFAFDFAF9F5F9E7A9F3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2D8
EAF9F7ECE0F6F0F9F1F3FDEEE8F1E6F5F7FFF1F4FCF6FCFC
FAFAF7FFF7FFF7FFFFFFFFFFF6F6FFFFFFFAFAFCFCFCF4EA
F3EEF5FFFBFDF6F5FFF6FBFBF1F4ECFAF7F7FAFFFFFFFAF7
FAFFFFFFFCFCF7F7F9F7FDF6F5F7F6FDF5FFF6F6FFFFF7F7
F6F6FFFAFAF5EDF5F5ECECE7E6ECF9FBFAF9FDFFF5F9F5F6
FDFBFDF9F9FDFAFDFBFBFBFAFAFAFAEFF6FBFBF9F7F7FFFD
FCF9FDF1EEFCC9FAFAFAF3F6FFF9E6BEDCF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4CDEE
FDF0F1E5E2F3EDF6E6FDF1F5E5EDEEF9F9FCF7FCF7FCFCFC
F7F7FAF7FAFAFAFFFFFFFFFFFFFFFFFAFAF7FCFFFCFFF0EF
FFF1F6FFFCFDF9F9F6FDFBFBFDF6E6FFFFFFFAF7FAFFFAF7
FAFFFFFFFFFBF7F6FFEFFDF6F5F0FCFDF5FFF6F6FFF7FDFA
FAFAFAF7F5F6FDFBF3F4F0F1FFFCFDFBF9F9F7F7F6FDFBFD
FDF6F9FBF5FDF9F9F5FBFBF7FAF9FCEEF4FBF9FAFAFAFFFD
FCFBFBEBF7F3CBF7F7FAF2F9F9F9F1CAC0F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5D7FD
F9F1EEEAE6FFF3F2E9F7F1EEE6F3EFF6F9F4F1FFF6FCFCFF
F7F7FFFFFAFAFFFAFAFAF7F7FAFAF7FAFAF6FCFCF3F4FBF7
F6FFF6F4FFFFFBF7F2EFF1F3F6FDE4FFFFFCFCFFF7FAFAFA
FAFFFFFFFFF3F7F4F6F0F5F3F0F3FFF6F6FFFAF6FFF7F9FA
F7F6F6F3F6F6F0F2F9F9F5FAFFF9F9FDFDF3FDFDFBF6F5F7
F6F6FFF6F5FDFDF9F6FAFCFFFFF9FFF9F9F7F3FFF9F9FFFF
F9FBFDE9F7F3D1F9F9F9FAF2F9FFF9D5B1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4DCE8FF
FAEEF0E8E0F7F3F2F1F1EFEEE6EEF2F5FCF7F4F7F6FBFFFF
F7FAF7FAFAF7FAFAFAF5FCFFFAFAFFFFFCFFFCFFF3F3EFF4
FCFCF7F6F9F9F6FBFDFFFFF2F6F9EFF4FFFCFFFCFAFAFFFA
FAFFFFFFFFF4F6FCF2F5F1F5F6FAF6F5F6F6FAF6FFFFFDFB
FDFFFFF1F4F6FCFAF6F6F7FAF9FAFDFBFBF9F6FDF9F4F3F6
F3FDF5F9F9FBFDF9F6FFF6FFFFFAFBFBFDFDF6FFF9FDF9FF
FDF7FBE9F7EFDFF9F6F2F7F2FFFCF9E6A3F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5E3EAF3
F5EEFCEDDBE4F2F2EFF6F6ECE6EAF5F6F4F6EFF7F7FCFFFF
F7FAFAF7FAFAFAF7F7F9FCFFFFFCFBF3F1F4F4F7F7F1F1F4
FFFBFFFAF9FCFFFBFDFDFBFCFDF6F4F6FCFCFFFFFBFCFFFF
FFFFFFFCFCFCFCFBEEF0FDEBF9FAF5F9F0F6FAFCF6FFFFFF
FFFDFBF6F5F9FDF6F9F7F7FFF9F9F9F9F9F9F6FBFBF4F6F9
FFF9F5FAF7FBF9F9FCF9F5FAF7F7FCF9FFFCFBFDFFF9F9FD
FCFDFBE9F7F1EAF3F6FBF9F6FDF9F4EDB1CCF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7EAE3EF
DEF0FAE1DDEBF6F0F1F6F6EAE6E6F6F7F7FCF3F6F3FFFFFA
FAF7F7F7F7F7FCFCFFFFFFFFF4F5F6F7F3F6F1F4F1F1EFF5
FCFBFAFDFDF9F9F9FFF9FCFDF6F9F7F7F6F7FCFBFCFCFCFC
FAFAFFFCFCFCFBFFEFF2FDEEF4FBFAF9F9FFF5F7F6FFFDFD
FDFCF9F7F9F4F9F9FDF7F7FAF9FAFBF5F7F7FDFBF6FDF6FF
F9FFEDF9FCF7F6F7F9F7FFFDFCF4FAFBFCFBF9FCFBFFFFFD
FCFCFBE6FCFBE9FCFAFBFBF9FDECF6F3C4B8F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD1EFE2FF
D1F6DFD9F5EBFFF0EAF6F3F1DCE6FBF9FCF7F3F7FCFCFFFA
FAF7FAFFFAF7F9F5F4FFFCFBF6F6F3F7F3EEF6FCFCFAF3F3
F6F6FFF6F5FBFDFFFDF9FAF3F6FCFFF3F6F4FCFCFCFBFCFB
FAFAFFFFFFFCFCFBF7ECFBF6F2F3FFFAF6FFF7FAF9FDFDFD
FBFDF6F7FDF5F2FBF9F7FAFFF3FDFCF9FFF9F9F7FFF6F9F5
F6F5F6F9F9F7FDF9FDF6FAFDFFF6F0F9FBF9FBFFFBFFFFFF
FDFFEBF9F4F4DEF1FAFDF9FFF1DAFDF9C6AEFAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2D3D6CFE4
E1BEC6DEB29DB8DDEFF6F6EAD0EFF6FBFBFFF7F4FCFBFFFF
FAFAFFFAFAF7F7EDF4FFFCFBFCF7FFF4FCF9FCF7FAF3FBF9
F9F3F2EBF7F9FBF7F3F3F6FCF6F3F7F3F6F4FCFBFCFCFCFB
FFFFFFFFFCFFFFFCF4F2F6F3F5F4F6F9F6F6F5F9F9FDFFFF
FCFCFBFCF5FFF9F5FBFCF9F5F5FBFCFFF9F7F9F9FFF5FDF5
FDF0F7FDFCFCFAF9FBFBFAF7F6FFF9F9F9FBFBFDFDFFFFFF
F9F9F1F9F4F4C0CACEE4F9F1EDD3F9F7EAA2D0FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD7DACFFFEA
D9EEF3CFC5F4F6D5DDEBF6DDD1F5F5F6F1F3F4FCFCFCFFFF
FFFFFAF7FFFAFAFAFCF3F3F3F3F5FFF4FCFCF9FAFCFAF9FB
F6FDFBF7F9FFFBFBF9FCFCFCF6F3F7F1F4F3FFF4F7FFFCFC
FCFFFFFFFCFCFBFFF1FBF7ECF9F4F6F5FDF5FFFBFCFFFFFF
FFFFFBF9F6FFFFF9F9FCF4F1F9F6F5F9FFFFFAF4F9FFF7F9
FDF0F5FCFCFBF9F9F6FCFFFAFCF6F9F6FDFDFBFBFFFFFFFC
FBFCFFE6FFF3A6F6E7D1EAF1F0DBEEF7F9C9ABF1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7DDCEDFEBE0
E4D7D296CFE5F4F7E1EAEACFDEEEF7F7F6F6F3FFFFFFFFFF
FFFFFAF7FAFFFFFFFCF4FFF1F7F7F0EDF1ECF3F6FFFAF6F5
F0F9F9FCFCFFF6F6F5FAFAF6F3F1EFFFF6FBFCF7F4FCFCFC
FCFFFFFFFFFFFBF7FAF9F3F1F5F5FCF5FAF6FDFFFFFFFFFD
FDFFFBF7FDF9F9F6FDF7F6F9FDF9F5F9FDF9F6F6F9F6F0F6
F6F6F6FBFBF7FAF9FAFFFFFAFAF2FCF9FFF9F9F9F9F9FFFB
FDFFF6F5F3F7A6F7F9DAE5F3F1EDEEFDFAF09FDEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFADAEAD1EBFDE0
F3D7A7E8BDF4E2E4EDEDEAC2D9ECF1F7EFF3F3FCFBFBFCFF
FFFCFCFFFFFCFBFCFFFCF3EAF2FAF7F5F3F5F0F6F3F6FAF6
E9EEF0EFEFF9F7F5FAFCFAF6F3F1EFFCFFF3FCFCFFF4F6FB
FCFCFFFCFCFFF6F3F9F5F7F1F7F5F0F7FAF6FFFDF6F7FFFD
FFFBFFF7F6F6F9F5FBF3FFFCF9F9FCFDFCFCF6FBFDF9F9FD
FFFAFDFDFDFAFAFCFFFAF2F2FAFAF6FDF6FDF9F9F9F9FDFD
FBFBF3F7FFEFB0FFFFE2EDECFFFBEDF1F7F7A8CAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EBD5EBCBF2F3CC
C4C2ECB5C4DAEEF7EFF7ECC0D1EDF6FFFCF6FBFCFBFBFCFF
FFFCFFFCFFFCFBFCFFFFFFFFF3F1EFEFEAE6EAE6E4E4E9EE
EAF7FFF9F9ECEFEEEEF1F5F5F5F9F6FFFCFFF4FFFCF7F6FB
FCFFFCFBFCF3F0FDFAF3F6EEF4F0F3F9F9F9FCFDF6FFF6FB
FFF9F9F5F9FDFDF7FFF9FAFFFCF9F6F9FDFCF7FAFDFBFCFA
FCFBFAFAFFF9FCF9FAF7FCF4FAFAF9F9FBF9F9FDF9F9FDFD
FBFBF3F7FDECB4FAFFE2F0EAF3F0F9F3EEFBC6AEFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D6DEE9D0EBF0AD
CCD1B9FFACF6F9F7EEE6ECC0D1EEF5F7F6F3FCFFFFFFFFFC
FBFCFCFFFBFCFFF4F4FFFFFFFCFFFCFFFFFFFFFBFBF4F4FC
F1F7F3F6FBFBFDF6EFE6E3F0FBF9EBF7F4FCF6FCFCFFFCFB
FFFCFCFBFFF7F1F6F3F9F6F2F3F7F3F5F7FBF9FDFDF5F5F9
F5F3FAF9FFFAF5F9F7F9F7FAF9F6FCFBFBFAFBFBFDF9FCFF
F6F6FBFBFBFFF7FAF7FCF6FFF5F9F9FDF9F9FBFBF9FFFAFD
F9FFF3F6F9E9B9F7EDEDF3EAEFEBF9FDE8FDE4A4F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6E3DFDFE8D4A2
E193EEDCD7C0BAE3ECD9E9BBD4F3F0F7FBF4F4FFFFFFFAF6
FBFCFFFCFBFCFCF7FFEFEFF3FCFBFBFFFFFFFFFCFCF4EFEF
FBF5F5F9F5F9FBF9FCFFF9E7DEF3F6F6F1FCF3F3FFFBFCFC
FFFFFFF3F1F4F7FFEAF3F6F9F3F7F3F5F7FDFBF9F9F7F5FA
F5F5FBF6FAF9F3FDF6FFF5FAFAF4F9F9F9F7FCF6F7FDFFFC
F7F5FCFCFCFAFAFFFDF6F6F7FDFFFCFCF6F9FBFDFDFAFCF6
F9FCF9ECF1F1C4EFE3DFE1D9D6D3E5FCEDF6E9ACDAF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD9D4D7F6DBAFA8
CDC19F82A1BDC9EAC7EAEAAFD4EEF1F7FBF4FFF4FFFCF6F6
F3F3FBFCF4EFE6E4F2F7F1F3FCFCFCFFFFFFFFFFEAEAFFEA
EEF0F1F9FAF9F5F1FBFAF7FAF3E2D8DEE9F4FFEFFFFCFCFF
FFFFFFF4EEFCFFFAEAF6F5F1F6F9F9F6F6FDFDF5FAFAFAF6
FDF9FBFCF5FFF9FDFDF9F5F5F7F4F4F4F9FAF7F9FFFCFCFF
F2F3F3F7FAFFFAFAF7FAFAF7FBFDFDFDF9FCFDFBFFFCF5F6
F4FCF9EFF1F1C4E8F6E4D5D5CEBFC1D2EEFAFFB3BDF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D5CEDFEBE689C6
B1E597EEA2CCD8C8CDF4E4B9CDEBF7F7FBF4FFF7FCFCFBFB
F4FFEFE9EDF7F5FBEEE0DFFCFCFBE7E2EAECDBD1D9D9CFC7
C7D6DADFF4FFF4EFFDF9F6FFFAFAF4E5EAFAF7F3FCFCFFFF
FAFAFFFCFCF7FCF1F7FDF9E8F6F9F3F6FFFAF5EEF5F9F7FF
F6F9FBF6F6FBFDF9F9F5F5F5F3F0F6F5FFFFFAFAFFFFFFFF
F1FCFFF3FAFFFFFAFFF7F6FDFDFBFBFBF9FFFDFAF6FCF9F5
F3FCF9F0F1FFC8E5F3F3F6FDF7EBDEDCE2F3EBC0B4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDCCCBE4D9E886CF
C3BCABBED4A99DDCD9EEDAB4CDEBF7F7FCF6FCF6F6F4FFFF
FCF3ECE9E9F0F5F0F2C1A4B6CAC6C6CBB8B3C3CFCFD1D4DF
DFCFE2E2C7D6E4F3FAF3F3F9F9FFFAF5E6EFEBF3FCFCFFFA
FFFFFAFCFBF6FCF1F9F3F6F0F0F2F3FDFDFBF9F1F5F4FDFD
FAFBFFF3EEEEEFF0F1F2F6FDFAF2FFF7F3F3EFF5FAF5F5FA
F3FCF6F7FFF7F7FAFAF7F3F7FDF9F9F9FBFCFFF6F9FAF7FF
FBFCF1F1FCF4D4E6EFF6FFF6FFF7E6EADAE4ECCCA9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3C5D0F7D5E894BD
C59CD6B5D0CEE1E4E7EBE7A5CDEEF1F6F6F7F6F3F4FCF3FC
FCFCF3F1ECE7E3D5CAC6D0958689A3BDC8D6E6E8ECF0FCFF
FFF6E6E6F3CED7E7E8EEF7F9F6F3E6E6EFF9F1F4EFF4FFF7
FAFFFFFAFCF6F7F0F2F3F6F5F5EBF3F6F9FAF7F1F6F7F7FA
FAFDFDFDFDFBFCF3F1F1F0F9F5F4FFFFFFFFFFF3F5FAFAF5
F7F1F4FFFFFAFFFFF4F7FAF3F7FFF4FFFFF9FCF6F9FAF7F9
F6FFEEFCF1F3DAE3F0F0FBF6F6F6F5EAE6DCF3DBA2FAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7CBD9F7D5ECA5A8
E4A5F3CDD1F6FBE7F2EEE889CFF1EEF7F6FFF4F3F6F7F7F6
F7F7F4FFF7F6EBE9E3DCA3D8ECE4CFD2ECE1EDEDF0E3CAC8
C8C3B7BEE6FFE7CDE6F4F3F3EEEED6EAF7F9F3FAF7F6FCF7
FAFAFAFAFCFBFCF5EFFBF1F1F3F0F7FAF9F7FAF6F6F5F6F7
F6F0F1F3F9FCF7FFF6F6EFEEF0ECEFEFEFF7F2EBF6F7FFF7
FFFAF7FAFFFAF9F7FAF9EFFFFFF1FBFCF9FCF9F2FAFAF9FF
F3FBFBF1F1F3D8E5F5F5F6F6F3FCF5F0DAE5F9E7A2F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFACED0D7FFCBF6BA9A
DEBFF1E7E7E6EDF3EFE5F974D5F0FCF6FCF3FCFFFFF3F3FF
FBFBF1EFECF0E7D7C4E8DB96B8F3F6E4D5CABAC2C5B3B2C4
B6A0A5A9A8ADCFD9DED3D9E6DDDACEC6C7D3E1F0F7F7FBFA
FFFAFFFFFFFFF3FFEEF6F1F3EEF6F4F9F9F7FAFFF6FAFFE8
EEF1F7ECFFF7FAF9FAFAF5F5F7F6F5F6F6F9FFFDEEECE7E0
E6F0FFFAFAFAF9F7FFF7F3F7F3F9FBFDFCF9FAFFF2F4F2F1
FCFCFCFCFBF6D5E8F9ECF9F6F6FBF3F0E8DDEEEFA2F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C9C6E3F3D2F1C674
CCD6ECFCEDE5FFF0EFE6E68DC8EBF6F6F6F3F6FFFAFBFBFA
FDF6FFFBFCF3FAF7E7C8CEDEA0B1DAF4A9CADDFF92B3BB86
78D9D5CFE6F3CEC3EFFAF0D7D5DBC8B7B0B6C9E7F2EDFCFA
FFFFFAFAFAFFF3FFF1EFF5FAE9F9F4F6FBFAF7F5FAFDEEFF
FBF5EFF1F1F6F3EBEBEBEBEBEBE6E6EEF3EFF5F5EEF0F5F5
F9E1DDE9F5FAFAFAFAFFFFF7F7FFFDF9F9F3F5F9F2F4F2F4
F3FCFCFCFBF6D7E6FBEBF9FFFFF9F6EAF7D7EFEFA2F3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0CDBDF3F6CAE8D454
CFEBECF4E7F4FFEFFFF6DC8DCCE6F6F7F3F6FFF3FDFBF6F7
FFF3FBF7F6F1F4F4FAACDEE7E1B08B8CF6979BC076F083CA
7B8FFFD3CFE7DACBC1CACFD9E5F2F6E2D9D6C8E5EFF5F4FA
FFFFFFFFFAFFFBF7F0F5F6F7EEF9F6F3F6F7F7F1FDE8F7F6
F1ECE1F3EEEEF1FAF7F5EEEEE9E9F5F3EFF0F1F6F6F3F7F5
F4F1F0FDF7EFF0F0F5F7F3F7FFFDFDFDF3F9FFF6F5F6F5F7
FCF6FCFFFCEBDDEAF4F7FCFCFFFAF7EEF3E2ECF59EF3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F3DACDC7E1ECBFE6F466
9FD7E5F6EEFAFFFAEEDFE471D7F1FFF6FCFBF7FFF7FCFDEF
F7F3FCF4F6F7FFF4FFC8D6ECD8F3D2EBA6C2D78894D398BF
BE6BFFD5CDF5F9DEA9F2DBD7D8E5DFDED4C4C6E1F1F6F4FA
FFFAF7FAF7F7F6FCEFF2FDEEF1F7F6F3F3FFF6ECE1F2F7EF
E1EEE8F6F0F1F0FAFFEDE4F9F1E0E9F1F1F5FAF0F0F1FAFA
F0F9FDF3F4F7F7F5F0F0EFF7FFF3F2F3F9F9F5F2F3F6FFFF
F7EEFFFCF4EFD4EEEDF7FAFBFCEAE9EEE8DBF1F79AF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFDB8B9AF0C2DBF3C5F0F4A4
94E4EDEAE7F3F1EDE4D4EB7FE1FAF7F7F6F6F1F4FFF1F1F7
F7F4FBFFFBF7FCF3F3E8D9CFF7D5DEADB2BC9693B7EEACA4
B478F4D9D3DEE3D1AEDED5C5EAE4CAD2E2DFEAF9F7EFFFFA
FAFAFAFFFFFFEDF6EFF2F6F3EFF5F5F9F5F6F4F0F3FFF7C6
AFB2BAC7E9F1FFEEE6E2E0D1D5D6D3C6CDD3CEE1EBEFF7F7
F3FBFDF1F2E5F1EFEBEBEFF4FBF6F3F4FCF6F6F3F6FBFCFF
F3F3FFF3F4EDCDF6F6F3FAF6F4ECF7EDEFE4FDF79EF3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF74D5681E2A9E7FBCBEAFFCB
84C6F7EBEDEFF1F3E9E6C78FDDF1F3F7F7F7F1F4FFF7F7F7
F7F7FCF7F3F6F7FFFCF1F0E7D8F3CDE0E0D5D6BAB8D1DBDC
CBB9EDEADCF3F3BFBDBBD7E4EEE5E7E5DDEAEDF0F5EFFCFC
FAFAFFFFF6F6EDF6EFF4F0F3EFF5F2F9F0FAF9F2F2F3F3BA
E8C4B9A9D2D5D3D7DEDEDFE0E4D3D7DFD7D3D4D1DAE6E8EC
F1F1F3F6EEFDEEF3FDFDFDFDFBFFF3EBF0F9F3F6FCF9FFFC
F7F6F3F1F9ECD1F7F1F0FAEFEBE6ECF0F1F1F3ED9CEFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAA503D352E7BBD6F6C2E1F0E7
7B9AEDE7EFFFF3F0EAE5D386D9F7F7F7F7F7FFFFFFFFFFF7
F7F7FCF6F4FBFBFBFFF1FAF1E7E3F6D6E9DDE6C6C4A7C6E0
D6B8BCD1D9F6F6C6F9EDEBF3F6FFEDD3D8FAF6F2EEF1FFFC
F7FFFFFFF6F6F7F3F7F2F6F1EFF7F0F9F0F9F9EDEDEEF7C1
D3F7DDB5F1F2FBECF6EAE9E4D3DAF3F2F6F6F4E2C9C8D4DE
EDF9EFEAEEF3FBF0F1F6FDF0F0F0FCF0F9FFF9F9F6F6FAFA
F3F6FAF0F9E8CAF5FCF2F9F3F0D0F6FAF1F4F2EF98EFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7E97E3671CF56D3D9B8B1BBF6F6F4
7C89E3E3FFEDF6F9F1E3D37FE4FAF3F7FFFFFFFFFFF7F6F5
FCF6FCFBFCFCFCFFFBF6F1F1F0EAE5F1D9E0D3D7CFA0DCB8
C3D3CFD5C4CFE0C8E3D3DAF3FFFFBECFEDF2EFF3ECF7F4FC
F7FFF6F3F3F6F7F3F5F2FDF2ECF5F2F4FAF1FDEEF0F0F3E3
CAC2DEB3D5C6C4B1AEB5D6BBB7BEBFB8BEDFFFF3F6DDC7C5
C5E3EAEAEAEFF1ECF2ECE6F0F0F0F0F2FCFDFBF0FFF6FAF5
F7F6F5EDF2E6C4F0F5F1F1F7F5CAF3F5F4F5E2E49EE0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F1884EA6E2E557C8F4EBE6F6E6F9EB
819BD8F1FAE6FBF4F4E3D37FE4F7F2F6FAFAF7F7F7F1EDF9
F1FCF6EFF3FCFBFFFCFFFFF1FFF1E9E7F5D4CFE6F9B2B6C2
C3DDDCD6ECE6EBD6F3E8FDEEFFDCC6F4F4F7EEEBF2FFF1F6
FAFFF6F3F3F6F7F3EAF9FFF3EBEEF6F6FAF1FDF9EEEEEFF1
F3DBEEB8B8E6F3FDCB73CBE5EAEAEBFDEAC5BDE3F6E1F2F7
D2CBEBF6F3EAEAEEE6E8ECEBECF2FAFBFCF6F3FBFCFAFAF5
FCF6F2F2F7E5C8F2FBF9FDF6E6BFEDF9F4F6DCEBA2D6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7AE4B94EAEEF158CFE2EAFFEBEAF5EA
90AFDCE4EDE9F6F3F4D4D781DFFDF3F0F9FAF3F7F7E4F5EA
F1F3FFF3FFF6FCFFFFFBFCF7F4FFFAEAE1DDE8E7E3EAE1ED
D9CAD7D3D6D6DADCEEFFEEF9CFD2F5EBF6F5EDF1F6FAF1F6
FAFFF6F3F6FAEEF6F0F7F9F5EBEEF6F9F7EFFFF7E6F1F6F2
F7F7D3F2A7BEE3E695ADABAECED8D9EBE9D9F4CFECF9F1F4
E8C7DBE3EAE8E0D7DAE7ECF6F6F9F5F0F6FAF9F5FAFCF6EF
F9F9E8F2F1DBD7F4E6E9F9F3F7ADE4EFF0EAD8E7A7C5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFAFFFAFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA6406DE1FDEEF6877AC1E2E2C4CCD1B4
93DEF6F3E4EDF6F3F4D4D778E7FFFFFBFBF3FFF3F3DEE1CC
C4DEE8F3FFFCF4FCFCFCFBFCF4F1F1EEEAEADDE0E3E8F1F7
F1E4E2F2EEEDEAD1D1C8C0C6DEF7F2EDF9F0EAF0F5F1F4FC
F7F6FFF6F3FAEAFBF6FFF5F6E9F0F3F2F7EFFFF9F6FFF0E1
EAFFF3CDDFC38B85A1AE9F6EBEE3D9ECE4EEE6DED6D2CBD3
DAEBC9B8C2C9D9E7E1ECDFD6D8E0E7F3F3F6FFFFF6F3F3F4
F7F6F0E8E8D7DBF2F9E9CDCBE7B1DCF6F1CAEBEAA9BEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE55E89EAEDFBE2F1E8988EBED9BFD7C3B9
D0FDF0EAE7F0FCFCEFDBCF75F0FDFDFFFAF7F7FCF3E5CAD7
E3D0E1F2F1FCF4FBFBFFFAF7F7F6FCF4EAF9F6F5F2FDFBF6
EEF3EAE6E6D8D8EBFFFFFFF9F9FCF3F6F6F0F9F9F6FFF3FA
FAF3F3F6F6FAF1F4F9FFF7F6EEF5F5F2F3F2F9FDF4EEFFF4
EDE9E9F2EADEE7E6D990E15ABBE1C4E6EDF4F0DCC3FAEACA
D8EAF6F6EDF3E1EED3E4EDDBDBEAF3FDF3F3F3F6F6FCFFF1
F9FBF0E2DBD5F0FCF7F6D9F6D6AFD7FBDDCBE9F2A2BCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7B750D1F2E5F1E2FFF1D38989A4BBC3C6E6
E8F3F5F3F7F3F6F6E5DACE80E7FDFDF9F4F5FDFCF3FCE6C6
D9E5D0E4E7EEF3FFFCFAFFFAFFFAF7FAEFFAF7F5EAF9F6F9
F9F4F7F2FFFAFAFFFFF9F7F7F9F9F2F6F0FDF7F9F1F1ECF7
F6FFF6FFFFF5FCF3F7F9F6F5EEFAF5F2F1F7F7FBF6EDF0F0
EEE4EBDAEEEEEDD3C6E99F7BC4E7C2D4E3F2EAC6C8E6C0B3
E2F1DDCFE2E3CAD4E1E7E6E6FBF0EAEDFDFDF3F6FBF2F3FB
F2F6EFE2CFE2FDF9F6F7D9F6EA91E0FBD5D5F0ECA4BAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF37F5DE2F2F7EEDBFFF1F0E5AB95B6DAEAE7
E0E8EBF3F1F6F6F6E3DBC88FE2FFFCFFFCFBF3FFF4F6F7E6
CDEBDDEFDEE1EEF3FFF7FAFAFFFFFAFFEEF4FFFFEEF1E7F6
F3F2F7F7F2F7F9F9F9F9F9F9F4F9EFF6F0FFF7FAF5F6ECF7
F6FFF6FFFFF5F6FFEEFDF3F9F0F4F9EAF9F4F2F6F0F9FAFA
F3F3DFE1F0E5E4EFD7BEEAC5CEF0E7E1E4F0EDC9D5BACCF1
EEDAE7FCECCFC9E6FDF1F1FBECE7FAEFEEF3F6F6F6F9FCF9
F9F6F7D6C3DCEDF9EFD5DEEEFA81E6FBCEDCF3E2A1C2FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF75E77FDF6FAF6CFEAF7F5EAF4F3A4E5EBEE
EAF3EBF0EBFFFFFDE8DBC28BEAFAFDF4F3F4FCF3FBF3F3EE
D6DEF9E6F1EED7DFF4F7FFF6F6F6F1FAFAEEF4FFF6FAECFF
F0F2FAFAFFFAFFF9FFFAF7FAEDF4EFFBF6F0F7FFF6EEF3F7
FFF6F6FFFAEEF0F4EEFDEEFFFCF1F1EAF3F5F6FAF6F0EDFA
FFFAFDEEDCF3E1DCE7D8C1B8AB9DABC2E0F2FBDECCDEF4F0
E3D0F3F3DCEAE7F0FDF6F5F5EAFDF0F9F9FCECF3F6FFF9F4
F9F0EDCFC6F3FDEFFDE6E7E8FD7BE5F2C8ECEAE796CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF14998F4F4F7FDD5F2F9F9EFFBF0B7EDF0F1
F7F6FAEBEBFAFCF9F2D1C883F1FAF5FAF7F7F3F7F6F7FBF1
E8DCD5E6E2F5F6D2CCE8F7EEF3F3F3FFFAFAF4F4FFF5F0F0
F6F9FAFAF7F4FFFAF0ECE7E6E1EAECF6F9F3F6F3FAF3F3F7
FFFAFAFAFAF3F4FCF2F0F6F9F5F5F0F9ECF1F6F9F7F5F1F7
F5FBFFEAF3DCEDF1E2E1D4EBE0D7D3E3DCE8DAD1C3DAD9CD
C2E6F2D4E7F9F3EEF1F4F7F7F9ECF3F3FAFCF6F6F1FDF6FC
F2F7E8CED1F4EDF3F6EDE9EEF56CECDECDF0E9E596D6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD944B9F4EEF3F7D6F3F1F0EEF6E6D6EEFAED
F6FAF7F5FAF9F6F3F4D1C492EEF7FDFBF3FAF5F6F4F6FCF4
F1DECFEFECF1E8EBCCCDECE5F5F6F6FFF7FCE7EAEAEFF0E7
EEF1F1F1E2DDE6DADED9D3D9E1E5E7EEF0F4FFFAF3F4F4FA
F7FAFAF6FCF3F7FAF2F6F1FAE9FAF3FDF3E7F7F5F1F6F1FA
F9FDFBF0EEE8EDDFF9E3C1C8CFE3D0D9D0E2E2E4C2C4CEDF
FFEEDFF9F6F1EFF4FAF7FBFBFBF3ECF9F5F9F9F5FAF6F7F6
FAF7D6CBE2E9F0E7DDD5E5EBF55DFDDDD3F3E2D994E0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9C4CD8FDFBF6F6DCF1E5E5E2E3F1F0E4F3E6
EFF0F6F6EEF0F3EEEDD9CF8DE8F5FCFBF6F7FAF6F4F7FCFB
FFEACDDAE8EDE0E8DBB4A69C8F90878589877D7E8B8B7B81
8B93989CA6A9A3BAD3DFF1F3E3D2CFE8EDF6F1F5F6F4F4FF
FFFFFCF4F4F1FAF4F9F9F6F4F0F7F3FCF0F0F6F0F6EEEEF7
FAFDFFF0F0EAFFEAF3F1ECEEE2D0C8CDBDAFC3D9EFDCD1FF
F3EEEBDCDDECF6FBF9F3F3F6FBF6F3F3FCF6F5F9F7F1FFF6
FFE4C5C6E6E5F6E3E7EAFFEDE465E1DED6FFE2CA92F3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFAFAFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF856BE7FDF0E4DCE1EEE1E1F4FFFFF7E7EEF9
E1F6F9F6E2EDF2F3EAD9D794DDF1F7FFFFF9F1FFF7F7FFFF
FBF3F6DEDDD5D0DDEDFBEEF3F3FCF2FBE7E5F1F5EAEAEDFC
FAF7F1F6FBF9F5F7EFF4ECEFEAE5DAE8F1F4EDF0FFF4FFF4
FAF2F3F6F7F1F4F9FFF9F1F9FBFAEFFBF1FCF9F9F1FFFCF5
F1F7F7ECFFF0EAFDF0FDFDFDFDFDEAFFFFE2FDF9EFF5F6FD
E7DBE7F9F4FCF6F3F9FAFAF7F9FFF9F6F3F9FAF4F2F9F9FA
F9DECAD5EEF6E6FDD7F3F2F6BD80DAEFE3FFE2C09AF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8C74DDF1F4F7F7F3F3F4F3F1EFF4FAE8FCEF
E6F9F9FCE1F6E8EEEDE3C3A0D7F6F7FBF9F4F6F5FAF7F7FF
FCF6F4F3F4E8D3D0D1DFEDE5EADFEEF9E6EFEFE2ECF6FAF7
E8EDF6F6FDFDF5F6F3F9DDD7EDFAE1E6F1EFF1F9FFEFF4F4
FAF1FAF9FCF7F9F7F9F9F6F6F6FFF0F2F3FCF5F4F4F1EEF9
F3F2FFEAECF3F4E7EDF9FFFDF3EEF0FFFFE4EBEAF3F1DBD6
E2EEF6F5FDFDF9F9F6F3FCFCF9F9FFF3F6F2F2FCFDF2FAF9
E8D2C5CFE7F7ECF4D8E8F2FFA09FDFEAE6FAE6B89EF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFAFAFFFAFAFAFAFFFFFAFAFFFAFAFFFFFF
FAFAFFFFFFFF8C72DFF1F3FDF9F2F2F3F4FCFFF4EFF0F6E5
EBF5FBF6F9E0FFF4EEF0CE96CDF6F7FBF9FFF3F5F9FCF7FF
FCFCFBFFF2ECEEE6D3BDEAF1F7EDE3ECFDF3EEDBD2E0DDE6
FFFFE6E6E7EDF5E7ECECF0EEFFEED2EAF0F4F5FAFDEFFFFF
FCF4FAF5F6F7F9F7FFF9F5FDEEFFF7E6F9F6F1E4E8E0DADB
E7E1ECF7FDF0E5F6FBFDF9F9EFE8EAEAF0E6E6EEDBDBECF9
F6F6F0F5FAF4F3FFF7FFF7F4F5F5FCF6FBEFF3FFFCF5F3F3
DAD9CBD9FFF3F2E4E4DAF7F782C9ECEAEBF3E3B49AFAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFAFAFAFAFFFAFAFAFAFFFFFAFAFFFAFAFFFFFF
FAFAFFFFFFFF9865E5F6EBFBF9FFFFFDFFFCFCFCFFFBE6D7
F3F5FCFFF6ECF3E7E1E9DD9CD3ECEAF7FFF5FFF7FCF4FFFC
FCFCFCFFFAF6F7F1EAB8B9CACBD3D0C9DEEFEBE8D0CCD0D3
CEC2D6D6C9C1C6D2DCD2CED2D3CFD2E3E3EEEDF3F1F4FFFF
FCF1FBF9F4FDF2FFF7FCF5F7EAFFF7E8F6F1F5DDE6DDE8E6
DFDAD5E0F1FFF0ECF3FAFAF9F9FBFBF9EFF2F4F0FDFDF4F0
F9FCFBFFF6FDFFF7FFF6FBFDF3F3FCF9FCF2FBF3F5FDF6EC
E2C3CCE3F1F0E2E7D7EEFDD181F9F3ECEBF3DECA99CDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAB158DDEBF3FCF9F9F9FBF3F0F6F1F4FCDBDB
FCF0FFFFF6F3E8E1F4F5ECA4CEEEF0F7FBF9F7F7F7FFFFFC
FBFCFFFFFFFCFBFCF4EAD8D7D6CADDE4CFCBCCD5D8CED3C6
C0D7D1C6D1C4BABABABABEC6D3D7ECECF7F7FFFCF4FFF4F3
F3F0F9FAF4FFF1FDF9F9F1FDF2F6F9EEE8EBECDDE6F6F9FA
F0E7DED9DDE8FDFBECFFF9FDF9F4FAFFFFFBFBFAFAFFFFFD
F4F2F2F3FBFBFCFCF3F4FFFFFCFDF6F6FDF6F5F4FFF7F6EF
D1BAE5E4EBF0F1F2E3E5D9B3A1F0F9EEE0F6D7E6C272F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFAFAFFFAFAFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAC559C4E8EFF3FFFCFCFCF3EEE8FFF4FFDFEA
F3EEF3F3FBF5F1D7D0EFE3ADD7E1EDFAF7FDF7F7FFFFFFFF
FCFCFFFAFAFFFAFAFFF4F0EAEAE7DDE2D9D7DADDDED8DAE8
E4D6DBE3DFDADCDAD9EBE7E9F3FAFAECF3F7FCF4FFFFF4F6
F3FBFBF3F5F7F7F9FCFAF6F9FDF5FCF9ECF0E2D5E6F3F1F5
F4F3E7D6E2DCE3F0EAF0FBFDFDF3F7F5F7FBFDFDFDFBFCFD
FFF9F7F9F9F9FDFDF4F4FFF4EFF6FCF6F6F4F3FBF3F6F3E0
C2CEDFEBF6F0F0F1F1CDE6B4B6E8F4E9E6FBD7E7BC32E3FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFAFAFFFAFAFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD957B7F4DAF6F3F0FFFBF3EEE8F4FFFFE9F7
E4FFFFFBF5F6F0E8D7E5E4B7E1DFEEF6F7F4FDFAF7FAFAFF
FBFFFFFAFFF7FFFAFAF7EDE6E6E6E6E4EAE7E7E7E7F7E1D7
DBD5D6DFE4E9E6F1F6E8EEF4EFECEFFFFCF1F3FAFAFFF4F7
F1F9FAF4F1F1FDFCFFF9FDF6FAF9F5F6F1E2D5BECCD7D8DA
EEF9F7EFC8B2B0ADA8A3B2DBEAE8F3F3F6FBFDFFFDFDF7F4
F9F4F7FCF3F2F9F3FFFFECF0FCF3EFF5F9F6FCFDF3F9FCCA
BEC9DCF1FFFBFAF1F1D7E9B6C0FAEEEDE7F6E2EC9E3E9CF1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FFFAFAFFFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE958B4F0DCFBF1F4FCF6FFF2F5FCFCF3E5EB
F1E2F3F9EDFFEFFAE1F9E4C2DFDBEFF3F9F7F6FDF5FAFAFC
FCFFFAFAF7FFFAF7FAFFFFFFFFFFFFFFFFFFF6F6FFFFF6F6
F6F6F3FFFFFFFFF4F2FAFFFFFCFCFBF6FFF7FCFAFFF2FCF6
F1F9F7FFFDF2F7FFFFF9F9FCF5FAFAF6F2F6F4D1DBC9D5D5
D9EEF5E7FAF6DFD9D7D3BCB5D0D5EDFBFDF7F7FFFBFDF4FF
FAF6FDF6F3F5F6F6F3E1ECEEE8EFF9F3F7FDFCF6FCFFF6C9
C4D5EDFFFCFFF6F1DFFFF6CDC3DAE3E7E2F3DEDFAC708DD9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFAFAFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAED67A9FFD7EEFBFDFBF3F3F9FBFBFCF3EFE1
FFE1F3EDF0F3F4FAE8EFEDBFDCE8DBEDF5F5F1F9F5FFFFFC
FCFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFF6F6F6FFF6FFF6F3
F6F6FFF3F3F6FFFFFFFAF7FAF9F9FCFCF4F4FCFCFAF2F6FF
F7FAFFFAFFF5FFF9FFF9F9F9F6FAFAFFFAFAF7E1E2DACAC7
BDBDDFDCE9E8E8F4F9EDE2C6AF98A1C6DEE5F7FDFDF0F0F6
F6FFF0F3F3EEE9F3D5DCE2D2D8DFF1E8F9F6F4F5FFFAF9B7
C3D6FCF4FBFCF3DEF7F2EED0C6CBF3EAD5DADFC2D7A297AC
E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAF06396EDE5E5EFEDF9F3F0F9FDFCFFFFFFDF
F7EEE9FFFBEBFFEFEAEAEABAE1F1E6EFE1F1F7F9F5FFFFFF
FBFFFAFAF7FFFAFAFFFFF6F6F6F6FFF6F6F3F6F6F3F6F6F6
FFF3F6F6F6F6F6F6F6FFFFFAFAF7FFFFFAF9FFFFFCFFF3F5
F2F6FBFBFCF9F9F9F9FFF9F9FAF9FAFAFAF7FAF4F9F9EADD
DCCAC1D3E4DFDDDCECF5FDEDF3EABFADA9B0D1DBE6EAEAE6
ECECF0FBF0EAEAD9D3E9E9FFE1DBE1F4F9F7F3FBFAF9F9AB
C8EAFFE1F0FFFADBF2EDEDCDD9C7D8E7F7EFF2B7F2C8C19C
D7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6588EDEFEAFAEBF4FBFCFDF9F3F3FFFFE9
EEF7E4F3F4FCF4F0E3E8F0CED4EDE9F6E6F2FDF9FFF7FAFC
FCFCFCFFF7FFFAFAFFFFF6F6F6F6F6FFF3FFF6FFF6F6F6FF
F6FFFFF6F6F6F6F6FFF6FFFFFFF7FFFFFAF9F6F6FCF3F6FF
FBF4F4FFFBF9FDFDF9F9FCF6FBFCFBF9FAFAFAF2EFF7F9F6
EDF1D6C2C6DBDFD0C9CDDFEFFFFBF5EAE9C0C9CCC9D3E1E4
E1E1D4CDCDD5DDE9F6FFF6E1DCE2F0F2F7FFF9F7F7F6F0A7
C7FDE5F9E1ECECEFF2F3EEDDDECFEBDBCEC5CAC5F4C8C694
DBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF7483FDFCE1F4EDF3F6F6FCFCF6F3FFFFF3
E4F1EEEEF0FFE5E3E7E8E7E2CDF9E5ECEAF7FDF5FAF7FAFB
FFFCFCFFF7FFFFFFFFFFFFFFF6F6F3F3F6F6F6F6FFFFF6FF
F3F6F6F6FFF3F6F3FFF6F6F6FFF5FCFFFCF9FFEDF7F6F6FD
F7FFFFF4FBFDFDFDF9F9FCF6F5F5FBFDF9F5FAFCFCF7FFF7
F6F5EEE5D3CADAE4E9DED2DDE2EEF9F4EFDFDBDEDCDCD7E4
DCD7DBE2F3FFF6F3F6F4E4D9E2F9F3F3F5F7F9F6FBF9ECA2
D5E8E8F0F3E7E4F0F1F1EDEEE5C1D6D7CFD6DAE7E6D4AF92
EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF807EF4F0F0E8EDF3F0F0FCF1F3FCFCFFFF
EEEBF3EFF2E8F0E7F4E8EAE0D4EFECE9ECF0FBF2FFFCFCFC
FCFFFFFFF7FFFFFFFAFAFFF6FFF6F3F6F6FFF6F6FFFFFFF3
F6F6F6FFF6F6F6F6FFF6F6F6FFF5FCFAF6F9F6F6F7FBECF6
F7F3F3F1F9FFFFFFF7F9F9F7F9FAF6FBFFFFFCF9F7F9FFF9
F9FBF9F1F4EDD9D4DAE5DCDCDBE2E2E7F7F3F3F3F7F7F1E6
F5FAF1F7EEFAF1F6E9E1E1E7F6FFF9F9FDF9F4FAF6F6EAA2
D2E5F6F3FCFAF7FFF9F0F6F2F4DDECE5E8EAF4EDEAC674AB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9869F4F0FFE5EFF1E7F3F0F1F4F1FCFFF4
E7E7FFF1E6EBFFEAEEE8EEDEDEEDE3E9F6EAF6F9F7F9FAFC
FCFCFAFAFAFAFFFFF7F7FFF3F3F6FFF6FFFFFFFFFFFFFFF6
F6FFFFF6F6FFF6F6F6F6FFFFFFFAFAFAFAFFFCFCF7F4EFF1
F7FAFAF6F9FFFDFDF9F7FDF9F9FFFBFBFFFCFCF6FDFDF9F9
F9F6FCFAF0EDFCEDE4DFDBDCD5D7DCDFECFAF4F3F3F1EAF1
E6E4E4EEF0FCEEF3EADCEAF1F5F7F6F7F7FFF6F6EDF1EEA0
D3F3F3FCFBF6F6F0F1FFF0FFEFD5DDECEFFDF7ECF26080EF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF19E71EBF4FCF4DBFAEDEEEDF4EFFFF4F4FF
F9D1C2D9DEFAFAEFEAF9E4E0DEEDE6EEEBFDE7FAF5F5F2FC
FCFCFAFAFAFFFAFFF7F7FFF3F3F6FFFFF6FFFFFFFFF6F6FF
FFF6F6FFFFFFF6F6FFFFFFFFFFFFF7FCFBFBFBF4FCFBFCF7
F3FDFAF7F9FDFDFDFFFFFCF9F9FCFBFCFCFBFBFCF7FAF4FD
F6F5FFFCFFEEEDF3F6EDEAE6D7CDC4BCB2B2C4D3E6F0F6F6
F2EDEDE1E2D7DCD7D5E5F9F5FFF6FFF7FAFCF6FBF2EFD6A0
ECF1FCFCF4F5F7F4E6F6F6F3F4F4EEFFEBF1F6EDE73DCDE9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE19A8FF1FDFCF6D3FAFAE6EBF4F4F4F4F4FF
FAE5F0F1F1F2F1EEEAF9E2E2E3E5E4F3E4F6F6F0F5F7F7FF
FCFCFFFAFFFAFAFAFAFAFFF6F6FFF3F6F6FFF6F6FFF6F6FF
FFF6F6FFFFF6F6F6F6FFF6F6FFFFF7FBF6F6FFF6F7F3F4F7
FFF7F6F6F9FDFFFFFFF9F7F9F9F9FFFCFBFBFBF9FFFFFAF6
F6F5FFFDFFFFFAEEF6F3EFEBF2EFE5EAECDDDBE0DFDADED5
CAD1E5E9DBDDE6EAFCF9FCF9F4F9F6FDFFF6FFF6F4EECCB7
FFEFFFFCF3F0F0EBF1EBF4E3F1F6E7F4F4EDFAEEE177768D
CDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFCC82C0E3F7FBF7E1E4FAEBFCF4EFFFFFF4E5
E4F4FAFFFFF4F0F6EAF6E6E7E1E7E2EEEBEBFDF0F5F7F7FC
FCFBFFFAFAFAF7FAFFFFFFFAF5F3FFF3F6FFF6F6FFF6F6FF
FFFFFFFFFFF6F6FFF3F6FFF6FFFFF5FFF9F9F6F4FCF7F7F1
F4FAF2F3FDF7FFF9F7FFF9FCF9F9FBFCFFFFF9FBF6F5FFFF
FFF9F6FDFFFFFFF7F7F1F6F9F5F3F0EBEBEAE7E2DBDBD5D5
DBE4DFD7E3EAEEF7FAF6F1F9FDF5F9F7F9FDFCEEF6E7C2C7
FFEFFFF4F4FBF1EAEAF1E6EBF7ECF4E7E5FAFAF1E0C3B287
93FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA
FAFFFAFAFFFFB37DD8E7F7EEEBF9DFF2F0EEF4F4F4F4FFE1
DEF3F4EFEFF4F0F4E8EDF0E4E8E6E2EAEFF0EBF7F1FDF7FC
FCFBFFFAF7FAFAFAFFFFFFF5F1F6F6F6F6FFFFFFFFF6F6FF
FFFFFFF6F6FFFFFFF3F6F6FFFFFFF5F6F9FCF3F7F7FFFFFB
F3FBF3F1FFF7F9F9FFF7FCF9F9F9F6F9F9F9FDF9FFEFF7F9
F9F7F9FBFFFFFFFAFAF7F7FCFCFCFCF7F1ECE5EEECE6E6E6
EAEAE9EBF3EEFBF9FFFDF6F9FDF5F9FFFDFDF4EFF6DEC8D7
FFEFFFF4F1FFFCF7E9F1F0F6F6EEF3FFECF4FFFFF0D0F6A0
70FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF928FDBFDF7EAF1F6E3F6F9F1FAFAEBF4F1F3
F3EAF4EDEFF4FFF9F3E4F0E2E8DCDCD9F4F1E1FAF1FAFFFF
FCFCFFFAF7FAF7F7FFFFFFF6F3F6F6FFF3F3F6FFFFFFFFFF
FFFFFFF6F6FFFFF6F6FFF6F6FFFFFAFFEDF4FCFCF4FFF7F1
F1FCF9F7F1F9F9F9FDFBFCFFFCFCFAFAF7F9FCFFFBEFF9F9
F9F9F9F4F6FFFFFFF7F7F7F7F6F1EDFBFCFCF0ECECECEEF6
F6EDF3F3F3F9F9F9FFFAFAF9F1F6F9F9F9F9F5ECE7DBCAE1
FFEFFCFBFCFBF6EDFCEEFAFAFCF6FCE8F3EFF4E5F1C4F3B1
5EE2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF71A2E9FBFBF2F7F6E5F9F5F6F7EFE0FFFCF3
F5EFF0F9FAF4EFF1F2F6F1D9FBE8E3D7EDF7DAF4F1F7FFFC
FFFBFCFAFAFAFFFFFAFFFFF6F3F6F6FFF6F6FFF3F6FFFFFF
FFFFFFFFFFF6F6F6F3FFF6F6FFFFFFF7F3F7F7F3FCF4F3FD
F9F9FDF5F9F7FFF7F5FCFBF9FFFFF9F7F9F9F5F6F9F1F7FF
F9FAF7F6F4FDFFFAF9FAF0F5F1EDF7F1F6ECECF6FCFDFFF3
F1F3F9F7F7FAF6F6F7FBF7F9F6FCFCFCF6F3F4ECDED6D0EF
FFF4F0FCFBFAFCEBFFEBFFF9FAF9F5F3F4F4E8EDE9CDF7DE
5EAEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FFFFFFFFFFFF5FB7EAF9F7F7F1EEE3F6F6F2F0ECE5F4EFEF
F6FCEEE7EBF4FFF2DDE5FFD8EAF0D8E9DEF6E2F5F7F6FAFB
FCFBFCFAFAFAFAFAFAFFF6FFF3F6FFF3F6F6F3F6FFF6FFFF
FFFFFFFFFFF6F6F6F3FFF6F6FFFFFAF6FCFFF7FBECF6F7F3
F9F5F7F2FDF9F9FAFAF9FCF9FFF9F9FFFDFDFBFDFAF9F6FD
F9F7FAF4FAFDFFF9FAFAF7FFF1FFEFFAF7F5EFF7FFF9F9FC
FDF7F4FFF4F7F6FCFDF6F9FAFAFAFFF6FCF6ECDFDBD3EEEF
FFF1F1FBF6FCF1F1F6FAF1F6F6FCF9F3F4FCE3EED7D4F3F9
7B7FF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFA
FAFAFFFFFFFF42D5DCEEFAF2F1FDF3EBF6F6F0E7EBFCEDEC
F3FFFFF3F3FFFFF9EEECF1E8EDE4D8D3CCD7D6F5EAF5F1F6
FCFFFFFFFFFAF7FAFFFFF6F6FFFFFFF6F3F3FFF6F6F6FFFF
FFF6F6F6F6FFFFF3FFF6FFF6FFFFF5FFF6F7FFF4F1FFF7FB
FCFAFFFBFBF9F9F7F7FFF9FCFCF7FFFDFAFFF9F9F6F9F9F9
FFF9F9EFF9FFFCFCF9F7F9FAFFF1F3F1FAF5FDFFFFFCFFFC
F7FDF6F3F9F3F3F9FBF7FFFFFAFFF7FBF1E5DCDBDCD1EEF0
F4F3FCFCF5F7E9F5E1DEE9FBFCF5FFEEEFF3EAEECDEDDDF4
9474FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFFFFFFFF2CF3C8E2EFE9F3F9F3E3F3F6F6F9F7EBFBFB
F6F3F4E5E5EFF4FFEBEFF0E8FBEEE2DBDBE8C4F5ECFCF5F5
FCFCFFFFFFFFFAFAFAFAF6F6FFFFF6F6F6F3FFF3F6F6F6F6
F6F6F6F6F6FCF6FFF6F6F6FFFFFAF9FFF6F7FCFCF4FCF6F7
FAFDFAF5F9F9F6F6FFF9F7FDFFF9FFF9F7FFFDFAF4FDFFFD
F7FFF9EEFFF7F5F9F9F7F9FFF7FAF5F1F4F7FDFFFFFDFFFF
F9F9FBFDF9F9F9F9FBFDFAFDF7FFF7F9E8E7F0E0DFE2FAF3
F1F3F3F7F1E6FADCF0F0F7F6F2F6F9FCFCF3F7ECD8F2EFDB
A26FFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF1DF1C8E7F6FFEEFCF5F3F2F6F6F6F7EDFCFC
F0F2EEEFEFF4F4EFFAE4F0EBFCEEF3DCDBE5C6EAEAFCF7F3
FFFBFFFFFFFFFAF7FFFAF6F6F6F6F3F3F3F6FFF3FFFFF6F6
F6FFFFFFF6F0FCFFF6FFFFFFFFFAFAFCFCFCFFF4FCFCF1FD
FDFDF7F4F9F9F6F6FFFFFFF9F9FCF7FFF9FDF6F2F9F6F9F9
F9F9F7F9F5FCF9FCF9FFFFFFF7FAF1FAF6FDFFFFFDFAFDFB
FBF9FFF9FAF9F9FAFAFAFAFDFDF7F6EAEBE8E8D3DFE9FAE0
F0FFF9FAE6F0D5F0F6EFEEFCF7F3F2F5E6EBF7E9E8EFEFDB
AF7AD9F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFF00DDE5EEF6F4EEF6FDF7E3FFF3F6EDF4FFFF
F3F9F3F7F9F4F4F4FFF4EFE3EDFCFCFADCD3BFEAE1FAFAF6
F5F4FCFFFCFCFAF7FAFFFFF6FFFFFFFFFFFFF6FFF6F6FFFF
FFFFFFFFF6F3FFF6FFFFFFFFFFFFF7FFFCF7F6F6FCFFF1F9
F9FDF9F9F9FFF9FFFFF9F9FFFFF9F5F9FFFFF6F2F9F6F9F6
F9FFFFFAF9FAFCF9FCFFFFFFFAFFF1FFF6F7FFF7FAFFFDF9
F9F9FFF9F9FAF5F7FAFAFAFAF5FBF9E6EAF0DEE2EFEEEBEE
F3FFF9EAF1EAD0FFF2F4FAF9F6F0F6F6E2F1F1EEF4FFE1E2
BF8BB8F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFA
FAFFFAFAFFF102F3FCF6FFF1EEF5FDF5ECEBF6F3E4F4FFFF
F4E5F9F7FDFCF4FFF4FFFAD7F0F5E7F0F3D7BAE5DFE1F9FF
FAF7FBFFFCFCFAF7FAFFFFF6F6F6FFFFFFFFF6F6F6FFFFFF
FFFFFFFFF6F6F6F6FFFFFFFFFFFFFAF7FAF3F4FCECF4F6FD
FDF5F9F9FFF7F7FDFDF7F7FFFFFDFDFFF6F6FBFAF4F9F9F9
F9F5F9FBFCFFFCFAFFFFFFFFFFF7F9FAF6FAFDF6F6FDFAFB
F9FCFDF2F6F6FFF7F9F7FAFAF6FFF0EAE8EBD2E8E3E5F0FF
FFF6E7EBF1D9F5F2F6F6F9F6FFFFF9FCF0FFEEF6EDEFDAE4
CE87B6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFA
FAFFFFFFFFEB30D2EBF4F5E6E6F7F9F5F3EBF6F6E3EFF4F4
EFE5F2F2FCFFFCEFFFFFFFD7F2F4FCF4EFE4BDE3F1E3EDFA
F7FFFCFCFFFFFFFAFAFFFFFFFFFFF3F6F6F3F3F6F6FFFFFF
FFFFF6F6F3F6F3FFF6F6F6FFFFFFFFEEF1FFF7F3F3F1F6FB
FDF7F9F9F9F9F9FDFDF7F7FFFDFDF6F6F6F9FDF7F6FDF1F1
F6FAF9FDFCFFFFF9FFFFFFFFF7FDFAF3FFFDFDFDF9FCFDFB
FFFFFFF6F7F6FFF6FBF7FFF6F9F6EAE7E7E8DFEAE7EFFCFC
FFF1F1FFDEEEEEF6F6FFF9FFFFF1EFFFF9F7E6FFEBF4EADF
CC76C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FFFFFAFAFFEB42DEE6FDECEDF5F3FFF7F3F2F6EBE1EEFFFF
F4EFF2F2F3F3F3F4F3F7F7E8E6EEF6F0F1F6BDE0E5EAEEF1
F5FAFFFBFFFFFAFAFAFAFFFFFFFFF3F6F6F3F3FFFFFFFFFF
FFFFF6F6F3F6F3FFF6F6F6FFFFFFFAF1F4FCF3F7F7F3F6FB
FDFFF9F7F9FDFDFFFFF9F9FFFDFDF1F1FBFDFDF7F6FDF1EA
F9F6FFFCFBF9F9FCFFFAFAF7FFFDF7F6F7F7FDFDFCFCFDFD
FDFDF9FCF6F9F7F3FBFAF6F9FDF7EFE6ECF0D7E5F7EFFCFF
EBE1F1E1E1FFF9FCF6FCF2F9F1F9F7F9F9F9F3FCF3F4F9DB
C368D6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFAFAFFD33BF0EAF4E6F5FFFCF5F7FDEAEDF2F2F0F4F4
F4FFE4E5EEF4F4F4F9E5EEF6E1EAEEF0F7F0C6E9D7EEF0F1
F7F5FCFCFFFFF7F6F9FAFAFFFFFFF6F6F3F6F6FFFFFFFFFF
FFFFFFFFF3F3F6F6FFFFFFFAF7F7FFF6FBFCFCFFF3FDFDFA
FAF9F9FFFFFDFDFFF6F6F6F6F6F6F6FDF9FBF6F7FFF7F9F9
F6FAF9F7F7F9F9FFFFF7FAF9F5F5FDFBF7F7FDFFFBFDFDFD
FDFDF9FCF9FFFFFDF5FAF9F7F7EEF1D3E7E2DEF2FAEDDEDE
FFD8D2E7F4F2F2F9FBF6F6FFF7EFEFEFF6F6F3FBFFEFEFD7
8971E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFF
FAFAFFFAFAC93DECEEF6F1FDF9FCF6F7F1F6EBFFFFEEFAFF
F4FFF1E4F3FFF4F4F1F3EEF1F2E6F3E9F0F6CAF1D9EBEFF3
FAF1F6FCFFFFFAF9FCFAFFFAFFFFF6F6F3F6F6FFF6F6FFFF
FFFFFFFFF3F3F6F3F6FFFFF7FFFFFAFCF5F6F4F4F7FAFFF9
F6FDF9F6F6FFF6F6F3F3F6F6F6F9F9FFF9F9F6FFF7FFF7FC
F9FCF9FBF9FCFCFAF7FFF9F9FAF3FBFBFFFFFDF9FAFBF7F7
FCFCF7F4FAF7F7F7FCF9F9F7F9F0EDD4EDEAF4EDF2F6F4E4
EBF3F6F6FCF6F6FFF9F9FFFFF7EEF9E7FFF6F3FBF9EAEAB0
5FBFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFA
FAFFFAFFFAB548F3F3EDF4F6F5FAF9FCF5FFEBF2F6F6F4FA
F4F4EFF4EFF3EFF4F4F4F1D9F6EAECE9E7EDCEF6E0E8E3EE
FAF9F5FCFCFFFFFAFAF7FAFAFFFFF6FFF6F6F6F6FFFFF6FF
F6F6FFFFF6F6F6F3F6FFFFFAF7F7FAF9F3F4EEF6F3F4F7F7
FBFDF9F6F9F6FFFFF6F3F6F3F6FDF6F9F6F9FFF9FFF7F4F5
FDFAF9FBFCF9F9F7FFF7F5FAF5F9FFFFFDFFFDFBF9FBF9FB
FDFDF9F3F6F6FFF6F9F7F2EFF3E7F0E0E4FBF4EDF6F2FAE5
F5FAFAFAFAFCF3F9EDF7FFF4FCEEEFF5F6F9ECF6E4D2DD93
70F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFA
FAFFFAFAFFA561F6E6EBF1FCFDF4F6F9F5FDF4F7F6F3F3F9
F4F4EFFAD9E5F4EFEFF9EED7EDEAE3EFE8F1D4F5F3E9E0F0
EAFAF3FCFFFCFAFFFAFAFAFFFAFAFFF3F6F6FFF6F6F6F6FF
F6F6F6F6FFF6FFF3F6FFFFFAFAFFF7FBFCF7FCF6F6F4F5F7
F6FBF9FFFBF9FDFFF6F6F6FFF5F6F6F6F9FFFAF4F4F9F6FF
F9FFFAF5F6F7F7FAF7FFF7FFFDFDFDFBFBFFFFFDFFFFFCFC
F3F3F6F7FBF6FAFBF6F4FFF5EAFDEFE2E4F1F4F2F4EFEDE4
FCF6F6F9FFF6F6EDFCEDF3F6EBF6F9F9FCF2F0F0EECED37C
8CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFFFAEDBA5DFDFDDFE9FDF1FDFBF5F5FDFDF3F6FFE8F9
FFEFEFFAE2E5F4FFEEFDFDEDEAF9F7E6F5FFD7F1F9EADEF6
EAF7F6F6FFFFF6FAFFFAFAFFFAFAFFF6FFFFF6FFFFFFF6F6
F6F6F6FFF3FFFFF3FFF6FAFFFAFFF7FCFCF3F7F1F6F3F6F5
F9F9F9FFFDF9FDFFFFF3F3F6F9F9F6FFF6FAF9F9FBFFFCFB
FBF9FDEFF6F7F7FAF2F5FDFBF9FFFDFDFFFCF9FCFDFBFDF9
F6F6FAFDF9F3FBF9F5F7F7F1F0FFEFD2E8F1F6F1FFF3EBF6
FBF9F6F7F2FFF4F4F4F6EBEDE7F7F6EFF5FCF3F6F0E9CC6F
A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFA
FAFFFFFAEEC94EF9F5DFE5FDF3FBFAF6F5FFF7EEE6EDF2F0
FFF4FFF4F4F4F4EEFAFBF3F6E1F6FDE2FDF7D8F3F5EFE6EF
EBF4F7F5FBFCFCFFFFF7FAF7FAFFFFFFF3F3F6F6F6F6F6FF
FFFFF6F6F3F6F3FFF6F6FAFAFFFAFAFCFBFCF7F4F9FDFBF6
F9F7FFFFFDF9FFFFFFF6FDF9F6F9F5FFF6FAF7F3FDFDFFFA
F6F3F0FDFCF7FAFFF2F6FDF9FCF9FBF9F9F9F9F7FFFCFDF9
FBF6F6F9FCF3FCF9F2F4F7FDF0F0E8CCF4E7EFFAF3EBF9FA
F3F1FAF6F6FFF4F6F6F7F6E8F6F0F9F2F5FAFCF6E2EDD185
86FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFA
FAFFFFFFF0CE43FDF6E5EBF1ECEEEBF6FDF9F2F9D3EBF6EB
F4F4EFEFFDF9FAFAFAFDF6F6EAF0ECEFFDEDDFF5F3EFECED
F3F0F3F1FCFCFFFFFCF6FAFAF1F6FFF6FFFFF3FFFFF6F6F6
F3F6FFF6F6F3F6FFFFFFFFFFFAFFF9FFFCF7F4FFF9FDFDF7
F7F7F9F9FDFDF3F6F6F5F6F6F6F6F9F6F9F9F9F3FDFDFFF9
F9F2F3FFFCF5FCFAF7F6F9FBF9FDF7FCF9F9F9F9F9F7F9FC
FDF6FFFAF7FCFFF3F2F9F7F7E6F5E3E4ECEEF7FAEDFFFCF7
F6F9F7FAF3F1F6FFF6EEE7FAEAF6FCF6FBF6F5E8F9ECDB88
84FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFF
FAFAFFFFEBC74BE6E4E5F2F6F3E5EEFFF9F9F9F3DDEDF6E6
EBF4F4EFF9FDF7FFF7FFF6F2F6F0E8E7F4F6DFF6F1F1ECE9
F6F6F1F5FAFBFCFCFCFCFFFAF1F6F6FFF6F3FFF3F3F6F6F6
F6F6FFFFFFF3F6FFFFFFFAF7FFFFF9FCF3F1FBFBFDF7F5FF
FFF9F9F9FFF4FDF6F6F9F9FDF3F3F4FDF9F9F9F9FBF9F9FA
F9F9FDFCFFF5FCF9F7FCF6FCF6F5F9FFFDFCFBFFFDF9FFF9
F6FDF7F5F5FCF9F9EFF6E9E3EFEEDBDEEEF2FAFAF1F4FCFA
F9FCF0E6F6F7F5E8E3F0FAF7F2FCFFF6F9F3FBF4F3E0CE6C
A1F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFF
F7F7FFFFF0C356F2E3EBFAE7F6ECF6FDFFFDFDF6F4FFFDE4
EDF4FFEFF7F9F4FAFAFAF6ECE8ECF7DFEDF3DEEDEFE5E8DD
F0F6F0F3F7FCFCFBFFFCFCFFF7FFF6F6FFF3F6F6F3F3F6F6
FFF3F6F6F6F3F6FFFFFFFAFAFAFAF4F1F6F6F9FCFDF5F7FF
F9FFF6F1ECF6F6F0F0F1F5F9FDFDF9F9FFFDFDFDF6FCF7FD
F9F7FDFCFFF7FFF9F9F9FBF9F9F9FBF9F9FDF6F9F9F3FAF9
F9FFF7F6F0F3F5E7DEEAF0EEE2DFEAEAFFEEFAFFFFF0F6FC
F1EBF6F0FFEEFAF6F6FAFAFFF9E3E6F7FCE5DFF0F0BB5B67
D2F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFF
FAFAFFFFF0DB50E5F9EBECF2EBEEF3F9F7FBF9ECF7EBEAED
E7EDFFEFFAF1F5F7F4FAFAE3F0F9F0EAE6EBE8F0F3EBEDE2
EBF0F1F6F1F7FFFCFBFCFBFFFAFAFFFFF6F6F3F6F6F6FFF6
F6F6FFFFFFFFFFFFFAF7F7F6FCFCF7F3F9F9F6F9F9FDFBF5
FFF6F6FBFBFDFFF9F9FBFDF6F3F3FDF9FFFBFBFBFAF9F7F9
FFFCF9F9FFFAF7F5FDFBFFFDFCFCFBF9F9F6F3F6FDF6FAF9
F9FAF6F9FDF2F7EFF0F0EEDFF5E9F2EAF3F6FAFFFAFFF3F0
F0FAF4EBEADEE3EFFAFAF7FAFAE0D9EEF0EEE6E1FC8C64D9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFAFAFFFFFAFA
FAFAFFFFEBDB48F3EEF7EAF6E5FDF1F0ECFDF5ECF7DFEBFF
E8E1FFF4F4EAF6FDF7F7FAF3ECF5F2E4D6F0F0EEECFAE6E6
F3F0E8FAF7F5FFFFFCFBFCFFFFF7FFFFF6F3FFFFF3F3FFF6
F3FFFFFFFFFFFFFFF7FFFFFCFCFBF6F1F4FDF6F9F9FDF6F6
FFF1FBFFFDFDFDF6F6FDFFF6F3F3F6FFFFFDFFF6F9F9FAF9
F9F9F9FBFCF6F9F6F6FDFCFFFFFCFBFBF7F7FDFDFDF6FAF5
F3F3FFF9FAEFF3EAEADFDFF9F3EAF4F4F0FDFAF4F3F3EDF6
FAEBEFE6F6F6F0EFF6EAE3E8F2F3FFEEEEF0D9FCFA607BF1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFAFAFFFAFA
FAFAFAFAF1CE4FE8E9F2F2F6E9F7F9E8E0F5EEF7F7EBFFF6
F6D3FFFFEBF6EEFFF3F5F9F6EAEAF3EDD3F6EEDEE7F3EBE1
EAF3E1FAF7F5F7F7FBFFFFFFFFFAFAFFFFF6FFFFF6F6FFF3
F6FFFFFFFFFFFAF7FAFFFCFCF4F6F7F6F7F6F5F9F3F9F5FF
FFF1F3F6FDF6F6F5F3FDFFF6F3FBFFFFFFFFFDF6F6F9F9FA
F9FDFFFBFCF5F6F6FCFDFDFCFCFCFDFDFDFBF6F7FCF9FAF6
FBF3FBF7F2F6F5EEFDDFF7FFEAFCEFF0EFFAFFEFFCFCFBF1
E7EEEDF5E1F2F4EFF0FFF7F7F4F4F3E8EEE0F3F4E06189FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFF
FFFFFAFAFFD64DEADDF6F2F6E9F6F3E5EAF9ECFAF3F7EBF6
F6D7EEFCEBF6F5F2FFF6EDF2FFE4DCE4D3F4EBE8DFE7F3EB
E6F3DDFFF7F6FDF7F9F6FCFFFFFFFAF7F7F0F0F1F6F6F6FF
FFFFFFFFFFFFF7FFFFFFFCFFF7F3FCF5F7FBF9F9FFFFF1FF
F6FFFFF6FDF6F6F9F6FBFDF6F6FFFDFFFAF7F9F6F6F7FFFF
F9F6FCFFFAFAFAF1F5F9FBF9FCF9FDFCF7FBF3F9F9F9F9F9
FCF2F9F9EFF6FAEAE5EBF9EAE7EDEAF5F7FAFFF4F1FFF6F5
F6FCF3F0FAEAF4EAF1F5F9F7FCFCFFEFF9ECFCEED8628FF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFFFFFFD65DE2E6F4F6F2E4FCFDF1F4E8F6F7F6F7F3F6
F2EBE1F3F3E1FFFFF6F2F6EEF4F2DDF3ECECF5F6DCE7EDE3
ECF0D9FFFAF7F5FFFAFAFBFFFFFFFFFFFAF7FAF7FFFFFFFA
F7F7F7FAFFFFF5FCFFFCFCFCFCFCF4FAFAFBFAFDF9FAF1F6
F6F3F3FDFBFBFBFDFFFDFDFDF9FDFDF9FBF9F9F6FBF9FFFF
FAF9F9F7F4F9F9F9FFF9FCF6F9F9F9F9FDFFF9F7F9F9F9F5
F6F0FAF0EEE7E3DDE6FBE6F3F4F6F6F4EDEBEFEFF4FCF6F5
F3F5FFFAF0F0EAF4E8FBEAFCFFF7F3F9F9F0F1E4E54AB0F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFAFFFF
FAFAFAFAFFD675C0E5F2FFF3E9F2F6F7E4EBFFFDF4F7F7EB
F6F6EEEBFCEEE4FAFAE7F6E5F6F0F1EFFCF2ECF6DCE4FCDA
E8F0D9FFFAFFF1F4FFFFFCFCFFFCFCFFF7FAFFFFF7FAFAFA
FFFFFFFAF5F3FAFCFFFCFCFCF3F6F7F9F6FCF9FAFDF9F6F6
F6F4F6FBFDFBFDFFFDFDFFFBFBFAF9FDFDFDFAF9F6FFFFFF
FFFCF7F0FDF9F9F9F6F9FBFAF9F9F9F9FAF9FAFAFAF7F7F6
F9F7F1F1EDEDF6ECE7E5EAFFF4F6F0F0EFFFFFF3EEF3FCF0
EFF7FAFAFAFAF2F4FFF0EFFCF4FCF3F6F0F3EBE5EA1BDBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFAFF
FFFFFAFAFFEB65C7E5E9FFF6F6E6EBF6E6FFEEF7F7F7F3F7
F6FFEBD3EBF4F3E1FFFAEBF3E0F0F6E7F3EDF6F0DCCFEBE8
E1DEE0F0F7FAF9F7F4FFFFFBFCFCFBFCF6FAFAF6FBF6FAFC
FBFBFCFCFCFCF7F3FCFCFBFCF7FCEFFAF6FCFCFBF6F9FFF6
F0F9FDFAF9FAFBFFFDFDFFF9F9FDFFF9F6FAFDF6F5F7FAFF
FCFFFAF5F9FAF4F9F9F9FFF9F9FFFFFCF3FAF7F5F3FBFBF9
F1E7EEFAECF4E6D7D5E9FAEFF4F6EFF4F4FFFCF6F3FCFAF0
ECF3F5F7FAEDF1FCF2F9F5F4F7F6EEF6EAE2D9EA9D3EF7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFFFAFAFF52D1EAE3EFF0F3DADFF6EDE4DCF7ECE4EBEB
F6F6EBE6E6FCF1F3E5FAF2E1FAEBFFF4DDF2FAFBF0EBD7E1
EDDAE1E6F4FAF7F1FCF7FFFCFCFFFCFFFCFCFBFCFFFBFCFC
F7F7FCFCFCFCF3F7FCFCFFF7F7F1FCF9F7FBFBF9F6FFF4F0
FFFFFBFBFDFDFDFBFBFFF9F4F4FBF9FAF9FAFDF1FCF7F9F6
F7F7FAFAFAF7F7FDFBFFF9FBF9FFFFFCF3F7FAF6F0FBFBF7
F7EBFCF0E7E8F4F3E7F1E8F3F0EFEEF1F3EEF6FFF6F9F9F6
FCFBFCFCF6E7ECFAEEF2F9F1F4F5E8F2DDF1F3D159AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFAFAFF
FAFAFFFAFAFF52E0E6E6F2F0F3DAE6F6F4DBEDF4DADAE5E5
FFF6FFF7C6E8F4F4F4E4F6EEF6EBF3F6E9F3F6FDFDE7EBDF
FADEE2E5E6EAEAF0FDFDFAF7F7FFF7F4FCFCFCFFFFFBFCFB
F3F6FCFCFCF3F3FAF7F7F7FFFCFCF3FDFDFFFDF7F4F4EFFB
FAFFF9FAFDF3F6FBFBFDFDF6FBF9F9FCFCFBF9FCF5F9F4FA
FFF9F4F6F9F4F7FDFDFFFBF9FBF9F9FCF7F6FBF4F5F7F7F4
F5E1EAE7E8F4F7EFE2F1EEF3F0FFEFFBF3FFF6F3FFFAFAF6
FFFFFFFCFCFFF7FAF6E4F4F6F3F1EEEBE4FCF49168EBFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFAFAFF
FFFFFFFFFFFF4AE8F5E3E4F6F6E6F7EBFFE4FDEFE0ECDAF6
EBF2F6EDD1FDF1F4EFF3F0EAEEF6EBFFE9E3F9FCEDDDE7DD
F3E6E3EFF5F3F9F0F6F4F4F9F5FAFDF7FCFBFCFFFFFCFBFC
FCFFFCFBFCF4F9F3F4F1F7FAF4F3F3F9F5F5F7F9F1F6F6F9
FDFBF9F0F1F9F9F1EFF1F3FDF7FFFBFCFFFBF7F6F5FCF9FF
FFF9F4F5FDF9FFFDF9F9FDF3F3F7F5F6F6F3FDF5FFF9F9F2
E7EAFAEDF5F3E7EEE7F6F3F0F4EFF4F3F0F9FFFCFAFFFCFA
FAF7FAFFFFFFFAF7FAEAF7EBEDEEEBE0F6F6D66F98FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFAFAFFFFFFFF
FFFFFFFFFFFF63C1F4DFD4FFFFF3F7EBF2EBFDF1EBFAE0E8
EEEDEDF6FAE2FCF3F7F0F2F0F1F1E5EDF1EAEEFAEEF2E2E4
EDE1D7E4E8E2F1EAFAF9F6F6F6F9F9F5FAFFFFFFFFF7F7FC
FCFCFBFCF6F6F1F4F4F5F3F6F1F5F7F5FFFFFFFFEEF9F9F3
F6F4F6F5FFF9FBF5F5FBFCF3F2F7F9FBFBFCF7FCFFFAF4F9
FFFFFAF7F9FCFBFDF6F9F6FAF5F6F3FCF6FCFBF4F7F2F7ED
F3F0FAEDEEF0F0FFEFF3ECF0EFFFFFEEF9F9FFF6F6FAF9F7
F9F5FAFAF7F7EFEAE3E6F4FBF6E7E2E4F4F3C765C1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFF
FFFFFFFFFFFF909EF6EBE1E5F6F6EAF4F7F7F7F6F7F5ECDD
F1EBF3E8E8E6E9EBEDEFF9EAF6EEF4F0F2F2DEF6F9F5F4D2
E8ECDEE8FBEDF0F0EAFAFAF1F7FDFFF7FAFCF6F5F5FCF6F7
F1F2F5F5FDFDFDF7F1F9FDFBF5F1F0F9FFFFFFF6F0FAFAED
F4F3F3F5FCF2FCF5FAF7F7F3FBFAFBFAFFFCF9FCFFFFF9FD
F6FCFFFFF6F9FFF9F9FDF2F3F0F4F7F3F9FBF9F4F0F0F3ED
F0E3E6E3EEF0F3F4E8F0FDFFF4F4FCF0FFF9F7F0F6FFFFF6
F6FCF0F4F6F2EDF1F3FBFCFFF3E1DDFAF6DBBB60D1F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAD85F5E8D9EDF6F6E4F4F7F6EDF1F7F5F3DC
EEEBF7DAECF6E2EEEDF4EFEAEEF6F6F6E4EDDBF9FCF1F3F3
DFD8DBDEFDF4EEFFEFF6FAF0F0F7F5F0FFF6FCFAFAF6F4FC
EEF9F9F5FDF4F1F0F5FFF7F7F9FDF7FBFBFDF6F1FFFFF7F1
FCF6F6F3FCF6EDF5FDFDFCF4F6F9F2FBF6F9F5F9F9FAF7F9
F9F0F6F5F9F9FBF9FBFFF5F9F6FCF6FBFBFFFFF2F9FBF7EC
EEDFEFFFEAEAFFEFEEFBFFFFF4F4F3F6F9F9FFF9F7F4F9FC
F9F5E6EDEDF1F3FCFFFFFFFFEDD7E8EFF0E69573F1F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFA
FAFFFFFFFFFFCA6EE8D9DAF0F0F6EBFFF3EDFFF3F6E5EEEE
E0F2EDE6ECE0E9F1EAF3EDF9F0FDEDF5F1CEEED9EBF1F0EA
E9E7D6CBCEDEE9ECF0E4DEEEF5F9FAF7EFFFFFF7F7F3F7F4
F6F3FCF6FAF9F6F9F7FBF6F6F6F9FDFCFAF0EDF9F5E9EAEE
F6F6F3F0F6FBF4ECF4F4F3F6FFFFEDF2F0F0F6F5F5FAFAFF
F6FAF7FCF6F6F4F7F7F1F5F5F5F3F9F3F5F0E3E5E5E2E0E6
F6E6EEE9DFEFEFF4ECF1EFEFF1F3F6FCF7F7F7FFF6F2F6FF
FCFCEBFFF4FCFFFFFFFFFCF3ECDEFAF6FDD46297F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFA
FAFFFFFFFFFFEE7EADEDF0F7F4EBF2F3FFF3F2EBF3EAFAF6
EEF6F2F2E1F3EDFAFAEDF3F5F2FFFDF4EEEAD1F6EBEEF9FB
F4E4E6EAE1DCE3E5ECFDF0F9F5ECE6F5FAF0F5FFFAF9FDFF
F7F7FFFFFDFBF7F7FAF5F2F2F5F7F7F9F9F1EDEFF6F9F9F9
F9FDFDF9F9FAF9F9F7F9FFF9F9F9FCF9F9F9F9FDF6F6F0F6
FBF9FFF7FFFDFDFDF6FBF9FBFBFCF9FAF9F0F6F4F4FFF6F6
FFDCF3F3EFFFF3EEE5F4F4F4FBF6FAF6FFF1F1F4FFF2F2F2
F2F6EBF7FBFCFCFFFFFFF3EDE1E8FAEEF29F51DBF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFFF9B9FE6EAFFFBEBF6F3FFF7EBF2FFF3F3F1
F6E6EDFFE6EBFCF4F3F3F4F9F6F6FFEBFFF6F0D5FAE5F0F3
F6F2E2EBE7DED7D6DFECEEE6E8F1F0ECEEF6FAF7FAF5F3FA
F7F7F9FDFFFAFAFFFFFAF3FDF7F7F9F6F6EFECF9F5FAF7F7
FFF7F7F9F7FAFFFFFFF9F7F7F7FAF9FFF7F9F7F7F0F7F6F6
FBFFF9F9F6F9F9F6FFFDFFFFFDF9F1F7F6F2FFECFFFFF6F6
F4EAE9FFEFF6F3FFEBFFF4EBF9FFF3F9F9F9FFF4F6F7F7FF
F4E8E6FCFCFCFCFFFFFCEBF0E6F4EDF6FC5B79F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFF
FFFFFFFFFFFFF7B28CD9EAF4FBF3FDF5FDFDEBFFF6FAECF3
F7E6F6F2E5EDF4F4FFF6DFF9FAF1F2F7F7F7EDEAD0FDE3DC
F3FDF0DDDCE2E2EAD8D3D7E3E8E3E4E9E8EFE8E5EDF9F7FA
F6F5F5F3F1F5F9F7FAF9EDF4F7F7FBFFF9EEF4EFF7EBF6F6
F5F9F7F5FBF6F6F6F6FDFFFFF4EFF5FCFBF9F7F9F5FDF9FD
F6F7F7F6FFFDFDFFFDF7F6F6F7FAF5FBFAEAECF0FFF6E8E4
E5E6EAF4F4F0FAF1F1F3F3FAFBF5F0F7EFEFF9FFFFF7FCF4
F4F6EDFBFFFFFFFFFFF3ECE7F1F3EEEBB72FCCF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7D390BAECF0F0ECF4F7F6FFF4EBECF9EDFD
EEEFEEEDEBEDF3FBEDEBF6D5DDF6E7F2EDF7F6E8E6C3DBF4
E6EBF4F7EEF0EBE0DCD9DCDFE3F3EDF0ECF3EDEBDEDDE3EA
ECF3FBECEEF6F6F0F0F0F6F6F0F6FDF9F4E7EEDEE2EAEAEE
F3F3EBECEEF3F6FFFFF6FFFFFDF6F5F1F3F7F6FDFFF9FFF9
F5F9F9F9F6FFFCFCFDF6FAF5F9F9F5FBFAEFF4FDEEDEE3F6
FFEEF4EEF2F0F1F4FFF3FCF2EDF6F4FFF3F6F7FFF6F2EAF4
F7F7FFFBFFFFFFFFFCE8EDE3F3EEEDFB5363F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEEA59BE9F6E8EAFFF4F5FBF4F3F4FAFAEB
F4F3E8F6F6EFF1F1EBFFEDCDEDDDE8FFF6EBF6F6E7FFD5E0
F6E7DFFFECF3FDF4E8E9E7F6E4E7F1E8D8F7E5EDF7F7F6E9
EEF7EAEFF0F7F4EFEFF3F5F5F9F6EFEEEDE5ECE4F1EAE6E6
E2EAF3F4F6F6FAF6FFFBE7E9F9F5F9F3EAF0F5F5F9F9FFFD
F9FAFDF6F6FFF6F1F3F6F7FAF5F5F2F4FBE7E9E7EAEEFCF4
EBF2EFF4F6FDEFF9F9F6E4EDF9FFF9FFF6F3F7FFF6F6F6F6
F3FFFCFCFFFFFFFFF3E6E5FFEEEFEFCB28B4F3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFBF84E6F5ECEFF2F6EBFDF6F3F7FFFDEF
F7E7F6F6FDF3F4EBF1EDFCFAD0E4E6D7EBF2EBFFF7DFEAF4
E0E6FADFE4E7F0FFFDE9E7F1F3E5F4FFDFE2EDEDEBF3E8EB
E2E0E2E9EEE9E4EAF9F9F4E6F4F6F5F4E5ECE1E6F9F7F3F0
FBF6EAECF6F9FAF9F3F4F7F5F3F4FAFBF9FAFBF6FDF6F6F9
FFFAF9F5F3F3F7F6F6FAFAF9F6FBF9EDECE6F1F1FDF5FCEE
EAFAF4EEFAF4F4F9F9F0F3EDFCF9F9FFFFFFF7F3F7F6F2ED
F7FFFBFFFFFFFFF4E4E1F0EBF4FFFAA03AEBF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD780C8F7F1E8EBF6F3F7F7F7E9F3FDF6
ECE7FFF2F0F3ECF1F0FFF1FCF9D3CAEBE7E0F3EDF3F3FDFB
FDF7ECEFFCFAEAF0F9F0E4F2FFE8E5FDEAEDF2F2D9E4E8DF
E0EBF9F4E8E9F3EBF1EEF3E9F9FFE4E3F1F1E9F3EDEDEAE4
E8EEF7F6F3E9F0F9F7EDF2FAF9F9FFFDFBFFFBF0F3FDFDF5
F1F9F9FDFFF6F6F6FDF5F5F6F4F5FDF0EEEEEFFDF7F1F9F3
FFE5ECF0FFF4EFF4F3F4FDFCFFFCF7FFFFFFF3FFF7F7FFF3
FCFBFCFFFFFFFCE8ECEDF4FFF4EFD27172FAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEE9B8DD7EDECE9FFF6F7EEF7E9F3F6F2
E5FFECEDE3ECF1F7EEF0FBEBEAE2FADCCDCDFFE3EEF4F6EB
EBF3F7FBF3EAEAF0F9F7EEE3E4EED9EADDCFD9E3E9E8EBF1
D2C1D1DACECFDEDADAEEF6E6D5D6D0D3CDD6DEDDE0F1F6FB
F6F3E7DFE7EAE7ECECF9F9F3F1F6F9F9F9F7F9F9F0E6DFE8
F3ECECF3F3F6F6EBEFEDEDF3EAEFE6DDF0EAF9F3F0E8E6E8
E5E5F1F4F4F4FFEDFCF3F9F7F6F6F9FFF7F3F7FCFBF3EFF3
FCFFFFFFFFFFEAD9E8FFFFFFEFDC8054BEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD87EDAE6EAEEEEFFF6F5FFF3F6FFF6
F2E0ECF7DCE8F3FAF7EBF0F3F0FDF2F2F2E8E8F3EBF3EDE2
EAF7F3EEF4E8F7F6F6F6FCFBFBE6F0E6E7F6FFF0EAE8E8E7
EDFAF0F0EAEDE6E1EAE1FDF0F3EAE5EFF0F6F6F5F5E6DAE5
E5E2E8ECEEF6F0ECECEDF7F3F3F3F1F1F6F6F1EFF6FDF6FF
EBEEF5F3EEEEF6F5F9F7F9F6ECFFF3F7E8DFF1F3F0F0F3F3
EEF1FFFFF4F2EAF3F6F6F9F9F9F9FFFFF3FFFFFBFFFFFFFF
FFFFFFFFFFFCD2EBF1FCFFF4F4A56CA3FAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFA86B5EADFF6F3F6F6F5FDF1F6F0EE
F6D8F3F3EAECF1EBFFEBF1F4E4F3FFFAFAF0F1F6EAF3F3F6
FDF6EEF3ECECF6F6F5F5FCF6F0F2F0F6F6F5F1FAFAEFEFF5
F9FFFAF0F0FFF6E3EED5D7EEE8E8E3EAFCEAF5F7F6EEF7F1
F0F9F7F1E1E4FBF6F5EAEFF3F3F5F9FBF6F6FDFDFBFDF6F6
F3F6F1EFF5F5EBEBEFEFF3F0F0F6EEEEF0F4E7E0EAFAF3F3
ECF4F4EFFFF9F9FFEEFCF9F9FFF6F4F5F4FCFCFFFCFFFFFF
FFFFFFFFFFF3CEF4F3F3F1FCEB746FE2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFB797E2CFF6F5FDFFF7F4F6F3EFF0
F0E0EDE5EEEEEBFFEBF6F1F3EEEBF6E8EAEEF4FDE9EEFCFC
F7F4F0ECF0EFF5F6EEF5F9F9EEF2EDE8F0FCF7E8EAEAEAE9
E9EAE6E6F3F3E8D7F0F0E3CFDCE3FFF1E5F4EBF9FBFBF0FF
FCF6F9F9FCD9E9EEF7F2F5EEF0F3EEEAF0F6F6F7EFEFEDEF
F3FBFDFFF6F6FDFDF6ECECF3F3EEE8F7F5F3F1F4FFF3EEEE
F0FFF4F4F9F3F3FCE9F6F4FFF7EDF4F5F4FCFBFCFCFFFFFF
FFFFFFFFF4E4E8F4F4F3FCEDE839A5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFD79EC0C8EDEAF6FFFFF7F7EBFAEF
F2F3E6F0E8F6F0F1F6EBFFF5FFEBEBEEF3F4F1FFECEEE4E4
E5F7E6FDF6F7F9EBE3F0FBF9EEDAF3E8F0F0F1FBF7E7E7FC
EAE3F6F3EFEAF0E7E6ECECECE6EEEEEEEDE2EDF6EAEAF1F3
F3F3E8EAF1E8E8E8E6E9F0FDF3F0F7F7F3E6E6EAF0ECE6F3
F6F6F3F3F6F6F3F3F6F7F9EBF1ECF0F7EAF3FFEFFFEEFDFB
FDF4F1F3F2FDF6F6ECF9F9FFF3F7F7F4F3FBFCFFFFFFFFFF
FFFFFFF4EAE1F4EEFAF0F1EEC924DBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEEBE9DB6EEF3F1FDFDFFF3F3F2F2
FAFAF5F6E3F6EEF3F0E8F9F6F6F2EBFFF3F9F9F3F7ECECF3
F4E8F5E6F6F0EAF9F2FFFDF0FFE6EAF0E7F3E7E4EAEAEAE6
D3E7F7F0E6F0FAF0F0E8F4F4F1EAF0F9EDF0F9FDE7F2F3F3
F6F3FFE8E5FCF9F9F1F0ECE0F0F9F7ECECF7F7EEE6E6EDED
E8EEECEAEAE8EEF3F3EEF1F7E6E7FDF0F3F4E5E5ECF0FDFF
FAEBFBF3FFF6F5F6F9F5F7F9F1F3FCFFF3FCFCFCFFFFFFFF
FFFFFCF1EBE8F1F9E5FAE2F1964BFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE4A8A4D8FFF4F9FDFFF3F7EDFF
F0FDFDEBE7F2F3EDEDECF7F6F6FFEDEBECF5F3EFF0EEF7F7
EEEEECEEE4DBD3D7E6F9FBEFE0E6EAEAF2F6E6F9F5F6F3DF
D8EDE1F6EAEEECE9E9EAF3F3F0FBF9F6F4FAF2ECEAF5F3F1
F0F9FBF3F6E6F0F3FCF0F1F5E4DEDEE8EDEDE5E4E8ECF1F7
F4E6F7F9E7E4DDE1E8F3F6F7F7F3EDE9F4F4F3F3FBFDFDF4
EEE5FBF6F6F9F6FCF6E7F7F9F1F7F1F6F4FCFCFCFFFFFFFF
FFFCF4E8E1FCF1E8FCDFF1F66283FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFEDBD8EB8DEF7F1FFFFF7F7F7ED
FDF2F9F4FFE5EBE6F0F3EDE6E8E8EEE5E5F6F9EFE6EEEFE7
F5F7ECFFF1F7F1EBEDFFF7EBEDEAF2E7EAEFE5FDF3F4F1F3
DFEFFAE8EAEFDED9E7FCEAEAECFCE7D9D7E7FAF3F3F9E5E4
EEE8EAF4EFF2EAE5E0E2E0E0E6EEEAE5E0DBE4EAECF0EEE4
E1DFD7D7E5F4F4E2DCD6D4E5E0DCE6DFEBF2ECE5EDEBEBF4
F3F4FBF5F0F9F9F9F6F7F2F6F7F7F7F6FCFCFCFFFFFFFFFF
F4E8E3F0F0F9F7FFE1E7EF7235C0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFAE391D5CCF0F4F3F7F6EBFFF9
ECEEFAF7E7EEEEF6EDE4EDDBF4EAE5ECF3FFFFF6ECEEF0EA
FDF3E5ECFDEDEDEFF0FAF6E0F0E8EAEAF2F3EAF3F1F6EAF1
EBF4F1F1F4FDE8F0E4F3EAF4DFE8F3EBF0DCDBF1FDF6E8F6
EEF2F0E6F1EFEFEEF3F3F3F4FFF4F3EAEAF3EFF3F3EFEFEF
EFF4FFF9F9EFE5F9F9F3EEE7F2FFFFF0F7F6F1F4FFFCFCF3
F6FCF0F6F9FFFFF4F9F6FBF4FFF7F3F3FCFFFCFCFCFFFFF4
EAEDFAFFF1FAF5EBF9F7AB4BBFF7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE69FCED6DBFDF6F9F4F7EDFD
ECF6E7FFF4ECF3F7F6F3F6EBE5E1DFECFFF6F9ECEDF6ECF3
F3E8E4E3F6F6FDF7EDD0E1DAF7F6EAFFFFFFEAF6FFF6F6F6
EBF6F6EAF9F4E9F4EECFF4E9F3FAF9F6E5E8F4EEF0F6F6F0
FAFAFDFDF6EFFDFBF0F3F3E5E5E8F4EEEEFFFFFFFFF9F9F0
F0FFF9F0EFE5F4FFEEF3FDFCF0F0F3FFF0FFF3EEFCFCFFF3
FCF3F3EFFFFFFFF4F4F9F7F1F7F1FBFFFFFCFFFCFCFFFFE7
E7F5FBF0FFEBE6DED9BA6389FAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEABBADD8D2F1F4F9F9EBEBF7
F5E8F2EFF7F5FDF7F3EDF2F6EDC9EAFFF6FFEEE4F4ECEDEE
F6F6FDEBEAFBFAFDEECACAE8E6EBF9F9F9F7DFF2F6F2FFF2
EBEDE8DFFDF3EDF6DFEDDCF3FDF7FDF2E8EBF9F9EEEEEEF6
F7F4EDF7F7FAFFFFFFF4F1FBFBF0F0E7F3EAF0FFF0EEEEF0
F0EEF4F5FDFBF0F3FDFBF9F9FDF0F0F0F0F4EBEBFFFFF3F6
F6FCF6EFF3F3F3F1FCF3F7F7F7F4F3FCFBFFFFFFFFFFFCDF
F3F6F4F1EDF9E0D5F4846ED8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFACCBAC6C7D3FBF3F3EBFFEE
FDEDF6EBFFFFF5F6EDE4ECEDEEEADCEEF0E7F1EBF0ECEDF1
E8D5D5E6EEFAF3EEF0E0D3F6EAEEF9FDEEF9D9E4FDF6F2F6
F0F3ECECF6F3FFE3F6E3DEEAF6F6EBE8F6F6F6F6F7FAFFFF
F7F3FFF4F4F4FFFFFFEFF4F4F4EDDCEDF0F4F0EEF4FAFFFF
FDF1EEFDFDFFF4F1FDFFF4F4FFFFF4F4FFEFFFF3F3FBF6FF
F3F0EEF7EBF7FFF3F6F3FCF1F3F7F1FBFCFFFFFFFFF4E8E4
FFF4F1EBEAF0EDD7C74FBCF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD6C6CAE4C4F0F6F6F3F6F6
F7FFEAF3EDEDFFFAE5F7EEF1DDD7FDD5C9E8EBF1F6F3F3EC
E6DADAE8EDF6F0F4E8FCD4F4F5F9F7F4EAE9EBF1F0F2F6FF
F0FDFDF4E1F6ECDAE1E6F6DAF7F2F6EDEEEFF7F7EBF1F7F7
F4EFF4F3F3F4F4F4EFFFF3EDEFFCEEEEF3FFF4FAF7FAFFFF
F4FFF4F4F4FFF4F4FFF4F4EFF4EFF4F3EDF4F3F9F9F0F3F6
FCF6F6F2ECF7FCF1FFF7FCF7F6FFF3FFFCFCFFFFF4F4EEF9
F4EBF0EAEBF6CE957B88FAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE2CFBAD3B2D9FDF4F9F6F7
FFECEEF2E1F1FAF6EDE5F4F3F6EECBC6FFDBE4EEF7FFF7EE
EBDFD9E0F6FDFBFDE1E5E2F1F5F7FBF0F6F6F2F2F2F6F3F4
EEFCF6E3CFE4F6F0F6F0E3E7E4F6F1F0FAFFFFFAF6F6EFEB
F4FCFBFFFFFCF4FFF4F4F3F4FCF1FFF1F4EDF1EFEFEFEDF1
EFF3F1EFF4F4F4EFF4F4F4F4F4FFF3F6FCFFF3FDF9FFF1EF
F6FFF6F6ECF7FBEFFFF3F6F6F7FCF1F4FCFCFFF4F4F0F0F1
EBF1E5FCE8ED868D9DD3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEBD3C1D0CBD3DEF1FDF6F9
FDECEEE8F0F9F9ECFAEED9D9F0F0FDE6CFC4F0DBDBEEF1F5
DAC6C0D3F6F3EFF7E4CDE2E9F6EEECEEF6FFF3F0F6ECF3EC
DCF3EEE4E7F6E6F0EAE7EDFAEFE5EBFFEBEBFFF0F1FAF5FB
FBFCFFFCFCFCFBF0F3FCFCFCEDEFFCFCF4FCF3F4F4F4F0F1
E7F1F6F3F3ECECF3FFF4E8F6FCFCF6F6F3F3FCF3F6F9F5FF
EEECECECF6F1FCF3F1E8F6F6FCF4F1F3FFF4EFE4EAF6F9F4
DBE8E9ECF49D318BD3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEAD6B4B4E4D9E5F3F6F6
F5EDF3ECD8E5E8EEF6F0F6C2DFE7F0FFF0EFE4D2F9DFDFE2
F3EDE8E7E7E8FFF7EEBEEAEBF6F6FFFFF2EDE9F0F6F3F3F3
D1F2E6EEE6D0D8FCF0FFF7EAE5ECF6FAEBFAF0F1FAF3F6FF
FAFAFFF6F5FAFFFFFCFFFFFCF4F1F3F3FFF4F4EFF3FFF9F6
F3E8F1EEF1F3F6E8F3F4E9FAF6FBF6F5F9F6F3FBF5F6EEE6
EBFFFFF7FFF1FBF4F3FCF3FFF4FFFCFFF3EAEEF0FFF9E5E9
F6E1FAF9BA44A0EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD9DDA9ADC6D0EBFFED
F7F3FFEDE2F4F6F6F5EAE7EEE4E4ECF3F6FFFFE8D2CFD0E3
ECC6BCCED5E6FDF6FBC3E1EAF6FFF6F6F3EDEDEDEDFFF6ED
D2F4F7E0E0D8F6E1F0EBF6F0F6E8FAFAFFEBF6F9FBFFFCFC
FAFFF5FFFAF6F5F6FFF9F9FCFBFFF0F0FCFFFFEEE6F3F3EE
F5FCF6F3F6F3FFF6F3FBFAF6F3FAF2F9F2F9F3FCF7FCF5F7
F6F1FFF7FFF1FCF7F3FFFFF4FFEFF4F3EDF0FFF7F9EBFCF7
E8F4EFB29060DEF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBE1EEB8B1B1F5F6F6
F3F7F3FDFDEAFDF6F7F5F6F0F6E7E1ECEEF3F6FFFFF6FFEE
F1EFEFF5EBF2F6F6F9CDEEF6F2F2F6F6EDF5F7F7F0F2F6F6
E0FAFAEBFDFCE6D9F0F1EEF7EDFCE6F0F7F6F1FCFCFAF6FC
FFF7FCF9F6FCFFFAF6FAFFF7FAFBF0FAF3FBFBF6FCF3EDEB
EFF7F6F9F0FFF6FFF0FCFBF0FFF2F2F9F6F6EFFFF5FFFAF9
FCF4F7FCF4F4F1F7FBFFFFFFEFFFF0E8F0FFFAF6E5FCE5EB
F4FDD78E73ACFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBE6E0B28CE8F3F6
F9F7F7EEFAFAEBF6F2F6F9ECE5D6E6F9F4EBE4EEF0F0F3F1
EEE2E8F7E8F6EBE9EAD6EDFAFAEBF6FDF2EBFFF4F0F6F6FD
F1F1FAFAF4EEDED6F1EBF6F5F4E6F7F5F0FAF1F1FFFAF6EF
F7FAFAFAFCFCF9F4F0FAFAF7F6FFF9F2F0F6FFFCF3FAE7F9
E7FAF9F0F9F3F6F6F3F6FCF0FCF6F0F4F6FFF0EFF9F9F4F4
F2F6F4F4F4F1F1F3FCFFFFFCF1FFF2FAFFF6F6E5F3E9F0E8
E5DF9658ACF1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAE8E8DC73E8DDFD
F0EBF7EEFAF4E5F0F6F6F9F0EEECF6E8F4F9FAE2C7DCFFEA
E9FFEBD8E4F2F3EDF6E1F3FAFAF1EAF6F2EBFFFFE3E8F4F0
F6EBFFFFF4EAE4DEF0FCF1FBF7F0F1FFF1E6F1F0F5F7F4FF
F6FFFAFAF6F9F4FFF6EFFFFFFCFCF6F5FFF0F6FFFAF6F6EA
E9E8E6FAF6EFF0F5F9EBFBF3FCFBF2FFF6F2F6F6EBF3FFFF
F4F4EFFCF3F1F3FFFFFFFCF4F7F9F6FAFAEBD7F1E7D6E6F7
E0C15B9CF1F1EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEED7F582CED1ED
F6EBF3F7F7ECF4E5F2F9EEF1F0E7D8E5FFEDE2DBFAE2D5E2
E2DED9E3DDF0F2F6F6E4EFF4FFF7F6EDF6EBFFFFE3ECF9E6
F3DFF1FFF2E2F3F4E8EDF0FAF6F0E0F0FAF4E1F1F6F7FAF6
FFF6FFFFF6F9F4FFF7E8EFF5F3F6F6F6F4F9EFEAEEF9FCEB
F6D6F3F4F0F6EFFCF0F2F7FAF6F4F6FFF6F2F6FFF7F7F4F4
F4F4F1FFF1F7F3FFFFF4E8EEF4F6FCF6F2E8EBEBF4E3D5DB
BE737DFFF1F1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBD893DDD3E8
EAFFF6FDFFEEEEF1E8FDEDFDE2F0F6EFEFF6FFF1E2DEF9F0
F6EEE9F3D7F3F6F6F6E7F4F4F4EEF7EEFFEBFFFFF0EFF4F0
E8E4F1E8F3EEF6D9E4FAF5F3FFF9F2FFF6F6F4F6FCFCF6FA
F2F6F6F6F6F6F9FFF7F7F2FCF6FCFAFAEEFFFFFFF9F6FCFC
E9EAF0EEFFEEF9F0F9FFF6F6F2FFFFFFF7F7FFFFF7F3F6F7
F1F1F3FFF6F4FCFFF4EAF6FCFCF6F2EBDFF6F3F4E7F3F1AA
8777DCEBF7F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAE482CAD2D6
E4E5FDF4F3F7ECD8F5EEFDEAE8F6EEF4EDE0ECFFF4F4EAFD
F0E1CFC5D3E7F6E4F6E7EFF1E7E8EFE2E5F1FAFFF7F7FFF7
F7EFDAFFECEEE5EAF5EBF0F7F0F0F4EFF4F6F6FAFAF9F9F7
F6F6F6F6F6F6FFFFFFF6FFF2F0FAFAF7F6EEF3F7FFF9F4F2
F0F7F4FFEEFFEAFAF2F9F4F6FFF0F4F7F4F4F7F4F3FBFBFC
FCFCFFFCF6EAE1E1E8F6F6F2F6F5DCF0F1E6FBF1D9B2A464
6AD2EBFFF0FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFACA3CFD8
E1DFE5F7EDF6EAF6ECFAEEEBF0FAFAFFFFFAEFDDEDFAF0E6
ECF3FFEFFFF2E2E3F6E5EDEDF3F6FCF3DAF2FAF4F3F3FAF4
F3F2F9D4F9E1F0F0EBF5F1EAF0E8E6FAF7F2F2FFF7FAFAF7
F6F6FFFFFFFFF6F2F6F2F2FFF6F2F4F7FAF7EBF7FFFFFFF6
F6FFFFF6F6F0EEE7E8FFFFF3EDF0FCF7FBFCF4F3FFFFFFFF
FFFFF4E7E8F6F4F3FAF6F6F6E7F5EEFAFFF1EED8D8CFE866
D8F1F1F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBAEADDA
EBE4E4EDEBFDF6F7F0E1FAE4EDF6F3F3FFFAEFE4F5F3E4EB
E7E6EAE4F1EFE6E5F6E5F3F1F6F5F3F3E3FFFFEFFCF1F3F6
F0EDDBC7F9E7ECD3EDF0F5FCF6E7EDF7F5F4F6F2EEF0FAF0
FFF6FFFFFFF6FFF2FFF6F2FFF6F2F4FAFAFAF6F0F4F4F4F2
FFF6F6FFF6F6E5F3EBE7FFF3FCF1F4FBFCFFFBFBFFFFFFFF
F4E7E3EFF7F7F7EAEEFFEEF4F0F1F1F6F3EBD5D7DCE5F356
F9F0F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBA0B9
E7E2E7E8F6EDFFF3E2FDE4EDF5FDE0DFF7F5F3F4F7E0D6E8
EADDDCE5F0E3EDE1F6EDF4FBFAF6F0FCF0EFF4F4F0FCFCFB
F6F6CED5E8EEE1CCF6F0F6EEF0FFF4F0F9F6F6F6F6F0F4F6
F6F2FFFFFFF6F6FFF2F6FFF6F6F6FFF7F0E2EBEAF6FFF4F0
EAF6F6FFFAECF4E0E0FCE8F7F3FCFCFFFFFFFCFCFCF3EFE7
E8F0F1F6FAF7F7F2F4F6F7F0E6E6F6FDE1D8EAEADEE9B77B
F0EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAC2A1
CFD9F9E8DAEBF7F7ECF2EEF4F4EFDCFDE8F7FBF9F5E7E7F4
FBFBE2F2FADDF7E6F4EEF4FCFCF5F5F6F0F3EFFFEBFFF9F9
FCFCE5F1D9EEEBE4F4FFF0F4FFEEFAFFF6FFF6FFFFF0E8FF
FFF6F6F4EFF4FFF6FFFFF6F2FFF2FFF3EEF4DFE2D5F0FFF4
F0F6FFFFFAF3F4EEFFE8FAE3DFE1E7EFF3F3E7E7E8EBEEEA
F3F1FAF0F0F4FAFCF6EAE6F1F4EFFFE5E8F4F3D8EDE397B5
F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBAF
9DAFDEEAD9F7EDF7F7ECFAE4F4F0FAD7DEFFFAF9F9F9FDF9
F0E5F2F2F0D1F7EEE3EDF3F4F6F6F5F3FCF3F1EFF3FCF7F7
F6F6F6E7DCF6EDFCF6F6FCF4F0F6F6FFF6FFF6F6F2E8F0F6
FFFFF2F4EFF4FFF6F6F6F6F6F6F2FFF4E9ECECE7D3E1F6FF
FFF6F6FFFFFFFAFFECE6F6FAFAF5EAE6E3E8F0EFEFFAFAF4
FCFAEDFCF2EAF7FAEBF1F4E8F1EEE4F0F4EFDCDFF5B5A1D6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEB
B896C7D6EADCF3F3F7FAEDF6FAFDEFE8FDDDECE2E2E8EEE9
E1D9EEE8F0CAFFF7E1E8F3F4F6F6F6FCF5FCF3FCFCFCFAFF
F9FAFAF6F2F6F4EEF0FCF4EFF9F6F2FFF2F6F6F6F6FFF0EA
F6FFF6F0EFF4FFFFFFF6F6FFF2F6F6FAF1DAECFAE5B7D2EE
F6F6F6FFF6F2F6FAF3F7F7F7FAFDF9FAF7F4FAFFFAF1E2E6
FAF0F6F4FADCE1E6FCE8E6F3DAD8F1FFEBD9E3FAE398B4EB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F1AF8D9AD2D8DEF3F6FDFAF5F4EAEDFDEAD6E0E9E9F3EEF1
F4F1E5E1EFD8F3FFEBE4F4F4F0EDF9FAF7F9F7EDFFFCFAF6
FCFBFCFCFAEEF9E7F6FAF2F4FCF6F2FFF6F2F6F6FFF6F0FF
EAF6FAE4E7FFEFF4FFF6F2F6F4EEF6FAFADDD9E7DCC9EEB7
A8C9F4EBDEE3F4FFF6F0F3EAEAF3F3EFF3FCF3F6FAF1E2E2
EAFCDAC4CBEEEBEBF9DACADEF6E5FFDDDDE4F3B2698EDCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFACC8EACF1E1E8F1EEF7F9EEEBF4F9F7EBECE9F1F4E5D8
DED7DDE1EFD8F6F1F6EEEEFFF3F9F6F6FCFBF9F4F6FBF7FB
FCFFFCFCF6F4E9E8FAF7F2F6F6F6F6F2F6F7F7F6FFFFF6E7
EFF6F0FAE8F4F4F4EFF1F7F2FAF1E8F3F0FDDDB6F9CBD7E4
DDDEBFDBF2E5E1D9DBE2F4F6FFF6FFFFFAF0EBF0EFF6EAE2
DEE0E4F9DBD5FAE6E1FFEEEFF6F0EFE2F1E8B76AC0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCA69FDF0DCF0F1F3FBFFF5F6EAEBEDD8E2F1F4EBDD
D7D7DEE0E2DFF1DEFFF6F0F4EFF3FCF6F2F7F6FCF2FFF6F6
FBFCF6F9FFF0E0EEF0F7F6F6F2FFEBEDF6EBEBF2FFFFF2E8
F4FFF2F3E6FFF4EFF4FCF1F6F2DEF0E0EFE4DCCFD9E8F3CD
F8D4D1E1F4FAFAF4F4E7DFEBE7EAF3FAFFFAF7F5E4DEEEF9
F1F5EFE4F2D6E2F0FAEFF6EAF0F4E8DBF1D27CB7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFA77A1EFF1E7EAE6EDFDF7F6F3F6EDE7F0F1F1F1EF
EFF4EEE4E1F0ECE7F6FFEEFAFAEBF3FCE8FFF4F6F0F6FBFA
F9FBF9F9FFF9F4F6EEFFFAF2F6F6EBFCEAFFFFFFF6FFF6FF
F6FFF2FAF4F6F4F4F4F4F4EFF4E7D0E6DFFFF2F2DDCFE5F3
C6C0CEF4F7EDF2F6EAEAF4F7F0F3F5F9E9E1E2E5EDF7F4E7
DDF1FAF3EDF7F9F6F4DEDFEFDDD6E7EBD2769DFAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFD58696F7F5F1F7E9EFEBEDF0F3F6EDF0FDFDF6E8
E2E9F4E8FDEEFCEDF6F6EDF1F5FAEBFFEDF0F9FCF6F5FCFF
EEF9FFF6F6F6F4EEF2FAFFEEFFF2F6EAF4F6FFF6F6F6FFF6
F6FFF6F6FFF2F4F4FFF4EFEFF4F4E7B7DFDDF0EEE6F4CFCB
F4F3D8BFB6B6C9D0D2DBDBD5CAC9CAC6DAF1F7EAE2DBE7F4
E8E5F1FAFFF6F3F3E3E7F9FCEAF4FFCC6D94F5FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7DB7BA4EAF6EAEEFFFFF4EEEDF0FDF0FAF4F4F6
F3E9FFE2E9E9E5EDF6F2F0FDF3F9E8EEF9E7F0F6F6FAF9FC
EEFCF7F0F6F6EEEAF6F6FAEEFFF2F6FFF6FFF6F6FFF2FFFF
FFFFF6F6FFF6F6FFFFFFFFFFF6EAEFF0C4CDF6EAEAE1ECED
C1B4C6D5D5E4F6E5EBE4ECFAF3EEF3E7DDE0E2FFE6D6C5D0
E1EBEBE4E4EBF2EBF4EDF3FCF0F3F98090F5F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCD8E97E2EEEFF3F3F1F6F7F5EEF6EEEEF1F1
F4EFE2FFF1F1EDE4E3F6F6FDF9FCF9EDF3F0E1F6F2FFF5F4
E7EDF7F6FCFCFAEFFFF2FAEFF0F6F6F6F6F4F4F2FFF2FFFF
FFFFF6F6FFFFF6F6F4F4FFFFEEF0F2F2FFC9C3D9F1FAF0E1
D1DBF0F3E7C8ADA5B0B5C5D8E2E5F2F6E9DED8DEEEEDEDF6
FFFFFFFDFDFDF6ECEAF4EDEADBE4E14DDCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFDC915972C6F1E6E9F6F7F5F6E4E9EEF6F6
FFFFE8FFF1F6E4E8DCE3F6F6F4FFF3EEF0FAEACDD7F6F7F1
FCEBF2F3F9FFF9ECEDF6F0F7F4F2F6FFF6EAF4F6F6F4F0FF
FFF6F6F2FFFFFFF6E8E8F6F6F4FAFFFAE6E0F0DCC8CEE1FA
F8F5ECF2F0CEBFBDB5B8CADADDD3DBEAEEF6FBF6F6F2F0EA
F0E9E1DDDDE3F4F4DAC4CFEDD39F5C7FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF19C5DEAFBF5EEDAE4FDF6FDF3F7EE
E9F1F3FFFFE8F0E8F6CBFFF6FFF3F6F3F6F7FAF0F1CBE1FC
E2E8EDF0F6F6F0FAF0EEEDF4FAFFF2FFF2F4EEF6F6F0F4F6
FFF2F4F4F4F4FFFFFFF4EAF6FAF3E8F1EAE6F1EDD9E8E1D5
E1FAE2E8DCC5C4C7BCB8C6C4BCBEC0BCBCD7EFE4D9D9EEFB
F6F4FAFDF0E5E5E5DAFFF6E48482CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF61BBE5E6EEE8EDF4F9F9ECECEA
EAF6F6FFF1E8DBD2C6B6E3FFFFF6FFF3F6F7FFFFE7F1D8E1
E5F4EFE5E5EBF7F6F1D9EEEAF7FAF0F6F6F0F6E7F6F2FAF0
F6F2F0F0F4F4F4FAF3F4E8DEFFF4F0ECDDF4F1DEDFF4EDEE
DEC8D2EAC1D1EEFAF5FFF5F7F0F6F6E6DEEAF4F4F3E4F0F4
F0F6EAE7D2E6F0F4EDF0E48B7FDBF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAC79C3DCDFFFEEF6FDF6F3FAFD
E8E9EAFFE8F7EAF6EABBE4E3F6FDF6F3F6FAFAFFFFE7E8FA
F0FBFBFBF0E2E5F0F6E3C6F4F1F1FAF6F2F6F1F6EFF4F0F1
F0F7DFF5E4E6EAFFEDF6EAECCDF1F6DDDAC8D6E6F0FAF4E9
FFFAEACBD2ECEADADEEBDBD6E5EAEFF7FFFFE2DCEEFAEAFF
EAE1EDEDF0F6EEF0FFCA817FDCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAF7A9FD1E9E4F7F3F7FFFDF9
EDFAF6EAE8F6EAE7F0D5DADBD9F6FFF9F7F7FFFAFFFFFAF0
F1F6F6FDF6F0DAE8EACBD6C0EAF7EBEEF6F1E6EDF0E9F1F3
F0D8ECE9D1F4E2E6F1DBD1EEF6D9F7E7DCE8C6CAD3D6DEE5
E2E9EEEBF1E6EAF3EADBF4F9F9F7F9F6EEE6FFEBF6EED9D9
E6F4F6F2DFD2E8FCBB6A90DBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD3888ECEE3D5F7F3E6EBFD
F5F5F6EAE8FBFDF7FFF0DBE4D5D2ECFFF7FAFAFFFAFFFFF4
FDE7FFF0F3FDE3F3E8EDC5C0D3EEFAEBFAE7EAF1F1F2EEEC
ECECD5D1D4E1D5DFDCD7DFB4D9CFB2CFE1B8C1F0EEE2DCEA
EAE0DBE3E0D5D9EEF0FDEBF6F6F3EBEBF2FFF3D7D1E0F5FB
F3EEF0F1DEF5F1F959ACF5F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFD99496CBC7E5EBEBFFF0
F5FAEAF6EDEDFFECE7F0EADFEEEED8E2E5E6F0FFFAFAF2FA
EDEBE6EBF6F6ECE7EAD5E0DACAEEF5F3E1F4E1E4FAF4EEEE
EAEAEDDDE8D0D6FDF0E7C7EAEAC9E1B1ABCBECD9CAD2E5FC
FDF3F0FFFFF2F2F6F2FFF6F2F2F2F6FFF7EAE7F0FFEAF5F9
FDE6F1EEE8D0E1BD4CFAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDCA19295DEE3E8EDF6
F3E8DFFFF3E4EAECEBEBF0C9CBEBEEE4ECEBD9CEDBF6F1F6
EAFAFAEEE3F6F5F0FAE6D0EFE8B8DCFAF0D2EEF0DEF3EEEA
FCF0E8EAD5CAD9DBF0ECE0E7F1C8D5D7D7E6C0C5DDF0FBF6
F7F0FFF2F3E6E6E4E8F1F3ECE7EDF7F3F0F9EFDEE2F6FFF6
F0DCF4DCE2E28453A6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEECA737597C0CDD7
D8DCD3F1F6F3E1D0D7DBDFE6F7D7D4DFE8E6E8DBC0AAB1C8
C6CAD7F0E2EEF5F0E7ECDBC6E6F0CAB7CEDFBAB0F1D6C1E5
E4EEF1EAE2D9EEE4D3E8E6D9D9D9F0DBEDE4F6E8FDFCFBF5
FDEDF2EDF7F7F3F2F1F1F5E8DAE9F7F3F0FFECE3DADFDDE4
F1E3D8B539216AC4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDCC19FA0C6DD
DEF1EAF0EEECECE9E9DFFAEDF6E6F2E7EADDD9F2FDF7EEEB
DDCED0D5DEEFFAFAEEEAFFEED0E2F2F7D9CEF6EFB1CBCAD0
E2F3E8E8EEE7E0D9FDF1F6E8FBF0E4EEFCE4E7F9F1EFE9E5
F4F4EFF9FBF7FDF6F6FCFDF2E6F1F0E5DFE7F3E6DDE7FFF1
E9E57A5FACFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEED3B190B0
B5C6E3F3F5EEF7F4EADFF7F3F2F7E5DDE5F3FDF5F4EDF9F3
FDEEF9DBC9C5D5EEFCEDECE8EEDFE3F1E4E7D8EAE7CACFC7
D8F2F6FDEFE7F0E7E8F6DDEDF9F7F7FBF3ECF3FDF1EBE7E5
EFEFE8E6EAEDF1F6F1F9F9F6F9F3E7F6FBFBEFF9E2DCE3DC
F36E6FC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE4BBA8
B5CDDAF4F6FDF3F6F6DFFAFAF3F2E5DDE5F5F6F7EFEEEAF5
FFEDF2F7F7FFEDD7DBECECFFDDE8F6EDFDE2ECEEE7E5C5D3
F0F0F6FBF1F0E0D4CBBEE2DCDBFFFFF6F6F5E4E6EBEEEEF3
F3F2F6FFFFF4EDE6E5F2F0EAEEECF4FDFDEAF6E8E4E4F1D0
6655D8F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9
AC90A5D5E3FDF6F5F6EAD5E8ECEDF7F7EDF3FAFFF4EFF4FF
F7FAFAF5F6F6FDEACFD5E2DFE4DFE4F7E7D7E8E5EDE7D2E5
E5E8E8EEE4ECF9F3EAE3CABBF1E6F3F7F7F6F6F6FFF6F1F1
ECEAECEBEAEAF9F5FAF5F4F9F9FBEAEDF5F6D3D9E4E7A65B
6ED5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EEBB90AABDDFF9F9F6E9E9E8EEEDFAF2E5E2F7F7ECECF7F9
F5FAF2EBF6F6ECF0FDEEEAF7DDD4DDFFFAF2D1D4F3DEEEDC
D8E8F1F2FFECE0DBE6EBF1E9DFE8ECDAE0EBF4F1E4F1F7F6
F0ECECF7EDF2F2E9E6E4EBE5E6EAEDE6EECBE1E3A8675194
EFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC9907885B3D7EFEFF9E6EEE8E7ECE2E4F7F5E0E5EADF
F3F9F1EDFFEDF3F6EDF0E7F0ECE7F3F9FAEBF6EAD1E4F7F5
E8EBD3C4D1DEE0DCDADAD7DDE0E6FDEEF0FFEAEFF3EAF6F0
F5F3FFE7E9E9DBE0DADFF0FAFFF7E4D0E2EC9C67567ED3F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F5D59A69483F75C3F4E6E0DFCDCEDCEDD9B9CFF7F0
EBE0EAECE2E4F3F7FDE3E9F0F3EEFFF7F3F7F6F2EAFBEAE2
D2E3F3EBEDF7F5E6D9E2E4E4F3F9F1E7DFE2F0E8E6DCC9D4
D4CDCAD3D7DBE1EFEDF9D9C9C0C5EEC4712A4396D9F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEE95587091C2EDF3F7F6DFD9D7F1EAEA
F7FAF5F5EEE8E1F3F6F3FDF7EEF0FFFFFFF6EDEADFE0FDE2
ECFFF6ECF0EEF3FDEFFBF4F1FBF3F6FCF9FAF6EDE6E8EFE3
DEDEE5F2FBF3F3E6F2DACBEFDCB77B5E7DCAF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFD69A7C72868FA7CAD5EBD7E8DEDE
C8BFD4E8EBF3E1D8ECF0EAE6FBF6E5E5FDF6F0FBFAF7EDE2
E6EEF3EDECF3EFEADBE6FAF0EEF6F5EBE6E2E2E5ECF2F6F3
DDCFC9D3E0C4B1C1D7ECEDD69E5E7CCBF5F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEBBA95877367676987ADA9AD
B5C0BFD7D8D9E8E6D5DDE4EEF6F2D9E1FDFDEEE2DFDFE7EC
F9F6F3F6F3EEF3F7ECEFF7FFFAF7F4F2F9F7EFE5E2DED8D9
E8FFF3F6DCE1FFFFEDD97C5B69C3F7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE4E4E9D9D1E4E6
E4EAC2D9EAE7CAB9B7D7EDEBE2DCE4ECFFF3EAFBF9FAF6DB
D6E3E1F0F3F3F3EDFDF3F9FDFBFDFAEFEDF7FFFAF7F6F6FD
FDF1F3EBF3E6D1A7968970D9F5F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAEDE6
F1F1E0D6DAEDE6E1E7B2A6C4EDF5E9DEDBEBE8ECEDE6E7EF
F3F6FDEEF0ECFCF2E2E9F7F7F3F9FAFFF3F3FAFAFAF3F9EF
F2EEE2EFCF9F807483A1D2F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F1ECF0E7D5DBE2E8E1EDD6BDB6B5BDCFE4F5E6CFD7F1E4EF
F5FDFDEEF0F0EAEAEAFAE7F3FFF7F9FBF6F9FAEAEAE7EEF9
EEDDA975687FB3D9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFAF0F1EEE9EBE9EDFAF1D9C9C3BA9F7C70859EA0A4A2AA
BEB7BED7DDD8E3EAE5FBE6FBF2EED7CDC6C0A974573B2731
31395F9BD8FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFEEE4D4C4BC9E
909EA29796A3AFA29A887A77706E7070767F90B7CDDBEDED
FAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FAFFFAFAFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FAEDE4E2D8BCB4BCC9CDCBD4E6E9EEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  ImageSize->{400, 190.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00;@3oool00`3gmoL0oooo0?ooo`040?ooo`030?Og
m`3oool0oooo0200oooo00@0e]KF0?Gem@3clo<0oooo0P3kno/20?ooo`040?Shn03oool0n?Sh0?Sh
n0H0oooo00<0n?Sh0?ooo`3oool00P3oool02`3_knl0lo?c0?ooo`3oool0n?Sh0??cl`3oool0lo?c
0?ooo`3bl_80n_[j0080lo?c203oool0203hn?P0lo?c0?ooo`3gmoL0oooo0?clo03oool0o?cl0P3o
ool0103alO40mOGe0?ooo`3[jn/G0?ooo`030?Ogm`3oool0oooo0080oooo00<0moOg0?ooo`3oool0
<@3oool00`3gmoL0oooo0?ooo`040?ooo`030?Ogm`3oool0oooo0200oooo00@0e]KF0??cl`3clo<0
oooo0P3kno/20?ooo`040?Ogm`3oool0moOg0?Ogm`H0oooo00<0moOg0?ooo`3oool00P3oool02`3_
knl0lo?c0?ooo`3oool0moOg0??cl`3oool0lo?c0?ooo`3bl_80no_k0080lo?c203oool0203gmoL0
lo?c0?ooo`3gmoL0oooo0?_kn`3oool0no_k0P3oool0103clo<0moOg0?ooo`3[jn/G0?ooo`030?Og
m`3oool0oooo0080oooo00<0moOg0?ooo`3oool0;03oool002D0oooo1@3jn_X:0?ooo`040?[jnP3o
ool0n_[j0?ooo`<0n_[j00<0oooo0?[jnP3oool01P3oool01@3jn_X0oooo0?ooo`3oool0n_[j00h0
oooo00@0i>CT0>7Qh@3jn_X0oooo103moOd01@3jn_X0oooo0?[jnP3jn_X0oooo00<0n_[j00<0oooo
0?Shn03jn_X00P3jn_X03@3moOd0m?Cd0?Cdm03oool0n_[j0?Shn03_knl0m_Kf0??cl`3oool0nOWi
0?ooo`3emOD00P3oool20?[jnP030?ooo`3hn?P0oooo00<0n_[j00<0oooo0?[jnP3lo?`00P3oool0
203kno/0oOgm0?gmo@3oool0oOgm0?Gem@3dm?@0^k^k203oool00`3jn_X0oooo0?ooo`040?ooo`03
0?[jnP3oool0oooo00<0oooo00H0n_[j0?ooo`3jn_X0oooo0?[jnP3oool20?[jnP80oooo00<0n_[j
0?ooo`3oool09`3oool50?[jnPX0oooo00@0n_[j0?ooo`3jn_X0oooo0`3jn_X00`3oool0n_[j0?oo
o`060?ooo`050?[jnP3oool0oooo0?ooo`3jn_X03P3oool0103Shn<0gmoO0?[jnP3oool40?clo005
0?[jnP3oool0n_[j0?[jnP3oool00`3jn_X00`3oool0moOg0?[jnP020?[jnP0=0?clo03dm?@0m?Cd
0?ooo`3jn_X0moOg0>k^kP3fm_H0lo?c0?ooo`3inOT0oooo0?Gem@020?ooo`80n_[j00<0oooo0?Og
m`3oool00`3jn_X00`3oool0n_[j0?gmo@020?ooo`080?_kn`3moOd0oOgm0?ooo`3moOd0m_Kf0?Ge
m@2j^[X80?ooo`030?[jnP3oool0oooo00@0oooo00<0n_[j0?ooo`3oool00`3oool01P3jn_X0oooo
0?[jnP3oool0n_[j0?ooo`80n_[j0P3oool00`3jn_X0oooo0?ooo`0Z0?ooo`009`3oool00`3jn_X0
oooo0?ooo`020?[jnP030?ooo`3jn_X0n_[j0080n_[j00<0moOg0?[jnP3oool01P3oool00`3jn_X0
oooo0?ooo`080?ooo`030?[jnP3oool0n_[j00l0oooo00<0i>CT0>7Qh@3oool00`3moOd01P3kno/0
n?Sh0?ooo`3hn?P0oooo0?Shn080oooo0`3jn_X0103gmoL0oooo0?ooo`3alO420?ooo`090?Shn03j
n_X0nOWi0?KfmP3inOT0oooo0?gmo@3kno/0mOGe0080n?Sh00@0moOg0?Gem@3hn?P0n_[j0`3oool0
103jn_X0oooo0?Ogm`3oool20?Win@040?clo03jn_X0oooo0?[jnP80oOgm00@0oooo0?Shn03clo<0
];Bd2@3oool20?[jnP030?ooo`3jn_X0oooo00@0n_[j3P3oool00`3jn_X0oooo0?ooo`0X0?ooo`03
0?[jnP3oool0oooo0080n_[j00<0oooo0?[jnP3jn_X00P3jn_X00`3gmoL0n_[j0?ooo`060?ooo`03
0?[jnP3oool0oooo00P0oooo00<0n_[j0?ooo`3jn_X03`3oool00`3Shn<0gmoO0?ooo`030?clo006
0?_kn`3gmoL0oooo0?Ogm`3oool0moOg0P3oool30?[jnP040?KfmP3oool0oooo0?7al@80oooo00H0
moOg0?[jnP3inOT0m_Kf0?Win@3oool20?clo0070?Gem@3gmoL0moOg0?Ogm`3emOD0moOg0?[jnP03
0?ooo`040?[jnP3oool0moOg0?ooo`80nOWi00@0oOgm0?_kn`3oool0no_k0P3moOd0103oool0n_[j
0??cl`2c/k<90?ooo`80n_[j00<0oooo0?[jnP3oool0103jn_X>0?ooo`030?[jnP3oool0oooo02T0
oooo000V0?ooo`80n_[j103oool00`3jn_X0oooo0?[jnP020?[jnP030?Ogm`3oool0oooo00H0oooo
0P3jn_X00`3oool0n_[j0?ooo`080?ooo`030?[jnP3oool0oooo00d0oooo00@0i>CT0>7Qh@3oool0
oooo0`3moOd0103jn_X0n?Sh0?[jnP3oool30?[jnP090?Shn03jn_X0n_[j0?ooo`3dm?@0kno_0?oo
o`3jn_X0n?Sh0080oooo00H0lo?c0?Win@3gmoL0m_Kf0?Ogm`3inOT30?ooo`040?Ogm`3clo<0n_[j
0?Win@80n_[j00T0mOGe0?Shn03oool0oooo0?Win@3emOD0nOWi0?ooo`3kno/00P3lo?`01P3moOd0
oooo0?clo03emOD0j^[Z0<G5a@h0oooo00<0n_[j0?ooo`3oool02`3oool00`3jn_X0oooo0?ooo`02
0?ooo`<0n_[j9P3oool20?[jnP@0oooo00<0n_[j0?ooo`3jn_X00P3jn_X00`3gmoL0oooo0?ooo`06
0?ooo`80n_[j00<0oooo0?[jnP3oool0203oool00`3jn_X0oooo0?ooo`0=0?ooo`040>?Sh`3Ogml0
oooo0?ooo`<0o?cl00@0n_[j0?Ogm`3jn_X0oooo0`3jn_X02@3gmoL0n_[j0?[jnP3oool0m?Cd0>o_
k`3oool0n_[j0?Ogm`020?ooo`030??cl`3inOT0moOg0080m_Kf00P0nOWi0?ooo`3oool0oooo0?Og
m`3clo<0n_[j0?Win@80n_[j00T0mOGe0?Ogm`3oool0oooo0?Win@3emOD0nOWi0?ooo`3kno/00`3m
oOd01@3oool0no_k0?KfmP3[jn/0aLG500h0oooo00<0n_[j0?ooo`3oool02`3oool00`3jn_X0oooo
0?ooo`020?ooo`<0n_[j:03oool002D0oooo00<0n_[j0?ooo`3oool00P3oool01@3jn_X0oooo0?oo
o`3jn_X0oooo0080n_[j0P3oool00`3jn_X0oooo0?[jnP0Q0?ooo`030>CTi03QhN40mOGe00<0oOgm
00<0oooo0?Shn03oool00`3jn_X40?ooo`0C0?Cdm03_knl0n?Sh0>g]k@3oool0lO7a0?[jnP3no_h0
n_[j0?Win@3gmoL0lO7a0?[jnP3fm_H0oooo0?;blP3dm?@0lo?c0?Gem@020?[jnP090?clo03oool0
n_[j0?ooo`3gmoL0mOGe0?clo03gmoL0oooo00<0o?cl00P0oooo0?[jnP3moOd0o?cl0?gmo@3lo?`0
g=cL0?[jnPd0oooo0P3jn_X00`3oool0n_[j0?ooo`060?[jnPD0oooo00@0n_[j0?ooo`3jn_X0n_[j
:03oool00`3jn_X0oooo0?ooo`020?ooo`050?[jnP3oool0oooo0?[jnP3oool00P3jn_X20?ooo`03
0?[jnP3oool0n_[j0240oooo00<0hn?S0=oOg`3emOD00`3lo?`00`3oool0moOg0?ooo`030?[jnP@0
oooo0100lo?c0>o_k`3jn_X0kno_0?ooo`3bl_80no_k0?gmo@3jn_X0nOWi0?KfmP3`l?00n_[j0?Ge
m@3oool0lO7a0P3clo<03@3emOD0n_[j0?[jnP3moOd0oooo0?[jnP3oool0moOg0?Gem@3moOd0moOg
0?ooo`3moOd00P3kno/00`3oool0n_[j0?gmo@020?gmo@030?clo03IfMT0n_[j00d0oooo0P3jn_X0
0`3oool0n_[j0?ooo`060?[jnPD0oooo00@0n_[j0?ooo`3jn_X0n_[j:`3oool002H0oooo00H0n_[j
0?ooo`3jn_X0n_[j0?ooo`3jn_X70?ooo`030?[jnP3oool0n_[j0080n_[j00<0oooo0?[jnP3jn_X0
3@3oool20?[jnPd0oooo00<0e]KF0?;blP3gmoL00P3oool0103moOd0oooo0?gmo@3jn_X20?ooo`03
0?[jnP3kno/0oOgm0080oooo00/0kNg]0?Cdm03emOD0n?Sh0?_kn`3gmoL0kno_0?ooo`3gmoL0m?Cd
0?Gem@020?[jnP070?KfmP3bl_80n_[j0?clo03_knl0oOgm0?3`l0020?clo0<0oooo0`3jn_X01@3o
ool0n?Sh0?Win@3jn_X0lo?c00<0oooo00@0no_k0?ooo`3MgMd0]kNg3P3oool40?[jnP80oooo00D0
n_[j0?ooo`3jn_X0oooo0?[jnP030?ooo`D0n_[j00<0oooo0?[jnP3jn_X09`3oool01P3jn_X0oooo
0?[jnP3jn_X0oooo0?[jnPL0oooo00<0n_[j0?ooo`3jn_X00P3jn_X00`3oool0n_[j0?[jnP0=0?oo
o`80n_[j3@3oool00`3Fe]H0lO7a0?Ogm`020?ooo`040?clo03oool0o?cl0?[jnP80oooo00<0n_[j
0?_kn`3lo?`00P3oool02`3^k^h0m?Cd0?KfmP3jn_X0oOgm0?Ogm`3_knl0oooo0?KfmP3dm?@0mOGe
0080n_[j00L0mOGe0?7al@3jn_X0oOgm0>k^kP3lo?`0k^k^0080oOgm0`3oool20?[jnP060?_kn`3o
ool0moOg0?Win@3jn_X0lo?c0`3oool0103kno/0oooo0=cLg02d];@>0?ooo`@0n_[j0P3oool01@3j
n_X0oooo0?[jnP3oool0n_[j00<0oooo1@3jn_X00`3oool0n_[j0?[jnP0Y0?ooo`009@3oool30?[j
nP030?ooo`3jn_X0oooo00<0oooo00@0n_[j0?ooo`3jn_X0n_[j1@3oool00`3jn_X0oooo0?ooo`05
0?ooo`030?[jnP3oool0oooo00@0oooo00<0n_[j0?ooo`3oool03P3oool04P3GemL0kno_0?ooo`3o
ool0oOgm0?ooo`3kno/0n?Sh0?ooo`3moOd0oooo0?gmo@3alO40m?Cd0>o_k`3alO40jNWY0?;blP80
m?Cd00@0oOgm0?clo03inOT0lO7a0P3fm_H03@3gmoL0oOgm0?3`l03dm?@0no_k0?Ogm`3`l?00moOg
0?knoP3jn_X0k^k^0>c/k03Zj^X0103oool0103gmoL0nOWi0?clo03jn_X20?clo0070?ooo`3jn_X0
oOgm0?gmo@3oool0a/K60<G5a@0=0?ooo`030?[jnP3oool0oooo01@0oooo00<0n_[j0?ooo`3oool0
8`3oool30?[jnP030?ooo`3jn_X0oooo00<0oooo00@0n_[j0?ooo`3jn_X0n_[j1@3oool00`3jn_X0
oooo0?ooo`050?ooo`030?[jnP3oool0oooo00@0oooo00<0n_[j0?ooo`3oool03P3oool04P3Fe]H0
kno_0?ooo`3oool0o?cl0?ooo`3kno/0moOg0?ooo`3lo?`0oooo0?clo03alO40m?Cd0>o_k`3alO40
jn_[0?;blP80m?Cd00D0o?cl0?_kn`3inOT0l?3`0?Gem@020?KfmP0<0?gmo@3_knl0lo?c0?clo03f
m_H0kno_0?Ogm`3oool0no_k0>g]k@3/k>`0jNWY103oool0103gmoL0nOWi0?gmo@3jn_X20?gmo@07
0?ooo`3jn_X0oOgm0?gmo@3oool0`/;20<G5a@0=0?ooo`030?[jnP3oool0oooo01@0oooo00<0n_[j
0?ooo`3oool09P3oool002H0oooo0P3jn_X60?ooo`060?[jnP3oool0n_[j0?[jnP3oool0n_[j0`3o
ool00`3jn_X0oooo0?ooo`050?ooo`80n_[j5P3oool0103Jf]X0kno_0?[jnP3oool50?gmo@<0oooo
0`3dm?@02P3clo<0mOGe0?Cdm03gmoL0oooo0>g]k@3alO40m?Cd0?Ogm`3oool20?Win@0>0?clo03i
nOT0moOg0?_kn`3fm_H0lo?c0?knoP3alO40n_[j0?clo03alO40l?3`0>[ZjP3moOd20?ooo`080?gm
o@3gmoL0o?cl0?Win@3oool0n_[j0?KfmP3lo?`20?ooo`030?Ogm`2d];@0gmoO00`0oooo0`3jn_X0
103oool0n_[j0?ooo`3jn_X60?ooo`030?[jnP3oool0oooo02l0oooo0P3jn_X60?ooo`060?[jnP3o
ool0n_[j0?[jnP3oool0n_[j0`3oool00`3jn_X0oooo0?ooo`050?ooo`80n_[j5P3oool0103IfMT0
kno_0?[jnP3oool50?clo0<0oooo00d0lo?c0?Cdm03dm?@0lo?c0?Ogm`3clo<0moOg0?ooo`3/k>`0
lO7a0??cl`3fm_H0oooo0080nOWi00h0no_k0?Win@3fm_H0o?cl0?Ogm`3clo<0oooo0?3`l03jn_X0
oOgm0?7al@3^k^h0jNWY0?gmo@80oooo00P0oOgm0?Ogm`3kno/0nOWi0?ooo`3kno/0m_Kf0?gmo@80
oooo00<0moOg0;:b/P3Ng]h0303oool30?[jnP040?ooo`3jn_X0oooo0?[jnPH0oooo00<0n_[j0?oo
o`3oool0<@3oool002L0oooo00H0n_[j0?ooo`3jn_X0n_[j0?ooo`3jn_X80?ooo`030?[jnP3oool0
oooo01l0oooo00<0e=CD0?Ogm`3oool00`3moOd01`3oool0oOgm0?Cdm03kno/0oOgm0?Cdm03_knl0
0P3oool00`3]kNd0oOgm0?KfmP030?gmo@080?_kn`3_knl0m_Kf0?gmo@3emOD0oOgm0?[jnP3gmoL2
0?Gem@0>0?KfmP3no_h0n_[j0??cl`3alO40lo?c0?Ogm`3hn?P0lo?c0?_kn`3oool0moOg0??cl`3g
moL20?_kn`050?Win@3lo?`0o?cl0?ooo`3moOd00P3oool00`2i^KT0lO7a0?ooo`0>0?ooo`050?[j
nP3oool0oooo0?ooo`3jn_X0>03oool01P3jn_X0oooo0?[jnP3jn_X0oooo0?[jnPP0oooo00<0n_[j
0?ooo`3oool07`3oool00`3Cdm<0moOg0?ooo`030?clo0070?ooo`3lo?`0m?Cd0?_kn`3lo?`0lo?c
0>o_k`020?ooo`030>k^kP3lo?`0m_Kf00<0o?cl00P0no_k0>k^kP3fm_H0o?cl0?Gem@3moOd0n_[j
0?KfmP80lo?c00h0m_Kf0?ooo`3jn_X0lo?c0?3`l03clo<0m_Kf0?Win@3clo<0no_k0?ooo`3gmoL0
lo?c0?Ogm`80no_k00D0nOWi0?gmo@3moOd0oooo0?gmo@020?ooo`030;Ng]`3alO40oooo00h0oooo
00D0n_[j0?ooo`3oool0oooo0?[jnP0i0?ooo`009@3oool00`3jn_X0oooo0?[jnP0:0?ooo`<0n_[j
0`3oool40?[jnP<0oooo0P3jn_XF0?ooo`060=OGe`3lo?`0moOg0?ooo`3moOd0no_k0`3moOd00`3d
m?@0lO7a0?ooo`020>o_k`<0n_[j00@0n?Sh0?[jnP3hn?P0n_[j0`3moOd01`3gmoL0m_Kf0?[jnP3j
n_X0o?cl0?KfmP3kno/00P3gmoL01P3emOD0oOgm0?Gem@3moOd0lO7a0?_kn`80lo?c00<0kNg]0?[j
nP3_knl00P3gmoL02P3jn_X0oooo0?gmo@3oool0o?cl0?_kn`3moOd0l_;b0=CDe03gmoM:0?ooo`03
0?[jnP3oool0n_[j00X0oooo0`3jn_X30?ooo`@0n_[j0`3oool20?[jnQH0oooo00H0eMGE0?gmo@3g
moL0oooo0?clo03kno/30?clo0030?Cdm03alO40oooo0080kno_0`3jn_X0103gmoL0n_[j0?Ogm`3j
n_X30?clo0070?Ogm`3emOD0nOWi0?Win@3lo?`0m_Kf0?_kn`020?KfmP060?Gem@3moOd0mOGe0?gm
o@3`l?00no_k0P3clo<00`3/k>`0n_[j0>k^kP020?Ogm`0:0?[jnP3oool0oOgm0?ooo`3moOd0no_k
0?gmo@3alO40eMGE0?Ogmdd0oooo000U0?ooo`050?[jnP3oool0oooo0?[jnP3oool00`3jn_X40?oo
o`030?[jnP3oool0oooo02<0oooo00<0fMWI0?KfmP3oool00`3moOd00`3dm?@0oooo0>o_k`020?Og
m`030?ooo`3moOd0oOgm0080n_[j00H0oooo0?Shn03oool0oooo0?[jnP3moOd20?[jnP090?Win@3a
lO40no_k0?Gem@3lo?`0mOGe0?clo03moOd0mOGe0080o?cl01@0oooo0?Gem@3moOd0nOWi0?7al@3m
oOd0lo?c0?Cdm03_knl0k^k^0?ooo`3lo?`0oooo0?clo03oool0m?Cd0?_kn`3oool0g=cL0?7al@/0
oooo00<0n_[j0?ooo`3jn_X00P3jn_Xk0?ooo`050?[jnP3oool0oooo0?[jnP3oool00`3jn_X40?oo
o`030?[jnP3oool0oooo02<0oooo00<0emOG0?KfmP3oool00`3lo?`00`3clo<0oooo0>o_k`020?Og
m`030?ooo`3lo?`0o?cl0080n_[j00H0oooo0?Ogm`3oool0oooo0?[jnP3lo?`20?[jnP0C0?Win@3`
l?00o?cl0?Gem@3moOd0m?Cd0?_kn`3moOd0mOGe0?gmo@3kno/0oooo0?Gem@3moOd0nOWi0?3`l03l
o?`0lo?c0?Cdm0020>g]k@0:0?ooo`3moOd0oooo0?gmo@3oool0m?Cd0?_kn`3oool0fm_K0?7al@/0
oooo00<0n_[j0?ooo`3jn_X00P3jn_Xn0?ooo`009@3oool30?[jnP030?ooo`3jn_X0n_[j0080oooo
00<0n_[j0?ooo`3oool01@3oool00`3jn_X0oooo0?ooo`090?ooo`80n_[j503oool03P3bl_80m_Kf
0?ooo`3moOd0m_Kf0?7al@3oool0kno_0?Ogm`3kno/0oooo0?gmo@3oool0n?Sh0P3oool20?[jnP80
n?Sh103oool0203hn?P0oOgm0?Ogm`3dm?@0m_Kf0?clo03fm_H0mOGe0`3lo?`03@3moOd0o?cl0?gm
o@3lo?`0lO7a0?Shn03inOT0n?Sh0??cl`3]kNd0kno_0?clo03fm_H00P3lo?`0103gmoL0oooo0??c
l`3;bl/;0?ooo`030?[jnP3oool0oooo00<0oooo103jn_X;0?ooo`<0n_[j:@3oool30?[jnP030?oo
o`3jn_X0n_[j0080oooo00<0n_[j0?ooo`3oool01@3oool00`3jn_X0oooo0?ooo`090?ooo`80n_[j
503oool03P3alO40m_Kf0?ooo`3lo?`0m_Kf0?7al@3oool0kno_0?Ogm`3kno/0oooo0?clo03oool0
moOg0P3oool20?[jnP80moOg103oool0203gmoL0o?cl0?Ogm`3clo<0m_Kf0?_kn`3fm_H0mOGe0`3k
no/01P3moOd0no_k0?gmo@3kno/0l?3`0?Ogm`80nOWi00D0lo?c0>g]k@3_knl0oOgm0?KfmP020?gm
o@040?Ogm`3oool0lo?c0<W9b@/0oooo00<0n_[j0?ooo`3oool00`3oool40?[jnP/0oooo0`3jn_X/
0?ooo`009P3oool20?[jnP030?ooo`3jn_X0n_[j02`0oooo00P0l_;b0?Gem@3oool0oooo0??cl`3_
knl0oooo0?Cdm080oooo00@0oOgm0?ooo`3oool0n_[j0P3oool00`3gmoL0n?Sh0?ooo`020?[jnP<0
oooo00<0n_[j0?gmo@3moOd00`3moOd00`3no_h0no_k0?gmo@020?[jnP0C0?Win@3oool0n_[j0?cl
o03clo<0m_Kf0?ooo`3kno/0nOWi0>OWi`3fm_H0oooo0?clo03emOD0n_[j0?clo03gmoL0lo?c0<_;
b`0;0?ooo`030?[jnP3oool0oooo00H0oooo00<0n_[j0?ooo`3oool0=P3oool20?[jnP030?ooo`3j
n_X0n_[j02`0oooo00P0lO7a0?Gem@3oool0oooo0??cl`3_knl0oooo0??cl`80oooo00@0o?cl0?oo
o`3oool0n_[j0P3oool00`3fm_H0moOg0?ooo`020?[jnP<0oooo00<0n_[j0?clo03lo?`00P3lo?`2
0?gmo@0G0?_kn`3moOd0nOWi0?[jnP3inOT0oooo0?[jnP3kno/0lo?c0?KfmP3oool0no_k0?Win@3V
i^H0moOg0?clo03moOd0mOGe0?[jnP3moOd0moOg0??cl`38b<P02`3oool00`3jn_X0oooo0?ooo`06
0?ooo`030?[jnP3oool0oooo03P0oooo000U0?ooo`030?[jnP3oool0n_[j0080n_[j0P3oool20?[j
nP030?ooo`3jn_X0oooo0080oooo0P3jn_XQ0?ooo`050<30`03emOD0o?cl0?Ogm`3fm_H00P3dm?@2
0?ooo`80oOgm00@0n_[j0?ooo`3emOD0n_[j0`3oool01@3hn?P0oOgm0?Win@3jn_X0moOg0080oooo
00<0n_[j0?ooo`3moOd00P3moOd01P3fm_H0oooo0?Win@3lo?`0oOgm0?Win@80oOgm0140o?cl0?oo
o`3moOd0m_Kf0?_kn`3jn_X0oooo0?[jnP3bl_80oooo0?[jnP3alO40n_[j0?ooo`3gmoL0lo?c0;Bd
]0090?ooo`80n_[j0P3oool00`3jn_X0oooo0?ooo`0l0?ooo`030?[jnP3oool0n_[j0080n_[j0P3o
ool20?[jnP030?ooo`3jn_X0oooo0080oooo0P3jn_XQ0?ooo`070;no_`3emOD0oOgm0?Ogm`3fm_H0
m?Cd0??cl`020?ooo`80o?cl00@0n_[j0?ooo`3emOD0n_[j0`3oool01@3gmoL0o?cl0?Win@3jn_X0
m_Kf0080oooo00<0n_[j0?ooo`3lo?`00P3lo?`01P3fm_H0oooo0?Win@3kno/0oOgm0?Win@80oOgm
0140no_k0?ooo`3moOd0m_Kf0?_kn`3jn_X0oooo0?[jnP3alO40oooo0?_kn`3alO40no_k0?ooo`3g
moL0lo?c0;:b/P090?ooo`80n_[j0P3oool00`3jn_X0oooo0?ooo`0o0?ooo`009P3oool20?[jnP80
oooo0`3jn_X40?ooo`80n_[j8P3oool01P2e]KD0b/[:0??cl`3gmoL0oOgm0?Cdm080oooo00<0oOgm
0?ooo`3moOd00P3oool0103moOd0n_[j0?Shn03hn?P20?ooo`030?[jnP3moOd0oooo0080oooo00h0
n_[j0?Shn03jn_X0mOGe0?[jnP3kno/0moOg0?Cdm03inOT0m_Kf0?Gem@3jn_X0moOg0?Gem@<0oOgm
00l0m?Cd0?_kn`3jn_X0no_k0?gmo@3inOT0mOGe0?3`l03jn_X0no_k0?clo03oool0lo?c0?Ogm`2e
]KD03P3oool30?[jnP030?ooo`3jn_X0oooo00T0oooo00<0n_[j0?ooo`3jn_X0;@3oool20?[jnP80
oooo0`3jn_X40?ooo`80n_[j8P3oool01P2e]KD0bl_;0??cl`3gmoL0o?cl0?Cdm080oooo00<0o?cl
0?ooo`3lo?`00P3oool0103lo?`0n_[j0?Ogm`3gmoL20?ooo`030?[jnP3lo?`0oooo0080oooo00h0
n_[j0?Ogm`3jn_X0mOGe0?[jnP3kno/0moOg0?Cdm03inOT0m_Kf0?Cdm03inOT0m_Kf0?Gem@80oOgm
00@0o?cl0?Gem@3lo?`0nOWi0P3lo?`02P3inOT0mOGe0?;blP3jn_X0nOWi0?gmo@3oool0lo?c0?Og
m`2e]KD>0?ooo`<0n_[j00<0oooo0?[jnP3oool02@3oool00`3jn_X0oooo0?[jnP0_0?ooo`009@3o
ool20?[jnP040?ooo`3jn_X0n_[j0?[jnP80oooo00<0n_[j0?ooo`3oool0103oool0103jn_X0oooo
0?ooo`3oool20?[jnQX0oooo00@0e]KF09BDU02?Shl0lO7a0P3moOd00`3kno/0oooo0?[jnP020?[j
nP80oooo00@0n_[j0?ooo`3jn_X0n?Sh0P3jn_X01@3hn?P0oooo0?ooo`3oool0n?Sh0080n_[j00P0
n?Sh0?Ogm`3oool0oooo0?gmo@3kno/0m?Cd0?3`l080n?Sh00/0oooo0?clo03jn_X0oOgm0?clo03o
ool0m_Kf0?_kn`3jn_X0no_k0?[jnP020?KfmP080?[jnP3clo<0l_;b0>o_k`3gmoL0oooo0?clo031
`L4;0?ooo`050?[jnP3oool0n_[j0?ooo`3jn_X0?03oool20?[jnP040?ooo`3jn_X0n_[j0?[jnP80
oooo00<0n_[j0?ooo`3oool0103oool0103jn_X0oooo0?ooo`3oool20?[jnQX0oooo00@0e]KF09:B
TP2?Shl0lO7a0P3lo?`00`3kno/0oooo0?[jnP020?[jnP80oooo00@0n_[j0?ooo`3jn_X0moOg0P3j
n_X01@3gmoL0oooo0?ooo`3oool0moOg0080n_[j01D0moOg0?KfmP3oool0oooo0?clo03kno/0m?Cd
0?3`l03inOT0moOg0?ooo`3moOd0nOWi0?gmo@3kno/0oooo0?KfmP3lo?`0no_k0?clo03jn_X00P3f
m_H0203jn_X0lo?c0?7al@3]kNd0moOg0?ooo`3inOT0`<302`3oool01@3jn_X0oooo0?[jnP3oool0
n_[j03l0oooo000U0?ooo`060?[jnP3oool0oooo0?[jnP3oool0n_[j0P3oool00`3jn_X0oooo0?oo
o`040?ooo`030?[jnP3oool0oooo01`0oooo00@0iNGU07=cL`3]kNd0W9bL0P3dm?@01@3gmoL0oOgm
0?ooo`3jn_X0oooo0080n_[j00P0oooo0?[jnP3jn_X0n?Sh0?ooo`3jn_X0oooo0?Shn0<0oOgm00<0
oooo0?[jnP3oool00P3moOd01P3oool0oOgm0?Cdm03fm_H0m?Cd0?Win@80oooo00<0n_[j0?gmo@3o
ool00P3jn_X0403inOT0m_Kf0??cl`3kno/0oooo0?[jnP3gmoL0oooo0?Gem@3clo<0moOg0?_kn`3d
m?@0oooo0?_kn`37alL?0?ooo`030?[jnP3oool0oooo03X0oooo00H0n_[j0?ooo`3oool0n_[j0?oo
o`3jn_X20?ooo`030?[jnP3oool0oooo00@0oooo00<0n_[j0?ooo`3oool0703oool02`3UiND0Lg=c
0>c/k02LW9`0lo?c0?Cdm03gmoL0o?cl0?ooo`3jn_X0oooo0080n_[j00P0oooo0?[jnP3jn_X0moOg
0?ooo`3jn_X0oooo0?Ogm`<0o?cl00<0oooo0?[jnP3oool00P3lo?`01P3oool0o?cl0?Cdm03fm_H0
m?Cd0?Win@80oooo01D0nOWi0?gmo@3oool0nOWi0?[jnP3inOT0m_Kf0??cl`3kno/0oOgm0?[jnP3f
m_H0oooo0?Gem@3clo<0moOg0?_kn`3clo<0oooo0?gmo@38b<P03`3oool00`3jn_X0oooo0?ooo`0m
0?ooo`009P3oool20?Ogm`80oooo103jn_X20?ooo`H0n_[j0`3oool00`3jn_X0oooo0?ooo`0F0?oo
o`060:FUY@0n?Sh0Xj>S0<?3``2BTY80kNg]0`3moOd00`3oool0n_[j0?ooo`020?[jnP040?ooo`3j
n_X0oooo0?ooo`80n_[j00@0oooo0?[jnP3kno/0oooo0`3jn_X02`3oool0lO7a0?Cdm03hn?P0mOGe
0>o_k`3^k^h0lo?c0?[jnP3`l?00oOgm0080moOg01<0n_[j0?Ogm`3lo?`0m_Kf0?_kn`3hn?P0m?Cd
0?_kn`3oool0n?Sh0?clo03jn_X0oOgm0?ooo`3jn_X0kno_0?;blP3_knl0gmoO00h0oooo0P3jn_Xm
0?ooo`80moOg0P3oool40?[jnP80oooo1P3jn_X30?ooo`030?[jnP3oool0oooo01H0oooo00H0YJFU
03dm?@2RXZ80`/;209>CT`3^k^h30?clo0030?ooo`3jn_X0oooo0080n_[j00@0oooo0?[jnP3oool0
oooo0P3jn_X0103oool0n_[j0?_kn`3oool30?[jnP0G0?ooo`3alO40m?Cd0?Ogm`3emOD0kno_0>k^
kP3clo<0nOWi0>o_k`3moOd0moOg0?KfmP3inOT0m_Kf0?_kn`3fm_H0o?cl0?Ogm`3dm?@0o?cl0?oo
o`3gmoL00P3kno/01`3moOd0oooo0?[jnP3]kNd0l_;b0>k^kP3Ng]h03P3oool20?[jnSl0oooo000V
0?ooo`040?[jnP3oool0n_[j0?[jnP80oooo0P3jn_X?0?ooo`030?[jnP3oool0oooo0080oooo00<0
n_[j0?ooo`3oool0303oool01P3gmoL0820P0>CTi03Xj>P0E5AD0?gmo@<0no_k00<0oooo0?Shn03h
n?P0103oool20?[jnP030?ooo`3jn_X0oooo00<0n_[j00`0n?Sh0?[jnP3jn_X0n_[j0?_kn`3moOd0
l?3`0?ooo`3jn_X0oooo0?KfmP3gmoL20?ooo`80lo?c00X0n_[j0?Win@3jn_X0m_Kf0?[jnP3kno/0
m?Cd0?Shn03inOT0oooo0`3jn_X01`3moOd0n_[j0?Ogm`3gmoL0kNg]0?clo03]kNd05P3oool01@3j
n_X0oooo0?ooo`3oool0n_[j0080oooo00<0n_[j0?ooo`3oool0;@3oool0103jn_X0oooo0?[jnP3j
n_X20?ooo`80n_[j3`3oool00`3jn_X0oooo0?ooo`020?ooo`030?[jnP3oool0oooo00`0oooo00H0
moOg024Q8@3UiND0iNGU059BDP3lo?`30?_kn`030?ooo`3gmoL0moOg00@0oooo0P3jn_X00`3oool0
n_[j0?ooo`030?[jnP0:0?Ogm`3jn_X0n_[j0?[jnP3kno/0o?cl0>o_k`3oool0nOWi0?ooo`80m_Kf
0P3oool20??cl`<0nOWi00@0mOGe0?_kn`3lo?`0lo?c0P3inOT01P3oool0n_[j0?Win@3inOT0oOgm
0?[jnP80moOg00<0k>c/0?_kn`3]kNd05P3oool01@3jn_X0oooo0?ooo`3oool0n_[j0080oooo00<0
n_[j0?ooo`3oool0;`3oool002H0oooo1@3jn_X30?ooo`030?[jnP3oool0oooo0200oooo00L0W9bL
0<c<c02LW9`0GUiN0?Cdm03moOd0no_k0080oooo00<0n_[j0?ooo`3hn?P00`3oool00`3jn_X0oooo
0?gmo@040?ooo`050?[jnP3oool0oooo0?[jnP3hn?P00P3oool0103fm_H0moOg0?Shn03hn?P20?[j
nP0=0?_kn`3clo<0m_Kf0?Shn03emOD0moOg0?ooo`3jn_X0o_kn0?Cdm03moOd0nOWi0?_kn`020?oo
o`060?[jnP3moOd0o_kn0?gmo@3jn_X0no_k0P3gmoL00`3hn?P0lo?c0?ooo`0D0?ooo`040?[jnP3o
ool0n_[j0?[jnS@0oooo1@3jn_X30?ooo`030?[jnP3oool0oooo0200oooo00L0WIfM0<[:bP2LW9`0
GEeM0??cl`3lo?`0no_k0080oooo00<0n_[j0?ooo`3gmoL00`3oool00`3jn_X0oooo0?clo0040?oo
o`050?[jnP3oool0oooo0?[jnP3gmoL00P3oool0103fm_H0moOg0?Ogm`3gmoL20?Win@0E0?_kn`3c
lo<0m_Kf0?Ogm`3emOD0m_Kf0?ooo`3inOT0oOgm0?Cdm03moOd0nOWi0?clo03moOd0oooo0?Win@3m
oOd0o?cl0?gmo@3jn_X0no_k0080moOg00<0m_Kf0??cl`3oool0503oool0103jn_X0oooo0?[jnP3j
n_Xf0?ooo`009@3oool00`3jn_X0oooo0?ooo`020?ooo`<0n_[j503oool20?[jnPd0oooo00L0jn_[
0861P@2d];@0^[Zj0?Cdm03fm_H0oOgm00<0oooo103jn_X40?ooo`030?_kn`3jn_X0oooo0080oooo
00T0n_[j0?ooo`3oool0oooo0?gmo@3alO40lo?c0?_kn`3inOT00`3oool00`3clo<0moOg0?ooo`02
0?[jnP040?ooo`3moOd0m_Kf0?Shn080m_Kf00X0oooo0?[jnP3jn_X0lo?c0?[jnP3lo?`0oooo0?Wi
n@3jn_X0no_k0P3lo?`00`3clo<0kno_0;jn_P080?ooo`030?[jnP3oool0oooo00h0oooo00D0n_[j
0?ooo`3jn_X0n_[j0?ooo`020?[jnR`0oooo00<0n_[j0?ooo`3oool00P3oool30?[jnQ@0oooo0P3j
n_X=0?ooo`070>_[j`21PH40]KFe0;^k^`3dm?@0m_Kf0?clo0030?ooo`@0n_[j103oool00`3kno/0
n_[j0?ooo`020?ooo`090?[jnP3oool0oooo0?ooo`3lo?`0l?3`0??cl`3lo?`0nOWi00<0oooo00<0
lo?c0?KfmP3oool00P3inOT0103oool0oOgm0?KfmP3inOT20?KfmP0:0?ooo`3jn_X0nOWi0?;blP3j
n_X0oOgm0?ooo`3inOT0n_[j0?_kn`80oOgm00<0lo?c0>o_k`2m_Kd0203oool00`3jn_X0oooo0?oo
o`0>0?ooo`050?[jnP3oool0n_[j0?[jnP3oool00P3jn_X_0?ooo`00:`3oool20?[jnR80oooo00H0
moOg03/k>`3Cdm<0EEEE0?ooo`3dm?@20?_kn`040?[jnP3hn?P0n_[j0?ooo`<0n_[j00D0no_k0?oo
o`3moOd0no_k0?gmo@020?ooo`040?[jnP3oool0n_[j0?[jnP80n?Sh00@0oOgm0?7al@3moOd0n?Sh
0P3lo?`01@3_knl0m?Cd0?clo03jn_X0lO7a0080n?Sh00h0mOGe0?KfmP3moOd0lo?c0?Gem@3hn?P0
n_[j0?clo03dm?@0nOWi0?ooo`3jn_X0n?Sh0?_kn`80oOgm00L0oooo0?Win@3oool0lo?c0=OGe`3;
bl/0lO7a0500oooo0P3jn_XR0?ooo`060?Ogm`0l?3`0dm?C05ADE03oool0lo?c0P3kno/0103jn_X0
moOg0?[jnP3oool30?[jnP050?_kn`3oool0o?cl0?_kn`3lo?`00P3oool0103jn_X0oooo0?[jnP3j
n_X20?Ogm`0;0?clo03alO40o?cl0?Win@3lo?`0no_k0>o_k`3clo<0no_k0?Win@3`l?000P3gmoL0
3P3emOD0m_Kf0?gmo@3bl_80mOGe0?Ogm`3jn_X0oOgm0?Cdm03inOT0oooo0?[jnP3gmoL0no_k0P3m
oOd01`3oool0nOWi0?ooo`3clo<0eMGE0<_;b`3alO40C@3oool002H0oooo00<0n_[j0?ooo`3jn_X0
0`3jn_X0103oool0n_[j0?ooo`3jn_XN0?ooo`060?Ogm`2i^KT0b/[:0;Bd]030`<00m?Cd0`3moOd2
0?ooo`030?[jnP3hn?P0oooo0080oooo00H0no_k0?ooo`3oool0oOgm0?_kn`3moOd20?ooo`80n_[j
0`3oool03`3clo<0k^k^0?gmo@3Fe]H0gMgM0>KViP3UiND0i>CT0>GUi@3^k^h0l?3`0?clo03clo<0
n?Sh0?Win@020?[jnP050?clo03oool0o?cl0?clo03inOT00P3oool0303moOd0n_[j0?gmo@3jn_X0
o?cl0?knoP3oool0n_[j0?clo03oool0fMWI0<c<c0`0oooo0`3jn_X>0?ooo`030?[jnP3oool0oooo
02/0oooo00<0n_[j0?ooo`3jn_X00`3jn_X0103oool0n_[j0?ooo`3jn_XN0?ooo`060?Ogm`2j^[X0
b/[:0;Fe]@30`<00m?Cd0`3lo?`20?ooo`030?[jnP3gmoL0oooo0080oooo00H0no_k0?ooo`3oool0
o?cl0?_kn`3lo?`20?ooo`80n_[j0`3oool01P3bl_80k>c/0?clo03AdM40fMWI0>;RhP80gmoO00D0
hN7Q0>[ZjP3^k^h0no_k0??cl`020?Win@80n_[j00D0oOgm0?ooo`3moOd0oOgm0?Win@020?ooo`03
0?gmo@3jn_X0oOgm0080no_k00L0o?cl0?ooo`3jn_X0oOgm0?ooo`3Hf=P0bl_;00`0oooo0`3jn_X>
0?ooo`030?[jnP3oool0oooo02d0oooo000W0?ooo`040?[jnP3oool0oooo0?ooo`80n_[j8@3oool0
1@3^k^h0?Shn0>GUi@2?Shl0lO7a00H0oOgm0P3jn_X20?ooo`030?gmo@3gmoL0oooo0080oooo00<0
oOgm0?ooo`3oool00P3hn?P30?[jnP0C0?ooo`3/k>`0oooo0=_Kf`3QhN40moOg0?;blP3oool0m?Cd
0?ooo`3hn?P0oooo0?[jnP3/k>`0g]kN0?7al@3kno/0n_[j0?clo0020?[jnP050?_kn`3lo?`0n_[j
0?[jnP3lo?`00P3jn_X01P3oool0n_[j0?gmo@3oool0n_[j0?Win@80moOg00<0h^;R0=_Kf`3oool0
4@3oool00`3jn_X0oooo0?ooo`020?ooo`@0n_[j2@3oool00`3jn_X0oooo0?ooo`0T0?ooo`040?[j
nP3oool0oooo0?ooo`80n_[j8@3oool01@3^k^h0?Shn0>CTi02?Shl0lO7a00H0o?cl0P3jn_X20?oo
o`030?clo03fm_H0oooo0080oooo00<0o?cl0?ooo`3oool00P3gmoL30?[jnP0C0?ooo`3Zj^X0oooo
0=GEe@3MgMd0m?Cd0?7al@3oool0lo?c0?ooo`3inOT0oooo0?KfmP3Zj^X0gMgM0>o_k`3lo?`0nOWi
0?gmo@020?Win@050?_kn`3lo?`0n_[j0?[jnP3moOd00P3kno/0103oool0no_k0?gmo@3oool20?Wi
n@80moOg00<0hN7Q0=cLg03oool04@3oool00`3jn_X0oooo0?ooo`020?ooo`@0n_[j2@3oool00`3j
n_X0oooo0?ooo`0U0?ooo`009@3oool00`3jn_X0oooo0?ooo`020?ooo`030?[jnP3oool0n_[j0240
oooo00@0L71`06m_K`1UIFD0k^k^0P3moOd0203kno/0oOgm0?_kn`3kno/0nOWi0?[jnP3oool0oOgm
0P3kno/20?Win@80n_[j00<0m?Cd0?ooo`3jn_X00`3jn_X02@3oool0inOW0>c/k03oool0hn?S0?oo
o`3MgMd0k^k^0?gmo@020?ooo`030?Shn03]kNd0oooo0080m?Cd00<0oooo0?[jnP3hn?P00P3moOd0
2@3jn_X0nOWi0??cl`3lo?`0oOgm0?Win@3gmoL0n_[j0?ooo`020?[jnP080?ooo`3jn_X0no_k0?oo
o`3gmoL0l_;b0?Ogm`3>c/h<0?ooo`80n_[j5@3oool00`3jn_X0oooo0?ooo`0S0?ooo`030?[jnP3o
ool0oooo0080oooo00<0n_[j0?ooo`3jn_X08@3oool0101`L700Kfm_06ATI03]kNd20?clo0080?_k
n`3lo?`0no_k0?_kn`3inOT0n_[j0?ooo`3lo?`20?_kn`80nOWi0P3jn_X00`3dm?@0oooo0?[jnP03
0?[jnP090?ooo`3Vi^H0j^[Z0?ooo`3QhN40oooo0=SHf03Zj^X0oOgm0080oooo00<0m?Cd0>_[j`3o
ool00P3clo<00`3oool0m_Kf0?Cdm0020?clo0090?_kn`3inOT0l_;b0?clo03moOd0nOWi0?Ogm`3j
n_X0oooo0080n_[j00P0oooo0?[jnP3kno/0oooo0?Ogm`3alO40moOg0<c<c0`0oooo0P3jn_XE0?oo
o`030?[jnP3oool0oooo02H0oooo000Z0?ooo`80n_[j8@3oool01P3@d=00@4100>o_k`21PH40k>c/
0?ooo`@0oOgm00`0moOg0?gmo@3oool0oooo0?_kn`3oool0n_[j0?Cdm03lo?`0oooo0?Cdm03clo<2
0?ooo`80n_[j01d0k>c/0>OWi`3inOT0nOWi0?ooo`36a/H0c<c<0<W9b@3Kfm/0n?Sh0>CTi03YjNT0
i>CT0?;blP3inOT0m?Cd0?7al@3moOd0m?Cd0?Ogm`3WinL0m?Cd0?KfmP3jn_X0m?Cd0?_kn`3gmoL0
nOWi0?clo0030?[jnP0;0?Shn03jn_X0n_[j0?[jnP3oool0n_[j0?KfmP3emOD0j^[Z0<[:bP3alO40
2P3oool00`3jn_X0oooo0?ooo`0D0?ooo`030?[jnP3oool0oooo02P0oooo0P3jn_XQ0?ooo`060=3@
d00n?Sh0l_;b08:2PP3/k>`0oooo103lo?`0303fm_H0o?cl0?ooo`3oool0no_k0?ooo`3jn_X0m?Cd
0?gmo@3oool0m?Cd0?;blP80oooo0P3jn_X07@3Zj^X0i^KV0?KfmP3fm_H0oooo0<71`@36a/H0`L71
0=GEe@3emOD0gMgM0>CTi03Lg=`0lO7a0?KfmP3clo<0l?3`0?gmo@3clo<0no_k0>;RhP3`l?00m_Kf
0?[jnP3clo<0nOWi0?KfmP3inOT0oOgm00<0n_[j00/0moOg0?[jnP3jn_X0nOWi0?ooo`3jn_X0m_Kf
0?Cdm03WinL0b/[:0?7al@0:0?ooo`030?[jnP3oool0oooo01@0oooo00<0n_[j0?ooo`3oool09P3o
ool002H0oooo00@0n_[j0?ooo`3jn_X0oooo0`3jn_XO0?ooo`0:0?Gem@27QhL0dM7A03dm?@3gmoL0
oooo0?_kn`3oool0oOgm0?Win@80oOgm0`3oool02@3moOd0oooo0?Shn03inOT0o?cl0?Cdm03fm_H0
n_[j0?ooo`020?[jnP030?7al@3oool0oooo0080k>c/00D0fm_K0>OWi`3WinL0jn_[0?Ogm`020?oo
o`80kNg]00<0j^[Z0>g]k@3oool00P3dm?@04`3oool0l?3`0>k^kP3[jn/0l?3`0?gmo@3fm_H0no_k
0?Shn03jn_X0nOWi0?[jnP3hn?P0n_[j0?Shn03oool0moOg0?[jnP3lo?`00P3jn_X0103emOD0n_[j
0;Rh^03jn_Y80?ooo`040?[jnP3oool0n_[j0?ooo`<0n_[j7`3oool02P3emOD0R8R80<o?c`0l?3`0
m_Kf0?ooo`3kno/0oooo0?clo03inOT20?clo0<0oooo00T0o?cl0?ooo`3gmoL0nOWi0?gmo@3clo<0
m_Kf0?[jnP3oool00P3jn_X00`3`l?00oooo0?ooo`020>[ZjP070=OGe`3Rh^80hn?S0>OWi`3fm_H0
o?cl0?ooo`020>[ZjP030>GUi@3/k>`0oooo0080kno_01<0oooo0>k^kP3/k>`0j>SX0?7al@3moOd0
mOGe0?Win@3fm_H0n_[j0?Win@3jn_X0moOg0?[jnP3gmoL0oOgm0?Ogm`3jn_X0oOgm0080n_[j00@0
mOGe0?[jnP2f][H0n_[jBP3oool002H0oooo0P3jn_X30?ooo`030?[jnP3oool0n_[j01h0oooo00H0
PH610<_;b`0:2PX0l_;b0?Ogm`3moOd30?ooo`030?[jnP3hn?P0n_[j00<0oooo00D0oOgm0?7al@3k
no/0n_[j0?3`l0030?Gem@030?Shn03jn_X0oooo0080oooo0240g=cL0>KViP3YjNT0inOW0?[jnP3J
f]X0g]kN0<O7a`3:b/X0d=3@0<k>cP31`L40clo?0?KfmP3gmoL0m?Cd0?Ogm`3oool0moOg0?Gem@3f
m_H0oooo0?7al@3emOD0m?Cd0?knoP3gmoL0n?Sh0?[jnP3oool0n_[j0?Gem@3oool00P3jn_X0203g
moL0o?cl0?Ogm`3inOT0oooo0=OGe`3`l?00n_[jA`3oool20?[jnP<0oooo00<0n_[j0?ooo`3jn_X0
7P3oool01P22PX80c<c<00X:2P3bl_80moOg0?clo0<0oooo00<0n_[j0?Ogm`3jn_X00`3oool01@3l
o?`0lO7a0?clo03inOT0kno_0080mOGe00<0m?Cd0?Ogm`3jn_X00`3oool02@3IfMT0h^;R0>CTi03T
i>@0mOGe0=?Cd`3MgMd0_[jn0<G5a@020<K6aP0F0;Rh^034a<@0lO7a0?Ogm`3clo<0moOg0?clo03d
m?@0lO7a0?Cdm03oool0l?3`0??cl`3bl_80o?cl0?KfmP3gmoL0n_[j0?ooo`3jn_X0mOGe0?ooo`80
n_[j00P0m_Kf0?gmo@3gmoL0nOWi0?ooo`3EeMD0l?3`0?[jnTT0oooo000U0?ooo`030?[jnP3oool0
oooo00H0n_[j00T0oooo0?[jnP3jn_X0oooo0?[jnP3oool0n_[j0?ooo`3jn_X04`3oool01`3gmoL0
/[:b0<71`@3YjNT0K6a/0?7al@3oool00P3kno/0103oool0moOg0?Shn03dm?@20?[jnP050?ooo`3j
n_X0n_[j0?7al@3fm_H00`3dm?@07`3^k^h0mOGe0?3`l03dm?@0h^;R0>o_k`3WinL0g=cL0<S8b03H
f=P0j>SX0=_Kf`3Shn<0l?3`0>[ZjP3Ti>@0n_[j0=OGe`3=cLd0jNWY0=7Ad@39bLT0h>3P0>;RhP3@
d=00moOg0??cl`3kno/0m_Kf0?knoP3gmoL00P3dm?@04`3gmoL0oooo0?ooo`3hn?P0oOgm0?Win@3k
no/0n_[j0?Win@3lo?`0oooo0?Shn03lo?`0oooo0??cl`39bLT0moOg0?ooo`3alO40A03oool00`3j
n_X0oooo0?ooo`060?[jnP090?ooo`3jn_X0n_[j0?ooo`3jn_X0oooo0?[jnP3oool0n_[j01<0oooo
00L0moOg0;:b/P31`L40inOW06a/K03`l?00oooo0080no_k00@0oooo0?Ogm`3gmoL0lo?c0P3jn_X0
9`3oool0n_[j0?[jnP3alO40m_Kf0?Cdm03clo<0m?Cd0>c/k03emOD0kno_0?Cdm03Ph>00kno_0>;R
hP3EeMD0`l?30=?Cd`3UiND0fMWI0>CTi03`l?00inOW0>CTi03jn_X0dm?C0<W9b@3Zj^X0cLg=0<O7
a`3IfMT0h>3P0=GEe@3gmoL0kNg]0?[jnP3dm?@0oooo0?KfmP020?;blP0C0?KfmP3oool0oooo0?Og
m`3moOd0nOWi0?clo03jn_X0nOWi0?gmo@3oool0moOg0?gmo@3oool0lo?c0<S8b03gmoL0oooo0?7a
l@170?ooo`00:P3oool00`3jn_X0oooo0?ooo`020?[jnQ00oooo00<0n_[j0?ooo`3oool0203oool0
3@2m_Kd0Z:RX0;Fe]@29RHT0g=cL0?Ogm`3oool0oOgm0?ooo`3jn_X0lO7a0?KfmP3Zj^X00P3jn_X2
0?gmo@0X0?7al@3jn_X0jn_[0>;RhP3Xj>P0fMWI0>WYj@3AdM40e]KF0>CTi037alL0R8R80;Fe]@2F
UYH0lo?c0=cLg03UiND0oooo0:ZZZP23Ph<0S8b<0;Rh^03[jn/0hn?S0>g]k@32`/80]kNg0=GEe@3`
l?00g=cL0=WIf@3Vi^H0dm?C0>WYj@3WinL0n_[j0?Ogm`3kno/0moOg0?Shn080oooo00H0n?Sh0?Ge
m@3hn?P0oOgm0?Cdm03emOD20?ooo`080?Shn03inOT0n?Sh0?[jnP3UiND0c/k>0>7Qh@3alO4J0?oo
o`80n_[j;@3oool00`3jn_X0oooo0?ooo`020?[jnQ00oooo00<0n_[j0?ooo`3oool0203oool03@2n
_[h0Z:RX0;Fe]@29RHT0gMgM0?Ogm`3oool0o?cl0?ooo`3jn_X0lO7a0?KfmP3Xj>P00P3jn_X20?cl
o00X0?7al@3inOT0j^[Z0>3Ph03Vi^H0e]KF0>SXj03>c/h0dM7A0=kNgP33`l<0OWin0;Bd]026QXH0
kno_0=GEe@3QhN40oooo0:>SX`1jNWX0QHF50;Fe]@3Shn<0fm_K0>SXj02h^;P0[Jf]0=?Cd`3^k^h0
fMWI0<c<c03]kNd0d];B0>;RhP3Ogml0n_[j0?KfmP3inOT0m_Kf0?[jnP80oooo00@0moOg0?Gem@3i
nOT0oOgm0P3dm?@20?ooo`080?Ogm`3inOT0moOg0?[jnP3Shn<0c/k>0>7Qh@3alO4J0?ooo`80n_[j
:`3oool002D0oooo00<0n_[j0?ooo`3oool00P3oool01@3jn_X0oooo0?[jnP3oool0n_[j0100oooo
00<0n_[j0?ooo`3oool0203oool03@2PX:00i^KV0:>SX`1:BTX0no_k0?ooo`3moOd0oooo0?_kn`3d
m?@0nOWi0?KfmP3WinL00P3oool20?gmo@0F0?ooo`3^k^h0k>c/0?;blP3clo<0iNGU0?Gem@3:b/X0
fMWI0;bl_03@d=00MgMg05YJFP39bLT0/k>c0:VYZ@2o_kl0gmoO0<o?c`3oool0m_Kf0?7al@80/K6a
01P0][Jf0:2PX02g]kL0jn_[0>CTi03fm_H0j>SX0?;blP3Shn<0eMGE0??cl`3YjNT0m_Kf0?_kn`3o
ool0mOGe0?gmo@3oool0n?Sh0?KfmP3dm?@0oOgm0?KfmP3hn?P30?ooo`080?Gem@3oool0moOg0>[Z
jP3^k^h0j^[Z0<g=c@3jn_XF0?ooo`80n_[j:`3oool00`3jn_X0oooo0?ooo`020?ooo`050?[jnP3o
ool0n_[j0?ooo`3jn_X0403oool00`3jn_X0oooo0?ooo`080?ooo`0=0:2PX03Vi^H0XZ:R04];B`3k
no/0oooo0?clo03oool0no_k0??cl`3inOT0m_Kf0>KViP020?ooo`80o?cl02h0oooo0>g]k@3[jn/0
l_;b0?3`l03Ti>@0m?Cd0<?3``3Fe]H0_[jn0<S8b01WIfL0Cdm?0<K6aP2YZJT0WIfM0;Vi^@3IfMT0
cLg=0?ooo`3fm_H0lO7a0:NWY`2XZ:P0[jn_09NGU`2^[Zh0iNGU0>3Ph03dm?@0i^KV0?7al@3YjNT0
eMGE0>k^kP3Ti>@0m?Cd0?Win@3oool0m_Kf0?gmo@3oool0moOg0?KfmP3dm?@0oOgm0P3gmoL30?oo
o`080?Gem@3oool0moOg0>[ZjP3]kNd0j^[Z0<g=c@3jn_XF0?ooo`80n_[j;P3oool002H0oooo00<0
n_[j0?ooo`3jn_X01P3oool20?[jnP030?ooo`3jn_X0oooo01H0oooo00D0bl_;0<k>cP3fm_H0ZZZZ
0?ooo`020?gmo@030?Win@3jn_X0n_[j0080lo?c01d0oOgm0?ooo`3jn_X0n_[j0?_kn`3emOD0lo?c
0?KfmP3/k>`0kno_0<C4a02l_;`0`<300<O7a`2CTi<0f][J0??cl`3UiND0oooo0?Win@3gmoL0oooo
0=[JfP3gmoL0oooo0??cl`3gmoL0hN7Q0?7al@030?ooo`0A0<G5a@3Rh^80lo?c0?Win@3dm?@0k>c/
0>GUi@3Fe]H0kno_0>[ZjP3fm_H0no_k0?Shn03gmoL0oooo0??cl`3moOd00P3fm_H0103inOT0lo?c
0?Shn03lo?`20?[jnP080?clo03oool0n?Sh0=;BdP3Ti>@0d];B0>[ZjP3jn_Y30?ooo`030?[jnP3o
ool0n_[j00H0oooo0P3jn_X00`3oool0n_[j0?ooo`0F0?ooo`050<_;b`3>c/h0m_Kf0:RXZ03oool0
0P3lo?`00`3inOT0n_[j0?[jnP020??cl`0M0?clo03oool0n_[j0?[jnP3kno/0mOGe0?7al@3fm_H0
jn_[0>k^kP2m_Kd0/K6a0;jn_P35aLD0TI6A0=WIf@3clo<0hn?S0?ooo`3inOT0moOg0?ooo`3Hf=P0
moOg0?ooo`3clo<0m_Kf0=oOg`3alO400`3oool04@2n_[h0g]kN0?Gem@3alO40m?Cd0?3`l03^k^h0
eMGE0>[ZjP3UiND0m_Kf0?Win@3jn_X0m_Kf0?ooo`3bl_80oOgm0080m_Kf00@0nOWi0?;blP3gmoL0
oOgm0P3jn_X0203moOd0oooo0?Ogm`3@d=00i>CT0=?Cd`3Zj^X0n_[jA@3oool002H0oooo00L0n_[j
0?ooo`3jn_X0n_[j0?ooo`3jn_X0oooo00<0n_[j0`3oool00`3jn_X0oooo0?ooo`0<0?ooo`<0lO7a
0140moOg0?[jnP3oool0oooo0>k^kP2e]KD0iNGU0;>c/`3^k^h0m_Kf0?gmo@3kno/0oooo0?[jnP3i
nOT0m_Kf0>OWi`040?ooo`0<0?_kn`3[jn/0m_Kf0>k^kP3oool0c<c<0;no_`3Cdm<0j>SX0:RXZ03/
k>`0lo?c0P3gmoL0303alO40o?cl0?Ogm`3clo<0l?3`0?Gem@3jn_X0m_Kf0?Ogm`3Zj^X0i^KV0>g]
k@80lO7a0100fm_K0>GUi@3=cLd0Shn?0?3`l03Kfm/0l?3`0;bl_03Ph>00j>SX0>k^kP3clo<0nOWi
0?clo03oool0nOWi0P3gmoL00`3oool0m?Cd0?Cdm0020?ooo`030?[jnP3emOD0o?cl0080oooo00H0
i^KV0>?Sh`3Kfm/0o?cl0?[jnP3]kNe20?ooo`070?[jnP3oool0n_[j0?[jnP3oool0n_[j0?ooo`03
0?[jnP<0oooo00<0n_[j0?ooo`3oool0303oool30?7al@0A0?Ogm`3jn_X0oooo0?ooo`3^k^h0][Jf
0>CTi02c/k<0kNg]0?KfmP3lo?`0no_k0?ooo`3jn_X0nOWi0?KfmP3Vi^H0103oool0303kno/0j^[Z
0?KfmP3[jn/0oooo0<?3``2l_;`0dM7A0>7Qh@2TY:@0k^k^0??cl`80m_Kf00L0lO7a0?clo03fm_H0
lo?c0?3`l03emOD0n_[j0080m_Kf00<0j>SX0>KViP3]kNd00P3alO40403Jf]X0iNGU0<k>cP26QXH0
jn_[0>3Ph03`l?00`/;20=gMg@3Ogml0j^[Z0?3`l03gmoL0oOgm0?ooo`3inOT20?KfmP030?ooo`3c
lo<0m?Cd0080oooo00<0n_[j0?Gem@3moOd00P3oool01P3Vi^H0h^;R0=cLg03lo?`0n_[j0>g]kD@0
oooo000b0?ooo`030?[jnP3oool0oooo0080n_[j203oool0103jn_X0oooo0?7al@3oool20?[jnP09
0>k^kP3Vi^H0n_[j0?Cdm02MWId0[:b/0>;RhP1=CDd0n_[j0080oOgm02L0moOg0?gmo@3alO40oooo
0?KfmP3emOD0l_;b0?ooo`3jn_X0n?Sh0?Cdm03Ti>@0k^k^0>_[j`3emOD0l_;b0>?Sh`3bl_80bLW9
0=OGe`3MgMd0[Zj^0<O7a`3dm?@0h^;R0>k^kP3lo?`0iNGU0>7Qh@3UiND0moOg0>k^kP3Ti>@0jNWY
0<S8b03Ph>00lO7a0?ooo`3AdM400`3]kNd07`2IVIT0U9BD05=CD`1mOGd0inOW09FEU@3Kfm/0eMGE
0?Cdm03gmoL0oooo0??cl`3dm?@0n_[j0?ooo`3gmoL0o?cl0?Shn03gmoL0mOGe0?Ogm`3lo?`0nOWi
0?[jnP3clo<0m_Kf0:NWY`2YZJT0dM7A0>SXj03alO40C@3oool00`3jn_X0oooo0?ooo`020?[jnPP0
oooo00@0n_[j0?ooo`3alO40oooo0P3jn_X02@3^k^h0i^KV0?[jnP3dm?@0WIfM0:b/[03Ph>00C4a<
0?[jnP020?clo00<0?KfmP3lo?`0lO7a0?ooo`3fm_H0mOGe0?3`l03oool0n_[j0?Ogm`3clo<0h>3P
0P3[jn/20?7al@0G0>7Qh@3`l?00`L710=OGe`3Jf]X0ZJVY0<;2`P3clo<0h>3P0>g]k@3lo?`0i>CT
0>3Ph03Ti>@0moOg0>g]k@3Rh^80jNWY0<G5a@3Ogml0lO7a0?ooo`3?cll00`3^k^h07`2?Shl0T92@
04m?C`1jNWX0l_;b09ZJVP3EeMD0c<c<0??cl`3dm?@0oooo0?;blP3dm?@0nOWi0?ooo`3fm_H0no_k
0?Win@3gmoL0mOGe0?Ogm`3moOd0nOWi0?[jnP3bl_80m_Kf0:JVYP2ZZZX0d];B0>SXj03alO40@`3o
ool002H0oooo0P3jn_XP0?ooo`060>c/k027QhL0bl_;0?_kn`1nOWh0lO7a0P3kno/0203jn_X0oooo
0?3`l03lo?`0mOGe0?7al@3UiND0oooo0P3jn_X03@3dm?@0f][J0?3`l03[jn/0m_Kf0<k>cP3Ng]h0
hn?S0<?3``3fm_H0g=cL0?3`l03Cdm<00P3dm?@06P3Shn<0moOg0=oOg`3/k>`0jn_[0??cl`3[jn/0
fm_K0??cl`3/k>`0j>SX0?7al@3oool0gMgM0>[ZjP3]kNd0n?Sh0>3Ph03Zj^X0bl_;0:6QX@1VIVH0
^KVi0>SXj03Ph>00j>SX0P3jn_X00`3clo<0lO7a0?Shn0020?[jnP80m?Cd00@0oooo0?Ogm`3lo?`0
o_kn0P3jn_X01@3`l?00mOGe09NGU`30`<00j>SX0080hN7Q3@3oool00`3jn_X0oooo0?ooo`0a0?oo
o`80n_[j803oool01P3/k>`0R8R80<c<c03jn_X0OGem0?7al@80no_k00P0n_[j0?ooo`3`l?00oOgm
0?Cdm03`l?00hn?S0?ooo`80n_[j0180lo?c0=OGe`3^k^h0jn_[0?Gem@3;bl/0gmoO0>7Qh@2m_Kd0
m?Cd0=WIf@3^k^h0clo?0??cl`3dm?@0h>3P0?KfmP3MgMd20>[ZjP0E0??cl`3Zj^X0fMWI0?7al@3[
jn/0i^KV0?7al@3oool0f][J0>[ZjP3^k^h0nOWi0=kNgP3Zj^X0b/[:09jNWP1WIfL0a<C40>KViP3K
fm/0i^KV0080nOWi00<0l_;b0?7al@3gmoL00P3inOT01P3dm?@0mOGe0?ooo`3gmoL0oOgm0?clo080
n_[j00D0kno_0??cl`2FUYH0`L710>SXj0020>7Qh@d0oooo00<0n_[j0?ooo`3oool0<`3oool002H0
oooo00@0n_[j0?ooo`3jn_X0oooo0`3jn_X00`3oool0n_[j0?ooo`020?[jnP030?ooo`3jn_X0oooo
0080n_[j403oool0403Zj^X0QhN707]kN`3Xj>P0dm?C0>g]k@3`l?00m?Cd0?gmo@3oool0m?Cd0?Kf
mP3WinL0moOg0?KfmP3UiND20?ooo`110?gmo@3YjNT0fm_K0?[jnP3WinL0hn?S0=gMg@37alL0WinO
0;Ng]`3jn_X0oOgm0?KfmP3/k>`0dM7A0=cLg033`l<0c<c<0<S8b03Ti>@0l_;b0>WYj@31`L40i^KV
0>?Sh`3WinL0i>CT0=cLg03GemL0i^KV0=CDe03clo<0k>c/0?Cdm03oool0m?Cd0>k^kP3?cll0`L71
0=cLg03Kfm/0emOG0?_kn`3jn_X0oooo0?Gem@3hn?P0n_[j0??cl`3oool0l_;b0?Ogm`3kno/0o?cl
0?[jnP3oool0n?Sh0?ooo`3lo?`0jNWY0>CTi03emOD0moOg0>;RhP3^k^h0@03oool0103jn_X0oooo
0?[jnP3oool30?[jnP030?ooo`3jn_X0oooo0080n_[j00<0oooo0?[jnP3oool00P3jn_X@0?ooo`0@
0>[ZjP27QhL0O7al0>_[j`3EeMD0k>c/0>o_k`3clo<0o?cl0?ooo`3clo<0m_Kf0>KViP3gmoL0m_Kf
0>?Sh`80oooo01T0o?cl0>SXj03GemL0n_[j0>CTi03QhN40emOG0;no_`2DU9@0/;2`0?KfmP3lo?`0
lo?c0>SXj03=cLd0f=SH0;^k^`39bLT0`L710>;RhP3alO40j>SX0;^k^`3QhN40gMgM0080hN7Q02H0
fMWI0=CDe03Shn<0dM7A0??cl`3Zj^X0l_;b0?ooo`3clo<0kNg]0<o?c`2g]kL0fm_K0=WIf@3>c/h0
no_k0?Win@3oool0mOGe0?Ogm`3inOT0lo?c0?ooo`3bl_80moOg0?_kn`3moOd0nOWi0?ooo`3gmoL0
oooo0?_kn`3YjNT0i>CT0?Gem@3gmoL0h^;R0>k^kT80oooo00150?ooo`0C0?[jnP3De=@0Jf][0<71
`@3emOD0l?3`05iNGP3alO40lo?c0?gmo@3oool0nOWi0?Gem@3clo<0moOg0?[jnP3]kNd0l?3`0?gm
o@020?ooo`0A0?KfmP3;bl/0fMWI0?7al@3clo<0oOgm0>o_k`3Xj>P0h>3P0<g=c@3Shn<0gmoO0>;R
hP3De=@0gmoO0=SHf03;bl/00P3Vi^H0803`l?00i^KV0=gMg@3clo<0l?3`0?Cdm03oool0iNGU0>?S
h`3no_h0b<S80>7Qh@3Cdm<0e]KF0>GUi@3GemL0jNWY0=CDe02XZ:P0kNg]0?3`l036a/H0l?3`0?gm
o@3hn?P0l_;b0?ooo`3jn_X0moOg0?Cdm03kno/0nOWi0P3oool0203moOd0n_[j0?Ogm`3jn_X0oooo
0<C4a03Zj^X0c<c<0P3Zj^X00`3Ti>@0oooo0?ooo`1M0?ooo`0C0?[jnP3De=@0Jf][0<71`@3dm?@0
l_;b065QH@3alO40lo?c0?clo03oool0nOWi0?Cdm03clo<0moOg0?Win@3/k>`0kno_0?clo0020?oo
o`0A0?Gem@33`l<0eMGE0?7al@3bl_80o?cl0>k^kP3WinL0g]kN0<S8b03Rh^80f][J0=gMg@3=cLd0
emOG0=?Cd`33`l<00P3QhN400`3_knl0hN7Q0=OGe`020?3`l00>0??cl`3oool0gmoO0>7Qh@3lo?`0
`L710>3Ph03@d=00clo?0>GUi@3GemL0j>SX0=GEe@2WYjL20>k^kP0;0<30`03^k^h0oOgm0?Ogm`3a
lO40oooo0?Win@3fm_H0lo?c0?clo03inOT00P3oool0203moOd0n_[j0?Ogm`3jn_X0oooo0<?3``3Z
j^X0c<c<0P3Zj^X00`3UiND0oooo0?ooo`100?ooo`009@3oool01@3jn_X0oooo0?ooo`3jn_X0oooo
00<0n_[j0`3oool00`3jn_X0oooo0?ooo`0A0?ooo`090>_[j`3AdM40:b/[0=WIf@3Vi^H0k^k^0:RX
Z013@d<0kNg]00<0oOgm0140n?Sh0?clo03emOD0no_k0?[jnP3^k^h0n?Sh0?ooo`3moOd0oooo0?7a
l@3IfMT0hN7Q0<k>cP3inOT0lO7a0?ooo`050?[jnP0e0?gmo@3WinL0i>CT0=oOg`3Ti>@0h>3P0=_K
f`3Rh^80e]KF0=[JfP3Ogml0emOG0>3Ph03Hf=P0h^;R0=[JfP3IfMT0lo?c0>_[j`3Vi^H0k>c/0=KF
eP3IfMT0dm?C0<C4a02k^k/0l?3`0>GUi@3Vi^H0[Jf]0?;blP3clo<0m_Kf0?ooo`3hn?P0oooo0?7a
l@3bl_80n_[j0?gmo@3hn?P0no_k0?Win@3gmoL0mOGe0?[jnP2l_;`0D51@0=gMg@3`l?00k>c/0>7Q
h@3alO40?P3oool01@3jn_X0oooo0?ooo`3jn_X0oooo00<0n_[j0`3oool00`3jn_X0oooo0?ooo`0A
0?ooo`090>_[j`3AdM40;2`/0=WIf@3Xj>P0kno_0:^[Z`12@T80k>c/00<0o?cl0140moOg0?gmo@3d
m?@0o?cl0?Win@3^k^h0moOg0?ooo`3lo?`0oooo0?3`l03EeMD0gMgM0<W9b@3inOT0l?3`0?ooo`05
0?[jnP0H0?clo03Vi^H0h^;R0=gMg@3Rh^80gmoO0=OGe`3Ogml0dM7A0=GEe@3Jf]X0dM7A0=[JfP3C
dm<0h>3P0=;BdP3Fe]H0lO7a0>KViP3Rh^80j>SX0=7Ad@3EeMD0b/[:0P2n_[h06`3clo<0inOW0=cL
g02VYZH0l?3`0??cl`3emOD0oooo0?Ogm`3oool0lO7a0?;blP3jn_X0oOgm0?KfmP3kno/0nOWi0?Og
m`3dm?@0n_[j0;fm_@1@D500g]kN0?7al@3/k>`0h^;R0?7al@110?ooo`009@3oool0103jn_X0oooo
0?ooo`3jn_X70?ooo`030?[jnP3oool0oooo0140oooo00X0e]KF0:FUY@13@d<0jn_[0>o_k`3Ph>00
K6a/09>CT`3fm_H0moOg0P3dm?@00`3jn_X0nOWi0?gmo@020?_kn`0<0?[jnP3emOD0m?Cd0?gmo@3g
moL0n_[j0?_kn`3UiND0i^KV0>WYj@3kno/0oooo0P3jn_X20?ooo`030?[jnP3oool0n_[j0080n_[j
0`3oool07P3_knl0l?3`0??cl`3alO40o?cl0?_kn`3[jn/0mOGe0>CTi03Shn<0m_Kf0>[ZjP3[jn/0
j>SX0?[jnP3dm?@0f][J0>;RhP39bLT0_kno0<k>cP3Fe]H0f=SH0?Cdm03gmoL0kno_0?Ogm`3clo<0
moOg0?Cdm080n?Sh00D0nOWi0?Ogm`3kno/0m_Kf0?Shn0020?[jnP040<g=c@3Rh^80U9BD0>CTi080
kNg]00<0jn_[0?ooo`3oool0?03oool0103jn_X0oooo0?ooo`3jn_X70?ooo`030?[jnP3oool0oooo
0140oooo01d0e]KF0:JVYP10@400k>c/0?7al@3Rh^80IfMW09:BTP3fm_H0moOg0??cl`3dm?@0n_[j
0?Win@3moOd0no_k0?clo03inOT0mOGe0?Cdm03lo?`0moOg0?Win@3jn_X0hn?S0>CTi03WinL0no_k
0?ooo`020?[jnP80oooo00<0n_[j0?ooo`3jn_X00P3jn_X30?ooo`0U0>k^kP3`l?00lo?c0?7al@3m
oOd0o?cl0>[ZjP3bl_80g]kN0>7Qh@3alO40i^KV0>[ZjP3Ti>@0nOWi0?Gem@3EeMD0gmoO0<[:bP2l
_;`0d=3@0=GEe@3De=@0m?Cd0?KfmP3_knl0m_Kf0?;blP3fm_H0lo?c0?Win@3gmoL0nOWi0?KfmP3i
nOT0m_Kf0?Ogm`020?[jnP040<o?c`3QhN40UIFE0>GUi@80kNg]00<0jn_[0?ooo`3oool0?`3oool0
0300oooo00<0n_[j0?ooo`3oool04@3oool03`3Bd]80_[jn06YZJP3Hf=P0k^k^0?Win@1:BTX0_Kfm
0?ooo`3dm?@0o?cl0?Cdm03lo?`0oOgm0?Cdm0020?KfmP0<0?Ogm`3clo<0m?Cd0?gmo@3alO40m_Kf
0?Win@3YjNT0l_;b0>7Qh@3kno/0n_[j0P3hn?P20?ooo`0;0?Shn03oool0n_[j0?[jnP3hn?P0oooo
0?gmo@3inOT0k^k^0?[jnP3emOD00P3fm_H0:@3emOD0n_[j0?7al@3alO40moOg0?3`l03fm_H0lO7a
0??cl`3WinL0jNWY0>c/k03IfMT0_Kfm0:VYZ@2`/;00d];B0=[JfP3`l?00lO7a0>o_k`3dm?@0n?Sh
0?Ogm`3moOd0l_;b0?Ogm`3moOd0moOg0?Win@3bl_80nOWi0?[jnP3oool0i^KV0?;blP1OGel0T92@
0??cl`3alO40jn_[04T0oooo00<0n_[j0?ooo`3oool04@3oool03`3Cdm<0_[jn06QXJ03Lg=`0k^k^
0?Ogm`18B4P0_Kfm0?ooo`3dm?@0no_k0?Cdm03moOd0o?cl0??cl`020?KfmP0<0?Ogm`3bl_80m?Cd
0?clo03alO40m_Kf0?Ogm`3YjNT0lo?c0=kNgP3kno/0n_[j0P3gmoL20?ooo`0;0?Ogm`3oool0n_[j
0?[jnP3gmoL0oooo0?clo03inOT0kNg]0?[jnP3emOD00P3fm_H0:@3emOD0nOWi0?7al@3`l?00m?Cd
0>o_k`3fm_H0k^k^0?7al@3Shn<0iNGU0>KViP3AdM40]kNg0:BTY02/[:`0c/k>0=CDe03_knl0l?3`
0>o_k`3dm?@0moOg0?KfmP3moOd0l_;b0?Ogm`3moOd0m_Kf0?Ogm`3`l?00nOWi0?[jnP3oool0j>SX
0?7al@1MGEd0TI6A0??cl`3alO40jn_[0440oooo000U0?ooo`D0n_[j00<0oooo0?[jnP3oool05`3o
ool04P3MgMd0`l?30820P01oOgl0];Bd0861P@1`L700m?Cd0?3`l03gmoL0oooo0?[jnP3moOd0m?Cd
0?ooo`3emOD0nOWi0?Ogm`@0oooo00H0m_Kf0?Gem@3fm_H0k^k^0=SHf03gmoL20?gmo@050?[jnP3h
n?P0n?Sh0?ooo`3jn_X0103oool0403hn?P0oOgm0?Ogm`3fm_H0n_[j0?ooo`3gmoL0n_[j0?7al@3o
ool0oOgm0?_kn`3inOT0l_;b0?ooo`3inOT40?[jnP0:0?Ogm`3`l?00l_;b0?Cdm03clo<0k^k^0??c
l`3QhN40l_;b0?[jnP80moOg00l0kno_0?Win@3inOT0moOg0?ooo`3gmoL0n?Sh0?clo03oool0moOg
0>k^kP32`/80b<S80<g=c@3alO40?`3oool50?[jnP030?ooo`3jn_X0oooo01L0oooo0180g]kN0<71
`@21PH40OWin0;:b/P20P800KVi^0?Cdm03alO40moOg0?ooo`3jn_X0o?cl0?Cdm03oool0mOGe0?Wi
n@3gmoL40?ooo`060?KfmP3dm?@0m_Kf0>_[j`3EeMD0m_Kf0P3lo?`01@3jn_X0moOg0?Ogm`3oool0
n_[j00@0oooo0100moOg0?clo03gmoL0m_Kf0?Win@3oool0m_Kf0?Win@3`l?00oooo0?gmo@3lo?`0
nOWi0?7al@3oool0nOWi0`3kno/02`3jn_X0moOg0>k^kP3_knl0lO7a0>o_k`3^k^h0lo?c0=oOg`3a
lO40nOWi0080m_Kf00l0kno_0?Win@3inOT0m_Kf0?ooo`3fm_H0moOg0?gmo@3oool0nOWi0>k^kP31
`L40alO70<g=c@3alO40@P3oool004@0oooo01`0`l?309^KV`20P800oooo0?7al@3^k^h0g]kN0?Cd
m03clo<0oOgm0?Ogm`3dm?@0o?cl0?7al@3dm?@0k^k^0?7al@3kno/0oooo0?gmo@3dm?@0oooo0?gm
o@3dm?@0oooo0??cl`3hn?P0k>c/0P3dm?@01`3jn_X0n?Sh0?[jnP3oool0n_[j0?gmo@3oool00P3j
n_X01`3oool0no_k0?[jnP3fm_H0m?Cd0?3`l03fm_H00P3oool01P3gmoL0lO7a0?Gem@3inOT0oOgm
0?7al@80moOg00L0l_;b0??cl`3kno/0nOWi0?_kn`3lo?`0n?Sh0080moOg01@0oooo0=gMg@3WinL0
mOGe0?Ogm`3dm?@0m_Kf0?Ogm`3oool0oOgm0?clo03bl_80o?cl0?Gem@3bl_80m?Cd0?KfmP39bLT0
lo?c0<C4a0H0oooo0P3jn_YG0?ooo`070<?3``2MWId0P8200?ooo`3alO40k^k^0=kNgP020??cl`0L
0?clo03gmoL0lo?c0?gmo@3alO40m?Cd0>g]k@3alO40no_k0?ooo`3lo?`0m?Cd0?ooo`3moOd0lo?c
0?ooo`3bl_80m_Kf0>_[j`3dm?@0lo?c0?[jnP3gmoL0n_[j0?ooo`3jn_X0o?cl0?ooo`80n_[j00L0
oooo0?_kn`3inOT0m_Kf0?Cdm03_knl0m_Kf0080oooo02D0m_Kf0?3`l03emOD0nOWi0?gmo@3_knl0
nOWi0?KfmP3`l?00l_;b0?_kn`3gmoL0no_k0?clo03fm_H0moOg0?KfmP3oool0fm_K0>CTi03emOD0
m_Kf0??cl`3fm_H0moOg0?ooo`3moOd0o?cl0?3`l03moOd0lo?c0?7al@3gmoL0m_Kf0<[:bP3dm?@0
aLG500H0oooo0P3jn_Xk0?ooo`00@`3oool02`3alO40e]KF0?Ogm`3alO40oooo0?_kn`3^k^h0m?Cd
0?Shn03clo<0lO7a0080m?Cd00P0oooo0?gmo@3oool0no_k0?ooo`3kno/0oOgm0?_kn`80oOgm00H0
oooo0>k^kP3clo<0nOWi0?KfmP3Vi^H20>c/k00<0?gmo@3oool0oooo0?[jnP3oool0n?Sh0?gmo@3o
ool0n_[j0?ooo`3emOD0nOWi0P3emOD03@3moOd0mOGe0?7al@3dm?@0n?Sh0>o_k`3alO40moOg0?cl
o03kno/0oooo0?Shn03kno/00P3moOd03P3inOT0n_[j0?clo03inOT0moOg0?[jnP3gmoL0k^k^0=[J
fP3alO40o?cl0?Shn03`l?00mOGe0`3kno/0203inOT0oooo0?clo03lo?`0n_[j0>SXj02LW9`0Y:BT
G`3oool02`3alO40e]KF0?Ogm`3alO40oooo0?_kn`3]kNd0m?Cd0?Win@3clo<0lO7a0080m?Cd00P0
oooo0?clo03oool0no_k0?ooo`3kno/0o?cl0?_kn`80o?cl00T0oooo0>g]k@3bl_80moOg0?KfmP3S
hn<0j^[Z0>_[j`3lo?`00P3oool02@3jn_X0oooo0?Ogm`3lo?`0oooo0?[jnP3oool0mOGe0?Win@02
0?Gem@0=0?gmo@3dm?@0lO7a0??cl`3gmoL0kno_0?7al@3fm_H0o?cl0?gmo@3oool0m_Kf0?[jnP02
0?gmo@80nOWi00`0oOgm0?Ogm`3emOD0no_k0?KfmP3]kNd0f=SH0?7al@3kno/0nOWi0>o_k`3emOD4
0?Win@070?ooo`3moOd0oOgm0?clo03Zj^X0W9bL0:BTY0140?ooo`00@`3oool02`3Vi^H0kNg]0?Cd
m03dm?@0oooo0?gmo@3/k>`0m?Cd0?gmo@3`l?00moOg00<0oooo00<0no_k0?gmo@3kno/00P3moOd0
8P3jn_X0oOgm0?gmo@3oool0nOWi0?Ogm`3`l?00mOGe0?ooo`3hn?P0jn_[0??cl`3dm?@0n_[j0?oo
o`3hn?P0oooo0?Shn03oool0no_k0?Win@3oool0n_[j0?7al@3jn_X0jn_[0?Gem@3^k^h0lo?c0?Sh
n03alO40oooo0?[jnP3kno/20?Ogm`0>0?clo03moOd0o?cl0?gmo@3oool0oOgm0?knoP3inOT0m_Kf
0?Cdm03gmoL0lo?c0>g]k@3alO420?gmo@070?clo03emOD0moOg0?_kn`3inOT0o?cl0?gmo@020?Wi
n@060?[jnP3[jn/0nOWi0<K6aP2OWil0k^k^GP3oool02`3Vi^H0kno_0?Cdm03dm?@0oooo0?clo03/
k>`0m?Cd0?clo03alO40moOg00<0oooo00<0no_k0?clo03kno/00P3lo?`0803jn_X0o?cl0?clo03o
ool0nOWi0?Ogm`3_knl0m?Cd0?ooo`3fm_H0jNWY0?;blP3dm?@0n_[j0?ooo`3gmoL0oooo0?Ogm`3o
ool0no_k0?Win@3oool0n_[j0?7al@3inOT0j^[Z0?Cdm03]kNd0l_;b0?Win@3alO40oooo0P3inOT0
403gmoL0m_Kf0?_kn`3moOd0no_k0?gmo@3oool0oOgm0?ooo`3inOT0moOg0??cl`3fm_H0lo?c0>c/
k03alO420?gmo@070?_kn`3dm?@0m_Kf0?Win@3gmoL0o?cl0?gmo@020?Win@060?_kn`3]kNd0moOg
0<K6aP2PX:00k^k^@`3oool004<0oooo00T0e]KF0>[ZjP3kno/0no_k0?gmo@3inOT0iNGU0?Cdm03l
o?`00P3dm?@00`3clo<0oOgm0?ooo`020?ooo`040?Shn03jn_X0n?Sh0?[jnP80n?Sh00/0oOgm0?7a
l@3lo?`0lo?c0?Ogm`3hn?P0m?Cd0>c/k03alO40m?Cd0?[jnP030?ooo`0C0?[jnP3oool0oooo0?gm
o@3kno/0kNg]0?7al@3`l?00m?Cd0?ooo`3inOT0lO7a0?Shn03oool0o?cl0?ooo`3gmoL0oOgm0?oo
o`030?gmo@80n_[j00`0oOgm0?clo03moOd0oOgm0?Shn03^k^h0moOg0?ooo`3alO40n?Sh0?Cdm03a
lO420?[jnP040?clo03kno/0n?Sh0?_kn`80n_[j00H0m_Kf0>c/k03UiND0QHF507QhN027QhLC0?oo
o`030?[jnP3oool0oooo04P0oooo00T0e]KF0>_[j`3kno/0no_k0?clo03inOT0iNGU0?Cdm03kno/0
0P3dm?@00`3bl_80o?cl0?ooo`020?ooo`040?Ogm`3jn_X0moOg0?[jnP80moOg00/0o?cl0?7al@3m
oOd0lo?c0?KfmP3gmoL0l_;b0>[ZjP3alO40lo?c0?[jnP030?ooo`0C0?[jnP3oool0oooo0?clo03k
no/0k^k^0?7al@3_knl0m?Cd0?ooo`3inOT0lO7a0?Ogm`3oool0o?cl0?ooo`3fm_H0oOgm0?ooo`03
0?gmo@80nOWi0140oOgm0?_kn`3moOd0oOgm0?Ogm`3/k>`0m_Kf0?ooo`3`l?00nOWi0?Cdm03alO40
n_[j0?Win@3lo?`0nOWi0?KfmP020?_kn`070?[jnP3fm_H0kNg]0>GUi@25QHD0N7Qh08N7Q`0C0?oo
o`030?[jnP3oool0oooo02d0oooo00120?ooo`070?7al@3Xj>P0mOGe0?gmo@3_knl0mOGe0>CTi002
0?gmo@030>_[j`3gmoL0n_[j0080m?Cd0P3moOd00`3jn_X0oooo0?ooo`020?Ogm`80n_[j00`0nOWi
0?Cdm03jn_X0mOGe0?ooo`3emOD0kno_0?;blP3emOD0l?3`0?ooo`3hn?P20?ooo`060?[jnP3/k>`0
l_;b0??cl`3gmoL0oOgm0P3fm_H02`3_knl0o_kn0?_kn`3`l?00h^;R0?;blP3gmoL0l_;b0??cl`3l
o?`0oOgm0080o?cl00@0oOgm0?[jnP3oool0nOWi0P3oool20?gmo@070?Ogm`3fm_H0mOGe0?[jnP3f
m_H0oooo0?[jnP020?clo080oooo00<0n_[j0?ooo`3moOd00P3gmoL01@3QhN40l_;b0>g]k@3Ng]h0
S8b<05d0oooo00`0lO7a0>OWi`3emOD0o?cl0>k^kP3emOD0hn?S0?gmo@3lo?`0k>c/0?Ogm`3inOT2
0?Cdm080o?cl00<0n_[j0?ooo`3oool00P3fm_H20?[jnP0<0?Win@3dm?@0nOWi0?Gem@3oool0m?Cd
0>g]k@3bl_80lo?c0>o_k`3oool0moOg0P3oool01P3jn_X0j^[Z0?7al@3bl_80moOg0?clo080m_Kf
00/0k^k^0?ooo`3lo?`0kno_0>3Ph03`l?00m_Kf0?3`l03bl_80no_k0?gmo@020?_kn`040?gmo@3i
nOT0oooo0?[jnP80oooo0P3moOd20?KfmP070?Gem@3jn_X0m_Kf0?gmo@3jn_X0oOgm0?clo0020?oo
o`030?[jnP3oool0no_k0080moOg00D0hn?S0?Gem@3^k^h0g]kN08b<S0130?ooo`00@@3oool0103a
lO40gMgM0?Cdm03oool20?Gem@070>WYj@3emOD0i^KV0?gmo@3fm_H0m?Cd0?Ogm`020?_kn`@0oooo
0100moOg0??cl`3gmoL0moOg0?ooo`3jn_X0oOgm0?Cdm03kno/0lO7a0?KfmP3oool0n?Sh0?ooo`3^
k^h0m?Cd0P3oool04`3jn_X0m?Cd0?Cdm03moOd0no_k0?gmo@3gmoL0kno_0?3`l03oool0moOg0?_k
n`3inOT0n_[j0>KViP3bl_80kNg]0?[jnP3emOD00P3moOd20?clo00=0?ooo`3hn?P0n?Sh0?[jnP3m
oOd0nOWi0?;blP3hn?P0n_[j0?ooo`3jn_X0n?Sh0?KfmP020?ooo`030?KfmP3jn_X0o?cl0080mOGe
00P0no_k0?Win@3dm?@0bLW90>KViP3De=@0F5QH0=KFeU`0oooo00@0lO7a0=_Kf`3dm?@0oooo0P3e
mOD01`3Xj>P0m?Cd0>KViP3lo?`0m_Kf0?Cdm03gmoL00P3kno/40?ooo`0@0?KfmP3clo<0m_Kf0?Kf
mP3oool0n_[j0?clo03clo<0no_k0?7al@3fm_H0oooo0?KfmP3oool0k>c/0??cl`80oooo02@0n_[j
0??cl`3clo<0o?cl0?_kn`3lo?`0moOg0>k^kP3`l?00oooo0?KfmP3kno/0nOWi0?[jnP3UiND0l?3`
0>g]k@3inOT0m_Kf0?_kn`3moOd0no_k0?gmo@3oool0n_[j0?Win@3jn_X0oOgm0?[jnP3`l?00moOg
0?[jnP3oool0nOWi0?Ogm`3fm_H20?ooo`0=0?KfmP3inOT0o?cl0?Gem@3clo<0no_k0?Win@3dm?@0
bl_;0>CTi03Cdm<0FUYJ0=KFeP130?ooo`00@@3oool02`3Ti>@0k>c/0?Cdm03alO40n_[j0>SXj03c
lo<0m?Cd0>;RhP3bl_80kNg]0080oOgm0P3oool20?[jnP030?ooo`3gmoL0moOg00<0moOg00d0oooo
0?[jnP3gmoL0lO7a0?KfmP3oool0n_[j0?Shn03oool0m_Kf0?Shn03alO40n?Sh0080n_[j00H0oooo
0?gmo@3jn_X0n_[j0?ooo`3hn?P20?gmo@090>k^kP3jn_X0lo?c0?Win@3bl_80o?cl0?Win@3Ogml0
nOWi0080n_[j103moOd01P3kno/0moOg0?[jnP3fm_H0m?Cd0?_kn`80n_[j00@0oOgm0?[jnP3jn_X0
mOGe0P3oool01@3jn_X0o?cl0?clo03oool0moOg00<0o?cl00L0[:b/0?ooo`2j^[X0PH6106ATI03V
i^H0n_[j05X0oooo00/0i>CT0>_[j`3dm?@0l?3`0?[jnP3Vi^H0l_;b0??cl`3QhN40l_;b0>o_k`02
0?clo080oooo0P3jn_X00`3oool0m_Kf0?KfmP030?KfmP0=0?ooo`3jn_X0m_Kf0?7al@3emOD0oooo
0?Win@3gmoL0oooo0?KfmP3gmoL0lO7a0?Ogm`020?[jnP060?ooo`3lo?`0n_[j0?[jnP3oool0moOg
0P3lo?`02@3]kNd0nOWi0?;blP3inOT0lO7a0?gmo@3inOT0gMgM0?Ogm`020?_kn`D0oOgm00D0m_Kf
0?_kn`3emOD0l_;b0?[jnP020?Win@040?gmo@3jn_X0n_[j0?Gem@80oooo00D0nOWi0?clo03moOd0
oooo0?Ogm`030?clo0070:f][@3oool0^;Rh0820P01TI6@0i^KV0?[jnP110?ooo`00;@3oool00`3j
n_X0oooo0?ooo`0A0?ooo`0D0=_Kf`3gmoL0oooo0?7al@3jn_X0gmoO0?Gem@3bl_80iNGU0?Shn03]
kNd0lO7a0?Cdm03moOd0no_k0?ooo`3jn_X0oooo0?Ogm`3oool20??cl`0:0?Ogm`3oool0n_[j0?gm
o@3dm?@0l_;b0?Gem@3fm_H0moOg0?_kn`80oooo00<0moOg0>k^kP3oool00P3jn_X07`3oool0n?Sh
0?Shn03jn_X0oooo0?[jnP3dm?@0jn_[0?ooo`3emOD0o?cl0?Ogm`3inOT0o?cl0?Win@3Kfm/0j^[Z
0>;RhP3lo?`0no_k0?clo03moOd0o_kn0?_kn`3dm?@0moOg0?7al@3hn?P0mOGe0?Cdm03oool00P3j
n_X01@3fm_H0oooo0?[jnP3emOD0oooo0080o?cl00/0nOWi0?knoP3dm?@0m?Cd0:RXZ03_knl0l_;b
0>k^kP1gMgL0/[:b0>[ZjP160?ooo`030?[jnP3oool0oooo0140oooo01@0f][J0?KfmP3oool0l?3`
0?[jnP3MgMd0m?Cd0?7al@3Ti>@0nOWi0>k^kP3alO40m?Cd0?clo03kno/0oooo0?[jnP3oool0m_Kf
0?ooo`80lo?c00L0m_Kf0?ooo`3jn_X0o?cl0?Cdm03bl_80mOGe0080m_Kf00H0n_[j0?ooo`3oool0
moOg0>k^kP3oool20?[jnP0V0?ooo`3gmoL0moOg0?[jnP3oool0n_[j0??cl`3Zj^X0oooo0?Gem@3l
o?`0moOg0?Win@3moOd0nOWi0=SHf03YjNT0hN7Q0?gmo@3jn_X0no_k0?gmo@3oool0nOWi0?Cdm03f
m_H0l?3`0?Ogm`3emOD0lo?c0?ooo`3inOT0n_[j0?KfmP3oool0nOWi0?Gem@3oool20?gmo@0;0?Wi
n@3lo?`0m?Cd0?Cdm02YZJT0lO7a0??cl`3]kNd0MWIf0;>c/`3Zj^X0@@3oool002H0oooo00<0n_[j
0?ooo`3oool01P3oool00`3jn_X0oooo0?ooo`0>0?ooo`0@0?[jnP3WinL0oOgm0?Cdm03kno/0fMWI
0>;RhP3Zj^X0lo?c0?KfmP3moOd0oooo0?Ogm`3dm?@0oOgm0?_kn`H0oooo00<0moOg0?ooo`3oool0
0P3oool20?Cdm0040>k^kP3kno/0m_Kf0??cl`80no_k00@0lo?c0?7al@3jn_X0n?Sh0P3oool20?[j
nP0:0?Ogm`3oool0n?Sh0?gmo@3_knl0oOgm0?7al@3moOd0nOWi0?[jnP80mOGe01D0oooo0?clo03h
n?P0h^;R0?Gem@3moOd0n?Sh0?gmo@3dm?@0n_[j0?KfmP3lo?`0nOWi0?ooo`3alO40oooo0?[jnP3f
m_H0no_k0?KfmP3moOd00`3jn_X03@3oool0nOWi0?Win@3lo?`0kNg]0<S8b02VYZH0a<C40;Ng]`3O
gml0a/K60:FUY@3gmoL0?P3oool00`3jn_X0oooo0?ooo`060?ooo`030?[jnP3oool0oooo00h0oooo
0100n_[j0>KViP3lo?`0m?Cd0?_kn`3GemL0gmoO0>WYj@3bl_80m_Kf0?clo03oool0moOg0?Cdm03l
o?`0no_k1P3oool00`3fm_H0oooo0?ooo`020?ooo`80m?Cd00@0kNg]0?_kn`3fm_H0l_;b0P3jn_X0
103clo<0l?3`0?[jnP3gmoL20?ooo`80n_[j00X0m_Kf0?ooo`3gmoL0o?cl0>o_k`3moOd0lO7a0?gm
o@3inOT0n_[j0P3emOD05P3oool0oOgm0?Ogm`3Rh^80m_Kf0?ooo`3gmoL0oOgm0?Cdm03kno/0m_Kf
0?_kn`3inOT0oooo0?7al@3oool0n_[j0?KfmP3lo?`0m_Kf0?gmo@3inOT20?[jnP0=0?ooo`3inOT0
nOWi0?clo03/k>`0alO70:RXZ036a/H0^[Zj0=kNgP36a/H0YZJV0?Ogm`100?ooo`009P3oool00`3j
n_X0oooo0?[jnP0G0?ooo`0?0=?Cd`3jn_X0mOGe0?gmo@3/k>`0kNg]0=3@d03emOD0i^KV0?7al@3f
m_H0lO7a0?ooo`3moOd0oooo0080no_k00D0n_[j0?ooo`3gmoL0lo?c0?ooo`020?Ogm`040?ooo`3j
n_X0oOgm0?7al@80moOg00L0oooo0>[ZjP3emOD0oooo0?7al@3/k>`0kno_0080oooo0100lo?c0?7a
l@3dm?@0oOgm0?Shn03inOT0no_k0?3`l03emOD0n_[j0?KfmP3moOd0n?Sh0?ooo`3inOT0n?Sh0P3l
o?`02@3gmoL0m?Cd0??cl`3moOd0nOWi0?Cdm03alO40n_[j0?KfmP020?ooo`0I0?gmo@3gmoL0n_[j
0?[jnP3moOd0no_k0?Shn03emOD0no_k0?clo03jn_X0o?cl0?ooo`3jn_X0l_;b0?ooo`3Ph>00m?Cd
0=KFeP3Bd]80_kno0?KfmP3Ph>00UiNG0>;RhP0m0?ooo`030?[jnP3oool0n_[j01L0oooo00l0d];B
0?Win@3emOD0o?cl0>_[j`3/k>`0c/k>0?Gem@3Vi^H0l_;b0?KfmP3alO40oooo0?clo03oool00P3k
no/01@3jn_X0oooo0?KfmP3clo<0oooo0080m_Kf00@0oooo0?[jnP3lo?`0l?3`0P3gmoL01`3oool0
j^[Z0?Gem@3oool0lO7a0>c/k03_knl00P3oool03P3bl_80lO7a0??cl`3lo?`0moOg0?Win@3kno/0
l?3`0?Cdm03jn_X0m_Kf0?clo03inOT0oooo0P3inOT20?_kn`090?KfmP3bl_80m?Cd0?_kn`3gmoL0
lo?c0?3`l03kno/0m_Kf0080oooo01T0oOgm0?KfmP3inOT0nOWi0?clo03jn_X0nOWi0?Gem@3kno/0
oOgm0?Win@3kno/0oooo0?_kn`3alO40oooo0=cLg03dm?@0eMGE0=;BdP35aLD0m_Kf0>3Ph02HV9P0
h^;R03l0oooo00100?ooo`0<0=GEe@3jn_X0n_[j0=oOg`3/k>`0f][J0>g]k@3jn_X0jn_[0?ooo`3b
l_80n?Sh0`3oool20?gmo@050?[jnP3oool0lo?c0??cl`3gmoL00`3oool07P3jn_X0oooo0?gmo@3g
moL0lO7a0?[jnP3inOT0oooo0?gmo@3fm_H0inOW0?Gem@3moOd0oooo0?clo03hn?P0lO7a0?ooo`3m
oOd0m_Kf0??cl`3dm?@0n_[j0?Shn03oool0nOWi0?Shn03lo?`0n_[j0??cl`80m_Kf00X0no_k0?Cd
m03moOd0mOGe0?KfmP3dm?@0m_Kf0?gmo@3oool0oOgm0`3oool00`3inOT0oooo0?_kn`020?_kn`04
0?Ogm`3jn_X0o?cl0?clo080nOWi00`0no_k0?Gem@3bl_80hn?S0?Ogm`3fm_H0m?Cd0<k>cP32`/80
NWYj0>KViP3alO5G0?ooo`0<0=?Cd`3jn_X0n_[j0=gMg@3YjNT0e]KF0>[ZjP3inOT0jn_[0?ooo`3b
l_80n_[j0`3oool20?clo0050?[jnP3oool0lo?c0??cl`3fm_H00`3oool07P3jn_X0oooo0?clo03g
moL0lO7a0?[jnP3inOT0oooo0?gmo@3fm_H0i^KV0?Gem@3lo?`0oooo0?_kn`3inOT0lO7a0?ooo`3l
o?`0m_Kf0?;blP3clo<0n_[j0?Win@3oool0nOWi0?KfmP3kno/0nOWi0?Cdm080m_Kf00X0nOWi0?Cd
m03kno/0nOWi0?Gem@3clo<0m_Kf0?gmo@3oool0oOgm0`3oool00`3inOT0oooo0?_kn`020?clo004
0?KfmP3inOT0no_k0?_kn`80nOWi00`0no_k0??cl`3alO40gmoO0?Gem@3gmoL0lo?c0<k>cP32`/80
NWYj0>KViP3alO4o0?ooo`00@03oool02P3GemL0oooo0=kNgP3MgMd0eMGE0>c/k03fm_H0jn_[0>c/
k03bl_830?gmo@030?ooo`3moOd0oOgm0080n_[j00<0oooo0?Ogm`3gmoL00P3oool20?[jnP80oooo
00X0no_k0?Ogm`3dm?@0moOg0?[jnP3moOd0m_Kf0?Gem@3kno/0moOg0P3moOd02@3emOD0nOWi0?oo
o`3gmoL0oOgm0?ooo`3kno/0mOGe0?Cdm0020?Win@0:0?Gem@3hn?P0n?Sh0>o_k`3fm_H0moOg0?Kf
mP3dm?@0l?3`0?[jnP80lo?c00H0moOg0?KfmP3oool0oooo0?KfmP3oool20?Ogm`040?Win@3oool0
n_[j0?_kn`80nOWi00@0moOg0?clo03lo?`0nOWi0P3jn_X0103lo?`0l_;b0>?Sh`3oool20?_kn`03
0?;blP2][Jd0dm?C05T0oooo00X0eMGE0?ooo`3Lg=`0fMWI0=3@d03[jn/0mOGe0>WYj@3/k>`0m?Cd
0`3lo?`00`3oool0o?cl0?clo0020?[jnP030?ooo`3fm_H0m_Kf0080oooo0P3jn_X20?ooo`0:0?_k
n`3gmoL0m?Cd0?Ogm`3jn_X0oOgm0?KfmP3emOD0no_k0?KfmP80o?cl00T0m?Cd0?Win@3oool0moOg
0?clo03oool0o?cl0?Cdm03clo<00P3inOT0103emOD0moOg0?[jnP3^k^h30?KfmP050??cl`3alO40
no_k0?Cdm03clo<00P3fm_H20?ooo`080?KfmP3oool0m_Kf0?KfmP3inOT0oooo0?_kn`3lo?`20?Wi
n@030?Ogm`3kno/0no_k00<0nOWi00@0o?cl0?7al@3Ogml0oooo0P3inOT00`3alO40[Jf]0=?Cd`11
0?ooo`009@3oool30?[jnQL0oooo00@0hN7Q0?clo03fm_H0emOG0P3kno/02@3jn_X0n?Sh0?7al@3[
jn/0oOgm0?ooo`3dm?@0no_k0?ooo`020?[jnP070?ooo`3hn?P0oooo0?Ogm`3`l?00oooo0??cl`02
0?ooo`090?[jnP3moOd0lO7a0??cl`3emOD0o?cl0?Shn03inOT0oOgm0080m?Cd00<0oOgm0?[jnP3j
n_X00P3dm?@00`3kno/0oOgm0?KfmP020?clo00C0?Gem@3gmoL0no_k0?Ogm`3hn?P0lo?c0?Ogm`3c
lo<0nOWi0?Ogm`3moOd0n?Sh0?ooo`3`l?00n?Sh0??cl`3jn_X0moOg0??cl`020?Ogm`060?Gem@3g
moL0nOWi0?[jnP3oool0oOgm0P3hn?P20?[jnP030?KfmP3inOT0o?cl0080o?cl00P0kNg]0>o_k`3L
g=`0moOg0?[jnP3lo?`0m_Kf0;2`/3l0oooo0`3jn_XG0?ooo`0?0>7Qh@3moOd0mOGe0=CDe03gmoL0
m_Kf0?[jnP3fm_H0l?3`0>[ZjP3lo?`0oooo0??cl`3kno/0oooo0080n_[j00L0oooo0?Ogm`3oool0
m_Kf0?7al@3oool0m?Cd0080oooo00H0n_[j0?clo03alO40l_;b0?Gem@3lo?`20?Win@040?gmo@3d
m?@0m?Cd0?clo080n_[j01X0m?Cd0??cl`3kno/0o?cl0?KfmP3kno/0o?cl0?Gem@3fm_H0o?cl0?Kf
mP3inOT0lo?c0?KfmP3clo<0n_[j0?KfmP3moOd0moOg0?ooo`3clo<0m_Kf0?7al@3jn_X0moOg0??c
l`80m_Kf00H0mOGe0?Ogm`3inOT0nOWi0?ooo`3lo?`20?Ogm`0?0?[jnP3inOT0m_Kf0?Win@3moOd0
o?cl0?gmo@3/k>`0kNg]0=OGe`3gmoL0no_k0?gmo@3emOD0[jn_0480oooo000U0?ooo`030?[jnP3o
ool0oooo01L0oooo00`0f][J0?Win@3/k>`0hn?S0?3`l03alO40o?cl0>c/k03alO40mOGe0?ooo`3d
m?@20?gmo@030?[jnP3hn?P0oooo00@0oooo00@0moOg0?ooo`3oool0n_[j0P3moOd01P3/k>`0k^k^
0?ooo`3lo?`0moOg0?ooo`80o?cl00<0m?Cd0?[jnP3hn?P00P3oool20?[jnP80oooo00L0oOgm0?Og
m`3gmoL0moOg0?Gem@3fm_H0mOGe0080moOg00<0oooo0?Ogm`3emOD00P3inOT01@3]kNd0m_Kf0>k^
kP3YjNT0kNg]0080n_[j00<0oooo0?Gem@3emOD00P3lo?`0103jn_X0oOgm0?gmo@3kno/30?[jnP0?
0?Shn03lo?`0n?Sh0?Ogm`3moOd0nOWi0?;blP3_knl0c/k>0?_kn`3emOD0n?Sh0?[jnP30`<00moOg
03h0oooo00<0n_[j0?ooo`3oool05`3oool0303Hf=P0nOWi0>c/k03Ph>00l?3`0?7al@3moOd0k^k^
0?7al@3emOD0oooo0?Cdm080o?cl00<0n_[j0?Ogm`3oool0103oool0103fm_H0oooo0?ooo`3jn_X2
0?clo0060>[ZjP3^k^h0oooo0?_kn`3fm_H0oooo0P3kno/00`3dm?@0n_[j0?Ogm`020?ooo`80n_[j
0P3oool01`3lo?`0moOg0?Ogm`3fm_H0mOGe0?KfmP3emOD00P3fm_H00`3oool0moOg0?KfmP020?[j
nP080>g]k@3emOD0k>c/0>OWi`3/k>`0no_k0?Win@3oool20?Gem@80oOgm00@0nOWi0?gmo@3moOd0
no_k0`3jn_X03`3fm_H0no_k0?Win@3gmoL0oOgm0?Win@3alO40k^k^0<W9b@3jn_X0lo?c0?KfmP3i
nOT0_[jn0?Ogm`110?ooo`00?P3oool01`3UiND0o?cl0?7al@3[jn/0jNWY0?Gem@3Vi^H00P3`l?00
1`3clo<0m_Kf0?Cdm03oool0m_Kf0?gmo@3hn?P00P3oool30?[jnP040?Shn03jn_X0n?Sh0?[jnP80
oOgm00h0m?Cd0?Ogm`3oool0m?Cd0?ooo`3kno/0lo?c0?7al@3dm?@0o?cl0?ooo`3moOd0oooo0?Sh
n080n_[j0P3oool20?Cdm00L0?;blP3clo<0lO7a0?ooo`3gmoL0n?Sh0?KfmP3gmoL0nOWi0?Ogm`3d
m?@0m_Kf0?7al@3kno/0mOGe0?[jnP3inOT0oOgm0?Cdm03moOd0no_k0?Gem@3fm_H0oooo0?KfmP3m
oOd0nOWi0?_kn`<0oooo00h0nOWi0??cl`3oool0n_[j0?ooo`3kno/0j^[Z0?Gem@3EeMD0nOWi0?[j
nP3dm?@0oooo0=SHf5P0oooo0100iNGU0?gmo@3alO40j^[Z0>KViP3clo<0jNWY0?7al@3^k^h0lo?c
0?KfmP3dm?@0oooo0?KfmP3lo?`0moOg0P3oool30?[jnP040?Ogm`3jn_X0moOg0?[jnP80o?cl00h0
m?Cd0?Ogm`3oool0m?Cd0?ooo`3kno/0l_;b0?7al@3clo<0oOgm0?ooo`3lo?`0oooo0?Ogm`80n_[j
0P3oool07P3clo<0m?Cd0?3`l03clo<0l?3`0?ooo`3fm_H0n_[j0?KfmP3gmoL0n_[j0?KfmP3clo<0
m_Kf0?3`l03inOT0mOGe0?[jnP3inOT0oOgm0??cl`3moOd0no_k0?Gem@3fm_H0oooo0?KfmP3moOd0
nOWi0?[jnP<0oooo00h0nOWi0??cl`3oool0nOWi0?ooo`3kno/0jNWY0?Ogm`3AdM40nOWi0?[jnP3b
l_80oooo0=GEeD80oooo000U0?ooo`@0n_[j5@3oool0303UiND0lo?c0>o_k`3^k^h0gMgM0??cl`3^
k^h0m_Kf0>k^kP3[jn/0moOg0?KfmP80moOg00L0oooo0?Shn03jn_X0n?Sh0?[jnP3hn?P0nOWi0080
oooo00/0no_k0?7al@3dm?@0moOg0?7al@3dm?@0o?cl0?[jnP3inOT0oooo0?gmo@020?clo0050?Og
m`3fm_H0oOgm0?ooo`3kno/00`3oool20?gmo@080?_kn`3`l?00k>c/0?Win@3emOD0l_;b0?Shn03n
o_h20?ooo`070?_kn`3emOD0mOGe0?gmo@3inOT0n?Sh0?ooo`030?[jnP80no_k00h0m_Kf0?ooo`3e
mOD0n_[j0?clo03hn?P0nOWi0?[jnP3hn?P0oOgm0?ooo`3kno/0oOgm0?[jnP80oOgm00T0j^[Z0?Ge
m@3/k>`0moOg0?Win@3fm_H0nOWi0>o_k`3<c<`0?P3oool40?[jnQD0oooo00X0hn?S0??cl`3^k^h0
kNg]0=_Kf`3bl_80kno_0?KfmP3/k>`0j^[Z0P3fm_H20?Ogm`070?ooo`3gmoL0n_[j0?Ogm`3jn_X0
moOg0?Win@020?ooo`0=0?_kn`3alO40m?Cd0?Ogm`3alO40m?Cd0?_kn`3jn_X0nOWi0?ooo`3moOd0
no_k0?clo0020?KfmP030?clo03oool0no_k00<0oooo0P3lo?`0203kno/0l?3`0>_[j`3inOT0mOGe
0?3`l03jn_X0o?cl0P3oool01`3moOd0m_Kf0?Gem@3moOd0nOWi0?Ogm`3oool00`3inOT20?_kn`05
0?KfmP3oool0mOGe0?[jnP3kno/00P3inOT01`3jn_X0moOg0?clo03oool0no_k0?gmo@3inOT00P3m
oOd02@3YjNT0moOg0>[ZjP3fm_H0nOWi0?KfmP3inOT0kNg]0<c<c0110?ooo`00<03oool00`3jn_X0
oooo0?ooo`0;0?ooo`0@0>_[j`3`l?00lO7a0>?Sh`3Ogml0moOg0>o_k`3fm_H0jn_[0>KViP3hn?P0
oOgm0?KfmP3dm?@0oooo0?[jnP<0n?Sh0180oOgm0?ooo`3oool0m?Cd0?Ogm`3clo<0lO7a0?Cdm03a
lO40mOGe0?clo03no_h0o?cl0?[jnP3oool0o?cl0?gmo@3jn_X20?Ogm`050?_kn`3moOd0oOgm0?[j
nP3oool00P3moOd02`3oool0lo?c0>o_k`3emOD0n_[j0?Win@3dm?@0moOg0?ooo`3moOd0o_kn0080
moOg00<0n_[j0?gmo@3hn?P00P3jn_X07@3fm_H0moOg0?_kn`3fm_H0moOg0?[jnP3]kNd0nOWi0?Og
m`3fm_H0n?Sh0?clo03no_h0n_[j0?knoP3jn_X0o?cl0?ooo`3moOd0o?cl0>OWi`3moOd0jn_[0?[j
nP3moOd0n_[j0>k^kP3emOD0^KVi04T0oooo00<0n_[j0?ooo`3oool02`3oool0403Zj^X0kno_0?3`
l03QhN40gMgM0?KfmP3alO40m_Kf0>[ZjP3Vi^H0moOg0?clo03fm_H0lo?c0?ooo`3jn_X30?Ogm`0;
0?clo03oool0oooo0?Cdm03fm_H0lo?c0?7al@3dm?@0lO7a0?Gem@3kno/00P3moOd01@3inOT0oooo
0?clo03moOd0nOWi0080moOg00D0no_k0?clo03lo?`0n_[j0?ooo`020?clo00<0?ooo`3bl_80k^k^
0?Cdm03jn_X0nOWi0?Gem@3gmoL0oooo0?gmo@3lo?`0moOg0P3inOT01`3moOd0moOg0?[jnP3jn_X0
mOGe0?Ogm`3kno/00P3fm_H00`3inOT0kNg]0?Win@030?Ogm`0B0?gmo@3lo?`0n_[j0?clo03inOT0
o?cl0?ooo`3moOd0o?cl0>KViP3lo?`0jNWY0?[jnP3kno/0nOWi0>c/k03clo<0^;Rh@@3oool003d0
oooo01T0h^;R0=WIf@3WinL0`L710=oOg`2b/[80^;Rh0>k^kP3fm_H0jn_[0>o_k`3lo?`0oooo0?Cd
m03moOd0oooo0?[jnP3oool0n_[j0?Shn03^k^h0oooo0?_kn`3moOd0oooo0080oOgm00X0n?Sh0?Cd
m03inOT0m?Cd0>_[j`3hn?P0o?cl0?Cdm03gmoL0oOgm0P3clo<0103dm?@0no_k0?gmo@3moOd40?oo
o`040?gmo@3clo<0lo?c0?Gem@80m_Kf0100m?Cd0?Shn03lo?`0oooo0?gmo@3lo?`0m_Kf0?[jnP3k
no/0n?Sh0?KfmP3kno/0oooo0?Shn03jn_X0oooo0P3lo?`02`3gmoL0o?cl0?knoP3inOT0n_[j0?Sh
n03fm_H0nOWi0?[jnP3lo?`0oOgm0080oooo00X0nOWi0?_kn`3clo<0bLW90=CDe03inOT0l_;b0=SH
f03gmoL0YjNWEP3oool06@3Rh^80e]KF0>CTi02n_[h0g]kN0;:b/P2h^;P0kno_0?KfmP3Zj^X0kno_
0?_kn`3oool0m?Cd0?clo03oool0n_[j0?ooo`3jn_X0moOg0>g]k@3oool0no_k0?clo03oool00P3l
o?`02P3gmoL0lo?c0?Win@3clo<0jn_[0?Ogm`3kno/0lo?c0?KfmP3lo?`20??cl`040?Cdm03kno/0
o?cl0?clo0@0oooo00@0o?cl0?;blP3clo<0mOGe0P3fm_H0103emOD0nOWi0?gmo@3oool20?clo00:
0?Gem@3inOT0no_k0?Win@3emOD0no_k0?ooo`3gmoL0nOWi0?ooo`80oOgm00L0moOg0?gmo@3lo?`0
nOWi0?_kn`3gmoL0m_Kf0080nOWi00@0no_k0?gmo@3oool0oooo0P3inOT0203dm?@0`<300<k>cP3i
nOT0lO7a0=?Cd`3gmoL0XZ:R@@3oool003`0oooo00h0inOW0=oOg`3Rh^80h^;R0=WIf@2GUiL0d=3@
0??cl`3Ph>00j^[Z0<o?c`3^k^h0moOg0?KfmP@0oooo00h0n_[j0?Ogm`3oool0oooo0?Cdm03alO40
moOg0?3`l03bl_80lo?c0?KfmP3jn_X0mOGe0?[jnP80o?cl00T0m_Kf0?Gem@3jn_X0moOg0?7al@3o
ool0no_k0?Ogm`3dm?@00P3moOd30?ooo`070?Ogm`3inOT0lO7a0?Gem@3moOd0n?Sh0?_kn`020?oo
o`070?gmo@3oool0moOg0?gmo@3hn?P0o?cl0?Ogm`030?Win@040?[jnP3fm_H0n_[j0?7al@80m_Kf
00@0no_k0?Shn03inOT0oooo0P3jn_X04@3lo?`0oooo0?[jnP3jn_X0no_k0?clo03oool0moOg0?;b
lP2/[:`0mOGe0>SXj03emOD0kno_0?gmo@3clo<0gmoO05@0oooo00h0inOW0=gMg@3Ogml0h>3P0=OG
e`2FUYH0clo?0?Cdm03QhN40j^[Z0<o?c`3^k^h0moOg0?KfmP@0oooo00h0n_[j0?Ogm`3oool0oooo
0?Cdm03alO40moOg0?3`l03alO40lo?c0?KfmP3jn_X0mOGe0?Win@80o?cl00T0m_Kf0?Gem@3jn_X0
m_Kf0?7al@3oool0no_k0?Ogm`3dm?@00P3lo?`30?ooo`070?Ogm`3inOT0lO7a0?Gem@3lo?`0n_[j
0?gmo@020?ooo`070?gmo@3oool0moOg0?gmo@3inOT0oOgm0?KfmP040?Win@030?KfmP3inOT0l?3`
0080m_Kf00@0no_k0?Ogm`3inOT0oooo0P3jn_X00`3lo?`0oooo0?Win@020?Win@0<0?_kn`3oool0
mOGe0??cl`2VYZH0nOWi0>GUi@3clo<0kNg]0?gmo@3`l?00g]kN@03oool003/0oooo0180moOg0=OG
e`3/k>`0m?Cd0<g=c@33`l<0]KFe0<G5a@3^k^h0kno_0>g]k@2o_kl0kNg]0?ooo`3fm_H0oOgm0?_k
n`3moOd20?ooo`<0oOgm0P3oool0103dm?@0kno_0>_[j`3[jn/20>GUi@060>o_k`3hn?P0n_[j0?[j
nP3`l?00kno_0P3emOD01P3jn_X0oooo0?ooo`3oool0oOgm0?KfmP80oOgm00/0no_k0?Cdm03lo?`0
m?Cd0>o_k`3dm?@0lo?c0?_kn`3moOd0o?cl0?ooo`020?_kn`060?Cdm03hn?P0oOgm0?ooo`3jn_X0
oooo0P3inOT01@3lo?`0n_[j0?knoP3kno/0oOgm0080n_[j0P3inOT05@3gmoL0m?Cd0?[jnP3inOT0
no_k0?[jnP3moOd0no_k0?gmo@3kno/0n?Sh0?knoP2h^;P0no_k0?;blP3[jn/0l_;b0??cl`3lo?`0
/K6a0?[jnP1B0?ooo`0B0?Ogm`3EeMD0jn_[0?;blP3<c<`0`/;20;Fe]@34a<@0k^k^0>o_k`3/k>`0
`<300>g]k@3oool0m_Kf0?clo03kno/0o?cl0P3oool30?clo080oooo00P0lo?c0>o_k`3Zj^X0j^[Z
0>KViP3Ti>@0k^k^0?Ogm`80nOWi00D0kno_0>k^kP3emOD0mOGe0?Win@030?ooo`0G0?clo03fm_H0
o?cl0?clo03kno/0lo?c0?gmo@3clo<0k^k^0?Cdm03clo<0nOWi0?clo03moOd0oooo0?_kn`3inOT0
mOGe0?Win@3moOd0oooo0?[jnP3oool00P3inOT00`3lo?`0n_[j0?gmo@020?clo080n_[j0P3inOT0
5@3gmoL0m?Cd0?[jnP3inOT0no_k0?Win@3moOd0nOWi0?gmo@3kno/0moOg0?gmo@2d];@0oooo0?3`
l03Zj^X0l?3`0??cl`3kno/0[Zj^0?[jnP0o0?ooo`00>`3oool03`3gmoL0hN7Q0>WYj@3]kNd0[Zj^
0=3@d03oool0[:b/0?[jnP3]kNd0k>c/0<71`@3_knl0moOg0?Cdm0030?ooo`050?clo03moOd0oooo
0?gmo@3dm?@00P3oool20?gmo@80oooo00<0no_k0?Cdm03moOd00P3gmoL01@3lo?`0oOgm0?3`l03T
i>@0lO7a0080moOg103moOd01P3oool0oOgm0?_kn`3gmoL0m_Kf0?[jnP80lo?c00X0m?Cd0?Ogm`3l
o?`0oOgm0?Gem@3hn?P0mOGe0?_kn`3oool0mOGe0P3gmoL0203jn_X0m_Kf0?[jnP3jn_X0no_k0?gm
o@3kno/0m_Kf0P3kno/01@3oool0n_[j0?gmo@3oool0mOGe0080nOWi0P3lo?`20?gmo@060?ooo`3h
n?P0o?cl0;bl_03/k>`0mOGe0P3]kNd0103lo?`0no_k0:RXZ03`l?1B0?ooo`0?0?Ogm`3Ng]h0jNWY
0>_[j`2][Jd0dM7A0?ooo`2/[:`0nOWi0>k^kP3/k>`0`<300>k^kP3gmoL0lo?c00<0oooo00D0no_k
0?clo03oool0o?cl0?Cdm0020?ooo`80o?cl0P3oool0303kno/0m?Cd0?clo03gmoL0m_Kf0?_kn`3m
oOd0kno_0>?Sh`3`l?00nOWi0?Ogm`@0o?cl00L0oooo0?clo03kno/0moOg0?KfmP3inOT0l_;b0080
lo?c00T0moOg0?Win@3moOd0mOGe0?Win@3clo<0nOWi0?ooo`3emOD00P3gmoL0203jn_X0m_Kf0?_k
n`3jn_X0no_k0?gmo@3lo?`0m_Kf0P3kno/01@3oool0n_[j0?clo03oool0mOGe0080nOWi0P3kno/0
2P3oool0oOgm0?ooo`3fm_H0nOWi0;Vi^@3]kNd0lo?c0>[ZjP3[jn/20?gmo@030:BTY03`l?00oooo
03h0oooo000U0?ooo`030?[jnP3oool0oooo01<0oooo00h0n_[j0=OGe`3Kfm/0g]kN0:VYZ@31`L40
Ph>30::RXP38b<P0a/K60>SXj02^[Zh0kno_0?Ogm`80m?Cd00T0oooo0?Ogm`3dm?@0no_k0?gmo@3_
knl0hn?S0?Ogm`3dm?@00P3moOd30?ooo`0?0>[ZjP3YjNT0lO7a0?Win@3jn_X0m_Kf0?_kn`3hn?P0
n_[j0>?Sh`3Ng]h0m?Cd0>o_k`3oool0oOgm0080oooo0140m?Cd0?gmo@3jn_X0m_Kf0??cl`3fm_H0
n?Sh0?KfmP3moOd0m_Kf0?Win@3fm_H0n_[j0?knoP3dm?@0n_[j0?clo0020?Gem@80m?Cd00P0n_[j
0?Win@3oool0no_k0??cl`3dm?@0moOg0?ooo`80n_[j00D0moOg0?[jnP3lo?`0n_[j0?gmo@020?cl
o00=0?KfmP3lo?`0k^k^0?;blP36a/H0m_Kf0=WIf@3Fe]H0alO70=SHf03jn_X0^KVi0;no_`070?oo
o`80n_[j3P3oool00`3jn_X0oooo0?ooo`0R0?ooo`030?[jnP3oool0oooo01<0oooo00h0n_[j0=CD
e03GemL0fm_K0:RXZ031`L40PX:20:6QX@39bLT0alO70>[ZjP2_[jl0k^k^0?Ogm`80m?Cd00T0oooo
0?KfmP3clo<0no_k0?clo03_knl0i>CT0?Ogm`3clo<00P3lo?`30?ooo`80j^[Z00d0l?3`0?Win@3j
n_X0mOGe0?_kn`3gmoL0n_[j0>;RhP3Ng]h0m?Cd0>o_k`3oool0o?cl0080oooo0140m?Cd0?clo03j
n_X0m_Kf0?7al@3fm_H0nOWi0?KfmP3moOd0mOGe0?[jnP3fm_H0nOWi0?clo03emOD0nOWi0?gmo@02
0?Gem@80m?Cd00P0n_[j0?Win@3oool0o?cl0?;blP3clo<0moOg0?ooo`80n_[j00d0moOg0?_kn`3m
oOd0nOWi0?gmo@3kno/0o?cl0?KfmP3lo?`0kno_0?7al@34a<@0m_Kf0080eMGE00D0_kno0=;BdP3j
n_X0/k>c0;fm_@070?ooo`80n_[j3P3oool00`3jn_X0oooo0?ooo`0U0?ooo`00>`3oool03P3]kNd0
clo?0>[ZjP3Zj^X0cLg=0;Rh^030`<00eMGE09fMW@3IfMT0f=SH0;Fe]@3[jn/0moOg0`3fm_H06`3o
ool0oOgm0>c/k03YjNT0l?3`0?7al@31`L40]kNg0<c<c039bLT0^KVi0<G5a@3AdM40d];B0=oOg`3A
dM40hn?S0<[:bP3UiND0n_[j0??cl`3inOT0oooo0?Gem@3_knl0m?Cd0?gmo@020?ooo`0O0?[jnP3m
oOd0m_Kf0?7al@3dm?@0l?3`0?7al@3clo<0oOgm0?Win@3`l?00l_;b0?clo03kno/0m?Cd0>o_k`3a
lO40l?3`0?KfmP3moOd0l_;b0?Ogm`3clo<0mOGe0?[jnP3emOD0lo?c0?KfmP3gmoL0n?Sh0?[jnP02
0?Ogm`0C0?clo03jn_X0o?cl0?ooo`3emOD0n?Sh0?ooo`3lo?`0lO7a0?[jnP3EeMD0lo?c0?ooo`3g
moL0lo?c0>c/k03Vi^H0d=3@0:b/[01B0?ooo`0>0>g]k@3;bl/0i>CT0>SXj03?cll0_;bl0;jn_P3D
e=@0WIfM0=WIf@3Jf]X0];Bd0>_[j`3gmoL30?KfmP040?ooo`3lo?`0k>c/0>WYj@80l?3`01D0`L71
0;Jf]P3:b/X0a/K60;Rh^033`l<0clo?0=7Ad@3Ogml0clo?0>;RhP37alL0i>CT0?[jnP3clo<0nOWi
0?ooo`3emOD0kno_0??cl`3lo?`00P3oool01@3jn_X0o?cl0?KfmP3alO40lo?c0080l?3`01D0lo?c
0?gmo@3inOT0lO7a0?Cdm03moOd0no_k0??cl`3^k^h0kno_0?7al@3fm_H0oOgm0?;blP3gmoL0lo?c
0?Gem@3jn_X0mOGe0??cl`3fm_H00P3gmoL05P3jn_X0moOg0?Ogm`3moOd0nOWi0?_kn`3oool0m_Kf
0?[jnP3oool0o?cl0?7al@3lo?`0e=CD0>o_k`3oool0m_Kf0?Ogm`3Zj^X0i>CT0<c<c02YZJTo0?oo
o`00>`3oool04@3Hf=P0gMgM0?_kn`3]kNd0ZJVY0:>SX`39bLT0c<c<0?Win@3`l?00j>SX08V9R@3a
lO40moOg0?ooo`3dm?@0m_Kf0080moOg0180m?Cd0?ooo`3fm_H0jNWY0=cLg03Fe]H0l?3`0<k>cP3/
k>`0lO7a0>_[j`3Shn<0b/[:0<C4a02o_kl0iNGU0>WYj@3Vi^H20?Cdm0060>o_k`3Zj^X0nOWi0?[j
nP3gmoL0oOgm0`3jn_X0203kno/0mOGe0?clo03bl_80m?Cd0?Win@3jn_X0nOWi0P3emOD0103hn?P0
lO7a0?7al@3kno/20?KfmP070>o_k`3alO40kNg]0?3`l03hn?P0j^[Z0?KfmP020?ooo`050?Shn03j
n_X0n_[j0?Ogm`3inOT00P3oool01`3kno/0n_[j0?[jnP3clo<0n?Sh0?knoP3inOT00P3bl_802@3G
emL0m_Kf0?Ogm`3gmoL0oooo0??cl`3YjNT0jn_[0:FUY@1B0?ooo`0A0=OGe`3IfMT0moOg0>c/k02X
Z:P0YJFU0<g=c@3AdM40no_k0?;blP3Xj>P0RHV90?7al@3gmoL0oooo0??cl`3fm_H00P3gmoL02@3d
m?@0oooo0?KfmP3YjNT0g=cL0=SHf03/k>`0clo?0>c/k0020>g]k@070>?Sh`38b<P0`l?30;jn_P3V
i^H0inOW0>KViP020??cl`060>k^kP3Zj^X0nOWi0?[jnP3gmoL0o?cl0`3jn_X05`3kno/0mOGe0?_k
n`3alO40lo?c0?Ogm`3inOT0n_[j0?KfmP3emOD0moOg0?3`l03clo<0nOWi0?Ogm`3fm_H0kno_0>k^
kP3/k>`0kno_0?Ogm`3[jn/0m_Kf0080oooo00D0moOg0?[jnP3jn_X0moOg0?Win@020?ooo`070?_k
n`3inOT0nOWi0?;blP3jn_X0oooo0?_kn`020?7al@090=SHf03emOD0m_Kf0?KfmP3lo?`0l?3`0>GU
i@3WinL0XZ:R03l0oooo000k0?ooo`0T0<[:bP3Zj^X0nOWi0?7al@1dM7@0d=3@0?Cdm03/k>`0oooo
0>o_k`3Xj>P0SHf=0>c/k03fm_H0m?Cd0?ooo`3jn_X0no_k0?clo03oool0no_k0??cl`3hn?P0c<c<
0=oOg`2QXJ40fMWI0:VYZ@3Lg=`0oooo0;^k^`28R8P0emOG0<W9b@3Vi^H0e=CD0P3^k^h0203Hf=P0
gMgM0;fm_@2k^k/0jNWY0??cl`3moOd0oooo0P3jn_X20?ooo`0=0?7al@3jn_X0j^[Z0?KfmP3lo?`0
m_Kf0?;blP3moOd0oooo0?KfmP3alO40l?3`0?Cdm0030>c/k0090>SXj03_knl0lO7a0?Ogm`3`l?00
m?Cd0?[jnP3Ogml0j^[Z0080n_[j00L0oooo0?Ogm`3gmoL0oOgm0?Shn03dm?@0n_[j0080lo?c00`0
o?cl0?[jnP3inOT0f=SH0?knoP3gmoL0oooo0?Ogm`3^k^h0gMgM0?7al@2VYZIB0?ooo`0^0<W9b@3S
hn<0lo?c0?7al@1dM7@0e]KF0?clo03]kNd0oooo0>o_k`3Vi^H0SHf=0>_[j`3fm_H0lo?c0?ooo`3j
n_X0no_k0?gmo@3oool0no_k0??cl`3gmoL0b<S80=kNgP2PX:00f][J0:VYZ@3MgMd0oooo0;>c/`26
QXH0fMWI0<o?c`3Vi^H0c/k>0>o_k`3`l?00emOG0=_Kf`2g]kL0][Jf0>OWi`3bl_80o?cl0?ooo`80
n_[j0P3oool02P3_knl0n_[j0>WYj@3dm?@0no_k0?Ogm`3emOD0oOgm0?ooo`3emOD20?7al@0=0??c
l`3[jn/0jn_[0>_[j`3Vi^H0k^k^0>o_k`3emOD0k^k^0?Gem@3inOT0gMgM0>WYj@020?[jnP070?oo
o`3gmoL0moOg0?gmo@3inOT0mOGe0?Win@020?Cdm080o?cl00X0no_k0=OGe`3kno/0nOWi0?ooo`3i
nOT0j^[Z0=OGe`3_knl0XZ:R?`3oool002D0oooo0`3jn_XC0?ooo`080<o?c`3inOT0nOWi0>SXj01D
E5@0hn?S0?_kn`3Vi^H20?ooo`0S0=gMg@2=SHd0i^KV0?Ogm`3fm_H0lo?c0?clo03fm_H0oooo0?_k
n`3gmoL0lO7a0?Cdm02`/;00j>SX0>;RhP2=SHd0m_Kf09bLW030`<00l_;b0<c<c02?Shl0clo?0<_;
b`3Kfm/0`l?30=GEe@3MgMd0kno_0>[ZjP3IfMT0i^KV0?3`l03dm?@0103oool0503gmoL0mOGe0?Sh
n03_knl0moOg0?KfmP3emOD0k^k^0>SXj03fm_H0kNg]0??cl`3_knl0lO7a0?Shn03^k^h0kno_0>[Z
jP3dm?@0lO7a0P3fm_H01P3hn?P0lo?c0?7al@3moOd0kno_0?7al@80moOg00D0oooo0?clo03clo<0
oooo0?Gem@020?KfmP050?Gem@3oool0o?cl0=gMg@3hn?P00P3oool01@3gmoL0kNg]0>OWi`3emOD0
XZ:R03`0oooo0`3jn_XC0?ooo`080<g=c@3clo<0m_Kf0>SXj01DE5@0jn_[0?Cdm03WinL20?ooo`0S
0=cLg02=SHd0i^KV0?Ogm`3fm_H0lo?c0?gmo@3fm_H0oooo0?_kn`3gmoL0lO7a0?Cdm02/[:`0inOW
0>7Qh@2;Rh/0m_Kf09^KV`30`<00l?3`0<[:bP2?Shl0dm?C0<o?c`3Jf]X0`L710<o?c`3IfMT0l_;b
0>;RhP3Fe]H0iNGU0>o_k`3dm?@0103oool0103gmoL0mOGe0?Ogm`3^k^h20?KfmP090?Ogm`3alO40
j>SX0?KfmP3/k>`0lo?c0>k^kP3alO40moOg0080k^k^00<0jNWY0??cl`3`l?000P3fm_H01P3gmoL0
m?Cd0?3`l03moOd0kno_0?3`l080moOg00@0oooo0?gmo@3clo<0oooo0P3fm_H01P3gmoL0m_Kf0?oo
o`3lo?`0gMgM0?Cdm080o?cl00D0n_[j0>k^kP3Rh^80mOGe09jNWP0o0?ooo`00>P3oool0;P2;Rh/0
l_;b0=kNgP3fm_H0lO7a0:FUY@3QhN40j^[Z0>OWi`3`l?00hn?S0>c/k01nOWh0n_[j0?Ogm`3fm_H0
m?Cd0?ooo`3alO40moOg0?_kn`3oool0moOg0??cl`3Xj>P0d];B0?Win@3MgMd0/K6a09FEU@2ATI40
l?3`0:NWY`1gMgL0fMWI0=;BdP3Shn<0[Zj^0=KFeP38b<P0hN7Q0=GEe@3QhN40n_[j0?Shn03oool2
0?[jnP80oooo02D0m_Kf0??cl`3dm?@0kno_0?KfmP3gmoL0lo?c0?;blP3oool0cLg=0;>c/`39bLT0
j^[Z0?ooo`3Xj>P0hN7Q0=?Cd`3Fe]H0b<S80=CDe03Rh^80k>c/0?Ogm`3dm?@0oOgm0>o_k`3UiND0
kno_0>c/k03emOD0o?cl0??cl`3no_h0mOGe0?Cdm03lo?`0oooo0080lo?c00<0m?Cd0<g=c@3fm_H0
0P3kno/01@3Zj^X0l?3`0>OWi`3gmoL0XZ:R0540oooo02h0Rh^;0?3`l03Kfm/0lo?c0?3`l02TY:@0
i>CT0>[ZjP3WinL0lO7a0>CTi03[jn/0Ogmo0?[jnP3gmoL0m_Kf0?Cdm03oool0lO7a0?Ogm`3kno/0
oooo0?Ogm`3clo<0j>SX0<o?c`3gmoL0g]kN0;:b/P2FUYH0Ti>C0>k^kP2TY:@0N7Qh0=WIf@3Cdm<0
hn?S0:j^[P3EeMD0aLG50>CTi03Bd]80gmoO0?Win@3gmoL0oooo0P3jn_X20?ooo`040?KfmP3bl_80
lo?c0>o_k`80mOGe01l0m?Cd0?3`l03oool0a/K60;:b/P37alL0jNWY0?ooo`3Vi^H0h>3P0=7Ad@3F
e]H0a/K60=?Cd`3QhN40jn_[0?Ogm`3clo<0oOgm0?7al@3UiND0kno_0>_[j`3dm?@0no_k0??cl`3l
o?`0m_Kf0??cl`3kno/0oooo0080lo?c00X0m?Cd0<g=c@3fm_H0n_[j0?KfmP3/k>`0kNg]0>CTi03g
moL0WYjN?`3oool002H0oooo00@0n_[j0?ooo`3jn_X0n_[j3P3oool03`3jn_X0Y:BT0=CDe03Xj>P0
g=cL0?Ogm`3Shn<0j>SX09NGU`3Vi^H0kno_0?7al@3WinL0dm?C08B4Q0030?Ogm`<0oooo00<0moOg
0?gmo@3fm_H00P3kno/20?7al@0E0>SXj03fm_H0jNWY0>KViP37alL0YjNW0=oOg`2c/k<0clo?0=OG
e`3clo<0n?Sh0>SXj03dm?@0no_k0=SHf03jn_X0lo?c0>o_k`3oool0n?Sh0080oooo01h0moOg0?Cd
m03clo<0l_;b0>o_k`3bl_80kno_0?Win@3^k^h0kno_0<;2`P3lo?`0^;Rh0?3`l03kno/0lo?c0>SX
j03Ti>@0f][J0?;blP3hn?P0hN7Q0<[:bP3GemL0kNg]0>o_k`3YjNT0lo?c0?3`l03emOD20?7al@0B
0?knoP3inOT0nOWi0?[jnP3emOD0n?Sh0?Gem@3_knl0n_[j0<_;b`3moOd0m_Kf0?;blP3<c<`0no_k
0?Cdm03`l?00W9bL?@3oool0103jn_X0oooo0?[jnP3jn_X>0?ooo`0?0?[jnP2UYJD0dm?C0>OWi`3F
e]H0m_Kf0>7Qh@3WinL0VYZJ0>OWi`3_knl0lo?c0>[ZjP3Cdm<0QXJ600<0moOg0`3oool00`3gmoL0
o?cl0?KfmP020?_kn`80lO7a01D0inOW0?KfmP3YjNT0i^KV0<K6aP2WYjL0h>3P0;Rh^03AdM40fMWI
0?KfmP3inOT0jn_[0??cl`3oool0dm?C0?[jnP3bl_80k^k^0?ooo`3gmoL00P3oool01@3fm_H0lo?c
0?;blP3alO40kno_0080l?3`01L0nOWi0>g]k@3^k^h0`L710?Ogm`2e]KD0lO7a0?_kn`3fm_H0jNWY
0>CTi03Jf]X0l_;b0?KfmP3Rh^80bLW90=CDe03]kNd0kno_0>[ZjP3clo<0l?3`0?KfmP020?3`l00B
0?clo03inOT0nOWi0?Win@3fm_H0n_[j0?KfmP3`l?00nOWi0<[:bP3lo?`0nOWi0??cl`3@d=00n_[j
0?Cdm03_knl0V9RH?`3oool003L0oooo00/0lO7a055AD@2WYjL0i^KV0<c<c03[jn/0i^KV0>OWi`3]
kNd0UYJF0?3`l0020?Win@060??cl`3Cdm<0OWin0?Ogm`3fm_H0n_[j0P3gmoL01@3]kNd0lO7a0?Kf
mP3_knl0oOgm0080oooo04X0lO7a0?ooo`3Zj^X0mOGe0=;BdP3Xj>P0/[:b0<;2`P3Ogml0d];B0>c/
k03Zj^X0lo?c0?[jnP3_knl0g=cL0?Cdm03hn?P0k>c/0??cl`3alO40n_[j0?Ogm`3clo<0moOg0?Cd
m03jn_X0lo?c0>c/k03fm_H0no_k0?gmo@3hn?P0kno_0?;blP3MgMd0_Kfm0;Zj^P3clo<0bl_;0=;B
dP3Rh^80inOW0?Win@36a/H0iNGU0?Gem@3clo<0dM7A0>[ZjP3fm_H0jNWY0>_[j`3WinL0k>c/0>g]
k@3kno/0o_kn0??cl`3lo?`0n?Sh0?Gem@3fm_H0m?Cd0?Gem@39bLT0o_kn0?clo03gmoL0_Kfm0?[j
nP3fm_H0k>c/0:VYZDh0oooo00H0lO7a04i>CP2VYZH0iNGU0<S8b03[jn/20>KViP0;0>_[j`2KVi/0
lO7a0?[jnP3kno/0m?Cd0=?Cd`1oOgl0moOg0?KfmP3jn_X00P3gmoL01@3]kNd0lO7a0?KfmP3_knl0
o?cl0080oooo02@0lO7a0?ooo`3YjNT0mOGe0<o?c`3Vi^H0/[:b0<;2`P3MgMd0e]KF0>c/k03[jn/0
lo?c0?gmo@3^k^h0g=cL0?Cdm03gmoL0jn_[0?;blP3alO40n_[j0?KfmP3clo<0m_Kf0??cl`3inOT0
lo?c0>_[j`3fm_H0n_[j0?gmo@3inOT0k^k^0?7al@3Kfm/20;Rh^00T0??cl`3;bl/0bl_;0>GUi@3Z
j^X0oOgm0<G5a@3Shn<0m_Kf0?;blP3Bd]80jn_[0?KfmP3Zj^X0k^k^0>SXj03[jn/0k>c/0?[jnP3l
o?`0lo?c0?_kn`3jn_X0mOGe0?KfmP3bl_80moOg0<S8b03kno/0oOgm0?KfmP2o_kl0nOWi0?KfmP3[
jn/0XZ:R?`3oool002D0oooo1@3jn_X00`3oool0n_[j0?ooo`0:0?ooo`0C0:j^[P2EUID0kNg]0?7a
l@3Bd]80jn_[0?ooo`3/k>`0j^[Z0:b/[03Vi^H0kNg]0?Ogm`3alO40eMGE0861P@3lo?`0lO7a0?[j
nP020?Ogm`0C0?Gem@3alO40oooo0??cl`3fm_H0oooo0?_kn`3gmoL0m?Cd0?[jnP3Shn<0j^[Z0>SX
j03[jn/0kno_0<[:bP3De=@0eMGE0=SHf0020>o_k`0J0?Win@3Cdm<0k>c/0?Gem@3alO40moOg0?7a
l@3jn_X0moOg0??cl`3jn_X0moOg0?Shn03emOD0k>c/0?Ogm`3inOT0oooo0?KfmP3alO40lo?c0?Og
m`3dm?@0Zj^[0>?Sh`2EUID20:n_[`0M0=;BdP3Vi^H0g=cL0<k>cP3Xj>P0l?3`0>KViP3Jf]X0iNGU
0>OWi`3IfMT0jNWY0?Ogm`3emOD0m_Kf0?Gem@3hn?P0lo?c0?clo03^k^h0n_[j0?;blP3_knl0fMWI
0>SXj03jn_X0m_Kf0:^[Z`3alO400P3[jn/00`2`/;00oooo0?ooo`0j0?ooo`D0n_[j00<0oooo0?[j
nP3oool02P3oool01`2^[Zh0U9BD0>[ZjP3alO40clo?0>[ZjP3oool00P3Zj^X02P2_[jl0i>CT0>g]
k@3fm_H0m?Cd0=OGe`21PH40oOgm0?3`l03jn_X20?Ogm`0C0?Gem@3alO40oooo0??cl`3fm_H0oooo
0?_kn`3gmoL0m?Cd0?[jnP3QhN40j>SX0>OWi`3Zj^X0kNg]0<[:bP3Cdm<0e]KF0=[JfP020>k^kP0X
0?Win@3Bd]80jn_[0?Gem@3alO40m_Kf0?7al@3jn_X0m_Kf0??cl`3jn_X0m_Kf0?Ogm`3emOD0jn_[
0?KfmP3gmoL0oooo0?Ogm`3alO40l_;b0?Ogm`3bl_80YjNW0>?Sh`2EUID0Zj^[0:j^[P3Hf=P0jn_[
0=WIf@3?cll0k>c/0?7al@3Xj>P0fm_K0>?Sh`3Xj>P0emOG0>OWi`80m_Kf0180mOGe0?KfmP3inOT0
mOGe0?clo03_knl0nOWi0?;blP3alO40emOG0>KViP3inOT0lo?c0:f][@3_knl0j^[Z0>OWi`2WYjLo
0?ooo`009P3oool00`3jn_X0oooo0?ooo`0=0?ooo`0M0>GUi@2:RXX0kno_0?ooo`3[jn/0U9BD0<G5
a@3MgMd0emOG0;Ng]`3moOd0j^[Z0>SXj03kno/0k^k^0=3@d01eMGD0o?cl0?ooo`3gmoL0oOgm0?Cd
m03<c<`0i>CT0>;RhP3clo<0oOgm0?_kn`3oool00P3hn?P02P3moOd0jn_[0?KfmP3emOD0oOgm0?Kf
mP3clo<0inOW0>SXj03Kfm/20?ooo`0S0?[jnP3kno/0m_Kf0?7al@3inOT0m_Kf0?Cdm03jn_X0lo?c
0?Ogm`3jn_X0m?Cd0?ooo`3fm_H0k^k^0?Gem@3clo<0nOWi0?gmo@3]kNd0m_Kf0>[ZjP3emOD0k>c/
0>CTi03Jf]X0hN7Q05UIF@3Ph>00inOW0?Shn03Ogml0`l?30>[ZjP3GemL00P3fm_H00`3hn?P0kNg]
0>GUi@020=gMg@0B0?Cdm03clo<0lo?c0?Gem@3lo?`0kno_0?clo03QhN40fm_K0?3`l03jn_X0emOG
0?Cdm02_[jl0n_[j0=CDe03dm?@0[Zj^?@3oool00`3jn_X0oooo0?ooo`0=0?ooo`0M0>GUi@29RHT0
kNg]0?_kn`3alO40V9RH0;jn_P3IfMT0emOG0;Vi^@3moOd0j^[Z0>OWi`3lo?`0kno_0<o?c`1eMGD0
oOgm0?ooo`3gmoL0o?cl0??cl`3:b/X0hn?S0>7Qh@3bl_80o?cl0?_kn`3oool00P3gmoL01`3lo?`0
j^[Z0?KfmP3emOD0oOgm0?KfmP3clo<00P3Vi^H09P3Hf=P0oooo0?ooo`3inOT0o?cl0?KfmP3`l?00
nOWi0?KfmP3clo<0n_[j0??cl`3fm_H0n_[j0?Cdm03oool0m_Kf0>k^kP3emOD0lo?c0?Win@3moOd0
k^k^0?Cdm03YjNT0l_;b0>[ZjP3WinL0fMWI0>7Qh@1JFUX0hN7Q0>KViP3dm?@0g=cL0<?3``3Zj^X0
f=SH0P3fm_H00`3clo<0k^k^0>CTi0020=_Kf`<0lo?c00l0m_Kf0?clo03alO40no_k0>;RhP3Kfm/0
l?3`0?Ogm`3IfMT0m_Kf0:n_[`3kno/0bl_;0?;blP2RXZ80?`3oool002D0oooo00<0n_[j0?ooo`3o
ool03P3oool04@1nOWh0hN7Q0?Gem@3^k^h0oooo0>_[j`2VYZH0UIFE0=SHf03Xj>P0inOW0?;blP3`
l?00moOg0>7Qh@37alL0T92@0080oooo00h0no_k0?ooo`3dm?@0moOg0<k>cP3Ogml0kno_0>;RhP3d
m?@0n?Sh0?[jnP3oool0n_[j0>k^kP80oooo00D0lO7a0?KfmP3clo<0n?Sh0?Cdm0040?[jnP060?Wi
n@3hn?P0oooo0?[jnP3emOD0kNg]0P3gmoL0<`3oool0mOGe0?ooo`3moOd0n_[j0?7al@3inOT0n_[j
0?7al@3emOD0nOWi0?clo03dm?@0h^;R0?7al@3Rh^80f=SH0>SXj037alL0l?3`0>7Qh@3`l?00c<c<
0=KFeP3;bl/0kno_0>SXj03kno/0clo?0>KViP3bl_80no_k0>_[j`3kno/0k^k^0?Gem@3fm_H0n_[j
0?Shn03emOD0e]KF0<;2`P3_knl0k^k^0>3Ph03/k>`0Ogmo0?_kn`3Rh^80j^[Z0:RXZ00l0?ooo`03
0?[jnP3oool0oooo00h0oooo0140Ogmo0>;RhP3gmoL0k^k^0?ooo`3`l?00Zj^[09FEU@3Jf]X0inOW
0>SXj03clo<0lO7a0?KfmP3Shn<0b<S808n?S`020?ooo`0>0?_kn`3oool0m?Cd0?Ogm`3=cLd0gMgM
0>o_k`3QhN40lo?c0?Ogm`3jn_X0oooo0?[jnP3^k^h20?ooo`050?7al@3fm_H0l_;b0?Ogm`3bl_80
1@3inOT01@3fm_H0oooo0?[jnP3emOD0k>c/0080m_Kf00H0oooo0?Gem@3oool0oOgm0?Win@3`l?02
0?Win@0K0?;blP3fm_H0nOWi0?[jnP3clo<0hN7Q0?3`l03Ti>@0emOG0>[ZjP35aLD0l?3`0>7Qh@3`
l?00bLW90=GEe@3<c<`0k^k^0>OWi`3lo?`0clo?0>KViP3alO40no_k0>c/k03jn_X0k^k^0080m_Kf
0P3inOT0303fm_H0e]KF0<?3``3]kNd0kno_0=kNgP3^k^h0PH610?_kn`3Lg=`0h^;R0:6QXCl0oooo
000U0?ooo`@0n_[j3@3oool02`19BDT0lo?c0?Ogm`3oool0moOg0?KfmP3moOd0jn_[0>g]k@3`l?00
m_Kf0080j>SX00@0no_k0?;blP3;bl/0P8200P3jn_X20?Ogm`090?KfmP3kno/0jNWY0=KFeP3WinL0
mOGe0=?Cd`3YjNT0k^k^0080lo?c01<0nOWi0?Cdm03dm?@0mOGe0?7al@3inOT0n_[j0?Shn03oool0
l_;b0>[ZjP3Xj>P0k>c/0?KfmP3dm?@0lo?c0?[jnP3dm?@0oooo0080n_[j0380m?Cd0?gmo@3alO40
n_[j0?Gem@3alO40k>c/0?KfmP3lo?`0lo?c0?Win@3lo?`0j^[Z0?Cdm03_knl0hn?S0=KFeP3YjNT0
f=SH0>;RhP3[jn/0clo?0<?3``3Hf=P0`<300?7al@3De=@0n?Sh0>g]k@3bl_80n?Sh0?[jnP3clo<0
n?Sh0?KfmP3emOD0oOgm0?clo03hn?P0cLg=0=CDe03]kNd0m_Kf0>c/k03Zj^X0K6a/0>7Qh@3clo<0
j^[Z09fMWAL0oooo00<0n_[j0?ooo`3oool08P3oool40?[jnPd0oooo00/0BDU90?Cdm03gmoL0oOgm
0?;blP3inOT0no_k0?3`l03]kNd0lO7a0?KfmP020>_[j`040?clo03bl_80b<S808>3P`80n_[j0P3g
moL02@3fm_H0no_k0>SXj03EeMD0i^KV0?Gem@3Bd]80j>SX0>k^kP020??cl`0>0?[jnP3dm?@0m?Cd
0?Gem@3`l?00nOWi0?[jnP3gmoL0oooo0?3`l03WinL0i^KV0>[ZjP3fm_H20??cl`030?[jnP3clo<0
oooo0080n_[j0280lo?c0?clo03`l?00nOWi0?Gem@3`l?00k>c/0?KfmP3inOT0mOGe0?Ogm`3kno/0
j^[Z0??cl`3]kNd0h^;R0=CDe03[jn/0emOG0>?Sh`3Xj>P0dM7A0<?3``3IfMT0`/;20?;blP3De=@0
nOWi0>k^kP3dm?@0moOg0?Win@3clo<0n_[j0P3fm_H03P3moOd0o?cl0?Ogm`3>c/h0dM7A0>g]k@3f
m_H0jNWY0>k^kP1/K6`0g]kN0?3`l03UiND0UYJF5`3oool00`3jn_X0oooo0?ooo`0U0?ooo`009P3o
ool50?[jnP/0oooo00D0C4a<0?_kn`3dm?@0moOg0>o_k`020>?Sh`0j0??cl`3UiND0iNGU0?3`l03g
moL0k>c/0??cl`3[jn/0c/k>08f=S@3emOD0no_k0?Ogm`3fm_H0m?Cd0?gmo@3oool0d=3@0=_Kf`3^
k^h0i^KV0;Bd]02MWId0T92@08R8R02;Rh/0P82007moO`2:RXX0PH6109BDU02MWId0YZJV0:>SX`3D
e=@0lO7a0?Cdm03Cdm<0jNWY0?KfmP3emOD0moOg0?Cdm03oool0oOgm0?Cdm03alO40mOGe0?[jnP3d
m?@0lO7a0??cl`3alO40n?Sh0>o_k`3]kNd0nOWi0?clo080lO7a02@0oooo0?Gem@3/k>`0kNg]0<o?
c`3>c/h0[Jf]0=SHf03^k^h0c/k>0?Gem@3Zj^X0g]kN0>c/k03kno/0lo?c0?KfmP3kno/0lo?c0?cl
o03dm?@0nOWi0>o_k`3emOD0i>CT0<G5a@3UiND0moOg0>SXj03oool0k>c/06EUI@3Shn<0oooo0=;B
dP2HV9Pm0?ooo`D0n_[j2`3oool0@@1<C4`0oOgm0?KfmP3fm_H0lO7a0>GUi@3Shn<0lO7a0>CTi03V
i^H0l?3`0?KfmP3^k^h0lo?c0>g]k@3?cll0SHf=0?Gem@3kno/0moOg0?KfmP3dm?@0o?cl0?ooo`3=
cLd0f][J0>g]k@3Xj>P0];Bd09bLW02?Shl0QhN708V9R@1mOGd0OWin08^;R`21PH40Ti>C09bLW02V
YZH0Xj>S0=?Cd`3alO40lo?c0=;BdP3Xj>P0m_Kf0?Gem@3fm_H0m?Cd0?ooo`3lo?`0m?Cd0?7al@3d
m?@0nOWi0?Cdm03`l?00lo?c0?3`l03fm_H0l?3`0>k^kP3gmoL0oOgm0080l?3`02@0oooo0??cl`3/
k>`0k^k^0=3@d03=cLd0[jn_0=WIf@3_knl0dM7A0??cl`3[jn/0g=cL0>c/k03kno/0lo?c0?KfmP3k
no/0lo?c0?clo03emOD0nOWi0?7al@3fm_H0i>CT0<K6aP3Vi^H0m_Kf0>OWi`3oool0kNg]06EUI@3N
g]h0oooo0<[:bP2BTY8o0?ooo`009@3oool70?[jnPX0oooo00H0KFe]0?knoP3UiND0fm_K0>o_k`3O
gml20?ooo`0E0>OWi`3hn?P0m_Kf0?KfmP3Ogml0lO7a0>OWi`3Fe]H0U9BD0?7al@3oool0n_[j0?oo
o`3gmoL0oooo0?_kn`3gmoL0gmoO0=OGe`3Kfm/0n_[j00<0l_;b0100i^KV0?3`l03dm?@0k>c/0?kn
oP3gmoL0m_Kf0?clo03dm?@0kno_0>[ZjP3]kNd0inOW0>WYj@3dm?@0l?3`0P3oool01P3jn_X0lo?c
0?KfmP3alO40n_[j0?Win@80n_[j00/0kno_0?7al@3jn_X0nOWi0?ooo`3clo<0n_[j0>c/k03oool0
k>c/0?7al@030?gmo@0H0?ooo`3QhN40nOWi0?7al@3gmoL0j>SX0>WYj@3jn_X0o_kn0??cl`3hn?P0
moOg0?_kn`3hn?P0lo?c0?Shn03clo<0n_[j0?Shn03MgMd0e]KF0>k^kP3WinL0emOG0P3bl_801@21
PH40m_Kf0?ooo`3:b/X0WYjN03`0oooo1`3jn_X:0?ooo`0606][J`3moOd0i>CT0=cLg03^k^h0hN7Q
0P3oool05@3WinL0nOWi0?KfmP3fm_H0h^;R0?;blP3Zj^X0emOG09BDU03alO40oooo0?Win@3oool0
moOg0?ooo`3kno/0m_Kf0=kNgP3EeMD0gMgM0?_kn`020??cl`0A0?;blP3WinL0lO7a0?Gem@3Zj^X0
o?cl0?Ogm`3fm_H0no_k0?Gem@3_knl0k>c/0>o_k`3UiND0j>SX0?Cdm03`l?000P3oool0103jn_X0
lo?c0?KfmP3alO430?Win@030?_kn`3_knl0lO7a0080nOWi00L0oooo0?Gem@3gmoL0k>c/0?ooo`3Z
j^X0l?3`00<0oOgm00D0oooo0>;RhP3inOT0kno_0?KfmP020>OWi`050?Win@3lo?`0lo?c0?[jnP3g
moL00P3inOT04@3clo<0n_[j0?Cdm03inOT0n_[j0=kNgP3EeMD0k^k^0>KViP3GemL0l_;b0?KfmP20
P800kno_0?ooo`30`<00VYZJ03l0oooo000U0?ooo`040?[jnP3oool0oooo0?ooo`@0n_[j00H0oooo
0?[jnP3jn_X0n_[j0?ooo`3jn_X30?ooo`0407=cL`3_knl0no_k0?_kn`80l_;b02l0oooo0??cl`3^
k^h0iNGU0?Gem@3fm_H0n?Sh0?ooo`3_knl0c/k>09NGU`3fm_H0no_k0?ooo`3emOD0n_[j0?Ogm`3m
oOd0no_k0?ooo`3/k>`0i^KV0;bl_03^k^h0mOGe0>CTi03no_h0l?3`0=cLg03Shn<0i^KV0?ooo`3V
i^H0inOW0?Ogm`3[jn/0l?3`0>o_k`3^k^h0j^[Z0?Cdm03jn_X0o_kn0?ooo`3moOd0n_[j0?Gem@02
0?Shn0030?[jnP3moOd0k^k^0080n?Sh00T0kno_0>GUi@3Rh^80gMgM0>?Sh`3hn?P0o?cl0>OWi`3k
no/00P3inOT02P3YjNT0k>c/0>GUi@3_knl0gMgM0>k^kP3fm_H0lO7a0??cl`3emOD20?ooo`060??c
l`3dm?@0o?cl0?gmo@3clo<0oooo0P3clo<0303IfMT0f][J0?knoP3dm?@0i>CT0?KfmP3jn_X0alO7
0>SXj03bl_80_Kfm09jNWPd0oooo00<0n_[j0?ooo`3jn_X0;03oool0103jn_X0oooo0?ooo`3oool4
0?[jnP060?ooo`3jn_X0n_[j0?[jnP3oool0n_[j0`3oool0:`1bLW80lO7a0?gmo@3inOT0l_;b0?Cd
m03oool0m?Cd0?3`l03UiND0mOGe0?KfmP3inOT0oooo0>k^kP3>c/h0UYJF0?KfmP3kno/0oooo0?Ge
m@3inOT0moOg0?clo03kno/0oooo0>c/k03Vi^H0_Kfm0?7al@3gmoL0hn?S0?gmo@3^k^h0fm_K0>3P
h03Vi^H0oooo0>KViP3WinL0mOGe0>c/k03`l?000P3^k^h0203Zj^X0m?Cd0?[jnP3moOd0oooo0?cl
o03jn_X0mOGe0P3gmoL03P3inOT0oOgm0>k^kP3gmoL0nOWi0?7al@3Ti>@0h>3P0=_Kf`3QhN40moOg
0?gmo@3UiND0no_k0P3inOT02P3Xj>P0j^[Z0>KViP3^k^h0fm_K0>c/k03fm_H0l?3`0?Gem@3dm?@2
0?ooo`080?Cdm03emOD0o?cl0?_kn`3clo<0oooo0?Gem@3clo<20=WIf@030?ooo`3bl_80i>CT0080
moOg00D0bLW90>[ZjP3clo<0];Bd09ZJVP0=0?ooo`030?[jnP3oool0n_[j02l0oooo000X0?ooo`80
n_[j2`3oool01P3jn_X0F5QH0>SXj03oool0no_k0?Win@80l_;b00d0lo?c0?_kn`3Kfm/0kno_0?oo
o`3fm_H0inOW0??cl`3^k^h0XZ:R0>k^kP3hn?P0nOWi0080moOg00@0oooo0?_kn`3oool0oooo0P3m
oOd0503[jn/0f][J0=SHf03MgMd0clo?0<g=c@3GemL0clo?0<G5a@3IfMT0aLG50=?Cd`2l_;`0_Kfm
0<30`038b<P0f][J0>c/k03gmoL0oOgm0`3dm?@20?[jnP0E0?ooo`3moOd0nOWi0?clo03alO40nOWi
0>WYj@3/k>`0g]kN0?Win@3gmoL0iNGU0=SHf03Ng]h0o?cl0>g]k@3inOT0oOgm0?Gem@3oool0o?cl
0080n_[j00@0oooo0??cl`3bl_80lo?c0P3lo?`05P3clo<0oooo0?clo03emOD0no_k0?Gem@3clo<0
m_Kf0>o_k`2j^[X0hn?S0>SXj03`l?00hn?S0=SHf02`/;00l?3`0>o_k`3gmoL0jn_[0<G5a@3gmoLn
0?ooo`80n_[j2`3oool0103jn_X0F5QH0>_[j`3lo?`20?Win@0?0??cl`3fm_H0lO7a0?clo03Kfm/0
l?3`0?ooo`3fm_H0j>SX0?Cdm03/k>`0Y:BT0>k^kP3gmoL0nOWi0080moOg00@0oooo0?_kn`3oool0
oooo0P3lo?`0303Zj^X0emOG0=KFeP3MgMd0clo?0<c<c03EeMD0c/k>0<K6aP3GemL0a/K60=7Ad@80
^[Zj00H0_[jn0<K6aP3GemL0k>c/0?Ogm`3lo?`20?Cdm00H0??cl`3inOT0n_[j0?ooo`3moOd0nOWi
0?gmo@3bl_80nOWi0>SXj03/k>`0gMgM0?KfmP3jn_X0inOW0=WIf@3MgMd0oOgm0>c/k03inOT0oOgm
0?Cdm03oool0no_k0P3jn_X0703oool0m?Cd0?;blP3clo<0no_k0?clo03dm?@0oooo0?clo03fm_H0
oOgm0?Gem@3dm?@0moOg0>o_k`2j^[X0i>CT0>_[j`3alO40hn?S0=WIf@2c/k<0l?3`0>k^kP3fm_H0
i^KV0<;2`P3gmoLn0?ooo`009@3oool00`3jn_X0oooo0?[jnP040?ooo`030?[jnP3oool0oooo00L0
oooo01d0EeMG0?Gem@3bl_80lo?c0?Win@3bl_80i^KV0??cl`3oool0moOg0?ooo`3kno/0lo?c0>k^
kP3Hf=P0iNGU0;Fe]@3Ogml0m_Kf0?Gem@3jn_X0moOg0?[jnP3kno/0oooo0?[jnP3hn?P0n_[j0?Sh
n0030>OWi`0?0>_[j`3WinL0inOW0?Shn03Hf=P0emOG0=oOg`3UiND0i^KV0?Shn03]kNd0m?Cd0>g]
k@3oool0lO7a0080n_[j02T0m?Cd0?7al@3jn_X0m?Cd0?7al@3lo?`0n_[j0?KfmP3jn_X0mOGe0?3`
l03Fe]H0`<300=OGe`3Kfm/0n_[j0>k^kP37alL0[jn_0:NWY`2c/k<0gMgM0>WYj@3clo<0n_[j0?oo
o`3moOd0m_Kf0?[jnP3gmoL0o?cl0?;blP3clo<0oooo0?7al@3no_h0k^k^0?[jnP3lo?`0oOgm0?Sh
n0020<S8b00<0>o_k`3oool0no_k0?3`l03/k>`0];Bd0?Win@3Zj^X0moOg0>[ZjP2KVi/0W9bL303o
ool00`3jn_X0oooo0?ooo`070?ooo`030?[jnP3oool0oooo0280oooo00<0n_[j0?ooo`3jn_X0103o
ool00`3jn_X0oooo0?ooo`070?ooo`0M05MGE`3dm?@0m_Kf0??cl`3oool0lo?c0>SXj03dm?@0oooo
0?Ogm`3oool0no_k0?Gem@3`l?00emOG0>CTi02g]kL0gmoO0?KfmP3dm?@0n_[j0?Ogm`3jn_X0no_k
0?ooo`3jn_X0moOg0?[jnP3gmoL00`3Vi^H03`3Zj^X0inOW0>OWi`3gmoL0emOG0=GEe@3Ogml0i>CT
0>KViP3fm_H0k^k^0?Cdm03/k>`0oooo0?7al@020?[jnP0g0?Cdm03alO40n_[j0?Cdm03alO40o?cl
0?Win@3fm_H0n_[j0?Gem@3alO40eMGE0;jn_P3GemL0f][J0?Win@3_knl0b<S80;2`/02XZ:P0/[:b
0=_Kf`3Xj>P0lo?c0?_kn`3oool0oOgm0?Ogm`3inOT0moOg0?clo03bl_80lo?c0?ooo`3`l?00o?cl
0>o_k`3inOT0o?cl0?gmo@3inOT0b/[:0<W9b@3alO40oooo0?[jnP3alO40jNWY0;Jf]P3jn_X0kNg]
0?KfmP3/k>`0WYjN09bLW00<0?ooo`030?[jnP3oool0oooo00L0oooo00<0n_[j0?ooo`3oool09@3o
ool002D0oooo00<0n_[j0?ooo`3oool00P3jn_X00`3oool0n_[j0?ooo`090?ooo`0H05QHF03`l?00
no_k0>o_k`3inOT0oooo0?KfmP3kno/0l_;b0>[ZjP3Ph>00n?Sh0>_[j`3^k^h0h^;R0>KViP2o_kl0
fm_K0??cl`3hn?P0o?cl0?Gem@3jn_X0oOgm0P3jn_X00`3oool0n?Sh0?ooo`040?ooo`80moOg00<0
oooo0?Ogm`3gmoL00`3oool0?`3bl_80oooo0?ooo`3moOd0m_Kf0?Ogm`3jn_X0oooo0?gmo@3alO40
n?Sh0?ooo`3clo<0oooo0?[jnP3lo?`0mOGe0?[jnP3clo<0m?Cd0=;BdP3;bl/0e]KF0>o_k`3Vi^H0
no_k0=oOg`3EeMD0^k^k0;Fe]@3GemL0o?cl0?Ogm`3oool0o?cl0??cl`3hn?P0oOgm0?Gem@3clo<0
mOGe0>7Qh@3]kNd0inOW0?[jnP3fm_H0o?cl0?KfmP3oool0alO70=GEe@3oool0no_k0?Cdm03Ogml0
n?Sh0<c<c03Kfm/0jNWY0?Cdm03Ogml0Z:RX08b<S00k0?ooo`030?[jnP3oool0oooo0080n_[j00<0
oooo0?[jnP3oool02@3oool0601HF5P0l?3`0?_kn`3alO40o?cl0?ooo`3emOD0o?cl0??cl`3[jn/0
h^;R0?Win@3]kNd0kno_0>7Qh@3Ti>@0`/;20=_Kf`3clo<0moOg0?gmo@3emOD0n_[j0?clo080n_[j
00<0oooo0?Ogm`3oool0103oool20?KfmP030?ooo`3fm_H0m_Kf00<0oooo03l0l_;b0?ooo`3oool0
o?cl0?KfmP3gmoL0n_[j0?ooo`3lo?`0lO7a0?Ogm`3oool0l_;b0?ooo`3inOT0o?cl0?Gem@3jn_X0
l_;b0?Cdm03AdM40bLW90=GEe@3^k^h0inOW0?[jnP3Ogml0emOG0;bl_02e]KD0eMGE0?_kn`3gmoL0
oooo0?_kn`3dm?@0n_[j0?gmo@3fm_H0mOGe0?KfmP3QhN40k^k^0>SXj03inOT0moOg0?clo03fm_H0
oooo0<W9b@3EeMD0oooo0?clo03fm_H0gmoO0?KfmP3=cLd0f][J0>OWi`3clo<0gmoO0:b/[02=SHd0
?P3oool002P0oooo00<0n_[j0?ooo`3oool02P3oool04P3jn_X0Hf=S0>c/k03Shn<0k^k^0?_kn`3`
l?00oooo0?_kn`3oool0gMgM0>k^kP3oool0nOWi0?ooo`3Xj>P0jn_[0;Rh^080l?3`00D0lO7a0?Wi
n@3emOD0oooo0?_kn`020?[jnP030?ooo`3jn_X0oooo0080moOg00<0oooo0?Ogm`3gmoL00`3gmoL0
0`3clo<0moOg0?Ogm`020?Ogm`090?ooo`3jn_X0n?Sh0?ooo`3inOT0oooo0?gmo@3dm?@0lo?c0080
no_k00<0nOWi0?[jnP3oool01@3jn_X05`3clo<0nOWi0=oOg`3<c<`0d];B0>GUi@3MgMd0jn_[0?kn
oP3^k^h0j>SX0:n_[`2`/;00fm_K0>KViP3Zj^X0k>c/0>o_k`3jn_X0jNWY0=SHf03YjNT0oooo0080
hN7Q01<0n_[j0?;blP3lo?`0n?Sh0:VYZ@3YjNT0gmoO0>o_k`3inOT0l_;b0?3`l039bLT0a/K60>SX
j03alO40]kNg0>o_k`31`L40f=SH03d0oooo00<0n_[j0?ooo`3oool02P3oool03`3jn_X0Hf=S0>g]
k@3UiND0kno_0?Win@3`l?00oOgm0?clo03oool0gmoO0>k^kP3oool0no_k0?ooo`020>[ZjP080;Zj
^P3alO40kno_0?7al@3inOT0mOGe0?ooo`3kno/20?[jnP030?ooo`3jn_X0oooo0080m_Kf00<0oooo
0?KfmP3fm_H00`3fm_H00`3clo<0m_Kf0?KfmP020?KfmP090?ooo`3jn_X0moOg0?ooo`3inOT0oooo
0?clo03clo<0l_;b0080no_k0P3inOT00`3oool0nOWi0?[jnP030?[jnP0G0?Cdm03inOT0gMgM0<[:
bP3Cdm<0i>CT0=gMg@3/k>`0oOgm0>g]k@3Zj^X0[Jf]0;2`/03Kfm/0i^KV0>[ZjP3/k>`0l?3`0?_k
n`3Zj^X0fMWI0>WYj@3oool00P3QhN404`3inOT0lo?c0?_kn`3inOT0Zj^[0>[ZjP3QhN40l?3`0?[j
nP3bl_80kNg]0<g=c@37alL0inOW0>o_k`2g]kL0l_;b0<71`@3GemL0?@3oool002P0oooo00<0n_[j
0?ooo`3oool02`3oool0101dM7@0n_[j0>7Qh@3dm?@20?;blP050?ooo`3gmoL0oooo0?;blP3`l?00
0P3^k^h0203Shn<0jNWY0>SXj03Rh^80no_k0>g]k@3hn?P0mOGe0P3jn_X00`3oool0oOgm0?ooo`04
0?ooo`030?Ogm`3clo<0moOg0080moOg0P3oool20?Ogm`030?ooo`3gmoL0oooo0080moOg00@0mOGe
0?ooo`3inOT0k^k^0`3gmoL02`3oool0mOGe0?clo03lo?`0n_[j0?KfmP3emOD0no_k0?Win@3jn_X0
o?cl0080moOg00T0m_Kf0>GUi@3Cdm<0fm_K0>[ZjP3AdM40fm_K0>g]k@3clo<00P3Ng]h01P3Lg=`0
emOG0=WIf@3Jf]X0hN7Q0?ooo`80lo?c01H0emOG0>?Sh`3clo<0m?Cd0?Shn03gmoL0no_k0:6QX@3V
i^H0l?3`0?;blP3Rh^80l?3`0>k^kP3/k>`0`<300=GEe@3Fe]H0i^KV0>OWi`2`/;00jn_[?@3oool0
0`3jn_X0oooo0?ooo`0;0?ooo`0>07AdM03moOd0hN7Q0?Cdm03clo<0m_Kf0?clo03fm_H0oooo0??c
l`3alO40k^k^0?3`l03UiND20>OWi`050>;RhP3inOT0k>c/0?Ogm`3emOD00P3jn_X00`3oool0o?cl
0?ooo`040?ooo`030?KfmP3clo<0m_Kf0080m_Kf0P3oool20?KfmP030?ooo`3fm_H0oooo0080m_Kf
00T0mOGe0?ooo`3inOT0kNg]0?Ogm`3fm_H0moOg0?ooo`3dm?@00P3moOd01`3inOT0m_Kf0?Gem@3k
no/0nOWi0?[jnP3lo?`00P3gmoL0:@3emOD0iNGU0=?Cd`3Jf]X0jNWY0=;BdP3MgMd0k^k^0?Cdm03O
gml0g]kN0=cLg03GemL0g=cL0=_Kf`3Rh^80oooo0??cl`3dm?@0fMWI0>;RhP3clo<0mOGe0?Win@3f
m_H0nOWi0::RXP3Xj>P0l?3`0??cl`3Ti>@0lO7a0>g]k@3^k^h0`L710=OGe`3Fe]H0inOW0>KViP2_
[jl0jn_[03d0oooo000f0?ooo`0H09NGU`3bl_80oooo0>?Sh`3clo<0l_;b0>o_k`3clo<0no_k0??c
l`3WinL0l?3`0>CTi03oool0k^k^0>o_k`3MgMd0kNg]0>[ZjP3[jn/0n_[j0?Ogm`3jn_X0oOgm0`3j
n_X0103oool0n?Sh0??cl`3clo<50?ooo`030?Ogm`3oool0moOg00<0moOg0P3oool20?[jnP0:0?oo
o`3moOd0moOg0>o_k`3gmoL0n_[j0?Ogm`3oool0o?cl0?Shn080nOWi0100no_k0?ooo`3lo?`0m_Kf
0?clo03jn_X0moOg0?[jnP3alO40o?cl0>?Sh`3IfMT0fm_K0=WIf@3Ph>00moOg0P3bl_802`3Zj^X0
i^KV0>?Sh`3^k^h0oooo0?;blP3Lg=`0l_;b0?Cdm03fm_H0mOGe0080m_Kf00H0kno_09nOW`3bl_80
no_k0?Win@3fm_H20?3`l0070?[jnP3Bd]80i>CT0?knoP3]kNd0lo?c07moO`1<0?ooo`0>09RHV03d
m?@0oooo0>GUi@3alO40lo?c0?7al@3dm?@0o?cl0?Cdm03WinL0lO7a0>KViP3oool20>k^kP080=kN
gP3]kNd0jNWY0>[ZjP3inOT0moOg0?[jnP3lo?`30?[jnP040?ooo`3gmoL0lo?c0??cl`D0oooo00<0
m_Kf0?ooo`3fm_H00`3fm_H20?ooo`80n_[j00X0oooo0?clo03gmoL0kno_0?Ogm`3jn_X0m_Kf0?oo
o`3moOd0moOg0P3inOT0403kno/0oooo0?clo03fm_H0oOgm0?Win@3fm_H0n_[j0?3`l03lo?`0i>CT
0=_Kf`3Lg=`0emOG0=oOg`3jn_X20??cl`0;0>[ZjP3Vi^H0i>CT0>k^kP3lo?`0lo?c0=cLg03alO40
mOGe0?KfmP3gmoL00P3fm_H03`3alO40X:2P0??cl`3lo?`0no_k0?KfmP3alO40l?3`0?ooo`3EeMD0
k>c/0?gmo@3/k>`0l_;b0820P00n0?ooo`00=P3oool01P2JVYX0lO7a0?gmo@3hn?P0oOgm0>GUi@<0
lo?c0100oooo0>KViP3`l?00l?3`0?;blP3Xj>P0h^;R0=oOg`3UiND0lO7a0?KfmP3`l?00mOGe0?Og
m`3moOd0oooo103jn_X20?Ogm`030??cl`3gmoL0moOg0080moOg00@0oooo0?Ogm`3oool0oooo103g
moL01`3oool0no_k0?Ogm`3fm_H0moOg0?Cdm03oool00P3gmoL00`3lo?`0oooo0?[jnP020?[jnP0@
0?ooo`3kno/0no_k0?Win@3oool0moOg0?Gem@3moOd0o_kn0?[jnP3fm_H0k^k^0>_[j`3`l?00jNWY
0=oOg`80hN7Q00H0g]kN0<[:bP3Ti>@0j>SX0=oOg`3/k>`20?Shn00E0?Cdm03inOT0oooo0?ooo`3f
m_H0kNg]0;Rh^03^k^h0no_k0?;blP3]kNd0l?3`0?Gem@3Rh^80moOg0??cl`3^k^h0kNg]0>;RhP1e
MGD0cLg=04/0oooo00H0VYZJ0?7al@3lo?`0m_Kf0?[jnP3Vi^H30?Cdm0030?ooo`3UiND0lO7a0080
lO7a00/0j^[Z0>;RhP3Rh^80iNGU0??cl`3fm_H0l?3`0?Gem@3gmoL0o?cl0?ooo`040?[jnP80m_Kf
00<0lo?c0?KfmP3fm_H00P3fm_H0103oool0m_Kf0?ooo`3oool40?KfmP070?ooo`3kno/0m_Kf0?Kf
mP3gmoL0m?Cd0?ooo`020?KfmP030?gmo@3oool0nOWi0080nOWi01P0oooo0?_kn`3kno/0nOWi0?oo
o`3fm_H0mOGe0?gmo@3oool0n_[j0?KfmP3_knl0jn_[0>o_k`3Zj^X0gMgM0>3Ph03Ogml0g]kN0<[:
bP3UiND0jNWY0=gMg@3Zj^X20?Win@0E0?Cdm03fm_H0oooo0?ooo`3fm_H0k^k^0;Ng]`3_knl0o?cl
0??cl`3`l?00lO7a0?Cdm03Shn<0m_Kf0?Cdm03]kNd0k^k^0>7Qh@1fMWH0cLg=03d0oooo000b0?oo
o`<0n_[j00`0oooo08:2PP3Shn<0oOgm0?Win@3UiND0j^[Z0??cl`3^k^h0oooo0>KViP3clo<20?kn
oP0<0?7al@3Xj>P0i^KV0>CTi03WinL0kNg]0>_[j`3`l?00mOGe0?Ogm`3moOd0oooo0`3jn_X0103o
ool0n_[j0?Gem@3oool40?Ogm`@0oooo00@0moOg0??cl`3oool0moOg0P3oool08`3inOT0m?Cd0?gm
o@3gmoL0m?Cd0??cl`3dm?@0moOg0?[jnP3oool0o?cl0?[jnP3kno/0oooo0?[jnP3kno/0mOGe0?oo
o`3inOT0o_kn0?ooo`3no_h0moOg0?KfmP3inOT0lo?c0>c/k03Zj^X0hN7Q0=WIf@3EeMD0f][J0>3P
h03Hf=P0jn_[0080m_Kf00T0n?Sh0?knoP3gmoL0no_k0?knoP3]kNd0j>SX0<S8b03^k^h00P3emOD0
2`3_knl0jNWY0>GUi@3/k>`0jn_[0>KViP3kno/0l_;b0>3Ph02c/k<0Ti>C04L0oooo0`3jn_X0303o
ool0PX:20>?Sh`3kno/0moOg0>CTi03[jn/0m?Cd0>o_k`3oool0iNGU0?Cdm080oooo00<0l?3`0>[Z
jP3Vi^H00P3WinL01`3^k^h0jn_[0?3`l03emOD0moOg0?clo03oool00`3jn_X0103oool0n_[j0?Ge
m@3oool40?KfmP@0oooo00@0m_Kf0??cl`3oool0m_Kf0P3oool0503inOT0m?Cd0?clo03gmoL0m?Cd
0?;blP3clo<0moOg0?Win@3oool0o?cl0?Win@3kno/0oooo0?Win@3kno/0mOGe0?ooo`3inOT0oOgm
0P3oool04@3gmoL0m_Kf0?Win@3clo<0jn_[0>[ZjP3Rh^80fm_K0=GEe@3Kfm/0gmoO0=OGe`3Zj^X0
moOg0?KfmP3inOT0oOgm0080nOWi00D0o?cl0>k^kP3WinL0alO70>o_k`020?Cdm00;0?7al@3Zj^X0
i^KV0>_[j`3/k>`0inOW0?[jnP3alO40h>3P0;:b/P2CTi<0?@3oool002`0oooo00<0n_[j0?ooo`3o
ool01`3oool01P2?Shl0n_[j0>_[j`3alO40i>CT0?Ogm`80no_k0140lo?c0?;blP3[jn/0jn_[0>k^
kP3oool0m?Cd0?7al@3Rh^80fm_K0=WIf@3bl_80n_[j0?7al@3oool0oOgm0?ooo`020?[jnP070?Sh
n03oool0moOg0??cl`3gmoL0lo?c0?Ogm`040?ooo`80moOg00@0oooo0?Ogm`3gmoL0moOg0P3oool0
1`3dm?@0oOgm0?Cdm03gmoL0lO7a0?Win@3gmoL00P3jn_X0203lo?`0oooo0?clo03jn_X0n?Sh0?cl
o03oool0kno_0P3jn_X00`3emOD0m_Kf0?knoP030?Ogm`030?;blP3kno/0o?cl0080kNg]00D0kno_
0?Win@3clo<0lo?c0?[jnP030?Shn00<0?7al@3kno/0n?Sh0?KfmP3/k>`0f][J0=oOg`3^k^h0nOWi
0?_kn`3dm?@0no_k0P3inOT01`3gmoL0j>SX0>k^kP3Shn<0l?3`0??cl`1MGEd0@@3oool00`3jn_X0
oooo0?ooo`070?ooo`0608n?S`3moOd0j^[Z0?7al@3Shn<0nOWi0P3jn_X04@3dm?@0lo?c0>[ZjP3]
kNd0kno_0?ooo`3clo<0l?3`0>;RhP3Lg=`0fMWI0?7al@3jn_X0lO7a0?ooo`3lo?`0oooo0080n_[j
00L0moOg0?ooo`3fm_H0lo?c0?KfmP3clo<0m_Kf00@0oooo0P3fm_H0103oool0m_Kf0?KfmP3fm_H2
0?ooo`070?Cdm03lo?`0m?Cd0?Ogm`3alO40nOWi0?Ogm`020?Win@080?_kn`3oool0o?cl0?[jnP3g
moL0o?cl0?ooo`3_knl20?Win@030?Cdm03fm_H0oooo00<0moOg00<0lO7a0?_kn`3lo?`00P3/k>`0
103^k^h0m_Kf0??cl`3clo<20?Win@030?[jnP3inOT0lO7a0080nOWi00T0mOGe0>c/k03Kfm/0hN7Q
0>o_k`3kno/0o?cl0?KfmP3lo?`00P3jn_X01`3fm_H0j>SX0>o_k`3UiND0lO7a0??cl`1NGUh0?@3o
ool00340oooo00<0n_[j0?ooo`3oool00P3oool05`2h^;P0o?cl0?Ogm`3`l?00i>CT0?Cdm03`l?00
kNg]0??cl`3^k^h0oooo0>OWi`3Zj^X0oooo0=gMg@3moOd0emOG0?7al@3YjNT0moOg0?Gem@3hn?P0
n_[j0080oOgm0`3jn_X20?ooo`040??cl`3oool0moOg0??cl`80moOg103oool03@3gmoL0m?Cd0?Og
m`3gmoL0oooo0?Ogm`3oool0o?cl0>g]k@3gmoL0nOWi0?Ogm`3bl_800P3jn_X03`3inOT0n_[j0?oo
o`3jn_X0o?cl0?_kn`3lo?`0nOWi0?clo03gmoL0mOGe0?[jnP3no_h0n_[j0?Shn0020?ooo`0;0?[j
nP3emOD0moOg0?ooo`3inOT0oOgm0??cl`3oool0moOg0?clo03fm_H00P3hn?P01@3oool0o_kn0>_[
j`3Ph>00d];B0080kno_00h0nOWi0?Gem@3`l?00m_Kf0>o_k`3fm_H0oOgm0??cl`3kno/0k^k^0=GE
e@3clo<0O7al0?OgmdD0oooo00<0n_[j0?ooo`3oool00P3oool05`2g]kL0nOWi0?Ogm`3alO40hn?S
0?KfmP3`l?00k>c/0?Cdm03_knl0o?cl0>OWi`3[jn/0oooo0=gMg@3oool0f=SH0?3`l03YjNT0m_Kf
0?Gem@3gmoL0n_[j0080o?cl0`3jn_X20?ooo`040??cl`3oool0m_Kf0??cl`80m_Kf103oool03`3f
m_H0lo?c0?KfmP3fm_H0oooo0?KfmP3oool0no_k0>c/k03gmoL0nOWi0?Ogm`3bl_80nOWi0?[jnP02
0?Win@0=0?ooo`3inOT0oOgm0?_kn`3moOd0nOWi0?gmo@3gmoL0m?Cd0?[jnP3oool0n_[j0?Ogm`02
0?ooo`0;0?[jnP3emOD0moOg0?ooo`3inOT0oOgm0?Cdm03oool0moOg0?clo03fm_H00P3jn_X05@3o
ool0o?cl0>c/k03Ogml0dm?C0>o_k`3alO40no_k0?KfmP3alO40m_Kf0?7al@3fm_H0o?cl0??cl`3l
o?`0k^k^0=OGe`3clo<0Ng]k0?Ogm`0l0?ooo`00<P3oool0203jn_X0oooo0?ooo`3oool0lo?c0>;R
hP3Zj^X0l_;b0P3clo<20?Ogm`030>_[j`3kno/0l_;b0080h^;R00/0lo?c0>[ZjP3`l?00j^[Z0>o_
k`3MgMd0inOW0?Gem@3]kNd0mOGe0?gmo@030?ooo`80n_[j00H0moOg0?ooo`3gmoL0moOg0?ooo`3c
lo<50?Ogm`0:0?KfmP3gmoL0moOg0?ooo`3jn_X0oooo0?Ogm`3moOd0m?Cd0?Ogm`80n_[j00D0mOGe
0?Win@3gmoL0n_[j0?gmo@020?ooo`030?Ogm`3moOd0n_[j0080o?cl00@0oooo0>k^kP3no_h0mOGe
0P3inOT0103oool0n_[j0?;blP3gmoL30?ooo`0=0?[jnP3kno/0oOgm0?Win@3jn_X0oOgm0?knoP3g
moL0mOGe0>OWi`3alO40g=cL0=kNgP020?;blP040?Ogm`3_knl0nOWi0?3`l080m_Kf00P0mOGe0?gm
o@3bl_80jn_[0=SHf03_knl0Xj>S0?[jnTH0oooo00L0n_[j0?ooo`3oool0oooo0??cl`3Rh^80jNWY
00<0lo?c00D0m_Kf0?Win@3[jn/0no_k0??cl`020>GUi@0;0?Cdm03[jn/0l?3`0>SXj03^k^h0fm_K
0>SXj03emOD0k>c/0?Gem@3lo?`00`3oool20?[jnP060?KfmP3oool0m_Kf0?KfmP3oool0lo?c203f
m_H01`3oool0n_[j0?ooo`3gmoL0o?cl0?Cdm03fm_H00P3jn_X01@3emOD0nOWi0?KfmP3inOT0oOgm
0080oooo00<0moOg0?gmo@3jn_X00P3moOd0103oool0k^k^0?ooo`3emOD20?Win@040?ooo`3jn_X0
lO7a0?Ogm`<0oooo00<0nOWi0?_kn`3moOd00P3inOT20?gmo@80moOg00@0j>SX0?3`l03Ph>00h^;R
0P3clo<01@3gmoL0lO7a0?[jnP3`l?00moOg0080m_Kf00L0o?cl0??cl`3/k>`0f=SH0>o_k`2RXZ80
n_[j03`0oooo000f0?ooo`060?7al@3YjNT0oooo0>k^kP3fm_H0lo?c0P3gmoL00`3^k^h0oooo0?3`
l0020>c/k00:0??cl`3kno/0l?3`0>_[j`3_knl0fm_K0>OWi`3Zj^X0jn_[0?Shn0@0oooo00@0n?Sh
0?[jnP3gmoL0moOg0P3clo<0103oool0lo?c0?ooo`3gmoL20?ooo`030?Ogm`3lo?`0moOg0080oooo
01L0n_[j0?gmo@3moOd0m?Cd0?gmo@3alO40o_kn0?Shn03emOD0nOWi0?Ogm`3oool0n_[j0?Win@3h
n?P0nOWi0?KfmP3clo<0moOg0?Win@3jn_X0nOWi0?Gem@020?Win@80oooo0P3jn_X01`3lo?`0oooo
0?clo03moOd0no_k0?ooo`3jn_X00`3hn?P20?knoP0F0?Ogm`3Zj^X0i^KV0=;BdP3Vi^H0gmoO0?oo
o`3inOT0i>CT0=?Cd`3fm_H0k^k^0?gmo@3bl_80mOGe0>[ZjP3Xj>P0jNWY0>o_k`2`/;00fMWI0?Og
mdT0oooo00H0lO7a0>OWi`3oool0k^k^0?Gem@3bl_820?KfmP030>g]k@3lo?`0l_;b0080kno_00L0
m?Cd0?[jnP3`l?00jn_[0>k^kP3Lg=`0iNGU0080j^[Z00<0moOg0?ooo`3oool00P3oool0103gmoL0
n_[j0?KfmP3fm_H20??cl`040?ooo`3clo<0oooo0?KfmP80oooo00<0m_Kf0?clo03fm_H00P3oool0
303jn_X0o?cl0?clo03dm?@0o?cl0?7al@3moOd0moOg0?Cdm03inOT0m_Kf0?ooo`80nOWi00D0moOg
0?Win@3fm_H0l_;b0?KfmP030?Win@030?Gem@3inOT0nOWi0080oooo0P3jn_X01P3moOd0oooo0?gm
o@3moOd0no_k0?ooo`80nOWi0P3jn_X20?gmo@0F0?KfmP3[jn/0j>SX0=?Cd`3YjNT0h>3P0?ooo`3j
n_X0i^KV0=GEe@3fm_H0k^k^0?clo03clo<0mOGe0>_[j`3YjNT0j>SX0>o_k`2_[jl0fMWI0?Ogmc/0
oooo000_0?ooo`030?[jnP3oool0n_[j00<0n_[j00P0lO7a0?3`l03emOD0l?3`0>k^kP3jn_X0kNg]
0?Ogm`80lo?c00@0oooo0>?Sh`3fm_H0no_k0P3clo<03P3kno/0emOG0?Shn03dm?@0emOG0>GUi@3O
gml0nOWi0?[jnP3kno/0oooo0?gmo@3hn?P0oooo0P3gmoL20?ooo`80moOg103oool20?Ogm`@0oooo
00H0n?Sh0?Cdm03moOd0kNg]0?KfmP3moOd20?Win@030?Shn03lo?`0n?Sh0080oooo00<0o?cl0?Og
m`3kno/00P3jn_X01@3inOT0mOGe0?_kn`3no_h0no_k00<0oooo00<0n?Sh0?[jnP3jn_X00P3fm_H2
0?[jnP0L0?gmo@3bl_80m_Kf0?KfmP3gmoL0n?Sh0?KfmP3_knl0j>SX0=;BdP3Xj>P0hn?S0?ooo`3g
moL0j^[Z0>o_k`3emOD0m_Kf0?Shn03fm_H0oooo0?gmo@3oool0m_Kf0>_[j`3IfMT0c/k>0;Fe]D<0
oooo00<0n_[j0?ooo`3jn_X00`3jn_X03P3alO40lo?c0?KfmP3alO40k^k^0?gmo@3/k>`0m_Kf0??c
l`3dm?@0oooo0>GUi@3gmoL0oOgm0P3dm?@03P3jn_X0emOG0?Gem@3`l?00emOG0>GUi@3Ogml0nOWi
0?[jnP3kno/0oooo0?clo03gmoL0oooo0P3fm_H20?ooo`80m_Kf103oool20?KfmP@0oooo00H0moOg
0??cl`3lo?`0k>c/0?KfmP3moOd20?Win@030?Ogm`3moOd0moOg0080oooo00@0oOgm0?KfmP3kno/0
n_[j0P3inOT0103emOD0no_k0?clo03lo?`30?ooo`030?Ogm`3jn_X0n_[j0080m_Kf00D0n_[j0?Wi
n@3moOd0l_;b0?KfmP020?Ogm`0G0?[jnP3fm_H0l?3`0>SXj03Bd]80j>SX0>GUi@3oool0m_Kf0>_[
j`3alO40mOGe0?KfmP3inOT0m_Kf0?ooo`3lo?`0oooo0?KfmP3]kNd0f][J0<k>cP2f][H0?03oool0
02l0oooo00@0n_[j0?ooo`3jn_X0oooo0P3jn_X0703[jn/0gmoO0?[jnP3_knl0moOg0?ooo`3clo<0
m_Kf0>c/k03_knl0oooo0>k^kP3`l?00l_;b0??cl`3bl_80nOWi0>OWi`3]kNd0lO7a0?Gem@3QhN40
i^KV0>o_k`3emOD0oooo0?_kn`3oool20?[jnP80oooo00<0lo?c0?Ogm`3clo<0103oool00`3gmoL0
lo?c0??cl`020?Ogm`80oooo00<0lO7a0?gmo@3gmoL00P3gmoL03`3lo?`0n_[j0?Shn03lo?`0oooo
0?[jnP3oool0oOgm0?7al@3kno/0oOgm0?Ogm`3moOd0k>c/0?KfmP020?_kn`0H0?[jnP3oool0n_[j
0?Ogm`3lo?`0m_Kf0?Ogm`3lo?`0o_kn0?clo03moOd0nOWi0?clo03hn?P0l_;b0?Shn03jn_X0o?cl
0>g]k@3/k>`0fMWI0>CTi03^k^h0oooo0P3QhN40103Ogml0nOWi0?KfmP3clo<30?Win@060?Shn03k
no/0l_;b0?Win@35aLD0e]KF@`3oool0103jn_X0oooo0?[jnP3oool20?[jnP0=0>_[j`3Ng]h0oOgm
0>g]k@3emOD0oooo0??cl`3fm_H0jn_[0>k^kP3oool0kno_0?;blP030??cl`0<0?Ogm`3Xj>P0k^k^
0?3`l03fm_H0h>3P0>GUi@3^k^h0mOGe0?ooo`3kno/0oooo0P3jn_X20?ooo`030??cl`3fm_H0lo?c
00@0oooo00<0m_Kf0??cl`3clo<00P3fm_H20?ooo`0O0?7al@3lo?`0moOg0?Ogm`3fm_H0oOgm0?Wi
n@3gmoL0oOgm0?ooo`3inOT0oooo0?gmo@3alO40no_k0?gmo@3gmoL0oOgm0>[ZjP3fm_H0o?cl0?_k
n`3inOT0oooo0?[jnP3gmoL0oOgm0?KfmP3gmoL0oOgm0?clo0020?gmo@0=0?Win@3lo?`0nOWi0??c
l`3jn_X0nOWi0?gmo@3_knl0k>c/0=OGe`3UiND0kno_0?ooo`030>7Qh@030?Win@3fm_H0l_;b00@0
nOWi00D0o?cl0??cl`3inOT0`l?30=KFeP0l0?ooo`00<@3oool20?[jnP0<0?ooo`3jn_X0b<S80>g]
k@3hn?P0n_[j0?clo03emOD0lO7a0>_[j`3moOd0kno_0P3oool00`3QhN40l_;b0??cl`030>o_k`0;
0>SXj03YjNT0mOGe0?3`l03Jf]X0l?3`0?[jnP3gmoL0oOgm0?ooo`3inOT00P3jn_X01P3oool0moOg
0??cl`3gmoL0oooo0?Ogm`<0oooo0140lo?c0?Ogm`3gmoL0oooo0?Shn03oool0oOgm0?KfmP3dm?@0
moOg0?ooo`3gmoL0n_[j0?Ogm`3oool0moOg0??cl`020?Ogm`030?Win@3hn?P0moOg0080oooo00H0
o?cl0?_kn`3kno/0nOWi0?_kn`3hn?P20?Win@090??cl`3jn_X0oooo0?Win@3jn_X0n?Sh0?clo03h
n?P0lo?c0080mOGe00<0n_[j0?Ogm`3hn?P00P3/k>`02@3clo<0kNg]0?Cdm03Shn<0l_;b0?KfmP3m
oOd0mOGe0?Shn0020?ooo`080>k^kP3WinL0moOg0?Win@3kno/0jNWY05mOG`3gmoM50?ooo`80n_[j
00`0oooo0?[jnP39bLT0k>c/0?KfmP3moOd0nOWi0?KfmP3alO40jn_[0?ooo`3^k^h20?ooo`0A0>CT
i03clo<0m?Cd0?7al@3^k^h0lO7a0>KViP3YjNT0m_Kf0?7al@3IfMT0kno_0?[jnP3fm_H0o?cl0?oo
o`3inOT00P3jn_X01P3oool0m_Kf0??cl`3fm_H0oooo0?KfmP<0oooo0140lo?c0?KfmP3fm_H0oooo
0?Ogm`3oool0o?cl0?KfmP3dm?@0moOg0?ooo`3fm_H0nOWi0?KfmP3oool0m_Kf0??cl`020?KfmP80
nOWi00<0m_Kf0?ooo`3oool00P3lo?`0103kno/0nOWi0?clo03gmoL20?Win@090??cl`3kno/0oooo
0?Win@3jn_X0moOg0?clo03gmoL0m?Cd0080moOg00<0nOWi0?Ogm`3inOT00P3]kNd02@3dm?@0kNg]
0?KfmP3Ti>@0lo?c0?KfmP3lo?`0m_Kf0?Win@020?ooo`080>k^kP3WinL0m_Kf0?_kn`3inOT0j^[Z
05mOG`3gmoLl0?ooo`00;@3oool0103jn_X0oooo0?[jnP3oool40?[jnP0J0:BTY03gmoL0j^[Z0?gm
o@3no_h0n?Sh0?KfmP3clo<0moOg0?Gem@3inOT0lo?c0?_kn`3Hf=P0lo?c0>k^kP3_knl0f=SH0>WY
j@3bl_80k^k^0?Cdm03bl_80hN7Q0>c/k03clo<20?gmo@070?ooo`3jn_X0oooo0?[jnP3oool0moOg
0?ooo`020?Ogm`030?ooo`3gmoL0moOg0080oooo00H0moOg0?ooo`3jn_X0oooo0?_kn`3gmoL40?Kf
mP080?Win@3oool0n_[j0?ooo`3gmoL0oooo0?Gem@3gmoL20?[jnP050?Gem@3jn_X0oooo0?knoP3e
mOD00P3gmoL04`3hn?P0moOg0?ooo`3lo?`0no_k0?ooo`3moOd0oooo0?clo03dm?@0mOGe0?KfmP3e
mOD0oOgm0??cl`3emOD0j>SX0>g]k@3Vi^H00P3alO40203^k^h0h^;R0?KfmP3inOT0oooo0?KfmP3k
no/0lo?c0P3fm_H01P3inOT0lo?c0?3`l03^k^h0dm?C08b<S480oooo00@0n_[j0?ooo`3jn_X0oooo
103jn_X06P2UYJD0m_Kf0>_[j`3lo?`0oOgm0?KfmP3emOD0m?Cd0?Ogm`3clo<0nOWi0?Cdm03jn_X0
fMWI0?Cdm03_knl0k^k^0=OGe`3Zj^X0kno_0?7al@3emOD0lo?c0>3Ph03Zj^X0lo?c0P3lo?`01`3o
ool0n_[j0?ooo`3jn_X0oooo0?KfmP3oool00P3fm_H00`3oool0m_Kf0?KfmP020?ooo`060?KfmP3o
ool0n_[j0?ooo`3kno/0moOg0P3fm_H03P3emOD0m_Kf0?Win@3oool0nOWi0?ooo`3fm_H0oooo0?Ge
m@3fm_H0nOWi0?[jnP3dm?@0nOWi0P3oool00`3emOD0m_Kf0?Ogm`020?Ogm`0K0?ooo`3moOd0no_k
0?ooo`3moOd0oooo0?clo03clo<0m_Kf0?Ogm`3fm_H0no_k0?Cdm03emOD0j^[Z0>o_k`3Ti>@0m?Cd
0?;blP3_knl0i>CT0?KfmP3inOT0oooo0?KfmP3lo?`0lo?c0080m_Kf00H0nOWi0?;blP3`l?00k^k^
0=?Cd`2<S8`m0?ooo`00;`3oool30?[jnP80oooo01d0n_[j0;Vi^@3no_h0h>3P0?[jnP3alO40n_[j
0?KfmP3lo?`0lo?c0?ooo`3hn?P0k^k^0?_kn`3QhN40lo?c0>o_k`3oool0kNg]0?Win@3WinL0oooo
0?3`l03fm_H0hN7Q0>_[j`3fm_H0moOg0?ooo`020?[jnP050?ooo`3jn_X0oooo0?ooo`3gmoL00P3o
ool20?Ogm`050?ooo`3clo<0oooo0?ooo`3jn_X00P3oool00`3moOd0m?Cd0?7al@020?KfmP80n_[j
00H0oooo0?Win@3oool0lo?c0?Ogm`3inOT20?Ogm`80n_[j00/0o_kn0?_kn`3jn_X0lO7a0?Ogm`3h
n?P0lo?c0?clo03kno/0oooo0?gmo@020?clo080oOgm00H0m_Kf0?Shn03moOd0l_;b0?[jnP3emOD3
0>o_k`0C0>SXj03dm?@0l_;b0?;blP3emOD0n?Sh0?KfmP3clo<0m?Cd0??cl`3/k>`0k^k^0?KfmP3_
knl0oOgm0?Ogm`3`l?00cLg=0::RXP140?ooo`<0n_[j0P3oool06P3jn_X0^[Zj0?gmo@3Ogml0oOgm
0?7al@3kno/0mOGe0?gmo@3clo<0oooo0?Win@3_knl0n_[j0>;RhP3dm?@0k^k^0?gmo@3]kNd0nOWi
0>KViP3oool0lO7a0?Win@3Ng]h0j^[Z0P3fm_H01@3oool0n_[j0?[jnP3oool0n_[j0080oooo00<0
m_Kf0?ooo`3oool00P3fm_H01@3oool0lo?c0?ooo`3oool0n_[j0080oooo00<0o?cl0??cl`3alO40
0P3fm_H20?Win@060?ooo`3inOT0oooo0??cl`3fm_H0nOWi0P3fm_H20?Win@0;0?ooo`3kno/0nOWi
0>o_k`3fm_H0moOg0?;blP3moOd0no_k0?ooo`3moOd00P3lo?`20?gmo@0A0?KfmP3jn_X0oOgm0??c
l`3inOT0moOg0?7al@3`l?00kno_0>SXj03fm_H0lO7a0??cl`3fm_H0nOWi0?Ogm`3bl_800P3dm?@0
2@3[jn/0kNg]0?Ogm`3_knl0o?cl0?KfmP3`l?00c<c<0::RXP0m0?ooo`00;`3oool0103jn_X0oooo
0?[jnP3jn_X20?ooo`040<k>cP3no_h0i^KV0?3`l080kNg]00L0n_[j0??cl`3lo?`0jn_[0>c/k03c
lo<0k^k^00<0no_k0P3dm?@20>k^kP0<0>c/k03dm?@0lo?c0>g]k@3bl_80m?Cd0?;blP3moOd0oooo
0?Ogm`3jn_X0lO7a0P3oool00`3clo<0oooo0?Ogm`050?Ogm`D0oooo00D0moOg0?ooo`3inOT0oOgm
0?Shn0020?[jnP0D0?clo03gmoL0mOGe0?KfmP3gmoL0n_[j0?Win@3jn_X0mOGe0?knoP3inOT0l_;b
0?ooo`3kno/0oOgm0?Shn03inOT0no_k0?gmo@3lo?`20?Win@80n_[j00X0oOgm0?ooo`3hn?P0o_kn
0?Gem@3jn_X0moOg0>CTi03QhN40k^k^0P3inOT01@3oool0moOg0?Win@3inOT0lo?c0080m_Kf00<0
inOW0?Win@3fm_H00P3fm_H0103Vi^H0nOWi0=[JfP24Q8A40?ooo`040?[jnP3oool0n_[j0?[jnP80
oooo00T0c/k>0?gmo@3UiND0lO7a0>c/k03[jn/0oOgm0?;blP3inOT00P3[jn/00`3dm?@0kno_0?gm
o@020?[jnP80m_Kf00H0l?3`0>o_k`3]kNd0mOGe0??cl`3/k>`20??cl`060?7al@3lo?`0oooo0?Kf
mP3jn_X0lO7a0P3oool00`3clo<0oooo0?KfmP050?KfmPD0oooo00D0moOg0?ooo`3inOT0oOgm0?Og
m`020?Win@030?gmo@3fm_H0mOGe0080m_Kf0`3inOT01@3clo<0oOgm0?Win@3bl_80oooo0080o?cl
00D0moOg0?Win@3kno/0oOgm0?clo0040?Win@0A0?gmo@3oool0n_[j0?clo03clo<0nOWi0?Ogm`3V
i^H0hn?S0>c/k03gmoL0n_[j0?ooo`3gmoL0nOWi0?[jnP3clo<00P3fm_H00`3WinL0n_[j0?KfmP02
0?KfmP040>SXj03inOT0fm_K08B4Q3d0oooo000`0?ooo`030?[jnP3oool0moOg0080oooo01D0`l?3
0?;blP3/k>`0jNWY0?Shn03fm_H0oooo0?clo03fm_H0oooo0>;RhP3clo<0k^k^0?Win@3clo<0no_k
0?Cdm03]kNd0k>c/0>7Qh@3clo<00P3^k^h02`3YjNT0lO7a0?7al@3clo<0oOgm0?_kn`3moOd0oooo
0?Shn03gmoL0oooo0080moOg00<0lo?c0?Ogm`3clo<00`3gmoL04`3oool0n_[j0?[jnP3jn_X0lO7a
0?KfmP3moOd0o?cl0?Shn03jn_X0moOg0?7al@3fm_H0lO7a0?;blP3jn_X0oOgm0?Win@3oool00P3m
oOd0103kno/0o_kn0?Shn03kno/20?ooo`080?Win@3jn_X0n_[j0?Win@3jn_X0oOgm0?Shn03inOT2
0?Shn00K0?Gem@3fm_H0mOGe0>WYj@3Zj^X0k^k^0=oOg`3Xj>P0oooo0?_kn`3oool0kNg]0?_kn`3X
j>P0kNg]0?ooo`3kno/0m_Kf0?Win@3oool0h^;R0?Ogm`3Ti>@0kno_0>k^kP1KFe/0d];B04D0oooo
00<0n_[j0?ooo`3gmoL00P3oool01033`l<0l_;b0>_[j`3WinL20?KfmP0;0?ooo`3moOd0m_Kf0?oo
o`3Ti>@0m?Cd0>o_k`3gmoL0m?Cd0?[jnP3fm_H00P3/k>`01@3Ogml0lo?c0>g]k@3_knl0j>SX0080
l?3`00P0lo?c0?clo03kno/0o?cl0?ooo`3gmoL0m_Kf0?ooo`80m_Kf00<0lo?c0?KfmP3clo<00`3f
m_H04`3oool0n_[j0?[jnP3jn_X0lO7a0?KfmP3lo?`0oOgm0?Ogm`3inOT0m_Kf0?7al@3fm_H0l?3`
0?7al@3inOT0oOgm0?Win@3oool00P3moOd0103lo?`0oOgm0?Ogm`3lo?`20?ooo`030?Win@3kno/0
nOWi0080nOWi01`0oOgm0?Win@3inOT0n_[j0?Win@3gmoL0m_Kf0??cl`3WinL0j^[Z0>k^kP3Rh^80
j^[Z0?ooo`3jn_X0oooo0?3`l03lo?`0jn_[0?3`l03oool0n_[j0?KfmP3jn_X0oooo0>?Sh`3gmoL0
iNGU0P3`l?000`1KFe/0d];B0?ooo`0l0?ooo`00;03oool20?[jnP030?ooo`3jn_X0oooo0080n_[j
0P3oool0303Jf]X0l_;b0?Ogm`3gmoL0i^KV0?7al@3/k>`0mOGe0>c/k03Ogml0oooo0>7Qh@80lo?c
00H0m?Cd0?KfmP3kno/0lo?c0?Ogm`3UiND20>k^kP080>g]k@3Vi^H0lo?c0>SXj03jn_X0mOGe0?oo
o`3kno/30?ooo`050?Ogm`3oool0oooo0??cl`3gmoL0103oool01P3hn?P0oooo0?gmo@3kno/0lO7a
0?clo080nOWi00X0m_Kf0?ooo`3lo?`0oooo0?gmo@3gmoL0oOgm0?Ogm`3dm?@0moOg0P3oool0103f
m_H0nOWi0?[jnP3hn?P20?_kn`040?Win@3fm_H0oOgm0?ooo`80o?cl01`0m_Kf0?gmo@3moOd0n?Sh
0?;blP3oool0nOWi0?3`l03/k>`0g]kN0?KfmP3bl_80lo?c0>o_k`3kno/0lo?c0?;blP3fm_H0jn_[
0>CTi03fm_H0l?3`0?KfmP3Shn<0j>SX0??cl`3^k^h0l?3`0P3kno/00`1kNg/0oooo0?ooo`100?oo
o`80n_[j00<0oooo0?[jnP3oool00P3jn_X20?ooo`0<0=_Kf`3clo<0moOg0?KfmP3UiND0lO7a0>c/
k03emOD0k>c/0=oOg`3oool0hN7Q0P3dm?@0403fm_H0moOg0?[jnP3clo<0mOGe0>CTi03`l?00k^k^
0>c/k03Vi^H0lo?c0>SXj03jn_X0mOGe0?ooo`3kno/30?ooo`050?KfmP3oool0oooo0??cl`3fm_H0
103oool01P3gmoL0oooo0?clo03kno/0lO7a0?gmo@80nOWi00X0m_Kf0?ooo`3kno/0oooo0?gmo@3f
m_H0oOgm0?KfmP3clo<0m_Kf0P3oool03@3fm_H0nOWi0?Win@3inOT0no_k0?clo03inOT0m_Kf0?cl
o03oool0o?cl0?_kn`3gmoL00P3moOd0703jn_X0lo?c0?ooo`3inOT0kno_0>[ZjP3Ogml0nOWi0??c
l`3dm?@0l?3`0?[jnP3dm?@0lo?c0?KfmP3[jn/0i^KV0?KfmP3`l?00m_Kf0>?Sh`3Xj>P0lo?c0>k^
kP3`l?00o?cl0?[jnP1kNg/n0?ooo`00;03oool20?[jnP030?ooo`3jn_X0n_[j00@0n_[j0100c/k>
0>SXj03dm?@0m_Kf0>OWi`3jn_X0h>3P0?7al@3gmoL0k>c/0?Shn03De=@0oooo0>[ZjP3^k^h0lo?c
0P3gmoL02`3/k>`0kno_0?Ogm`3Ng]h0jNWY0>c/k03[jn/0h^;R0?[jnP3emOD0moOg00<0oooo00H0
n_[j0?ooo`3oool0oooo0?Ogm`3clo<30?ooo`80n_[j0P3moOd30?KfmP050?Win@3dm?@0mOGe0?oo
o`3dm?@00P3fm_H0103emOD0oOgm0?Ogm`3dm?@20?ooo`090?gmo@3fm_H0nOWi0?[jnP3moOd0n_[j
0?_kn`3gmoL0oOgm00<0o?cl01P0oOgm0?clo03gmoL0o?cl0?Shn03lo?`0oOgm0?Shn03fm_H0k^k^
0>3Ph03oool0j^[Z0>c/k03_knl0o_kn0>o_k`3kno/0kno_0>g]k@3bl_80gmoO0?Cdm03`l?020?Og
m`060??cl`3Xj>P0gmoO0??cl`3Ogml0RHV9@P3oool20?[jnP030?ooo`3jn_X0n_[j00@0n_[j01d0
c/k>0>SXj03bl_80m_Kf0>WYj@3inOT0h>3P0>k^kP3gmoL0jn_[0?KfmP3Cdm<0oooo0>_[j`3^k^h0
lo?c0?Win@3fm_H0j^[Z0>g]k@3fm_H0g]kN0>OWi`3[jn/0j^[Z0>7Qh@3jn_X0mOGe0?Ogm`030?oo
o`060?[jnP3oool0oooo0?ooo`3fm_H0lo?c0`3oool20?[jnP80o?cl0`3fm_H01@3inOT0lo?c0?Ge
m@3oool0lo?c0080m_Kf00@0mOGe0?gmo@3fm_H0lo?c0P3oool02P3moOd0m_Kf0?Win@3jn_X0oOgm
0?_kn`3lo?`0m_Kf0?clo03moOd20?clo0050?gmo@3kno/0moOg0?clo03jn_X00P3kno/01P3gmoL0
m_Kf0>k^kP3Ogml0oooo0>[ZjP80kno_00T0oooo0>o_k`3lo?`0lO7a0>k^kP3emOD0hN7Q0?Cdm03`
l?000P3gmoL01P3dm?@0j>SX0>3Ph03dm?@0h>3P08V9RCh0oooo000_0?ooo`040?[jnP3oool0n_[j
0?[jnP80oooo00P0e]KF0>;RhP3alO40lO7a0>;RhP3jn_X0m?Cd0?KfmP80moOg00D0m_Kf0>c/k03b
l_80l_;b0?gmo@020?KfmP80l?3`00@0m?Cd0>_[j`3inOT0gMgM0P3^k^h01@3Jf]X0oooo0?Ogm`3o
ool0n_[j00<0oooo0P3jn_X0203hn?P0oooo0?[jnP3hn?P0n_[j0?ooo`3emOD0oooo0`3moOd02@3j
n_X0o?cl0?clo03inOT0lO7a0?Ogm`3clo<0oOgm0?clo0030?gmo@0>0?[jnP3moOd0o?cl0?[jnP3f
m_H0nOWi0?ooo`3inOT0moOg0?Cdm03inOT0oooo0?clo03gmoL20?[jnP0:0?ooo`3gmoL0n?Sh0?Sh
n03emOD0no_k0?7al@3YjNT0gMgM0?knoP80l_;b00D0m?Cd0>k^kP3^k^h0k^k^0?_kn`020?Gem@03
0?Win@3^k^h0j^[Z0080j>SX00@0no_k0?Ogm`3inOT0l?3`0P3Shn<00`2`/;00oooo0?ooo`130?oo
o`040?[jnP3oool0n_[j0?[jnP80oooo00P0e]KF0>;RhP3dm?@0l_;b0>CTi03moOd0m?Cd0?KfmP80
moOg00D0m_Kf0>_[j`3clo<0lo?c0?ooo`020?KfmP0=0>k^kP3bl_80lo?c0>c/k03fm_H0g=cL0>g]
k@3/k>`0fMWI0?ooo`3gmoL0oooo0?[jnP030?ooo`80n_[j00P0moOg0?ooo`3jn_X0moOg0?[jnP3o
ool0mOGe0?ooo`<0o?cl00T0n_[j0?_kn`3moOd0nOWi0?7al@3fm_H0lo?c0?gmo@3kno/00`3moOd0
3P3inOT0oOgm0?_kn`3inOT0m_Kf0?Win@3oool0nOWi0?Ogm`3dm?@0nOWi0?ooo`3lo?`0m_Kf0P3i
nOT03P3oool0moOg0?Win@3inOT0m_Kf0?[jnP3`l?00inOW0=gMg@3kno/0lo?c0?Cdm03fm_H0kNg]
0P3_knl03`3lo?`0mOGe0?Gem@3jn_X0l?3`0>[ZjP3Xj>P0j^[Z0?clo03gmoL0nOWi0?3`l03Ti>@0
iNGU0;2`/00n0?ooo`00<03oool20?[jnP0;0?ooo`3jn_X0n_[j0>_[j`38b<P0j^[Z0?Ogm`3dm?@0
k>c/0>KViP3^k^h00`3gmoL0603moOd0e=CD0>[ZjP3bl_80oooo0>[ZjP3clo<0l_;b0>KViP3^k^h0
kno_0=_Kf`3Zj^X0h^;R0>7Qh@3alO40n_[j0?Ogm`3oool0no_k0?gmo@3kno/0moOg0?[jnP80moOg
00L0oOgm0?_kn`3moOd0oOgm0?Ogm`3moOd0no_k0080oOgm00L0n_[j0?_kn`3kno/0m_Kf0?ooo`3a
lO40oOgm0080n_[j00T0oooo0?gmo@3jn_X0n_[j0?ooo`3fm_H0oOgm0?KfmP3hn?P00P3oool08@3f
m_H0n_[j0?Cdm03inOT0oooo0?Win@3oool0o?cl0?Shn03clo<0l_;b0?gmo@3_knl0kNg]0?Shn03c
lo<0emOG0>c/k03^k^h0lo?c0>o_k`3clo<0no_k0?KfmP3moOd0l?3`0?7al@3gmoL0nOWi0?3`l03c
lo<0mOGe0??cl`020?KfmP040=oOg`3Xj>P0WIfM0?OgmdH0oooo0P3jn_X01P3oool0n_[j0?[jnP3[
jn/0alO70>WYj@80m_Kf00<0jn_[0>KViP3^k^h00`3gmoL0603oool0dm?C0>_[j`3clo<0oooo0>_[
j`3clo<0l?3`0>OWi`3]kNd0l?3`0=cLg03[jn/0hN7Q0>3Ph03`l?00n_[j0?Ogm`3oool0no_k0?cl
o03kno/0m_Kf0?[jnP80m_Kf00L0o?cl0?_kn`3lo?`0o?cl0?Ogm`3lo?`0no_k0080o?cl00L0n_[j
0?clo03kno/0m_Kf0?ooo`3`l?00oOgm0080n_[j00T0oooo0?gmo@3inOT0nOWi0?ooo`3fm_H0oOgm
0?KfmP3gmoL00P3oool08@3emOD0nOWi0?Cdm03inOT0oooo0?Win@3oool0o?cl0?[jnP3emOD0lo?c
0?_kn`3alO40k^k^0?[jnP3dm?@0emOG0>WYj@3_knl0m?Cd0>o_k`3dm?@0o?cl0?KfmP3lo?`0l?3`
0??cl`3gmoL0n_[j0?7al@3bl_80mOGe0?Cdm0020?KfmP040>;RhP3Zj^X0WIfM0?Ogmch0oooo000_
0?ooo`0D0?[jnP3oool0n_[j0?[jnP3oool0n_[j0?ooo`3Ph>00jNWY0>k^kP3dm?@0inOW0?7al@3]
kNd0lo?c0=[JfP3Vi^H0m_Kf0?Ogm`37alL20??cl`0>0?Cdm03]kNd0k>c/0?Ogm`3bl_80o_kn0?Sh
n03Zj^X0n?Sh0>?Sh`3UiND0jn_[0?3`l03lo?`30?Ogm`80oOgm00@0oooo0?_kn`3kno/0m_Kf0P3m
oOd02P3clo<0moOg0?Ogm`3oool0oOgm0?clo03oool0n?Sh0?Cdm03`l?030?[jnP0:0??cl`3lo?`0
oOgm0?Ogm`3kno/0n?Sh0?_kn`3inOT0no_k0?Win@80n_[j00D0moOg0?Win@3gmoL0o?cl0?_kn`02
0?Win@080?clo03emOD0mOGe0?KfmP3inOT0m?Cd0>c/k03Xj>P20?;blP0:0?7al@3clo<0l?3`0>k^
kP3clo<0moOg0??cl`3inOT0moOg0?ooo`80no_k00T0moOg0?KfmP3clo<0m_Kf0?3`l03Zj^X0oOgm
09>CT`1XJ6P0AP3oool0503jn_X0oooo0?[jnP3jn_X0oooo0?[jnP3oool0h>3P0>KViP3`l?00lo?c
0>KViP3dm?@0kNg]0?Cdm03Jf]X0iNGU0?KfmP3gmoL0a/K60P3dm?@01@3fm_H0k^k^0>_[j`3fm_H0
lo?c0080oOgm00L0jn_[0?[jnP3Rh^80iNGU0>[ZjP3`l?00oOgm00<0moOg0P3lo?`0103oool0no_k
0?_kn`3fm_H20?clo00N0??cl`3gmoL0moOg0?ooo`3lo?`0oOgm0?ooo`3gmoL0m?Cd0>o_k`3jn_X0
nOWi0?[jnP3clo<0no_k0?gmo@3fm_H0no_k0?Win@3lo?`0nOWi0?clo03inOT0n_[j0?Win@3fm_H0
nOWi0?Ogm`3moOd0no_k0P3inOT0503lo?`0m_Kf0?Cdm03emOD0moOg0?Gem@3Zj^X0inOW0?Cdm03_
knl0lO7a0??cl`3`l?00kno_0??cl`3fm_H0lo?c0?[jnP3fm_H0oooo0P3lo?`02@3gmoL0m_Kf0?Cd
m03fm_H0lO7a0>_[j`3lo?`0TI6A06QXJ00o0?ooo`00;03oool0103jn_X0oooo0?ooo`3jn_X60?oo
o`0<0<71`@3Ogml0oooo0?ooo`3gmoL0l_;b0?clo03alO40n_[j0>WYj@3]kNd0moOg0P3kno/03`3i
nOT0mOGe0?7al@3clo<0kNg]0>[ZjP3kno/0l?3`0>?Sh`3^k^h0f=SH0>GUi@3Rh^80jn_[0?[jnP02
0?KfmP050?Win@3jn_X0oooo0?ooo`3gmoL00`3moOd01@3fm_H0lO7a0?Cdm03dm?@0m_Kf0080mOGe
0P3oool02P3_knl0n_[j0?Ogm`3fm_H0mOGe0?[jnP3emOD0no_k0??cl`3bl_820?[jnP060?Shn03k
no/0n_[j0?[jnP3oool0n?Sh0P3jn_X20?Ogm`0Q0?Shn03emOD0o?cl0?knoP3emOD0nOWi0?KfmP3a
lO40moOg0>c/k03bl_80oooo0?Cdm03`l?00k^k^0?ooo`3inOT0oooo0?KfmP3inOT0moOg0??cl`3i
nOT0moOg0>o_k`3Shn<0lo?c0?Win@3WinL0h^;R0?;blP1VIVH0`L7104<0oooo00@0n_[j0?ooo`3o
ool0n_[j1P3oool07@31`L40gmoO0?ooo`3oool0moOg0?;blP3moOd0lO7a0?[jnP3Xj>P0kNg]0?Kf
mP3jn_X0o?cl0?Ogm`3bl_80l?3`0?7al@3]kNd0j^[Z0?[jnP3^k^h0h^;R0>g]k@3GemL0i>CT0>;R
hP3Zj^X0nOWi0080m_Kf00D0nOWi0?[jnP3oool0oooo0?Ogm`030?clo0050?KfmP3alO40m?Cd0??c
l`3fm_H00P3emOD20?ooo`0D0>k^kP3inOT0m_Kf0?KfmP3emOD0nOWi0?Gem@3kno/0lo?c0?;blP3i
nOT0no_k0?Ogm`3lo?`0n_[j0?Win@3oool0moOg0?Win@3kno/20?KfmP050?[jnP3fm_H0o?cl0?cl
o03dm?@00P3gmoL06P3clo<0n_[j0>g]k@3`l?00oooo0??cl`3`l?00kno_0?ooo`3inOT0oooo0?Kf
mP3jn_X0moOg0?Gem@3jn_X0moOg0>o_k`3Shn<0m?Cd0?_kn`3WinL0i>CT0??cl`1UIFD0`L71?`3o
ool002l0oooo00<0n_[j0?ooo`3oool0103oool01@2NWYh0jn_[0>GUi@3fm_H0jn_[0080moOg00@0
m_Kf0?Gem@3Ogml0k>c/0P3YjNT06P3Xj>P0k^k^0?[jnP3Xj>P0k^k^0>o_k`3alO40n?Sh0?[jnP3f
m_H0inOW0=gMg@3Zj^X0kNg]0?7al@3jn_X0lO7a0?Ogm`3oool0n_[j0?KfmP3emOD0oOgm0?Ogm`3c
lo<0mOGe0P3lo?`0403alO40o_kn0?clo03bl_80n_[j0?ooo`3gmoL0lO7a0?[jnP3dm?@0lo?c0?Ge
m@3clo<0mOGe0?Shn03clo<20?_kn`0<0?ooo`3jn_X0no_k0?ooo`3lo?`0oOgm0?ooo`3fm_H0oooo
0?Win@3bl_80lo?c0P3dm?@07P3jn_X0mOGe0?7al@3emOD0l?3`0>KViP3Shn<0lO7a0??cl`3`l?00
oooo0??cl`3kno/0oooo0?KfmP3`l?00oooo0?Ogm`3kno/0m?Cd0?KfmP3^k^h0l_;b0?_kn`3oool0
hN7Q0?_kn`3IfMT0H61P0=7AdDH0oooo00<0n_[j0?ooo`3oool0103oool01@2NWYh0jn_[0>GUi@3f
m_H0j^[Z0080moOg00@0m_Kf0?Gem@3MgMd0jn_[0P3Xj>P06P3YjNT0kNg]0?Win@3Zj^X0k^k^0?3`
l03bl_80m_Kf0?Win@3dm?@0j>SX0=kNgP3Xj>P0kNg]0?3`l03jn_X0lO7a0?Ogm`3oool0n_[j0?Kf
mP3emOD0o?cl0?Ogm`3bl_80mOGe0P3moOd0403alO40oOgm0?_kn`3alO40nOWi0?ooo`3fm_H0l?3`
0?[jnP3dm?@0lo?c0?Gem@3bl_80mOGe0?Ogm`3clo<20?_kn`0/0?ooo`3inOT0o?cl0?ooo`3moOd0
o?cl0?ooo`3fm_H0oooo0?Win@3bl_80lo?c0?Cdm03clo<0no_k0?Cdm03`l?00lo?c0?3`l03Vi^H0
hn?S0?3`l03dm?@0l?3`0?ooo`3dm?@0o?cl0?ooo`3gmoL0l?3`0?ooo`3fm_H0o?cl0?Cdm03fm_H0
kNg]0??cl`3lo?`0oooo0>7Qh@3jn_X0fm_K061PH03AdM4o0?ooo`00;P3oool01@3jn_X0oooo0?oo
o`3oool0n_[j00<0oooo00d0KVi^0=[JfP3bl_80l?3`0>_[j`3clo<0oooo0??cl`3UiND0kNg]0??c
l`3Vi^H0k>c/0080j^[Z01T0k^k^0?[jnP3jn_X0m_Kf0<k>cP3IfMT0jn_[0?3`l03YjNT0e]KF0<[:
bP3Ph>00k>c/0>GUi@3^k^h0mOGe0?[jnP3_knl0oooo0?Ogm`3clo<0m?Cd0??cl`3fm_H0n_[j0080
moOg0P3fm_H06@3jn_X0o?cl0?7al@3inOT0mOGe0>_[j`3fm_H0m?Cd0?7al@3jn_X0k^k^0?Cdm03f
m_H0oooo0>k^kP3alO40m_Kf0?Gem@3jn_X0oooo0?[jnP3lo?`0n?Sh0?KfmP3hn?P00P3dm?@00`3c
lo<0mOGe0?7al@020>OWi`0B0>7Qh@3gmoL0l?3`0>WYj@3^k^h0lo?c0>o_k`3^k^h0kno_0?Gem@3f
m_H0moOg0?ooo`3clo<0oooo0?gmo@3oool0lo?c0P3oool01`3kno/0l_;b0=cLg03dm?@0dm?C09JF
UP3gmoL0A@3oool01@3jn_X0oooo0?ooo`3oool0n_[j00<0oooo02X0KVi^0=WIf@3`l?00l?3`0>_[
j`3clo<0oooo0??cl`3UiND0k^k^0?;blP3Vi^H0k>c/0>WYj@3Zj^X0kNg]0?Win@3moOd0mOGe0<k>
cP3IfMT0jn_[0?3`l03YjNT0e]KF0<_;b`3Ng]h0k>c/0>CTi03^k^h0mOGe0?[jnP3_knl0oooo0?Og
m`3clo<0m?Cd0??cl`3fm_H0n_[j0?KfmP3gmoL20?KfmP0I0?Win@3lo?`0l?3`0?Win@3emOD0j^[Z
0?KfmP3clo<0l?3`0?_kn`3/k>`0m?Cd0?KfmP3oool0kNg]0?3`l03fm_H0mOGe0?[jnP3oool0n_[j
0?clo03fm_H0m?Cd0?Ogm`020?Gem@80lo?c00d0l?3`0>GUi@3UiND0h>3P0?KfmP3^k^h0jNWY0>o_
k`3dm?@0lO7a0>o_k`3alO40m_Kf0080moOg00H0oooo0?;blP3oool0o?cl0?ooo`3dm?@20?ooo`07
0?clo03clo<0g]kN0?KfmP3De=@0UiNG0?Ogm`0o0?ooo`00;P3oool00`3jn_X0oooo0?ooo`050?oo
o`0d09^KV`3WinL0oooo0?[jnP3fm_H0oooo0>_[j`3bl_80lo?c0?7al@3WinL0oooo0>GUi@3kno/0
m?Cd0?Gem@3hn?P0m_Kf0>c/k03fm_H0eMGE0?[jnP3^k^h0n?Sh0=kNgP3YjNT0g=cL0=OGe`3/k>`0
i^KV0>WYj@3alO40kNg]0?[jnP3hn?P0m?Cd0?[jnP3hn?P0o_kn0?ooo`3jn_X0oooo0?Cdm03moOd0
n?Sh0?Ogm`3`l?00n?Sh0?Gem@3hn?P0oooo0?Shn080n_[j00D0oooo0?[jnP3hn?P0n?Sh0?[jnP03
0?Shn00C0?Win@3gmoL0oooo0?[jnP3gmoL0no_k0?ooo`3no_h0oooo0?Win@3emOD0lo?c0>_[j`3n
o_h0moOg0?;blP3Zj^X0oooo0?Cdm0020?ooo`090>WYj@3hn?P0lo?c0?Win@3oool0m?Cd0?Ogm`3o
ool0j>SX00<0no_k00L0oooo0>[ZjP3`l?00lo?c0?Ogm`1NGUh0moOg04H0oooo00<0n_[j0?ooo`3o
ool01@3oool0>02KVi/0i^KV0?ooo`3kno/0m_Kf0?ooo`3[jn/0l_;b0??cl`3alO40i^KV0?ooo`3V
i^H0o?cl0??cl`3dm?@0nOWi0?KfmP3[jn/0m_Kf0=GEe@3jn_X0l?3`0?KfmP3Rh^80jn_[0=kNgP3F
e]H0k>c/0>KViP3Xj>P0l?3`0>k^kP3jn_X0moOg0?Gem@3jn_X0moOg0?gmo@3oool0n_[j0?ooo`3c
lo<0oOgm0?Ogm`3fm_H0kno_0?Win@3emOD0moOg0?ooo`3gmoL0nOWi0?[jnP3oool0nOWi0P3gmoL0
0`3inOT0moOg0?Ogm`020?Ogm`050?KfmP3oool0nOWi0?KfmP3inOT00`3oool02P3inOT0moOg0?;b
lP3/k>`0oooo0?KfmP3dm?@0jNWY0?ooo`3fm_H20?ooo`090>_[j`3inOT0lo?c0?Win@3oool0m?Cd
0?Ogm`3oool0j>SX00<0o?cl00L0oooo0>_[j`3`l?00m?Cd0?KfmP1KFe/0moOg0400oooo000V0?oo
o`030?[jnP3oool0oooo00d0oooo02H0dm?C0;^k^`3`l?00kno_0?7al@3hn?P0lo?c0>g]k@3jn_X0
o?cl0?3`l03]kNd0jn_[0?;blP3[jn/0mOGe0=OGe`3fm_H0l_;b0?Ogm`3Xj>P0iNGU0=gMg@3UiND0
m?Cd0?[jnP3`l?00gmoO0=[JfP3Ph>00i>CT0>k^kP3]kNd0k^k^0>c/k03Ng]h0jNWY0??cl`80k^k^
00<0m_Kf0?7al@3fm_H00P3fm_H04@3jn_X0j>SX0=oOg`3UiND0jn_[0??cl`3/k>`0kNg]0?Cdm03o
ool0moOg0?ooo`3lo?`0m_Kf0?Gem@3fm_H0o?cl0080no_k01T0nOWi0?_kn`3hn?P0oOgm0?clo03k
no/0m_Kf0?Shn03lo?`0kno_0?knoP3^k^h0i>CT0?ooo`3clo<0kno_0?3`l03alO40l_;b0?7al@3/
k>`0l?3`0??cl`3gmoL0oooo0080lo?c00X0moOg0?Win@3oool0oooo0?_kn`3/k>`0hN7Q0>o_k`3o
ool0Hf=S?`3oool00`3jn_X0oooo0?ooo`0=0?ooo`0Z0=?Cd`2j^[X0l?3`0?3`l03dm?@0m_Kf0?Cd
m03[jn/0nOWi0?gmo@3_knl0kNg]0>_[j`3clo<0kNg]0?KfmP3EeMD0m_Kf0?;blP3gmoL0j>SX0>KV
iP3Kfm/0i^KV0?Cdm03gmoL0l?3`0>3Ph03IfMT0gmoO0>?Sh`3]kNd0k>c/0>g]k@3[jn/0gMgM0>[Z
jP3clo<0k>c/0>k^kP3fm_H0l?3`0`3fm_H04@3inOT0inOW0=kNgP3Rh^80j^[Z0??cl`3[jn/0k>c/
0??cl`3oool0m_Kf0?ooo`3moOd0mOGe0??cl`3fm_H0oOgm00@0nOWi01/0m_Kf0?clo03moOd0n_[j
0?Gem@3inOT0no_k0>o_k`3moOd0k^k^0>?Sh`3oool0m?Cd0>k^kP3`l?00m?Cd0??cl`3bl_80kNg]
0?Cdm03clo<0moOg0?ooo`3bl_80m?Cd0?Ogm`3kno/00P3oool01P3lo?`0kNg]0>?Sh`3^k^h0no_k
06=SHd40oooo000f0?ooo`060>k^kP2LW9`0m_Kf0>WYj@3oool0m_Kf0P3clo<08P3jn_X0j^[Z0?;b
lP3gmoL0m_Kf0?3`l03Xj>P0jn_[0<c<c03Ogml0oooo0>_[j`3fm_H0inOW0=GEe@3hn?P0h>3P0?oo
o`3emOD0lO7a0>OWi`3gmoL0iNGU0>o_k`3GemL0iNGU0>k^kP3gmoL0jn_[0?Ogm`3`l?00lO7a0?Ge
m@3_knl20?Gem@0@0?Ogm`3^k^h0iNGU0>CTi03_knl0i^KV0>;RhP3dm?@0l_;b0?Ogm`3hn?P0no_k
0>c/k03jn_X0n?Sh0>c/k080moOg00<0no_k0?clo03jn_X00`3gmoL00`3clo<0moOg0?_kn`020?Ge
m@070>SXj03Vi^H0j>SX0?gmo@3]kNd0k^k^0?Cdm0020?_kn`070?Gem@3^k^h0n?Sh0?Cdm03fm_H0
moOg0?ooo`020?KfmP0:0?ooo`3kno/0oooo0?ooo`3bl_80i>CT0?ooo`3^k^h0b<S80;Bd]4l0oooo
00/0k^k^09^KV`3fm_H0j>SX0?ooo`3emOD0m?Cd0??cl`3jn_X0jn_[0??cl`020?KfmP0M0?7al@3[
jn/0kNg]0<g=c@3MgMd0oooo0>_[j`3fm_H0inOW0=GEe@3fm_H0gmoO0?ooo`3clo<0m?Cd0>WYj@3f
m_H0i>CT0?7al@3Hf=P0iNGU0>g]k@3gmoL0jNWY0?Ogm`3_knl0l?3`0?Cdm03_knl00P3emOD02@3f
m_H0k^k^0>GUi@3Ti>@0lO7a0>KViP3Rh^80lo?c0?Cdm0020?KfmP050?_kn`3YjNT0nOWi0?Win@3Z
j^X00P3emOD00`3inOT0oOgm0?[jnP030?KfmP050??cl`3gmoL0n_[j0?Gem@3dm?@00P3WinL02@3Z
j^X0o?cl0>_[j`3_knl0m?Cd0?gmo@3inOT0m_Kf0>g]k@020?Win@030?KfmP3gmoL0oooo0080m_Kf
00X0oooo0?clo03oool0oooo0??cl`3UiND0oooo0>o_k`3;bl/0];Bd@@3oool003L0oooo00D0P820
0?Gem@3alO40jn_[0??cl`020?Ogm`030??cl`3fm_H0inOW0080l_;b00T0k>c/0>k^kP3_knl0no_k
0=?Cd`3[jn/0h>3P0>g]k@3clo<00P3lo?`02@3]kNd0l?3`0?_kn`3`l?00kno_0?3`l03oool0i>CT
0>[ZjP020?;blP0>0>GUi@3Ng]h0j^[Z0??cl`3WinL0lO7a0?;blP3dm?@0j^[Z0?ooo`3Shn<0l_;b
0?Cdm03^k^h20>WYj@80m_Kf00H0inOW0?[jnP3]kNd0no_k0?[jnP3oool20?clo00;0?;blP3lo?`0
mOGe0?[jnP3moOd0o_kn0?Gem@3no_h0m?Cd0?KfmP3emOD00P3`l?001P3no_h0moOg0?Ogm`3oool0
k>c/0?;blP80lo?c00X0no_k0?gmo@3oool0m_Kf0?ooo`3dm?@0oooo0?Ogm`3dm?@0nOWi0P3oool0
1`3kno/0jn_[0??cl`3no_h0k^k^075aL@3jn_X0D03oool01@20P800moOg0?7al@3[jn/0lo?c0080
moOg00h0lo?c0?KfmP3WinL0l_;b0?3`l03/k>`0l?3`0?7al@3lo?`0dm?C0>_[j`3Ph>00kNg]0??c
l`80oOgm00<0k>c/0>o_k`3jn_X00P3`l?00103bl_80oooo0>GUi@3Zj^X20?;blP0H0>CTi03Ogml0
jn_[0?Cdm03Xj>P0lo?c0?7al@3clo<0jNWY0?ooo`3Shn<0lO7a0??cl`3]kNd0j^[Z0>SXj03gmoL0
m_Kf0>WYj@3inOT0kNg]0?[jnP3inOT0oooo0P3kno/04`3`l?00oOgm0?Gem@3inOT0oOgm0?ooo`3f
m_H0oOgm0?Gem@3fm_H0mOGe0?3`l03^k^h0oOgm0?Ogm`3inOT0oooo0>c/k03`l?000`3dm?@02@3l
o?`0oooo0?Ogm`3oool0lo?c0?ooo`3gmoL0lo?c0?_kn`020?ooo`070?clo03/k>`0m?Cd0?ooo`3_
knl0LG5a0?[jnP110?ooo`00=`3oool01`3Hf=P0f][J0>KViP3^k^h0oOgm0?KfmP3oool00P3fm_H0
9@3Ph>00moOg0=cLg03bl_80n?Sh0>k^kP3bl_80no_k0??cl`3YjNT0lo?c0>[ZjP3]kNd0j^[Z0??c
l`3_knl0j>SX0?KfmP3dm?@0no_k0?[jnP3`l?00j>SX0?gmo@3_knl0i^KV0>GUi@3hn?P0l?3`0>[Z
jP3UiND0jNWY0?gmo@3`l?00jNWY0>k^kP3hn?P00P3clo<01`3Jf]X0i^KV0>OWi`3[jn/0mOGe0>c/
k03]kNd00P3bl_80503`l?00m_Kf0>o_k`3_knl0oOgm0?ooo`3^k^h0lo?c0>o_k`3fm_H0n_[j0?Wi
n@3fm_H0o_kn0?Gem@3Ogml0moOg0>k^kP3dm?@0kno_0P3oool20?;blP070?Ogm`3inOT0nOWi0?oo
o`3dm?@0oooo0?Win@050?ooo`060<o?c`3_knl0oooo0?Gem@2UYJD0XZ:RD@3oool01`3Hf=P0f][J
0>KViP3^k^h0oooo0?Gem@3oool00P3fm_H04@3Ph>00moOg0=cLg03clo<0moOg0?3`l03clo<0oOgm
0?;blP3Xj>P0lo?c0>_[j`3]kNd0j^[Z0??cl`3^k^h0j>SX0080m_Kf0P3kno/0403`l?00inOW0?oo
o`3`l?00j>SX0>OWi`3jn_X0l?3`0>[ZjP3Vi^H0j^[Z0?gmo@3`l?00j^[Z0>o_k`3fm_H20?Gem@07
0=[JfP3UiND0j>SX0>c/k03fm_H0k>c/0>g]k@020??cl`0:0?7al@3fm_H0lO7a0>o_k`3moOd0oooo
0>k^kP3clo<0k^k^0?KfmP80nOWi00P0m_Kf0?ooo`3gmoL0gmoO0??cl`3`l?00lo?c0>k^kP80oooo
00<0l_;b0??cl`3fm_H00P3inOT0103oool0lo?c0?ooo`3kno/50?ooo`060=;BdP3alO40oooo0?Cd
m02UYJD0Xj>S@P3oool003P0oooo00D0UiNG0>?Sh`3fm_H0n_[j0?Ogm`020??cl`040?7al@3Ph>00
iNGU0>k^kP80j^[Z0200l_;b0?Cdm03[jn/0j^[Z0>o_k`3lo?`0jNWY0?_kn`3gmoL0lO7a0>c/k03^
k^h0m_Kf0?Cdm03jn_X0k>c/0>g]k@3/k>`0mOGe0>SXj03Zj^X0i^KV0>[ZjP3WinL0m?Cd0>OWi`3a
lO40iNGU0=7Ad@3Shn<0kno_0??cl`80n_[j01/0lO7a0?_kn`3hn?P0n?Sh0=SHf03/k>`0l_;b0>o_
k`3bl_80k^k^0?7al@3fm_H0moOg0?3`l03^k^h0n_[j0?ooo`3fm_H0o?cl0?Shn03[jn/0lo?c0>c/
k03emOD0l_;b0??cl`3oool00P3_knl02`3alO40lo?c0?;blP3kno/0m_Kf0?ooo`3gmoL0m?Cd0??c
l`3inOT0no_k00@0oooo00H0lo?c0>OWi`3emOD0no_k0>[ZjP0k>c]C0?ooo`0;09NGU`3Rh^80m_Kf
0?gmo@3gmoL0m?Cd0??cl`3`l?00h>3P0>GUi@3^k^h00P3[jn/0903alO40lo?c0>_[j`3Xj>P0k^k^
0?gmo@3YjNT0o?cl0?Ogm`3`l?00k>c/0>o_k`3fm_H0mOGe0?Win@3^k^h0kNg]0?3`l03gmoL0j>SX
0>[ZjP3YjNT0j^[Z0>KViP3clo<0j>SX0?3`l03Shn<0clo?0>?Sh`3alO40m?Cd0?Win@3kno/0l?3`
0?clo080nOWi00T0fMWI0>k^kP3bl_80k^k^0?3`l03^k^h0l?3`0?KfmP3gmoL00P3_knl03P3kno/0
oooo0?KfmP3moOd0m_Kf0>c/k03clo<0k^k^0?Ogm`3clo<0m?Cd0?ooo`3^k^h0l?3`0P3dm?@01@3c
lo<0o?cl0?KfmP3oool0moOg0080m?Cd00<0no_k0?clo03oool00`3oool01P3dm?@0j>SX0?Cdm03l
o?`0kNg]03Ti>D<0oooo000h0?ooo`0;0;jn_P2MWId0kno_0?7al@3jn_X0oooo0??cl`3bl_80n_[j
0?KfmP3Shn<00P3^k^h06P3jn_X0moOg0??cl`3oool0nOWi0??cl`3gmoL0k>c/0?;blP3emOD0i^KV
0?3`l03hn?P0o_kn0?7al@3oool0j^[Z0>CTi03YjNT0iNGU0>c/k03UiND0inOW0??cl`3Xj>P0nOWi
0`3alO405@3Xj>P0n?Sh0>o_k`3lo?`0j>SX0?;blP3gmoL0oooo0>OWi`3moOd0nOWi0>o_k`3Ogml0
k^k^0?Gem@3[jn/0m_Kf0>k^kP3Vi^H0jn_[0>k^kP020>WYj@090>k^kP3alO40l?3`0?Ogm`3WinL0
lO7a0??cl`3UiND0k>c/00<0no_k00P0l?3`0?Ogm`3fm_H0mOGe0?Win@3`l?00no_k0?;blP80no_k
0`3oool01`3`l?00j^[Z0>o_k`3Ti>@0gmoO0?3`l01;Bd/0D`3oool07P2n_[h0WIfM0>k^kP3alO40
oOgm0?ooo`3clo<0l_;b0?[jnP3fm_H0hn?S0>k^kP3`l?00nOWi0?KfmP3bl_80oooo0?Win@3clo<0
moOg0>c/k03dm?@0mOGe0>KViP3`l?00nOWi0?ooo`3`l?00oooo0>[ZjP80inOW00P0i>CT0>[ZjP3V
i^H0inOW0?3`l03Vi^H0n_[j0?3`l080m?Cd01D0j^[Z0?Win@3`l?00oOgm0>OWi`3clo<0m_Kf0?oo
o`3Xj>P0o?cl0?Win@3`l?00h>3P0?3`l03gmoL0k>c/0?Ogm`3^k^h0i^KV0>g]k@3^k^h00P3Zj^X0
3@3^k^h0lo?c0?7al@3gmoL0inOW0?3`l03dm?@0iNGU0>c/k03moOd0n_[j0?_kn`3clo<00P3fm_H0
1@3emOD0nOWi0?7al@3lo?`0lo?c0080o?cl0`3oool01`3alO40jn_[0?7al@3UiND0h^;R0?7al@1;
Bd/0@`3oool003P0oooo00d0i>CT0:NWY`3IfMT0lo?c0?[jnP3oool0moOg0?ooo`3moOd0j^[Z0>OW
i`3clo<0jn_[0080moOg01T0oooo0>c/k03dm?@0k^k^0?3`l03gmoL0k^k^0>c/k03^k^h0fm_K0=KF
eP3inOT0lO7a0>3Ph03Zj^X0l_;b0>CTi03hn?P0moOg0>3Ph03/k>`0mOGe0>g]k@3^k^h0j^[Z0080
mOGe01T0n_[j0?KfmP3jn_X0k>c/0>_[j`3emOD0kNg]0?gmo@3clo<0i>CT0?;blP3clo<0mOGe0>GU
i@3Ng]h0kNg]0>CTi03Shn<0kNg]0?Ogm`3Vi^H0n?Sh0>SXj03Lg=`0jn_[0080moOg00d0lo?c0>[Z
jP3clo<0m?Cd0?[jnP3kno/0kno_0?_kn`3gmoL0nOWi0?gmo@3WinL0nOWi0080l?3`00<0lo?c0?_k
n`3kno/00P3oool0203kno/0j>SX0=oOg`3_knl0no_k0>o_k`3gmoL0Ph>3D`3oool0:03Ti>@0Z:RX
0=SHf03dm?@0oOgm0?ooo`3gmoL0oooo0?gmo@3[jn/0inOW0??cl`3]kNd0moOg0?KfmP3oool0jn_[
0?Gem@3_knl0l?3`0?Ogm`3^k^h0k>c/0>k^kP3Kfm/0emOG0?Win@3_knl0h>3P0>[ZjP3bl_80i^KV
0?Win@3fm_H0gmoO0>g]k@3fm_H0j^[Z0>c/k03YjNT20??cl`0X0?_kn`3fm_H0n_[j0>c/k03Zj^X0
lo?c0?3`l03kno/0lo?c0>KViP3clo<0l?3`0?Gem@3Ti>@0g]kN0>g]k@3UiND0i>CT0>c/k03gmoL0
i^KV0?Win@3WinL0gMgM0>SXj03fm_H0moOg0??cl`3YjNT0m?Cd0??cl`3kno/0oOgm0>k^kP3kno/0
m_Kf0?Win@3lo?`0inOW0?Win@80lO7a00<0m?Cd0?clo03lo?`00P3oool0203lo?`0j>SX0>7Qh@3a
lO40o?cl0?7al@3fm_H0Ph>3@`3oool003P0oooo0280n_[j0>?Sh`3EeMD0lO7a0??cl`3gmoL0k>c/
0?Shn03^k^h0n?Sh0>OWi`3^k^h0kNg]0>k^kP3Lg=`0j^[Z0>c/k03oool0m_Kf0>c/k03_knl0oOgm
0>GUi@3/k>`0k^k^0>o_k`3jn_X0gmoO0>o_k`3YjNT0l_;b0>[ZjP3`l?00n?Sh0`3alO406P3clo<0
j>SX0>CTi03]kNd0lo?c0>WYj@3[jn/0g=cL0??cl`3jn_X0jNWY0>g]k@3alO40i^KV0?7al@3_knl0
m?Cd0??cl`3oool0l_;b0>SXj03^k^h0lO7a0>c/k03^k^h0lo?c0P3kno/0203UiND0no_k0>o_k`3W
inL0oooo0>o_k`3dm?@0lO7a0P3oool02@3gmoL0kno_0?KfmP3oool0m?Cd0?KfmP3`l?00oooo0?Cd
m0030?_kn`0:0?ooo`3clo<0k>c/0?ooo`3`l?00m?Cd0?Win@2][Jd0CDe=0?Ogme<0oooo00`0n_[j
0>?Sh`3EeMD0l?3`0??cl`3gmoL0jn_[0?Win@3^k^h0moOg0>OWi`3^k^h20>g]k@0^0=_Kf`3Zj^X0
k>c/0?ooo`3fm_H0k>c/0?3`l03moOd0iNGU0>c/k03]kNd0kno_0?[jnP3Ph>00l?3`0>[ZjP3bl_80
j^[Z0??cl`3fm_H0lO7a0?Cdm03alO40m?Cd0>SXj03Ti>@0j^[Z0?Cdm03Xj>P0jn_[0=cLg03alO40
oOgm0>SXj03^k^h0l?3`0>KViP3_knl0k^k^0??cl`3dm?@0oooo0??cl`3Zj^X0kno_0??cl`80kno_
01H0m?Cd0?Win@3inOT0iNGU0?Win@3^k^h0inOW0?ooo`3`l?00m_Kf0?Cdm03oool0o?cl0?KfmP3`
l?00m_Kf0?ooo`3dm?@0m_Kf0?Cdm03oool0lo?c0`3lo?`02P3oool0m?Cd0>g]k@3oool0lO7a0?Ge
m@3inOT0Zj^[04];B`3gmoM30?ooo`00:@3oool00`3jn_X0oooo0?ooo`0=0?ooo`0?0>[ZjP2][Jd0
dm?C0??cl`3lo?`0jn_[0?Ogm`3YjNT0l?3`0?Shn03lo?`0lo?c0?;blP3fm_H0b<S80080oooo00l0
i>CT0?Cdm03]kNd0m_Kf0?clo03/k>`0n_[j0?knoP3:b/X0j>SX0>GUi@3inOT0m_Kf0=oOg`3alO40
0P3bl_80803]kNd0g]kN0?[jnP3]kNd0h>3P0=cLg03dm?@0moOg0?Cdm03[jn/0n_[j0>k^kP3_knl0
nOWi0>k^kP3inOT0no_k0?ooo`3bl_80n_[j0?_kn`3bl_80lo?c0?3`l03oool0k>c/0?3`l03_knl0
m?Cd0?_kn`3`l?00no_k0P3inOT0303bl_80kno_0??cl`3_knl0no_k0?;blP3gmoL0m_Kf0>o_k`3d
m?@0l?3`0??cl`80moOg00<0l_;b0?Win@3oool00P3oool0203Ng]h0m_Kf0>o_k`3/k>`0gMgM0??c
l`1_Kfl0f=SHA@3oool00`3jn_X0oooo0?ooo`0=0?ooo`0?0>[ZjP2][Jd0d];B0?Cdm03inOT0jn_[
0?Ogm`3Xj>P0kno_0?Ogm`3moOd0lo?c0?;blP3fm_H0bLW90080oooo00/0i>CT0?Cdm03]kNd0m_Kf
0?gmo@3[jn/0no_k0?gmo@3:b/X0j>SX0>KViP020?Win@0?0=oOg`3bl_80l_;b0?;blP3]kNd0gmoO
0?gmo@3]kNd0gmoO0=cLg03clo<0moOg0?;blP3[jn/0nOWi0080k^k^00H0moOg0>g]k@3gmoL0n_[j
0?ooo`3dm?@20?_kn`0;0?3`l03clo<0l?3`0?ooo`3^k^h0l?3`0>k^kP3emOD0oOgm0?3`l03moOd0
0P3inOT20?3`l0040?Cdm03[jn/0oooo0??cl`80m_Kf00@0kno_0??cl`3alO40lo?c0P3gmoL00`3c
lo<0no_k0?ooo`020?ooo`080=oOg`3fm_H0lO7a0>g]k@3Ph>00m?Cd06i^KP3Hf=Q40?ooo`00>P3o
ool0;P36a/H0i>CT0?3`l03fm_H0lo?c0?Shn03oool0lo?c0>g]k@3oool0iNGU0>k^kP3`l?00emOG
0=CDe03Xj>P0l?3`0?KfmP3clo<0i^KV0=[JfP3YjNT0m_Kf0?Cdm03jn_X0l_;b0?KfmP3gmoL0j^[Z
0>_[j`3_knl0l_;b0?ooo`3kno/0m_Kf0>;RhP3]kNd0h^;R0?Cdm03Jf]X0m?Cd0>g]k@3_knl0n?Sh
0>[ZjP3inOT20?Gem@090?;blP3clo<0lo?c0?ooo`3[jn/0k^k^0>_[j`3bl_80lo?c0080no_k0P3o
ool20?;blP030??cl`3oool0lo?c0080k^k^0P3clo<20?_kn`060??cl`3moOd0moOg0??cl`3gmoL0
l?3`0P3gmoL00`3fm_H0l_;b0?_kn`020?ooo`080??cl`3hn?P0j^[Z0>SXj03YjNT0c/k>07emO@3j
n_YG0?ooo`0^0<K6aP3Ti>@0l?3`0?KfmP3clo<0m_Kf0?ooo`3clo<0kNg]0?ooo`3UiND0k^k^0?7a
l@3GemL0eMGE0>SXj03alO40m_Kf0??cl`3Vi^H0f][J0>SXj03fm_H0m?Cd0?clo03dm?@0mOGe0?Og
m`3Zj^X0jn_[0?7al@3bl_80oooo0?gmo@3dm?@0hN7Q0>c/k03QhN40m_Kf0=[JfP3bl_80kNg]0>o_
k`3gmoL0jn_[0?Ogm`80m?Cd00T0lo?c0?Cdm03dm?@0oooo0>g]k@3_knl0k^k^0??cl`3dm?@00P3j
n_X20?ooo`<0m?Cd00H0oooo0?Cdm03_knl0kno_0??cl`3dm?@20?Win@060??cl`3lo?`0m_Kf0?;b
lP3gmoL0lO7a0P3gmoL00`3fm_H0lo?c0?clo0020?ooo`080?Cdm03inOT0jn_[0>[ZjP3[jn/0c/k>
07]kN`3jn_Y50?ooo`00>P3oool00`3?cll0d];B0=WIf@020?clo0060?Ogm`3/k>`0l_;b0>3Ph03k
no/0kNg]0P3clo<0103^k^h0aLG50=_Kf`3^k^h20?Ogm`0:0>c/k03IfMT0h>3P0?clo03no_h0iNGU
0?7al@3fm_H0n_[j0?KfmP80l_;b0P3emOD04P3jn_X0i>CT0<o?c`3emOD0m_Kf0>7Qh@3WinL0mOGe
0?3`l03no_h0nOWi0?KfmP3^k^h0mOGe0?Win@3oool0no_k0?ooo`80lo?c00@0no_k0?ooo`3clo<0
kno_0P3^k^h00`3_knl0l_;b0>k^kP050??cl`060?ooo`3bl_80oooo0?ooo`3gmoL0l?3`0`3fm_H0
2@3gmoL0kNg]0??cl`3fm_H0moOg0?3`l03kno/0oooo0??cl`020?3`l0050>o_k`3kno/0iNGU08R8
R02MWId0F03oool04@3?cll0dm?C0=WIf@3moOd0nOWi0?Ogm`3/k>`0l_;b0>7Qh@3jn_X0kNg]0?Cd
m03clo<0k^k^0<K6aP3Kfm/0k^k^0080moOg00<0jn_[0=WIf@3Ph>000P3moOd01@3UiND0lO7a0?Ge
m@3kno/0m_Kf0080l_;b00D0m_Kf0?Cdm03lo?`0hn?S0<o?c`020?KfmP0=0>?Sh`3WinL0m_Kf0?3`
l03oool0n_[j0?KfmP3_knl0m?Cd0?_kn`3oool0o?cl0?ooo`020?Cdm0040?clo03oool0m?Cd0?7a
l@80kno_00<0lO7a0??cl`3_knl01@3dm?@01P3oool0m_Kf0?ooo`3moOd0nOWi0?7al@<0m_Kf00X0
moOg0>o_k`3clo<0m_Kf0?Ogm`3alO40o?cl0?ooo`3dm?@0l?3`0P3alO40103lo?`0j>SX08J6QP2M
WIe60?ooo`00:P3oool00`3jn_X0oooo0?ooo`0=0?ooo`0:0>[ZjP2d];@0i>CT0=WIf@3clo<0mOGe
0>g]k@3/k>`0f=SH0>SXj080m_Kf00T0`/;20>OWi`3oool0k^k^0=?Cd`3jn_X0h>3P0??cl`3Xj>P0
0P3WinL06`3emOD0_kno0>c/k03fm_H0oOgm0?7al@3YjNT0l?3`0?;blP3clo<0mOGe0>k^kP3Vi^H0
fMWI0>k^kP3gmoL0jNWY0>_[j`3hn?P0nOWi0?3`l03kno/0m_Kf0?Win@3oool0moOg0?Win@020?oo
o`0>0?_kn`3clo<0l_;b0?ooo`3clo<0k^k^0?ooo`3fm_H0i^KV0>g]k@3_knl0l_;b0??cl`3Vi^H2
0?Win@80mOGe01D0nOWi0?Gem@3^k^h0k>c/0?ooo`3gmoL0l?3`0??cl`3kno/0oooo0??cl`3kno/0
l_;b0>k^kP3`l?00n?Sh0>SXj03Ogml0moOg0;Rh^02QXJ40B@3oool00`3jn_X0oooo0?ooo`0=0?oo
o`0:0>[ZjP2d];@0i>CT0=WIf@3clo<0m_Kf0>g]k@3/k>`0f=SH0>SXj080m_Kf01<0`/;20>OWi`3o
ool0kno_0=;BdP3inOT0gmoO0??cl`3Xj>P0inOW0>SXj03gmoL0_[jn0>_[j`3fm_H0oooo0?;blP3Y
jNT0l?3`0080lo?c00P0l_;b0>k^kP3Vi^H0f=SH0?3`l03gmoL0j^[Z0>c/k080n_[j00L0lO7a0?[j
nP3fm_H0n_[j0?ooo`3fm_H0n_[j0080oooo02L0o?cl0?Cdm03clo<0oooo0?Cdm03_knl0oooo0?Kf
mP3Xj>P0k^k^0?7al@3fm_H0lo?c0>WYj@3jn_X0no_k0?Gem@3fm_H0no_k0?Gem@3^k^h0jn_[0?oo
o`3gmoL0lO7a0?Cdm03lo?`0oooo0?Cdm03lo?`0lo?c0>k^kP3`l?00nOWi0>WYj@3QhN40nOWi0;Zj
^P2PX:00A`3oool002`0oooo00<0n_[j0?ooo`3oool0303oool01P3QhN40]kNg0;6a/@3dm?@0m_Kf
0?Ogm`<0o?cl00H0moOg0?KfmP3alO40i^KV0>c/k03clo<30?ooo`0:0?7al@3`l?00mOGe0?;blP3h
n?P0c<c<0?Cdm03alO40n?Sh0>g]k@80moOg00`0l_;b0?KfmP3gmoL0j^[Z0?clo03WinL0k^k^0>g]
k@3fm_H0oOgm0>o_k`3fm_H20?_kn`050?Gem@3oool0oOgm0?Win@3moOd00P3inOT06P3gmoL0nOWi
0>o_k`3bl_80nOWi0?Ogm`3bl_80j>SX0?KfmP3gmoL0kno_0?Ogm`3`l?00nOWi0>o_k`3alO40nOWi
0?KfmP3oool0mOGe0?Win@3moOd0moOg0?_kn`3clo<0moOg0P3oool02`3]kNd0l?3`0?3`l03inOT0
mOGe0?_kn`3Xj>P0no_k096AT@1cLg<0n_[j04/0oooo00<0n_[j0?ooo`3oool0303oool01P3QhN40
^;Rh0;6a/@3emOD0m_Kf0?Ogm`<0oOgm00H0moOg0?KfmP3`l?00inOW0>c/k03clo<30?ooo`0:0?7a
l@3_knl0mOGe0?;blP3fm_H0cLg=0?KfmP3bl_80m_Kf0>g]k@80moOg00`0l_;b0?KfmP3jn_X0jn_[
0?gmo@3Vi^H0l?3`0>k^kP3gmoL0o?cl0?3`l03fm_H20?clo0050?KfmP3oool0o?cl0?Win@3lo?`0
0P3jn_X06P3gmoL0n_[j0?3`l03clo<0no_k0?KfmP3clo<0jn_[0?Ogm`3inOT0l?3`0?KfmP3`l?00
no_k0?3`l03bl_80nOWi0?KfmP3oool0mOGe0?[jnP3lo?`0moOg0?clo03dm?@0moOg0P3oool02`3_
knl0l?3`0?3`l03jn_X0m_Kf0?clo03[jn/0oOgm08j>SP1cLg<0n_[j04L0oooo000U0?ooo`030?[j
nP3oool0oooo01<0oooo01P0n_[j0>SXj03Lg=`0inOW0?[jnP3/k>`0k^k^0?[jnP3Ti>@0m_Kf0?[j
nP3alO40k>c/0>OWi`3jn_X0h^;R0<O7a`3oool0j>SX0>_[j`3GemL0l_;b0>g]k@3Ph>020?_kn`0D
0>SXj03bl_80oOgm0?gmo@3WinL0l?3`0>[ZjP3moOd0mOGe0>GUi@3`l?00lO7a0?Win@3^k^h0oooo
0>CTi03_knl0mOGe0?Cdm03fm_H20?Ogm`0L0?Win@3oool0kno_0?ooo`3kno/0moOg0?ooo`3gmoL0
oooo0?Ogm`3Zj^X0j>SX0?Win@3fm_H0l?3`0?Shn03inOT0l_;b0?clo03oool0lo?c0?KfmP3/k>`0
oooo0??cl`3]kNd0no_k0?3`l080oooo00`0lo?c0?Ogm`3fm_H0nOWi0=OGe`3bl_80e]KF0?Win@31
`L40W9bL0?7al@3[jn]40?ooo`030?[jnP3oool0oooo01<0oooo01P0n_[j0>SXj03Lg=`0j>SX0?gm
o@3[jn/0k^k^0?[jnP3UiND0m_Kf0?Win@3`l?00k>c/0>SXj03inOT0h^;R0<O7a`3oool0jNWY0>_[
j`3Hf=P0l_;b0>g]k@3QhN420?[jnP0D0>[ZjP3bl_80oooo0?ooo`3Xj>P0l?3`0>_[j`3oool0m?Cd
0>CTi03`l?00lO7a0?_kn`3`l?00oooo0>KViP3`l?00mOGe0?Cdm03fm_H20?[jnP0L0?Win@3oool0
kno_0?ooo`3lo?`0m_Kf0?ooo`3fm_H0oooo0?KfmP3Zj^X0j>SX0?[jnP3fm_H0l?3`0?Win@3kno/0
lo?c0?_kn`3oool0l_;b0?KfmP3[jn/0oooo0?Cdm03_knl0o?cl0?7al@80oooo00`0m?Cd0?Ogm`3f
m_H0n_[j0=OGe`3alO40e]KF0?Ogm`31`L40W9bL0?7al@3[jn]70?ooo`00?03oool02`3Kfm/0emOG
0=kNgP3WinL0oooo0?[jnP3oool0k^k^0>SXj03]kNd0oOgm0080l?3`00H0m_Kf0?3`l03Rh^80nOWi
0?KfmP3Xj>P20??cl`050?KfmP3WinL0mOGe0??cl`3inOT00`3moOd0403_knl0lO7a0>GUi@3Xj>P0
lo?c0?Cdm03Ti>@0mOGe0??cl`3hn?P0oooo0?KfmP3emOD0no_k0?Gem@3clo<30?KfmP060?ooo`3g
moL0oOgm0?KfmP3inOT0k^k^0P3oool01@3fm_H0oOgm0>WYj@3^k^h0oooo0080nOWi0P3fm_H20?oo
o`0:0?Ogm`3oool0moOg0?KfmP3`l?00l_;b0?ooo`3clo<0oooo0>[ZjP80oOgm00T0lo?c0=kNgP3b
l_80lo?c0?;blP2YZJT0N7Qh0>_[j`3gmoL0G03oool04`3Kfm/0f=SH0=gMg@3Xj>P0oooo0?gmo@3o
ool0k^k^0>SXj03]kNd0oOgm0?3`l03_knl0m_Kf0?7al@3Rh^80nOWi0?KfmP3YjNT00P3clo<01@3f
m_H0inOW0?Cdm03dm?@0moOg00<0oooo00/0kno_0?3`l03Ti>@0j>SX0??cl`3fm_H0i>CT0?Gem@3c
lo<0nOWi0?ooo`020?KfmP030?clo03fm_H0l_;b00<0m_Kf00H0oooo0?Ogm`3lo?`0m_Kf0?[jnP3^
k^h20?ooo`050?KfmP3lo?`0j^[Z0>k^kP3oool00P3inOT20?KfmP80oooo00X0moOg0?ooo`3gmoL0
m_Kf0?7al@3clo<0oooo0?Cdm03oool0j^[Z0P3lo?`02@3bl_80gmoO0??cl`3dm?@0lo?c0:ZZZP1g
MgL0jn_[0?Ogm`180?ooo`009@3oool00`3jn_X0oooo0?ooo`0D0?ooo`0Y0?[jnP3Ti>@0b/[:0=KF
eP3UiND0mOGe0??cl`3/k>`0mOGe0?gmo@3Zj^X0m_Kf0?Gem@3Ph>00oooo0?;blP3[jn/0l?3`0<k>
cP34a<@0j>SX0>CTi03WinL0kno_0>OWi`3^k^h0iNGU0?_kn`3oool0moOg0?Gem@3`l?00o_kn0>c/
k03Ti>@0mOGe0>o_k`3fm_H0l?3`0>o_k`3fm_H00P3inOT00`3hn?P0m_Kf0?KfmP020?KfmP0C0?oo
o`3fm_H0lo?c0?3`l03inOT0m_Kf0??cl`3gmoL0nOWi0??cl`3gmoL0oooo0>k^kP3Zj^X0lo?c0?Cd
m03fm_H0l?3`0?Ogm`020??cl`0C0?;blP3inOT0no_k0?ooo`3kno/0j^[Z0>3Ph03fm_H0lo?c0?Kf
mP3Jf]X0kno_0?_kn`3`l?00[jn_06EUI@3Bd]80oooo0?3`l0150?ooo`030?[jnP3oool0oooo01@0
oooo01d0n_[j0>CTi03:b/X0e]KF0>GUi@3dm?@0lo?c0>c/k03emOD0oOgm0>[ZjP3fm_H0m?Cd0>3P
h03oool0m?Cd0>[ZjP3`l?00clo?0<G5a@3WinL0i>CT0>OWi`3alO40inOW0>o_k`3UiND0n_[j0?oo
o`020?Ogm`0:0>o_k`3oool0k>c/0>GUi@3emOD0l?3`0?Ogm`3`l?00kno_0?KfmP80n_[j00<0nOWi
0?KfmP3fm_H00P3fm_H04`3oool0m_Kf0?;blP3`l?00n_[j0?KfmP3clo<0moOg0?Win@3bl_80moOg
0?ooo`3^k^h0j^[Z0?;blP3dm?@0m_Kf0?3`l03gmoL00P3dm?@04`3clo<0no_k0?clo03oool0o?cl
0>[ZjP3QhN40m_Kf0?;blP3fm_H0g=cL0?7al@3kno/0lO7a0;:b/P1TI6@0d];B0?ooo`3`l?00B03o
ool003h0oooo01<0[Jf]0=[JfP3Ti>@0kNg]0>c/k03fm_H0l?3`0?[jnP3Ti>@0m_Kf0??cl`3jn_X0
i>CT0?Gem@3Shn<0j>SX0>[ZjP3Ti>@0kno_0080i>CT00D0kno_0?Gem@3bl_80h^;R0?ooo`020?3`
l00>0?KfmP3/k>`0alO70?Win@3^k^h0k>c/0?Cdm03moOd0inOW0?Ogm`3dm?@0lo?c0>k^kP3inOT3
0?ooo`090?KfmP3clo<0m_Kf0?ooo`3fm_H0m?Cd0?Win@3fm_H0l?3`0080lo?c00/0m_Kf0?ooo`3f
m_H0iNGU0>_[j`3oool0lo?c0?3`l03inOT0oooo0?Win@020?ooo`070??cl`3Rh^80kno_0?Ogm`3[
jn/0oooo0?Cdm0020>o_k`060?;blP3Cdm<0eMGE0>CTi01IFET0l?3`H03oool04`2^[Zh0f][J0>CT
i03]kNd0jn_[0?KfmP3`l?00n_[j0>CTi03fm_H0lo?c0?[jnP3Ti>@0mOGe0>CTi03WinL0j^[Z0>CT
i03_knl00P3UiND05@3alO40m_Kf0??cl`3Shn<0oooo0>o_k`3alO40m_Kf0>g]k@37alL0nOWi0>c/
k03]kNd0mOGe0?clo03WinL0moOg0?Cdm03bl_80k^k^0?[jnP030?ooo`0F0?KfmP3bl_80m_Kf0?oo
o`3fm_H0m?Cd0?[jnP3fm_H0l?3`0?Cdm03bl_80m_Kf0?ooo`3fm_H0iNGU0>_[j`3oool0lo?c0?7a
l@3kno/0oooo0?_kn`80oooo00l0m?Cd0>?Sh`3_knl0moOg0>[ZjP3oool0m?Cd0?3`l03alO40lo?c
0=GEe@3GemL0iNGU05IFEP3`l?00BP3oool003h0oooo00/0n_[j0:6QX@3Kfm/0inOW0=[JfP3gmoL0
k>c/0>k^kP3clo<0l?3`0?clo0020?Ogm`080?KfmP3WinL0o?cl0>7Qh@3clo<0gmoO0>OWi`3_knl2
0?_kn`0>0?Gem@3`l?00l?3`0?knoP3oool0n?Sh0?_kn`3`l?00fMWI0>[ZjP3dm?@0l?3`0?Cdm03^
k^h40?ooo`030>SXj03oool0m_Kf0080lo?c00<0m_Kf0?ooo`3clo<00P3oool0803]kNd0gmoO0>?S
h`3`l?00lo?c0?KfmP3oool0nOWi0?Gem@3oool0n_[j0>?Sh`3Ph>00kNg]0?;blP3Vi^H0j>SX0>k^
kP3clo<0nOWi0>o_k`3dm?@0oOgm0>SXj03`l?00lo?c0?ooo`3Xj>P0l_;b0=[JfP3Vi^H0]KFeH@3o
ool05@3jn_X0XJ6Q0=WIf@3Xj>P0f][J0?Ogm`3/k>`0k^k^0?Cdm03_knl0oOgm0?Ogm`3inOT0mOGe
0>OWi`3kno/0h^;R0?;blP3MgMd0i^KV0>k^kP020?clo0030?Gem@3`l?00kno_0080oooo00T0nOWi
0?clo03alO40fMWI0>_[j`3dm?@0l?3`0?Cdm03^k^h0103oool00`3Xj>P0oooo0?KfmP020?Cdm003
0?KfmP3oool0l_;b0080oooo0200k^k^0=oOg`3Rh^80l?3`0?Cdm03fm_H0oooo0?[jnP3dm?@0oooo
0?[jnP3Shn<0hN7Q0>o_k`3clo<0inOW0>SXj03^k^h0lo?c0?[jnP3`l?00m?Cd0?clo03Zj^X0lO7a
0?Cdm03oool0j>SX0??cl`3Hf=P0hn?S0;Fe]D/0oooo000o0?ooo`0I0>_[j`2FUYH0e]KF0>WYj@3c
lo<0moOg0>g]k@3fm_H0oOgm0>WYj@3Lg=`0hN7Q0>;RhP3_knl0hN7Q0>k^kP3Xj>P0b/[:0?Ogm`3W
inL0mOGe0?Cdm03fm_H0mOGe0?;blP020?_kn`0:0?ooo`3inOT0mOGe0?7al@3dm?@0kno_0?Cdm03_
knl0m_Kf0?ooo`<0m_Kf0140l?3`0?KfmP3fm_H0l?3`0??cl`3oool0m_Kf0?ooo`3clo<0m_Kf0?7a
l@3]kNd0no_k0;Jf]P3^k^h0m_Kf0?ooo`020?KfmP0G0??cl`3gmoL0moOg0?ooo`3jn_X0m?Cd0?oo
o`3inOT0hN7Q0?Shn03fm_H0m?Cd0=_Kf`3Shn<0j>SX0??cl`3GemL0kno_0>SXj03Rh^80no_k09RH
V03[jn/0HP3oool02`3[jn/0UYJF0=KFeP3Zj^X0lo?c0?Ogm`3]kNd0m_Kf0?gmo@3Xj>P0gMgM0080
h^;R00P0k^k^0>7Qh@3^k^h0j>SX0<[:bP3gmoL0j>SX0?Cdm080m_Kf00h0mOGe0??cl`3lo?`0o?cl
0?ooo`3jn_X0m_Kf0?;blP3dm?@0l?3`0?Cdm03_knl0m_Kf0?ooo`<0m_Kf0140l?3`0?KfmP3fm_H0
l?3`0?Cdm03oool0m_Kf0?ooo`3bl_80m_Kf0?7al@3/k>`0n_[j0;Ng]`3^k^h0m_Kf0?ooo`020?Kf
mP0G0??cl`3gmoL0moOg0?gmo@3jn_X0m?Cd0?ooo`3jn_X0h^;R0?[jnP3fm_H0m?Cd0=cLg03Vi^H0
j>SX0??cl`3Jf]X0lO7a0>_[j`3Shn<0n_[j09RHV03[jn/0B`3oool00400oooo00X0[Zj^09bLW03B
d]80gMgM0?KfmP3jn_X0mOGe0>_[j`3lo?`0eMGE0P3Xj>P04@3^k^h0m?Cd0>GUi@3Shn<0fMWI0?oo
o`3UiND0lo?c0>k^kP3inOT0moOg0?KfmP3/k>`0no_k0?Ogm`3lo?`0oOgm0080nOWi00h0m_Kf0??c
l`3dm?@0m_Kf0?ooo`3clo<0m_Kf0?ooo`3`l?00j^[Z0?Win@3Shn<0oooo0??cl`80m_Kf0240m?Cd
0?KfmP3inOT0fMWI0>OWi`38b<P0]kNg0<W9b@3[jn/0g]kN0?Cdm03fm_H0lo?c0>[ZjP3clo<0kno_
0?clo03fm_H0nOWi0>7Qh@3Xj>P0fMWI0<C4a03]kNd0j>SX0=SHf03Ng]h0m?Cd0?ooo`3MgMd0m_Kf
0;Jf]P2?Shl0I03oool02P2_[jl0VYZJ0=;BdP3Ng]h0m_Kf0?[jnP3emOD0j^[Z0?gmo@3Fe]H20>WY
j@0:0>k^kP3dm?@0iNGU0>7Qh@3Hf=P0oooo0>CTi03dm?@0l?3`0?Win@80moOg01D0kNg]0?clo03f
m_H0no_k0?clo03jn_X0nOWi0?KfmP3bl_80m?Cd0?KfmP3oool0l_;b0?KfmP3oool0l?3`0>[ZjP3j
n_X0i>CT0?ooo`3dm?@00P3fm_H08@3dm?@0m_Kf0?[jnP3IfMT0inOW0<W9b@2g]kL0bLW90>_[j`3N
g]h0m?Cd0?KfmP3clo<0j^[Z0??cl`3_knl0o?cl0?KfmP3jn_X0h^;R0>[ZjP3Jf]X0a<C40>k^kP3[
jn/0f][J0=kNgP3fm_H0oooo0=gMg@3clo<0/[:b08j>SP1<0?ooo`00@@3oool07`39bLT0JFUY0?3`
l03`l?00l_;b0?_kn`3emOD0jNWY0>g]k@3Rh^80l?3`0>[ZjP3GemL0g]kN0>;RhP3Ph>00g]kN0?Og
m`3clo<0k^k^0?_kn`3clo<0m_Kf0?gmo@3oool0moOg0?gmo@3hn?P0oooo0>3Ph03`l?000P3fm_H0
1@3oool0k^k^0>c/k03clo<0oooo00@0lo?c00D0oooo0>g]k@3kno/0m_Kf0??cl`020?3`l00:0=cL
g03?cll0j>SX0<c<c03EeMD0h>3P0??cl`3jn_X0lo?c0=kNgP80j^[Z0P3inOT03`3clo<0hN7Q0>_[
j`3`l?00kno_0>?Sh`3Cdm<0l?3`0>o_k`3YjNT0l?3`0>KViP3`l?00OGem0;Jf]P1V0?ooo`0O0<[:
bP1YJFT0l?3`0?3`l03clo<0no_k0?Gem@3Zj^X0kNg]0>;RhP3alO40jn_[0=OGe`3Ng]h0h>3P0=oO
g`3Ng]h0m_Kf0?Cdm03_knl0o?cl0?;blP3fm_H0o?cl0?ooo`3fm_H0o?cl0?Win@3oool0h>3P0?3`
l0020?KfmP0L0?ooo`3]kNd0jn_[0?;blP3oool0l_;b0?Cdm03bl_80lo?c0?ooo`3_knl0o?cl0?Kf
mP3bl_80l?3`0>o_k`3Lg=`0clo?0>SXj03=cLd0e=CD0>7Qh@3dm?@0n_[j0?Cdm03Ogml0jn_[0>[Z
jP80n_[j00l0mOGe0>CTi03^k^h0lO7a0>o_k`3Ti>@0e]KF0?3`l03_knl0j^[Z0?3`l03Xj>P0lO7a
07alO02g]kL0C@3oool00480oooo01X0eMGE09JFUP3emOD0m_Kf0>SXj03Zj^X0lO7a0?Ogm`3alO40
oOgm0?Ogm`3Rh^80lo?c0>OWi`3^k^h0kNg]0?KfmP3alO40mOGe0>[ZjP3[jn/0nOWi0?gmo@3clo<0
oooo0?Shn080m_Kf00H0m?Cd0??cl`3oool0k^k^0??cl`3Zj^X30?KfmP040?ooo`3fm_H0m_Kf0?Kf
mP<0lo?c01@0kNg]0??cl`3Vi^H0gmoO0?3`l03]kNd0m?Cd0<_;b`3bl_80`<300;Fe]@3:b/X0dm?C
0=_Kf`3De=@0b<S80<O7a`3alO40j^[Z0>7Qh@80inOW00X0l_;b0?_kn`3gmoL0lo?c0>KViP3moOd0
j^[Z0?ooo`1`L700mOGeJ03oool06P3EeMD0UYJF0?Gem@3gmoL0jNWY0>_[j`3`l?00m_Kf0?3`l03m
oOd0m_Kf0>;RhP3dm?@0j>SX0>k^kP3]kNd0m_Kf0?7al@3emOD0jn_[0>g]k@3inOT0o?cl0?Gem@3o
ool0nOWi0P3fm_H01P3dm?@0l_;b0?ooo`3^k^h0l_;b0>[ZjP<0m_Kf00D0oooo0?KfmP3fm_H0m_Kf
0?;blP020?Cdm00P0>o_k`3dm?@0inOW0=oOg`3`l?00k^k^0?Cdm03;bl/0lo?c0;no_`2f][H0bLW9
0=;BdP3Kfm/0eMGE0<W9b@36a/H0lO7a0>[ZjP3Rh^80inOW0>SXj03alO40n_[j0?KfmP3clo<0inOW
0?clo03Zj^X0oooo06e]K@3emOE>0?ooo`00@`3oool01P3=cLd0UiNG0>k^kP3^k^h0lo?c0?KfmP80
mOGe00T0k^k^0?7al@3bl_80hN7Q0?ooo`3alO40i>CT0?KfmP3lo?`00P3jn_X0303bl_80h>3P0?Kf
mP3oool0mOGe0>c/k03fm_H0oOgm0?Win@3oool0nOWi0>o_k`80m_Kf0P3clo<30?ooo`80m_Kf01@0
oooo0?KfmP3clo<0oooo0>k^kP3clo<0oooo0<;2`P3IfMT0n_[j0>7Qh@3Kfm/0l_;b0>KViP2][Jd0
[jn_0<G5a@3Hf=P0i^KV0?Ogm`80g]kN00@0kno_0>g]k@3oool0oooo0P3jn_X01P3^k^h0lo?c0>[Z
jP3Jf]X0i>CT0=_KffX0oooo0140cLg=09NGU`3^k^h0kno_0??cl`3fm_H0mOGe0?KfmP3^k^h0lO7a
0?Cdm03Rh^80oooo0?7al@3Ti>@0m_Kf0?gmo@020?Win@0<0??cl`3QhN40m_Kf0?ooo`3dm?@0kNg]
0?KfmP3lo?`0n_[j0?ooo`3jn_X0kno_0P3fm_H00`3dm?@0l_;b0?ooo`020?ooo`80m_Kf01@0oooo
0?KfmP3dm?@0oooo0>k^kP3bl_80oooo0<?3``3IfMT0n_[j0>7Qh@3Kfm/0lo?c0>OWi`2][Jd0/;2`
0<G5a@3Hf=P0iNGU0?KfmP80g]kN00@0k^k^0>g]k@3oool0oooo0P3moOd01P3/k>`0m?Cd0>[ZjP3K
fm/0hN7Q0=cLg4l0oooo00150?ooo`0;09bLW01MGEd0n_[j0>k^kP3UiND0m_Kf0?clo03gmoL0j>SX
0??cl`3oool00P3Xj>P00`3=cLd0moOg0?ooo`020?Ogm`070?_kn`3_knl0bl_;0?_kn`3YjNT0l?3`
0?Cdm0020>o_k`050>k^kP3dm?@0oooo0?ooo`3dm?@00P3fm_H00`3dm?@0oooo0?Cdm0020?Cdm00H
0?ooo`3dm?@0m_Kf0?Win@3Xj>P0j^[Z0?3`l03]kNd0j>SX0=CDe03kno/0j>SX0=[JfP34a<@0_;bl
0<O7a`34a<@0_[jn0;bl_03Fe]H0i>CT0=WIf@3_knl0m_Kf0P3kno/01P3Ti>@0hn?S0?ooo`3Vi^H0
QhN70<c<c6d0oooo00/0W9bL05eMG@3kno/0k^k^0>CTi03fm_H0oOgm0?Ogm`3YjNT0lo?c0?ooo`02
0>SXj0030<_;b`3fm_H0oooo0080m_Kf00L0n_[j0?3`l03;bl/0o?cl0>SXj03`l?00m_Kf0080l?3`
00D0kNg]0?Cdm03oool0oooo0?Cdm0020?KfmP030?Cdm03oool0m?Cd0080m?Cd01X0oooo0?Cdm03f
m_H0n_[j0>SXj03Zj^X0lO7a0>g]k@3Xj>P0eMGE0?[jnP3Xj>P0g=cL0<C4a02l_;`0a/K60<C4a02n
_[h0_;bl0=OGe`3Ti>@0fMWI0>k^kP3fm_H0n_[j0?gmo@80iNGU00@0oooo0>CTi024Q8@0c<c<D03o
ool004H0oooo00@0HF5Q0>GUi@3^k^h0kNg]0P3inOT01`3/k>`0jNWY0?KfmP3oool0j>SX0=?Cd`2h
^;P00`3oool0903gmoL0oooo0?gmo@3alO40h^;R0?Cdm03Vi^H0inOW0?Shn03alO40k^k^0>[ZjP3i
nOT0m_Kf0?3`l03WinL0m_Kf0?Win@3fm_H0kno_0?3`l03dm?@0nOWi0?Cdm03Ng]h0oooo0?7al@3M
gMd0l?3`0=gMg@3clo<0k^k^0<S8b03Zj^X0`<300>o_k`80m?Cd0100n?Sh0?KfmP3Ti>@0j>SX0?Ge
m@3bl_80kno_0?7al@3YjNT0iNGU0>SXj03fm_H0l?3`08j>SP1oOgl0moOgKP3oool0101QHF40iNGU
0>k^kP3]kNd20?Win@070>c/k03Zj^X0m_Kf0?ooo`3Xj>P0d];B0;Jf]P030?ooo`060?KfmP3oool0
oooo0?7al@3QhN40m?Cd0P3UiND02`3gmoL0lO7a0>k^kP3Zj^X0n_[j0?KfmP3`l?00inOW0?KfmP3j
n_X0m_Kf0080l?3`00l0m?Cd0?[jnP3dm?@0g]kN0?ooo`3`l?00gMgM0?7al@3Ng]h0m?Cd0>k^kP38
b<P0j^[Z0<71`@3^k^h00P3emOD01P3gmoL0m_Kf0>KViP3Zj^X0m?Cd0??cl`80l?3`00P0j^[Z0>OW
i`3Vi^H0m?Cd0?3`l02;Rh/0Ogmo0?Ogme00oooo000Y0?ooo`030?[jnP3oool0oooo01/0oooo00`0
NWYj0=;BdP3Ti>@0lo?c0?Ogm`3lo?`0kNg]0?KfmP3YjNT0m_Kf0>OWi`3EeMD20=_Kf`0A0?ooo`3f
m_H0o_kn0?_kn`3moOd0kno_0?KfmP3lo?`0mOGe0=[JfP3[jn/0e]KF0<30`03fm_H0k^k^0?3`l03[
jn/00`3`l?00403]kNd0j>SX0??cl`3WinL0fm_K0>k^kP3fm_H0n?Sh0=gMg@36a/H0bLW90=GEe@3S
hn<0j>SX0>_[j`3alO420>[ZjP0?0?Cdm03inOT0n?Sh0?Cdm03WinL0jn_[0?Cdm03Jf]X0inOW0?Ge
m@3_knl0e=CD0?knoP1ZJVX0f][J05<0oooo00<0n_[j0?ooo`3oool06`3oool0<P1jNWX0dM7A0>CT
i03clo<0moOg0?gmo@3]kNd0m_Kf0>[ZjP3fm_H0inOW0=GEe@3Kfm/0fMWI0?ooo`3gmoL0oooo0?[j
nP3oool0l?3`0?KfmP3moOd0m_Kf0=[JfP3Zj^X0e]KF0<30`03gmoL0k^k^0?7al@3]kNd0l?3`0?7a
l@3`l?00k>c/0>WYj@3dm?@0i^KV0=_Kf`3^k^h0m_Kf0?Ogm`3Lg=`0a/K60<[:bP3Fe]H0iNGU0>WY
j@3[jn/0lO7a0P3Zj^X03`3dm?@0nOWi0?Ogm`3fm_H0i^KV0>_[j`3fm_H0fMWI0>KViP3fm_H0l_;b
0=;BdP3lo?`0JVYZ0=_Kf`1B0?ooo`00B03oool0202DU9@0c<c<0>GUi@3/k>`0oooo0?Gem@3YjNT0
moOg0P3]kNd0703`l?00gmoO0>g]k@3GemL0i^KV0?7al@3no_h0nOWi0?_kn`3Zj^X0jn_[0?KfmP3/
k>`0j^[Z0>3Ph03Jf]X0k^k^0?Gem@3dm?@0i>CT0?[jnP3^k^h0j^[Z0>g]k@3Lg=`0d=3@0?gmo@3W
inL20>_[j`070>;RhP2[Zj/0k>c/0=WIf@3Bd]80o?cl0??cl`020?ooo`80l_;b00h0m_Kf0?Cdm03b
l_80oooo0>_[j`3_knl0oooo0?Shn03jn_X0k^k^0>o_k`3@d=00_[jn0?[jnW<0oooo0140U9BD0<_;
b`3UiND0jn_[0?ooo`3emOD0j^[Z0?KfmP3]kNd0k>c/0?3`l03Ogml0k^k^0=SHf03UiND0l?3`0?oo
o`020?[jnP80jn_[0140m_Kf0>c/k03Zj^X0h>3P0=[JfP3^k^h0lo?c0?Cdm03Ti>@0n_[j0>k^kP3Z
j^X0kNg]0=gMg@3@d=00oOgm0>OWi`020>[ZjP070>7Qh@2[Zj/0k>c/0=WIf@3Bd]80o?cl0??cl`02
0?ooo`80l_;b00h0m_Kf0?;blP3bl_80oooo0>[ZjP3`l?00oooo0?Gem@3moOd0lO7a0>k^kP3@d=00
_Kfm0?[jnU<0oooo000U0?ooo`030?[jnP3oool0oooo0240oooo02D0bLW907EeM@2GUiL0cLg=0=OG
e`3Cdm<0kno_0??cl`3AdM40g=cL0>KViP3gmoL0eMGE0>SXj03WinL0fm_K0:ZZZP38b<P0bl_;0?7a
l@3QhN40mOGe0>OWi`3Kfm/0alO70>o_k`2i^KT0h>3P0:n_[`3clo<0`/;20>GUi@3alO40j^[Z0=SH
f03Shn<0j>SX0080f=SH00H0l_;b0>k^kP3fm_H0inOW0?_kn`3emOD20>g]k@0@0?Ogm`3clo<0lO7a
0?KfmP3[jn/0jNWY0??cl`3oool0h>3P0=[JfP3Lg=`0m?Cd0=KFeP2g]kL08b<S0<C4a540oooo00<0
n_[j0?ooo`3oool08@3oool03@3:b/X0MGEe09NGU`3=cLd0f=SH0=?Cd`3alO40lo?c0=3@d03Kfm/0
i^KV0?Ogm`3De=@00P3Xj>P05P3Kfm/0ZZZZ0<S8b03:b/X0l?3`0>;RhP3emOD0inOW0=_Kf`36a/H0
l?3`0;Ng]`3Ogml0/;2`0?7al@31`L40i>CT0?7al@3Zj^X0fMWI0>CTi03Xj>P20=WIf@060?3`l03]
kNd0m_Kf0>SXj03lo?`0mOGe0P3]kNd0403gmoL0lo?c0?7al@3emOD0j>SX0>WYj@3clo<0oooo0>?S
h`3Jf]X0gMgM0?7al@3Hf=P0]KFe024Q8@34a<AD0?ooo`009@3oool30?[jnR80oooo01l0`L7109jN
WP37alL0gmoO0>[ZjP3`l?00k>c/0>SXj03Ogml0k>c/0?KfmP3bl_80j^[Z0=WIf@3clo<0n?Sh0>_[
j`3>c/h0eMGE0=kNgP3inOT0k^k^0?ooo`3_knl0h^;R0?KfmP3>c/h0l?3`0;6a/@3:b/X0h^;R0080
jNWY01`0j>SX0=SHf03alO40inOW0?_kn`3Ti>@0no_k0>OWi`3inOT0k^k^0>GUi@3clo<0moOg0?kn
oP3jn_X0n?Sh0?[jnP3clo<0l?3`0>CTi03Xj>P0i^KV0=cLg03moOd0jNWY07YjNP1PH600n_[jDP3o
ool30?[jnR80oooo01l0`L7109nOW`36a/H0g]kN0>[ZjP3`l?00k>c/0>WYj@3Ogml0kNg]0?KfmP3b
l_80j^[Z0=WIf@3bl_80moOg0>_[j`3>c/h0eMGE0=kNgP3jn_X0k^k^0?ooo`3^k^h0h^;R0?Ogm`3>
c/h0kno_0;6a/@3:b/X0h^;R0080j>SX01`0inOW0=WIf@3alO40j>SX0?_kn`3Ti>@0o?cl0>OWi`3i
nOT0kno_0>GUi@3dm?@0nOWi0?_kn`3moOd0m_Kf0?gmo@3bl_80lO7a0>GUi@3WinL0i^KV0=gMg@3o
ool0jNWY07YjNP1OGel0n_[jE@3oool004/0oooo00X0k^k^0;Zj^P2e]KD0fMWI0?Gem@3moOd0m_Kf
0=oOg`3jn_X0lo?c0P3UiND01@3fm_H0moOg0>o_k`3emOD0k^k^0080n?Sh0100kNg]0=_Kf`3/k>`0
oooo0>SXj03]kNd0h^;R0>o_k`3WinL0a/K60?;blP3emOD0no_k0>k^kP3EeMD0_kno0P3Kfm/03`3o
ool0m_Kf0>GUi@3Vi^H0kno_0?Gem@3dm?@0oOgm0?ooo`3/k>`0hn?S0>o_k`3YjNT0kNg]0?clo002
0>SXj0050>GUi@3]kNd0IVIV0=SHf03gmoL0N@3oool02P3^k^h0^k^k0;Fe]@3Jf]X0m?Cd0?gmo@3f
m_H0gmoO0?[jnP3clo<20>GUi@050?KfmP3gmoL0k^k^0?Gem@3]kNd00P3gmoL06@3]kNd0fm_K0>c/
k03oool0j>SX0>g]k@3Rh^80k^k^0>OWi`35aLD0l?3`0?KfmP3kno/0l?3`0=CDe02n_[h0g=cL0=_K
f`3oool0m_Kf0>CTi03Vi^H0k^k^0??cl`3bl_800P3oool03@3]kNd0iNGU0?3`l03Zj^X0k>c/0?gm
o@3Zj^X0j>SX0>CTi03alO40IVIV0=SHf03gmoL0EP3oool004d0oooo00D0k^k^092@T02ZZZX0gmoO
0?Win@020>SXj0030>g]k@3jn_X0iNGU0080n?Sh01X0kNg]0?[jnP3jn_X0jn_[0?KfmP3]kNd0o?cl
0>[ZjP3hn?P0eMGE0?ooo`3bl_80e=CD0??cl`3]kNd0f=SH0?7al@3bl_80k>c/0=_Kf`3Zj^X0jNWY
0=kNgP3/k>`0h>3P0??cl`80l?3`00l0moOg0>_[j`3inOT0k>c/0??cl`3WinL0kno_0>GUi@3[jn/0
i>CT0<_;b`3Shn<0YjNW059BDP3^k^h0O@3oool02P3^k^h0T92@0:ZZZP3Ogml0nOWi0>WYj@3Xj>P0
k^k^0?[jnP3UiND20?Ogm`0J0>c/k03inOT0n_[j0>_[j`3fm_H0k>c/0?gmo@3Zj^X0moOg0=CDe03o
ool0l_;b0=CDe03clo<0k^k^0=SHf03alO40l_;b0>c/k03Kfm/0jn_[0>WYj@3Ogml0k>c/0>3Ph03d
m?@20?7al@0?0?KfmP3/k>`0moOg0>g]k@3bl_80i^KV0>_[j`3UiND0j^[Z0>KViP3;bl/0hn?S0:RX
Z01ADE40kno_05P0oooo001>0?ooo`0E0?Ogm`3emOD0VYZJ04M7A`1eMGD0m_Kf0>KViP3Ogml0c/k>
0>g]k@3IfMT0clo?0?3`l03Ph>00jn_[0>7Qh@3clo<0o?cl0>WYj@3_knl0kNg]0080moOg01h0lo?c
0>_[j`3Zj^X0d];B0??cl`3[jn/0m_Kf0>KViP3QhN40hn?S0?3`l03^k^h0g=cL0>o_k`3UiND0g=cL
0=CDe03=cLd0d];B0=GEe@3Ogml0j^[Z0=OGe`39bLT0`l?30<S8b00/;2`0UIFE0=WIf@3gmoMo0?oo
o`0E0?Ogm`3emOD0VYZJ04Q8B01eMGD0m?Cd0>KViP3Ogml0c/k>0>g]k@3IfMT0clo?0?3`l03Ph>00
k>c/0>;RhP3clo<0oOgm0>WYj@3`l?00k^k^0080moOg01h0l_;b0>[ZjP3Zj^X0d];B0??cl`3[jn/0
moOg0>KViP3Rh^80i>CT0??cl`3alO40gmoO0?3`l03Xj>P0g=cL0=CDe03=cLd0dm?C0=OGe`3QhN40
kNg]0=WIf@39bLT0aLG50<C4a00Z:RX0UYJF0=WIf@3gmoMI0?ooo`009@3oool00`3jn_X0oooo0?oo
o`0[0?ooo`0B09ZJVP1kNg/0QHF50:NWY`3Fe]H0jn_[0>OWi`3Ng]h0_kno0>OWi`3Zj^X0h>3P0>_[
j`3Zj^X0iNGU0?Ogm`3Ti>@0moOg0P3kno/06@3]kNd0i^KV0?;blP3]kNd0lo?c0>[ZjP3Vi^H0kno_
0>k^kP3emOD0i^KV0>7Qh@3Ti>@0l_;b0?7al@3<c<`0d];B0=kNgP2_[jl0e=CD0>c/k03GemL0H61P
0<_;b`3gmoL0F@3oool00`3jn_X0oooo0?ooo`0[0?ooo`0]09ZJVP1lO7`0QXJ60:NWY`3EeMD0jn_[
0>SXj03Ng]h0_kno0>SXj03[jn/0hN7Q0>c/k03Zj^X0i^KV0?KfmP3UiND0m_Kf0?_kn`3jn_X0kNg]
0>KViP3clo<0kNg]0??cl`3Zj^X0i^KV0?3`l03^k^h0mOGe0>KViP3Rh^80iNGU0?;blP3clo<0clo?
0=?Cd`3Ph>00/K6a0=OGe`3]kNd0e]KF05iNGP3;bl/0moOg05`0oooo000U0?ooo`030?[jnP3oool0
oooo02`0oooo02/0jn_[09BDU01bLW80IVIV06QXJ02][Jd0[:b/0<30`03GemL0f=SH0>SXj03Fe]H0
i>CT0>k^kP3clo<0h>3P0?clo03QhN40gmoO0>KViP3hn?P0lo?c0?KfmP3]kNd0n?Sh0>k^kP3oool0
n_[j0?Cdm03gmoL0kno_0>CTi03MgMd0fMWI0?ooo`3fm_H0gMgM0?ooo`3/k>`0Ogmo05YJFP33`l<0
moOg05X0oooo00<0n_[j0?ooo`3oool0;03oool01@3[jn/0UIFE07=cL`1WIfL0JFUY0080[Jf]02@0
`<300=OGe`3Hf=P0j>SX0=GEe@3Ti>@0k^k^0?;blP3QhN40oOgm0>;RhP3Ogml0inOW0?Win@3clo<0
m_Kf0>k^kP3gmoL0kno_0?ooo`3jn_X0m?Cd0?Win@3_knl0iNGU0=kNgP3IfMT0oooo0?KfmP3Lg=`0
oooo0>g]k@1lO7`0Fe]K0<?3``3gmoMM0?ooo`00F@3oool0303jn_X0i^KV0?7al@3Fe]H0f][J0>GU
i@3WinL0YJFU0<C4a03emOD0g]kN0>c/k080kNg]00/0i^KV0?Cdm03lo?`0kNg]0>_[j`3bl_80j>SX
0?Shn03clo<0n_[j0??cl`020?[jnP090??cl`3^k^h0kNg]0>g]k@3Cdm<0P82008:2PP3Bd]80moOg
0900oooo01T0n_[j0>KViP3alO40e]KF0=[JfP3Vi^H0inOW0:JVYP34a<@0mOGe0=kNgP3[jn/0k>c/
0>g]k@3WinL0lo?c0?gmo@3^k^h0k>c/0?;blP3YjNT0moOg0??cl`3jn_X0lo?c0080n_[j00T0lo?c
0>o_k`3^k^h0kno_0<o?c`20P800Ph>30=;BdP3gmoL0G`3oool002H0oooo00<0n_[j0?ooo`3oool0
<P3oool03@3jn_X0lO7a0>k^kP3[jn/0kNg]0?7al@3IfMT0`/;209jNWP1_Kfl0WYjN0:2PX02RXZ80
0P2n_[h20=SHf00=0>[ZjP3jn_X0n_[j0??cl`3Hf=P0a/K60:ZZZP1dM7@0>c/k034a<@0h>3P0Vi^K
0=SHf01Q0?ooo`030?[jnP3oool0oooo0380oooo00d0n_[j0?7al@3^k^h0jn_[0>g]k@3alO40fMWI
0<?3``2OWil0L71`09jNWP2PX:00XZ:R0080_[jn00<0emOG0=SHf03Zj^X00P3kno/02P3bl_80emOG
0<K6aP2YZJT0M7Ad03/k>`0a<C40>CTi09^KV`3Hf=QS0?ooo`009@3oool40?[jnSH0oooo0`3jn_X6
0?ooo`030?[jnP3Ti>@0h^;R0080^k^k00@0c<c<0=?Cd`3Vi^H0k^k^J03oool40?[jnSH0oooo0`3j
n_X60?ooo`030?[jnP3Ti>@0h^;R0080_;bl00@0cLg=0=CDe03Vi^H0k^k^J`3oool006/0oooo00<0
mOGe0?ooo`3oool0/@3oool00`3emOD0oooo0?ooo`1^0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00>P3oool2@0000400oooo0T00001i0?ooo`900000;P3oool3@00006H0oooo000k0?ooo`03@000
003oool0oooo0400oooo00=000000?ooo`3oool0M`3oool00d000000oooo0?ooo`0]0?ooo`03@000
003oool0oooo06D0oooo000d0?ooo`A000000`3oool00d000000oooo0?ooo`0:0?ooo`9000000`3o
ool2@0000080oooo0d0000030?ooo`9000000`3oool2@0000080oooo0d00000=0?ooo`06@000003o
oom000000?oood000000oooo140000020?ooo`E000000P3oool00d000000oooo@0000002@00000<0
oooo0T0000030?ooo`=000000P3oool3@0000080oooo0T00001E0?ooo`A000000`3oool00d000000
oooo0?ooo`090?ooo`=0000000<0oooo@000040000000P3oool3@0000080oooo00=000000?ooo`3o
ool00T0000020?ooo`=000003@3oool3@0000080oooo0d0000030?ooo`9000000`3oool3@0000080
oooo0d000000103ooom00000@000040000030?ooo`900000A`3oool003D0oooo00Q000000?ooo`3o
oom000000?oood000000oooo@00000/0oooo0T0000020?ooo`03@000003oool0oooo0080oooo00=0
00000?ooo`3oool00P3oool01T000000oooo0?oood000000oooo@0000080oooo00A000000?ooo`3o
oom000003P3oool01T000000oooo@000003ooom000000?ooo`=000000P3oool01T000000oooo0?oo
od000000oooo@0000080oooo00A000000?ooo`3ooom000000`3oool01T000000oooo0?oood000000
oooo@0000080oooo00=000000?oood0000000P3oool00d000000oooo@000001H0?ooo`08@000003o
ool0oooo@000003ooom000000?oood00000;0?ooo`05@000003oool0oooo0?oood0000000P3oool0
0d000000oooo@00000020?ooo`03@000003ooom0000000D0oooo00=000000?ooo`3oool0303oool0
14000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool00d000000oooo
@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000103oool014000000oooo
0?oood0000160?ooo`00=@3oool024000000oooo0?oood000000oooo@000003ooom000002P3oool0
1D000000oooo0?oood000000oooo00=000000P3oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0080oooo00A000000?ooo`3ooom000000P3oool00d000000oooo0?ooo`0<0?ooo`05@000
003ooom000000?oood0000000`3oool014000000oooo0?oood0000020?ooo`03@000003ooom00000
0080oooo00A000000?ooo`3ooom000000`3oool00d000000oooo0?ooo`020?ooo`06@000003oool0
oooo@000003ooom000000P3oool00d000000oooo@0000002@00005H0oooo00Q000000?ooo`3ooom0
00000?oood000000oooo@00000/0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003o
oom000000080oooo00=000000?oood0000000T0000030?ooo`03@000003oool0oooo00`0oooo00A0
00000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?oood00
00000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000@0oooo00=000000?ooo`3o
ool0A`3oool003D0oooo0d000000103ooom00000@000003oool2@00000P0oooo0T0000020?ooo`03
@000003ooom00000009000000P3oool3@00000030?oood0000100000009000000`3oool2@0000080
oooo1400000<0?ooo`90000000<0oooo@000003oool00P3oool2@00000<0oooo1d0000020?ooo`90
00000P3oool4@00000040?oood00001000000?ooo`9000000P3oool3@00000040?oood0000100000
@00005H0oooo0d000000103ooom00000@000003oool2@00000T0oooo0T0000020?ooo`A0000000<0
oooo@000040000000T0000020?ooo`=000000P3oool4@00000/0oooo140000020?ooo`A000000P3o
ool2@00000<0oooo1D000000103ooom00000@000003oool3@00000030?oood000010000000900000
A`3oool003D0oooo00A000000?ooo`3ooom000007@3oool00d000000oooo0?ooo`0a0?ooo`03@000
003oool0oooo00X0oooo00=000000?ooo`3oool0F03oool014000000oooo0?oood0000140?ooo`03
@000003oool0oooo00T0oooo00=000000?ooo`3oool0A`3oool003@0oooo1400001>0?ooo`03@000
003oool0oooo00d0oooo0T00001I0?ooo`A00000403oool00d000000oooo0?ooo`0a0?ooo`900000
E@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool008D0oooo
0T00003o0?ooo`X0oooo00270?ooo`03@000003oool0oooo0?l0oooo1`3oool007T0oooo0d000003
0?ooo`=000000`3oool3@00000D0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`04
0?ooo`03@000003oool0oooo00L0oooo0T0000000`3ooom00000@00000020?ooo`90000000<0oooo
@000040000000P3oool00d000000oooo0?ooo`02@0000080oooo0d0000001`3ooom00000@0000400
0000oooo@000003oool00d0000030?ooo`90000000H0oooo@000003ooom000000?oood0000020?oo
o`9000004P3oool2@0000080oooo0T0000000`3ooom00000@00000020?ooo`9000000`3oool2@000
0080oooo0d0000001P3ooom00000@00004000000oooo@0000080oooo0T0000020?ooo`900000Q@3o
ool007X0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080oooo00=0
00000?ooo`3oool0203oool00d000000oooo0?ooo`0>0?ooo`07@000003oool0oooo0?oood000000
oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000
oooo@00000040?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@0000002
0?ooo`90000000H0oooo@000003ooom000000?oood00000F0?ooo`06@000003oool0oooo@000003o
oom000000P3oool00d000000oooo0?ooo`020?ooo`06@000003oool0oooo@000003ooom00000103o
ool01T000000oooo0?oood000000oooo@00000H0oooo00=000000?ooo`3oool0PP3oool007X0oooo
00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3o
ool0203oool00d000000oooo0?ooo`0>0?ooo`07@000003ooom000000?oood000000oooo@0000002
0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo@0000004
0?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`900000
00D0oooo@000003ooom000000?ooo`03@00001<0oooo00A000000?ooo`3oool0oooo0d0000020?oo
o`=000000P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00E000000?oo
o`3ooom000000?ooo`03@00000<0oooo00=000000?ooo`3oool0P`3oool007X0oooo0T0000030?oo
o`900000103oool3@00000/0oooo00=000000?ooo`3oool03@3oool2@00000030?oood0000100000
0080oooo0T0000000`3ooom00000@0000002@00000<0oooo0T0000020?ooo`=000000P3oool3@000
0080oooo140000020?ooo`90000000D0oooo@00004000000oooo@00000020?ooo`=000004`3oool2
@0000080oooo00E000000?oood00001000000?ooo`03@00000030?oood0000100000009000000P3o
ool3@0000080oooo0d0000020?ooo`=000000`3oool2@00008@0oooo001j0?ooo`04@000003oool0
oooo@00001<0oooo00=000000?oood0000003`3oool2@00000030?oood000010000001D0oooo00=0
00000?ooo`3oool0:`3oool00d000000oooo0?ooo`070?ooo`03@000003oool0oooo00L0oooo00=0
00000?ooo`3oool0SP3oool007T0oooo1D0000020?ooo`03@000003oool0oooo00h0oooo0d00000?
0?ooo`90000000<0oooo@00004000000503oool2@00002`0oooo0T00000B0?ooo`900000T03oool0
0?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.157534, -0.0238147, 
  0.00580218, 0.00580218}, {{27.125, 191.25}, {185.313, 
  21.1875}} -> {-66.2021, -12.4581, 1.77861, 1.77861}, {{207.688, 371.813}, {
  185.313, 21.1875}} -> {-387.352, -12.4581, 1.77861, 1.77861}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Thus, we have succeeded in drawing the monochrome sketch images. Both \
images on the right and left in Fig.7 are based on the three-dimensional \
color as well as two-dimensional monochrome characteristic vector natures.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.5.2 Color sketch",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In order to draw a sketch by color pencils, it is essential to use the \
red, green and blue color components of the image shown in Fig. 5. In \
addition, the monochrome sketches to the red, green and green color \
components are required. These processes are carried out by a following \
computation.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
colorSketchData=
\tTable[1-vectorMag2D[eigen2DVect[sample[[i]]]],{i,dim[[1]]}];\
\>", "Input",
  CellLabel->"In[52]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Figure 8 shows the sketches of the red, green and blue components in Fig. \
5.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[ListDensityPlot[colorSketchData[[i]],
\t\tPlotRange->All,Mesh->False,Frame->False,
\t\tPlotLabel->StringForm[\"``\",color[[i]]],
\t\tDisplayFunction->Identity],{i,dim[[1]]}]],
\tPlotLabel->\"Fig.8. Components of color sketch\",
\tImageSize->{450,150}];\
\>", "Input",
  CellLabel->"In[53]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
%%ImageSize: 450 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[.5 .325 -101 0 ]
[.5 .325 101 12.5625 ]
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .325 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.8) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Components) show
171.000000 12.812500 moveto
(of) show
189.000000 12.812500 moveto
(color) show
225.000000 12.812500 moveto
(sketch) show
261.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Red) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3F3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF3F3F3FFFFFFFFFFF3F3FFFFF3
FFFFFFF1F1F1F1FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3F3FFFFF3FFFFFFFFF3F3FFFFFFFFFFFFE6E6FFFFCBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFF3F7F7FFFFFFFFFFF7F7FFF7F7
FFF5F5F5F5F1F5F1F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF3F7F7FFF7FFF7FFFFFFFFFFFFEEEEEEDED9FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFFFF7F3F7F7F3F7FF
FFF5F5FFF5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F3FFFFFFF7F7F7FFFFFFFFFFFFFFEEEEEEC2F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F3F3F3F7FFFFFFF7F7F7F7FFF7F7F5F5F5
F5F5F1F1F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
FFFFFFF7F7F7FFFFF7FFF7F7FFFFFFFFFFFFEEEEF7D1FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F3F7FFFFFFFFFFFFECF5FFF7F5F5FFF5FFF5F1
F5F5FFFFFFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFF7F7FF
FFFFF7F7F7F7F3F3FFFFF3F3FFFFFFFFFFFFEEEEF7D1FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F3F7FFFFFFFFFFFFFFFFECECEAF5F5F5F5FFFFF1F5
FFFFFFFFFFFFF7F7F3F3FFF7F7FFFFFFFFF7F7FFFFFFFFF7
F7FFF7F7F7FFFFF7FFF7FFF7FFFFFFFFFFFFEEE5E2D9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F3FFF3F7FFFFFFE3E3E3E3F7EAEAF2FFF5F5F5F5F5FFFF
FFF7F7FFFFFFFFFFF7F7F7F7F3F7F3F7F7FFF7F7F7FFFFF7
FFF3F7FFF3F3F3F7F3FFF7FFFFFFFFFFFFFFFFF3DEF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F3F7E3D9F7FFE3E3E3E3E3ECF7F5F5F5FFFFF5FFFFFFFFFF
FFF7F7F7F3F7F7F7FFF7FFF7F7FFF3FFFFFFF7F7F7F7F7FF
F7F3FFF7F3F3F3F3F7FFF3F7FFF7F7FFFFFFFFF7D1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7DAD9
F3F7D1D8E3E3E2EAF3EAEAF7FFF5F1F5F5F5FFFFFFFFFFFF
FFFFFFF3F7FFFFFFF7F3F7F7FFF7F3F7F7F7F7F7F7FFF7FF
F7F7F7F7F3F3F7F7F3F3F7F7FFF3F3FFFFFFF7E2D9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F3F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFDAE2
FFF7E3DADAE3F7F3F3EAF2FFFFF5F1F1F5FFFFFFFFFFFFFF
FFFFFFF7F7F7FFFFF7F3F7F7FFFFFFFFFFFFF7FFFFFFF3F3
FFF7FFF7FFF7F7F3FFFFF7FFFFF7F7FFFFFFE2E3F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFF7F7F3
E3E2F7FFFFF3F3F7FFFFF7F3F3F3F7FFF5F1F1F5FFFFFFFF
FFFFFFFFFFFFF7FFF3FFEEEEF7FFFFFFFFFFF7F7F7F7F7F3
F7FFFFF7FFF3FFF7F7F7FFFFFFFFFFFFFFFFE3D9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F7FFF7F3DACBD9
E3D9FFFFF7F7F7F3F7F3F7F7F7FFF7F3F3F7FFF1FFFFF5F5
FFFFF5F1F5F5F5F7F3FFEBE3F7F3F7FFFFFFFFFFFFFFF7F7
F7F3F7FFF7F7F3F7F7FFF7F7FFFFFFFFFFFFE3D9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F7F7FFF3D9D8E3
F3FFF7FFF7F7F7F7FFF7F7FFFFF7FFFFF7F7FFF5F1F5F5F5
F5F1ECF7F5F5F1FFFFF7F7F7F3F7F7F3F7FFFFFFFFFFFFF7
F7FFF3F7F3FFFFF3FFF3FFF7FFFFFFF7F7F7D6F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF3F7F7F7F7E2E3F3F3
FFF7FFF7F7FFFFFFF7F7FFF3F7F7FFFFF7F3F3F7FFF5F1F1
F5F7FFF7FFFFF5F1F5FFF7F3F7F7F3F7F7F7FFFFF7F7FFFF
F7F3FFFFF3FFF7F7FFF3F7FFFFFFFFF7F7F3DEF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F3FFFFFF
FFFFFFFFFFFFFFFFF7F7FFFFF7F7FFF3FFFFF7FFDAD9FFFF
F7F7FFFFFFFFFFFFF7F7FFF3F7F3F7FFFFFFFFF7F7FFFFFF
FFF7FFF3F3F3F3F7F5F1F5FFF7F3F7F7F3FFF7FFF7FFF3F7
F7F3F7F7F7F7F7F7FFF7FFFFFFFFFFFFFFE2E3F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F3FFFFFF
FFFFFFFFFFFFFFFFF3F3FFFFF7F7FFF3FFFFF7F7F7F7FFFF
FFFFFFFFFFFFFFFFF7F7FFF7F7F7F7FFFFFFFFFFF7F7F7F3
F7FFF7F7F7F7FFF3F7F7F5F5FFFFF7F3F3F7F3F7F3F7F7F7
FFFFFFF7FFF7F3F7FFFFF7F7F7FFFFFFF7EADEF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F7F7F7FF
FFFFFFFFFFFFFFF7FFF7F7F3FFFFF7F3F7F3F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7FFF7FFFFFFFFFFFFF7FFF7
F7F3F3FFF7F3FFF3F3F3FFF5F5FFF5F5FFF7F7F3FFFFF7F3
F7FFF7FFFFFFFFFFFFFFF7F7F7FFFFF7F7E3E2F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFF7F7FF
FFFFFFFFFFFFF7FFFFF7F3F7F7F7F7F7F7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFFFFFF7F7
FFFFF7FFF7F3FFF7FFFFF7FFF5F5F5F5FFF7F7F7F3F7FFFF
F3FFF7FFFFFFFFFFFFFFF7FFFFF7F7F7EBCEF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3FFFFFFFF
FFFFFFFFF7F3FFF7F3F3F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF3F7F7F7FFFFFFFF
FFFFF7F7F7F7FFF7FFFFF7FFFFF5F5F5F5FFF7F3F3FFF7FF
F7F7FFF7FFFFFFF7F7FFFFF3F7F7FFF3D6D1F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFF
FFFFFFFFF3F7FFF3FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFF7F7F7FFFF
FFFFFFFFFFFFFFF3F3F3FFFFFFFFF1F5F5FFFFF7F7F3F3E5
E5F3FFF7F7F7F7F7F3F7F3F7F7FFF3F7D9DAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F3F7FFFFFF
FFF7F3F3FFF7F3F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F3FFF7FFF7
F7FFFFFFFFFFFFF7FFF7FFFFFFFFF5F5FFFFFFF7F7F3F3E3
E3F7F3F7F7F3F7F7F7F7FFF7FFFFF3F7E2D9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F7FFFFFFFF
FFF3F7F3FFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F3F7F7F7
FFF7FFFFFFFFFFF7F7FFFFFFFFFFFFF5F1F5FFFFFFF7F7F3
F3FFE5E5F7F7F7F7F7FFFFF7F7F7F3FFECE2FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F3FFF7F7F7F7
F3F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F3F7FFF7
F3F3FFFFFFFFF7FFF3F7FFFFFFFFFFFFFFF5F5FFFFFFFFF7
FFF7E3E3FFF7F7F7F3FFF7F3F7F7F3FFECE2FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E2E2F7F7F7F7F7F7
F7F7F3F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F3FFFF
FFF7FFFFFFFFF3F3FFF3FFFFFFFFFFFFF5F1F5FFFFFFFFF7
FFF7F7FFE3E5F7F3F7F3F7FFF7FFF3FFDEF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEEC8DEE4F7F7FFFFF7F7
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7
FFF7FFFFFFFFF7FFF7F3FFFFFFFFF5F5F5F1F5F5F5FFFFF7
FFF3F7D9F5E3FFE5EEFFFFFFF7F7F7EECEF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEEC8BEBDE2F3F7FFF7F7F7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7
F7F7FFFFFFF7F7F3F3F3FFFFF5F5F1F1F5F5F1F5F5FFFFFF
F3F7F7DAD9FFF3EEEEF7F7FFF3FFF7E5D1F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFB38FBE8FF3F7FFF7F7F7F3
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F3
F7F7FFFFFFF7F7F3F3F3FFFFF5F5F5F5F5F5F5F1F5FFFFFF
F3F7F7FFF7F7FFF3F7F7F7F7FFF3F3E4F3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFDA67A1B188FFF3FFF3F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF7
F7F7FFFFFFFFF7FFFFF7FFFFFFFFF5F1F1F5F5F1F5FFFFFF
F3FFF3FFF7F3F7F7F7F7FFF7FFF7EED1D9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE38771EB839DF7F7F7FFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFF7
FFFFFFFFFFF7FFFFFFF7FFFFFFF5FFF5FFF1F5F1F5FFFFFF
F7F3FFF7F7F3FFF7F3EEF7F7FFFFE5D1D9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F79F68C7F19481E3DAF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFFF7FFF7F7FFF7
FFFFFFFFFFF7F7F7FFFFF7FFFFF5FFFFF5F1F5F1FFF5FFFF
FFFFF3F3F3FFF7F7F7F7EEFFFFFFF7DEF3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFB5494DA2E3BC758DDADAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF3F7FFFFF7F7F3F3F7F7F3F7FF
FFF7F7FFF7F7F7F3FFFFF7FFFFF5FFF5F5FFFFF5F5F5FFFF
FFFFF3F3F3FFFFFFF7FFF3F7ECECF7D6F7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF74EB5EBD6F75886E3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F3FFF7F7F7FFFFFFFFFFFFFF
FFF7FFF3F7F3F3F7FFF7FFFFF5FFFFF1F1FFFFFFF1F5FFFF
F7F3FFFFFFF7FFF7FFFFF7F3ECE3F7DEF7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7DA32F3DAEB5057D1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFF7F3F7FFFF
FFFFF7F3F3FFFFFFF7FFFFFFF1F1F5F5F5F5F1F1F5F5FFFF
F3F7FFFFFFFFF7F7F7F7F7F7F3FFFFD8F7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF3847FF3EC7D4DE2F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F3F7FFFFFFFFFFF7F7F3FFFF
F7F3F3F3F3FFFFF7FFFFF5F5F5FFF1FFFFF1FFFFF5FFFFFF
F3F7FFFFF7F7F7F7F7FFFFFFFFF3F7D1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAC56D6EB8F59C8F7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFF7F7F7F3
FFF3F7FFF7FFF7FFFFFFF5F5F5F5F5FFFFF1FFF5F5F5FFF7
FFF7F7F7FFFFFFF7F7F7F3F7F7F7FFD8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7BE61A0DEBE71C8F7FFF7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFF7F7FFFFF7FFF7
F7F3F7FFF7F7FFFFFFF5F1F1FFF5F5F5F5F1FFF5F5F5FFF7
FFF7FFF7F7FFF7F7FFF3F7F7F3F7F7E2DAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7EE648FF7A262ACFFFFF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F3F7F3FFFFFFFFFFF7FFF3F3F7F7FF
F7FFFFFFFFFFFFF5F5F5F1F5F5F5FFFFFFFFF5FFF5FFFFFF
F7F3F7F7FFF7F7F7FFF7FFF7F3F3F3F7D8F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7C84C69D0D650ACFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7FFF7F3F3FFFFFFF7F3F3F7FFFFFFFFF7
F7FFFFFFF5F5F5FFFFF5F5F5FFFFFFFFFFF7F7F5F5FFFFF7
F7FFF7F7F7FFF7FFFFFFF3F7FFF7F3FFECD8D9F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF37F83FFE58766F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7F7FFFFF7F7F7FFF7F7FFFFFFFFFFF7F7FF
FFFFFFF5FFFFFFFFF5F5F5FFFFFFFFFFFFF7FFF7FFFFFFF3
F3F7F3FFF3FFFFF3F3F7F3F7FFF3F7FFF7FFDEF3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7BC52C8EEAC73BEF7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFF7F7F7F3F7FFF3FFFFF5F5F5F2FFECF2
F7FFFFF5F5F1F5F5FFFFFFF7F7FFFFF7F3F7F3F3FFFFFFF7
FFF7F7FFF7F3F7F3F7F3F7FFFFF3F7F7FFF7E4F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF77787F5CE6FACF7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F3FFF3F7FFF3FFFFF5F5F5F2FFECF2
F7ECECFFFFF5F5FFFFFFFFF7F7FFF7FFF3FFF7F7F3F7FFFF
F7F3FFFFF7F7F3F3FFF7F7FFFFF3FFFFFFF7EAE3F3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEE58B1E56090F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD9E2FFF3F7F7F7FFFFF5F5FFF5ECF7FF
F5F7ECECE4ECF1F5F5FFFFF7F7FFF7F7F7F7FFFFF7F7FFFF
F7F7F3F3FFFFF7F3F7F7FFFFFFF7F7F7F7F7F7EADEE3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCE58D9985AF3F3F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDADAF3FFFFF3FFFFFFF5F5FFF2F2FFFF
F5FFF5ECE4FFF7EEEBFFFFF7FFF3F3F3F7FFFFFFF7F3F7FF
F7F7F7F7FFFFF7F3F7F3F7FFF7F3F7F7F7F7FFF7EAE2FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF876DDE5CACF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F7FFF3FFFFFFFFFFF5EAF3FFFF
FFF5FFF5FFECF7EEF2F7FFFFF7F3F3F3F7F7F7FFF7F7F3FF
F7F7FFFFFFFFFFFFF7FFF7F7F7F7FFF7F7FFF7F7EAD8DAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DAA457DE497EF7F3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE3E3FFFFFFF7F3EBE6EBF3F7FFF5F1F1F1FFF2F7FFFF
F5F5F1F1FFFFF5F5E4F7F2F2F3F7F7F7F3F7F7FFF7FFF7FF
F7F7FFFFFFFFFFFFFFF7F7F7FFF3FFF7FFF3F3FFFFF7E3DA
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E2
90B98E59AAFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF3F7FFF7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFE3E3FFFFEEEBF3F7FFECEAF1EAF2FFF5F1F5FFFFFFFF
F1F5F5F5F1F1F1F1F7E4FFF5F3F7F3F3F3FFFFFFFFF7F7FF
FFFFFFFFFFFFFFFFF5F5FFF3F3F7FFFFF7F7F7FFF7F7F7D1
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF78D
90CBDE38ECFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7F7F7FFFFF3F3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7EBEEFFECEAF1EAF3FFF7F7FFF5F1F1F1F1EAEA
F5FFFFFFFFFFFFFFF1ECECF7EBEBFFFFFFF7FFFFFFFFF7F3
F7FFFFFFFFFFFFFFF5F5FFF3F3F3F7FFFFF7FFF7FFFFF7E2
EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C87E
D6D16690FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFF3F7F7F3F3FFFFFFFFFFFFFFFFFFFFFF
FFF7EBEBF7F3FFF5F2F7EEEBEBEBF2F5FFF7EBEBF3F7F3F3
FFF7F7F7F7FFF7F7F5EAFFFFF7F7F7FFFFF7FFFFEEEEFFF7
F7FFFFFFFFFFFFF5F5FFFFF7FFFFF3FFFFF7F7FFF7F7F7EA
F7EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE28DA0
C7D100F3FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F3F7FFFFF7F7F7F7F3FFFFFFFFFFFFFFFFFFFFEE
EBF7F3F7F3ECEAE2EEEEE3E2E2EED1E2FFF7D6D1E4F2F3F7
F3F7F3F3F7F7F7F7FFF7F7FFFFFFFFF3F3FFFFF7F7EEFFF3
F7F3F7FFFFFFF5F5F1FFFFFFF7FFF3FFF7FFF7F7FFFFFFEC
F2FFEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EB99A3BA
C8CD1DFFF7F7FFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFF7F3F7FFFFF7F7FFFFF3FFFFFFFFFFFFF7F3EBEBEB
F7F3E3E4ECE2EBE3EAEAF3E4E5E3E2F7DEEECED8D8EBF7F3
C8C8E2E3F3EBF7F3F7F7F7FFFFFFFFF3F3FFFFF3F3FFFFF3
F7F3F7FFF5F5F5F1F5F5F5FFF7FFF3F7FFFFFFFFFFFFF7F7
E2E5EBEBEEF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7BD8FC8BE
EB7E66FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFF7F3F7F7F3F7F7F7F7F7FFFFFFFFF7F3EEF3FFFFF7
ECDEC7DAE5EAE2F3E3D8D8F7F3EEEED1F7ECDAEAF3D1DEEE
C4C4F5F7CEA4B3F7F7F7FFFFFFFFFFF7F7FFFFF7F7FFFFF7
F7F7F7FFF5FFF1F5FFF5F5FFF7FFF7FFFFFFFFF7F7FFF3F3
F7EAF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF78FBCC4DE
E269A8F7FFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFF7FFF7FFF3FFFFFFF3F3FFFFFFEEE6F3FFF7F3FFC7BD
D8F7E2E3F7DAF7F2F7DEDEF7F3F7F7F3D1EAD9ECF7D9DAF3
CED0FFEBD9DACEC8EEFFFFFFFFFFFFFFF7F7FFFFF7F7FFFF
F3F7F7FFFFF5F1FFF1F1F5FFFFF7F7FFFFFFFFF7F7FFF7F7
FFF2EAEBEEEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEBEB4CEB7EA
7A62D1F7FFFFFFFFFFFFFFFFF7F7F3F7F7FFFFFFFFFFFFFF
FFF7FFFFEEF3ECF1F1F2EEF7FFEEE6EEFFF7D9C47F3F99C1
C3E3EBE5DEECF1FFEAD9D6CBCBD1D8CECBEBF5E3FFFFFFEB
E2D8DEF1F7D9F7D9C4B2C8F7FFF7F3F7F3F3FFFFF7F7EEFF
F3FFFFFFFFF5F1F5FFFFF5F5FFFFFFFFFFFFFFF7F7FFFFFF
FFEAFFD6E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6A7E2B0A4E5
2CC8FFFFFFFFFFFFFFFFFFFFF7F7F7F7F3FFFFFFFFFFFFFF
F7FFFFEEF7FFF1FFFFE4F3FFEEE3F1D9A3A7E3EB996A61DA
EBD1D6E2E6E6E3F1E2F7FFFFFFF7F7F3E5F7F3F3CBD9E2D1
DEF5E2FFF1DEEEF7F3F5C7C5E2F7F7F7F7F7FFFFFFEEEEF7
FFF7FFFFF5F5F7F7FFFFFFF1FFFFFFFFFFFFFFF7F7FFF7F7
FFDEEEEAE3D1DAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA4B3DA93CA7B
5AF7FFFFFFFFFFFFFFFFFFFFF7F3F3FFF7FFFFFFFFFFFFFF
F7FFEEF7FFF5F5F7F2EAF7E2E2ECB54A8C9DD6CED1BDC8F7
FFF7F3F7FFFFEEEBEBFFFFFFFFFFF7F7D9E3ECE3FFE2E3E3
E3E5CDF2F7DAD9E2EEE4CEACD1ECF3FFEEFFF7F7FFEEEEF7
FFF7FFF5F5FFF7FFF7FFFFF5F5FFFFFFF7F7FFFFFFF7FFF7
FFE5E5F3D8DAE3D1DEEEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8AD1D69FF249
B3F7FFFFFFFFFFFFFFFFFFFFF3F7F3F7FFFFFFFFFFFFFFFF
F7F7F3FFF5F5EEF7F2ECE2D9CEADA3B55099E3F7FFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFF3FFF7FFF7FFFFFF
E3F3CAE2E2D1E3DEF7B9DAC4BFC7F5F3F3F3EBF3FFEEEEFF
F7F7FFF5F5FFFFF3F7F7FFF5F5FFFFFFF7F7FFFFFFF7F7FF
FFFFEAF3E3E3D1E3ECDEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6DACCED1BC3D
ECF7FFFFFFFFFFFFFFFFFFFFF3F7F7FFFFFFFFFFFFFFFFFF
F7F7F3FFF1EEEEEBF3EAC7B9B0CEF7BFADDEF3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF3F7F3F3F7FF
FFE4EBE2F3E3D1FFE2CBD8CDBDACC7E4EAF7F7F7FFFFFFFF
F7F7FFF5F5FFF7F7F7FFF7F5F1F5FFFFFFFFFFF7F7F7F7FF
FFFFECFFF7E3FFDAD8F2EEFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7F7F7F7F7FFFFFFFFFFFFFFEE62B0E4ECA94F
F7FFF7FFFFFFFFFFFFFFF7F7F7F7F3FFFFFFFFFFFFFFFFFF
F7EEF7F5F5E6FFF7D9BDAAC6D9EAE2B1BED9F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF3F7F7F7FFF7
FFECF3EEC2C4B5D1F5EBC1D6D9907ED9E4FFEBFFFFFFFFFF
F7F7FFF5F5F7FFF7F7FFFFF7F5F5FFFFFFFFFFF7F7F7F7FF
FFFFFFEAF7F3DAEEF7EBFFEEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7F7F7F7F7F7F7EEE6EEFFFFFFFFD683A8EAF3727B
FFF7F7FFFFFFFFFFFFFFF7F7F7FFF7FFFFFFFFFFFFFFFFFF
EBF7FFF1EEF7F7D1C4D0DAECF5D8D6A8EBEBF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F3F3F7F7F7F7FFF7
F7F7D8CBD9E2C899CDDEB4BCC6D06B87C7EAEBF3F7FFFFFF
FFF3FFFFF1F7FFF7FFF7FFF7F5F5FFFFF7F7FFF7F7FFFFF7
F7FFFFF7EABEB5D1D6D1F5FFEEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFEEE6EEFFFFEED6AC95B1EAC743C8
FFFFFFFFFFFFFFFFFFF7F7FFF3F3F7F7FFFFFFFFFFFFFFFF
E6F5F1F5E6F7F7A8EEE2DAECF2C3B3CEF5EBF7E6EEFFFFFF
FFFFFFFFFFFFF7F3F7FFFFFFFFFFFFF7EBEEEBF3F7F7F7FF
F3E2F7D9DAFFE3C2C2ABA34F7B5B68BE3D6AD0E4E3F7F7F7
FFF3FFF5F5F7F7FFFFFFF7F7FFF5F1F5F7F7F7F7F3F7F7F7
F7FFFFF5E2D1B07FADD1D1E5EBF7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBD09CAAC5F76E7BF7
F3F7FFFFFFFFFFFFFFF7FFF7F7F7F3F7F7FFFFFFFFFFFFFF
E6E2EEF7E3F7F7AAC2DFD1DAE3B4A8F2F1EEE3F5EBF7FFFF
F7F7FFFFFFFFEBF3F7FFFFFFFFFFEEF3F3F7F7F7FFF7F7F3
EBEADEE2DADAE3E2ECF7ECCE9AA28F4F898CDAE3E2EEEEF7
FFF3FFF5F5F3FFFFFFFFF7FFF7F5F1F5FFFFF7F7F3F7F7FF
FFFFFFF5EAD99995B9E3F3EAEAE2FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2AC6EACEAE33FC2F7
F3F7FFFFFFFFFFFFFFFFF3F3F7F7F3F7F7FFFFFFFFFFFFF7
E2DEE6F3EBEEEED9C3BCBAB5D6C5B7EAECF5F1F1F7EBEEFF
EBEBEEFFFFEEEEE6FFF7F3F7EEE6EEF7F7F3F7EEF7FFF7EB
E3F2E4EADAF7F7ECE2F3FFFFCBD8E299B9F7D0E3DADEFFF7
FFF3FFFFF1F7F7FFFFFFF7FFF7F5F5FFF7F7F7FFFFF3F7FF
FFFFFFFFF7EED1C8EBF3F7F3E6D0EEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE3CA8F7074C6D9C339F3DA
FFFFFFFFFFFFFFFFF7F3F7F3F7FFF7F7F7FFFFFFFFFFF7F7
EADEEEF7EBF3EAF1F5F5E2AD8EB0D1F3ECF5F5F5F5F5EEE6
EEFFEEE6E6EEFFEEEBFFF3F7DAEAF1F1F1ECF7F7F3F3F3EC
ECEBE2EBF3F7F7E2FFF7FFFFD9F5D9CEE2CDEECDD1C8EAF3
FFF3FFFFF1F7F7FFFFFFFFF3FFFFF1FFF7FFF7F7F7F7F7FF
FFFFFFFFFFF3F7ECEAFFF7FFF3EADAEEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFEED6B58478B5D8E2F7715DE2E3
F7FFFFFFFFFFF7F7F7F7F7F7F7F7F7F3F7FFFFFFFFFFF7F7
EADEFFE6FFF2ECEEEBEBEBF7ECDEE4EAF2FFF7F3EAF2FFFF
FFFFF5F5FFFFFFFFF7E5DEEEEAECF5FFF7EAE4EAEAECF5F5
EBFFECDAF7F7ECE2EBFFECECF3EBD2D0DAB7E2E3CFBFD0EB
FFF7F7FFF1F7F7FFFFFFFFF3FFFFF5F5F7F7F7F7FFF7F7FF
FFFFFFFFFFF3EAF5ECE4E2F7F7FFD6EEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFD699767DB9E2F7D9E43698F7F3
F3FFFFFFFFFFF7FFF7F3F7F7F7F7F3EBF7FFFFFFFFFFFFF7
E2DEFFE6F5F5F7F3F7F3F7F3F3F3EBEBEBE6F3FFFFF7F3F7
FFF7EAEAF7F7F7F7F3EAEAF7F1F1F1F5ECF3F3FFFFF2DEE6
F7F7F7E5EAEAE3EEEBF7E4DEEEEEF3CEE39DEEE5EAC7BEC8
F7F7FFF7F1F7F7FFFFFFFFF7F7FFF5F5F7F3FFF7FFFFF7F7
FFF7F7FFFFEAD9E6E6E6D0EBF7DAF7DEEEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF9361A8C7F7EBEEE6EE25C2F7FF
F7FFFFFFFFFFFFF7FFF7F7FFF3EEF7EBF7FFFFFFF7F7FFF7
EBD8FFE6F1F7F7F7F3F7FFFFFFFFFFFFFFFFF7F3F3F3F3EB
E6F3F7F3EBF3F7F7FFFFFFF7EAEAEAEAECF1F1EAF7EBFFF7
EBE6EBEEF3F3E3F3EEEBECE2EBEBFFC4FF9DE6E5D6D1C7B5
D1F7FFF7F1F7F7FFFFFFFFFFF3FFF1FFFFF7F7F7F7FFFFF3
F7FFF7FFFFE4E2DAFFFFD8F2D6FFD9DEEEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEEE6D63B9AD1E5D6D6E5E68F3BE3F7F7
FFFFFFFFFFFFF7F7F3FFF3F3FFF7F3EBFFFFFFFFF7FFF7F3
F3E3E3EEE2F3FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFD9E2F3F3E2E2F3F7FFFFFFF7F7FFEADEDEDEE3
D6D6EBF7FFEEEEFFF7E5EBEEEBEBD1D1F3A2C6E5D6D1ECD1
ACC8F7F3EAFFF3FFFFFFFFFFF3FFF1FFFFF3FFF7F7FFFFF7
FFF7FFFFFFECAC7662ADE2E2FFDEF3DEEBF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFD62CEEDAD6CEEAEAE56783FFFFF7
F7FFFFFFFFFFF7FFF7F7FFFFF7FFF7FFF7FFFFF7F7F7FFF7
F3FFE2EEDEECF7F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFDADAFFFFDADAFFF7F3F3F7FFF3EBFFF7F7ECEA
ECE4ECE4ECEBEBE6E6EBFFE3F5E4F7F3F3B6BDD6D6D8F7F7
E39CFFFFEAF5F7F7FFFFFFF7F7FFF1FFFFF7F7FFFFFFFFF7
F7FFFFFFFFEC9CA9A8ADF3E2EEEBE2F5F3F3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDECFAB4CECDEDFE3E3D2EE6796FFF7FF
F7FFFFFFFFFFF7F7F7F7F3F3F3F7FFFFF7FFFFF7F7F7F7FF
F3FFF1E6EEE2F3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7F3F7F7FFF7F3F3F7F7F7F7FF
FFEAF3F1F2E5EAFFECECF7E2E2D9D6DED6B5A4ABB5C4CAC4
D1A3F7FFF3F1F7F7FFFFFFF7F7FFF1FFFFF7F7FFFFFFFFF7
F7FFFFFFFFECB194E290A4DEE6EEEBEBF3F3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD8ADC86DFFC1EAEAD2FFD23CBEF7FFF7
FFF7F7FFF7F7F3F7FFF7F3F3F3F3F7F7FFFFFFF7F7F7F3F7
F3FFF5E3EEDEECEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFFFF7F7F7F7F7F7F7FFF7F3F3F7
FFF7F2F1F5F5F2F3F2F2F3F7FFFFEBEBDEBE9F9DA3B0CBE3
DED9EEF7F3F1F3F7F7FFFFF7FFF7F1FFF7FFF7FFFFFFFFF7
F7F7F7FFFFFFD289F7DA6B99F7F3FFF7F3F3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDE74B3B7847766555173AA3FF3F7F7FF
FFF7F7FFF7F7F3F3F7F7F7FFFFF7F7F7F7F7FFF7FFF7F7F7
F3FFFFF1EEEEF1EBF3F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFFFF7FFFFFFF7F7FFF7F7FFF7F7
FFF5F5F5F5FFFFFFF7F7FFF7F3F7F3EBF7EAEAFFF7F7EBDE
DEF2EAF3F3F1F7F7F3FFFFF3F7F7F1FFF3F7FFF7FFFFFFF7
F7F7F7F7F7FFD98ED8C1EA7BACF3FFF7F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDE5BC46B407CA4C2B4758977F7DADAFF
F7F7FFFFF7F7F7FFF7FFFFF7F7FFF7FFFFF7FFFFF7FFFFF3
EBFFFFF5F5EEE3EAFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F3FFFFFFFFF7F7FFF7F7FFF3FF
FFF5FFF5F7F3F7FFF7FFF3F3F7F3F7F3F7F7EEF7FFFFF3F7
F7ECECF3F7EAF7F7F3FFFFF7F7FFF1FFF3FFF3F3FFFFFFF7
F7FFFFF7FFF7DFA2F3D6CED1A8D1F7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD85CD92CE3FFF7FFEEECC4B5F7E2E2F7
F7F7FFF7FFF7F7FFF7FFFFF7F7FFFFF7F7FFFFFFFFF7FFF3
EBFFFFFFF1EEEEEAF7F3F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F7FFFFF7F3F7FFFFFFF7F3F7FF
FFF5F5FFF3F7FFF7F7F7FFFFF7F7FFFFFFFFF7F7FFFFF7F3
F7F7F3F7FFE4F7F7F7F7FFFFF3F5F5FFF7F7F7F7FFFFFFF7
F7FFFFF7FFF7DF8BD1BCDACBD1C4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEEC876877BFFFFF7F7F7EEECD9F7F3F3F7
FFF7F7F7F7F7FFF7FFFFFFF7F7FFFFFFFFFFFFFFFFFFF7F7
F7F7FFFFF5F5FFF1F3F7FFF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFF7F7F7F3F7F7FFFFFFF7F7FFF5
F1F5FFF7F7F7F7EBEBFFF7F7FFF7F7FFFFFFFFFFFFFFFFFF
F7F7FFFFFFE4FFF5F2F7FFF7F7F5F5F7F3F7FFFFFFFFFFF7
F7F7F7F7F7FFD97CF7A2CBF7F7D1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFDEC9AB84E2FFFFFFFFFFF3E3D9DAD9F3F7
F7FFF7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FF
F7F3FFFFFFF5F5F5ECF7F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFF7F7FFF7F7F3F7FFF7F3F7FFF5
F1F5FFF3FFFFFFEBF3F3F7F7F3F7F7F3F3F7F7F7FFFFFFFF
FFFFFFFFF7EAFFF1E4FFF7F7F5F5F1F7F7FFFFFFFFFFFFF3
FFF7FFF3F3F3E65AAD71A4EAD9E3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7D6DEBEF7F7FFFFFFFFFFF7F7F7E3D9F3F7
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FF
FFEEF3F7FFFFF5F5F1F7F7F7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFF7F7F7FFFFFFF7F3F7FFFFF5F1
F1ECF3F7FFFFF7F7FFFFFFFFFFFFFFFFFFF7FFFFF7FFFFFF
FFFFF7F7EAF5F5E3D9F3F7FFF5FFF5FFF3FFFFFFFFFFFFF7
F7FFF3F7F7F7DE47DA96A0ABD6FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE2E2D1F7FFFFFFFFFFFFFFF7F7F7FFD9DAFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
FFF7FFF3FFFFFFF5FFF5F3FFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFF7F7F7FFF5F5F5F5F5F5F5F5FF
F7FFF7FFEEEEF3FFFFFFFFFFFFFFFFFFFFFFF7F7F7F3F3F7
F7F7F7EEF2F1ECF2E3FFFFFFFFF1FFF7F7FFFFFFFFFFFFF7
FFF3FFF7F3F7D155FFBED19DD6EEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDEEAD1F7FFFFFFFFFFFFFFF3FFF3F7D9DAFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F7F3F3F7FFFFFFF5F5F1F7F7FFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF3FFF7F7F5FFFFF5F5F5F5F5F7F7
F3F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7F7F7F3FFFFF7F2F5FFFFFFF5ECF3F7FFFFFFFFFFFFFFF7
FFF3FFF7F3F7D648F7D1A9B7D6E6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDEEBD9F7FFFFFFFFFFFFFFEBF7F7F7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
FFF7F3F3F7FFFFF5F5F5F5F3FFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFDAD9F3F7F7F7F5FFF5F5F1F5FFFFFFF7FF
F7FFFFF7FFF7FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFF7
F7FFF3F3FFFFF5F1FFF5F5F5F1F7F3F7FFFFFFFFFFFFFFFF
F7F3FFFFF7F7D63BDECA7D6E578FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7EAEAF7FFFFFFFFFFFFF7EBEEF3F7F7F7FFF7
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3F7F7F7F7FFF5FFF5F1F7F7F7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFDAD9F7FFF7F7F5FFF1F1F5F5F2F3F7FFF3
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFF7
F7F7EEF7FFF5F5FFF5F5F1F5F5FFFFF3FFFFFFFFFFFFFFF7
F3F3FFF7F7F3CB42E4F3C9F79375FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7DAE2F3F7FFFFFFF7F7FFEBF7FFEBFFD9DAF7F7
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FFF7FFF3FFF5F5F1F1FFF3FFF3FFFFFFFFFFFFFFFFFF
FFF7F7FFF3F7F7F7F7F3F7F7F3FFF5F5F5FFF1EAFFF7F3F7
FFFFFFF3FFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFFFFFFFFF
FFEBF7F5F1F5FFFFFFF5FFF5FFFFF7F7FFFFFFFFFFF7F7F3
F7F3F7F7F7F7CB42E4F3E2D967A0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7DAD9FFFFFFFFFFF7FFEBEEF5F2F3FFD1CBFFF7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F3F7F3FFFFFFF1F1F5ECF7F3FFFFFFFFFFFFFFFFF7
F7F7F7FFF7F3FFFFF7F7F7F3F7F7F7ECFFFFF5F7F7F7F3F3
F7F7F3F7ECECFFFFF7F7FFF7F7FFF3F7F7F7F7F7F7FFF7F3
EBE3F1F5FFFFFFFFFFF1F1F1FFFFF7F3F7FFFFFFFFF3F3F7
F7FFF7FFF7F7C455CBB6CB9A69C4FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7F7FFFFFFFFFFF7F7F3FFF1EAF3F7D9D9FFF7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7F7F3F7F7F7FFFFF5FFFFF5F7EEF7FFFFFFFFFFFFFFF7
F7FFFFFFFFFFF7F7FFF7F7F3FFF7F7F3F5FFF5FFF7EBEBF7
EAEAFFFFECECFFFFF7F7FFF7F7FFF3EEEEF7FFFFF7F7F7F7
F7F1FFFFFFFFFFFFF5FFFFF5FFFFFFF7F7FFFFFFFFF7F7FF
F7F7F7F7F7E3BA75EAE3E34B93DAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF3F3FFFFFFFFFFFFFFF3F7F7FFF1F1EBF7F7F7FFF7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7F3F7F7FFF7F7FFFFF5FFF5FFEBF7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7F7FFFFF3FFF5F5FFF7F7F7EE
E3F5F3F7ECEAF7FFFFFFFFFFFFF7FFF3EBF7FFFFF3EEF3EC
F1F5FFFFFFFFFFFFF5FFF5FFFFFFFFF7F7FFFFFFFFFFFFFF
F7F7FFFFFFEBAA7AF7DECA7797B0E3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFF7EEF7FFFFF1EAEEE3D9F3F7F7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FFFFFFF7FFF3FFFFFFF5F5FFEBF7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFF7F7FFF1FFF7F7FFF7
EBE3EBFFF5EAF5ECFFFFFFFFFFF7FFF7F3F7FFF7F7F7FFF1
FFFFFFFFFFFFFFFFF5FFF1F5FFFFFFF7FFF7FFF7F7FFFFF7
F7FFFFFFFFF39C72FFDABC7F6F74C8E6EEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF3F3FFFFF5FFEAF7E2DAF3F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7F3F7FFF7F7F7FFFFFFFFFFF3F7F3F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F3F7FFFFF3FFF5F5FFF7F7F7
F7F7EBE3EBF3E3F5F7FFFFFFFFFFF3F7FFFFF7F7F7F5F1F5
FFFFF7F3F7FFFFFFF5FFF1F5FFFFFFF3F3F7F7F7FFF7FFF7
FFF7F7F7F7EE9F8EE3EBEEEEEC7A85C4DAEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFF7EEECF1F5F1F1F3FFFFF3F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7FFF3FFFFF7F7F3F7FFFFFFF7F7F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFF3FFFFF5F5F7F7F3
F3F7F7F7F7F7EBE3F2E4EAF3F7FFF7F3FFF7F7F7FFF1FFFF
FFF7FFF3F7FFFFFFFFF1F5F5FFFFFFF7F7F7F7F7FFF7F7F7
F7F7F7FFF7E5A199C9D1C8F7D6AC97ACBEDEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFEBF7E2EBFFF5F1EAE3F7FFFFF7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7FFF3F7F7F7F7F3F7FFFFFFFFF3F3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFF3FFFFF5F5FFFFF7
F7F3F3FFF7F7FFF3DEEAEAF3FFF7FFFFF3F7ECF1F1F5FFFF
F7FFFFF3F7FFFFFFFFF1F5F5F5F5FFFFFFF7F7F3F3FFF7F7
F7F3F3FFF3F7CAB08BADB49FB3D9B4C7A3B5E3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFF7EBF7F2DEE2EAF2ECDEE2F7FFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7FFF3F7F7F3EBFFFFF7F7FFF7EEFFF7FFFFFFFFFFF7
F7FFFFFFFFFFFFFFFFFFFFF7F7F7F3F3ECF1F1F5FFFFF7F7
F7FFFFF3F3F7FFF3EEF3ECE4F5F7F7F3F7F3F5F1F5FFFFFF
F3F3F3F7F7FFFFFFF5FFF5F5FFF5FFFFF7F7F7FFF7FFF7F7
F7F7F7F7F7ECD9F3E2C7DEC4C4C7D1BC8F6361AAEEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FFFFF7FFFFFFF3F3F3DEF7F3F7EAF3E2E3F3F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7F7FFFFF3EBF7F3FFFFF3F7F3F7F7FFFFFFFFFFF3
F3F7F7FFFFFFFFFFFFFFF7F7FFF3FFF5F5FFFFF7F7FFF3F7
F7F7F7FFFFF7F3F7FFE2ECFFE4FFF3FFF7F7F5F1F5FFFFF7
FFFFFFF7FFFFFFFFF5F5F5FFF5F5F5FFF7F7F7FFF3F3FFFF
F7F3F3F7FFDEE5F7EED9D1C6BD9BEAF1F5DFA9A3E6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3F3F7F7FFFFEEEBFFF5EAF7F3F3F1F3E2DADADAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7FFFFF7F7F7FFF7F7FFF7EBFFFFFFFFFFF7F3FF
FFFFF7FFFFF7F7FFF7F7F7F7FFF3F5F5FFFFF7F7F7F3F7FF
FFFFFFFFFFFFFFFFF7DEFFE3EAFFF3F7F7F5F5FFFFFFFFF7
FFFFF7FFFFFFFFFFF5F5F5F5F5FFF5FFFFFFF7F7F7F3F7F7
FFFFFFFFFFE3EBFFF7F7E3D8D19ABFEECE8F83B5EBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3F3FFFFEEE6EEFFF2ECF7F3FFF7EAEEFFF3E3E3F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7FFF7F7F7FFFFF7F7F7F3F7FFFFFFFFF7F3FF
F7F7F7FFF7FFFFF7F7FFF3F7F7F7F1FFF7F7F3FFFFFFFFFF
FFEEEEF7F7FFFFF7F7E4FFE2F3F7F7F3FFF1FFFFFFFFFFF7
FFF7FFFFFFF7F7FFF5F5F5F5F5F5FFFFFFF7F3F3FFF3F7F7
FFF7F7FFF7E5EBFFFFF7F7F7E3C487BD9086C6EBF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3F3FFEEE3F1E2DEEAF3F7FFF3F5EAE2E3F3F7F7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7FFF7F7F3FFF7FFF7FFF7F7F7F3FFFFFFFFFFF7FF
F7F7FFF7F7F7F7FFF7F3FFFFF3FFF5F5F7FFF7FFFFEEEBF3
F3F3F3F7F3F7F3F7ECECF5ECF7F3F7F7FFF1FFFFFFF7F7F7
FFF7F7F7FFF7F7FFF5F1F5F5F5F5F5F7F7F7F3F7F7F7F3F7
FFF7F7FFF7E5EBFFFFFFF7F7F7F7BCB090DAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FFF7FFE6F1FFEEF7F3F3F3F7F3F5EAE2E3F3F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE3E3FFE3E3FFFFFFFFFFFFFF
FFF7F7FFF7FFF3F7F3FFFFF7FFF7F7FFF7FFFFFFFFFFF7FF
FFF7F7F7FFF7F3F7F7F7FFF7F7FFF5F5F7F7FFF7F3F3F7F7
F3F3F7FFF7F7F7F7E4FFEAF7F7F7F3FFF5F5FFF7F7F7FFF3
FFF7F7F7FFFFFFFFF5F1FFF1FFFFF5F7F7FFF7FFF3FFFFF7
F7F7F7F7F3FFF3FFFFF7F7FFF7FFDECDCEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
FFF7FFF7EBF1F5F2F3F3F7FFEBF7F5EAF7F7F7FFF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE3E3FFE3E3FFFFFFFFFFFFFF
FFF7F7FFF7FFF3FFF7F7F7F7FFFFF3F7FFFFFFFFFFFFFFF7
F7FFFFFFFFF7F3F3F7FFFFF3FFF5F5FFF3FFEEEBF3F3F7F3
F7F7F7F7FFFFF7F5FFECE4FFF3F7F7FFF5F5FFF3F7F3F7F7
F7FFF7F3F7FFFFFFFFF5FFF1FFF5FFFFFFFFF3F3F7F7F7FF
F7F7F3F3F7E5E6F7F7FFF7FFF7F7EBD1EEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
FFF7FFF3F3F5F7ECF7F7E2EAF3F7F1F3FFFFF3F7FFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F3F7F7FFF3FFF7F7FFFFFFFFF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFF7F7F5F5FFF3FFEEEBF3F3F7F3
F2F5F7F3F7EAECEAEAECE3F3F7F3FFF5F1F5FFF7F7F7F3FF
F7FFF7F3F7FFFFFFFFF5FFF1F5FFFFFFF7F7F7FFFFF7FFF7
F7F7F3F3F7E5E6FFF7F3FFFFFFFFEBC2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F7F7FFEBF7FFEAF3EEECF7E2FFF3EAF7FFFFF3F7FFF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F3FFF3F7FFF7FFF7F3F3F7FFF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7F7F7FFF7F7FFF1F7F7FFF7F7FFFFF7F7
F5EAF3F7F7F2ECF7F7F7F7F7F3ECF5F1FFFFFFFFF7FFF7F3
F7F3F7FFFFFFFFFFF5F5F1FFFFFFFFF7FFFFF7F3F3F3FFFF
FFF7F7F7F7FFEBF7FFF3FFFFFFFFF3DEF3F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3
F7F7FFEBF7FFF5F5D9EEEAF3EBECEAFFF7F7F7FFF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F3FFF7F7F3F7F7F7F3F3F7FFF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F3FFF7FFF7F7F5F5F7F7FFF7F7FFF7FFF7
F7FFFFF3F3F7F7F3F3EEF3F7FFF5F5F1FFFFFFF7F3F7F7FF
F7F7FFF3F7FFFFF5F5F1F1FFFFFFFFF3F7FFFFF7F7F7FFFF
FFF7F7F3E5E5E6F7F7F3FFFFFFFFF7E2D1F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F7F7FFF3F3FFFFF1D6F7EAF3E3F1F3FFF7FFF3FFF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7
F3FFF3FFFFFFF3F7FFFFF7F7F7F7F3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFF3F7F3F3F7F1FFF7F7FFEEF3FFF7F7F3
F3F7F7F7F7F7F7FFFFF7F7FFFFF5F1FFF5FFF7FFF7F7F3F7
F3F7FFF3F7FFFFF5F1FFF5FFFFFFF7FFF7F3F3FFFFFFFFFF
FFF7F7F3E5E5EBF7F7F7FFF7F7FFFFF7D1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7EBFFFFF1E6E4E4F3E3F1F3F7F7F7F7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F7FF
F7F7F7F3F7F7FFFFFFFFFFFFFFF7FFF7FFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFF7FFF3F7F5FFF5F3FFFFEEF3FFFFFFF7
F7FFF7F7F7F7FFF7F7F7F7FFF5FFF5F5F5FFF7F7F3F7F3F7
F3F7F7FFFFFFFFFFF5FFF5FFFFFFF7F7F3F3F3FFFFFFFFFF
FFF7F7F3E5D9EBFFFFFFFFF7F7FFFFF3D8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F3
F7FFFFFFE6F5F1F5E6EAF2F7E3F1F3F7FFF3F7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F3F7F7F7F7F7F7FF
FFF3FFF7FFFFFFFFFFFFFFFFFFF7FFF7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3FFF3F5FFF5F7F7FFEEF7F7FFFFFF
FFF7F7EEEEEEFFF7F7F3FFFFF5FFF5FFFFFFF7F3F7F7F3FF
FFFFF7FFFFFFF5F1F5F5F5FFFFFFFFF7FFFFF7FFFFFFFFFF
FFFFFFF3E5D9EBFFF7F7FFF7F7FFFFF7D9D9F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBF3
EBFFFFF7EBF1F5F2E3ECF5EEE3EAF7FFF7F7FFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F3FFFFFFF7F7F3F7
F7F3F7F7F7FFFFFFFFFFFFFFF7F7F7F7F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFF3FFF1FFF7F7FFEBF7F3FFFFFF
F7F7FFEEEBEBFFFFFFF3FFFFF5FFF5FFFFF7FFF7F7F7F7FF
FFFFECF5F5F5F5F1F5FFFFF7F7FFFFF3F3F3F7F7FFFFFFFF
FFFFFFF3FFFFF7F3F7F3F7FFF7F7F7FFDAD9F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FF
E6FFEEEBF7F1F5F2D9F5F1F7DFE4FFF7F7F7F3F7FFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFF7FFF7F7F3F7F7F7F7F7FFFF
FFFFFFF7F7FFFFFFFFFFFFFFF7F7FFF3F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFF7F7F1FFF7F7FFF7EEFFF7FFFF
F3FFFFEEF7F7FFF7F3F7FFFFF1F1F1FFFFF7F7F7F7F7FFF7
F7F7F5F5F5FFF5F5FFF5FFF7FFF3F3FFFFF7F7F7FFFFFFFF
FFFFF7EEE3E3DFEBF3FFFFF7F7EEF7FFD9E3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7EEE3F5
EED6D6E4A98FA8CEE5ECF5ECD9EAFFF3F3FFF7F7FFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFF7FFFFF7F7F7FFFFFFFFFF
FFFFF7F3F7FFFFF7F7F7F7F7F3F3F7F3F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7F7F5F5F7F7F7EBEBFFF7FFFF
F7F3EBEBF7FFFFF7F7F7F7FFF1F5F5FFFFFFFFFFFFF7F7F7
F7F5F5F5F5F1F5F5F1F1FFFFF7F7F7FFFFF7FFFFFFFFFFFF
FFFFF7EEE3E3EEEBEBEBF7F3F7F3F7F3FFD6F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7E3FFF5
E3F2F3D1BCECF7C7D1E2F7E2D6F3FFF3F7F3F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7F7F7FFFFF7F7F7FFFFFFFFFF
F7F7F7F3F7FFFFF7F7F7F7F7F3F3F7F3F7F7FFF7F7FFFFFF
FFFFFFFFFFFFFFFFF7F3F7F3FFF5F5F3FFF7EEF3F7FFFFFF
FFFFF3EBF7FFFFFFF7FFF7FFF1F5F5FFFFFFFFFFFFFFFFF7
F7F5F5F5F5F1F5F5F5F5FFFFFFF3F3F3F7F7FFFFFFFFFFFF
FFFFFFF3FFE5C8E3F3EBF3F3F7F3F7F3F7E2E3F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6F1F1E3
E3DED087CADEECF7D9E6E3CAE4F3FFF7F7F7F7FFFFFFFFFF
FFFFFFF7F7FFFFFFFFF7FFF7F7F7F7F7FFF7F7FFFFFFF7F7
F7ECE3FFFFFFF7F7FFFFFFFFF7F3F3FFF7FFFFF7F7FFFFFF
FFFFFFFFFFFFFFF7FFF7FFF3F5F5FFF3EEEBF7FFFFFFFFFF
FFFFF3EEFFEEEEF7F3F7FFF5F5F5FFF5FFFFF5F5FFF5F5FF
F5F5F5F5F5FFFFF5FFFFFFFFFFF7FFF7FFFFFFFFFFFFFFFF
FFFFF7EEE5E5C5EAE3EEF7FFF7F7FFFFF7FFDEF3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6F5F7CF
ECD199E3B4F7D6D9E3EAEAB9D6EBF3F7F3F7F7FFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFF7F3F7FFFFFFFFF7F7E3E3FFF7FF
F3EAEAF3F3F7F3F3FFFFFFFFF7F3F3FFFFF7FFFFFFF7F7FF
FFFFFFFFFFFFFFF7FFF7FFF3F5F5F7F7EEEBF7F7F3F7FFFF
FFF7EEEBEEEEEEF3F7F7FFF5F1F5F5F5F5F5F1F1FFF1F1F5
FFFFFFFFFFFFFFF5FFFFF7F7FFFFF3F7F7FFFFFFFFFFFFFF
FFFFF7EBF5E3C4ECECF3F7F7FFF7F7FFF7F7D1F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F3F7F7E2F5EAC4
BDBCE6ACC4D1EBF7EBF7F2B4D6EBF3FFFFF7FFFFFFFFFFFF
F7F7FFFFFFFFFFFFFFFFFFFFF7F3F3F7F7F3F3D9D9F3F7F7
F7FFFFFFFFF7F7F7F3F7FFFFFFF7F3FFFFFFF7FFFFF7F7FF
FFFFFFFFFFF7F7F7F7FFFFF3F5F5F3FFFFEEF3F7F3FFF7F7
F7F3EBEBEEFFFFF7FFF7FFFFF5F5F5F5F1F5FFFFF5F1F5FF
F5F5FFFFFFF5F5F5FFF7FFF7FFFFF7FFF7FFFFFFFFFFFFFF
FFFFF7EBF5E3C4ECECF7F7F3FFF7FFF3F7FFD9E3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EBF3EBEAF1E2A4
BEBEBEFFA0F3FFF7E5D9EABDD6F3F7F7F7F7FFFFFFFFFFFF
F7F7FFFFFFFFFFF7F7FFF7F3F7FFFFF7F7FFFFFFFFF7F7F7
EEF3F3F7FFFFFFF5F1EAEAF7FFE2D9F7F7FFF7FFFFFFFFFF
FFFFFFFFFFF7F7F3FFFFF7F7F1F7F7FFF7F3F7FFFFF3F3F3
F7F7E6FFFFEEEEF7F7F7F7FFF5F1F5F1F1F5F5F5F5F1F5FF
F1F5F1F1F1FFFFFFF7FFF7FFF7F7F7FFF7FFFFFFFFEEEEFF
FFFFEBFFEEF3C4FFE4F7F7F7F3F3F7F7F7F7F7D8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFEBF1EAC38F
DA81F3DACEB4B5F3DECED9BDD6F3F7F7FFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFF7FFF3F7F7F7FFFFFFFFFFF7F7FFF7F3E3
E2F7F3F7FFFFFFF5F5FFF5EAE4F3D9F3F3FFF3F7FFFFFFFF
FFFFFFF7F7FFF7FFF7F7F7FFF1F7F7FFF7F7FFF7F7F3F7FF
F7F7F3EBEEEEEEF7F3FFF7FFFFF5F5F1F1F5F5F5F1FFFFF5
FFF5F5F5F5FFFFFFF7F7FFFFF7FFFFFFF7FFFFFFFFEEF7F7
FFFFEEE3F7F7CBF7E2D6E2F3F3E5EEF7F7F7F7DEF3F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBECFFEA9B9B
B5B986688FB9BEDABEECDA9CD6F3F7F7FFF7FFF7FFFFFFFF
F7F7FFFFF7F3D9D9F7F7F3FFF7F7F7FFFFFFF7FFD9DAFFD9
DAF7D6EAF7FFFFFFF1FFFFFFFFE3D8E2F3F7FFF3FFFFFFFF
FFFFFFF7F7F7FFFFF7F7F7FFF1FFF3F7F3F7FFF7FFF7FFF3
F7FFF3F7E6FFFFFFF7F7F7F7FFF5F5F5F5FFF5F5FFF5F5FF
F7F7F7F7FFFFFFFFFFFFFFF7F3F7F7F7FFFFFFFFFFFFEBEB
EEFFEEE3F7F7CBEBF3EBD6CBCBD0DAEBF7FFF7DEEBF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6F1F1F781BC
97D97BEB93D6D9BCBEFFDAADCBF3F7F7FFF7FFF7FFFFFFFF
F7FFF3F3F7FFE3ECF3EBEEF7F7F7E3D9F3F7E3DEEAE2D8D6
D6D8D9E2F2FFFFF5F5F5F5FFFFFFFFEAF7FFF7F7FFFFFFFF
FFFFFFFFFFF7F7F3FFFFF3F5F5F7F7F3FFFFF7EAE2ECF7FF
F7F7F3EBEEFFFFFFF7F3F7F7F3F3F3F7FFFFFFFFFFFFFFFF
F3F7F7F3FFFFFFFFFFF7F3F7F7F7F7F7FFFFFFEEEEFFEEE6
EEFFEEEBF7FFCBE6FFF7F2F5FFDFE2EEF7F7F7DEEBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E2FFF5F786BE
A89C9CB1D19D8FD1D1E4C7B1C3F3F7F7FFF7FFF7F7F7FFFF
FFF7F3F3F3F7FFF7F2BEA4C2D8D1DADEBEBDCEDFD9D9D9DF
DFD9EBEBD6E2EAF2FFF2F2FFFFFFFFF5ECE2DAF7FFFFFFFF
FFFFFFFFFFF7F7F3FFF7F7F5F5F3F7F7FFFFF7EADEEAF7F7
F7F7FFF7F3F7F7F3EBEBF7FFEEEEFFF7F3F3F3F7FFF7F7FF
F3FFF7F7FFFFFFFFFFF7F3F7F7FFFFF7FFFFFFEEEEEEEEFF
FFFFF7E2E3EED6E6FFF2FFF2FFE6EAECEEEBF3E4E6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBEAF5F5F39DB0
B06ADAA3B5B4D1DADAEEEA97C3F3F7F7F7F7F7F7F7FFF7FF
FFFFF7F3F3EEF3E2D1C2D189707D9CBDCBD0D6DEEAECFFFF
FFFFE6E6F2D6DEEBEEF3F7F3F3F3F2EAF2EAE3F7F3F7FFFF
FFFFFFFFFFF7F7F7F7F7F7F5F5F3F7F3F7F7F3EAEAF7FFFF
FFF7F7FFFFF3EBF3EBEBF7FFEEEEFFFFFFFFFFF3F7FFFFF7
F7F3F7FFFFFFFFFFFFFFFFF3F7FFF7FFFFFFFFFFFFEEEEE3
E3E3DAE3E2EED6EBF7F5F2F7F7F3EBF1F3EBFFF2DEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6F1F5F5F3A99C
DA83ECB1B1F2F1E6E4EEE582C4F7F7F7F7FFF7F7F7F7F7F7
F7F7F7FFFFF7F2EAE6D9A3C8FFEAC1C4EAD9FFDAE3E2C3CB
C3BDB4BDDEF7EACEDEEEF7F7F3F3E2ECF7F3FFFFF7F7FFFF
FFFFFFFFFFFFFFF7F7FFF3F5F5F3FFEEF3F7F3ECF5F5F5FF
F5F2ECE2F3F7EEFFEEEEEBF7EEEEFFF7F7FFEEE5F7F7FFF7
FFFFFFFFFFFFF5F5FFF7F3FFFFF7FFFFFFFFFFEEE6EEEEF5
E3E3E3F7F7EECEEEF7F7F3F7F3F7EBF5EAF3F3FFD8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EBF5FFF2F7BC8A
D09FEEE3D1D9DEF7E3E5EE6ECAF7FFF7FFF7FFFFFFF3F3FF
F7F7F3F3F3F7ECDED1EEDA99B5ECECDAD1D8D9ECBCACAAB0
A9978F9AA2A0BED1EAE3E5E5E2E3EEDEDEE2EAF7F7F7FFFF
FFFFFFFFFFFFF7FFF7FFF3FFF1F3FFEBF7F7F7F3F5FFFFF1
F5EAEAECFFEEEEEEEEEEEBF7EEEEFFF7F7FFEEEEF7F7EBDF
EBF7FFFFFFFFF5F5FFF7F3F7F3FFFFFFFFFFEEFFE6EEE6E6
FFFFFFE3E3EECEEBF7F5ECF7F7F3F3F5F2EBF3FFD8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EAF5F1EAF3CA5C
C8B5CBDEE3D6FFEAEAD6EB7CC1F3F7F7F7F7F7FFFFF3F3FF
F7FFFFFFFFF3FFFFECD9E3E59AB1CEE3A3D9D8EC97D9BC8A
7EC8B2ACDEF3D8B5E3ECE2D9DED9C4BEBDC6D9F3FFF3FFFF
FFFFFFFFFFFFF7FFF7FFF3FFF1F3FFF3FFF7ECE4FFFFF5FF
FFF2ECEEE6EEF7F3F3F3F3F3F3F3F3F3F3F7FFFFF7F7EEEB
F7E3EBF3F7FFFFFFFFFFFFF7F7FFFFFFEEEEEEFFE6EEE6EB
E3FFFFE3E3EED6DEEAEAEAFFFFEBF7F1F7EBF7F7D8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DEF1F1EAEBD63B
CBCBD6F5D9EEFFECFFECDF7CD8D9F7F7F7F7FFF3F7F3F3FF
FFF7FFF7F7F3F7F7FFC4EBEEE5B59776F598AAD283E297DA
6D8FFFB8B6EBD1E2C4F3EEEBF2D6E2FFEBDED2EAF7FFF7FF
FFFFFFFFFFFFFFF7F7FFF3FFF1F7F7F7F3F7E3E4FFECF3F7
F5EADAEEF7F3F7FFFFF5F1F5ECECFFFFFFF7F3F7F7F7F7F7
EEEBF7FFF7F3F7F7F7F7F3F7FFF7F7FFEEEEFFEEE6EEE6EB
FFE3FFFFFFE6DEE5F2F7F7F7FFEEE6E2F3F3F7F7D8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F3F3EBE2EBDED9EBF752
8FC8DEF7E2EBF7FFE4E5EB5CE2E2FFF7FFFFF7FFF7F7F7F3
F7F7FFF7F7F7FFF7FFD9E2F7EEE3EEE29AADD088A2C9A0AF
A476FFCAADD9EBEBABF5EAE3D1E5CBD1C2C4D0ECF7FFF7FF
FFFFFFFFFFFFFFFFF3FFF7F7F1FFF3F7F3F7ECEAECF7FFF7
ECF2EBF7F7FFFFFFFFF2EAF5ECE3F3F7F7F7FFF7F7F7FFFF
F7FFFFEEEEF7F7F7F7F7F3F7FFEBEBEEEEEEE6EBF7EEFFFF
EBDEFFFFEEEEC9F2ECECFFF3F7E2D8DAF7EBF7FFD8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE29CADF2E3DEFFDEF5F79D
7AD1E3E6E2F3EADEDACEEC68E4FFF7F7F7F7F7FFFFF7F7F7
F7F7FFFFFFF7FFF3F3EEE3E2FFF7D2B0A4B5817AB3F5C6BA
AC7EECD8C2C7DEEAB2DEE5D8EBCBBFD6F3E4F3FFFFF3FFFF
FFFFFFFFFFFFF7F7F3FFF7F7F1F7F7F3FFECECF7F7FFEECE
B2A8C2D1F3F7FFF7F3EEEBDFDFD1D1D1D9D2CAE3F3F3F7F7
F7FFFFE6EEE5F3F3F3F3F3F7FFEEEEEEF7EBEEF7EEF7FFFF
E6EEFFEEF7EAC9F5F2EAFFF7FFDEEAF7FFEBF3F7D8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF75E7277DECEE3FFE6F1FFC4
6AA9F3E2E3EBE2EBDFDECE77E4F7F3F7F7F7F7FFFFF7F7F7
F7F7FFF7F7F7F7FFFFF3F7ECE3F7DAEAECD1D9B3B1D1D1E5
CEB0E3DED2DEEECEC5C9E2EAE2EBE2EAEBEAF7F7FFF3FFFF
FFFFFFFFFFFFF7F7F3FFF7F7F1F3FFF3ECF7F5F3F7F7EBBC
E4CFB4A3D6DFDFE3E6E2DEDEDED1DFDFD1D1DAD9DEE6E6E6
E6E6EEEEE6F7EBEEFFFFFFFFFFFFEEE6EBFFF7EEF7EBFFFF
EEEEEEE6F7DED8F7F3EAFFECE2D1E2FFF7F7FFF7D1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFB51BC847EBD6E3F7E2ECF7EC
607CEEDEEBFFE6E3D6EACB70E4F7F7F7F7F7FFFFFFFFFFF7
F7F7FFF7F7FFFFFFFFF3FFF7ECEAF5E3EAE3DECEB8A2C8D6
CB939DBCC8EEE6BDE2DED8F3E3ECE4E3E3FFF5F7F7F3FFFF
FFFFFFFFFFFFFFF7F7FFF7F7F1F3FFF3ECF7F5F2F2F3F7B3
DAF7F1B8E3ECF7ECE2DEE3DED1D6EAEAECF5E3D9C3C9DEE4
ECFFEEE6E6F3F3EEE6EEFFF7F7F7F7EEF7FFF7FFEEEEEEEE
E6EEEEE6FFDECEF3FFEAEAECE3B0F3FFEBF3F7F7D1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7EB8F4B7BC239E5EEDADEDAF7F7FF
6262DFDEF3DEF5EBE3E4CB70E4FFF3F7FFFFFFFFFFF7F3F7
FFF7FFFFFFFFFFFFFFF7F3F7F7F7ECF2E3EACECAD190D9AA
B8CABFCEBACED6B3D8D1D1F7ECECC4D9F5F1F1F7F7F7F7FF
FFFFFFFFFFFFFFF7F7FFF7F7F1F3FFF3FFE4FFF5F5F7F7E2
BEC3E5C4E2E3EBDED1CEC4B1BDC2B5B1BAE3FFF5F7D9BDC4
C7E4E4E4E4E3E3EAF7EEE6EBEBEBEBF7F7F7F3EBFFEEEEE6
EEEEE6EEECEABEEEF3EBEBF3F3B6EBF3F3F3EEEBDEF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7906BA3E5DF2DD9F7EBE6F7EBFFF5
696EC8EAF3D8F1EEEBEACB70E4F7F7F7FFFFF7F7F7F7EEF7
F3FFF7F3F7FFFFFFFFFFFFF3FFF7F3ECF5E5DEF2F5B1B0BE
BEE2C7BCE5E3E6C5EBEBEEF3FFDACEF5F5FFF5F3FFFFF3FF
FFFFFFFFFFFFFFF7F7FFFFF3F1F3F7F7FFE4FFF7F2F5F3F7
EBDADECEC9EBF7F7CE90D9D2DED6DEEEE5BCB5E5F2DAF3F3
C8CAE2F3F3E3E3D9D1DEEAF1EAECFFF3F7F3F3F7FFEEEEEE
FFEEEEFFE4E3C2F7EAECF7F3E3ADDEFFF7F3EBEBD8F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7BF5B9AECEEEB33D6EEEEFFEBF7FFEA
7D8FD9EAEAEBF7ECE5D9C477E4F7F3FFFFFFF3F7F7EBF7F7
F7F3FFF3FFF7FFF7F7FFFFF7F7FFFFF7ECE3F3EAECEBE3F7
D1C8DECFCDCACBD1F3FFF3F5D6D1F7F1F5F5FFF3FFFFF3FF
FFFFFFFFFFFFF7FFF7FFF7F7F1F3F7F7FFE4FFF3EAF5F7F7
F7F7C8F2BEC8EBDEA0CAB5A8B5B5B1C8ECD9F5BFC9EBEEEE
DABFD1EAEADEDEDEE2EEEEF7EAEAF7EEEBEEEEE6EEFFEEE6
FFFFE6ECE3DED9FFEAE2F7F7F797E2F7F7EEEEEBE3DAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFB5586BE3F7EEF76A61DAEEE6D1D8D1B3
7BD0EAECE5EBF7ECEED6C47DDEFFFFF3F3F3FFF3F3E6ECD8
D6EAEEF3FFFFF7F7FFF3F7FFF7F3F3F7F7EAE2EAEAE4F2FF
F3DAD1E2EAE3E2D6D8CBBECAE3F7FFF1FFF7F3F7FFF7F7FF
FFFFFFFFFFFFF3F3F3FFF7F7F1F3FFF3FFE4FFF7F7FFF5EC
EEFFF3C6CEECAA98B3ABB562B0DED6D6C7E5EBEBDEE3F2D8
D2E3AA8EA4B2BDD9D9E5E3D9E2EBEBF7E6EEFFFFEEE6E6EE
EEF7EBDEEEC6D0DEEAE4DAC4DA9DE2F3F7EBFFEEEAD9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE3768AEBEBF3DADAE5687DD9F1C4D1CAA2
A9F1E2EBE6E2F5F5E6D6CE6DDAF7F7FFFFF7F7FFF7EEDADE
E3DAEAFFF7FFF7FFF7F3F7FFFFF7F7F7F7FFF7F3F7FFF5F1
ECF3EBE6EBE2E2EEF3F7FFFFFFF5F1F5FFF3FFF7F3FFF7FF
FFFFFFFFFFFFF7FFF7FFFFF3F1F7F7F7F3F2F5FFECEAFFFF
ECEBEBF7ECD9CECEE297D94EB6D8C4EAD9F7EEEBC1F5E5C4
D1EAECECEBF3EBD9C8E3EAE2E2F3F7FFEEEEEEEEEEFFFFE6
FFF7EBD8D9C4EEFFF7EAC7ECC49DE2F3EBE3ECEEEAD9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7C46DCBEAE3E3DAFFDABD44619CA3ADA9B5
D9F3F3EBFFEAF7F2D6CBDE68E3F7F7FFFFF7F7FFF7FFEBD1
DAE3DAE4ECF7F7FFFFFFFFFFFFF7F7FFF3FFFFFFF3FFF5F5
F5F5FFFFF7F3F3F7FFFFFFFFFFF5F5FFF7F7FFF7F7F7F7FF
FFFFFFFFFFFFFFF3FFFFF7F7F1FFF3F7F3F7F1FFECF2F2F2
F5E2EAE3E2ECEAC8ADECBE77BDDEC8CFDAEEDED6C1E3C8B3
EBDADFD2D6D6B9BCDAEAEAEAF7E3F7F7FFFFEEEEFFE6E6FF
E6EEEED8C4D6F7F3ECE2D8E4DA6DF3F3E6ECECEEE2DAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF3946ED9ECEAEBD6FFDAD9EE7D6FA0C4D1E5
D6DEE3EEEBF2F7F7D1D6BC88E4FFF7FFF7F3F7FFF7F7F7F7
D0EEE3F3E3ECF7F7FFFFFFFFFFFFFFFFF7F7FFFFF7F3ECF5
F5F5FFFFFFFFFFFFFFFFFFFFF5F5F1FFF3FFFFFFF7F3F7FF
FFFFFFFFFFFFF7FFF7FFF3FFF1FFF3F3FFF7EAECF5F5F7F7
F7F7ECE2F7EBD6ECD6B5D1C4B3EAEBD1E4EBDAD1DAB9C6EE
EED1EAF5E5C8C7E5F7F5F5F3E2EAF7F3EBF7EEEEEEFFFFEE
EEEEFFD1B4D9F3F7E5C7E3E4EE62EBFFEBECECFFC4F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF76D86F7ECFFEABDDAFFF7D9D1D18ACFF3DE
D9F1E3E3D8FFFFF5DED6B783ECFFF7FFF3FFF7F3FFF7F3F7
EADAF7EBF7EAE2EEF7FFFFFFFFFFFFFFFFF7F7FFFFFFEAF5
F5F5FFFFFFFFFFFFF7F7F7F7F5F5F1FFF7F7FFFFFFF7F7FF
FFFFFFFFFFF7FFFFF7FFF3FFF5F5F7EEF7FFECF7F5F5F5F7
F7F7F3F5E3F7DAD6EBC4ACA7936E83BCECF1F3D6C6DFE2DE
D9B5E3E3D1E2ECF2F7EAEAFFEEF7F3F3EBFFF3F7EEFFFFEE
EEEEECBCC1E6EEDEEBECECD6FF67DFF3EBF5ECFFC4F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF75BA9EBEBF5F7D2FFF7EBEEF7D9B5ECEEE5
FFF5F7D9D9F7F5F5EEBDD868F7FFF7FFF7F7F3F7F7F7FFF3
F7ECD6EBEEF7F5DEDAF3F3F7FFFFFFFFF7F3FFF7FFFFECF2
F5F5FFFFFFFFFFF7F7F7F7F3EBF7F5F5FFF3F7F7FFF7F7FF
FFFFFFFFFFF7FFF7FFF7F7FFF5F5F7FFE6F3F5F3EAECECF7
FFFFFFEAF7E3F7F7EED9D6D9DFD9C7D6DAF5CDC4BDD6CEC1
AFDEEACEEAEBF7EAEAEAF7F3F7EBF7F7E6F7F3EBE6FFEEFF
E6FFDEBDDEE6ECF7F5ECF5DEEE55EBEEF3F5ECF7CBF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE253C1EEEEF5ECCBFFE3F3DAEAE3E5EBF7EA
ECF7F3EAF7F2F2ECEEBDC189EAF7F7F3F3FFF7F7F7F7FFF7
F3EED9EBF3F3E5E6D1E2F7F3FFFFFFFFF7F3E3E2ECECECEA
ECF3F3F3EBE6E6D9DED6CBD1D9E5F3ECF5F7FFF7FFF7F7F7
F7FFFFFFFFF7F7FFFFF7F3F7F1FFF3F7EBEBF7DEE4ECECF7
FFFFFFF7ECEAF3E5FFE3BFC3C9E5D1CBB5D6CEDEA0ADB0DA
FFECDAF7F3E3EAECFFF7F7F7F3F3F3F7E6EEEEE6EEEEEEEE
EEFFD1C4D6DAECE5D6DADFDAF141FFF3ECECE4F3D1F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA855E3F7F3EAF5CBE5DADACED9F3F3E3F3DE
EBEEF7F7DEE2F3E4DFD1C488E4F7F7F3F3F7FFF7F7F7FFFF
FFF7E3E2EAF7CED8D0B0A3A39C9C909797908F837C7C6877
838A90979D9D97B8D2D6EBF3E2CED9EEECF5F7F7FFF7F7F7
F7FFFFF7F7F3FFFFFFFFF7F7F1FFF3FFF7F7FFECEAEAEAF7
F7F3F7F7F7F3F7E3FFF3EBE6D6C4C2CBAD97B4CEE5BCBCFF
FFEEE3E4E2EAF3F3EBEBF3F3F3F3F3F7FFEEEEFFEEE6FFEE
FFE3B5B5DAE4F7DEE5E6FFE3DE4DE3EAE4FFE4EBD1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF907FE2FFE3DFD2E3EED2D2EBFFFFFFE6EEF2
D9F7F7F7CBDEEAEAD6D1CE89E2F7F7FFFFFFF7FFF7F7FFFF
FFF7FFEEEAE2BECAF2F3EAEAEAF7ECF3D9D1E2EBEEF7EEF7
F7F3EEF7FFF3EBEAECECDEE3EEEBDEEBF7F1F7F7FFF7FFF7
FFF7F7F3F7F7FFFFFFFFF3FFF1FFF3FFEBF7FFF7EAFFF5EA
F5F3FFEBFFF7F3F7F3FFFFFFFFFFE6FFFFD8F7F7F7F7F3F7
E5D9EAF7FFF7F7F3F7E6EEEEFFFFEEF7F7EEEEEEEEFFEEEE
FFD8B7D2ECECEAF7D0EBECE3AA6FD8EAEAFFE4E6D8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9789D9E3E5FFFFEAEAEEEBE3E6EEFFDEF5F3
DEF7F7FFD1ECD6DEDED6BA96DEF7FFF3F7FFF3F7FFF7F7FF
FFF7F7F7F7F7E2D1CEDADAD9D9C4D8F7DAD8D8D9E6F3F3FF
E2ECF7F7FFF3F3FFECFFD6D1EEF7D8EBF5F5EBF7FFF3F7F7
FFF7FFFFF7FFFFFFFFFFF7F7F1FFF7F7EBF7F7ECF5EAE4F5
ECEAF7EBF3F7F7EEEEF7FFFFF7F3F3F3F7DEE3DEE2EAD8CB
D6ECF3F7F7F7EBEEEEE6FFFFEEEEFFF3F3EEEEFFFFE6EEEE
E5CFB4CEE3F7E5EED0EBECEC8990DEF2E2EEEADFD8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF977DEAE5EBF7FFECECEBE5F5FFEEE6E2F2DE
DEF3FFF7F7CBFFEEEEE4C48FCEF7FFF3F7FFF3F7FFF7F7FF
FFFFFFFFF7F3F7ECDEB0E2DEE2DEE3F7F7EEFFDECFECD9DE
F7FFE4E4E4E3F7ECE4E3EBF3FFEAC7EAF5F7F3FFF7F3FFFF
FFF7FFF7F3FFFFFFFFFFF7FFECF5FFE3EBF3E3E2E6E3DFDF
EBEAEAFFF7F7EEF7F7FFF3F7F3EBF3F3EEDEDEEEE2DEF7F3
F3F7F3E6E6EEE6FFEEFFEEEEEEE6FFF3F3E6EEFFFFE6EEEE
CECEBAD6F7F7FFD6DED9ECFF61B9EAD9E2EAEAD9D8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA36FF5EAF3F3FFFFFFF7ECF5F7F7FFF1E3C5
EBEAFFFFF7DEEEECE4DADE8FD2EAECF7FFF7FFF7F7FFFFFF
FFFFFFFFFFFFF7F3F7B5B7C4BECECABEE3F5D1D1B3B7C9D6
D1BCD9D9CBC1BECAD9CED1D6D1CDDAF3F3F7F7FFFFF7FFFF
FFF3F3F7FFF7FFFFFFFFF3F3EAF5FFE3EBF7EAE6EAE2DED9
DEDED1E4ECF7F7F3F7F7F7F3F7F7F7F7F3EBEEF7FFFFEEEE
EEF7F7FFEEFFFFEEFFEEFFFFEEE6FFF7EBE6FFE6E6FFEEEE
D8B4CEE4E3E2E2E3CFEAF5C55AF3DED9E2EAE2EEC8DAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFBD60EBD9EBF7FFFFF5F2E4EAE3F7EEF5D2D2
F5E4FFFFF7ECDEE4EEEEF78ECAECECFFF3F7F7F7F7FFFFFF
FFFFFFFFFFFFFFFFF7F7E2E2E2C5DEF3C5BDCEE3E2D1D2B9
D2EBC4BDD9D2C3C3C3C1CBD1DEEAF7F7F7F7FFFFF7FFF7F7
F7FFFFFFFFFFF7FFFFFFF7F7EAF1F5F7EEEEEAD9EAF7F3EE
DFD6CED1E2E3F7FFF3FFF7FFF7F7FFFFFFF3F7F7F7FFFFFF
EEEEEEEEFFFFFFFFEEEEFFFFFFFFEEFFF7F7EEEEFFEEEEEE
B9B9D6DAD9E2EAF3E2E3D19386ECF5F3F7F3E3F5C787F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCB6FCDDADEECFFF7EAEAEAE4DAFFEEFFD1E6
EAE4ECECFFF3E3CDC8E5DE97D2E3ECFFF7F7F7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFD9D9F3EADEDEDED8CACAE2EBEB
CAC4EEF3DED8EBEBDEEAE2F7FFF7F7F3F3F7FFF7FFFFF7F7
F3F3F3F3F7FFF7FFFFFFFFF7F7F5FFF5F3F7E3CEE2F7EBF3
F7F7EBD1D9DAE2EAEEF7FFF7F7F3F7F7F7F3F7F7F7FFFFFF
FFFFFFFFFFFFFFFFEEEEFFEEE6EEFFEEF7F7EEFFE6EBF7D6
B0CAD6E6EAE2E5ECECC3EC96A2E2F3DEF3F3E5F78F4EE2FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD96DC4F5C1E3EBF3E4F1ECE4DAEEFFFFDEF7
DAFFFFF5EAEAE2DED6D6E29FD9D9EAF7FFFFF7FFF7FFFFFF
FFFFFFFFFFFFFFFFFFFFF7F3F3F3F3F7FFDADADADAFFDADA
FFFFDAD9F7FFDAF7E3DADAF7F3F7F7FFFFF3F7FFFFFFF7F7
F3F7FFFFF3F7FFFFFFFFFFF7F7F5F5F5ECEAE2C8C4CECED6
EEFFFFE5BCA29C9D9696B0E2F3EEF3F3F3F3F7FFFFFFEEEE
FFEEEEFFEEEEFFEEFFFFEBF3F7EBEBE6FFEEFFFFE6EBFFB9
AABEDAE3FFF1FFECECD1F59DB0F7F3DAF7F7E2D97B55A8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEB68CAEBD2F2E3EEEAF2FFE4F7F5F5EBD6E6
EED6ECF2E2FFE6FFE4E6F3A9E5D2F1F3FFFFF3F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE3E3FFFFFFFFFFFFF7FFF7FFFFFFF7FFF7
F3F7FFFFF7FFFFFFFFFFFFFFF3F7F3F7F5F5F2D9E2CECED1
D1EBF3DEFFEED6CBC4C2AAA8CAD9EEFFFFF7F7FFFFFFEEFF
EEEEFFEEE6E6F7EBEBD9E3E2DEE3FFEBEEFFFFEEFFFFF3B7
B0D1DEFFF5FFEAE3D9F7F3C1ADD8D9EEF3F3F3D6887C8BE3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEB7AB7F5C8DAF2F7F1F3ECECF1F1F5EBE5D6
FFD6ECE3EEEBEEFFEADEF7A9D8E5DAECF7F7F7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF7F7FF
F7FFFFFFFFF7FFFFFFFFFFFFF3F7F3F7F7F7F3E2EAEBD6C5
B9B9D6D1DEDAE6EEFFEED6B397839CBDD6E5F7FFFFEEEEEE
EEFFEBF3F3F7EBF7CFD8DEC9E2E3E3EBFFEEEEEEFFEEF7AD
B0C5F5EEF1F5E4CBFFF7E6C2B4BCECEEE5EEF7BDB7AA9FB5
E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF776A3E6DED9E6EBFFEAEAEAF5F5FFFFFFD1
F7EBDEFFF1D8FFECD9E3ECA8DEEEE3F5EAF7F7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
FFF3F3F3F7F7FFFFFFFFFFFFF7F3F7F7F7F3F7ECF5F5F5EE
E3CEBCC8E3D6D1D1E6EEFFEEEEDAB3ADA8AACBD6E6EEEEE6
EBEBEBF3E2DEE4CDD0E3E3FFD6D9D9EEFFE6E6FFEEEBF795
C1DEFFD0EBFFF7D6EEEBF7B2D6BAE6EBF7F3EEADD9C4CE9D
E2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF759CE6E6E4FFE3EEF1F7F7F5ECECFFFFDE
EBF7D9EAEEF5EBE3DAEBEAC2CDEBD9FFE4FFF7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFF
F3FFFFFFF3F7F7F7FFFFFFF7F7FFF7F7F7F7F7EAE4F2F5F5
F7F3DABEC4D8D6C4BEBDD6EEFFFFEEDADEB5CAC9C3D1D8DE
E2E2D6CBCDD8D8E3FFFFFFDAD0E2F7EEE6FFEEEEE6F3E286
CEF7D6F2D0DEDEF7F3EBEEC2CFC1EAEBD9CAC5A9F2C4D68F
EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8A8AEEFFDAECEEEBF2E2F5F7F7ECFFFFEC
DAEEEBEBE2FFD9DEECDFEADFB6F5D9F7E4FFF7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFF7
F7FFFFFFF3F7F7F7FFFFFFF7F7F7F7FFF7F3F7FFFFF3FFF5
F5FFF7E5CECADAEAECE3C7CED6E6EEEEE6D1D1D9D6D1D6E2
C2BDD0D8EBFFF5F2F7ECDEC7E2FFEEEEE6EEEEF7F3FFDE90
D1DADAEAEBD6D6E2ECEAEBDFD1ACC4C1BECAC5D9EAD1BE9B
EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF908FEEE6EED6EBF3DEEAEAF7EBF5F5FFFF
E4E6F3EBEAD6ECEAEBE5F2DEBCECE6F3EAF7F3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F3
F7F3F3F7F7FFFFFFFFFFFFFFFFF7F7FFFFFFFFF7F7F3FFFF
F5F1F5F7F7EECECACFDED0DFD1DED6D6E6EEECECF7F7EEDE
F2E5EEEEE6E5DAF2E3DAD9ECEBFFEEFFFFEEF7EEF7F3DE8F
C5D6F7EAF5F7F7FFF2EAF2DAE5CEEAE2E2D9EEEEEBCE82B5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFA388E6E6FFD6E3F3D9EAE2E3EEE3F5FFEE
D9E3FFEED9DAFFEAEBE5F7D1D1EACEF3F1F3F3F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7
F7FFFFF3F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFF7FFF7FFFF
FFF5F5FFF7F7FFEEDAE4CFD1D1DFDFDAECEEEEECECEAE2F3
E3DFDFEBEBEED1E4DADAF5F7E6EEEEE6E6FFF3F3EBE3E28A
CBEAECF5F1F1F5E3EBFFEAECC7B5BACEEBFFF1E3EB7587F3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7A888EEEEFFEBE2F7EEEBDEEEE6FFEEEEFF
F5C4B5D2CAFFFFECE5EEEAC9DEEACEF7EAF7EEFFF7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF7F7F7
F3F7FFF7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF3F7F7FF
FFF5F1F1F5F7F3F7EEEEF5EACDBDC1BDA398B1C4DEE3ECEC
ECEBE6D6D6CED6D6DEE2EBE6FFEEFFEEEEF7F7F3FFDED18F
E5E3F5F5EEEBEEF7D6ECF7ECECE4C7D6D6DEF3EAEB4ED1EB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE2A89DEEEEFFF7D8F7F7DED8EEEEEEEEEEFF
FFE5EBEAECF7F7F3DEEEE4CBEBE3D9E3EAF2F7F7F7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFF7
FFF7F3F3F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFF7
FFF5F5FFF1FFFFF7F7EEE6E6EEEED9DEECE2D1DAE5D6D9CA
C1CEDEE2D9E2F1F2F7EBF7EEF7F7FFFFFFF3FFF3ECE2BCB0
FFE6FFF5EBE3DED9ECE3F7D9EEF7D9EEEEEEFFEAE37B8697
DAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD198CADAF7F7FFD9E3F7E2F5EEE6FFFFEEE5
E5EEF7F7F7F7EAF2DEF7E2D0D0E2EADEF3EAF7F7F7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7F7
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F3F7F7
FFF5FFF1FFF1F5FFF7F3F7FFEEEEF7EBEAE4EADECBD2CBCB
D2DFDED6E2EBE6EEEEF3F3EEF7F7EBF7FFF7F7E2F5E6AFC4
FFE6FFF7F7F1E3D9E2ECDEEBF7E5EED9D6F7F7F3E2BEBA8F
A4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC489E3ECF3F3EEF3E2E4ECEEEEEEEEEEFFE3
E3EEEEE6E6EEECECD6F3EBE4DFD8E4E6F3F5EAF7F7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFF7
F3F3F3F7FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF
FFFFF5F5F5F1F5FFFFF7F7FFFFFFFFEEEBEBD9E2EAE4E4E4
E4E4F2EBF3EBFFEEFFF7F7EEF7EBF7EBFFF7FFDEF3D9B7CB
FFE6FFF7ECFFF5F7DEECEAF7F7E5ECFFDEF7F7F7ECC9F3A8
7CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA893EAEEF7EBEEEBE3ECEAF7FFFFE6EEE3E4
EAE6EBDFE6EEFFF7F5E3EBE2DAD1D0D6F7F7E4FFF3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFF7FFF7F3
F3F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF
FFFFFFF5F5F5F5F5F5F7F3F3F7F7F7FFFFFFF7F3F3F3F3F3
F3F3EBEEEEFFEEEEFFEEEEEEF3F3EEFFE6F7F7E4EBD0BDD6
FFE6F5F1F5F1EAE2F2EAF7F7FFF7FFE3F2E6EED6EBBEF3B5
67F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF81ADF7EEEEEBF7FFE4ECEAF7F7EAD6FFF5EA
E3F7E5F7FFEEE6E5F5ECEEDEF2E5CECEEEF7DEFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFF7F3F7
F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF3FFFF
FFF7F7F5FFFFF5F5F5FFFFFFF3F3F7F7F7F3F3F7FFFFFFEE
E6EEFFEEEEEEEEEEEEFFEEEEF7F7EEEEF7F7ECE3D9C4C4EC
FFEEE2F5F1F7F5DEFFDEFFF7F7F7EAF2F7EEDAE3DECBF7DA
55C6F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF76BCF3F3EBF7EBF7E3ECECEAEEEADAEEE6E5
E3F7EEE6E6EEFFEED6DAF5CDECF3CBE2D6F7E4F7FFF3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7
F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7F7F7F7
FFF7F7F5FFF5F5F5FFFFFFFFF7FFF3FFF7F7F3F7FFFFFFFF
FFFFEEFFEEEEEEFFFFEEEEEEEEEEFFF7F7F3DEE3D1C5E5EC
FFE3E3F1ECF5ECECF2F7E3F7F7FFE2EBEEF5D9EBC4D6F3F3
8394F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF61CFDFF3EEEBEEF7F7E4ECF2F2DAE6F5DEDE
EAFFFFECECFFFFFFEEE5F7E5E3E2C7CEBED1E2F7F7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFF7FFF7F3
F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF7F7F7F7FFF7
FFFFFFF5FFF5F1F5F5F5F5FFFFF7F3F7FFF7F7FFFFFFFFFF
FFFFEEEEFFEEEEFFFFEEFFFFEEFFE6F3E3D6DAD0D1C4E4EC
EEEBF5F5EAF3E2F2DACED9FFFFF3ECD8E5EAE6EBBDECE3EB
A38AFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF49F1D2DEEBEBEEEBF3E2F3F7F2ECFFE2F2F2
F3ECEED2D2E6EEFFE6ECECEBF7F7E2DFDEDAC4F5F3FFF7F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF7F3FF
FFF7FFFFFFFFF7F7FFFFFFFFFFFFFFFFF7FFFFFFF7F7FFF7
FFFFFFF1F5F5F5F1F5F5F5FFFFFFF7F7FFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEEF7F7FFE6F7DEE2F2C3EACBFFEE
E3EAEAF3E3D8F7D1EEEEF3F7F3ECF2FFF5ECF3E2D6FFECD6
B07CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF3BF2D2EBEEFFEBFFF3F2F2F7F7F7FFEBF7F7
DEE4EEDFDFEEEEE6FFDAECE6FFF7F5D1D0EBC4EAF3FFFFF3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F3F7
F7F7FFFFFFFFF7F7FFFFFFFFFFFFFFFFF7F7F3F7FFF7F7F7
FFFFFFF5F5F5F5F5F5FFFFFFFFFFF7FFF3F7FFFFF7F7FFFF
FFFFFFFFEEEEEEEEEEEEEEF7F7E6F7F2E2E5DAC7DAD9FFD6
EAFFF7F7D8ECC3EEF7EBEBFFF3ECEAF3E3E6F7DEEEEEECD6
B789E2F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF19DADFF7EBEEEBF7EEF7E3F5F3F7EEEEFFFF
ECFFECFFFFEEEEEEFFEEECD6F7FFF5ECDAC8BDEAEAFFFFF3
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFF3F7
F7F7FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF3F7FFF7FFFF
FFFFFFFFF5FFF5F5F5FFFFFFFFFFF7FFF3F7FFF7FFFFF7FF
FFFFFFFFEEEEE6E6EEEEEEEEEBF3FFE2D9F2BDF3DEEAE3E2
F3FFF7D9EADEBCFFF3F3F7F7F7EEF7F7DFEEEEE4EEFFD9DE
BCA0C2F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF713DEE6EBFFEBEBEBEEF3F3E4F7F3E5EEFFFF
EED6ECECF7F7EEFFEEFFFFD1EEF5ECFFFFD2B4E5E3ECF7FF
FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7FFF3F7
F7F7FFFFFFFFFFF7F7FFFFFFFFF7F7FFF7F7F3F7F7FFFFFF
F5F5FFF5F1FFF5FFFFFFFFFFFFFFF7FFF3FFF7F3F3F7F7FF
FFFFFFEEEEEEFFEEFFEEEEEEF3FFE2E3E5E5C6E5DADAE2FF
FFF7D9E3E3D1F3F3F7F7F7F7FFFFF7FFEEFFEBF2DEE6D2E5
CA97C4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF33FDEE6EEF3F3F3F7F7F3F3EAECF1EAE6EEEE
E6D6E4ECF7FFF7E6FFFFFFDEDEF7F5FFFFDFB6E6F3EAEEFF
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F3F3
F7FFFFFFFFFFFFF7F7FFFFFFFFFFF7F7F7FFFFF7FFFFF5F5
F5FFF1FFF1FFFFF5FFFFFFFFF7F7FFF3FFF7F7F7FFF7FFFF
FFFFFFEEEEEEFFEEFFEEFFF7FFF3DEE2EAD2E4D6ECE6F5F5
FFE3ECFFD1EBEBF7F7FFF7FFFFEEEBFFF7F7E3FFD8EEDEE5
D183D1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF354E2EEEEF3F3F7F3FFF7F3F1F2ECE4EEFFFF
EEE6ECE4ECEBEBEEEEFFFFE4D9E5ECF2F7EBB0E2EBF1F3F7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7F7F3F3F3
F7FFFFFFFFF7F7FFFFFFFFFFFFFFF3F3F7FFF7F3FFFFF5F5
FFF5F5F5F1FFFFF5FFFFFFF7FFF7FFF3F7F7F7F7F7F7F7F7
FFFFFFFFEEEEE6E6FFEEF7FFF7FFE4DEEBD9D9D6FFE6F5FF
E2DAEEDAD1FFF7FFF7FFF3F7EEF7F7F7F7F7F3F5EBEEF7D6
CB7CDEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFD94BEBEBE3EAF3FFE6F3F7F7E3ECEAEAF7EEEE
EEFFD2D1E4EEEEEEF5DEEEEAECEEE5F2EEE6BEE2DFF1F7F7
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F7FF
FFFFFFFFFFF7F7FFF7F7F7F7F7F3FFFFF7F3F7F7FFFFFFF5
F5FFF1FFFFF1F1FFFFFFFFF7F7F7F7F3F7F7F7FFF7FFF7F7
FFFFFFFFEEFFFFFFE6EEF7F7FFECE3D1D0D1E5E4FFEED1D1
FFD2C4D9F3F3F3F7FFF7F7FFF7EBEBEBF7F7F3F1FFE6ECD9
8A84EBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFD155EAF2F5E2EEF7E6EBF7EBF3EAF5F5F3FFFF
EEFFE5D2ECFFEEEEE3EBEEE3F1EBEAEAEEE6BEEADFECF5F3
FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFF7FFFFF7
FFFFFFF7F7FFF7F7F3F3F7F7F7F7F7FFF3FFF7FFFFFFFFF5
FFF5F5F1F5F5F5FFFFFFF7F7FFF3F3F3FFFFFFF3F7F7FFFF
FFFFFFEEEEE6E6E6F7F7F7F7ECE3E3CEE2EBEEEAEAECECDA
E3EAF7F7FFECECFFF7F7FFFFF7EBF7E3FFF7F3F1FFE6E4B3
6DCEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC267DEF7EAE3F7EBEEE6E6F3FFEAF1F5F2ECFF
EEEEE6EEE5ECE6EEEEEBE5D2F7DAE5EAE3D9BDF5E2EEEAF3
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F3F3FFFFF7
F7F7FFF7F7F7FFFFF7F3F7F3F7F7F3FFF3F7FFFFFFFFFFF5
FFFFF1F1F5F5F5FFFFFFF7FFF7F7FFFFF7FFFFF7F3F7FFFF
FFFFFFEEEEEEFFF7FFF7EAE4EAEBEAD2EAFFE6EAEAE4FFD6
EAF7F7F7F7F5ECF7EEF7FFECF5EBEBF3F7F7E5F7D6C6DE96
89F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFB86FF7D9E4E3FFF7EBF7EBF3F7EEF7F5FFF2F7
EEEEE6FFCBD6EEE6E6F7EBD6E5E5CBFFD2DABDEBEAF3E4F7
F7FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF3F3FFF7FF
F7F7FFFFF7F7F7FFF7F7F7FFF3F7F7F3FFFFFFFFFFFFF5FF
F5F1F5F5FFF5F5FFFFFFF7FFF7F7F7F7F7FFFFFFFFFFFFFF
F7F7EEEEFFEEEEF3F3ECFFF5DAF2DED6F3EEE3EAECE3EBD6
FFF7F7F7FFF7F7E3F5EEF3F2E2F7F7F7FFF3EBEAEBC2D17F
A0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFEECA62F7F7E2DAEEEBF7F3F3F3F7F7F3F5FFF2EE
F7E6E6FFD6D6EEFFEEF7F7ECD6EBDEEAEEFFC5EAE3EBEAF5
F3FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F3FFF3F7
FFFFFFFFF7F7F7FFFFF3F3F7F7F7F7FFF7FFFFFFF5F5F1F1
F5FFFFF5FFFFFFFFF7F3F7F7F3FFF7FFFFFFFFFFFFFFFFFF
F7F7EEFFEEEBF3FFF7E4ECE3EAF5E2C9E5EEEAF7FFEBE3EC
FFF7F7F3F3FFF3ECECF7EBEEE5F3F7EBF3FFF3F7EADECB75
B8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFEECE62F3F3DEE4EEF7F3FFF7F3FFF7EEE4ECF2EE
F7EEFFEEEEEEEEEEFFF3F2EADEF7F7D8F7EEC2F7EAEEE3F1
F3FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF7F7F3F7
FFFFFFFFF7FFFFFFFFF7F7FFF7FFF7FFF7FFFFFFF1F1F5FF
F5F5F5F5F5FFFFFFF7F7F7F7FFF3F3FFFFFFFFFFFFFFFFFF
FFEEEEEEFFF3F7F7ECECF7F7ECF2E3B0EEECECF7EBE3F2F7
F7F3F7F7F7FFF3F7F7F7F7E5F7EEF7F3F3F7FFF7D9EECB8E
9CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7D162F7EBE4E4EBEAEEF7F3EEF3EBF7D1EAF5F3
EEEEE6E6F7F7FFFFFFF7EAEAECDEF7E4F3DECEEBF1EEEBEC
ECF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF7F7F7FF
FFFFFFFFF7F7F3F7F7F3F3F3F7F3FFF7F7F7FFFFF5F5F5F5
F5F5F5FFF5FFFFFFFFF3F7F7F7FFF7FFFFFFFFFFFFFFFFFF
FFEEFFEEE6F7FFF7E4F7EEF7D6E3CDD2F7E4FFF7E5FFF5F7
ECF5F3F7F3F7F7FFF7EBE3F7E6F7FFF7FFF7F3DAF5EBD18E
9CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF3D15BF3E3E4E4F5F2E5EEFFF7F3F3F7D6ECF5EA
E6EEEEE6F7F7FFFFFFFFECEAF7E2E5EADFEBCEF3EAEBF7EA
F5F3F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F3F3F7FFF7FF
FFFFFFFFFFF7FFF7F7FFF7F7F3F3F7FFF7F7FFF5F5F5F5F5
FFF5F5F5FFFFFFF7F3FFF7FFF7F7FFFFFFFFFFFFFFFFFFEE
EEFFE6E6E6F7FFF7E4F3E3EBE2F2D0E3F7E4FFFFE3EEF5FF
F5F5E2D1E3F7EADEDEEEF7F3F3FFFFF7F7ECF1EEEBDFBC7F
B5F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7CE5EEBDFECFFECFFEBF3F7FFF7F7F3EEFFEED6
EEEEFFE6FFECECFFFFFFECF3DEE5EBE4E3F3CBEBE3E3EEE2
F5F7F7F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F3FFF7F7F7FFFF
FFFFF7F3F3F7F7F7F7F7FFFFFFFFF7F7FFFFFFF5FFF5FFF1
F1FFF5F5FFFFFFF7F7F3F3FFFFFFFFFFFFFFEEEEFFEEEEEE
EEFFE6EBEBF7FFEAE3E3F2ECCDD9DEEBFFDEF7FFFFDEF1F5
E3D8F5DEFFE2FFF1F5F7F7FFF7D6D6F3FFDED1EBE2B56287
D9F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7DE62ECEBF2F2F5ECEEEEF7F7F3F7EBF7EADAE5
EADFFFE6FFEAEAECECFFFFE2E2F7EEEAD9EAD6F7EBEAEAEB
ECF5F3F7F3F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F3F7F7F7F3F7
FFF7F7FFFFFFFFFFFFFFFFF7F7F7FFF7FFFFFFF5FFF5F5FF
FFF5F5F5FFFFF7F3FFFFFFF7FFFFFFFFEEEEEEEEFFEEEEEE
EEEEF7FFF7ECDEE3F3E4F2DAE2F2EAEBF5E5F7FFEEFFEBEC
E5F7EEDED9CEDEEBF7F7F3F7F7D2CAEBEEEBE3D1F58877E2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF3DE5CEEEBF2F5F3E4EEEEF7EBF7F7EBF7DEEAFF
F1D9FFEEEEEAECF5ECFFFFF3D8FFF7EAC7D9D6ECEBEEE2EB
F3F5EAFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F3FFF7F3F7F7F7F3F7
FFF3FFFFFFFFFFF7F7FFFFF7F7F7F7FFFFFFFFF1F1F5FFFF
F5F1F5F1F5FFF7F3F7F7FFF7FFFFFFFFEEEEFFFFFFEEEEEB
EBEBFFF7FFEAF7F7E3DAE3E3ECF7EEEEEAF7FFEEEEEEE2F2
F7EBE6D6F7F7EEEBF7E6DFE6F3F3FFEBEBEEC8F5FF5994F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7D662E5EBF5F1F2DAF7F3EBDFF3F7F7F7EAF5FF
F5D2FFFFE6ECEAFFF3EAECF7D9EBF3F7D8F7F7D9ECEBEAE2
EBFFE4FFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F3FFF3F7F7F7F7F7FF
FFF3F7F7FFF7F7F3F3FFFFF7F7FFFFFFFFFFFFF5F5F5FFFF
F1FFFFF1F5FFFFFFFFF7F7FFFFFFFFFFFFFFEEEEFFEEEEF7
F7F3F3FFECF2EBE3F7DEEAFFEAFFDEEAECFFF7EBF5F5F1E3
D9E4ECE5D1F3F3EBEEFFF7F7ECECF3E6EBD6EBEED6699DFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFDE61ECDAEBF5F7DAEBF3E3E6F7EEFFF3F7F2F1
F5D6EBF5E6F7F7EAF5F1EAEAFFE3DFF3D8FFF3E5DADEF3E4
EBF7E4FFFFF3F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7FFF3F7F7FFFFF7FF
F7FFFFF7FFF7F7F7F7FFFFF7F7FFFFFFFFFFFFF5F5F5FFFF
F5F5F5FFFFFFFFF7F7F3F7F7FFFFFFFFFFFFEEFFEEEEEEEE
FFF7F7FFE4F3EEEAEEDAF2F7DAE6D9F7FFFFF7EBE3FFECF3
F7FFEAE2F7D9F3E3EAF3F7F7F5F5FFEBF7E5F5EEC572A0F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFDE70E4E5E3F1EAD6E6EEEBF7E5F3F7F3F7F2F5
F1ECD0EBEBDAF5FFF2F1F5F7ECE4DFF7E3DEEAF5D9DEEEDE
F3F3E4FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF3FFF7F7FFF7F7
F7F3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFF
FFF5F5F5F7F7FFF7FFFFFFF7FFFFFFFFFFFFFFEEEEEEEEE6
EBEBFFF5EAEBEAD9E3EAEAECE6FFECECEEE6E6E6EEF5ECF3
F3F3FFF7E2E2E6ECE2F5DEF5FFF7F3F7F7EAE3DAD662C4F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFDE81CEDFF5F5F3D9E2EBF7DFE6FFF7EEF7F7EA
F5F1EAE6F5EBDAFFF5EAFFEAF3F2E3E5ECF7F2F5D9E4F7D6
EBF3E4FFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F3F7FFFFF7F7F7F7
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFFF
FFF5F5F5F7F7F7F7F3F3F7F7FFFFFFFFEEEEEEEEEEE6E6F7
FFF7F5E3EBEBF5E2DEE3F7FFE6FFECECE6FFFFECE4EAF5EE
EBF3F7F7F7F7F3F3FFEAE4F5ECF5F3F7EEEAE6E4E639E2FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEE75D1E3EBF5F7ECEAEAF5E3FFEBF7F7F7F2F7
F5F5E4D1E6EEEBD0FFFFE4F3EAF5F1D6F5F7ECE4D1D1E3DE
E3E3EAF7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7FFFFFFFFF7F7FFFFF3F3F3F3F3FFFFF7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5FFFFF5FFFFFFFF
F5FFFFFFFFFFF7F7F7FFF3F7FFFFFFFFEEEEE6E6EBF3F3FF
E3E4E2EEF7ECE2D1C6F7EEE6EEECECEEEEFFF5F2F3FFF7EE
E2E4EAF3F7EEEEFFF3F7F3ECF7F2EBF7D9CDC5D6A355F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF6FCDEAE3D8E2F7DEDEF5E5EBD9F7EBE3EAEA
F5FFECE4E2F5E3EBDAFFE4D9EEEAF1EBDAF7FFFFE4EBD9D9
ECDADAEAFFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7FFFFFFFFF7F7FFFFFFF7F7F7F7F7F7F3F3F7F7FFF7F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFF5FFFFF1F5F5F5F5
FFFFFFFFFFFFFFF7F3FFF7FFFFFFFFFFEEE6EEEBEEF3F3F7
ECEAF7ECEAE3E5F7E4EEE3F5ECECEEE3EAE4F2FFF7F7F7F7
F5F1F5F5ECE3EBF7EBEAF2EAECF3E5EAC4F7E3D678B3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF6FDEE2F3E2E2F7DEE5F5E3DAEBEED9D9E4E4
FFF5FFF7C1DEEEEEEEDAEAE3F3EAF7F7EBEEFFF7E3E2E6DE
EEEADFE3EAF7F7F7F7F7FFF7F7FFF7F7FFFFFFFFFFFFFFFF
F7F7FFFFFFF7F7FFF7F7F7FFF7F7FFF7F7FFF7FFF7F7F3FF
FFFFFFFFFFF5F5FFFFFFFFF5F1F5F5F5F5F1F5F5F5F5F5FF
FFFFFFFFFFFFF7F7F7FFF7F7F7FFFFFFEEEBF3FFF7FFFFEC
EAD6F3EAEEE5F7FFD6EEF1F2ECFFE6F1F3FFF7F3FFF7F7F7
FFFFFFF5F5FFF3F7F7DAECF7F3EEEBE2DEFFE39C83EEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF62EBF2E2DEF5FFEAF7EAFFDEF7E6DFEBD9F5
EAF1F5ECD9F5E3EEE6EEF3F1EBEBEAF5EAE2F3FFF7CEE5D9
EBE4E6EAF5F3FFF7F3F7FFF7F7FFF7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7F7FFF7F7FFF7F7FFF7F7F7FFFFF3F7F7FF
FFFFFFF5F5F1F1F5F1F5FFF5F1FFF5F5FFF1FFF1F5F5F5FF
FFFFFFF7F7F7FFF7F7FFF7EBEBEEE6EEEEF3F7F7FFECECE4
E2E3E3DEEEF3ECE4D6FFF5EAEEE6EEEAEEF7FFFFF7FFFFF7
F7F3F7FFFFFFF7F3F7E6F7EBEEEBE2CDEAF7CB83ADFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF7AC6F7E3CDFFFFF2F7EAF1EAF7EBE6FFDEEA
EAEAECF7FFDAF5EEFFF7FFECE3FFE3ECF7EAF3FFF3DEE3D1
EEDAD9E3E4E3F3F7FFF7F3F3F3F7F7F7FFFFFFFFFFF7F7FF
FFFFFFFFF7F7F7FFFFF7FFF3F3F7FFF7FFFFFFFFF3FFFFFF
FFF5F5F5FFF5F1F5F5F1F5F1F1FFF5F1F1F5FFF5FFFFFFFF
FFFFFFF7F7F3F3F7F7F7F7EEEEEEE6FFF7F7F3FFFFE4ECEC
E2F2E3DEEBF7E4FFE6F5EAECE6FFFFE4F7F7FFF7F7F7F7F3
F2EAF7F7F3F3EBE6DFE3ECF1F2E3D9D6ECEEC477D1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA3A8F7EADEE3F5FFEBEEF7F7F7F3F7F7EBE2
F2ECF2EAEAEADEE3EEF7FFDAEBEEFFE3F2EAD6F7F3E3FFC7
E3EBD1F3FFEAF5F7F7FFFFF7F7F7FFF7FFFFF7F7F7FFF7F7
F7FFF7F7F7F7F7F7F7FFF7F3F7F7F3FFFFFFFFF7F7FFFFF5
F5F1F1F5F5F5F5F5FFFFFFF1F1FFF1FFFFF5F5F5FFFFFFF7
F7FFFFFFF7FFFFF3F7FFEEEEF7F7EEF7FFF3F7FFF5F2F7E3
EAEAE2DED9EAECEEE3ECF7FFEEEEF5EAFFF7F3EEF7FFFFF7
ECF5EEF3F7F3EEEAEAF1F5FFEAD9CDFFECCBC46FDAF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFBD90F3E2D9EEEEF5E2EEF7F5ECEBF7F7F3D9
F2EAF7DEECF5DAEEDEFFF7D9DEEBF7F3E3ECD1F3EBDAF5E4
DADAD1D9F7F7F1FFF7F7FFF7F7FFF7F7FFF7FFFFFFF7F7FF
F7F7FFF7F7F7F7F7F7FFFFFFF7F7F7FFFFFFF7F7FFFFFFF5
F5F5F5F1F5F5F5FFFFFFF5F5F1F5F5F5F1F5F5FFFFF7F3FF
FFF7F7F3F7F7F7FFFFFFEEEEF7FFEBF3F3FFFFECEAF3EEE5
F7DAEEECE3F7FFE6F1F3FFFFEEEEEAF7F7F7FFF7F3F3F7FF
F7F3E3EEEEEAEAF5FFFFFFFFE2C5E5ECF7D1A289F7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD683EAD8D9FFE6F1EAFFF3ECFFF2F2E3F3EB
E2F2ECE4EBDFEBE3E3EEEEFFEAEEECF3EECAEED8EAEBEBE2
E2D0D0BECEE3EAEAF1EAEAF3F7FFFFF7F3FFFFF7F7F3F7F7
F7F3F7F3FFF7F3F7F7F3F3F3F3FFFFFFF7F3ECF5F5F1F1F1
F5F5F5F1F5F1F5F5F5F5F1F5FFFFF1F5F5F5F5F7F7F7F3F7
F3F7F7FFFFFFFFFFFFEEE6EBEBEBF7F7F7F5EAECEEE6E2EA
F5DFF3E2E5E6E6EEEAE5E6E6E3EAECFFF3F7F7FFF7F3F7FF
FFFFEBFFECF5FFFFFFFFF5EAE2CBFFECF2C97BA8F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEE94B9EAEAFFEBEAF1F3FFF3F1EAF2E5FFF3
F2F1F5F1DFF2E2F3F7EEF7F3F2FFEEF2EBEBCBF7E4EBF3F7
F7E3D6E2D9D1EBE5F3F2F5FFF7EAEAF7FFF7F7FFFFF7F7FF
F7F7FFFFF7F3F7FFFFF7F7F7F7FFFFFFF3FFF1F5F5FFFFFF
F5F5F5F5FFF7F7F7F7FFFFFFFFFFF5F5FFFFFFF7F7F7F3F3
F7FFFFFFFFF7F7F7F3F3F7F3F3F7F7FFECE2F3E3EBFFF5F5
FFD9ECECE6FFF5F1D9EEEEEEF1F7F7F7FFEEEEF3FFF3F3F3
F3F7EBF7F1F5F5FFFFFFEAEED1DAFFEAFFA36FE2F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFA8ADEBE4FFF3EAF5F3FFF7EAF1FFF3F3EB
F3EAEAFFE2E2F2F3F7EEF7F3F7F5FFEAFFF3F2D1F5D9DEEE
FFF3C8DAECCEC9D9E3EAEAE4EAF5F5EAEAF7FFFFFFE2E2FF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFF7F7F3F5ECF3F7FFFFFF
FFFFFFFFF7F7F7FFF7FFFFFFFFFFFFFFFFFFF7F7F7FFF7F7
F7FFFFFFF7FFFFF7FFFFF7FFF7F7E3E4F5EEFFE5F5FFF5F5
E5DAEAFFE6ECF2FFD9FFEEDAF2FFF3F7F7F7FFF3F7F7F7FF
ECE2E6F5F5F5F5FFFFF5E2EED1EEEEF7EC6594F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7C296E6EAF7F3F3EEF3F7F7EAF5FFF7EBF3
F7E4ECF5E4EEEEEEFFECDAF7F7EEF1F7F7F7E6E3D1F7EADA
EEF7EAD1D6E5D9E5D9CEDFEBEBDFE3F3ECEAE4E4ECE3E3FF
F7F7E2E2F7F7FFFFFFFFF7F7FFFFF3F7F7F1F7F3EEE3F3F7
F7F3F7F7F7FFFFF7F3F7F7F7FFF7F7FFFFFFF7FFF7F7F7F7
F7FFFFF7FFFFFFF7F7F3F7F3FFFFEAF3FFDAE5F7FFF5E3DF
E5EAF7EEEEEAF7E5E5ECEAF7F5F3EEF3EBEBF7FFFFF7F5EC
ECF2EEF1FFFFFFFFFFEAEBD9E3EEEEF7B340D9F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7D997C8ECECEEE5E3F7FFFFEEF2F5FFEEF7
EBF5F7EAEAEEEBF1DEDAECD9D9F2ECF1ECF7F3E5D9C1E2F5
DAEEF7F5E3EBD9D0DED6D6DEE2F7EBF7F3FFF7F3E3E4E4E4
EAECEAF3F2F7F3F7F7F3F7F7F7F7F7FFF5ECF3E3EEF7EBEB
F3F7EEEEF3F7FFFFFFF7FFFFF3F7F7F3F3F3F3F7FFFFFFFF
FFFFFFF7FFF7F3F3F7F3FFF7ECECEAF3EEECEBFFECD9E3F7
FFE4EEEEF5ECE3E5FFECF5EAE3EAE2FFF3F7F7FFF7F3E3EC
F7F7FFF1FFFFFFFFF5E2E3D6EEEEEEF35D7FF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEEB0ADEBF1F3DEFFE3F3F3EBF2F5FFFFE6
EEEEEAF7F2EAECE3D8FFDEC4ECE2EAFFF5EAF5F3E2FFCFD9
FFDAE5FFF2F5F7E3D2D9E2F3E3E4E3DED1F7E5EEF7F7FFF7
F7F5F1F5F5F5F5ECECF5F5F5F7F7F5F1ECE5EBE2E4DEE2E4
DEEAF7EEF7F7F7FFFFFFF3F3FFFFF7F3F7FFFFFFFFFFFFFF
FFF7F3F3F7FFF3F7F3F3F7FFEAF5ECFFF3EAE2E2E2EBFFF5
EAECE6ECEAF7E6FFFFECDAEEF7ECE3FFF7F3F7FFF7F7F7F7
F3FFF5F5FFFFFFFFEAE3D9FFEEE6E6B145C6F3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC49DE6F1F3E6F1F5EAF7F3F3F7FFFFEB
F7E6F5F5F2EAF7D8E3DEF5FFC7E3E5D6EAF1EAFFF7DAEAEE
D9EAEEE5F3EAECFFEEE3DEEADEE3ECFFE3D9EEEEEBE3D9E5
E5D9D2E3F7F2F2F5F5F5ECEAF5F1F5F7E5EEE2DEF7FFF3EB
F7ECE4EAEAFFF7F3F3F7F3F7F3F3F7FFF7F3F3F7F7F7F7F7
F7F7FFF7F3F3FFF2F5FFFFECF2F3FFE3DEECEEEEFFF3FFEA
F7EEEEE4FFEEEEFFECFFDAEEFFF7F7FFFFFFF7F3F7F7F3EE
F7FFF1FFFFFFFFECDAD1E3E6EEFFFF945BF3F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD697D1EAF7E3EAF5F2F7F7F7E2ECFFF7
EBE6FFF1F3ECEAECE2FFE3F5F5D1C5EAE6DFF2ECF3F3F7F3
F7F7F3EBFFFFECECEEDFC6DEFFE3DEF7EEF7ECECD1E3EBD6
D6DEF5EEDFDFDFE3F7F7F7EAF5FFE5DFEEF5DEF3EEE3DEE3
EBEBF3F7EADEECFFFFEAEAFFFFFFFFFFFFFFFFF7F7F7F7F3
F3FFF7FFF7F5EAEAF7EAEAF5FFF7F7EAECF7EBFFF7E3ECE4
FFDEEAF5F7EEE6EEEAF5ECFFFFFFF3FFFFFFF3FFF7F7FFF3
F5F1F5FFFFFFF5E2E2E5EBF7EBE6C66F87FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEEAAACD0ECEBE2F5FFF7EEF7E2ECF5F1
E3FFEBECE5DEEAF7EEE2F1E6EEE3F7DACBCBFFE2EBEBF3EA
EAF3F7F3FFF7F3F2F5FFF3EBDFEBD6E3D8C3C9D8E2DEE3F7
D1AFC9D8C9CDE4DADFEBE3D6D9D9DACFBDC3D6E2D9EEF1EB
D9EBDED6DFE5E3E4E4F7F2EAEAF3F7FFF7F7FFF7EAE4DEE4
EAE4EAEAEAF5ECE2ECF7F7F7E5E6E2E4F7DEE2EAE3DAD6D6
DEDAE5E5E5EEFFDEF5F3F7F3F7F7F7FFF7F3F7F5F1EAE4EA
F5FFFFFFFFFFE2C8D6F7FFFFEBDA7E68D1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFDA98D6E2EAEBF7F5EBF3FFF3F5FFF5
F1DFEBF7D6EBEEFFF7DEE2EEECF2F2F2F2EAE5F3E5EEEEDE
E5F7F3F3EEE5F3F7F2EAEAF2F3DEEAD6EAECF2E3DEDAEED6
CEEBF7ECEAEEDED9DEDAF5EBECE4E2E5ECFFFFE3E3E3D1E3
E2DEDEE2ECEBEEEBEBECF1ECECF1EAE4F5F5E4EAF5FFF7FF
EBEBF3F3F3F3F3F7FFFFF7F3E2F5F1EEDED9F5F5E4E6F5F5
F1E3FFFFEEEEE6EBF2F7F7F7F7F7FFFFF3FFFFF1FFFFFFFF
FFFFFFFFFFF5BCDAE3F2FFF7EE9C6FB5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFA0B9EBDEF3F3F5EBF3F7EBF5F5F1
F5D6F3F3E4EBDEE3F7E2E3EEDAF7FFFFFFF2EEF3E6F3F3F3
F7F3F3F3EBEBF7F7F2F2F5F5F3EEDFF2EBE3EEF2F2F3E2E2
DEFFEEF7F2F5FFEAF3D9CEE5E4E3DEE4FFECE5EEEBEBF5EA
EBF3FFF3D9D9F3F3F7EBEBF7F7F3F7FFECECFFF7F7F7F3F7
F3F7EBE6EBEBEBE2DEDEE5F3F2FFE3EEF7F7DACBD6EEF5F5
EAEEEBE6FFF5F5FFE4FFF7F7FFF7F3F3ECF5F5FFF5FFFFFF
FFFFFFFFFFEABEEBEBF2ECF5E67A7FF7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC4A2EED1F3F3EEFFF7EEF3F2F5F5
F2D9EBDFF1E3DEFFE3F7F3F7EEEAFFECE5F2EEF7E3EEECEC
F7EBF3EBECEAF2F7EAF2EAF7D9E3EAD0D2EEE3E2E3E3E3D6
D6E3E3EBF5F1E3D9F7F7EBD6DEDEF5E3D0EAD9F7F3F3F2FF
F5F2ECF3F7CEE2E2E4ECF3EBF3F3EBEBF3F3F3EEEBEBEBE6
EBF3F7FFF2F2F7F2FFE3E3F1F1E3E5EAF2ECE5EEFFF5F1F1
EAF7E5EEFFEAECF5DEF7F3FFF7EEF3F3ECF5F1F5F5FFFFFF
FFFFFFFFECDADEF7F7F2F5D9D949B0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFD6A9C6C1EBF7EBFFFFF7F7EAFFF5
ECECE3EBEAF7F3ECF5E5F7F3FFEAECF7F3EEEBFFEBEED6D6
DEE3E3FFF5F1F5EAE2ECF2F7D9C7F3D0DAF7F7F2E4DEDEF5
ECE2F3E3D9DFDAD0DEEAE2E2EAF7EEE2E3D2EEF2EAEAF5F1
F1EAE2ECF7E5E6E6E3E2EAF7F3F3F7F7EBE6E6EBF3EAEAF1
F5F5F1F1F5F5F1F1F5EEFFE6EEE6F3F5F7ECFFE6FFF1FFF7
F7EEF7EAE4F5F7F2E2F7F7FFF3F7F7ECEAF1F5FFFFFFFFFF
FFFFFFECE3D1EEEBF7EAE3D9CF3DE3FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEEC8B0BCF2F3EBEEEEFFF3F3F1F1
FFFFF7F3E2F5EBF7E3DEF7F7F7F2EAFFF3F7F7F3F7EBEBF3
E3D9F7E3F7ECE4F5F2F5F7F3FFEAECD9CFF5ECEAF3F7F7DE
D8E4F5F5ECE2F7F2EBDFE3E3DFD9D9EAE2EAEAF7EAF7EAEA
EAE4FFDED9FFF7F7EEE6D9D8E2F1EADEE4F1F1EAE4E2DFDF
E3ECEBDFDFE6EBEBE6E6EEF7E3E3ECEAECEEDEE2EAF2F7F7
FFE6F2E2FFF7F3F7F7F3F7F7EEF3F5FFEAF5F5F5FFFFFFFF
FFFFF5EAE2D6E3F5DAF7CDEA9B66FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE6B4ADDEFFEBF7EEFFF3F7ECFF
F5FFFFE6E6F1F3EEDEF5EEF7F7FFECEAEBF3F2EAECEEF7F7
EEEEEBEEE3D9D1D1E2F5F3FFE2E4EAE4EAF1D6EEEEEEFFE2
D9E3EAECF2F7F2EAEAECF5F5F2F2F5F5F7FFF3EAECFFFFEE
DAE3F7EEECD6E4ECFFFFF7F3E3D9D9E6EBDFD9DFE6EBF7F7
E5E3E2F2EAD8D1DEF3F3F3F7F5EAF7EAEEEEF5F5F3F3F3EE
EEE6F1F7F7F7F7FFF7E3F7F7EEF7EAF2ECF5F5F5FFFFFFFF
FFF5ECE5D0F5E3D6F5C6E5F56DA0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFEEC89FBEE3F7EBFFFFF7F7F7EC
FFF5FFEEFFE3EAEAF7E6E6EAEAEAF1E3E5F7F5EAE2F3ECE2
F3F7EBFFEBF7F3E6E3FFECE2ECE2EAF3EAF7E5EEDEE3EEF3
DAE2EEE5F3F3E5DFEBECEAEAF2F5ECE3D9EBFFEEE6E6D6DE
E3EBE5E3DEE3E6D6CBCBCBCBD6E4E4DED8DEE4E4E4E4E4E4
DEC4CBD2D6EEEED6CBCBCBD6D9DFD6C4E5F5F1DADFE3E3EE
EBEBEAF3EEF7F7F7F7F3F3F7F7F7F7F2F5F5F5FFFFFFFFFF
ECE2D9EBE2F5F7FFD1CDEB7C50D1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE2A3D9C4F7EBF3F7F5EAFFF3
F1F1FFFFE6EEEEF5ECE5EEDEEEE6E3EBF3FFFFF7EBF3EAE5
FFF3E5EBF7EEF7F3ECFFF5DEEEE3DAF3EAEAE3DEEBFFE3EB
EAE3EBEEEBF7E6F5DEF7F3EBE3EBF7E6ECD6D6FFEEF5EAF7
EAE4F2E2EBF7EAF1F5F5F5EEFFEEEEDEDEE6E6E6E6DEDEE6
E6EBF5FFFFE6DEF5FFF5F1E3EEFFFFEAF5EAE3E5FFF7F7EC
F7F5E4F7F7FFFFF3F7F7ECE2FFF7F3EAF5FFF5F5F5FFFFEC
E3E3F7FFECF7ECDAF7EAAA67D1F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEBB0D1D8E2F7F3F7E3F7ECF7
ECF7ECFFEEEBF3F7F5ECF3EAE3DEDAEBFFF7F5EAECF7EBF3
F3EBE5E2F5F3F7FFF7C4D1D1DEF2F7FFFFFFDEF1FFF1F5F5
EAF7F2E5F7EEE2EEF7D1F7EBF7EEEBFFDAEAF5D9E2F5F7F7
FFFFF7F7ECECF7F3EAF2F5E2E2E3EEF1F1FFFFFFFFF5F5EC
ECFFFFECEAE2EEFFF1F5F7ECEAECF5FFEAFFEEEEF5F5FFEA
F5ECEAEBFFFFFFF3F3F7E2DAF7EAF1FFFFF5FFF5F5FFFFDE
E3ECF1EAFFE3D2E2E4B57DA4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEEC5B0DAD6F7EBF7F7EAEAF7
F3EAF2F5FFF7F7F7F3ECF1F5EABEEAFFF7FFEAE2F7EAECF3
F3F3F7EAE3F3FFF7F7C1BEE5DED6EBF7E3E2DEEAFFF1FFF1
EAECEAD6EEF3ECF2DEECDAF7EEF7F7F5D9EAF5F5EBEBF3F7
FFEEEEFFFFFFFFFFFFEBE3F3F7F5F5F1F2E4ECFFECE4E4EC
EAF1EAECF7F3ECF5F7F3F7F7FFF5EAEAECEEE6F7ECFFEAF2
F7F5F2EBF3F3F3EEFFF3F7F7F7ECEAF5F1FFFFFFFFFFF5D6
EAF5EEE2E5F2CBD8EB7F90D9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD1C6C7C7D9F3F3F3EAF5F7
FFECF2EAFFFFF7EAE5E3EBEAF7E2D9EEECE3EBE5ECEAECF7
EBD2D2E6F3FFF3F7EEE2DEFFF3EBEBEEDAE2D8D6EEF5F1F5
EAECEAEAF5F3FFE2F7EAE3DAEBFFEEE2F2ECECECF3F3FFF7
F3F3F7EEEEEEFFFFFFE6EEEEEBD9DAECE5EEECE4ECFFFFFF
F7E3EBF7F7FFEBE3F7FFEEEEF7F7EEEEFFE6FFEAEAF1F7FF
F3EEEBF3EBF7FFF3F7F3F5EAF3F7EAF1F5FFFFFFFFECE2D9
FFEEE3DAD9E2DAD1BE67D1F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFDED6C3E2D1EBF3F3F3FFFF
F7FFE3ECEEEEFFF5DEF7EEE2D1D6F7CEC4E5E5EBF7F3F3EB
E6D6D6EBEEF3EBF7E3ECD6E6F3F7F7E3E3E2EAE2E2F1F5FF
ECF2F7FFE4FFF3DEE4ECEAD6F7F5F1ECE5EAF7F7E2E2FFF3
F7F3F7EBEBEEEEEEE6FFEBDEE6F5DAEBEEFFEEFFFFFFFFFF
EEFFEEEBEBFFEEEEFFEEEEE6EEE6EEEBEBEEECFFFFEAF3F7
FFF7F7F3EBF7F5EAFFF7F5F7F2FFEAFFF5F5FFFFECECEBF2
EEE3E3D9DAECCAA290A4FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE6DEB9D1BED6F7EEF7EBF7
FFEBEBECD9E2F5F5ECE3EEF3F7EEC4C1FFD9E3EEF7FFF7EE
EADED8D9F3F7F3F7E4E3D9EEF3F3EEE3F5F5F1F1F1F2ECF5
F5ECF2E5CBE5EAF5F2E3D8E3DEF2F7EEFFF7F7F7F5F5E6EB
F7F5F1FFFFF5EEFFEEEEEBEEF5E3FFE3EEDEE3E6E6E6DEE3
E6EBE3E6EEEEEEE6EEEEEEEEEEFFECE3F7FFEAF5ECFFEEEB
F7FFF7F7EBF7F1E4FFF3F7F2F7F5EAECF5F5FFECECEEEEEC
E2E3DAF5D6EB8399ACDAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFEEDAC7D1D6D1D9EBEEEBF7
EEEBF2DEEAF2ECECFFF1D9D6ECECFFE5CBBEECD9D9EEE2F2
D9C4BED2F7EBE6EEEACDE2DAEBEBDEEBFFFFECEAF5E4EAEC
E4F7E4DED9F3E2EADEE2EAF7F3E2DEFFE3DAFFDEE3EEF5F1
F1F5FFF5F5F5F1E2EBF5F5F5DEE6F5F5EEF5EBEEEEEEE2E3
D9EBF7ECEBDEEAEBFFEED6EAF5F5F2F2EAECF5ECF7F7F3FF
EBEBEBEBF7EAF5EAEAE2F7F2F5ECEAEAFFECE4DAE6F7F2F7
D1E6DEE5EE99469FDAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEED9B5BEE3D6E3F2F5EB
F3ECF2EBD6EAEAF2F5F2F3BED1E3ECFFECEAE3D1FFD6E2D8
F3ECE4E3E3E5FFE6F7BAEBECF5F1F5F5EAECE4EAF5ECECF3
D8FFE5EEE5CAD8EAE3F3EEE2E2DEF2EEE3F7DEEBFFF1F5FF
F7F7FFF7F3F7FFFFF5FFFFF5EEE3EAECFFEEEEE5ECFFEBF5
F3DAE3E2E3F3E3DAEBEED6F7EAF1F7F3F7ECECF1F3F7EBE3
EBFFFFF7FFEAF1ECEAF5EAFFECFFF5FFEAE3EBEEFFF2DADE
F2D1FFECA44CB3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEE3BFBEC7CEEAFFEC
F7F3FFEEE5F5F2F5F7E3EAF7E2E3EBF3F7FFFFE5CAC4CAE2
EBC4B7CAD2E3EEF7F3B8D2F5F1F5F1F5F3ECECECECFFF5EC
CEEEEEDED9CBEADEEADEF5E2F3EAEBF7EBD8F5F5F1FFF5F5
F7FFF3FFF7F7F3F7FFF2F2F5F1FFEAEAF5FFFFE4D9EBEEE2
F3FFF7F2F5F3FFE3E4F1F7ECECF7EAF7F3F7EAF5F3FFF3F3
F7EEFFF7FFEAF5F7EAFFFFECFFE4ECEAEEEEFFF3F2E3F5F7
D6EEE5ACAC7BE2F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE2EEC8BCBDEBF5F5
F3F7F3F7F7E3F7F5F7F7F5F5F2DED9EBEEF3F7FFFFF7FFEE
EBF5F5F7EAF1EBFFF3C2EBEAEAEAFFF5ECF3F3F7EAF1F5F5
D2E6EEE5F3EAECD6E2ECE2EBEAF7D6EBEEF5E3F5F5F7ECF5
FFF3FFF7F7FFFFF7F7F7FFF3F7F1E4F7ECF1F1F7F5ECDED8
EBF3F7EAE5FFF7FFEAF5F1E4FFEAEAF7F7F7EBFFF3FFF7F7
FFF3F7F5ECECEAF7F1FFFFFFE4FFEAE2EEFFF7ECDAF5DAD9
EEF7C69A86ACFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3E2E3B59BE3F2EB
F7F7F7EEFFFFE4ECF1F5FFF1E2CBE5F7EBE6E3EEECECF3E2
EBD9DFF2ECF5ECEBDEC8EEFFFFEAEBEEF1E6F7FFEBF7F3F7
E5F3F3EBEEE6D9CFEAE4F5F5EED6F3F2E5F7ECE3FFF7F7EB
F3F7ECECFFFFF7F3EEF7F7F3ECFFF2F3EEF7FFF5EAF7D9EB
E2F7F7EEF7F3F7F7ECF7F5E4FFF7EEF3F7FFEEEBF7F7F3F3
F3F7ECECECEAEAEAF5FFFFF5EAFFF3F7FFF7ECDAECE2E2D6
E5DAA07DBEF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6F1E381E3D9EE
E2EAF7EEFFEED9F2F5F5FFF5EBEBF3DFEEFFF7DEC1D9FFDA
D9FFEAC7E2F1F7EAFFD9EEFFFFF7DAEBF1E6F3F3DEDEEEEA
F5E6F7EEF7EEE3D6EAF2F5F1FFE5E3FFE3D8E3E5F5F7F3FF
F7FFECECF7F7F3FFF7EBFFFFF5F5F7F3FFEEF7FFF7F7ECE5
D9E6E3F7F7EBEEF3F7E2F1EAFFFFF3FFF7F3F7F7EBF3FFFF
ECECE4F5EAEAEAFFFFFFF5ECF7F7F7F7F7E3D1F3DED0E2FF
D9BE71ACF7F7F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE2F38FD9CEEC
F5EAF3F7F7EBEEE3F5FFEEEEECDED1DFFFE6DFD9F5DECEDF
DFD9D1E2D6EAF2ECF7DAE6EEFFFFF7ECF5E6F3F3DEDEF7E2
ECD9F2F3F3E6F2F7EEF2ECFFF1E3CEEEF7F3DAF2F1F7F7F7
FFF7FFFFF7F7F3FFF7E5EBF3F3F7F7F7F3F7EBE6EBF7FFDA
F7C6F3F3EEF7EBFFEEF3F3F7F7F3F7FFF7F3F7FFF7F7ECEC
ECECEAFFEAF7EAFFFFECE2EBF3F7FFF7EAD9EAEAEBE5CECB
AC878FFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DAA3E2CEE3
E3FFEBEEFFEEEEEBE5FFEEFFDAEAF2F5E6F7FFE2D8D9F7F1
F5EEE3F3D1ECF5F2ECE6EEF7EBEEFFEAF5E6F3F3EBEEFFF3
E6E5EBE2F3EEEAD1DEF7F2F1FFF2EAFFF7F7F3ECF5F5ECF7
F3F7F7F7F7F7F7FFF7F7F3FFF7FFF7F7EBFFFFFFF7F7FFFF
D9DEEEEBFFEBF7EEF7FFF7F7F3FFFFFFF7F7FFFFF7F3F2F7
EAEAEAFFF2ECF5FFECE3F7FFFFF7F3E3D1ECEBEED9EAEB9B
9698E3F3F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE398DAD0DA
E5E3EEF2F3F7EBD6F7EEFFE5E5F5F1F5EEDFEBFFE3EBF1F7
ECDEC4B5D2EAF3E2ECE6E6E2E2DAE6D6DEF3FFFFF7F3F3E6
F3F3D6F7E4EBD9E2F5DEEAEBE2EEF3EBF3F7F7F7F7F2F2F3
F7F7F7F7F7F7FFFFFFF7FFF3EEF7F7F3F7EBF3F7FFF7F3F3
EEF3F3FFEBFFE6F7F3F7F3F7FFEAECF7ECECF7ECEAF1F1F5
F5F5FFF5F2E5D8D8E2F7F7F3F7EACAEBE2D1F5EBCB937F69
7EDAF3FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3B5DAD0
D9DAE3F7ECF3E3F5EBF7EEEAEAFFFFFFFFFFE5D6EBF5F2E2
EAEAFFEBEBFFDEE3ECDEDEDEECE2F7ECD9F3F7F3EEF3F3EE
F3F3FFCBF7D1DEF2D9E5ECD9E2E6E3F7F3F3F3FFF3F7F7F3
F7F7FFFFFFFFF7F3F7F3F3FFF7F3F3F3F7F3EBF7FFFFFFF7
F7FFFFF7F7EEEBE3EBFFFFF3EEEAF5F7F1F5ECEAFFFFFFFF
FFFFECDEE2F7F7F3F7F7F7F7E3F7DEF7FFE3E2C7C6B5E393
E2F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEB3C8DE
EBE2E3ECEAF7F3F7EAD9FFE3ECF7ECECFFFFE5DEF7ECDEEA
ECDAE6E2E2ECDAD9F7DEEBE3ECE2EAEAD6F7FFF3F5ECF7F5
ECE5DEC1F7D9F5D1E3EAF2FFF7E3EEF3F3F3F7F3EBEEF7EE
FFF7FFFFFFF7FFF3FFF7F3FFF7F3F3F7F7F7F7EAECECECF3
FFF7F7FFF7F7E2F7EAE3FFF3F5EAECF1F5FFF1F1FFFFFFFF
ECDED9EBF3F3F7EEEBFFEBF3EAECE3ECEBE2BEC4DAD9F583
F7F3F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDAACBE
E3E2E3E5F5ECFFF3DAF7E3EEF7FFD9DEFFF7F3E3F2D6CBE5
ECD6D6E3DEE4EBD6F7EEEEF1F7F7EAF5E2EBF7F3E2F5F5F1
F1F1C9D1E5EBDEC4F7EEF7EBEEFFF3EEF7F7F7F7F7EEF3F7
F7F3FFFFFFF7F7FFF3F7FFF7F7F7FFF3E2D6ECE3F7FFECEA
E3F7F7FFF7EBF7E2DEF5EBF7EAF5F5FFFFFFF5F5F5EAE4DE
E2EEECF5F7F3F3F3F3F7F3E2D1D1ECF7D2C5DADED9E3D08F
EBEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCEAD
DEEBECE3D6EAF7F7EBF1F1EEEEF2DAF7DFF7F3E3F2E6E6EE
FFFFD6F7EBE4F7EAECEEEEF5F5F3F3F7EAECF3F7DEFFF2F2
F5F5E3EBD8EBE2D8F3FFEEF3FFEBF7FFF7FFF7FFFFEAE2FF
FFF7F7ECE4ECFFF7FFFFF7F3FFF3FFF3E2FFDAE4D0EAFFEC
EAF7FFFFF7F3F7EBFFEBFFDFD6D8DEE4EAEADEDEE2EBEBEB
F3ECF7EAEEF3F7FFF7D9D8EAEBE6FFD9E3EEECE2DEF7B0C2
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEAC
9EBEEEEAD6F7ECF7F7ECFFE3EEF5F7D6D9FFF5E5F7FFFFFF
F5EAE5F7E5CDF7F7E4DEF2F7EAF7F3F3FFEAECF3F2F5F3F3
F7F7F7EAD8F7E3F5F7F7FFF3EEF7F7FFF7FFF7F7F3E2EAF7
FFFFF3ECE4ECFFF7F7F7F7F7F7F3FFF7EAE6E6DAC7E3F7FF
FFF7F7FFFFFFF7FFEBE6F7F7F7EAE2E6DFE6EEEBEBF7F7F7
F5F7ECFFF3E6F3F7E3EAEEE2EAEEDAECEEE5D1D6F2C9B9DE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE
C895D6D0DADAF2F3F7FFECF5FFFFF2ECF2D6F3D2D9E3F7EE
E3EAEAE5DEC4FFF7E4DEF2F7EAF7F7FFF3FFECF5F5F5F7FF
F7F7F7ECEAF7F3EAEAFFF3EBF7F7F3FFF3F7F7F7F7FFEAE3
F7FFF7EAE4ECFFFFFFF7F7FFF3F7F7F7F5D6EBF5E5AAD1EB
F7F7F7FFF7F3F7F7F3F7F7F7FFF5F5FFFFF7F7FFF7E3D6D9
EEEAF7F3F7D1D1D1F2E2DEEEC4C5E5FFDAC8D9FFF3B0C5EE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7AC9CB5CFD0D9F3F3F7FFF7F5F1ECF2DECBD9D9D9F3E6F7
FFE6E3EAFFD8F3FFEAE3F7EEE3ECF7F7F3F7F3E3FFF5F7F7
FFFFFFFFF7EBF7E3F5F7F3F3FFF7F3FFF7F3F7F7FFF7EAFF
E3F7F7DADEFFE4ECFFF7F3F7F3EBF7F7F7D9DAE5DFBFEAB6
B0CEF7ECDEDEF3FFF7EEF3EBEBF3F3F3F7F5F1F5F7E3D6D6
D9F5D1BEC2E2E3D8F5CBB0D6ECDAFFDFD0E3F2CE93A4DAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFD1A3BCEEDAE3EBEEF7F7F2EAF5F7F7E6EBD9E2EEDFD1
D9D1D6ECFFD8F3EBF5EBEBFFEEF5EAECFFFFF7F3EAF1F3FF
FFFFFFFFF7F7EBE6F7F3F3F7F7F7F7F3F7F7F7F7FFFFF7DE
E4F7EEFFEBECECECE4EAF7F3F7F5EAF3F3FFD9BEEEBDE3D9
E5CFB6D6EEE3DED6DEE5F7F7FFF7FFFFF7EAE4EAEBF7D9D1
D1D6DAECD9C4F7D8D0FFE4ECECECE6E2DAEECD7ED1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFD17AF7EEDAECEEEBF3FFF7F5E4EAECD1D9EBEEE6D6
D1D1D6E4ECDEEBDEF5F7F7EEE6EBF5EAF3F3F7FFEAFFECF7
FFFFF7F7FFF3DFEBEEF3F7F7F3FFEBEEF7EBEBF3FFFFF3E2
ECFFF3F3E6FFECE4ECF5EAF7F3DEEBE2F1E4E2CBD1DEEBBF
F5D6D6DAEEFFFFEEEEDED9E4E2EBF3F7FFF7F3EAD1D1D9EE
EEF7EAD9ECBCD6ECFFECECE4ECEEDAD1EEEC95C8F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF82B0EAF3E3E4E2E5F2FFF5ECF5ECEAF5EEEBEBE6
E6EEEBDFD9EAEBEBF1FFF3F7F7E3EBF5DEFFF3F7EEEAF1F7
F7FFF7F7FFF7F3F7EBFFF7F3F7F7EBF5E3FFFFFFF7FFF7FF
F7FFF3F7F3F7ECECECECECE4ECE3CEE4D6F7E2EADFD9E5F5
BFD6DAEEFFEEFFEBDEEEF7F7F5F1F5F2DED6D8DEEEF7F3D6
D6EBF7EBEEECECECECE3D9E6DFD9E3E6EA99ACFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFD99A9FFFF3EEF1D9DEE6EEF5ECF7EAF5FFF7F7E5
D9E3EEDFF7E5ECECFFF1EAF3F3FFE6FFE2EEF7FFF7EAF5FF
EBF7FFF7F7F7F3EBF3F7FFEBFFF3F7E3ECF7FFF7F7F7FFF7
F7FFF7F7FFF3ECECFFECE4E4ECECDEABD9E3EBE5E6ECCBBF
FFD9D1C4ABABD2D6CDDAD9CBB8BDC3C3D9F3FFE3D8D1DEEE
DEE5F7FFFFF7F3F3E2DAF7FFEAECFFD690A3F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7E287A8ECF7E3EAFFFFEEEBECEAF7F5F5EBE6EB
F3D9F5E3E3D9DEECFFF5EAF7F3FFEEEEF5E3EEF7F7F7F2F5
EBFFF3EEF7F7EBE6F7F7F7EBFFF3F7FFF7FFF7F7FFF3FFFF
FFFFF7F7FFF7F7FFFFFFFFFFF7E3E4EAC8D0EAEAEADAEBE3
B5A5CADECED6F7D9E6D9E2F7F3EEF5EAD9DFDEFFD8CBADC3
E4EAEAD6D6EAF1EAE3F7EEFFE4F3F397A8F7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDAA3ACF7EBEAF3F3EBF3F7F7F1F2F7EBEBE2
E3D8D6FFEEEEFFE3E2F5F5F7F5ECFFEBEBE2D9F7F3FFEAF7
E2E3F3F7FFFFF7EBFFF3F7EBEEF7F7F7F7ECECF3FFF3FFFF
FFFFF7F7FFFFF7F7ECECFFFFEBEEF3F3FFBEB6D9F2FFDED6
D9DFE5E3D8C3A897A3A9BCD1DEE4F2F7E3D9D2D9F3ECE5EB
FFFFFFEEEEEEEEF7EBEEE6E3D1DFF375E3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFDA936782C6EEE6E3F3F7F7F2DEE2EBF3EA
FFFFD9EEFFE5E5F7DAE2F7F3ECF5F3EBF3F7D9BECAECF3EC
F5E3EAF3F7FFF7E5E3F7EEF3F3F3F7FFF7E3ECF7F7F3EEFF
FFF7F7F3FFFFFFF7E2E2F7F7F3F7FFF7E5DEEAE5CAC4DAF5
F1EAEAFFDEC3B6AFA9B4CDD6D8D1DEF1F1F2F3F2F5F1EAE4
EAE4E4E4E4DAEEEED6B5C4E2DEBE8190FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7AC71DEECF3EAD6E5F7F3F7F3F7EE
D9E2F3EEEEECFFECF7CEF5F7FFF3F7F3F7FFF7EBF2C4E2F5
E2EEEAEAEAECEAFFEBEBEEF3F7FFF3FFF3F3EBF7F7EEF3F7
FFF3F3F3F7F7FFFFFFF7EEF7F7F3EAF5EAE4ECEBD1E5D9C3
DAF5EEE4CBBCBDBCB1B4C9BEB0B9BCB6B0D1F3E2D6D9ECF3
F3FFFFF7EADAD6D6D1FFF7EBA19AD9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF75DAE3E2EAE5EBEBF7F7EBEBDE
DAF7F7EEDAE4E3DED1C6DEFFFFF7FFF3F7F7FFF3ECF7CFDE
EBF7F3EBEBE3F7F5F5DAEBE6F3F7EEF7F7EEF5E3F7F3F7EE
F7F3EAEAF2F7F7F7F3F7E2D9FFF7F1EAE2F7ECD9DEEEEBEE
CFC3CFE3B6CDF1F7F2FFF2F7EAF2F5D6D1D9F3F3EBE5EAF5
F7ECE4D9D6EBE4FFE3EBEBAC90E2F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAC90D1DADAFFEBF3F7F3F3FFF2
D9D9DAFFE4FFF3EAE5C4E3E2F3F7F7F3F7F7F7FFF7ECE5F7
EBF3F3F3EBE3E3EAF2D9BEF7E3E3F7F7F3F7ECF5EBF3EAEC
EEF7DAEAE5E2ECFFF2F5E2F2D1ECF5D9CDCAD6EAF5FFEEE2
FFFFE3C9CDE5E6D6D8E4D1D2EBEBEEF7F7FFE5DEEAF5EAFF
E4DAE6F7EEF5E3F3FFD99F90E3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFB58AACDAD9E3F7F3F7FFF7F7
EEF5F7DAECECF7E2E3D6E6D9E3F3FFECECF7F7F7F7F3F7EB
EEF5F5F7F2EAD6EBEBD2DAC7D9EBE4EAF7ECD6E2ECE2ECF1
F2D9EBE2D1EEE3EAECE3DEEEF5E3F7E3E5E4CEC4CAD9D9D6
DEE4EAEAF2E6E6EBE5D8F2F7FFFFFFECEAEAFFEAECF7D6D6
E6EEECDEC5D9F7F7D17E9FE2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFDA90A8C7DED1F7F2E4EAF7
F7F2F7ECE5ECFFFFFFEADEE2CFD0ECECECF7F7F7FFFFF3F3
F3ECFFEAECFFD9EBEEF2C9B5DAEAFFE2F7E3D9ECF2F7EEF2
F2EBD6D6CEECDADFE5DFD9BFD1C4BDD9D9B6CFF2EECBDAF2
DED8D1D9D9CBCBE3F1FFEAEAEAF3EAECF5F5EAD1CAD9F7F7
EEEBEAF7D6DEF7FF76B5F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFDAACACD9CEE5EAEAFFF5
F7F5DEF7E5ECFFF7EBF3F3D1DEEED1DEE4EAF7F7FFF7FFFF
EEE5EAEAF5F7EAE2E4D0D9DFC4F7ECF5E3F7D9E2FFEEEEEB
E6EBEAD6EBDEE2FFE5DED1EEFFCAE4A8A8C4E2D9C8CAE3F5
FFF5F1FFFFF1F1F5F1FFF5F5F5F1F5FFF7EBD9E5FFF7F7F7
EED9DAEBE2C7DEC272FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDAAA9BA2D9DEE5ECF5
ECE2DEEEE3E3ECF3F3F3F3BFC4EAEEE3EBEAD8CADEF3F3F3
E5F7F3EBE2F7F3EBF7DEC8EBE3ACD9EEE3C8F2EAD6FFF7EA
F5F7E4F2DED1DAE3EAF3E4F7EED1C7CBDAE6ABC2EBEAFFF7
F7F1F7EAF2E4E4DEDEEBF3EBE6E6E6E6D9EAE5D2EBFFFFEC
E4D1FFD1DEF79568B5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEECE8789A0CECAD2
CED1CFDAEBF3ECDEDEE3DEE2F7E2DEE3E5E2E3D8BCA2A9C3
CACAD1F2D9EAF3EBE3EBD9CAEAE2CBCEE3E3AAA4FFCBCAF2
ECE4F7ECEADAFFD6D6EAE3D0D6E3F5EAF5D6F7D9F1ECF7F7
FFECEAE3F7F7F3EBEEEBF3F7E6E6E6EEECFFD6CBD6DED1DE
F2C3C3BF55417FD1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDACEA2A8D1E2
E3F7EAECEEEBEBD9D9DEECE2E3E2F7ECEADEDEF7FFFFF7EA
DED1CECED6EAF7F7EBDAFFF7E3EBF3E5CED0E3F3B3C4CED6
E3EAEAEAF7F2DEDAEEEEEBD9ECEBE2F7ECE3E6F7E6EBE6DF
EBEBE6EBF3EBEEEEFFE6EEEBF3EBD6DEEAE3F3E3D2DEECE5
E2D87A73BEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEDABC9EB4
B9C1E2F3F3EBF7E3DADEFFF7EAECEEE6EEF3F7F7F7F7F7F7
FFF7F5DECABED2EEECE5EBEBE5E3F7EEE5DED2D9E3D1DABD
E3EAECFFECEAF5D1F7E5E2EEF3F7F7EAE5EBF3F7EBE6DFDF
E6E6E6DEDEE6EEFFEEEBF7F7E2EAE4F2F2F3EEFFD9D6D9D6
DE8A87D1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE6C6B3
C8D6CAF2F5FFF3F7F7DEFFFFF7F7EEE6EEF7F3F7F3F7EEF7
FFF7F7FFFFFFECD6D9EBEBEEE2F7E4ECEEEBF7FFEEE5D0D9
FFE4ECF7EBE3EBD9CAC1ECCAD9FFFFF3F3F3E2E4EAF5FFFF
FFF5F5F5FFEBE6E6D6DEEEE2EAECE3F7F7DAF2E3E3CDDED1
6F6BD9F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDA
B3A2A3D2E2FFF7F3F7E5CEECF7F7FFFFF7F7FFFFF7F3F7FF
FFFFFFF7F3F3F7E3B5CAE4DEE3E3E3ECD6D1E5E5ECD9D0E2
DADEDEEADAE6FFEBE3DEC5B9F3E2F3F7F7EBEBF5F5F5EEEE
F7E5DEE6DEE3FFECFFF7DEECF7F3DAE3EEF2C7CDC9ECB374
84D9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EEBC97B3C7E3F7EBEBE3E3E4DADAFFF7EEEBFFFFF7F7FFFF
FFFFF7EEF3F7F7EAECEAE3FFE2D9DEFFFFF7C8D9EAECD9DE
E3EEFFEAF7EADED6DFE6F3E4DAE5EBD9DFE6EEEBE5EBF7F7
D9E5F7FFE3E3F7EAEAECF7E3DEEED8D8EBBFD6E29A6F6798
F3F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFD1987F93C1CEDEEAF5E2EAE5ECF7EBDAECFFEAEAEEEB
F7F7EEF7FFF7F3F3F7EAE5E2DED0E2F7FFF3FFE3D6E3FFEC
ECDEC4B9C4D9D9D6D8D8D1D6EBE3FFF3F7FFEBEBF3F3F7EE
F5EAECDEEAEAD0D2CECEE6E5FFDEE2C7DEEEA4797B94DAF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7DAA4755C5B8DCAF7D9D1DECBC4DEECD6BCD1F7F3
F3E2E3E2DEEBF3F7F7EBEBE3ECE4FFF7F3F7FFFFF3F7E2DE
D9E2F3EEECF1F1E4D8D8D8D8D1CED9D6C4CEE2D1D6D6C4D1
D1CBBEC4BECED1E5D6EECAC4AAB7EAD68B4E61A4DAF7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEE98557A8FCAFFF3EBEBEAD6D6EAEEEE
F7F5F2F2F7DEE3F7F3F3F7F7E3ECFFFFFFFFECDED9F3ECEA
F7FFFFF7EBEBF3FFF3F7FFF7F3EEEBEEDFE5F3EBE5E5ECD1
CBCBD9F3F7E2E2D9E3D6BEECD1B08A7390D1F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFDAA4866F90A3B9D8E3FFD6DED9D9
C9C9D8DEE3F7E2D6E4ECEAD8EAFFE3E2F7FFE4F7F2EAE4EA
EAE4E4E4ECF7F3EBD6E2F7EBEBF7F3E6E6E6D1D8EAEAE2E2
C4B8B2C4D1B09DA9C1F3E4E2AC7F94D9F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEEBC968A776F6F6890C4B8B8
C4C1CEE3DAD9F7F3EBD9E2EAECFFDED8F7F7E2D8D8D8DEEB
EBF7F3F7ECE4ECFFECEAF7FFF7F3F7E3E3F7EAD8DED8CBD6
EEFFF3F5DEE3FFFFE3D99A6876D1F7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE6E6EBD9CBDEEA
E3E5C8DAEAEBC8BCC1E3F7E3D8D1E5E4FFEAE2F3F7FFEABC
C4D6D8EAECECECECF7F3F7F7F3F7FFE2D9EBF7F7F3F7F7F7
F7F7F3F5E2E4D6B4B4A887E2F7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE6
F3F3E5D9DFEBE3E2EBB4B4D1F7F7F3E2D8F3F7ECEAD8CFDE
F3F3F7E2EAE4FFEAE5E2FFFFF3F7F7FFF3F3F7F7F7F3F5EA
EAEAE4E2F3B394878AA4D9F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7EBEBE5D9DEDEE2D9EBD9BEC4BEC4D9EAFFEADEEBF2DEFF
F7F7F7E2EAEADEEAEAF5E5EAFFFFF3F7F3F7F7E3EAE3EAF5
EAE4B98A7283BDDAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7EEEBF3EBEEFFF7D9CBCBC4A8817C96A9A3B0A8B0
D1CBCBDEE2D1E2ECDEEADEEAFFFFE2D6CECBB47C70553A46
494F6DA4DAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE6D6CBCBA4
90A2B0A9AABDB4A8B194838175757F7C8190A0CAD1DAEEEE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEEE6E6D9C2BEC4D1D8D1D6EBEBEEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Green) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFF
FFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF4FFF4FFFF
FFFFFFFFFFFFFFFFF4FFFFF4FFF4FFFFFFFFFFFFFFFFFFFF
FFF4F4FFFFFFF4FFFFFFFFF4F4F4FFFFFFFFF4F2F2FFFFF2
F4FFF4F4FFF4F4FFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFF4
F4F4F4FFF4FFFFFFFFFFF2F2FFFFFFFFFFFFF2FFF2FF9EE8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFF
FFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7F7FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFF7F7F7F7FFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4EDF7F7FFFF
FFFFFFFFFFFFFFF7F7FFFFF7F4FFF7FFFFF7F4F4F7FFFFF7
F7F7F7F7F7F7F7FFF7F7FFF4F7F7FFFFFFFFF4F6F6FFF6F6
F4FFF7F7F7EDF7F4F7FFF7F7FFFFF7F7FFFFFFF7F7F7F4FF
F7F7FFF4F7FFFFFFFFFFF6F6FFFFFFFFFFFFF2F6FFE59FEF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFF7F7FFF7F7F7F7F7F7FFF7F7
F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFF7F7FFF7F7F7F7F7F7FFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFFFFFFFFFF7F7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E0F7F7FFFF
FFFFFFFFFFFFFFF4F7F7FFF7F4F7F4FFFFF7F4F7F7F7FFF4
F4F7F7F7FFF7FFFFF7F7F7F7FFFFF7F4F4ECEBF6F6F2F6FF
F7F7FFFFF4EFFFFFFFFFF7F7FFFFF4F4FFFFFFF7F7F7F7F4
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2F2F6BEBAFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFF7F7FFF7F7
F7F7FFFFFFF7F7FFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFF7F7F7F7FFFFF7F7FFFFFFFFFFFFFFFF
F7F7FFF7F7FFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFF7F7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E0F7F7FFFF
FFFFFFFFFFFFF7F7F7F7F7F7FFF7F7FFF7F7F7F7F7FFF4FF
FFF7F7F4F7FFF7F4F4F4F7FFF7F4EEF6F6F6FFF6F6F7F4F4
F4F7FFFFF7F7FFFFF7F7F7F4F7FFF7F7FFFFFFFFFFF7FFFF
F7F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6FFF6EFB2D9FF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFF7F7FFF7F7FFFF
FFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFF
FFFFFFFFF7F7FFFFFFFFF7F7FFFFF7F7F7F7FFF7F7F7F4F7
F7F7FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E0F4FFFFFF
FFFFFFFFFFFFF4FFFFFFF4FFFFF4FFFFF7FFF7F7F7F7F7F7
F7FFFFFFF7F4F7FFFFFFF7F4F7EEF7FFF6F7F7FFF7FFF4F7
F7F4F4F4F4F7F7F7F4F4F4F7F7FFFFFFFFFFF7F7FFF7F7F7
FFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF6FFF6D9B2EFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7FFF7
F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFF
FFFFF7F7F7F7FFFFFFFFFFFFFFF7F7FFF7F7FFF7F7F7F4F7
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E0F4FFFFFF
FFFFFFFFFFFFF7F4F4F4F7FFFFF7F7F7F4F7FFF4F7F4F7FF
FFFFF7F4F7FFFFF7F4F4F7FFFFEBF3EEF7F4F4F7EFEFF4FF
F7FFFFFFFFFFF7F7F4F7F7F7F4F7F7F7F7F4F7F4FFFFFFF7
F7F4F4F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF6EEC6C2FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFF7F7F7F7FFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBE8F7F7FFFF
FFFFFFFFFFFFF7F7FFFFFFFFF7F7F7F7FFFFFFF7F7FFFFFF
F7F4FFF4F7FFFFF7F7FFFFF6F2EEF7F7FFFFFFF7F7F7FFF7
F4F4F7FFFFFFFFFFF7F4F7FFFFF7F7F4F4FFFFF7F7F7F4FF
F7F7F7FFFFF6F6F6F6FFFFFFFFFFFFFFFFFFF6E7B2DCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
F7F7FFFFFFFFF7F7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFF
FFF7FFF7FFF7F7FFF7F7F7F7F7F7FFFF
FFF7F7FFFFFFFFFFFFF7F7FFFFFFF7F7FFFFFFF7F7FFFFFF
FFF7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E0FFF4FFFF
FFFFFFFFFFFFF4F4FFFFF7F7F4F7F7FFFFFFFFFFFFFFF7F7
F4F7F7EDF7FFF7F4EEF2F2F6FFF7F7F7EFEFEFF7F7F4F7FF
FFEFEDF4F4F4F4F7F7F4F7FFFFFFFFF7F7FFF7F7F4F4FFF4
F7F7FFFFFFF6F6F6F6FFFFFFFFFFFFFFFFFFF6D1AEF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
F7F7FFF7F7FFF7F7FFF7F7F7F7FFF7F7F7F7FFFFFFFFFFFF
FFFFF7F7FFF7F7FFF7F7FFFFFFFFFFFF
FFF7F7FFFFFFF7F7F7FFF7FFFFFFF7F7FFFFFFF7F7FFFFFF
FFF7F7FFF7FFFFF7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9E4FFF4FFFF
FFFFFFFFFFFFF7F7FFFFF7F7F4F7F7FFFFFFFFF7F7F7EFED
F4F7EDF4F7ECEBF2F6F7EDEFEFE8EDDDECECEEEEEEF7F4FF
FFFFFFE0ECEFEFF7FFF7FFFFFFFFFFFFFFFFF7FFFFF7FFF4
F7F7FFFFFFFFF7F4F7FFFFFFFFFFFFFFFFFFEFB8CAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFF7F7F7F7FFF7F7FFF7FFF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF4F7F7FFFF
FFFFFFFFFFFFFFF7F7FFFFFFF7F7FFFFFFFFF7FFFFFFEFF4
E5EEF7F6EBF6FFFFFFF7EDFFEFEFF7ECEEEEF7F7F7ECECE5
F7F7E5FFE5EFFFFFEDEDFFFFFFFFFFFFFFFFFFF7F7FFFFF7
FFF4F4F7FFFFF7F4F7FFFFFFFFFFFFFFFFFFE1AEEFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F7F7F7F7FFFFFFFFF7F7FFFFF7F7FFF7F7FFFFFFFFFFF7F7
FFF7F7F7F7FFF7F7FFFFF7F7FFFFFFFF
F4F7F7F7FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF4F4FFFFFF
FFFFFFFFFFF7F4FFF7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F4
E4ECEEFFEEFFFFEEEEEEEEEDEDF7F4EDEFFFEEFFEEE6E6E0
E5E5ECECF4E4F6FFE0F6EDEDEFFFFFFFFFFFFFFFFFFFF7F7
F7F4F4FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFD5B0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFF7F7FFFFFFFFF7F7FFFFF7F7FFF7F7FFFFFFFFFFF7F7
FFF7F7F7F7FFF7F7FFFFF7F7F7F7FFFF
F4F7FFF7F7FFFFF7F7FFFFFFFFFFFFFFFFF7F7FFF7F7F7F7
FFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF4F4FFFFFF
FFFFFFFFFFF7F4F7FFFFFFFFFFFFFFF4F4F7F7F4F4EFE8ED
E4E7E5E5E0EEEEE6E6EEFFE5F7F7F4FFF4F4F7EEEEE6EEFF
FFEEEFEFF7E5F7E4FFECE4E4EFE8EFFFFFFFFFFFFFFFF7FF
F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFC2C2FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFF7F7FFFFF7FFF7FFFFFFFFFFFFFFF7F7FFF7F7F7F7
FFF7F7FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4F4F7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F4F7F4EDF4F7
ECE5F7FFEEE4E4E4E5E0F7EEFFF6F6F4FFFFF4FFEEEEEEFF
EEFFEDEDF7F7ECE0F7F2FFECE8EDF7E8EFFFFFFFFFFFFFF7
F7FFF6F6FFFFFFFFF7F7FFFFFFFFFFF7F7F7AED9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FF
FFF7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4D4F7F7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F4F7F7F7F4F7F4F4
FFF7FFF7F7FFFFFFF7F7DBEEE6ECEBF7F4F4EFF4F7FFEEEE
FFF7EFEDE8EFF7F7EEEEF6F2F2EBE4EDF7EFFFFFF7F7FFFF
F7F7F6F6F7F7FFFFF7F7FFFFFFFFFFF7F7EDAFE8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7
F7F7F7FFFFF7F7F7F7FFFFFFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4D4F7F4FFFFFF
FFFFFFFFFFFFFFFFF7F7FFFFF7F7FFF4FFFFF7FFEFEDFFFF
F7F7FFFFFFFFFFFFF7E4FFECEEECEBFFFFFFF7F7F4EFEFEF
FFF4F7F4F7EDF4EDEFEEEEEEEBF6F6EBE0F6EFFFF7FFF4F7
F7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFE1AEEFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFF7F7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFF7F7FFFFFFFFF7F7
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDD9F7F4FFFFFF
FFFFFFFFFFFFFFFFF4F4FFFFF7F7FFF4FFFFEFF4F4F4F7F7
F7F7F7F7FFFFFFFFF7E4E5F7E4E7EBFFFFF6F2EBF3EDEDEF
E8F4F7F7F7F7F7FFF4F4E5FFF3F6EBEEEEF3EFEFE8F4F7F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D1AEF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFF7F7FFFFFFFFFFFFFFF7F7F7F7FFF7F7FFFFFFFFF7F7
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8DBFFF4F7F7FF
FFFFFFFFFFFFFFF7FFF7F7F4FFFFF7F4F7F4F4F7F7F7F7F7
F4F7F7F4F7F7FFFFFFFFFFFFF7E5F7F2F6F6F6F6F6F7F7FF
FFF4F7EFF4F7F7F7F7F4F7EEF7F2ECEEFFEBF6EDF7F7EFF4
F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFF7EFBDCEF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFF7
F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8DBFFF4F7F7FF
FFFFFFFFFFFFF7FFFFF7F4F7F7F7F7F7F7FFF7F4F7F7F4F7
F4FFFFF7F7F4FFFFFFFFFFFFF7E5F7F6F6F6F6FFF6FFF7F7
FFF7F7F7F7EDF7FFF7F4F7FFEEE6FFEEE6F6FFEBE4EFF7F7
F4FFF7F7FFF7F7F7F7FFFFFFFFF7F7F7EDB6E8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF7F4F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7FFFFFFF7F7FFF7F7FFFFFFFFFFFFF7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8DBF7F7FFFFFF
FFFFFFFFF7F4FFF7F4F4F7F7FFFFFFFFFFFFF7F7F7F7FFF4
F4FFFFFFF7F7FFFFF7F7F7F7F7EFE5F7F6F3EBFFF7EEF7F7
FFFFF7F4FFF7F4FFFFFFF4FFFFFFE6E6E6F6F7EEEBF7EFF7
EDEFFFFFF7FFFFFFF7FFF7F7FFF7FFF4E5AEEFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7F7F4F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4FFF7FFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFF7F7FF
FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9E4F7F7FFFFFF
FFFFFFFFF4F7FFF4FFF7FFFFFFFFFFFFF7F4F4F7FFFFF7FF
F7FFF7F7F4FFF7F4F7F7F7F7FFF7F7E4E7F6F6ECF6EBF6F6
FFEEEEFFF4F4F4FFF7F7F4FFFFFFEEFFFFEBECE6EEF3EDF4
F7E8FFF7FFFFF7F4FFFFF4F4FFFFF4F7DBB0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF7
F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFF7F7F7F7FFFFFFFFF7F7FFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF4F7F7FFFFFF
FFF7F4F4FFF7F4F7F7FFFFFFFFFFFFFFF7F4F7FFFFFFF7F7
F7F7F4F4F4FFF4FFFFFFFFFFF4FFFFFFF7E0E0ECF3F3ECEE
F6EBEBFFF7F7F4FFF7F7F4FFFFFFFFE6E6F4F3F7F2F6F4F7
EDEFEDFFF7F7F4FFF7FFF7F7FFFFF4F7C6C2FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFF7
F7FFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFF4F4FFFFFFFF
FFF4F7F4FFF7F7F7FFFFFFFFFFFFFFFFF7F7F4FFFFF6F6FF
F4F7FFF7F4F7F7FFFFFFFFFFF7F7FFFFFFE5EEEEE7F6EEF7
EBF2F2FFF6F6F7F7FFF7FFF7FFFFFFEEF6EEFFFFF2F6F7EE
E0F7F7F7F7FFFFF4F7F7FFFFF7F7F4FFC8C8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFF7F7FFFFFFFFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDDDDF7FFF7F7F7F7
F4F7F7F7F7F7FFFFFFFFFFF7F7FFFFF7F7F7F7FFFFF6F6FF
F4FFF7F4FFF7FFF6F6FFFFFFF7F7FFFFFFFFF7F7F4EEFFEE
E6F2F2FFF6EEF4F7FFF4F7F7FFFFFFFFF7ECF7FFF2F6F6FF
ECF7F4F4EDEDF7F7F4F7F7F7F7F7F4F7BDD1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFF7FFF7F7F7FFFFFFFFF7F7F7F7FFF7F7FFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFB8DCF4FFF7F7F7F7
F7F7F4F7FFFFFFFFFFFFFFF7F7FFFFF4F7F7FFFFFFFFFFFF
F4FFFFF7FFF7FFF6F6FFFFFFF7F7FFFFFFFFFFFFE4ECE5F6
F6F3F2FFFFF4F7F7F7EDFFFFFFFFFFFFFFF7EBF2F7F3FFF6
F7EDEFFFEDFFEDEFFFFFF7FFF7FFF4F4AFEDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F7F7FFF7FFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7F7F7FFF7F7FFFFFFF7F7FFF7F7F7F7FFF7F7FFF7F7F7
F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE5B2CBDBFFF4FFFFF7F7
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF7F7F4F7FFF7
FFF7FFF7FFF7FFFFFFF7F7FFF7FFF4F4F7FFFFFFE4F7ECF4
F7F7F6F6FFF7F7F4F4EDF7F7F7FFF7F7FFF7ECF3F7F3F6F6
EEEDEFE8F7EDFFEDF7FFF7FFF7F7F7F4AFEDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFFFFF7F7
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7F7F7FFFFFFFFF7F7FFF7F7FFFFFFFFFFFFF7F7F7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE5B2A1CAD9F4F7FFFFF4F7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F4F4F4F4FFF4FFF4
F7F7FFFFF4FFFFFFFFF7FFF4F7F7F4F4F7FFFFF7FFE5FFF3
FFF6F3EEF6F7F7F4F7EFF7F7FFF7F7F7FFFFFFF4FFF6F6F6
FFF3F4F4F4F7E8F7EDFFF7FFF4FFF7EDAEEFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFA687BD98E7F7FFFFF7FFF4
F7FFFFF7F7FFFFFFFFFFFFFFFFFFF7FFFFFFF7F7F7F4F7F7
FFFFFFFFF7F7FFFFF7F7F7F4F7FFFFFFFFFFFFF7F7F4ECEC
FFF2EBEEF6F7FFF7FFF7F7FFF7F7FFFFFFFFFFF7F4ECF3FF
F6F3F7FFF7F7FFE8EFEFF7F7FFF4F4D9B5FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7FFF7FFF7F7F7F7F7F7FFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC5095C691F4F4FFF7FFF7FF
FFFFFFF7F7F7F7FFFFFFFFF7F7FFF7F7F4F4FFF7F7F4F4FF
FFFFFFFFFFF4FFF7F7F7F4F4F7FFFFFFFFFFFFFFF7E5E5ED
FFF2F2F2FFF7FFF7F7F7F7F7FFFFFFF7F7FFFFFFFFF7F7FF
F6F6F7F7F7F4F7EFEFEFF7F7FFF7F7D4BDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7FFFFF7F7FFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFDD7560EC9D9DEFF7F7FFF7FFFF
FFFFF7F7FFF7F7F7F7FFFFF7F7F7FFF4FFFFF4F7FFF4F4FF
FFFFFFFFF7FFF4F7FFFFFFFFFFFFFFFFFFFFF7F7F7E5F6F7
F6FFFFFFF6F7F7F7FFFFF7F7F4F7FFF7FFF4F7F7F7F4F7F7
F6F6FFF4F7F4FFF7E8FFEFF4FFFFFFCDC2FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFFFFFF7F7FFF7F7FFFFFFFFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F48452BBE0A785F7EFF7F7FFFFFF
FFFFF7F7FFFFFFF7F7F7F7FFFFF7FFF7F4F4FFFFFFF7FFF7
FFFFFFFFF7FFF7FFFFFFFFF7F7F7F7FFF7F7F7FFF4F7F4FF
F6F6F2F6FFF6FFFFF7F7F4F7F7F4FFFFF7EDF4F4F4F4F4F4
FFFFFFF7F7FFF7F7EFEFFFF7F7FFF7BDCFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4FFF7F4F4FFFFFFFFFFF7F7FFF7F7F7F7FFF7FFF7F7F7F7
F7FFF7F7FFF7F7FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA03743A7F7C58692EFEFFFFFFFFFFF
FFFFF7F7FFFFF7F7F7FFFFF7FFFFF7FFFFF7F7F7FFFFF7F7
FFFFFFF7F4F7F7F7FFFFFFF4F7F7F4E8F4F4EDE5ECF4F7F6
F2EBF3FFF6F6F7F4F7F7F7F4F7F7FFFFFFF4F4F7FFFFFFFF
F3F2F6FFFFFFFFFFF7F7E8EFF4EDEFAED9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7F7F7FFFFFFFFFFFFFFF7F7FFF7F7FFF7F7FFF7F7F7
F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF736AAF4DBFF6487DDFFFFFFFFFFFFFF
FFFFF4F4FFFFF4F7FFFFFFF7FFFFFFF7F7F7FFF7FFFFFFF7
F4F4F7F7F7F7F7F4FFFFFFF7F4F4F7FFF3EBEBE5EEF2F2F6
FFF7FFF4F4F7F4F7FFF7F7EDFFFFFFFFF7EDF4FFF7FFF7F3
F7F2FFF6FFFFFFFFF7FFF7EDEFF6E5AFE8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFF7F7FFFFFFFFF7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFF7F7F7F7FFFFF7F7F7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFF
FFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7CC26F4E5E47653DDFFFFFFFFFFFFFFFF
F7F4F7F4FFF7FFF4FFFFFFF7FFF7F7FFFFF7F7FFF7F7F7FF
F7FFF4F7FFF7F7F7FFFFFFFFE0F6FFF6F6FFFFF4F7F7FFFF
FFFFF7F4F4F7F7F7F7F7F7EDFFFFFFFFF7F4F7FFFFF4FFF6
F6FFF6F6FFFFFFFFFFF7F7F7EDDDFFC1E8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFF7F7FFFFFFFFF7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7FFF7F7F7FFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFED717FEDEC7D53D5FFFFFFFFFFFFFFF7F7
F4F7F4F7F7FFF7FFF7FFFFF7FFF7F7FFFFFFFFFFF7F7F7FF
F7FFF7F7F7F7FFFFFFFFFFF7ECF3FFF2F6F6F6EEF4FFF7FF
FFF7F4F4F4F7F7F4F4F7FFF4F7F7FFFFFFF7F7FFFFF4FFF6
F6FFF6F6FFFFFFFFFFFFFFFFFFE8EEBCEDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7F7F7F7F7F7FFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7A050CAF4A164D5F7F7FFFFFFFFFFFFF7F7
F7FFF4F4FFF7FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFF7F7
FFFFFFF7F7F4FFFFFFFFFFF7F7ECF2F6F2F2F6F6FFF7FFF4
F7F7F4F4F4FFF7FFFFF7F4F7F7EFF4F7FFF4F4FFF7F7FFF6
F6FFF6F6FFFFFFFFFFFFF7F7F7F4F7AFEDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7F7F7FFFFF7F7F7F7FFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7B959A0EDA96DC3F7FFF7FFFFFFFFF7F7FFFF
FFF4FFF7FFF7FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFF4FF
FFFFFFF7FFF7FFFFFFFFE5E0E4EEFFFFF6EEF7FFFFF7FFF7
F4F7F7F7F4F7FFFFFFF4FFF7F7F7F7F4FFF4F4FFF4F7F7FF
FFFFFFFFFFFFFFFFFFFFF7F7F4F7EDC8CAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7F7F7FFF7F7
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7E55786EFB973C3F7FFF7FFFFFFFFFFF7FFF7F7
F7F7F4F7F7F7FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFF7F7FF
FFFFFFFFF4FFFFE5E4F4E7F6F2FFFFFFFFF7FFF4F4F7F7FF
FFF7F7F7FFFFFFF7F7F4FFF7F7F7FFFFF4F7F7F4EDF7F7FF
FFF6F6FFFFFFFFFFFFFFFFFFF4F4EDE5B9DDFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7F7F7FFF7F7
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7FFF7F7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7B23C5AD4DC59A9FFF7F7FFFFFFFFF7F4F7F7FFFF
FFF7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF4F7F7
F7F4F4F4F7FFFFE4FFEEECF2F6F7F4EDE8E8EDF4F4F4F4ED
EDF4F4F4F4F4F4F7F7EFF4F4F7F4F7F7FFFFFFEFF7F7FFFF
FFF6F6FFFFFFFFFFFFFFFFF7FFF7F4F7D5B9CAEFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7F7F7F7F7FFFFFFF7F7FFFFF7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFED6984FFEC9575EFF7FFFFFFFFFFFFF7F4F7F7FFF7
F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7FF
F7FFFFFFFFF7F7F7E5FFEEFFF7F7F7F7FFFFFFFFFFF7F7FF
FFFFFFEEEEFFFFFFF7FFF7FFF7F7FFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFF6F6F6F6FFF7FFF7F7F4F7DDC9D9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7F7F7FFF7F7FFFFF7F7FFFFF7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7B649CCF7BB6CC3F7F7FFFFFFFFFFFFFFFFFFF7FFF4
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F4F7F4
FFFFFFFFFFF4ECDBE0EED5C3C8CFD4DBCDD1D1D1E0DDE5E0
E5FFFFEEF6F7F7F4F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF6F6F2F2FFFFF7F7FFEFFFEFDCC0EFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF76579F4D56BAAF7FFFFFFFFFFFFFFFFFFFFFFF7F7F7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F4FFF7
FFFFF7F7FFE4DDF6D4C3FFCDE5FFEFE8EFE6E6E6E1D5D4E1
D1C8D4E4FFF7F7F3F6F6F6FFFFF6F6FFF6F6F6F6FFF7F7FF
FFFFFFFFFFFFFFFFF6F6FFFFF6F3F7F7F7EFEDB8D1FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFF7F7FFF7F7F7F7FFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7
FFFFFFFFF7F7FFF7FFF7FFF7F7F7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE545B2E78295F4F4FFFFFFFFFFFFFFFFFFFFF7F7F7F7
FFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFF4F4F4F7F7F7
F7FFF7FFF7DBFFF6D4BCF6CDE5EFEFFFFFF6F6FFE6F7EFFF
F6EEEDDCD4D4E0F7FFFFF6FFFFF6FFF2FFFFFFF6FFF7F7FF
FFFFFFFFFFFFFFFFFFF6F6FFF6F3F7F4F7F4F7E0BBD5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFF7F7FFF7F7F7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
FFF7F7FFF7F7FFF7F7FFFFF7FFF7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFB656D4A764E4F7F7FFFFFFFFFFFFFFFFFFFFF7F7F4FF
FFFFFFFFFFFFF7EEE4F4F7F7F7FFFFFFFFF7FFF7F7F7FFF7
FFF7F7E5D4E5FFFFFFF6BCFFFFE8FFFFFFF6F6FFE1E1FFFF
F6FFF6F7F4EFE8D9ECF6F6FFFFFFF6F2F6F2F2FFFFFFFFF7
F7FFFFFFFFFFFFFFFFF6F6FFFFFFFFF4F7F7F4EFD4BDEFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF6D77E469A8EDF7FFFFFFFFFFFFFFFFFFFFF7F7F7F7FF
FFFFFFFFFFF7F7E4EEF7F7F7EEE5FFFFFFF7F7F7F7F7F7F7
FFDDD4DDFFFFD4D4FFF6CAC1DDE8FFFFFFFFFFE6EDE8FFFF
FFF6FFF6FFF7EEEEE6EFF6F6FFFFFFFFF6EEEEF6F6F6FFF7
F7F7F7FFFFF7F4F7FFFFFFFFFFFFFFF4F7FFEFF7EDCACAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC933FF25987F7EDF4FFFFFFFFFFFFFFFFFFF7FFF7FFFFFF
FFFFFFFFF7F7F7F7FFF4FFE5F7E4FFFFFFFFFFF7F7F7DDD4
D4E5EEEEFFFFD4A9C3B09EAACAE5F2E4DBE4E4CCE1EFF6F6
F6F6F2F2FFFFF6F6F4E7D5DDF2F2F6FFF6EEEEFFF6F6F6FF
FFF7F7F7F7F7F7F4FFFFFFFFF6F6FFF7F7F4F7EFF4E5BBCC
FFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFF7F7FFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4
87BE786B9BF7F4F7F7FFFFFFFFFFFFFFFFFFF7F7FFFFFFFF
FFFFFFFFF4F7F4F7FFF4F7E7E4F7FFFFFFF7F4F7FFE5E5FF
FFDDEFEFDDF6ECCDEFEFF6EBE0E0EDEDFFE8EFECF2F6F2F6
E5E0ECF6F2F2F2F2EEF3EEE1FFFFF2F6F6F2F6F6F6F2F6FF
FFFFF7F7F7F7F4F4FFFFFFFFF2F2FFFFF4F4F7F7F7EDEEAE
F7EFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF482
8FC2CD3EE5F7F7FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFFFF4F4F6ECFFF4EDF7EDF7FFFFF7F7F7F7E5E5FFFF
FFDDDDDDD5D1C5D5DDE0E0E5F4FFF7F7FFEFE8E8E8E0E7ED
EFFFEFE8E8EFFFFFF2F6EBDDE8EFF6FFFFF6FFFFF6F6FFFF
F6F6F7F4F4F7F4F4FFF7F7FFF6F6FFFFF7F7F7F4FFF7EFB5
E5F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7B079
D1CA7497F4F7FFFFFFFFFFFFFFFFF4F7F7FFFFFFFFFFFFFF
FFFFFFE5ECF4F2EBF7F4FFFFF7EDFFF7F7F7DDDBE5FFFFF6
F6F7EDD1C8CCE0E4F3E0C2BBD9DCD4E0E8E8E7E7EDF7F4F4
FFF7F7F7F7EFEDF7F6F7E6FFEEEFEFF6FFF6FFFFFFF6F6FF
F6F6FFFFF7F7F7FFF7F7F7FFFFF6F3F7F7F7FFF7F7F7EDC8
E5E4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC80A5
CBC80BF4F7F7FFFFFFFFFFFFFFFFF7F7F4F7F7FFFFFFFFFF
FFFFFFE4F6EEF6F6EBEBF2F2ECEFFFF4F7F7DBF6F2F2F2EF
C9C8D4D5E8E5F7E6D9C1D4D9BAB2B7AAAABABAA8AFAEC2E8
F4F7F3F3F7F7F7EDEFEEE6EEE6FFEFEFF2F2F6F3F7FFF2F6
F6FFFFFFF7F7FFF4F4FFF7F7FFF6F3FFFFFFF7F7F7FFF7D5
D1EFE4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFF7F7FFF7F7FFF7FFF7FFFFFFFFFFFFFF
F7F7FFF7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E48F98B6
CCDC28DDEEF7FFFFFFFFFFFFF7F4F4F7F4F7F7FFFFFFFFFF
FFF7F7F4F4F2FFFFF7F7FFEEE4F7F7F4DCDBEFF7E6E0C5C5
D5E8D9E0F6ECC2A7AAC0D1DB9F95E6EEF7E5B9B2F4E4BDB8
D1EFD4D4ECECF7F4F7EFFFFFEEEEFFEFE5F6F6ECF4FFF2F2
F6F6F6F3F4F4F4F7F7F4F7F4FFFFFFF7FFF7F4FFF4FFF7EF
C0E5EBE7E4EDEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFF7F7FFF7F7F7F7FFF7F7F7F7FFFFF7F7FFFFFF
F7F7FFF7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7A68AC3BA
E48C71E5E5FFFFFFFFFFFFFFF7F4F4F7F4FFF7F7FFFFF7F7
F7F7F7EFF7F2F7F4F7F7F7E6F4F4F4E4E6F3D1D4F4DDD5E0
CBC8C5D5C8E4BDD1EFE8E8EEE0CCE5ECFFF7D1C1E6ECF7C3
C8CCD1D5D1F4E6E5F7F4E5F7FFEEEEFFEFECF6F3F3FFF2F6
F6F2F6F3F7F7F4F7FFFFF7F7F6F6FFF7FFF7F4FFF4FFF4F4
E4CEF6F7FFF3EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFFFFFF7F7FFF7F7F7F7FFFFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF80C5C8CF
DD69B2F7FFFFFFFFFFFFFFFFF7EDFFF4F4F7FFFFF7FFF7F7
F7ECECF7F6F6F4FFEFE8E5E0EFF7DCD5E0CBDDE5DBD5C3C8
DCEFDCD9C3E4E5A19C9898A6BDCCD4EDEDF4E0D1EEEBF6BD
CCCAE5D4CBC8E1D9F7EFE8F4FFEEFFEEFFE0F6F6EEF7F6F6
F2F2FFF7F7F4EDFFF4F4EFF7F2F2FFF4F7F7F4F7F7FFF7EF
F7D1E5E4E4E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFF7FFF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5BAA6D9B6D9
8A73DCF7FFFFFFFFFFFFFFF7EFF7F6EEE8FFF7F7F7FFFFFF
EFECF6F6EEE5D9D4E0E5CCE5E4C2A0C3CDD1E8D1885FBA81
6AB5DCCCCFDDDBFFC0937366719CB0D4CBAAC8D9B59F9197
DBDCEBECD4AAB6CCEDEEDCD9DCD4F7FFECF7EFFFF7F7FFF2
F2F2FFF4FFF4EDF7FFFFF7EFEEF6FFF4FFFFF4F7F4F4F7F7
F4E4D4C9D9E8EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFF7F7FFFFF7F7FFF7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6A8E8B5A3ED
5ABDFFFFFFFFFFFFFFFFFFEDF7FFF6EEE8F7FFFFFFFFFFFF
E8FFF6EEE6EFF2F7EECDE0EFCBBACADBBDD0ECC2512E408F
BD97978092A7B6CA84C3F4FFF7EEEED18C858F9E8C808BA6
EDD4BEDCECE0E4F7EFDCEFDDF2E4CBDCD5ECE8FFFFEFECFF
FFF6FFF4F7F7F7F7FFFFFFF4F4FFFFF4FFF7FFF4F7FFF7F7
FFEFE0F4E5D9CCEDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7FFFFFFFFFFFFF7F7FFFFFFFFF7F7FFFFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9CB6DD8FC592
6CE5FFFFFFFFFFFFFFF7F4EDF6F2F2E7F7FFFFFFFFF7F7FF
E8F6EEE6EFF6EEF7F2CFE79F97B9B68CBA9FA7A0C8A9A0E5
FFD4BBC8E6C8AE978FF4FFF7F7FFEBEBD4EFF4E5F6EDE0AE
8FA0E5AEC3D1ECE5E4CFE8EFE6FFE0FFF4E0E8FFFFEFECFF
FFF6FFEDF7FFF4F7F7FFFFF7EDFFF7F7F7FFF7F7FFF7F7F7
FFF7DBE4D1CCEECDD1E5FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF79D1D09DF765
ABFFFFFFFFFFFFF7F7F7F4F7F2F6F2E0FFFFFFF7F7F7F7FF
E8F2F4E8F6EEEFEDF2DCA8A0D1C8E5C55A90D9D0F2EDE0FF
FFFFF7F4F7FFF4D3D3F4FFFFF4FFF6FFE0F4EEFFEEFFFFFF
EFA88FD9EEE0E5DCEEB6F4F4F3DDEEE0E5DBEFEFFFFFFFF6
FFF6FFEDF7FFF7F7F7F7FFF7EDFFF4F7FFF7F7F7F7FFF7FF
FFF4ECD1DCE4C8D5E6D1F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFF7F7F7F7FFF7F7FFF7F7FFFFF7F7FFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5ABBCCCDD44C
E5F7FFFFFFFFFFF7F7FFEDF7F2F6ECEFFFFFFFF7F7FFFFFF
E8F2E5EFEBEFEFE6E0B29FC2C6D9D4C27CDCEFF3FFEBEEFF
FFFFFFF7F7F7F7F2F2F4FFF7F7FFFFEBEDF4E6EEE6E6EEFF
FFCFA0777F9ADDD4C8AEE0D9EFE6DDFFE0D4FFE8F6F6FFF6
FFF6FFF7EDFFF7F7F7FFF7F7EDEFF7FFFFF4FFF7FFF7F7FF
FFF7EFD9DDE5F7D4CFEDE4FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFF7F7F7F7FFF7F7FFF7F7F7F7F7F7FFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFEFEFEFEFEFEDF4F7FFFFFFFFFFE553BBE4E4B24C
EFFFF7FFFFFFFFFFFFF7EFF7F6F2E0FFFFFFFFFFFFFFFFFF
E0EEE1F6ECEDFFEEBDB0C1D1EFD4BA9FA8EFECF2F6F6F6FF
EEEEFFF7F7F4EEECEBF4FFF7F7FFF6E4E5E4E6EEEEEEFFEE
FFD9EBE5D1A779A0E4D4EFE5E0C9B2DCE5CBD9DDE5F6FFF6
FFF6FFF7EDF7FFF7F7FFFFF7EFEFFFF7FFF4F7F4FFFFF4FF
FFFFF4E0EDE0D5EEF6ECF7E4F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFF
F7F7FFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEFEFEFEFEDEDEDEFECE0E4F7F7F7FFC680B2E5EC7C7C
F4F7F7FFFFFFFFFFFFF4F4FFF6F3EDFFFFFFFFF7F4F7FFFF
D4F7E8EBEFDCE4AEC1D4E5FFF7C2D4A4D5DCE0FFEEF3F2FF
E6E6FFFFF4F4E6FFE6F4FFFFF4FFEBE5DCCDE6EEEEEEFFEE
FFE0F6E8EFEFD573A0C192AAE4E5D5BBDDE0E7C8EFEFFFFF
F6F6FFF4F4F7FFF7FFF7FFF7EFEDF4F4FFF7FFF4FFFFF4F7
F4F7F4EEDCC2A8C8CECDF7FFE4FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7FFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFEFEFFFFFF7F7F7F7E5DBE4F7F7EECDA095AFDCCC4EC2
F7FFFFFFFFF7F7FFF7EFF7FFF3EEF4E8EFFFFFF7F7F4F7ED
C9D9E0ECEDEEDD79EFE4E4F7F4C1B6DCC2D4C896B2E5F6DC
D9DDEEFFF7E5CBD4D4E5F4F4EEEBDDDDE4D5C2E0EEEEEEFF
E5CCD4EFEFFFEFB9817E884A77807CE5B2A9ECCBC5D5ECF6
F6F6FFEDF7F7F7F6F6FFF7F7FFF4F7F7F7FFF4F7FFFFF7F7
F7F7F7F4EEC8AB78B2CBCBE7E4EFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FF
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFE4CC969ECAF78383F7
F4F7FFFFFFF7F7FFF7EDFFFFEDF4EEF2E0FFFFF7FFF7F7ED
CFD9E5EDF4F7F788C6E1DDE4F7BEA9EBCCD5D4E5BCD9F4D9
EBDDDCF6FFD9D1EDDBEEEEF6EEE6D5CBE4F7E0E4EEEEFFFF
CDDCB5EDEFEFF7EDD9EFE5CD8E9AA26DB6D9D9E5D9D4E0F6
F6F2F6EDF7F4FFF2F6F6FFF7F7F4F4F4FFF7F7FFF6F6FFF7
FFF7FFEDEBD0988EBFE6EBE6E4D9FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFF7F7F7F7FFFFFFF7F7FFF7F7F7F7
FFF7F7FFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFD49871A8ECEE5DB2E4
ECEEE5FFFFFFFFEFE8EFF6F3F4EDF2F6E0FFFFF7F7FFFFE0
C6D9DCE8F7F7E5AFAEC1BBB2E0C8C1F6DBE7E7FFD1CCDDDB
E5DCCAECE6C1E5E8E5E4E4D1BEB2B6D1D5D4D4D5E0EDF4E4
B9CBA5ECEFF7F7DCDCE8FFF7E0F2F392BBC8EEE5D5C2D4F3
F6F6F6F7EDF4FFF2F6F6FFF7F7F7EFFFF4F4F7FFF6F6FFF7
F7F4F7F7EEFFC8C2EBF2F6F3E0C2E5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFFFFFF7F7F7F7FFFFFFF7F7FFF7F7F7F7
FFF7F7FFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7E5BA866B86CCEFDB47ECE4
DBE5E5FFFFFFFFEDF7F6F6E0F7ECF6F6E0FFFFFFFFFFF7E0
C3D9D4FFE5DCDDE1C1BCAF8A8FB5E4EFE4EFEFE8DDD9BAB9
D1CCA0BDBDA9D4E6EDE5E6DDB2BADBE4D4E0D5D4D5CDCFC9
B2DCAEC6F4F7E5CBF3EFFFF4ECEEF6CFDCA4F4E0D5CCBDE4
ECF6F6FFE8F4FFF2F6F6FFF4FFFFEDFFF7FFFFFFF6F2F6FF
FFF4F4FFFFE6EFE5E5FFF6FFF2E5CCE5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE5C69F7978BBE0EDF7A758F4E4
E4FFFFFFFFF7F4EFF7F2F6E7EFEBF7F3E0FFFFFFFFFFF4E6
C8C8DBE0EBE5EFEDE7D9D9C1B2A49DBCC9C3D1E8EFEFD1D1
E8ECDDC1C8DDDDC8BDBEBBB6C8E7ECEFEFF3D9C5CCCFCDCB
E5EEC5B6ECECD4D4D1F7EEE4F4F4EEDCD9A3E0F7E5CCB0DD
E8F6FFF6E8F4FFF6F2F6FFF4FFF7F7F4F4FFF6F6F2F6F6FF
F7F7F4FFFFE6E1F7E6DCDCF6F3F7D5E0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7C9907786C6E0EEE8F77180F4F4
F4FFFFFFFFF7F4EEF6F2F2F3F3F2EDDBEDFFFFFFFFFFE4F7
CDBCE0D4EFE5F4E4EEECE4E4D4CFC8AEC3E8D1C3C8C2B7BD
C3D1C6B0BDD1D1D1E8EDEDD1C6E5E5DCF6F7F4FFE0DBD9DC
ECEEE5AEDCDCCCCBC3D4E6D4DDDDF4D9E0ABC8EEF4DDB9BD
E6E5FFF6E8F4FFFFF6F6FFF7F7F7FFEFF7F6FFF6F6FFF6FF
F4F7EFF7FFECC2DBE0E6C9EBF3E5EFDCE5FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7FFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF78C62AED5ECE5F7EDEF4CAEEFFF
F7FFFFFFF7F4EDF6FFFFFFFFFFEEF4D4F4FFFFFFF7F7E4F3
CFC1FFC1E1EEEBE4F7F7FFFFFFFFF7F7E5DBDBDBD4DCF4ED
E8D1D4F4EDD4DCD4D5D5FFE5E4EDEDEDE5F2F2EEEDF4E5E4
F4F4F7C5D4D4C3DCD4C8E5D9DBE0F2C9ECABC1F3EBEECCA8
CBE8F2FFEFE6F7FFF6FFF6FFF4FFF4F4F7EEF6F6F6F6F6FF
F7F7F4F4FFF4C2CAF7F4CDE8D5F7DCE1E0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7FFFFFFF7F7FFF7F7FFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE5DBC63098DDECECDCF4F4B246DDE4E4
FFFFFFFFF7F4EDFFF6EEEBF2F6EEECE4F4FFFFFFF7FFEFEE
DBD1DDD9C3E5F2E7EFF7FFF7F4F7F4F7F7F7F4F7FFE5D4CF
CFCFCFCFCFD4ECC8CDD4BCC3C3C3C3C3BBBDC3C9E4EBD3C9
D4E0EDECD4C6DDFFDDBBD1D4C3B6AEBBC2C4BBF7ECE5D5EF
A0B0F6F2F3EDF4FFFFF2F2FFF4FFEDF7F7F7FFF2F6F2F6FF
FFF7FFEFF7F7C16D5293D9ECFFE7EFDBE5EFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDBFFC633EFE5E4EDF4F4ED7F79FFE5EE
F7FFFFFFFFF7EDFFFFF3FFECF7F3ECF7F4FFFFF7F7E4EBF6
E1ECDDEFC8E1EEE4F7FFF7F4F7FFFFF4F7F7F4F7FFFFF4FF
FFFFF7F7F7EDDBE4E5E0E0E4EBE6EBF6F3E4E0CBCDD1E0F3
F7F3EBF2EEE0DCF4F4E4D5E6CDE4DCE4DCEEC8F4CAE7E5DD
D580EFFFEBEDF7F7FFEBEBF7F7F7F4F4F7FFFFF2FFFFF2FF
FFF4F7F7F4F7BEB0AEA6E8ECF6E4D4EFF2E8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCDD1A94CF4F4F4F7F4E5FF6497FFF7FF
F7FFE5E5F7F7F7F7F6F6E6EEF6F6EEFFF4FFE5EEEEF7EBF6
E1F7EBE5E4CAE5E4FFF7FFF7F7F7F4FFFFFFF7F7FFFFF7F4
F7FFF7FFF7FFF7FFF7EFEDEDF3ECEEFFFFFFF6E4EDDCCFC6
C3D9E8DCD5ECEEDBE0E0F7EBE1D9D4E0D5CEBABAD9EDCFC3
CD85EFECF6E8F7F7FFEBEBF7F7F7F7FFF4FFFFF2FFFFF6F6
FFF4F7F7F7EFDB96E57E9ADCE0E4E0E4ECE8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC8B2C36DF7E5ECECEDF4D952BDF7FFEE
E5F7EEE5F4FFF7EEF7E0ECECECECF7E6E4FFE5EEEEE4E7F6
E8F4EBF4F4CADDD4FFFFF7F4F4F4F7FFFFFFF4F4FFFFF7F7
F7F4F4FFF7FFFFF7F7E8F7F7F2F6F6F6F6F6F2F6F7F4F4ED
FFE5E0EBF6E6E1E8E1E1D9D9E0DBD4CFC1BBA1AAAFAFD4D9
C9ABF7E7F6E8F4F7F7F2F2F7FFF7EDF4F7F6F6F2FFFFFFF2
FFF7FFF7FFF4ED8BECD55A90F4F4FFEFE8E8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD46CAEBBAE93837E88A6C44CE4F7F7E5
E5F7F7FFF4EEF6EBE0EEEEFFFFF7E4E0EEF7FFF7FFEDF3EE
E8F4EEECE6EDD4D9EDF7FFFFFFF7F7F7F7FFF4F4FFFFF7F7
F7F7FFF7FFF7FFFFFFEDF7FFF2FFFFFFF7F7FFF7F7FFF7F4
F7FFF7FFEEF2F6FFFFFFFFEFE8E8E8E8E8E6F7E5E4E4E0E0
E7E4EFEDF6E0F4F4F4F2F2F4F7F7E8FFFFF6F6F6F2F6FFF2
F6F3F7F7F7F4F493C3B6E47597EDFFEFEFEFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFD44FC186698197ABA7829D6DF7EFEFFF
F7F7FFF7F7EEE5E5F7FFE5F4F7F7F7FFFFF7FFFFE4F6FFF3
E4EFF7F6ECF7D4D3EEEDFFFFFFF7F7F4F7F4FFFFF7FFFFF7
FFF7FFFFF4F4FFFFFFF7EDF6F6FFFFFFF7F7F6EEF7FFF4FF
F4FFF4F7EEF6F6F6F6F6FFFFFFFFF6F6FFEFE8E8E8DDE5E4
E0EDEFEDFFDBF4F4F4F6F6F7F7FFE8FFFFFFF6F2F2FFF6F6
FFF3F4FFFFEDF7B5F2E5C6CC92C3EFEFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7D44FD53FD4E5F7E0F7D5C3AEF7F4F4F7
F7EEE5F4FFEEE5E5F7FFE5EDECE4FFF7F7FFFFE5FFE4EFF7
E6F4F4FFEBEFF4C8F2ECE4F7FFFFF7FFF7F7FFFFF7FFFFF7
F7F7F4F4F7F7F7FFE5E4E4F6FFFFF7F4F7FFF6F6F7F4F7F7
F7FFF4F6FFF6FFF2F6F6F6F6F6F6F6F6FFFFF6F2F6EFEDF4
F4F7EDEEF6E4E5F4F7F3F6FFF4EFEFFFFFFFF6F6F6FFF6F6
F6FFF7FFFFF4F497C8C2D4C2CAB6F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE4BA72A082FFFFF7E4E5F7EEE0F7F4F4F7
FFE4F7E0E6FFE5E4E5E5E5E0EFE5FFFFFFFFFFE5E5FFE4F6
E0F7EDFFEBFFF7C8EBF3E5F7FFF7F7F4F7F7F7FFF7FFFFFF
FFF4F7F7FFFFF4FFE5ECECF6F7F7F4FFF4FFFFFFF7F7FFED
F4F4F7F6F6F6F2F6FFFFF3F3F6EEF3F2F6FFF6F2F6FFF6F6
EFE5F2FFE5DBEDDDE4F3F6F7F7EDF7FFFFFFF6FFFFF6FFF2
FFFFF7EEECF7F785F6A2C8F6F7C2F7FFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7D9B6C198DCFFFFFFFFE5E0ECEDEFEDF4F7
F7FFE0E5DBE4F7FFFFFFFFE5E5FFFFFFFFFFFFFFFFFFE4F6
E6F7EFEDE5EBEEE4D4E4E5F7FFF7F7F7F4F4F4FFFFF4F7FF
FFF7F7F4FFFFF7F7F7F7ECF6F7FFF7FFF7F7FFF7F4F7FFEF
EDF7FFF6F6F2FFF7F4F4EFEFF4F7EEE6ECF7F7F7EFEFF6F6
FFF6F6F2EFCDFFD4C8FFF7F7F7FFE7F6F6F2F6F6F6FFF6F6
FFFFFFF6F3EDF765BB849FE5CAD5FFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7EFD1DCC9F7E4FFFFFFFFF7EFF7F7F7EDF4F7
E4E4E5E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4F6
EEEEF7F4F4FFF6F3DCE6E5E5F7FFF4FFFFFFFFF7FFF7F4FF
FFFFFFF7F7FFFFF4F7F7ECF2F3F7FFEFEFF7F4F7FFEFE8E8
EDF7F6F6F6F6F7F7FFFFF7F7FFFFF7F7FFF7EFEFF7EFFFFF
EFEFF3F3E5E5E5D4C2F4F7FFF7FFE7F6F6F6FFFFFFFFF2FF
FFFFFFFFFFEFFF4DED9E9EA9C6FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7E0D9EDF7E5E5FFFFFFFFF4EDF7F7FFEDEFE5
F7E4FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFDBE6
F4F2F7EFEFF7FFEEF7E5E5EBEFF7F7F7FFFFF7F4FFF7F4FF
FFFFFFF7F7FFF7F7FFE4F6F4E4F4EDE5E5E8EDF4F7E8FFFF
FFF6F6FFFFEFF4FFFFF7F7F7F4F7F7FFF7F7FFF7F4EDF4ED
F7EDEDEDE0E4E5ECD1FFFFF7F4EFEEF6F6F6FFFFFFF6F6F6
F6FFF7F7FFEFEF5AF4BBC8A4C6E5FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD4E1EDF7FFFFFFFFFFFFF7EDFFF4E4F3EFE5
E4FFF7FFFFFFFFFFFFFFFFFFF7F7FFFFF4F4F7F7FFFFE4FF
F3F6F3F7F7EDEFF6F6E4EDEEEEEFF7F4FFFFF7F4F7F7F7FF
FFFFFFF7F4F4F7FFFFE5F3E4E4EDF7ECECF4FFF4E7E4F6F6
F2F6FFF7EDF7FFF7F7FFF7F7F4F7F7FFF7F7F7F7FFFFF7F4
F4F7F7EFEEEEFFEBF4F7F7FFF4F7F6F6F2FFFFFFFFF6F2FF
F6FFF7FFF3ECED54F4C5B6BCC6DBFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCDDCE7F7FFFFFFFFFFF7EDE4EEF7EEEEF7FF
E5E0E4FFFFFFFFFFFFFFF7F4F7F7F4F4F7F4F4F4FFFFF7E4
EFF6EBF4F7EFEFF6F3DDE5F4F6EBE4F7F7FFFFFFFFF7F7FF
FFFFFFFFFFFFFFEFEDF4E4ECF7F7FFFFFFF7EFF3F6FFF6F6
FFFFFFEDFFFFFFFFF7F4FFF7F7F7FFF7FFF7F7F7F7F7FFF7
F4F7E7F6FFFFEEEEFFF4EDEFEDFFF6F2F6F6F6FFFFF6F6F2
FFFFFFF7F3ECED48EDCC8F836786F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEFCDEEE4FFFFF7F4F4F4E5E4ECE0F7F7F7FFF7
E4E0FFE5FFFFFFFFFFFFF4FFFFFFFFF6F6F7FFFFF7FFFFE5
F7F3F6F6F7E6EFEEFFF3E4E6F7EEE4FFF7F7FFFFFFFFF7F4
F7FFF7F7F7F7E5F6F3EEE6F7EDFFF7F7F7FFF7D9EFFFFFFF
FFEFEFEDFFF7F4F7F7F4FFF7F7F4F4F7F7F7F7FFFFFFF4FF
F4F4ECF6F6F2ECF7F7F7EDF4F4FFF6F6FFF6FFF6FFF6FFFF
F2F2F6FFF7EDEC4FF4F4DCDDA466F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFEFCCE4FFF4FFFFE4ECF4F4E4F7FFD4FFEDEFF7EE
ECF4E5E5FFFFFFFFF7F7F4FFFFF6F6F6F6FFF7F7F7F7FFE5
F7F3FFF2FFF4EDE5EEF2F2E8F4E6F4FFFFF4FFFFFFFFF7F4
DDE0EDE7ECF7EEEEEEECECF6EDF7F7FFFFE5EED9FFE8ECF6
F6E5EFF4F4FFF7F7F7F7FFFFFFF7EFFFFFF7FFFFFFFFF7F7
F7EDFFF6EEF4EFF7F4F7F7F7F7FFFFF6F6F6FFFFF6FFF2F2
F6F2F6F7F7F4E456F4F4F7D96C88FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFD9E0EFF4F7FFF7DDE0ECE4ECF7F4DBFFEDECE5E4
FFE4FFFFFFFFFFFFF4F7F7FFF6F6F6F6FFFFFFFFFFF4FFFF
E5E7F3FFF6F4F7EDFFEBEBECD9D4DCFFF7F7FFFFFFF7DDE4
EEE0E8E0E4F4FFFFF7E4F3F6EEEFEDF7FFE5E5E5DDEDEEE0
E0E7F4EFEFF7FFF4F7F7FFF7F7FFF4F7F7F7F7F7F7FFF7F7
E8DDE6E4F4F7F7F7EFFFF4F7FFFFFFFFF2F6FFFFF6F6FFFF
F6F6F6F7F7F4E467CFC8C8976CB0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEFD9F7F7FFFFFFF4F4F7E0E1EDF4E8E0EEF3E7E5E4
F7E5FFFFFFFFFFFFF4FFFFFFF6F2F2FFF6F6F6FFFFF7F7FF
F7E5F7EEEBF7F7E8FFEEF7FFF6E8D4F7F4FFFFFFF7F7E5E4
F7FFFFFFFFFFF7F7FFE4E4ECFFEEF7EDF7F4F7F7EEE0DCEF
F7EFF4F7F7F7FFF4F7F7FFF7F7FFF4FFEFEDFFEFF7F7F7EF
F6E4F4F7F7FFF7F4F4F4F7F7FFFFFFFFF2FFF6F6FFF2F2F2
F6FFF6F6EEEFC97CE0E5D4628ACCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE8E6FFFFFFFFFFF4F4E4DDF4F7EFE1E0EEE4F7E5F7
E4FFFFFFFFF7F7F7F7FFFFFFFFF6F2F6F2F6F6FFFFFFF7F7
F7E0EBFFEBFFF7E5F7FFF6FFF6E8E4E4F7F7FFF7F7FFFFFF
FFFFFFFFFFFFFFFFFFF7EEFFECF2FFF7F4F7FFEEECF4F6DD
E5F4FFFFF7F7FFF7F4F4F7FFFFF7EFF4F7F7EFFFF4EDE5F2
EEEDFFFFF7FFF7F4F7F7F7F7FFFFFFF6F6FFFFF6F2FFF6F2
F6FFF6F6F6EDB685F7DBC37F8AA3DDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE0ECE5E5E5E5F7F7E5DCF4F7EDFFE1EEE4EDF4EEE4
EEE5FFFFFFF7FFF7FFFFFFF6F6F6F6F6F6F6F6FFFFF7F4F7
FFE4EEECFFF2F6EDEDEFFFF6F6EFE1EFE5F4F7F7F7F7FFFF
FFFFF7F7FFFFF7F4F7FFE5EEE4FFF6FFEDF7F7E5F3FFF7F6
E4E4EDF7F7F7F7F7FFF7F7FFFFF7EFF7F4EDFFEDFFFFEBF4
F7F4F7F7F7F7FFF7F4F7FFF4FFFFFFF2F6F6F6FFF2FFF6F6
F6F6F6F6F6E8B085FFDDB888726DB2DBE4F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7D9F7E5FFFFE5F4F7D9ECEFEFEDEFE4EBECEFECE4FF
E5E5FFFFFFFFF7F7FFFFFFF6FFF6F2F6F2FFF6FFFFF7F7FF
FFF7ECEEEBF7F2F4FFEDF7FFFFFFD5FFE7EFF7FFF7FFF7FF
FFFFF4F4FFF7F7FFF7F7FFF7E0F6FFF3F7F7FFF7F7F7F7FF
F7F6E6DCE8E0DCF4FFF4F7F4F7FFF4F7FFFFEDEFFFEEEEF7
F4F7F4F7F7FFF7F7EDF7F7F7FFFFF6FFF6F2F6FFF2FFF6F6
FFF2F3EEEEF4AE91F7F7F4EDE47B7EB6D5E4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEDD9F4F7E5E5FFF4EDD9DDE4E0EDE8EBF4FFECF7E4E5
E5FFFFFFFFFFF7F7FFFFFFFFF6F6F2F6F6F2FFFFFFFFF7F7
FFE5F7E0F7F3F6EEF4EFEFF7FFFFE1EEEBE4FFF7F4FFF7FF
FFFFF7F7F7F7F6F6FFF4FFFFE4EEF6F3F7F7F7FFFFF7FFF7
FFFFF7F3F2F6EBEDEDEDF4FFF7F7F7F4EFEDF6F2F2ECF7F7
FFF7FFF4F7FFF7F7F4F7F7FFFFFFF2F2FFF6F6F6F2FFF6F6
FFF6EBFFEFF4B29AD4DBDDFFEDB8A0A8B2CDF7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7DCE4EEE4E5E5FFF7D4D5D4ECEFECDCF2F4EEFFE5F7E5
E5FFFFFFFFFFF4FFFFFFFFFFFFF6FFFFF6F2FFFFFFFFF7FF
F7E5F7E5E0F2F6F6F7F7F4F7F7F7EDF4E5E5FFF7F4F7FFFF
FFF7F7F7F7F6FFFFF6F4FFFFEDEBFFFFEDFFF7FFFFF7FFF4
F4F3F6FFFFFFF2FFE1F4F7FFFFF4FFFFF4EFF2FFF7F7F4FF
FFF7FFF4F7FFFFF7F7F7F7FFF7F3FFFFF6F6FFF6F6FFFFF6
F6FFEEF6E4EFCDB2AEC6C5BDD4E1BACCA8A0DCF4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE4DCF7ECE5E5E5F7DCEFD4E0E5ECE4D4F7ECEEFFE4FFFF
FFFFFFFFFFFFF4FFFFFFF6F6F6F6F2F2F6FFF6FFFFF7F7F7
F7FFE4E5E4E7EBF6ECFFF7EDE5EDEFF7E0F7FFFFFFFFF7F4
F7F7F7F7F7F6F6F3ECF7FFF7EDEBEDE8E6EDEDF4F4F7F7F4
F4F3FFF6F6F2F6F6E5EFF7F4F7F4F7F4F7FFEBF4F7F7F7FF
F7F7F4F7F7F7F4EFF4F7F7F7F4EEF3F2F2F6F6F2F2F6FFFF
F2F6F7F3E5E6D4E8EED1F7E0DDECD3BB94655897E5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7D1DDEEF4FFFFE5E0E4ECC8EDF7E0E0E4F7F7ECE4E5FFFF
FFFFFFFFFFFFF7F7FFFFF6F6F2F6FFF6F6FFF6FFFFF7F7FF
FFE5EEF7F7E5FFF7ECFFF7FFFFF4F7E5F7E4FFFFFFFFE4EC
E7E4F7FFF7F4F4F7FFFFEFEDEEE4F7F7F7FFF6F2F6FFF6F6
F6F6F2F6FFF2F6F6E5E6F7FFF4F4F4E0F6EEEEFFF7F7FFF7
FFF7F7F7FFF7F4F7F7F7FFF7F6EEF4F6F6FFFFF6F6F6FFFF
F6FFFFEFFFE5D9E8FFDDD4D9D1D0F2F7F7E0AA98DBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EDD4ECF7E4F7EDDCF4FFEFD4FFEDD4E6E5F7F6E4EFFFFFFF
FFFFFFFFFFFFF7F7FFFFFFF6FFF6F2F6F2F6FFFFFFFFF4FF
FFE5E5FFF7E4F7F7EBECF7F7F7FFF7D4E5DDF7FFFFF7ECF3
F6F7E4FFFFF7F7FFF7F7E0F2F6E8FFECF6F6F6FFF6F6F2F6
FFFFF6F6FFF2F6FFEDEDFFEEE4F4F4ECFFECFFF7F7FFFFF7
FFF7FFFFFFFFFFFFF4FFFFFFEEFFF6F7FFF6F6F6F6F6FFFF
F6FFFFEFFFEDE0E8EFEDDDDBD1B1D1E6CA957EB1E0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E8D4F7F3F3DCE0DDD9C8D1E5EDF6E0ECF7FFE6E4F7F7FFFF
FFFFFFFFFFFFF7F7FFFFFFF2F2FFF6F6FFFFFFFFF7F7F4FF
FFFFFFF7E4E4F7ECF7F2FFFFF6F6F7E0EFF4F4FFFFE4ECEE
F2F7E4FFF7FFFFF7E4E4F3EEFFE8FFECF6F6F2F6FFF6F6F6
FFF6FFF3F3FFFFF7EFEDFFECE5F7EDFFEBF7F7F7FFFFFFF7
FFF7FFFFFFFFFFFFF4FFFFFFFFEEEEECF6F6F6F6F6FFF2F6
F6FFF6ECEFF7E0EFEFF7EFEDE5D4BAC68F7BAEE0EFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D9D1F3FFD5C9CFC9C9D4DBECE8EBEDECFFF7ECEEEEF7FFFF
FFFFFFFFFFF7F4F7FFFFFFF6F6FFFFFFFFFFF7F7F7FFF7FF
FFFFFFF7E5E0F7E6F3F2FFF6EEEBF6FFE0F7F7FFFFE5ECF6
F6E0FFF7F7EEEEFFE0F2F3EEF7EDFFF4F6F2F2F6FFFFF7EC
ECF4F4F7F4F7F4EFEFF7F7F7FFEFEFF6ECF7F7FFFFF7F7F7
FFF7F7F7FFFFFFFFF4FFFFFFF7F7F7EBF2FFF6F2F6F6FFF2
FFF2EFF6EFF7E0FFFFEFF7F7F7EFD9B27DCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
CDE7F7F3CFE6FFD1F4E0E6EEE8E6F4F4F6F7ECEEE5FFFFFF
FFFFF7F7FFF7F4F7FFFFF6F2ECEFFFEFEFFFF7F7FFF4FFFF
FFF7F7FFF7FFE7F2FFF6F6F6F3FFECE7E5FFF7F7FFFFE0F3
E7E5F7F7FFE4ECEFEBF2F2F7EFF7FFF4F6F6FFF7F4EDF4F7
F4F4F7FFF7F7F7F7F4FFF4FFEFEFF6F6F4F7F7F7F7F7FFF4
FFF7F4F4F7F7F7F7F4FFF7F7F7F7F7EEF6F6F6F6FFFFFFF2
FFF2EFECE8FFDBFFFFEDEDEFFFF7DDBBB6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC
CBF6ECF7C6EEE5E0E7EEFFF7E4ECF7EDEEEEF7FFF7FFFFFF
FFFFF7F7FFFFFFF4FFFFF2F6ECEFFFEFEFFFFFFFF7F7FFFF
FFE4E0E4F4E5F3FFF2F6F6F6F7E5F4F7FFFFF4F7F7FFE5E4
F7FFFFFFFFF7ECEBFFF6F2F7EFF7FFECF2F6FFF4F7F7F4F4
F7F7F7F7FFFFF4F7FFF7F4F7F7EFF2F7F7F7F7F4F7F4F7FF
F4FFF7F7F7F7F7F7F7F4FFEFF4F7F7F7F6FFF2FFFFFFFFF2
F6FFF3E4EFF7D9EDEDEFEDEFFFEFE0B0E4FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4
DCEEEEEECEEEE4E6E6EEF7EFE0F7EDE5ECFFF4F7FFF7FFFF
FFFFF7F4F7FFF7F7FFFFF6F6F6F6FFFFFFFFF7F4F7FFFFFF
FFDBEEFFECF6ECF7F2EBF3F7E5FFF7F7F4F4F7FFF7F4F7FF
FFFFFFFFFFFFE5E0F3F6F6FFEDF7F7F3F6FFFFF4F7F4F7F4
F4F4FFF4F7EDF4F7F7F7F7EDEDE5EEF7FFF7F7F7F7F7F4F7
F7F4F4F7FFFFF7F4F4F4F7F7F7F4F4F6F6F2F6F6F6F6F6F2
F6FFF7EDEFF7CFF7F4F4EFFFEFFFE0AAEDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDDD4
DDEEECF3D1EEF7F4ECECFFF7DBEFE5F2F4FFF4F7FFF7FFFF
F7F7F4FFF4FFF4FFFFFFFFFFF6F6FFFFFFF7F7FFFFFFE5DB
E5E5F7FFECF7EEEBFFECE6EBEFE5E4F7F4F4F7FFFFFFF7F4
F7FFFFFFFFFFF7F7F4F2FFF7F4F4F7FFF2FFF7F7FFFFF7F7
F7F7FFF7F7F4EDF4F4EDE8DDE6ECF7FFF7F4F7FFF4F7F4F7
FFFFFFF7F7F7F7F7F7FFFFF7F7F7F7F2FFF2F2FFFFFFFFFF
F6F6FFEFEFFFC3FFF7F7EFEFFFF6E0C1D5F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFC9E4
FFE5EFE0D9E6EEFFE0EEF7EFDCEDF4F2F3EEF7FFF7FFFFFF
F4F4F7F4F7F7F7FFFFFFFFFFFFFFFFF7F7F4FFFFFFFFE5DB
FFE4ECFFEEF7EBF6EEF7ECEEFFEBDBFFFFFFF7F4F7FFF7F4
F7FFFFFFFFFFF7ECF6E6F7F7F4EDFFFFF2FFF7F7FFF7FFF7
F7F7F7F4F4F7F7F4F4F7EEEEFFFFF7F7F7F4F4F7F4FFF7F7
FFF7F7FFF4F7F7F4F4F7F7F4F7F3F6F2F6F6F2FFFFFFFFFF
F6F6FFE8F7F7C8F7F7F7E8FFF6F6EFC9BBF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0CDFF
ECF4E4E4E8FFE6FFEDFFF7E8E6F4F4EBECE5F4FFF7FFFFFF
F4F4FFFFF7F7FFF7F7F7F4F4F7F7F4F7F7F7FFFFF7F7FFF7
ECFFECE5FFF6EEFFEBE6EBECECFFE0FFFFFFFFFFF4F7F7F7
F7FFFFFFFFF7F7E5ECE4F6F4EDF4FFF6F6FFFFF4FFF7F7F7
F7F7F7F7F7F7E7ECFFF6F3F7FFFFF7FFF7E8FFF7F7F7F7F7
F7F7FFF7F4FFF7F7F4F7FFFFFFF3F6F6FFF6F2FFF6F6FFFF
F6F6F6E0F7F7C8F7F7F7EFFFF2FFF6D1AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDCDBF6
F3E4E5DCDCF7E6FFF4F4F4E8E6EDF7EEEEF7F7F7F7FFFFFF
F4F7F4F7F7F4F7F7F7F4FFFFF7F7FFFFFFFFFFFFF4ECE4E5
EEEEF7ECECF3EEF6FFFFFFEBEBF6E4F7FFFFFFFFF7F7FFF7
F7FFFFFFFFF7F7FFF4ECF3F4F7F7F7F6ECEFFFF4FFFFFFFF
FFFFF7EDF7F7F6FFF6F2F7F7FFF7F4F7F7F4F7FFFFF7F4F7
F4FFF4F7F7F7F7F7F7FFF7FFFFF7F6F2FFFFF6FFF6FFF6FF
FFF2F6E0F7F4D4EFECECFFF6F6F6F6E49BEFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0E4E4F2
F7E4FFE8D4E5F6F7F4F7F7E8E6E8F6EBE5ECE4F7F7FFFFFF
F4F7F7F4F7F7F7F4F4F7FFFFFFFFFFF7F4F7F7F7F7E4E4E5
FFE6FFFFF3F6FFF6FFFFFFF6FFEBE5F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE4EEFFE8F7F7F4F6ECEFFFF7F7FFFFFF
FFF7EDEFFFFFFFF6FFF6F4FFFFF7F7F7F7F7F7FFFFF7F7F7
FFF7F4F7F4FFFFF7FFF7F4F7F3F3F6F2FFF6FFFFFFF6F6FF
F6FFF2E0F7F4E4F2FFFFF2F6FFF2EFE5AAC6F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4DCE5F4
DBEFF7D9D9EBFFEFF7F7F7E8E6E8F2F4F7EEE5F7F7FFFFF7
F7F4F4F4F4F4FFFFFFFFFFFFF7F4F7F7F4EEE0E5E4E4EDF4
EEE6FFF7FFF6F6F6FFF6F6FFF6ECF7F7F7F7FFFFFFFFFFFF
F7F7FFFFFFFFFFFFE4EEFFEDEFFFF7F6F6FFEFEFF4FFFFFF
F7F7FFFFEFEFF6F2FFF6F4F7F7F7FFEDF4F7F7F7F4FFF7FF
F7FFEFF7FFF4F4F7F7F4FFFFF6EEF7FFF2F6F6F6F6FFFFFF
F6F6F6E0FFFFE0F2FFF6F6F6FFEBEDE8C8AAF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFE0ECFF
CFF7DDD4F4EBF7EFF4F7F4EDDBEDF2F3EEF7F4F7FFFFFFF7
F7F4F7FFF7F4F7F4F7FFFFFFF7F7F4F7F4E7EBEEEEFFEBEB
EEEEFFECEBFFFFFFFFF6F7E6E6EEFFF4F7F7FFFFFFFFFFFF
F7F7FFFFFFFFFFFFF7E0FFF4F4F4FFFFF2FFEFF7F7FFFFFF
F4EFEFFFEFEFF2FFF2F2F7FFF7F4F7F4FFF4FFF7F7F7F7F4
F7F4F7F4F7F4F4F7F7F7F7FFFFF7EEF6F6FFF6F6F6FFFFFF
FFFFE4F7F4F4D9F3F6FFF6F6EFD4F7EFC9A2F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDDCCCCC9DD
D9B0BAD9B8AAC2E0F4F7F7E8CDF7EBEBE6FFF7F7FFFFFFFF
F7F7FFF7F7F4F4EDF7FFFFFFFFF7FFE5EEECEEF4F7E6FFF6
F7EEEEE6F7F6FFFFEEEEE6EEECF4F7F4F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFE5E5F6ECF4F7F7F6F6F7F7F7F7FFFFFF
F7F4EDF7F7FFF6F2F6F6F2ECF7F7FFFFF7F4F7F7FFF4FFF4
FFEFF4F7F4F4F4FFFFFFF7F4F3F6F6F6F6FFF6FFFFFFFFFF
F6F2ECF7F4F4B2B5BDE5F7F4EDC3FFF7E595CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4D9C9FFE7
D5EDEED5CCF7F7DCE0EBF6DCCFF6ECECE4F4F7FFFFFFFFFF
FFFFF7F4FFF7F7F7FFF7F7F7F4F4FFE5EEEEF3F7F6F7F6F6
F6FFFFFFF6FFF2F2ECEEEEEEECF4F7F4F7F7FFF7F7FFFFFF
FFFFFFFFFFFFFFFFE4E6F7ECF4F7F7F2FFF7FFF4F7FFFFFF
FFFFF4F7F7FFFFF6F2F6EEE5FFF4F4F7FFFFF7EFF7FFF4F7
FFEFF4FFFFF7F4F7F7FFFFF7F6F7F6F6FFFFF6FFFFFFFFF6
FFF6FFE8FFF798FFDCC9EEF4EDCDEFF7F7BDA3EFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4DCC6D9EEE0
E5D4D4A0CDE4F7F7E5EDEECFDBEBF4F7F7F7F7FFFFFFFFFF
FFFFF7F4F7FFFFFFFFF7FFEFF7F7EDE4E6E6EBEBFFF7F6EE
EBF2F2F6F6FFF2F2ECF7F7EEECF4F4FFF7FFFFF7F7FFFFFF
FFFFFFFFFFFFFFF7F7F7EBF4F4F4F6F6FFF7F7FFFFFFFFFF
FFF7EDFFFFFFFFF2F6F7EEF7FFF7EDF7F7F4F7F7F4F4EDED
EFEFF4F7F7F4F7F7F7FFFFF7F7ECF6F6FFF6FFFFFFFFFFF6
FFFFF3F4F7F79DF4FFC9DDF6EFECE0FFF7EE93D9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D9E5C8E6F7EF
F7DBAFE6BCEEE4E4EEEFEFC1DBF3E7F7F4F7F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7EDF4F7F4ECEBF2EBEBF3EBFFEE
E4E6EBEEEEF6FFF6F7F6F7EEECF4F4FFFFF7FFFFFFF7F7FF
FFFFFFFFFFFFF7E5EEF4F2EDF7F4F2FFFFEDF7FFF7F7FFFF
FFF4FFEFFFFFFFF2F6ECFFFFF7FFFFF4FFF4F7FFFFFFFFF7
FFF7FFFFFFF7F7FFFFF7ECECF7F7F7FFF2FFFFFFFFFFFFFF
F2F2EBF7F7EDA9F7F7D4E8EBFFFFE4E8EDEDA3BAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E8D1E5C6EEF4D5
C8C5EEBBC2D9ECF7EBF7EDC3CFEEECFFFFF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F4F4F4EDE8EDEDE8E0E0E6
E5F4FFF7F7EDEDE7ECEEECECECECECFFFFFFF7FFFFF7F7FF
FFFFFFFFFFF7E5FFFFEBEEEDF7EEF6FFFFEFF4FFF7FFF7FF
FFF4EFEFFFFFFFF2FFF7F7FFFFF7F7FFF4FFF4F7F7FFFFF7
F7FFF7F7FFF7FFF7F7F7F6EEF7F7F7F6FFF2F6FFFFFFFFFF
F2F2EBF7F7EDAEEFF7CFF4E6F6F6F6F2ECEFC2A2F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D1D9EBC8EEF6AE
D5DBB8FFAEF3F6F7ECE4EDC3CFEBF4F7F7F7FFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFF7F7EE
EEFFF7F7F7FFFFF7EFE8E0ECF2F6E7F7F7FFF7FFFFFFFFFF
FFFFFFFFFFF7E4ECE6F7F7F4F4F6ECEFEFEDF7FFFFF4F4F7
F4EDFFFFFFFFF6F6F7F7F7F7F7F7FFFFF7F4FFFFF7FFFFFF
F7F7F7F7FFFFF4F7F7F6F3FFF4F7F6FFF6F6FFF6FFFFFFFF
F6FFECF7F7E8B5F4E4E5EFE5ECEEF6FFDBF7DB9DEDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFE0DCD9EEDDA7
E59CECDDD9C1B9DCEDD4EDBCD5F2EDF7FFF7F7FFFFFFF7F7
FFFFFFFFFFFFFFF7FFF4F4F7FFFFFFFFFFFFFFFFFFF7F4E4
EBEEFFF7EDF4F4FFFFFFFFEDDCEBEEF4F4FFF4F7FFFFFFFF
FFFFFFF7E4E5F7FFE0F4F7F7F4F6ECEFEFF4FFF7F7F4F4F7
F4F4F4F7FFFFF2FFF7FFF4F7F7F7FFFFFFF7FFF7FFFFFFFF
F4F4FFFFFFF7F7FFFFF3EEF4FFFFF6F6F6F6F6F6FFFFF7F7
F6F6F7EDEFEFC1EDDCDBDBC8C3CCE5F6E4F7E4A2D5F7FFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4D4D1EEDDC2AE
D5C2A888A3BDC6EBC2E5EDB5D5EBEFF7FFF7FFF7FFFFF7F7
F7F7FFFFF7F4EDE8F4F7F4F7FFFFFFFFFFFFFFFFEFEFFFED
EFE0F6F6FFF7EDEDF7F7F4F7EDE8DCDCE4F7FFF4FFFFFFFF
FFFFFFF7E4EEFFF7E4F4F4EDF7F2FFF7F4F7FFF4F7F7F7F7
FFF7F4F7FFFFF2FFFFF7F4F4F4F7F7F7FFF7F7FFFFFFFFFF
ECEBECF7F7FFF7F7F4F7F7F7FFFFFFFFF6F6FFFFF6F6F7F7
F6F6F7EDEFEFC1E8F7E0D4DBCDB0B6CBF6EFFFABB2F7FFFF
FFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDD1C9D9EEE08FCE
BDE59DEBA0CCDDC8CFEEE0BDCFE6F7F7FFF7FFF7FFFFFFFF
F7FFEDE8EDF4EEF2EBDBDDFFFFFFEFE8EDE4D4CFD9D9CFC6
C6DCE1E1F7FFEFEDF7F7F7FFF7F7EFE6E4F7F7F7FFFFFFFF
F7F7FFFFFFF7EEECF2F7FFE1F6FFF6F4FFF7F4EFF7FFF7FF
F7F7F4F3F2F2FFF6FFF6F2F2F2EEF7F4FFFFF7F7FFFFFFFF
ECF2F6F4F7FFFFF7FFF7F7FFFFF6F6FFF6F6FFFFF6F6FFFF
F6F6F7EDEFFFC8E4EDEBF4F7EFEDD9CCD5FFE8B7AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE8C8C6D4CCE688D5
CDC6AEBDD4B0A5E1DCECD9B6CFE6F7F7FFF7FFF7F7F7FFFF
FFF7EDE8E8EDECEBF3C4A6B5C8C2C2C8B6B5C2C8CFCFCFD9
D9C8DBDBBDCADDEEF7F4EEF2F6FFF7F4E4EEEFF7FFFFFFF7
FFFFF7FFFFF7EEECF2F7F7EDEEEFE7F7FFF7F4EFF7EFF7FF
F7FFFFEEE6EBEEE7E4EEF7FFFFF2FFF7F4F4EDF4F7F4F4F7
F4F6F3F7FFF4F4F7F7F7F4F7FFF3F3F6FFF6F6F6FFFFFFFF
F6F6EFEFFFF6D5E6E8F2FFF4FFFFE4E5C9E6E8C29DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0C1C8E5C5E898C2
CBABD0B5D4D4E4E4EEEFE0ABCFEBEFF7F7F7F7F7F7FFF7FF
FFFFF7F4EDE4E0D1C9CACD968C8AA1BCC8D9EDEDEDF7FFFF
FFF7EDEDF4D4DBE5DCE4F6FFF6F2E1E8EFF6ECF7F4F7FFF4
F7FFFFF7FFF7F7EDEBF7F7F4F4E4EDF4F7F7F4EFF7EDEDF7
F4F4F7FFFFF4F7EDEFF7EEF6F6F6FFFFFFFFFFF4F4F7F7F4
F7ECEEFFFFF7FFFFEFF4F7F4F7FFF7F6F6F2F6F6FFFFFFFF
F6F6EFFFEFF2E1E0EDEEF3F7F7F4F7E6DBDCEDD498F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4C8CFE5C5EDABAA
E5ADF7D4DCF7FFE8F2F4E58CD1EEEFF7F7FFF7F7F7F7F7F7
F7F7F7FFF4F6ECE8E0DCA0DCE6E4D1D1EDE5EEF7FFE0CFCF
CFC8BDC3E7FFE7D1F4F4EDEDEDEDD1EDF7FFEBF7F7F7FFF4
F7F7F7F7FFFFFFF4E6FFF4EDEEF6FFFFF4F7F7F7F7F4F4E8
F7E1EDF4F4F7FFFFFFFFF3F3F6E4E4EBEBF2F2EBF3F7FFF7
FFF7F4F7FFF7FFF7F7F7EDFFFFEEF2F6F6F6F6F6FFFFFFFF
F2F6F6EFEFF2E1E0F4ECF3F7F4F7F7EECCE5F7E09EF4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7CDC6C0FFBDF7C29D
E4C5EEE4ECEDF4F4ECE4FF73D4EDFFF7FFF7FFFFFFF4F4FF
FFFFF4F4EDEDE5D9C1E5DD97BBF7F7E5D5CCB6B6C3B8B7CA
B9A4AAAEAAAED4DDD9C8D9EFDDD4C1C2C6D5DDECF7F7FFF7
FFF7FFFFFFFFF7FFE5EEF4EDEBF6F6F7F7F7F7FFF7EFFFDC
E6F4F7EDFFFFFFFFFFFFF7F7FFEFEFF7F7FFFFFFF3EBEBE0
E4EDFFF7F7F7FFF7FFF7F4F7F4F6F2FFF6F6FFFFF6F6F6F6
F6F6F6FFF6F6DCE6F4E6FFF7F7F4F4EEE0D5EFE69EF4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4C8BACCDBD4F4CD7F
CBDCF7F3EEEDFFEEECE6E491C8E8F7F7F7F7F7FFF7FFFFF7
FFF7FFFFFFF4F7F4E5C8D1DCA0AEDCF7ABCDE0F794B2BB8A
7BDBDBD4E7ECC6CCF4EFEECFC9DBC8AFA2AFCAE5ECEDFFF7
FFFFF7F7F7FFF7FFEFE4F7F7E4F6F2F4FFF7F7F7EFFFE6FF
FFF4EDF7F6F6EEE6E6E6E6E6E6E6E6EBF2F2F6F6EEEEF6F7
F3E0D9E8F4F7F7F7F7FFFFF7F7FFFFF6F6F2F2F6F6F6F6F6
F6F6F6FFF6F6DCE6F4ECF6FFFFF7F7E6F7C8EFEB9DEDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEDC8B6DBE5C1EDD960
CFF4EEE5EFF7FFECFFF6DC91C8E8F7F7F7F7FFF4FFFFF7F4
FFF7FFF7F7F4F7F7F7A9DCE5E4B08C90F79AA3C27DEE84CC
8093FFDBCFDDD9C6C2C1C6D1DCEEECD4CDC8CDE5EBF4F7F7
FFFFFFFFF7FFFFF7EDEBF4F4EDF6FFE7F4F4F7EDFFDDF2F6
EFEDE4F2E5E4E6F7F4F4EDEDEDEDF4EDE8EDECF3F3F3F6F2
F6F3EEFFF7EDEDEDF4F7F4F7FFFFFFFFF2F6FFF6F6F6FFFF
F6FFF6FFF6EED9ECEDF7F6F6FFFFEEEEF4DBE8F298EDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F4D5C9C1D4F3B6EDF770
A0D9E4F7F7F7FFF7EBDDE072D1F4FFF7FFFFF7FFF7EEF6ED
F7F7FFF7F7F7FFF7FFC0D1EDD4EECCEFAAC8D99198D59AC2
B679FFDBCFF7F7D4AFF3DDD4DCE5E5DBD4C1CADDECF7F7F7
FFF7F4F7F4F4F7FFEDEBFFEDEDF2F6E7F7FFF7E5D5ECF4EC
DDEFE6F7EDE5E4F7FFE5DDF7F4E5E8EFEFF4F7EDEDEFF7F7
EBF2FFF6F6F7F7F4EDEDEDF7FFF6F6F6FFF6F6EEEBF2F6F6
FFF2FFF6F6F4D4EFEDF7F7F2F6EBEEF7DDD5EFF292F4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD48C9DEFAFDCEEBEEEF7B0
96EDEEE6EEF4F7F4E4D3ED83E0F7F7F7F7F7E4E5FFE4E4F7
F7F7FFFFFFF7FFF4F4E5D5CCF7CBE0AAB0BE9B9CBAEDAAA2
B98CF7E0D1E1E1C8B6D9D5C6E7EECBCBD9E0ECF6F4F4FFF7
F7F7F7FFFFFFEDF7EDEBF7F7E8F2FFF4F4F7F7EEEEFFFFBB
A2B2B2C2E4EFFFE5DBDDD9C8D4D9D4C2C8D4D1E0E8EDF7F7
F3F6FFF2F3E5F4EDE8E8EDF7FFF6F6F6F7F3F6EEF6F3F6FF
F6F2FFF2F7EFCDF7F7F7F7EEEEEFF4E5E4E8FFF298EDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF74C5A84E697ECFFC3E6FFD1
88D5F3EBEEF4F7F7EDE4C697DBEFF4F7F7F7E4E5FFF7F7F7
F7F7FFF7F7F7F7FFFFF4ECE5D5EECCDCD9DCD4BAB9D1DCDC
CBC1EEF3D9F6F6BAC2C2D4DDF4E0E6DCDBE8EEEBECF4FFFF
F7F7FFFFF6F6EDF7EDEEEEF7E8F6ECF4EDFFF7EBECEEF7B0
EDBAB6A9D1D1CFD4E8E5E4E4E8D4D4E0DBD4D1CDD9E6E6EB
F2F2F6F6EBFFEBF6FFFFFFFFFFFFF6EBEEF7EEF6F7F7FFF6
F6F6F2F6F4F4CFF7ECECF7ECECF4EEE5F7E8EFE597E8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF79F02D156ECB0D9FFAEDCEDE4
81A4EEEDF4FFF4F7F4E0D48CD4F7F7F7F7F7FFFFFFFFFFF7
F7F7FFF7F7FFFFFFFFF4F7EEE5E5F7D5EDD9E4C8C8A7CCE8
D9BDC2D5DDF6F6C8F6EEF4F4FFF7E4CCD4F7F7F4E6F4FFFF
F4FFFFFFF6F6F4F7F7ECF6F4E8FFE4F4EDFFF7E5E5E6F7C9
CCECD4B5ECF4FFEDF4E5ECE7D4DCF7F4F7F7F7E7CDC8D4DC
EDF4ECE6EBECF7EEF2F6FFEEEEEEF7EEF7FFF7F7F6F6FFFF
F6F6FFF7F7EDC5F3F6EEFFF3F3D9E4F7F7EDE8E891E8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7E47D3673CC5DD1CBAB9EA9F6F7EF
8391E0EDFFF4FFF7F7E0D486E0F7F4F7FFFFFFFFFFF7F7F4
FFF7FFFFFFFFFFFFFFF7F4EFECE5E6F4D5DCCFDCD4A4D9B6
C5D4D4DBC6D1E8C9E4D3D9EEF7F7B6CDE5EDEDF4E6F7F7FF
F4FFF6F2F2F6F4F7F4EBFFF4E8F6E5EDF7F4FFE6E6EEEEE4
CDB9D5B5D5C6BCA9AAB6DCBDAEB5C1BDC2DDFFF4EEDBCDC6
C9E4EDEDEDF7F4EDEFECE0EEEEF6F6ECF7FFFFECFFF6FFFF
F6F6FFEDF4E4C1EEF2EEEEF2F3C8FFFFEDF7E1E596D9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7EF8752A9E0E45BC8F7EBE6F7E4F7E0
8BAADCF7F7EDFFF7F7E0D486E0F7F4F7F7F7F7F7F7EEECF7
F4FFF7F4F7FFFFFFFFFFFFF4FFEEE4E5F4CDCDE8F7B6B6C2
C2DCDDD9ECE4E6D9F7E0FFE6FFD5C5EFEFEFE8ECECFFF4F7
F7FFF6F2F2F6F4F7E4F6FFF4E8F2EDF4F7F4FFF6E5E6EBEF
F7D9F3B6BAE0F6F6CB77BDE4E1E5EBFFEFCAC2E4EEE5F7F3
D4CBECF7F4E5E5F4E5E5EDE8EDEDF4FFF7F4F4F3F6FFFFF6
F6F6F3EDFFE0C8ECF2FFFFF3E4BDF7EFEFFFDCED98CFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7A85098E6EBF255D4DDEEFFEBE5EDE4
98BBDDE0EEEDF7F7F7D4DB86DBFFF7E5EEF7F4F7F7E0F3E5
EFF4FFF4FFF7FFFFFFFFFFF7F7FFF7E5DDD9E7E6E1ECE0ED
DDCBD4D4D9D9E1DDE6FFE6F7C5D4F6E4F4F4E5F3EEF7F4F7
F7FFF6F2F6F7EFF7ECF2F6F4E8F2F7F7F4F4FFF2DCE6F6EC
F7F7D4EDA7BBE4E69BAEAAB1D1DDDDECEDD9EED1F7EEEEF7
EFCBDCE0E6E6E0D4D9E6EBF6F4FFF4EEF3FFF6F6FFF6F6F2
F2F2E6F4F7D9D4EEE0EDF3EBF7AFE6EFF6ECD4E48FC2FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7F7FFF7FFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA04176DDFFEBF68581B2DDE6C3CDDBB9
98E5EEF7E0F4F7F7F7D4DB79E4FFFFEEEEF4FFF4F4DBDCC8
BDD9E5F4FFFFF7FFFFFFFFFFF7F4F4EFE4ECDCDCE1E8EFF4
F4E5E4F4EFEEE6CBCFC6C3C9E5F6EBE5F4EDE5EBECEFF7FF
F4F6FFF6F2F7EDEEF3FFF2F7E5EEF6F4F4F4FFF6F6FFE6D5
E5FFEECCE5C08F8AA8B09F6FC8E6D9ECEDECE4DBD9D4C5D3
DCECCFC2C8CFE0E5DCF4DDD1D4DBE0EEF2F6FFFFF6F6F6F6
F6F3EEEDE5DCD9F7F7E4C8CFEFB6DBF2EFBBE0EC91BDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFDD618FE7EDF4E0F7E5A798B0CFBAD4BAB8
D9F6EEE0E4F7FFFFF4DBCD78F4FFFFFFF7F7F7FFF7E5C3D4
E4CCDDECEFFFF7FFFFFFF7F4F4F7FFF7E5F3F6F6F4FFFFF7
EFF7EEECE7D4D4EFF2F6FFF6F6FFEDF7F7EEF6F3ECFFF7F7
F7F2F2F6F6F7F4E5F3FFF2F7EDF4F2F7EDF7F7FFF7E5FFEF
E5E4E4ECE4E0ECEDD592DC5AC8E6C2E8F7EFF4DBC8F7EECD
DCEDF7F7EFEDD9ECD5E5ECD9D9E6EEFFF6F6F6F6F6F6F6F2
F6F3EEE8D9D5EEFFF4F7DBF6D9B6D4FFDBBCE0EC83BDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7AE5AD1EEE6F4E0FFF7D39F95A4BDC9D1F4
ECF2F3EDFFF7F7F7EDDBC88AE4FFFFEEE5F4FFFFF7FFE4C1
DDE5CCE4E5EFF7FFFFF7FFF7FFF7F4F7F4F7F4ECE5F7F7F7
F7EFF4EBF6F6F6F6FFF6F2F2F6F7EDF7EEFFF3ECE4E4E4F4
F6FFF6FFFFF4FFF4F4F6F6F4EDF7F6F3EDFFF4FFF7E1E1E6
E6DCE4D4F4EFECD5CAECA27BCFECC2CDE7F7EEC6CDEBC2B0
E1F7DCCFE0E0CCDCE4E5E8E8F7F4E5EEFFFFF6F6F6F6F6F2
F6F6ECE8CFE0F7F4F7F7DBF6EC9DDBFFD4C2ECEC91B0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF47861E0F3F7EFDBFFF7F4DDB29DBAE1EEE5
DCE8EFEDF7F7F7F7EDDBC898DBFFEEFFEEEEE5FFF7F7F7D9
D1EFDBEDDCDCE5F7FFF4F7F7FFFFF7FFEFF7FFFFE6F3E5F7
EFEDF4F3EBF3F6F6F6F6F6F6EFF7EDF7EEFFF3F7F4F3E4F4
F6FFF6FFFFF4F7FFE7FFF3F7EFEFFFE6F7F7F7F7E6F7FFEF
E8EFD1DCEEE0E5ECD9C3EFC1D9F3EBE5DDEBEEC8D4BBCCEE
ECDCE5FFECD4C3E1FFEFEDF7ECE4F7ECEBEEF6FFF6F6F6FF
F6F6F4D9C1DCEDF7F4D9DCEBFF8CE7F2C6D1F6CF9EB5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF75A78FFF7F7F4D4EEF2EBEEFFF7A9EDE6EC
E5FFEFF4F4FFFFF7EDDBC391E4F7F6E5F4E5EEF4FFF7F4E5
C9E4F7E4EFF4D4DDF7F4FFF6F6F6EEF7F7EFF7FFEEF7ECFF
EFEDF7F7FFF7FFF6F6FFF6FFE5EFE8FFF7EEF3FFEEE7F7F4
FFF6F6FFF7EFE5E5E7FFECFFFFEFEFEBF7F4F7EFF7E6E1EF
F7F4F4E6DDEEE5E0E5DDC3B8AEAAB6C3D9ECF7E0D1E0F7F7
E4D5F3F3DDECDCE6F7F4EDEDE5FFEEF4F7F6E6F7F2FFF6F6
FFEEEFD4C3F7FFF4FFE4E5E6FF80E5EEBDE7E5D98CC8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F4F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEF4C96F7F7F4F7D4EBF7FFEBF4F4B6EEECF4
FFFFF7EFEFF7FFF7F4D4C38BEEF7F4F7F7F7F4F7F7F7FFF4
DDD5D9E5D5F4F3C9CCE6F4EBF2F2F2FFF7F7F7F7FFECEBEE
F7F7F7F7F4EFFFFFF6E4DBE0E0E4E4F7F7F7EEEBF7ECF7F4
FFF7F7F7F7F7E5EEECEEF7F7F4F4EDF6EEEDF7EDEFEDEFED
F4FFFFE7EEDDEEEFDDE5D4EFE0D4D5E4DDE4D9D1C2DCDDCD
C1E5F3D3E5F6EEE5EDEFEDEDF4E6EEF3FFF7F4F3F2FFF6F6
F6F4EDD1CDF7EEF3F7EEE4ECF274EBDCBBEEE0E08CCFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F4F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD14BB5F7EFEEF6D9EEF4EDEEF2E4D0EBF7F4
F7F7F4F4F7F7F7F7F7D4C398EBF7F6EEF4F7F4F7F7F7FFF7
F4D1D1EDE0ECE5ECCBCBE4E5F3F6F6FFF4FFEFEDE4ECEEE5
EFF4F4F4E0D9E6D9DBD5DBDBE5EFDCEFEFF7FFFFE6F7F7F7
F4F7F7F7FFF7F7F7EBF7F4FFE5F7F4FFF6E4F7F7EDF7EFEF
F7FFFFEEEFE7ECE5F7E4C3C8CDE0CBD9D5E4E5E5C9C8D4DD
FFEFE1F6EEF7E6EFEFF7F7F7F7EEE6F3F6F6F6F6FFF6FFF6
FFF4D9C9E4ECEEE4DBD4E8EFF461FFD9C1F6DBCD8FD9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8F58D4FFF4F3F7E0F7E5E5EDE8EFECE4F4ED
ECEEF7F7F4F7F4F4F4DBCD91E6F4EEEEF7F7F7F7F7F7FFFF
FFE5C3D9E4E4E5E8D9BBA7988B8C86868C85777F91918385
8B919797A4B0AABCCDDCF4F4DCD4CBE5EDF4EFEEEEF7F7FF
FFFFFFF7F7F4F7EEF6F6F3F7EFF4F4F6EBEEF7EDF4E5E5ED
F4F4F7EEEEE6F7EEEEF4ECEBE4D4C9CFC2B2C1DBF4E4D3FF
EEECE6D1DCEDF4F4F7F7F4F4F4F4F4EEF6F2F2F2F6F2FFF6
FFE5C9C9EDE4F6E0E5EDFFEDE767DDD5CCFFDBBC91EDFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7F7F7F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF7977E4FFF4E5DCDDEFE4E4F7FFFFF4E8EFF7
E4F6F6F6E8F4F4F4F4DBD498DCEEF7FFFFEEE4FFF7F7FFFF
FFF7EED1D4CBD5E1EDF7EDF4F4FFF4F4E4E4F4F7E8E0E4F6
FFFFEBEBF6F6FFF6ECF7ECECE4E0D9E6EDF7E5ECFFF7FFF7
F7F4F4F7F7EFEEF6FFF6F3F7FFF7EDF2F7F7F7F4EFFFF7F7
E6E8F7EBFFEEE6F6EBFFFFFFFFFFE6F7F4E1FFF6EBF3F3FF
E6DCE4F4EFF7F7F4F7FFFFFFFFFFF6F7EBFFFFF6F2F6F6FF
F7E1CFD4ECF6E4FFD9F7F4FFC286DCE0E0FFDBB692F4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8679DBF7F7F4F4F4F4F7F7F7F4F7F7EDFFF4
EDF7F6FFE5F7EDF4F4E4C5A4D5F6F4FFF7E5ECF4F7F7F7FF
FFF7F7F7F7DDC9CDD4E6EEE0E6E4EDF4E4F4F4E6EDEBF6F2
E4E5EEEEFFFFF7F7EEF3DBD3EEF7E5E4EFEDF6ECFFF4F7F7
F7F4F7EEEEF4F6F2F6F6F6F7F7FFEDEBEFF4F4F7F7F3ECF7
F7EDFFE4E6EEF7E5EEFFFFFFEEE6EEF7F7DCE6E5F7F3DBD9
E8EFF7F4F7F7F7F6F6F6F6F6F6F6FFECF4F2F2F6FFF6FFF6
E7D4C2CBE5F4ECEEDDE5F4F6A4A4E1E0E0FFE0AA98F4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFF7F7FFF7F7F7F7FFFFF7F7FFF7F7FFFFFF
F7F7FFFFFFFF8679DBF7F4FFF7F4F4F4F4FFFFF7F4F7F7ED
F4F4FFF6F6E8FFF7EFEED496CDF6F4FFF7FFF4F4EEEEF7FF
FFFFFFFFF4EDE5E0CBC6ECF3F6EFE0E6F7F2EBDBD4D9DBE8
F6FFDBDBE0EEF7E5E6ECEFEBFFEDDCEEEDF7F6F3F7F4FFFF
FFF7F7ECECF4F6F2FFF6F2FFEDF7F4E6EFF7F7E4E6DCD5D4
E0D4E7EDF7EEE5F7FFFFFFFFEEE6E6E6F6ECECF3D4D4E7F4
F4F7ECF6FFF6F2FFFFFFFFF6F2F6F6F4F4F2F6FFF6F6F2F7
DCDBC8DBFFF4F3E4E4DCF7F388CDDCEEE0F3E0A492F7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFF7F7F7F7FFF7F7F7F7FFFFF7F7FFF7F7FFFFFF
F7F7FFFFFFFF8C73E0F7E8F4F7FFFFFFF7FFF7F7FFFFE4DC
F7F4FFFFF7F4F4E4E0ECDC9ED4ECE5F7FFF4FFF7EEE5FFFF
FFFFFFFFF7F7F7F4E5B2BBCDD5D9D4CFE1EDF4EDDCD4D4D9
CCBDD9D9C8BDC1CCDBD4CDD1D5D1D5D9D9E6E4EDEFF7FFFF
FFF4FFF7E5F6EBFFF2F6F6FFEDF7F4E6EFEFF7D9E4DCEBEB
E0D9D4D4EFF7EEE6EEFFFFFFFFFFFFFFEEF7F7EEFFFFF6F2
F6F7F3FFF2FFF2FFFFFFF6FFF2F6F6F7F7F6F2F6F6FFF2EC
E8C0CCE0F7F7E4E5D9F4F7D48CF6ECEEE0F3D9BC92CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7A466DBEFF4F7F7F7F7FFF4F4FFEFF7FFDBDB
FFF4FFFFF7F7EDE0F7F7E4A7D1F4EBF4FFF7F7F7F7FFFFFF
FFFFFFFFFFFFFFFFF7E5D5D9D4D1D9DBD1CDC8CDD4CDD4C8
BDD4D4C6CFC2BDBDBDBBBDC8D5D1E7E0F7F7FFFFF7FFF7F7
F7E5EEF7E5F6EBFFF2F3EEFFF7F4FFE5DDEDEDE0E0F7F7FF
F7EEE5DDD4E5F7FFE6FFFFFFFFF7F7FFFFF6F6FFFFFFFFFF
F6F2F2F6F6FFF2F6F6F6FFFFF6F6F2FFF7F7F6F6F6FFF2EC
D9B5ECE4EFF4F7ECE5E5DCBEA9F7F7E6D4F4C8E0BD71F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFF7F7FFF7F7FFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7BA64BDEFF4F7FFF7F7F7F4F4EFFFF7FFE0E6
F7F4F7F7FFF4F7DCD5EEE0AEDBE5EBF7F7FFF7F7FFFFFFFF
FFFFFFF7F7FFF7F7FFF7E5E0E0D9D4E4D9D4D9D9DCD4D1E7
F4E5D9D9E4DCD1D1D4E5E4E0E6FFFFE4F4F7FFF7FFFFF7F7
F4ECECF4F4F4F2F6F6F7EBFFFFEDFFFFE4EEE6D9E4EBF3F4
EFEDE0D5E6D5DBEDE5EEFFFFFFF4F7F4F7FFFFFFFFF6F6FF
FFF6F2F6F6F6FFFFF6F6FFF6F2F6F6F6F7F7F2F6F6F3EEE0
C6CDE0EDF7F4F4F7F7CFE4BABAECE4E5DBF4CCDDC233DCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
FFF7F7FFF7F7FFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD15FAFF7E5FFF4EDF4FFF7F4EFF7FFFFECF7
E5FFFFFFF4F7F7EDD9E5E5BDE4E0ECF6F3EEFFF7F7F7F7FF
FFFFFFF7FFF4FFF7F7F4EDE8E8E8E8D9DCE5E5E5E5F4E1CD
C8C1CFE1D9DCE5F4EEE0EFF7F4E4E4FFFFF4F7F7F7FFF7F7
F4F4F3E5EFEEFFF6FFF6FFF6FFF7EDF7F7DBCDBAD9DCD9DC
EFF4F4EEC8B6B5AFA9A2B2D9E6E5F4F4F7FFFFFFFFF6FFF6
F6F6F6F6F6F2F6F6FFFFEBECF7ECE4F6F6F6F6F6F2F7F6CB
C1CBDDF7FFFFFFF7F7D4E4BAC1F7E4F4E0F7E0EEA54697EF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
FFF7F7FFFFFFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE061AEEBE0F7F7F7F7F7FFF7F4FFFFF7EDE6
EEE4F7F6EEFFF4F7E0FFDBC8E1E0EDF2F6F3F7FFF4F7F7FF
FFFFF7F7F4FFF7F4F7FFFFFFFFFFFFFFFFFFF6F6FFFFF6F6
F6F6F2FFFFFFFFEFEDF7FFFFFFFFFFF7FFF7FFF7FFF4FFF7
F4F7ECF6FFEBF2FFFFF6F6F6F6FFF7F7EDF7F7CAD4C9D9D4
DDF4F4EDF7F6E0E0E1D9C0B8D4D3F6FFFFF7F7FFFFFFF6FF
FFF2FFF6F2F6F7F3F3E4EDF4EDF7F4F3FFFFF2FFF6FFF4CF
C8D4F4FFFFFFF7F7DDFFEECDC9D9E4E4DBF4D4E0B5738FD1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFF7F7F7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7E76DABFFD9F7F7FFF7F4F7FFF7FFFFF7F4E0
FFE0F7EEEEF7F7F7E6F7E4C1E1E5DCEEF3F4EFF7F4FFFFFF
FFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFF6F6F6FFF6FFF6F2
F6F6FFF2F2F6FFFFFFF7F4F7F7F7FFFFF7F7FFFFF7F4F7FF
F7F7FFF7F6F7FFF6FFF6F2F2F6FFF7F7FFFFFFE6E1D9C9CB
C1BDE0DDEDE5E6F7F2EBE4CCB7989FC5E0E5F7FFFFEEEEF6
F6FFEBECECE7E4EFD5DBE0D4D4DDF7E6F2F6F6F2FFFFF4BA
CAD9FFF7FFFFF4E1F3ECEFD1CDCDF7E5CBD1D4C2DCA49DA9
DDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7ED6197ECE4E5F4EFF7F7F4FFF7FFFFFFFFE0
F7ECECFFFFF4FFECEEEFE5BAE5EEE7EDDDEEF7F7F4FFFFFF
FFFFF7F7F4FFF7F7FFFFF6F6F6F6FFF6F6F2F6F6F2F6F6F6
FFF2F6F6F6F6F6F6F6FFFFF7F7F4FFFFF7F7FFFFFFFFF7F4
E4ECEEEEEEF3F6F6F6FFF2F6FFFFFFFFFFFFFFF7F7F7E6D1
D4CBC9D4E5EDE8DDEBF2FFEBF3ECC1ABA9AFD4DBE4E4E4E0
E6E6EEFFF7EFECDBD5EDEDFFE5E4E4F7F6FFF6F6FFF7F7B0
C8ECFFE5EEFFF7D9ECEDEDCFDCC2CCE0F7ECF3BAF4C8C5A3
CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF618AECF4E6F7EFF7FFF7FFF7F7F7FFFFEC
ECF7E4F7F7FFF7EEE4E4EED1D4EEECF7E4ECFFF7FFF4F7FF
FFFFFFFFF4FFF7F7FFFFF6F6F6F6F6FFF2FFF6FFF6F6F6FF
F6FFFFF6F6F6F6F6FFF6FFFFFFF4FFFFF7F7F7F7FFF7F7FF
EEE5E5F6F4F7FFFFF6F6F6F6F6F6FFFFFFFFFFF7F4F7F7F7
EDECD5CAC1D4DBD1C8D1E4EBFFF6F2EDEDC3C5CFC6CDE4E7
E0E0D4CFCDD4E0EDF7FFF7E5DDE5E4F2FFFFFFFFFFF4F7AE
C1FFEDF6E5F4F4ECECF4EFE0E0D1ECD4C5C1C8CCF4C8CD97
D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6D8CFFFFE5F3EDF7F7FFFFF7F7F7FFFFF7
E5EEECECF7FFE5E0E5E5E5E8CFF7E4EDE6F4FFF4F7F4F7FF
FFFFFFFFF4FFFFFFFFFFFFFFF6F6F2F2F6F6F6F6FFFFF6FF
F2F6F6F6FFF2F6F2FFF6F6F6FFF4FFFFFFF7FFEFF7F7F7FF
F7FFFFEFF7FFFFFFF6F6F6F6F2F2FFFFF6F6FFF6F6FFFFF4
F7F4E5E4D3CDD9E4EDDCD4E5E4EBF6F7F4E6DCDBD9DBD3E7
E7E0DCE0F4FFF7ECEEF7E5DDE6F7F2F2FFFFFFF7F4FFEDA4
D4EFEFF4F7EDEDF4F7F7EFEDE8C1D1D9D5D5E0ECE8D4B68F
E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF7985F7F7F7EBEDF4F7F4F7EFF7FFFFFFFF
F4E6F4EBF4EDEEE5F7E5E5E8D4F4EBE8ECECEEE4FFFFFFFF
FFFFFFFFF4FFFFFFF7F7FFF6FFF6F2F6F6FFF6F6FFFFFFF2
F6F6F6FFF6F6F6F6FFF6F6F6FFF4FFF7F7F7F7F7F7FFE4EC
F7F4F4EDF7FFFFFFF2F6F6F2F6FFF2F2FFFFF6F6F6FFFFF7
F7F7FFEFEEEEE5D9D9E4DDD9DCE5E8EFFFF4F7F7F7F7EEE0
ECFFEEF7ECFFF7EEE4E5E5E5F7FFF6F6FFFFF7FFF7F4E6A4
D4EDF7F7FFF7F7FFF7F7F4F6F2D3E4E0E7ECF6EBEDC579A8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8C73F7F7FFECECEFEDF7F7F7F7F7FFFFF7
EFE4FFEEECEFFFE6F4E5E5E8DBEFE4E8F7E5FFECF7F7F7FF
FFFFF7F7F7F7FFFFF4F4FFF2F2F6FFF6FFFFFFFFFFFFFFF6
F6FFFFF6F6FFF6F6F6F6FFFFFFF7F7F7F7FFFFFFF7F7E4E4
F7F7F7F4F7FFFFFFF6F2FFF6F6FFF2F2FFF6F6F6FFFFF7F7
F7EFF7F7EDE4F6EEEDDCDCE0D3D4DCE6EDFFF7F7F7F4EDF4
E4E0E0ECEEEEF7F7EEDDE5EFFFFFFFFFFFFFF4F4EDF7F4A4
D4F7F7FFFFFFFFF7F7FFF4F6ECDDE6F3E1FFF3ECF4647FED
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEF9779EFF7FFF4D9F7EDEFF4F7F4FFF7F7FF
F7D4C5DBE4F7F7ECECFFDBE8DBEFE4EFEDFFE4F7F4F4F4FF
FFFFF7F7F7FFF7FFF4F4FFF2F2F6FFFFF6FFFFFFFFF6F6FF
FFF6F6FFFFFFF6F6FFFFFFFFFFFFF4FFFFFFFFF7FFEEEEF7
F4FFF7F7F4FFFFFFFFFFF6F2F6F6F2F6F6F2F2F6FFFFF7F7
EFEDF7F7F7E5E7EBF6EEE6E8D9CFBDB5B5BBC8D4E7EFF7F7
F4EDECE0E0D3E0D9D1E5F7FFFFFFFFFFFFF7F7F7EDF7D5A2
ECF7FFFFF7F7F7F7EDF7F7F7E5E4EBECEDF7F3EEE848C4E4
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD9A28BF4FFFFF4D4F7F7EDF4F7F7F7F7F7FF
F7E5ECF7F7ECEBEBECFFDBE8E0E6E5F6E1F6F7ECF4F7F7FF
FFFFFFF7FFF7F7F7F7F7FFF6F6FFF2F6F6FFF6F6FFF6F6FF
FFF6F6FFFFF6F6F6F6FFF6F6FFFFF4FFF7F7FFF7F7E5E5F7
FFF7F4F4F4FFFFFFFFF6F2F6F6F6FFF6F2F2F2F6FFFFF7F7
EFEDFFF7F4FFF7E5F3F2F3ECF4F4EFEFECDCE0E5E0D9DBD4
C8CDE4EDDCDCE1E5F7F7F7FFEFEFFFFFFFF4FFF7F7F4CFB6
FFF4FFFFF7F7F4EFF7EFF7E4EEF7EFF7F7EDF7EBE183808D
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFF7F7FFFFC28FBBE4F7F7F4E5E5F7EFFFF7F4FFFFF7E5
E4F7F7FFFFEEEEF6ECF7E0EDE5E5E1F2E8ECFFECF4F7F7FF
FFFFFFF7F7F7F4F7FFFFFFF7F3F2FFF2F6FFF6F6FFF6F6FF
FFFFFFFFFFF6F6FFF2F6FFF6FFFFF4FFF7F7F7F7FFF7F7E4
E5F7ECEEFFF7FFF6F2FFF6F6F6F6F2F6FFFFF6F6F6F6F7F7
FFF7EFF4FFF4F7F4F7ECF3F2F6F2EEEDEDEDE4E0E0E0DBDB
E0E6E0D9ECE4F3FFFFEDEDFFEFEFEFEFFFF7F7F4F7E5C1C5
FFF4FFF7F7FFF7EDEDF7EDECF7ECF7EFEDF7F7EEDCC2B285
97F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFF7F7FFFFAA8AD4E5F4EDEFF7E0F2EEEFF7F7F7F7FFE0
DBF4F7F4F4F7EEF3EBEDECDDEDE6E1EBEDEFEBF7EFFFF7FF
FFFFFFF7F4F7F7F7FFFFFFF3EEF6F6F6F6FFFFFFFFF6F6FF
FFFFFFF6F6FFFFFFF2F6F6FFFFFFF4F7F7FFF7F7F7FFFFEE
ECEEF7EEFFF7F6F6FFF2F6F2F6F6EBF3F6F2FFF2FFEEF4F7
F7F4F7FFF7F4F7F7F7F7F7F6F6F6F6FFF7F4EFF4EDE8EDED
EDEDE5EDEDE4F2FFFFEFEFFFEFEFEFFFEFEFEDF7F4E0C8DB
FFF4FFF7F7FFFFF7EDF7F4F7F6ECF7FFF4F7FFFFF4D4F79D
73F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8A9CD4FFF7EDF4F7E4F2FFEEF7F7EDF7F7F4
F7EDF7F4F4F7FFF7EEE5F4DBEFDDDDD9F7EFE0F7EFF7FFFF
FFFFFFF7F4F7F4F4FFFFFFF6F2F6F6FFF2F2F6FFFFFFFFFF
FFFFFFF6F6FFFFF6F6FFF6F6FFFFF7FFEFF7FFFFF7FFF7F4
F4EEF3F7EEF6F6F6FFF6F6FFF6F6F7F7F2F6F6FFF2F4F7F7
F7F7F7F4F7F7F7F7F7F7F3F3F3EFE4F2F6F6EEECECECE4ED
EDEDF7F6F6F6F6FFFFFFFFFFEDEDEFFFEFEDF7EEE4DCCDE0
FFF4FFFFFFFFF7F4FFF7F7F7FFF7FFEFF7F4F7EDF4C8F4B2
61DDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF6DA7E4FFFFF4F7F7E6FFF6F6F4ECE0FFFFF7
F7EDF4F4F7F7F4F7ECF6F7D4FFE8E6D9EEF7D9EEEFF7FFFF
FFFFFFF7F7F7FFFFF7FFFFF6F2F6F6FFF6F6FFF2F6FFFFFF
FFFFFFFFFFF6F6F6F6FFF6F6FFFFFFF4F7F7F7F7FFF7F4FF
F7F7FFF3F6F2FFF3EBF6F6F6FFFFF6F2F6F6F2F2F6F4F4FF
F7FFF7F7EFFFF7F4FFF7E4ECECE7F7EFF3E4E4F3F6FFFFF6
F6F2F6F6F6FFF6F6FFFFFFFFF7F7EFEFF7EFF7ECE1D5D3EC
FFF7F7FFFFF7FFF4FFF4FFF7F7F7F4F7F7F7EFEEECCFF7DC
69A7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
FFFFFFFFFFFF5BBCE5F4F7F7F4EFE4F6F6F2ECECE5F7F4F4
FFF7EFE8EDF7FFF4DCE5FFDCE5EFD9EDE0F7E1F2F4F7F7FF
FFFFFFF7F7F7F7F7F7FFF6FFF2F6FFF2F6F6F2F6FFF6FFFF
FFFFFFFFFFF6F6F6F6FFF6F6FFFFF7F7FFFFF7EEE4F7F7E5
EEF4F7EBFFF6F6F7F7F2F6F6FFF6F6FFFFFFFFFFFFF7F7FF
F7F7FFF4F7F7F7FFF7F7F4FFEFFFEDF7F7F4EDF7FFF2F2F6
FFF2F6FFF6F6F6F6FFFFFFFFFFFFFFF7F7F7F4DDDCD4F3EC
FFF7F7FFF7FFF7F7FFF7F7F7F7FFFFF4F7FFE4ECDBD4F4F7
8378F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7
F7F7FFFFFFFF42DCD9EDFFF4F4FFF4EBF6F6EBEDEDFFF4F4
F7FFFFF7F7FFFFF7EFECEEEDEEE5DDD1CBD9D1F3E5F4EFF7
FFFFFFFFFFF7F4F7FFFFF6F6FFFFFFF6F2F2FFF6F6F6FFFF
FFF6F6F6F6FFFFF2FFF6FFF6FFFFF4FFF7F7FFE5E4FFF7EE
F6F7FFF2F6F6F6F2F2FFF6F6F6F2FFFFFFFFF7F7F7F7F7F7
FFF7F7EDF4F7F7FFFFF7FFF7FFEFF4EFF7F4FFFFFFF6FFF6
F2FFFFF6F6F2F6F6FFFFFFFFFFFFFFF4F7EDDDDCDDD3EBEE
F7F7FFFFF4F4EFF7E5E0ECFFFFF4F7F7F4F7E6ECD1EEDCF7
9173FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7FFFFFFFF31F4C1E4F4EDF4FFF4E4F2F6F2FFF4EDF7F7
F4F7F7EDEDF4F7FFEDECEEEDF7E5E0DCD9EFC6F4ECF6F4F4
FFFFFFFFFFFFF7F7F7F7F6F6FFFFF6F6F6F2FFF2F6F6F6F6
F6F6F6F6F6FFF6FFF6F6F6FFFFF7F7FFF7F7FFFFE5EEF4F4
F7FFF7EBF6F6F7F7FFF6F2FFFFF6FFF6F6FFF7F7F7FFFFFF
F4FFF7EDF7F7F4FFFFF7FFFFF4F7F4EFEFF7FFFFFFFFF6FF
F6F6F2FFF6F2F6F6FFFFFFEFEFFFFFF4EDE5EEE8DBE6F7F4
F7F7F4F4F7EDF7DDEEEEF3F6F3F7F7FFFFF7F2EBD9ECECE0
9D72F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF1DECC1E4F7FFF4FFF4F4F3F6F6F6F4EDF7F7
F7F7EFF4F4F7F7F4F7E4EEF4FFE5EED9DCE4C5EDECF6F4F4
FFFFFFFFFFFFF7F4FFF7F6F6F6F6F2F2F2F6FFF2FFFFF6F6
F6FFFFFFF6F2FFFFF6FFFFFFFFF7F7FFFFFFFFF7EEEEEDF7
F7FFF3EEF6F6F7F7FFFFFFF6F6F6F2FFF6FFF7F4F7F7F7F7
F7F7F4F7F4FFF7FFF7FFFFFFF4F7EDF7F7FFFFFFFFFFFFF6
F2F6FFF6FFF6FFFFFFFFFFEFEFFFF7E6EFE6EFD5DDEBF7E5
F4FFF7F7EDEEDBEEF6ECECFFF3F7F4F4E4E6F7ECE5ECECE0
AF7CD1F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFF00DCE4EFF7F7F4F7FFF7E4FFF2F6EDF7FFFF
F7F7F7F4F7F7F7F7FFF7ECECE5FFFFF7D9D5BBEDE0F7F7F7
F4F7FFFFFFFFF7F4F7FFFFF6FFFFFFFFFFFFF6FFF6F6FFFF
FFFFFFFFF6F2FFF6FFFFFFFFFFFFF4FFFFF7F7F7FFFFE7EC
ECF6F6F6F6FFF6FFFFF6F6FFFFF6F2F6FFFFF7F4F7F7F7EF
F4FFFFF7F7F7FFF7FFFFFFFFF7FFEDFFF7F7FFF7F7FFFFF6
F2F6FFF6F6FFFFFFFFFFFFFFF7F4F7E8EEEEE8DBF4EBEFF4
F4FFF7EDF7ECD0FFF2F3F7F6F6EEF7F7E0EEEEF4F7FFE0E8
C18FAEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7F7
F7FFF7F7FFEF06F7FFF7FFF4F4F7FFF4EDEBF6F2E4F7FFFF
F7EDFFF7FFF7F7FFF7FFF7DBECECE0EEEED4BAE5DDDDF7FF
F7F7FFFFFFFFF7F4F7FFFFF6F6F6FFFFFFFFF6F6F6FFFFFF
FFFFFFFFF6F6F6F6FFFFFFFFFFFFF7F4F7F7F7FFE4E5ECF6
F6F7F2F6FFF2F2FFFFF2F2FFFFFFFFFFF7F7FFFFF7F7F7F4
FFF4F7F7F4FFFFF7FFFFFFFFFFF4F7F7F7F7FFF7F7FFFFF2
F6F6FFF2F6F6FFFFF6F6FFFFF4FFF7EDE6EFD5E5E4E5F7FF
FFF7EDEFF7DDF4F2F6F6F6F6FFFFF6FFEEFFECF7F4F4DBE8
CF8BB0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7F7
F7FFFFFFFFE833D1EDF7F4E8E8F7F7F4F4ECF6F7E0F4F7F7
F4EDF7F4F7FFF7F4FFFFFFD4F7EEFFEEE6E0C2E0F4E0ECF7
F7FFFFFFFFFFFFF7F7FFFFFFFFFFF2F6F6F2F2F6F6FFFFFF
FFFFF6F6F2F6F2FFF6F6F6FFFFFFFFEFF4FFF7F7E5E4F4F7
F7F3F2F2F6F6F6FFFFF2F2FFFFFFF7F7F7F7FFF7F7FFEFEF
F7F7F4F7F4FFFFF7FFFFFFFFF7FFF7F4FFFFFFFFF6F6FFF6
F6FFF6FFFFF6FFF6FFF6FFF7F7F7EFE5E5EDDBEEE4F4FFFF
FFF7F7FFE4ECEBF6F6FFF6FFFFEEEBFFF6F7E4FFF4F7ECDC
C87FBDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FF
FFFFF7F7FFE848DCE8FFEDEDF4F4FFF7F4F4F6ECE0EFFFFF
F7F4F4F7F7F4F4F7F4F4F4E6EDECF7EEEEF7C1DCE4E8EBEF
F4F7FFFFFFFFF7F7F7F7FFFFFFFFF2F6F6F2F2FFFFFFFFFF
FFFFF6F6F2F6F2FFF6F6F6FFFFFFF7F4F7FFF7F7F7F4F4F7
FFFFF6F2F6FFFFFFFFF6F6FFFFFFF4F4FFFFF7FFF7FFEFE6
F7F4F7FFF7F7F7FFFFF7F7F7FFFFF4F7F7F7FFFFF6F6FFFF
FFFFF2F6F6FFFFF6F6FFF7F7FFF4F4E6EDF7D4EBF4F4FFFF
EFE4EEE5E5FFF6FFF6FFF2F6EEF6F7F6F6F6F4FFF7F7F7D9
C272CDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FF
F7F7F7F7FFCA45EEEDF7E8F4FFFFF4F7FFEFEEF3F3ECF7F7
F7FFEDEFF4F7F7F7F7E8EFF3DCEEECEEF7EBC1EDD4EDEEEE
F7F4FFFFFFFFF4F7F7F7F7FFFFFFF6F6F2F6F6FFFFFFFFFF
FFFFFFFFF2F2F6F6FFFFFFF7F4F4FFF7FFFFFFFFF4FFFFF7
F7F6F6FFFFFFFFFFF7F7F7F7F7F7F7FFF7FFF4F7FFF4F7F7
EFF7FFF4F4FFFFFFFFF4F7F7F4F4FFFFF7F7FFFFFFFFFFFF
FFFFF6F6FFFFFFFFFFFFF4F7F4EFF7D0ECE5DCF2F7EDE0E0
FFDBD9ECF2F2F2F6FFF6F6FFF7EBEBEBF7F7F4FFFFF4ECD9
926FE4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FF
F7F7FFF7F7BD48EDEFF7F4FFF7FFF7F7F4F7EDFFFFEBF7FF
F7FFF7EDF7FFF7F7F7F7EFF4ECE7F4E4ECECC8F4D4EFEDF2
F7EFF7FFFFFFF7F7FFF7FFF7FFFFF6F6F2F6F6FFF6F6FFFF
FFFFFFFFF2F2F6F2F6FFFFF4FFFFF7FFF4F7E5E5F7F7FFF7
EEFFF6F7F7FFF7F7F4F4F7F7F7F7F7FFFFF4F7FFF4FFF4FF
F4FFFFF7F7FFFFF7F4FFF7F7F7F4FFFFFFFFFFFFFFF6F2F2
F6F6F2F6FFFFFFFFF7F4F7F4FFF4EED4EFE5F7EEF2F6F3E4
EFF4F7F7FFF7F7FFF6F6FFFFF7ECF6E4FFF7F4FFF7EDE6B6
63B6F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7F7
F7FFF7FFF7A753F7F3EEF7F7F7FFFFFFF4FFEDF4F7F2F7F7
F7F7F4F7F4F7F4F7F7F7F7DCF4EEF4E4E4EFD4F7DCE5E5EB
F7F7F4FFFFFFFFF7F7F4F7F7FFFFF6FFF6F6F6F6FFFFF6FF
F6F6FFFFF6F6F6F2F6FFFFF7F4F4F7F7F4F7E4ECF4E5ECF7
F6FFF6F7FFF4FFFFF7F4F7F4F7FFF7F7F4FFFFF7FFF4EFF4
F7F7F7FFFFFFFFF4FFF4F4F7F4F7FFFFFFFFFFFFF6FFF2F2
FFFFF2F6F6F6FFF7F7F7F4EFF4E5EEE8DBFFF7EEF6F2F7E8
F4F7F7F7F7FFF7F6EEF7FFF7FFECEBF3F7F6ECF7E5D5DC9B
6BEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7F7
F7FFF7F7FF986DF7ECECF4FFF7F4F4F7F4FFF7F7F7EEF3F7
F7F7F4F7E1EDF7F4F4F7EDD9EEECEDE6EDF7DBF7F4E4E0EE
E5F7F4FFFFFFF7FFF7F7F7FFF7F7FFF2F6F6FFF6F6F6F6FF
F6F6F6F6FFF6FFF2F6FFFFF7F7FFF4FFFFF7FFECECE5F7F2
F6F6F6FFF7F4FFFFF7F7F7FFF7F4F7F7F7FFF7EFEFF4F7FF
FFF4F4EEEEF7F7F7F4FFF7FFFFFFFFFFFFFFFFFFF6F6F6F2
EEEEF2FFFFF6FFF4F7F7FFF4EEFFEEE8DBF7F7F2F3ECEDE5
FFF6F6F7FFF7F6EEFFEEF3F7ECF6F6F6FFF3EEF4ECD1D488
83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FF
FFFFFFF7E4B567F7F7E0ECFFF4FFFFF4F4FFFFF4F7FFE4F7
FFF4F4F7E8EDF7FFEFFFF7EEEEF7FFE0F4FFDBF4FFE8E0F7
E6F4F7F7FFFFF7F7FFF7F7FFF7F7FFF6FFFFF6FFFFFFF6F6
F6F6F6FFF2FFFFF2FFF6F7FFF7FFF4FFFFF7F7E4F3EDF3F2
F6F6F6FFFFF7FFFFFFF4F4F7FFFFF7FFF7F7F7F7FFF7F7F7
FFF7FFE5EEF4F4F7ECF3FFFFFFFFFFFFF6F6F6F6FFF6FFF6
F7F7F6FFFFF3F4F7F4FFF7F7EEFFEED1E5F4F6EEFFF4EFF7
FFF6F6F3F3FFF2F7F7F6ECEEE5F3F6EBF4FFF4F7F4EDCD78
98FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7F7
F7FFFFF7E5C655F4F4E0E6FFF4FFF7F7F4FFF7EFE7EEF3EC
FFF7FFF7F7F7F7EFF7F4ECF3E0F7FFE0F7F7E0EEF7E8EBED
ECEEF7F4FFFFFFFFFFF4F7F4F7FFFFFFF2F2F6F6F6F6F6FF
FFFFF6F6F2F6F2FFF6F6F7F7FFF7F7FFFFFFF7EFF7FFFFF6
F6F2FFFFFFF7FFFFFFF7FFF7F7F7F4FFF7F7F4EDF4F4F7F7
F7ECE5F7FFF4F7FFECF3FFF6F2F6FFF6F6F2F2F2FFF6FFF6
F6F6F6F6F6ECF7F7F4F7F7FFEEEEE5D1F7E5ECF7F4EFF7F7
F7F4F7F6F6FFF2F6F6F7F6E5F6EEF6F3F4F7FFF7E6EDD48A
7EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7F7
F7FFFFFFEDC848F7F7E6EBF4EDEEE5F4FFF7F4F7D4EBF7E6
F7F7F4F4FFF7F7F7F7F7F3F3E6F7E4EEF6E7E4F6F4E8F2E8
F7EEEEEDFFFFFFFFFFF7F7F7EEF6FFF6FFFFF2FFFFF6F6F6
F2F6FFF6F6F2F6FFFFFFFFFFF7FFF7FFFFF7EFFFF7F6F6F2
F2F2F6F6FFFFF4F7F7F7F4F7F7F7F7F7FFFFF7EDF7F7F7F7
F7ECEEFFFFECF6F7F4F7F6FFF2FFF6F6F6F2F2F2F6F2F6F6
FFF6FFFFFFF7FFEFF7F4F7F7E6F7E7E4EDEBF4F7F4FFFFF7
F7FFF4F7F4F7F6FFF6ECE4F7E6F6FFF6FFF7F4EFF7ECE08A
7EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFF
F7F7FFFFE8C154E4E4E6F2F7F4E5EEFFF7F7F7F4E0EEF7E4
EDF7F7F4F7F7F4FFF4FFF6F2F6F4E5E5F3ECE4F6F4EDEBE8
F7F7EBF4F7FFFFFFFFFFFFF7EEF6F6FFF6F2FFF2F2F6F6F6
F6F6FFFFFFF2F6FFFFFFF7F4FFFFF7FFF7EFEEEEFFECF7FF
FFF6F6F6FFF7FFF7F7F4F4FFF4F4F7FFFFFFF7F4F7FFF4F4
F7F4F7FFFFECF6F6F2F6F2F6F6F2F2F6FFF6F2F6FFF6FFF6
F6FFFFFFFFF7F7F7F4F7ECE0EEEDDDDCEFF2F7F7F7F7FFFF
FFFFF4EDF7F7F4ECE6EEF7F4F3FFFFF6F7F7FFF7F7E0D470
9CF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFF
F4F4FFFFEDBD61F4E4ECF7E5F7EDF7FFFFFFFFF7F7FFFFE6
EDF7FFF4F4FFF7F7F7F7F6ECEDEFF7DBEDECDCEBF3E5E5DC
EFF7EEEEF4FFFFFFFFFFFFFFF4FFF6F6FFF2F6F6F2F2F6F6
FFF2F6F6F6F2F6FFFFFFF7F7F7F7F7F4F7F7EEEEFFF4F3FF
F6FFF7F4EDF4F7EFEFF4F4F7FFFFFFFFFFF7F7F7F7FFF4F4
F7F4F7FFFFF4FFF6F6F6FFF6F2F2F6F6F2FFF2FFF2F2FFF6
F6FFFFF7F4EFF4E4DCE6EEEFE8DDECEDFFEBF7FFFFF4FFFF
F7F4FFF4FFF7FFFFFFF7F7FFF7E7E7F4FFE4E0EEF7BA6465
CCF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFF
F7F7FFFFEDD45ADDFFEDE6ECECEFF4F7F7FFF7EDF7ECEEEE
E4F4FFF4F7F3F6F7F7F7F7E4F4F4ECE5E8E4E4EEF3EBEDE0
EFEFF3F3EFF7FFFFFFFFFFFFF7F7FFFFF6F6F2F6F6F6FFF6
F6F6FFFFFFFFFFFFF7F4F4F7FFFFF7F4F7F7F7F7F7FFFFF2
FFF7F7FFF7F7FFF7F7FFFFF7F4F4F7FFFFF4F4F7F7FFF7F7
FFFFF7F7FFF7F3F2FFF2FFFFF6F6F2F2FFF6F2F6FFF6FFF6
F6FFF7F7FFF4FFECEBEEEFDDEEE0F4EDEEF6F7FFF7FFF4F7
F4F7EFF4EDE4E6ECF7F7F4F7F7E0DBECEEECE4E5FF9169D1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7FFFFF7F7
F7F7FFFFE8D44EF4F4F7E5F3E6FFF4ECECFFF4EDF7E0ECFF
E4E4FFF7F7E6F6F6F7F4F7F2F4F4ECDBD5F4F4EFECFFE4E0
F7EDE6F7F7F4FFFFFFFFFFFFFFF4FFFFF6F2FFFFF2F2FFF6
F2FFFFFFFFFFFFFFF4FFFFFFFFFFF7F4E5F6F7F6F6FFF6F6
FFF4FFFFFFFFFFF7F7FFFFF7EDEDF7FFFFF7FFF4F7FFF7F7
FFFFF7F7FFEEF7F6F2FFF6F6FFF6F6F6FFFFFFFFFFF6FFF7
F3F3FFF7F7EFECE4E6DDDDFFF7E5F7F7EBFFF7F7F7F7F4FF
FFEDEDEDF6F6EEECF6E6E0E6F2F3FFEBEBEEDDFFF76875EF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFF7F7FFF7F7
F7F7F7F7EFC65AE5EDF4F4F6ECF7F7E6E0F4EDF7F7EDFFF7
F7D4FFFFEDF6EBFFF2F6FFF6EEEDECE5CDF7E5DCE5F3EBDC
EEEDE0F7F7F4F7F7FFFFFFFFFFF7F7FFFFF6FFFFF6F6FFF2
F6FFFFFFFFFFF7F4F7FFFFFFF7F7F7F7ECECF4F6EEF7F2FF
FFF4F7F7FFF7F7F7F7FFFFF7EFF7FFFFFFFFF7F7F7F7F7F7
FFFFFFFFFFECEEEEF6FFFFF6F6F6FFFFFFFFFFF6F6F6FFF7
F3ECF4F4F4F4F6ECFFE0F7FFE4FFF4EEECF7FFF4FFFFFFF7
EFF4F7F4E5F2F3ECEEFFF7F7F7F7F4E6EBE0F7F7E06686FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FF
FFFFF7F7FFCD5AE5DCF7F4F6ECF7F4E5ECF7EDF7F4F7EDF7
F7D9EFFFEDF6F3F2FFF3EBF2FFE5D9DBCDEFE6E5DDEDF2E8
E6F4DBFFF4F7FFF7F7F7FFFFFFFFF7F4F4ECECEEF6F6F6FF
FFFFFFFFFFFFF4FFFFFFFFFFF7F7FFF4F4F7F7F7FFFFEBFF
F7FFFFF7FFF7F7FFFFFFFFF7F7FFFFFFF7F4F4F7F7F7FFFF
F7F7FFFFF7F7F7EEF2F2F6F6F6F6FFF6F2F6F6FFF6F6F6F6
F6ECF7F7F4F4FFE6E5EFF7E5EFF4EEF3F4F7FFF7F7FFF7F4
F7FFF4F7F7EDF3EEF4F3F6F7FFFFFFEBF6ECFFEFDC668BF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FF
F7F7FFFFFFCD67E0E4F7F7F2E6FFFFF4EEE5F7F7F7F7F4F7
F4ECE4F7F7E4FFFFF6F4F7ECF3F2DCEEECEEEEEEDBEDEEE0
ECEED4FFF7F7F4FFF7F7FFFFFFFFFFFFF7F4F7F4FFFFFFF7
F4F4F4F7FFFFF4FFFFFFFFFFFFFFF7F7F7F7F7FFF7F7EBF7
F7F4F4FFF7F7FFFFF7F7FFFFF7F7F7F7F4F7F4F4F7FFFFFF
F7F7FFF7EEF2F2F6FFF6F6F6F2F6F2F6FFF6FFFFF6F6F6F6
F3EEF7EDEDE5E0DCE4F2E0F7F7F7F6F3EDEDF4F4F7FFF7F4
F4F4FFF7F4F4E6F7ECFFECFFFFF7F4F6F6F4F7E4EC4EAAF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F7FFFF
F7F7F7F7FFCD7CC1E4F4FFF2EBF4F7F7E0E6FFFFF7F7F7ED
F7F7EBEDFFEFE4F7F7E5F7E4F6EBF4F4FFECE0EEDBE4F6D9
E7EED4FFF7FFEDEFFFFFFFFFFFFFFFFFF4F7FFFFF4F7F7F7
FFFFFFF7F4F4F7FFFFFFFFFFF7F7F7ECECEEEEF7FFF6F6F7
F7F7F7FFF7FFF4F7F7F7FFF7FFF7F7FFFFF7F7F4F7FFFFFF
FFFFF7EEFFF2F6F6F6F6F2FFF2F2F6F2F6F6FFFFFFFFFFF7
F7F7EFF7EEEEF7EDE5E6E4FFF7F7EEEEF4FFFFF7F4F7FFEE
ECF4F7F7F7F7F3F2FFF3F4FFF7FFF4F6EEF7EDE4EF1AD4FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF7FF
FFFFF7F7FFE567CEE0EDFFF6F6E8EDF7E4FFECF7F7F7F4F7
F7FFECD5EDF7F7E5FFF7EBF3DCECF7EFECE4F7F4DDCBEFEC
DDDDDCEEF4F7F4F3E5FFFFFFFFFFFFFFF7F7F7F7FFF7F7FF
FFFFFFFFFFFFF7F7FFFFFFFFF7EEDBF7F3F6F6FFF6F6FFF7
EFF7FFF7F4F7F7F7F7F7FFF4F4F7F7F4F4F7FFF4F4F4F7FF
FFFFF7ECF3F7EEF6F6F2F2FFF6FFFFF6F6FFFFF6F3F4F4F7
F7E5F3FFE6F7E4D4D1E4FFF4F7F6ECF7F7FFFFF7F4FFF7EE
ECF4F4F4F7EEEEFFF2F6F3F7F7F7ECF6EDEDDDEEA03BF7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FF
F7F7FFF7F7FF4FD9E4E5F4F4F3DBE1F7EFE0DBF7ECE4ECEC
F7F7EDE7E7FFF7F7E5F7F2E7FFEDFFF7DCECF7FFF4ECD3E4
EED9E4E4EEF7F7E4EEF7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7FFFFFFFFF7F7FFFFFFF7F7E4EBF3F7FFFFF6F6FFF7EF
FFFFF7F4F7F7F7F4FFF7F7EFEFFFFFF7F7F7F7EDFFEFF4F7
F4F4F7F7F7F4F4FFFFFFF6FFF6FFFFF6F6FFFFF3EEFFFFF7
F7ECF6EEE5E5F7EBE4F7E5EEEEECEFF7F7F4F7FFF7F7F7F7
FFFFFFFFF7E4ECF7EBF3F6F4F7F3E5F4E5EEF3D45CA6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FF
F7F7FFF7F7FF4FE7E4E4F4F4F3DBE8F7F7DCECF7DBDBE6E6
FFF7FFF7C8EDF7F7F7E4F6F4F4EDF3F6EDF4F7F7FFEDE6E0
FFD5EBE6E4E4E4EDFFFFF7F7F7FFF7F7FFFFFFFFFFFFFFFF
F7F7FFFFFFF7F4F7F7F7F7FFEEEEEDFFFFFFFFF2F7F7F4F4
F7FFF7F7F7EDF4F4F7FFF7EFF7F4F4FFFFFFF7FFF4F7EDF7
FFF6EEEEF2EEF7FFFFFFF6F6F6F2F6F2F6F3F4EFF4F4F4F7
F7E5E6E5E5F7F7E6E4F4E6EEEEFFF4FFF4FFF7F4FFF7F7F7
FFFFFFFFFFFFF4F7F6E5F7F6F3EEECEFE5F6F79865E5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFF7F7FF
FFFFFFFFFFFF48EDF4E0E8F7F7E8F7EDFFE8FFF4E0ECDCF7
ECF4F7EFCFF7F7F7F4F4ECE5EFF7ECFFE6E4F4FFEFE5E4DC
F7E1E4F4F4F4F6ECF7EFEFF7F4F7FFF7FFFFFFFFFFFFFFFF
FFFFFFFFFFF7ECE5E5E4F7F7ECE7EDF6F2F2F2F6F4F7F7F4
F7F7F7EDE8F7F7E8E8E8E8F7F4FFF7FFFFFFF4F7F4FFF7FF
FFF6EEEEF6F2FFFFF6F6FFF6F6FFF6F6F6ECFFF4FFFFFFF7
E5EEFFEDF3F7E5F4EFF7EEEEF7F4F7F7EEF6FFFFF7FFFFF7
F7F4F7FFFFFFF7F4F7E6F7ECEEECECE8F2F6D9798FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFF7F7FFFFFFFF
FFFFFFFFFFFF5FCAF7DDD4FFFFF4F7EDF4EDFFF4EDF7E1E6
EBEFEFF6F7E5FFF4F4ECECEBF4EFE6EEEBE7EFF7EDF7E0E8
EEE4D3E5EDE6F4E4F7F4F7F7F7F7F7F4F7FFFFFFFFF7F7FF
FFFFFFFFF7F7E4E5E5ECEDF7EDF4F4F2FFFFFFFFEDF4F7ED
EDEFF4F4FFF4F7F4F4F7FFEFEDEFF4F7FFFFF4FFFFF7EEF6
FFFFF7F7F2F2FFFFF6F6F6FFF2F6F6F6F7F7F7EFF4F7F7EE
F7EEFFEDECEEF4FFF4EEE6EEF4FFFFF4F6F6FFF7F7F7F7F4
F7F4F7F7F4F4ECE6E0E4F7FFF7E4E6E5F7F4C573B5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFF
FFFFFFFFFFFF85AEF7EDE0E6F7F7EDF7F7F7F7F7F7F4EDDC
EEEDF4E6E6E4EDEFEDEBF6EEF7EFEFF7F3F2E4F4F7F7EED4
E5ECE0E6FFEFEFEEE5F7F7EFF7FFFFF7F7FFF7F4F4FFF7F7
E4E4F4F4FFFFFFF7E4EEF7F7F4EDEEF6FFFFFFF7EDF7F7E8
EFEFF4F4FFEDF4F4F7F4EFEFF7F7F7F7FFFFF4FFFFFFF6FF
F2F6FFFFF2F2FFFFFFFFF2F6EBF7FFEEF7FFF7EFEDEDEEEE
EBE0E4E0F4ECF7F7E5EEFFFFF7F7FFF4FFF6F2EEF7FFFFF7
F7FFEEF3F6F2EEF4F7FFFFFFF7E0E0F7F6E0BA69CAF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9D98F7EDD9EDF7F7E8F7F7F7EFF4F7F4F3DD
ECECF7D9ECF7E5EFF4EEEBEEF4F7F7F4E5EEE0F4FFF7ECF3
DDD4DCE0FFF7EDFFECF6F7EDEDF4F4EDFFF7FFF7F7F7F7FF
E4ECEEECFFEFEDEDECF6F4F4F7FFF2FFFFFFF7EFFFFFF4ED
FFEFF4F4FFEFE5ECF7F7FFEFF6F6EDF7F7F7F4F6F6FFFFF2
FFF6F2F6F2F2FFF6F6F6F6FFF7F6F3F4FFFFFFF4F7F7F6EC
ECDDEBF6EFE5FFF4E6FFFFFFF7F7F7F7F6F6FFF6F2F2F6FF
F7F4E4EEEEF4F7FFFFFFFFFFEEDCE7ECECEC9770EDF7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFF7
F7FFFFFFFFFFBD79ECE1D9EDF7F7EDFFF4EFFFF4F7E6ECEE
E0F3EFE7ECE0E7F7EDF4EDF6F3FFEFF4EECCEEDBECF4EEE5
E7ECD5C8CCDDEDEDEFE1D9EBF2F6F7F7EDFFFFF7F7F4F7F7
F7F4EEECF7F7F4F7F7FFF7F7F7F6FFF6FFF7EFF7F4E4E6EB
F6EFEDEEF6FFF2E4EFEFEFF6FFFFE5EDEEEEF7F2F2FFF6F6
FFFFFFF6F6F6F2F6F6F6FFF7F7F4F7EFF4EDE0E0E0E0E0E4
F7E4ECE7DDF4F4F7E6F7F4F4F7F7F7FFF2F7F7FFF6F2F6FF
FFFFEBFFF7FFFFFFFFFFFFF7EBE8F7F6FFD4698FF7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFF7
F7FFFFFFFFFFE579B8EFEBF4F4EDF4F4FFF4F4EDF4EDF7F7
EDF7F4F4E0F7F4F7F7EDF4F3F3FFFFF4ECE6D4F6EBEFF4FF
EEE5EDEFE4DDE0E5EDFFEFF7F4ECE4F3F7EDF4FFF7F7FFFF
F7F7FFFFFFFFF7F4F7F4ECEBF3F2F2F2FFEDE5ECF7F6F6F6
F6F7F7F6F6FFF2F2F6F6FFF6F6F6FFF6F6F6F6FFF6F6F6F6
F6FFFFFFFFF7F7F7F4F4F4F7F7F7F7F7FFF4F2F7F7FFF7F7
FFDBF7F7F4FFEEE6E5F7F7F7FFF7F7F6FFEEEEF2FFF2F2F2
F2F6EBF7FFFFFFFFFFFFF7EEE5EFF7EBEB9E53D4F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFFF91A9E8E6FFFFEDF7F4FFF7EDF4FFF4F4F4
F7E7EEFFE4EFFFF7F4F4EEF7F6F7FFEDFFF7ECD4F7E5F7F4
F7ECE5EFE5E0D9D1DDEDEDE8E8EDEFECEBF6F7F4F7F7F7F7
F4F4F4F7FFF7F7FFFFF7EBFFF2F2F6EEF4EDE6F6F3F7F2F2
FFF3F3F6F6FFF6FFF6F6F2F2F3F7F6FFF2F6F6F6F6F6FFF6
F6FFFFEFEDFFFFF7FFFFFFFFFFF7F7FFF7EEFFECFFFFF7F7
F7ECE4FFF4F6ECFFF4FFF7EFF7FFF4F6F6F6FFF2F6F7F7FF
F7EBE6FFFFFFFFFFFFFFECEEEDF7EDF6FF6571F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFF
FFFFFFFFFFFFF7A793DCE5EEFFF4FFF4FFFFEDFFF7F7EDF4
F7E7F6F4E6EDF7F7FFF7DDF7F7EEF4F7F7F7ECEFCBFFE0DD
F4F7ECD9D9E0E6EED3D4D4E0E6E4E4E8E6ECE6E6EEFFF7F7
F6F2F6F4EEF3F6F3F7F6EEF7F2F2FFF7F4EDEEEBF7EBF6F6
F2FFF6F2F6F2F2F6FFFFF6F6EEEBF2F6FFF2F6F2F6FFFFFF
FFFFFFEDFFEFEFF7F7F4F7F7F4F7F7F4F7EBECEEFFF7E5E0
E0E0E5F7F7EBF7F7F7F7F7F7FFF4EEF2EBEBF6FFFFF7FFF7
F7F6EEFFFFFFFFFFFFF7EBEDF7F4EFE6BA33C2F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7C898C0EDEEECEFF7F7F7FFF7EDEDF7EDFF
EFEDECEEEBEDF7FFF4EFF7D4DCF7E5F4EFF7F7E5EDC1D9F4
ECEFEEEEEFEBEFE5DCDBE0E0E4EFECEEEDF4EDE8DCDBE0E6
ECF7F6E6ECF6F6EEEBEEF7F7EEF6FFF7F4E5ECDCE0E8EDF4
F7ECE4EEEDE8EFFFFFF6FFF6FFFFFFFFF6FFF6FFFFFFFFFF
EFE8E8F7EFF7F4F4F7F4F7F4FFFFF7F7FFEBF7FFEFDCE4F7
FFF4F7EEEBEEF7F7FFF7FFF4EEF2F6FFF3F6F7FFF6F2EEF7
F7F7FFFFFFFFFFFFFFECEEE5F4EFEDF4565EF7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE5A3A2EDF7E0EFFFF7F4FFF7F4F4F7F7ED
F7F4E7F6F6ECF7F7F4FFF4D1EEDCE7FFF7EDF7F7E5FFD5E4
F7EEDDFFE0EEFFF7EDEDEDF7E5E5F7ECDCF7E5EEF7F7F7ED
EFF4E8EDEFF4F4F4F4EFF4F4F7F7EDEDEDE5EEE5F4ECE4E8
E1EDEDEFF7F7F7EFFFECE0EFFFEFEDEDE0ECEFEFFFFFFFEF
FFEDF4F4F7FFF4EDF4F7F7F7F7F4F4EEF6E4EDE4E4ECFFEE
E7F4F4F2F4FFF4F7F7F7E5EEF6F6FFFFF6F3F7FFF6F6F6F6
F4FFFFFFFFFFFFFFF7E4E6FFEFF4F4D427AEF4FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFB58AEDF4E6F4F4F7EDFFF7F4F7FFFFED
F7E8F7F7FFEEEEF4F7F4FFF7D5E5E7D9EDF4EDFFF7DDE5F7
E4E7FFDDDBE0EEFFF6E7EDF4F7E0F7FFE0E4EEEEECF6ECEE
E5E4E6ECEFEDE0E4F7F4F7E5F4F7F4EEE4ECDDE4F6F2F3EE
FFF7EDEDF7F7FFF4F4EDFFEDF4F4FFF7F7F4F4EDF7EDEDF7
F7F7F7F4F4F4F7F7F7F7F7FFF4FFF6EEECE4EEEEFFF4FFEC
E4FFF7EBF7F7F7F7FFE5FFEEFFF6F6FFFFFFF7F4F7F6F2EE
F7FFFFFFFFFFFFF7E5E5F4EDF7FFF7A638E8F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCD88CEF7EEE5EDF7F4F7F7F7EDF7FFF7
EDE8FFF4EEEEE6F7F7FFF7FFF7D4C9ECE7E0F4EFF4F4FFFF
FFF7EDF4FFF7E5EEF3ECEFF7FFE5E4F7E5EDF4F4DDE4E7E0
E4EBF7F6EBEBF6EBEFE5F3EDF7FFE4E5F7EFECF3EEEEEFE5
E6EBF2F6F3ECEFF4F4EFF7F7F4F4FFF7F4FFF7EFF7F7F7F4
EDF7F4FFFFF7F7F7F7F7F7F7EEF2FFEBECEFEBFFF7EFF7F4
FFE4E6EEFFF7F4F7F7E5EEFFFFFFF2FFFFFFF4FFF7F7FFF4
FFFFFFFFFFFFFFECECF4F7FFF7F4D97470F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE59597D9EFE6EDFFF7F7EFF7EDF7F7F4
E6FFEDEFE0ECF3F4EFF7FFEDE7E0F7DDCFCFFFE5EFF7F7ED
EDF4F7F7EDE0E0EEF7F4E7E0E8EFD9EFE1CDDBE4EDEDEFEC
CCC1D1DCCECEDCD9D9F4FFE6D4D4CCD1CFD9E0D3DCF4F7F7
FFF7EDE4ECECE5F4F4FFF7F7F7FFF7F7F7F4F7F7EDE8E0E7
F4EDEDF4F4F7F7ECECE5E5EEEEF4E7DBEEEDF6F3EFEFEDED
E4E5F7F7F7F7FFF4FFF4F6F2F6F6F6FFF7F4F7FFFFF7F4F7
FFFFFFFFFFFFEEDDEDFFFFFFF4DD8751BAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCC80E0EDE4EFEFFFF7F4FFF4F7FFF7
F4E0ECF7DCE5F4F7F4F4F7F4EBFFF3F3F3ECE8F3EEF4EDE5
EDF7F3ECF7E5F2F6F6F6F6F6FFE8EEE6E5F7FFEEE6E5E5EC
F7FFEEEEE6EEE6E5EFE4FFECF7EDE5EEEEF7F7EEEEE4D9E0
E0E0E7EDEFFFEEE6E6E5F4EEEEF4F4F4F7F7F4F4F7FFF6FF
EBEBF2F2EBEBF6F2F6F3F6F7ECFFF4F7E7DCE6EEEDF7EEEE
E6F7FFFFF7F4EDF7F7F7F6F6F6F6FFFFF4FFFFFFFFFFFFFF
FFFFFFFFFFFFD9EFF7FFFFF7F7AB6F9DF7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF780B8EFDBF7F4F7F7F4FFF4F7EFED
F7D9F3F4EDE6F7EFFFEFF7F7E4F3FFF7F7F4EFF6ECF4F4F7
FFF7ECF3ECECF6F6F3F3FFF7EDEFF7F7F4F7F7FFFFEEEEF7
F7FFFFEEEEFFF7E0ECD4D9F3EDE5E0E6F6EFF7F7F4ECEEEB
EBF2F2EEDCE5FFF7F4E5EBEEEEF2F6FFF7F7FFFFFFFFF6F6
F4F7F4F4F7F7ECECF4F4F7EEEEF7EFEEEEF7EFE8EFFFEEEE
E6F7F7F4FFF7F7FFF4FFF6F6FFF6F2F3F7FFFFFFFFFFFFFF
FFFFFFFFFFF7D4F7F7F7F7FFED786CDDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAE9FE5CDF7F4FFFFF7F7F7F4EDEF
EFE5ECE4EDEBEFFFEFF6EEF4EFEBF7E8EDEDF7FFECEEFFFF
F7F7EEEBEEECF3F6EBF3FFF4F4EFEDEFF7F7F7E8E8E8E8ED
EDE8E0E4F4F4E5D3EEEEE0CDDBE0FFF7EFF7F4F4FFFFEEFF
FFF7FFF7F6D9EDF4FFF4F7EFEFF4ECE6EBF6F6F6EEEEEBF4
F7FFFFFFF7F7FFFFF7EDEDF4F4EFE5F7ECF7F4F7FFEEE6E6
EEFFF7F7F7F4F7FFECF6F2FFF7EEF2F3F7FFFFFFFFFFFFFF
FFFFFFFFF7E5ECF7F7F7FFF7ED3FA0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCDA3CBCDEBE5F7FFFFF7F7EDF7ED
F4F7E4EEE8F6ECF7FFE5FFF3FFEBEDEFF4F7F4FFEBEEE6E6
E5F7E6FFF7F4F7ECE4EEF7F4F4D9ECEFF4EDEFFFFFE5E5FF
E5E0F7F3F4ECF7ECE8EDEDEDE4ECEFEDEDE8EDF7E5E5E6E6
E6ECE0E5ECE5E6E6E4EDEFF4F4EFF7F7F7ECECECEEECE4F4
F7F7F4F4F7F7F4F4F7F7F6E6EEECECEEE5F7FFF4FFE6FFFF
FFF7EFF4F7F7F7F7EBF6F6FFF4F7F7F7F7FFFFFFFFFFFFFF
FFFFFFF7EEE4F7EFF7F7F7F7C227D4FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE5B2A0BEECEEF4FFFFFFF4F4F4F4
F7F7F4F7E5F7EBF4F7E4F7F6F6F3EDFFF4F6F6F3F7EBEBF2
F7ECF3E4F6EFE8F7F4FFF7EDFFE0E4F4EFEEE0DBE0E4E4E7
CDE4EEEEE0EFF7EEEEE5F7F7F4EDF7F7EEEEFFFFE0ECEEEE
EEF4FFEDEDFFF7F7EEEEECE0F6F4F7F4EDF4F4EDE8E4ECEC
E5EFECECECE6ECF4F4ECEEF7E4E4F6ECF7F7E4E0E6EEFFFF
F7EDF7F7FFF7F4F7F6F3F7F6EEF4FFFFF7FFFFFFFFFFFFFF
FFFFFFF4EBEDF7F7E6F7EDF4934CF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFDBAAAED4FFF7F7FFFFF4F7EFFF
EFF7F7EDE8F4F2EDF4ECF3F6F6FFEFEDEDF2F3ECEEEEF7F7
EEEEEDEFE4D9CFD4E4F7FFE8DCE0E5E5EEEEE4FFF7F7F4D9
D4EEDBF7E0E5E0E0E0E5EEEEEEFFF7F7EEF7EBE6E5F4F4F4
F4FFF7F7F7EDF4F7FFEEECF4E4DBDBE6EBECE4E0E6ECECF7
F7E4F7F7E4E8E0E0E6F7F3F7EEECE5E4F7F7EEEEFFFFFFF7
EFE5F7F7F7F6F6FFF7E4F7F6EEF7F4F7F7FFFFFFFFFFFFFF
FFFFF7E5E5FFF7EDFFE6F7F7647CFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE4BA95BBDCF7F4FFFFF7F7F7EF
FFF4F4F7FFE6ECE4ECF4EDE4E8E8EDE6E5F6F7ECE4ECECE4
F3F7EDFFF4F7ECE6EEFFF7ECEFE6EEE0E5E6E4FFF7F7F4EE
DDF4FFE5E0E6DCD9E6FFE4E4E0FFE5D4D4E0F7F4F7FFE5E4
F4EDEDF7F4F3ECEDE8E8E8E8EDF4EDE5E1D9E4EDEDF4F4E4
E0E5D9D9EDF7F7E7E0D9D9EDE0DCEDE4EBEBE6E5F4EDEDF7
F7F4FFF4EEF6F6F6F7F3F2F6F7F7F7F7FFFFFFFFFFFFFFFF
F7ECE4EEF7F7F4FFE5EFEC7431BAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7DC91D9D1ECF7F4F7F7EDFFF7
EDEDF7F4E8EFEFF7EEE4ECDBF7ECE5EDF2FFFFF6EBECEEE6
FFF2E5EDFFEDE4E6EEF7F7DBECE5EEE4F4F7EFF7F4F7EFF4
EDF7F4F7F4FFEDEEE7EEE4F4DCE0EEEFEEE0DDEFFFF7E6F6
EBF2EBE4F3EBECE6EEEEEEF7FFF7F4ECECF7F4F7F7F4F4F4
F4F7FFF6F6F4E4F7F6EEE6E4F3FFFFEBF4F7F7F7FFF7F7F7
F7FFF4F6F6FFFFF2F6F6F6F6FFF7F4F7FFFFFFFFFFFFFFF7
EEEEF7FFF7F7F4EFF7F7AF4CB9F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE09DD1D9D9FFF7F7F7F7EFFF
EDF6E5FFF7EDF4F7F7F7F6ECE6E0DDEBFFF6F7EDEFF6EBF3
F3E6E4E5F7F4FFF4E4CFE4D9FFECE5FFFFFFEDF7FFF7F7F7
ECF6F6ECF7F7EDF7ECCBEEEDF4FFFFF7E5E6F3F4F4F7F6EC
F7F7F7F7F6ECFFFFEEEEEEE0E0E5F7E6E6FFFFFFFFF6F6EE
EEFFF6EEECE0F7FFE6EEF7FFECEEEEFFEEFFF4EFFFFFFFF7
FFF7F7EBFFFFFFF2F2F6F6F7F7F4FFFFFFFFFFFFFFFFFFEC
EEF7FFF7FFEFEDDDD4B86B80F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE4B6B6DCD1EEF7F7F7EDEDF7
F4ECF3EDF4F4FFF7F4EFF4F7EFCCE7FFF6FFEBE4F7EDEFEB
F7F7FFEDEFFFF7F7E5C8C9E4E4ECF7F7FFF7E0F3F7F4FFF4
ECEEE6E0FFF4EFF7E0EFDDF4FFF7FFF4ECEBF6F6EBEBEBF6
F4F7EDF4F4F7FFFFFFF7F7FFFFEEECE0EEE6EEFFEEECECEE
EEE6F3F4FFFFEEEEFFFFF7F7FFEEEEEEEEF7EDE6F7FFF7F7
F7FFF7ECF3F4F4EEFFF3F7F7F7F7F7FFFFFFFFFFFFFFFFE0
F7FFF7F7F4F7E5D4F4886CCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7C2BDCBC4D1FFF4F4EDFFEF
FFEFF7EDFFFFF4F7EEE4EDEDEFEFDDEEEFE5F3EEEEEDEFEE
E6D4D4E6ECF7EEE5ECDCCDF7E4ECF7FFF4FFDBE6FFF7F4F7
F4F7ECECF7F4FFE4F6E0DCEEF7F7EFEDF6F6F6F6F4F7FFFF
F4F4FFF7F7F7FFFFFFF4F7F7F7F4DDEEF4F7EEEBF3F7FFFF
FFF7EFF7FFFFF7F7FFFFF7F7FFFFF7F7FFF4FFF4F4FFF7FF
F4EEECF4EBF7FFF4F6F3FFF4F4F7F4FFFFFFFFFFFFF7ECE4
FFF7F7EFEDF4F4D9CB4CB9F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCDC6D4E1C6EEF7F7F4F7F7
F7FFEFF7EDEDFFF7E5F7EEF4E1D9FFD9C9E7EEF3F6F2F2EB
E6D9D9E6ECF7EEEEE5FFD4F7F4F7F7F7EFEDECF3F4F4F7FF
F4FFFFEEE0F7EDD9E0E4F6D9F7F4F7EEEBECF4F4EFF7F4F4
F7F4F7F7F7F7F7F7F4FFF7F4F4FFF7EFF4FFF7F7F4F7FFFF
F7FFF7F7F7FFF7F7FFF7F7F4F7F4F7F4EDF7F7F7F7F4F4F7
FFF6F7F3EBF7FFF4FFF7FFF7F7FFF7FFFFFFFFFFF7F7EBF7
F7EFF4EDEFF7CB957D80F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFDBCEC1D4B8D9FFF7F7F7F7
FFEDEFF4E5F4F7F7EFE5F7F2F6EECFCAFFDCE4EEF7FFF7EF
EDE0DBE4F7FFFFF7D9E0E8F4F4F4FFF7F7F7F4F4F4F7F7F4
EDFFF7E0CFE8F7ECF7EEE0E5E4F7EEECF7FFFFF7FFFFEDED
F7FFFFFFFFFFF7FFF7F7F7F7FFF7FFF7F7F4F7F4F4F4F4F7
F4F7F7F4F7F7F7F4F7F7F7F7F7FFF7FFF7FFF7F7FFFFEEEB
F6FFF6F6EBF7FFF4FFF3F6F7F7FFF4F7FFFFFFF7F7EEEEF7
EFF7E6FFEDED8A9798CCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE5CCC4D4CCD5DDF4FFF7F7
FFEDEDEDF4F7F7EDF7EDD9D9EFEFFFE7CFC3EEDCDCEFF4F4
DBC8C1D4F7F4F4F7DBC8E0ECF7EFF4F4F7FFF7F4F7F4F7ED
D9EEF4E4EDF6E7EEE6E5EEF7E6E5ECFFEFEFFFF4F7F7FFFF
FFFFFFFFFFFFFFF7F7FFFFFFF4F4FFFFF7FFF7F7F7F7F7F7
EFF4F7F7F7F4EDF4FFF7EDF7FFFFF7F7F7F7FFF7F7F6F3FF
ECEBEBEBF6F4FFF7F4ECF6F7FFF7F4F7FFF7F4E5E6F6F7F7
E0E7EDEDF7A03082CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE4D1BABAECD9E5F4F7F7
F4EFF4EDD9E4E8EDF7EFF6C1E0E5EFFFEFEDE4D4F6E5E1E5
F2EFE8E5E4E5FFFFE5BDE7ECF7F7FFFFF3EEECF3F7F7F7F4
CFECE0E5E0CDD9FFEEFFF4EDE5ECFFF7EFF7F4F7FFFFFFFF
F7F7FFF7F4F7FFFFFFFFFFFFF7F7F7F7FFF7F7F4F7FFF7FF
F4EFF7F4F7F4FFEFF4F7EDF7F7FFF7F4F7F7F7FFF4F6EBE4
ECFFFFF7FFF4FFF7F7FFF7FFF7FFFFFFF7EEEBEEFFF7E6ED
F6E5F7FFC14E9DE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D1DCAAB0CCD1EDFFEF
F7F4FFEDE0F3F7F7F4EFE5ECE5E4EBF2F6FFFFE5D4D5D5E5
ECC8BDCDD4E4FFF7F4C8E4E5F7FFF7F7F2EEEEEEEEFFF7EF
CDEFF4DBDBD4F7DBF4F4FFF4F7EFF7F7FFF4FFFFFFFFFFFF
F7FFF4FFF7F7F4F7FFF7F7FFFFFFF4F4FFFFFFF4EDF7F7F7
F4FFF7ECEEF4FFFFF4FFF7F7F7F7F4F6F2F6F4FFF4FFF4F4
F6EEFFF7FFF4FFF7F7FFFFF7FFF4F7F7EEEEFFF4F7EFFFF4
EDF7F4B2975CD9EDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5D9EEBBBAB0F7F7F7
F4F7F4FFFFEFFFF7F7F4F7EFF7EDE5EDEEF2F6FFFFF6FFEE
F4EDEDF4EDF4F7F7F7CFEFF3F2F3F7F7EEF3F4F3F3F4F7F7
DBF7F7E5FFFFE4D4F4F7F7F4F7FFEDF4F4FFF7FFFFF7F7FF
FFF4FFF7F7FFFFF7F7F7FFF4F7FFF4F7F7FFFFF7FFF7F4F4
ECF3F7F2EBFFF7FFF4FFFFF4FFF4F4F6F6F6ECFFF4FFF7F7
FFF2F7FFF7F7F4F7FFFFFFFFF4FFF3EBEEFFF7F7E6FFE6EF
F7FFDC8975A0F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4E0DCB98FE4F4F7
F7F7F7EFF7F7E7EEF4F7F7EDE6DCE8F7F7EDE4EEEFEFF2F4
EEE6ECF7E8F7EDEDEFD9EDF7F7EBF7FFF4E6FFEEEEF6F6FF
EEEEF7F7EEE5D9D9F7F4FFFFF7EDF4F7F4F7F7F7FFF7F6EC
F4F7F7F7FFFFF6F2EEF7F7F4F7FFF7F3EEF7FFFFF4F7EFF7
ECF7F6EEF6F4F7F7F7F7FFF4FFF7EEF2F6FFEEECF7F6F2F2
F2F6F7F7F7F4F4F7FFFFFFFFF4FFF2F7FFF7F7E6F7EDF4ED
E5E09852AAEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E0E8DC83E5DCFF
F4EDF7EFF7F7DDECF7F7F7EFEDEDF6ECF7F4F7E0C6DBFFEE
EBFFECDDE5F4F3EEF7E0F4F7F7EEEEF7F4E6FFFFE0E6EEF3
F7E6FFFFEEE4E4E4F7FFF7FFFFF4F7FFF7EDF7F4FFF7F3FF
F6FFF7F7F6F6F2FFF6ECFFFFFFFFF7F3FFEEF7FFF7F7F7F4
EFE6E4F7F6EBEEF4F6ECFFF4FFFFF2FFF6F2F6F6EBF3FFFF
F7F7F4FFF7F4F7FFFFFFFFF7F7F6F6F7F7EFDCF3EDDCE7F4
E4C45997EFEFE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5D1F48FD4D1EF
F7EDF4F7F7EDF7E6F4F7EFEDF7EDDCE7FFEDE0DCF7E5D9E0
E0E0DDE4E1F4F3F6F6E4F4F7FFF4F6EEF7E6FFFFE0ECF6E4
F7E0F7FFECE0F7EEE5F4F4FFFFF7E4EEF7F3E5F7FFF7F7F6
FFF6FFFFF6F6F2FFF7E5ECF4F4F7F7F7F2F6EBE6ECF7FFEF
F7D9F3F3EEF6EBFFEEF3F4F7F6F2F6FFF6F2F6FFF7F7F7F7
F7F7F4FFF4F7F7FFFFF7ECEBF2F6FFF6F3EDECECF7E4D9E1
C3757BFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4D498E0D9E5
EFFFF7FFFFEFEFF3E5FFEDFFE6F7F7EDF4F6FFF3E5E1F7F4
F7EDEBF2DCF7F7F6F6E8F7F7F7EFF4EBFFE6FFFFECEBEEEC
E0E4F4EFF4EFF7D9E0F7F7FFFFF7F3FFF6F6F3F7FFFFF7F7
F2F6F6F6F6F6F6FFF7F7F2FFF7FFF7F7EBFFFFFFF6F6FFFF
EDECEEEBFFEBF6EEF7FFF6F6F2FFFFFFF7F7FFFFF7F4F7F7
F4F4F7FFF7F7FFFFF7EEF6FFFFF6F2EFE4F7F4F7EFF7F4AE
8F73D5E8F7EDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DC7DCBDCD5
E4E6FFF4F4F7EDD9F3EDFFEDEDF4EDF4EDE0ECFFF7F7E8FF
F7E5D5C6D1E5F7E5F6E8F4F7EFEFF4E4E5EBF7FFF4F4FFF4
F4ECDCFFF4EFE6EDF7F4F4F4F4EEF3ECF3F6F6F7F7F7F7F4
F6F6F6F6F6F6FFFFFFF6FFF2EEF7F7F4F6EBF3F7FFF6F2F2
EEF4F3FFEBFFE6F7F2F6F2F6FFF3F7F7F7F7F7F7F7FFFFFF
FFFFFFFFF7ECE6E6EBF6F6F2F6F3E0EEF7EDFFF4E0BEAE6D
6DCBE8FFEDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA6A1D4DC
E4DDE6F7EFF7EFF7EDF7EDEDF4F7F7FFFFF7F4E1EDF7EFE8
EDF7FFE6FFECE4E4F6E8F4F4F7FFF7F7DCECF7F7F7F4F7F7
F4ECF3E1F7E5F4F4EFF4F7EDF4E6E4F7F4F2F2FFF4F7F7F4
F6F6FFFFFFFFF6F2F6F2F2FFF6F2F3F4F7F4EBF7FFFFFFF6
F6FFFFF6F6EEEEEEEBFFFFF3EEF3FFF7FFFFF7F7FFFFFFFF
FFFFF7ECEBF6F7F4F7F6F6F6EEF7F4F7FFF7F4DDDDD4E569
D1EFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5A8B0DC
EFE4E4EFEDFFF7F7F4E5F7E5EFF7F7F7FFF7F4E8F4F7E8ED
E5E4E0E4F7ECECECF6E8F7F7F7F7F4F7EDFFFFF4FFF7F7FF
F7EDE7D1F7EDECD4EEF7F7FFF7E4EEF4F4F2F6F2EBEEF7EE
FFF6FFFFFFF6FFF2FFF6F2FFF6F2F3F7F7F7F6F3F7F7F7F2
FFF6F6FFF6F6EBF4EFEEFFF3FFF4F7FFFFFFFFFFFFFFFFFF
F7ECE4ECF4F4F7EEEBFFEBF3F4F7F7F7F7EFDCDCDDE4F454
F6ECEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD49DC1
EEE5E5E5F7EFFFF4E6FFE5EDF4F7E0E0F4F4F4F7F7E5DCED
EEE0D9E5F4E0EFE7F6EDF7FFF7F7F4FFF7F4F7F7F7FFFFFF
FFFFD4D4ECECE4CCF6EEF7ECEEFFF3EEF7F6F6F6F6EEF3F6
F6F2FFFFFFF6F6FFF2F6FFF6F6F6FFF4F4E8EFEEF6FFF7F3
EEF6F6FFF7ECF7E4E7FFEBF7F7FFFFFFFFFFFFFFFFF7F4EC
EBEEF7FFF7F4F4F3F2F6F4F4EDEDF7FFE4DCEEEDDCEDBB78
ECE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7B8A0
D4DBFFE5D9EDF7F7EDF4EDF7F7EDDDFFECF7FFFFF4E8E8F7
F4F7E4ECF7DBF7E7F3EFF7FFFFF4F4F7F4F7F4FFF4FFF7F7
FFFFE5EEE0EBEFE7F2FFEEF3FFEBF7FFF6FFF6FFFFF3EBFF
FFF6F6F7F4F7FFF6FFFFF6F2FFF2FFF4F4EEDDE8DDF3FFF7
F3F6FFFFF7F4F6EBFFEBFFE0E0E6ECF4F7F7ECECECEBEBEC
F4F7F7F4EEF3F7FFF7EDEDF7F7F4FFE5E5F7F7D4EEE49AAE
EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5AA
A1B2E0EDD9F7EFF7F7EDF7E5F4EFF7D9E1FFF7FFF7F7FFF7
EDE4F4ECF4D4F7EFE0F4F7F7F7F7F4F4FFF4F7F4F7FFF4F4
F7F7F7EFE0F6EEFFF7F6FFF3EEF6F6FFF6FFF6F6F2EBF3F6
FFFFF2F7F4F7FFF6F6F6F6F6F6F2FFF7EDECECE5D5E5F6FF
FFF6F6FFFFFFF7FFECE6F6F7F7F4ECE6E0E6EEECECF7F7F7
FFF7F7FFF2E6F4F7EFF7F7EDF4EFE4EEF7F4DDDCF7B6A3CD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5
B298CBD9EEDDF4F4F7F7EFF7F7F7EDE8FFE1ECE6E6E5EDE8
E1DCF3E0F4CDFFF7E0EDF7F7F7F7F7FFF4FFF7FFFFFFF7FF
F7F7F7F7F3F6F2F4F4FFF2EBF7F6F2FFF2F6F6F6F6FFF3EE
F6FFF6F3F4F7FFFFFFF6F6FFF2F6F6F7F7E1E0F7E5BADCEB
F6F6F6FFF6F2F6F7F4F7F7F7FFFFFFFFFFF7F7FFF7F7E8ED
F7F4F6F2F7DDE5EDFFEDEDF7DCDCF3FFEFDDE4F7E49AB0E5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EFA98DA1D9DCDCF4F7FFF7F4F4E8EFFFEDDCE5EBEBF3EEF3
F7EFE5DDE6D9F4FFECE4F7F7F7F7F7F7F4F7F3EEFFFFF7F7
FFFFFFFFF7EBF6EEFFF7F2F2FFF6F2FFF6F2F6F6FFF6F3FF
EEF6F7E5ECFFF4F7FFF6F2F6F3EBF6F7F7DCD5E6DDC5ECBD
AAC9F7EFE4E6F3FFF6EEF4ECECF4F4F4F7FFFFFFF7F7E8E8
EDFFD9C1CCF3EFF4F7DBCFE1F6E5FFDCE1E4EFB26788D5FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7C287B0F7E5E5F4EDF4F7EDEDF4F7F7EDECEBF3F7E7DC
E1DCE1DDE6D9F7F4F7EBEFFFF7FFF7F7FFFFF6F3F7FFF4FF
FFFFFFFFF7F6ECE6F7F4F2F6F6F6F6F2F6F7F7F6FFFFF6EC
F4F6EEFFEBF7F7F7F4F4F7F2F7F7EDF4F4FFDCBAF7C8DBE0
D9DDBDD9ECE5E4D9E0E7F7F6FFF6FFFFF7F4F4F4ECF6EDE8
E1E1E4F6DCD9F7EDE5FFEBECF6EEF4E0F7E5BB6DBAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC269FFF4DDEEEFF4FFFFF4F7EDEDEFDCE6F3F7EDE1
DCDCE5E4E0E0F4E1FFF6ECF7F4F7FFF7F3F2F6FFF4FFF7F7
FFFFF6F6FFF4E0ECEEF4F6F6F2FFEBEEF6EBEBF2FFFFF2EB
F7FFF2F4E6FFF7F4F7FFF4F6F2E4F7EDF4E8E5CFDCEBEFCB
F4CDC8DCEEF7F7EEEEE0DDF4ECECF4F7FFF7F4F4E7E4F7F7
EEF3ECE4F4E1E5EEF7ECF6E6EEF7EFDCEED47BB0F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF76FA7F6F4E5E6E4EEFFF4F7F7F7EEE5EDEFF4F4F4
F4F7ECE0E5F4EDE8F7FFEBF7F7EFF7FFE6FFF2F6EEF7FFF7
F7FFF6F6FFF7F3F6EBFFF7F2F6F6EBFFEEFFFFFFF6FFF6FF
F6FFF2F7F3F6F7F7F7F7F7F4F7EEDCE0D9F6ECF4D4CCE5F7
C2BDC9EEF4E4ECF7E5E0EEF4F4F7FFF7EDE5E8E8EDF4F4ED
E0F3F7F4EDF7FFF6F3DCE0F4DCD4E7ECD17698F7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC7F9FFFF7F7F4EBF4EDEDEFF7F6EEEFF7FFF7EC
E6EBF7ECFFEFFFEFF7F7EEEBF3F7EDFFEEEEF6FFF6F4FFFF
ECF6FFF6F6F6F3EBF2F7FFEBFFF2F6EEF7F6FFF6F6F6FFF6
F6FFF6F6FFF2F7F7FFF7F4F4F7F7ECBBDDD9F4ECEDECCDCB
F7F2DCBEB0B0C8D4D4DCDCD4C8C6CFCFDBEBF3EDE8E1EDF7
EDE5EEF7FFF6F2F2E4EEF7FFE4EBFFCA6490F4FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7D474B0EEF7EFEBFFFFF7EFEFF4FFEFF7F7F7F6
F2EBFFE6EBEBE5EFF7F4F4FFF2F6E5EFFFEEEEF6F6F7F7FF
ECFFF3EEF6F6ECE6F6F6F7EBFFF2F6FFF6FFF6F6FFF2FFFF
FFFFF6F6FFF6F6FFFFFFFFFFF6EEF4F3C3CCEEDBDBDDF4E5
BCAFC5D9D9E7F3E0E8DCE4F7F4EFF7ECDCDBE4FFEDDBCDD4
E0ECECE6E6ECF4EDF7EFF7FFF4F4F2888AF4F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC386A0E5F4ECF3F4F4F7F7F4EDF7EFEFF4F4
F7F4E6FFF7F7EEE4E5F7F7FFF6FFF6EDF4F4E4F6F2FFF4F7
EFEEF3F7FFFFF7EBFFF2F7ECEEF6F6F6F6F7F7F2FFF2FFFF
FFFFF6F6FFFFF6F6F7F7FFFFEBEEF2F2FFCBC2D5E5F7E6DB
C8D9E6EEE0C8B0ABB7BDC8D9E4E6F3F6E4DBDBE0EBEEEFF7
FFFFFFFFFFFFF7EDEDF7F4EFDCE0DC4ED5FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFD5885879CCEEE6ECF7F7F4F7E8EDEFF7F7
FFFFEBFFF7EFE5EEDDE5F6F6F2FFF2EBECF7EDCFD9F7F4F7
FFEFF4F4F7FFF7ECEEF6EEF4F3F2F6FFF6EEF7F6F6F3EEFF
FFF6F6F2FFFFFFF6EBEBF6F6F3F7FFF7E7E7F7D5CAD1DDF7
F4ECF4F3ECCDC2C2BDBDC8D9E0D4DBE8EDF7FFF7F7F4F4ED
F4ECE0DBDBE4F7F7DCC8CFECD0A65E7EFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEF9761EFFFF2ECD9E4FFF7FFF4F7EE
EBF3F2FFFFE6F4EDF6CDFFF6FFF2F6F2F6F4F7ECF4D1EDFF
E4E5F4F7F7F7F4FFEEECEEF3F7FFF2FFF2F3EBF6F6EEF3F6
FFF2F3F3F7F7FFFFFFF7EEF6F7F4EDF7EDEDF7E5D4E4DDCF
DDF7DDECDBC6C8C8BDBDC3C3C3C2C2BDBDD4E6E0D9D9ECFF
F6EEF7FFEEE5EDEDD9FFEEE6867EC2FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF58C4E8E4ECE6ECF7F7F7EDEDEC
EEF6F6FFEFE8DDD4C8B8E4FFFFF6FFF2F6F4FFFFE5F7DCE4
E0EEE6E0E4EFF7FFF7DDECE6F4F7EEF6F6EEFFEEF6F2F7EE
F6F2F4F7F7F7F7F7F4F7E4DCFFF7F7F4E5F7F7DDDBEEE4E5
DDC8D9E4C2D9F7F7F7FFF7F7F7FFFFEDE1EDF7F7F4E4EEEE
ECF6E6E6CBE4F4EEECEEE6867ED4F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFA075CBDDDDFFEFF7FFF7F4F7FF
ECEBEEFFE8F7EBF7E5C1E5E4F3F7F6F2F6F7F7FFFFE5E6F7
EEFFFFFFEEE0E5F7FFE5CBF6F7F7F7F6F2F6F7FFECF3F4F7
EEF7E5F4EDEDEFFFF4F7E5EFCCF7FFD9D4CAE1EDF4F7EEE4
FFFFE5CDD9ECE0D4E0F4E0D4E0E0E7F4FFFFE0DBEBF7E6FF
E6E5F4EDECEEEFEBFFCB837ED5FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA79A8D1EBE4F7F4F7FFFFF7
EDF7F6EEEDEFECEBF3D4E0DCD5F3FFFFF7F4FFF7FFFFF7EC
EEF7F7FFF7F4D9E5E4C8D1C3EDF4F4F3F6F7EDF4F7EFF7FF
F4DCECECD9EEEFEDF7DDD1E5F7DCF4E5D5E6C1C8D4D4D9E0
E0EDF4F4EEDBE0EEECDBF4F6F6F2F6F6EBE4FFEBF6ECDBDC
EDF7F7F7E4CDE0F6BB6C8AD4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC8798D1E0D4F7F4E8EDFF
F4F4F6EEEDF7FFF4FFECDCE4D4D3EBF6F7F7F7FFF7FFFFEE
FFE5FFF4F7FFE4EEE5EFCCC2DDF7FFEEF7EEEDECECECE5EF
F4ECD9D9D0E5D4D9D5D4DCB0D5CFB5CCDDBAC6F4ECE0DDED
ECE0DBE0DBCFD4ECF4FFECF6F6F2EBECF4FFF3DBD1E0F4FF
F7E5ECEEDCF7EFF659AAF4F7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC8FA0D9C9E5EDEDFFEF
F4F7ECF6EFEFFFECEBF3EBE0EBEFDCE4E6E4ECFFF7F7ECF7
E4E5E4ECF7F7EDEDF4DDE6DCC9EFF7F7E5F7E4E4F7EEE4E5
E0E7ECD9F4CFDCF6F7E7CBE7E6C9E5B0AED1ECD4C9D4E4F7
FFF7F4FFFFF4F4F7F4FFF7F4F4F4F7FFF7EDEFEEFFE5F4F7
FFE4F7ECE7D1E0C346F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD59798A0DCE0E5EFF7
F7EDE1FFF2E5EDEBECECF3CACCECEEE4EDEDDBCDD9F6EBF6
E4F7F7EBE5F7F4EDF7E8CCEDECBBE1F7EED3F3F4DCEBEFE7
F3E4E0ECCCC3DDD4E5EDDCE4F3CDD9E0E0E0BBC5DCF4F7F4
F7F4F6ECF4E8E8E8EDF4F4EDE8EFFFF7F7F7F4E0E0F7FFF7
F4DDEEDDE4DD8A51A0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5BD7483A6C9CDD4
D9E1D1EEF6F2E6D5D9DDE0E6F7D9D5DDE6E4E5DBC2AAB0C8
C6C8D4ECE6F4F4EDE4EBDCC6E4EBC8BACEDCBCB6F7E1BCE4
DDE0E5EEE6DDEFE7D9EBE4DDDCDCEDDCECE6F6E7FFFFFFF4
FFEFECE5F7F7F4F4F4F4F4E8DCEDFFF7F4FFF4EDDCE0E0E7
ECEDDCB63B2165BBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5B9A0A7D4E5
E5EEE6EEEEECEBEBEBE0FFECF7E6F3E5EDE0D9F4FFF7EFED
DBCDD1D9E5F4F7F7ECEEFFF3D9E7F2F6D9CCF3E5B8D1CBCC
E0F4E0E0EDE4E0DDF7F7F6E7F4EDE5EDFFE4E7F7F4EDE7E4
F7F7F4FFF4F7FFF7F7FFFFF4E8F4F7E4DBE7F4E4DCE5F6EB
E7ED8664A9F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5CCAE95B5
B8CDE5F2F3ECF7F7EEE0F7F3F3F7E4E0E5F4FFF4F7EDF7F4
FFEFF7DBC6C3D4EEFFEEEBEEEDDDECF7E5ECDCEEE5C9CCC2
DBF7EEF6F3ECEDECEEEFDCEDF7F7F7FFF7EDF4FFF4EDE7E4
F4F4EDEDF4F4F4F7F4F7F7F4FFF7E5F7F6F6EBF6E0D9E0DC
F7796CBAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5DBAEA6
BBD3DCF3F7FFF2F6F6E0F7F7F6ECE4E0E5F4F7F7F4EFEDF4
FFEDF4F4F4FFEFD9DCECEBFFDCEEEDEDF7E7ECEFE8E5C1D4
F7ECEEF6EBECDCD4CDBEE1DBDCFFFFF7F7F4E5E8EDEDEDF4
F4F4F7FFFFF7F4EDEDF7ECE7ECE6F7FFFFECF7E5E5EDF4D4
7153CCF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
A697A8D9E4FFF6F2F6EDD9E6ECEEF4F4EEF6F7FFF7F4F7FF
F4F7F7F4F7F7FFEED3D5E1E0E5DDE5F7EDD5E6E5EDE6D5E0
DDE4E4ECE5E6F6EDE4E0C8BDF4E4F4F7F7F7F7F7FFF7F4F4
EDEDF4F4F4EFF7F4F7F4F3FFF6FFECECF3F3D5DCEDE5AE59
69CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E5B68FB2CCE5F6F6F6EBEBE8EFEDFFF6E5E0F7F4ECECF4F7
F4F7F4EFF7F3ECF3FFF2EEF7E4D9D9F4F7F3D3D9ECE4EDDC
DCE7EFECF6F4E4D9E0E6EBECDDE7ECDBE0EDF7F4E8F4F7F7
F4ECE4F4EDF4ECE0E0DCE0E0E8E8EFE8ECC8E0E4B271528D
EDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC2847492C2D9EDECF7E4ECE6EDEEE0E5F7F4E1E1ECE4
F6F4F7EDFFEEF6F7EEF3EBF3EBE5EFF4FFECF6E5D3E5F4ED
EDECD4BDC8DBDBD9DCDCDCE1E0E4FFEBECFFE7ECEEE4F4EC
ECEEF6E4E0E0DCE8E1E8F7FFFFFFDDD1E4E69D745675CCF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F4CC8C61494782CBF3E1DCE0CFD4E0EFDDC2CFF7EC
ECE0EBF2E6E6F6F7FFE4ECF6F6F2FFF7F4F7F6F2ECFFECE6
D4E5F4EFEFF4F4E7DBE4E4E4F6F6F7E5E4E0F3ECE4D9C8D9
D9CFCDD9E0E0E4EEF7F6D9C8C3C3EDC5792C418CCCF7F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE58D597C97C1EEF4F7F6E0DDDCF4E5E5
F7F7F4F4EFEDE5F6F7F4FFF7F2F2FFFFFFF6F2F2E6E0FFE0
ECFFF6ECF7F4F4FFF4F7EFEDF4E7ECEEEEFFF4EDEDEDECE0
DBDBE0EBF6F3F3E6EFD9C8ECDBBD826275C3F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC8C78788F9EB2CFDCF4D9EDE5E5
D1C8D9EDEFF4E5DDF2F2EBEBFFF6E6E6FFF6F6FFF7F7EEE0
E6F2F6EEECF4F4EFE4ECFFF7F4F7F7F4EDE8EDECEBF2F6F3
E0D4CFDBE6C5AFC1D9E6EFD9A85D71C1F4F7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE5B68A796D6D6D6685AFAAAF
B8C2C2DCD4D4E5E5D5E1E8EFF6F2DCE5FFFFF3E6E6E6EBEC
F4F7F4F7F6F2F6F4ECF3F7FFFFFFF7F4FFF4F4ECE6E6E0D9
E8FFF4F7D9DDFFFFEED97E5F61BAF7F7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5DBDBE0D1C8E0E5
DDE0B9DDEDEECBB9B9DCEEEFE8E1E6F2FFF6ECFFF7F7F4D9
E0EBE6F3F6F6F6EEFFF4F7FFFFFFF7F4F7FFFFFFFFF7F7F7
FFEFF4E4F7E0CDAEA38F6DD1F4F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E4DB
ECECDBD1D9ECECE4E4AEABC8EEF7EDE0E0ECE5ECEEEBE5F4
F4F7FFF3F3F2FFF3E4ECF4F4F4F7FFFFF7F7FFFFFFF4F7EC
F3ECDBF4D1AE93747393CCF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EFE4EBE0CCD5D9E4DCE7CBBABAB6BCD1E4F7EDD4D9F4E5EC
F4FFF7F3F3F6F2EBEBF7EBF6FFF4FFFFF7F7FFEFE8E4EBF7
ECE0B2816D75A3CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7EDEFE5E0E8E0E4F7EFD1BDB7B09773677E9EA3AAAAB6
C8BBC2DBE0E0EBF2EBF7E0F7F2EBD9D4CDC8B27F61412F3B
3636538CCCF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFFFFFE5DBC6B7B08F
869EA49898A7B1A49D8A7F7C747471676D7383AEC3D4E4E4
F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFF
F7E4DBDBCFB2AAB0BDC3BDC6E0E0E5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -14 0 ]
[.5 1.0125 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Blue) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFF
FFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6DCFFF4FFFF
FFF3F3F3FFFFFFFFF4FFFFF4FFF4FFFFFFFFFFFFFFFFFFFF
FFF4F4FFFFFFF4FFFFFFFFE8F4F4FFFFFFFFF4F4F4FFFFF4
F3FFF3F3FFF4F4FFF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFF4
F4F4F4FFF4F4F4FFF4F4F4FFF4FFFFF4FFFFFFFFF4FF8CDC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFF
FFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8F8FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFF8F8F8F8FFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6DCF8F8FFFF
FFF3F7F7FFFFFFF8F8FFFFF8F4FFF8FFFFF8F4F4F8FFFFF8
F8F8F8F8F8F8F8F7ECEFFFE8F8F8FFFFFFFFF4F8F8FFF8F8
F3F7FFF7F7EDF8F4F8FFF8F8FFFFF8F8FFFFFFF8F8F8F4FF
F8F8FFF4F8F8F8FFF8F8F8F4F8F8F8F8F4F8FFFFF8DE8AE7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFF8F8FFF8F8F8F8F8F8FFF8F8
F8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFF8F8FFF8F8F8F8F8F8FFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFF8F8FFFFFFFFFFF8F8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D0F8F8FFFF
FFF7F7F7F7F7F7F4F8F8FFF8F4F8F4FFFFF8F4F8F8F8FFF4
F4F8F8F8FFF8FFF7ECEFEFEFFFFFF8F4F4EEEEF8F8F4F8FF
F7FFF7FFF4EFFFFFFFFFF8F8FFFFF4F4FFFFFFF8F8F8F8F4
FFF8F8FFFFFFFFFFFFF8F8F8F8F8FFF4F8F4FFF8F4B6A7FF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFF8F8FFF8F8
F8F8FFFFFFF8F8FFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFF8F8F8F8FFFFF8F8FFFFFFFFFFFFFFFF
F8F8FFF8F8FFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8FFFFFFFFF8F8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D0F8F8FFF7
F7FFF3F7FFFFEFF8F8F8F8F8FFF8F8FFF8F8F8F8F8FFF4FF
FFF8F8F4F8F7ECE8E8E8EFFFF8F4F0F8F8F8FFF8F8FFF7F3
F3F7FFFFF8F8FFFFF8F8F8F4F8FFF8F8FFFFFFFFFFF8FFFF
F8F4FFFFFFFFFFFFFFF8F8F8FFF8F4FFF8F8FFF4F09CCCFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FFF8F8FFF8F8FFFF
FFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFF
FFFFFFFFF8F8FFFFFFFFF8F8FFFFF8F8F8F8FFF8F8F8F4F8
F8F8FFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D0F4FFFFF7
FFF7F7F7F3F3F4FFFFFFF4FFFFF4FFFFF8FFF8F8F8F8F8F8
EFF7FFFFEFEDF8FFFFFFF8F4F8F8FFFFF8FFFFFFF7F7F3FF
F8F4F4F4F4F8F8F8F4F4F4F8F8FFFFFFFFFFF8F8FFF8F8F8
FFFFF8F8F8FFFFFFFFFFFFFFF8F8F8F8FFFFFFF4CC9CF0FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFF8F8FFF8
F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFF
FFFFF8F8F8F8FFFFFFFFFFFFFFF8F8FFF8F8FFF8F8F8F4F8
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D0F4FFFFFF
F7F7F7F7F7F7F8F4F4F4F8FFFFF8F8F8F4F8FFF4F8F4F8F7
FFF7EFE8EFFFFFF8F4F4F8FFFFF8F8F4FFF7F7F7F7F7F7F8
F8FFFFFFFFFFF8F8F4F8F8F8F4F8F8F8F8F4F8F4FFFFFFF8
F8F4F4F8F8FFF8F8FFFFFFFFF8F8FFF8F4F8FFEEB2B9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFF8F8F8F8FFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6DCF8F8FFFF
FFFFF3FFFFFFF8F8FFFFFFFFF8F8F8F8FFFFFFF8F8FFF7FF
F8E8F7F4F8FFFFF8F4F8F8F8F8F4F4F8FFF7FFF7FFF7F7F8
F4F4F8FFFFFFFFFFF8F4F8FFFFF8F8F4F4FFFFF8F8F8F4FF
F8F8F8FFFFF8FFFFF8FFFFF8FFFFF8FFF8FFF8E398D6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
F8F8FFFFFFFFF8F8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFF
FFF8FFF8FFF8F8FFF8F8F8F8F8F8FFFF
FFF8F8FFFFFFFFFFFFF8F8FFFFFFF8F8FFFFFFF8F8FFFFFF
FFF8F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D0FFF4FFF7
F7F7FFF7FFFFF4F4FFFFF8F8F4F8F8FFFFFFFFFFFFFFECEC
E8F8EFF4F8FFFFF8F4F8F8F0F8FFFFF7F3F3EFF8F8EDF4FF
FFF0E5EDF4F4F4F8F8F4F8FFFFFFFFF8F8FFF8F8F4F4FFF4
F8F8FFFFFFF8F8F8F8FFFFF8F8F8FFF8F8FFFFC598F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
F8F8FFF8F8FFF8F8FFF8F8F8F8FFF8F8F8F8FFFFFFFFFFFF
FFFFF8F8FFF8F8FFF8F8FFFFFFFFFFFF
FFF8F8FFFFFFF8F8F8FFF8FFFFFFF8F8FFFFFFF8F8FFFFFF
FFF8F8FFF8FFFFF8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D0FFF4FFF7
F7F7F7F3FFF7EFF8FFFFF8F8F4F8EFF7FFFFFFEFEFEFFFF8
EDF8EFEDFFF8EEEEF4EDE8F4F7ECECE7EEEEF8F8F8F8F4FF
FFFFF7E2F0F0E7EFFFF8FFFFFFFFFFFFFFFFF8FFFFF8FFF4
F8F8FFFFF8F8F8F4F8FFFFFFFFFFF8F8FFF4E69FC4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFF8F8F8F8FFF8F8FFF8FFF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6DCF8F8FFFF
FFFFF7F7FFF7F7F8F8FFFFFFF8F8F3F3FFF7ECFFFFFFFFED
F8FFF8F8F8F8F8F4F4EDECFFF7F4F4F0F4F8F8F8F8F4F4F0
F8F8F0FFF0F0F7FFE8EEFFFFFFFFFFFFFFFFFFF8F8FFFFF8
FFF4F4F8F8F8F8F4F8FFFFFFFFF8F8FFFFF8D494F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
F8F8F8F8FFFFFFFFF8F8FFFFF8F8FFF8F8FFFFFFFFFFF8F8
FFF8F8F8F8FFF8F8FFFFF8F8FFFFFFFF
F4F8F8F8FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFF8F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0E1F4FFFFFF
F7F7F7F3F7F8F4FFF8F7F7FFFFFFF7F8EFECF7FFFFF8F4F4
EDEFFFFFF8F4F4F4F8F8F0EFF3F7F3F7EFF4EEF8F8F4F4EE
F0F0F4F4F4EEFFF7E2FFE2E2F0FFFFFFFFFFFFFFFFFFF8F8
F8F4F4FFF8FFFFFFFFFFFFF8F8F4F4FFFFF8C0A2FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFF8F8FFFFFFFFF8F8FFFFF8F8FFF8F8FFFFFFFFFFF8F8
FFF8F8F8F8FFF8F8FFFFF8F8F8F8FFFF
F4F8FFF8F8FFFFF8F8FFFFFFFFFFFFFFFFF8F8FFF8F8F8F8
FFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFF8F8
FFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBAE8F4FFFFFF
F3F7F7FFF3F8F4F8FFF7F7FFF7F7F7EDE8EFE7E1EDFFF3F4
EDF7F8F8F8FFFFFFF8F8F8EEEEF8F7F7F7F7FFEEF8F4F8FF
FFF8EFEDF4EEFFF0FFF0E2EDEDE2F0FFFFFFFFFFFFFFF8FF
F8FFFFF8F8FFFFFFFFFFFFF8F8F8F8FFFFF8A7B9FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFF8F8FFFFF8FFF8FFFFFFFFFFFFFFF8F8FFF8F8F8F8
FFF8F8FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFF8F8
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8C0E8F8F8FFFF
F3F7F7F7F7F7F7F7F7FFFFFFF7FFFFE8EDEFE1E7F4F4E8EF
EFF4F8FFF7E8EDF4F8F8F8F8FFF0F4F8F7F7FFF8F0F8F8FF
F0F4ECF3FFFFF0EEF8FFFFF0E2E8F4E2F0F8F8FFFFFFF8F0
F8FFF8F8FFFFFFFFF8F8FFFFFFFFFFF8F8F89BD0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FF
FFF8F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4B9EFF8F8FFFF
F7F7FFF3FFF7FFFFFFF7F7F7EFF4F3EDE1EFEFEFEDEFEDED
F7F8F7F4EFF7F7FFF4F4F4F8F8F8F8F4F7F3F3F7F4FFF8F8
F4F7F7F7F3F7FFF8F0F8FFFFFFF8E5E8F8E8F8FFF8F8F8F8
F8F8F4F4F8F8FFFFF8F8FFF8F8FFFFF8F8E59BE2FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8F8
F8F8F8FFFFF8F8F8F8FFFFFFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4B3F8F4FFF7F7
F7F7F7F7FFFFF7FFEFECF3F7F8ECF7E8FFFFEFFFFFF8F7F3
F4EFF7F7FFF7F3F3F8EDFFF8FFF8F8F4F8F4F8F7ECEDEDED
F8F7F7FFF8EFF3F3EFF0F8F8F8FFFFF8EEF7E7FFF8FFF4F8
F8F8F8F8F8F8FFFFFFFFF8FFF8FFFFFFFFD69BF0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFF8F8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FFF8F8FFFFFFFFF8F8
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEB8F8F4FFF7F7
F7F7F3F7F7F7F3F7F4E8F7F7F4EFFFE8FFFFE7EDEDEDF8EF
EFF8F8F8FFFFF7F7ECEDF4F8F4F0F4FFFFF8F8F4F4ECF3F7
F3F7F7F7F4F4FFF7FFEFEEF8F8FFF8F8F8EFE7E7E2F4F8F8
FFFFFFFFFFFFF8F8FFFFF8F8F8F8FFFFF8B2A7F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFF8F8FFFFFFFFFFFFFFF8F8F8F8FFF8F8FFFFFFFFF8F8
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9B9FFF4F8F8FF
FFF7F7F3F7FFF7F8F7EFEFEDF7FFEFE8EFE8EDF8F8F8F8F8
F4F8F8F4F8F8F7F7F7F7F7F7F8F8EEF8F8FFF8FFF8F4F7F8
F8F7F3F7F3F3FFF3F3F3FFEEF8FFF4F8FFF8FFE5F8ECE7F4
F8FFF8F8FFFFF8F8FFFFFFFFF8FFF8F8F0A2D1F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFF8
F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9B9FFF4F8F8F7
F7F7F3FFF3F7ECF7FFEFE8EFF8F8F8F8F8F7F8F4F8F8F4F8
F4FFFFF8F8F4FFF7F7FFFFF7EFF8F8F8FFF8F8FFF8F8FFF8
FFF8F7F7F7F7FFF7FFFFF4F8F8F4FFF8F4FFFFF8E5E7EFEF
F4FFF8F8FFF8F8F8F8FFFFF8F8F4F4F8E2A6E2FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFF8F4F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8FFFFFFF8F8FFF8F8FFFFFFFFFFFFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2BFF8F8FFFFF7
F7F7F7F7ECE8FFEFE8EDF8F8FFFFFFF7F7F7F8F8F8F8FFF4
F4FFFFFFF8F8FFF7EFF8F8F8F4E5EFF8F8F8F8FFF8F0F4F8
F4F8EDF4FFFFFFF7FFFFF4F8F8F4EEF4F4FFF8F8F8EFE5F8
E5F0FFFFF8FFFFFFF8FFF8F0F8F8FFF4D0A7F0FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8F8F4F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4FFF8FFFFFFFFFFFFFFFFFFFFF8F8F8F8FFFFFFFFF8F8FF
FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0D0F8F8FFFFF7
F7F3F3F7EDEFFFE8F7F8F7FFFFFFF7FFF8F4F4F8FFFFF8FF
F8FFF8F8F4FFF8F4F8F8F8F8FFF8ECF4F0F8F8F4FFF8FFF8
FFF4F8F8F8FFFFF3F3F3FFF8FFF4F4FFFFF8F4F4F8F8EEEC
F3E9FFF8FFFFF8F4FFFFF4F4FFFFF4F8C6A8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFF8
F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFF8F8F8F8FFFFFFFFF8F8FFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6DCF8F8FFFFF7
F7F4EDEDFFEFE8F8F8F7F3FFFFF7FFFFF8F4F8FFFFFFF8F8
F8F8F4F4F4FFF4FFFFFFFFFFF4FFF7F7F8F8F8F8F4F8F4F8
F8F4F0F4F8FFFFF7FFF7FFF8FFF4F8F4F4F4F8F8FFFFF4ED
F0E7EEFFF8F8F4FFF8FFF8F8FFFFF4F8B2B9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFF8
F8FFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6DCF4FFFFFFFF
FFF4EFE8FFEFECF8FFF3FFF7F7FFFFFFF8F8F4FFFFF0F0FF
F4F8FFF8F4F8F8FFFFFFFFFFF8F4F7F7F7F8FFFFF0F8FFF8
F4F8F8F8F8F4F8F7F7FFFFF8FFF4F8F8FFF8FFFFFFFFF8F8
E2EFF7E7F8FFFFF4F8F8FFFFF8F8F4FFA8CBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8FFF8F8FFFFFFFFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFC5EDFFF8F8F8F8
F4F8EFEFEFF8FFF7F7FFF7F8F8FFF7F4F8F8F8FFFFF0F0FF
F4FFF8F4FFF8FFF0F0FFFFFFF8F4F7F7FFF7F8F8F4FFFFFF
FFF4F8F8F8F4EFFFF3F4F4F8F4FFF8F8F8F4F8FFFFFFFFFF
F0F8F4F4EEEEF8F8F4F8F8F8F8F8F4F89BDBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFF8FFF8F8F8FFFFFFFFF8F8F8F8FFF8F8FFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0A7E2F4FFF8F8F8F4
EFEFEDECFFF7FFFFF7F7F7F8F8FFF7EDF8F8FFFFFFFFFFFF
F4FFF7F4FFF8FFF0F0FFFFFFF8F8FFF7F7F3F7F7F4F8F8F8
F8F4F8F4F8FFF7F7FFECF8F4F4FFF8F8FFF8F8FFF8F8FFFF
F8EEF0FFEDECE5F0FFFFF8FFF8FFF4ED96EEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8F8F8FFF8FFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8F8F8FFF8F8FFFFFFF8F8FFF8F8F8F8FFF8F8FFF8F8F8
F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B6BDE9FFF4FFF7F4EC
EFF8FFF7F7F7F7F7F7F7FFFFFFF7F7F8FFFFF8F8F4F8FFF8
FFF4FFF4FFF8FFFFFFF8F8FFF8FFF4F4F8F7FFF7F4F8F8F4
F8F8FFF8F8FFFFF7F7F3F8F8F8F8F8F4F8F8F4F8F8F8FFFF
F8EEF0F0F7E5FFE5E7FFF8FFF8F8F8E1A3EEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFFFFF8F8
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8F8F8FFFFFFFFF8F8FFF8F8FFFFFFFFFFFFF8F8F8
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8AD94D5E3F4F8F7EFE1EF
ECFFF7FFF7F7FFFFF7F7FFFFFFF7EFF8F4F4F4F4FFF4FFF4
F8F4F7FFF4FFFFFFFFF8FFF4F8F4EDF4F8FFF3F8FFF8FFF4
FFF8F4F0F8F7F7F3F3F3FFFFFFF4F8F4F8FFFFF4FFFFFFFF
F8F4F4F4F4F8E2E5E2FFF8FFF4FFF8DCA2F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAD6BB6ADE9F8F7EFEFF8ED
EFF7FFF8F8FFFFFFFFFFFFFFFFFFF8FFFFFFF8F8F8F4F8F8
FFFFFFFFF8F8FFFFF8F8F8F4F4FFF7FFFFF7FFEFF8F4F8EE
FFF8F4F0F8F7F7F3F3F3FFFFF8FFF8FFFFFFFFF8F4F4F8FF
F8F4F8FFF8F8FFE9F0F0F8F8FFF4F4D69DFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8FFF8FFF8F8F8F8F8F8FFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFDF4C8BCB9DF4EDF7EDEFECF3
F3FFFFF8F8F8F8FFFFFFFFF8F8FFF8F8F4F4FFF8F8F4F4FF
FFFFFFFFFFF4FFF8F8F8F4F4ECF3FFFFFFF7F7F3F8F8F8EE
FFFFFFF4FFFFFFF7F7F3FFF8FFFFF8F8F8FFFFFFFFF8F8FF
F8F8F8F8F8F4F8F0EDE5EFF8FFF8E7CBAEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8FFFFF8F8FFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF06B49EEB2A2F0ECEFF7F8F3F7
F7FFF8F8FFF8F8F8F8FFFFF8F8F8FFF4FFFFF4F8FFF4F4FF
F7F7F7F7F8FFF4F8FFFFF7F7F7F7FFFFF7F7EFF4F8F8F8F8
FFFFF8FFF8FFFFFFFFF7F7F8FFF8FFF8FFF4F8F8F8F4F8F8
F8F8FFF4F8F4FFF8E2F4DFEDFFFFEFBFC0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFFFFFF8F8FFF8F8FFFFFFFFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F48D3FBDDBB297EFFFF8ECF3FFF7
FFFFF8F8FFFFFFF8F8F8F8FFFFF8FFF8F4F4FFFFFFF8FFF4
F7F3F7F7F8FFF8FFFFFFF7F8EFEFECF3EFEFF4FFF4F8F4FF
FFFFF4F4F8F8FFFFFFFFF3FFF8F4F8FFF8EEF4F4F4F4F4F4
FFFFFFF8F8FFF8F8F0DFF4EFEFFFF8A8C6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4FFF8F4F4FFFFFFFFFFF8F8FFF8F8F8F8FFF8FFF8F8F8F8
F8FFF8F8FFF8F8FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA4393AA4EDC989A2FFFFF7FFF7FFF7
FFFFF8F8FFFFF8F8F8FFFFF8FFFFF8FFFFF8F8F8FFFFF8F4
F3F7FFF8F4F8F8F8FFFFF7EDEFEFF4E9F4F4EEF0F4F4F8F8
F4EDF4F8F4F8F7F3F7F7F7FFF8F4F8FFFFF4F8F0FFFFFFFF
F4F4F8FFFFF8F8FFF8F8E2E5F4E1E79BD0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8F8F8FFFFFFFFFFFFFFF8F8FFF8F8FFF8F8FFF8F8F8
F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8399DF4DCFF668CE8FFFFF7F7FFF7FF
FFFFF4F4FFFFF4F8FFFFFFF8FFFFFFF8F8F8FFF8FFFFFFF8
F4F4F8F8F8F8F8F4FFFFF7EFF4F4F8FFF4EEEEEEF4F4F4F8
FFF7FFF3F3F7F3F7FFF7F7F4F8FFFFFFF8F0F4FFF0FFF8F4
F0F8FFF8FFF4F4FFF8FFF8EEE5F8DD96E2FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8FFFFFFFFF8F8FFFFFFFFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFF8F8F8F8FFFFF8F8F8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFF
FFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8D720EDF0E18459E5F7F7F3F3F3F3FFFF
F8F4F8F4FFF8FFF4FFFFFFF8FFF8F8FFFFF8F8FFF8F8F8FF
F8FFF4F8FFF8F8F8F7F3F3F7EEF8FFF8F8FFFFF7F3F7FFFF
FFFFF7F3F3F7F7F7F7F7F7F4F8FFFFFFF8F0F8F8F8F4FFF8
F8F4F4F4FFF8FFF8FFF8F8F8E5D7F4AAE9FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8FFFFFFFFF8F8FFFFFFFFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8FFF8F8F8FFFFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEE7276E5ED8462D6ECF7F7FFF7F7F7F8F8
F4F8F4F8F8FFF8FFF8FFFFF8FFF8F8FFFFFFFFFFF8F8F8FF
F8FFF8F8F8F8FFFFF3F7F3F4F8F4FFF4F8F8F8EFF3F7FFFF
FFF7F3F3F3F7F7F3F3F7FFF8F8FFFFFFFFF4F4FFFFF4FFF8
FFFFF8F4F8F4FFF8FFFFFFFFFFE2DFADEEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8F8F8F8F8F8FFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF89550C3EDAC67DFECF4F7F3F3FFFFFFF8F8
F8FFF4F4FFF8FFFFFFF8F8FFFFF7F7FFFFFFFFFFFFFFF8F8
FFFFFFF8F8F4FFFFF7FFF3F4F8EEF4F8F4F4F8F8FFFFF7F3
F7F7F3F3F3FFF7FFFFF8F4F8FFF8F8FFFFF8F8FFF8F8FFF8
F8F4F8F8F4F8FFF8F8F8F8F8F8F4EF96EEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8F8F8FFFFF8F8F8F8FFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8C454ABEFAB6BBDEFFFF8F7F7F7FFF8F8FFFF
FFF4FFF8FFF8FFFFFFFFFFFFFFF3F3F8F8FFFFFFFFFFF4FF
FFFFFFF8FFEFF7F7F3F7F8EEE6F0FFFFF8EFF7FFFFF7FFF7
F3F7F7F7F3F7FFFFFFF4FFF8F8F8FFF8FFF8F8FFF4F8F8FF
FFF4F8F8F4F8FFFFFFF8F8F8F4F8EEAEC4FFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFF8F8F8F8FFF8F8
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFF8F8F8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F0567BE7C880C5E7F7F4F7F7F7FFFFF8FFF8F8
F8F8F4F8F8F8FFFFFFFFFFFFFFF3F3F8F8FFFFFFFFF8F8FF
FFFFFFFFF4F7FFEFF4F4F0F8F8F8FFFFFFF7FFF3F3F7F7FF
FFF7F7F7FFFFF8F4F4FFF8F8F8F8FFFFF4F8F8F8F4F8F8FF
FFF4FFF4F8F8F4F8F8FFFFFFF4F4EED6ACD7FFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8F8F8FFF8F8
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8FFF8F8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8C63F49D6E761A4FFECEFF3F3F3F7F8F4F8F8FFFF
FFF8FFF8F8F7F3F7FFFFF7F3F7F7F7FFFFFFF8F8FFF4F8F8
F8F4F4F4EFF7F3F4FFFFF8F8FFF4FFF7F3F3F7FFFFF8F4ED
EDF4F4F4F4F4F8FFFFF4EEF4F8F4F8F8FFFFFFF8FFF8FFF8
F8F8F4F8FFF8FFF8FFFFFFF8FFF8F4EFC5A3C4F0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8F8F8F8F8FFFFFFF8F8FFFFF8F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEE6E6CFFEDA17BE7ECFFFFF7F7F7FFF8F4F8F8FFF8
F8F8FFF8F8F7F7F7F3F3F7FFF3FFF7F3F7FFF8F8F8F8F8FF
F8FFFFFFF7F8F4F4EFFFFFF8F4F8F7F7FFFFFFFFFFF4EFF8
F4F4F8F8F8FFFFFFF8FFF8FFF8F8FFFFFFFFFFFFF8F8FFF4
F4F8F4F8FFFFF4F4F8F8FFF8FFF8F8F4F8CFB3D4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8F8F8FFF8F8FFFFF8F8FFFFF8F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8C143CEF8BE6BC5ECEFF7F7F7F7F7FFFFFFFFF8FFF4
F8FFFFFFFFFFF3FFFFFFFFF7FFF3FFF7F3FFFFFFF8F4F8F4
FFFFFFFFFFEDEFEDEFFFD7C6D0DCDBDED7D7D7DBE9E5E7EE
EEF4F8F8FFF8F8F4F8F8F8FFFFFFFFFFFFFFF8F8FFFFFFF8
F8F4F8F8FFFFF8F8F4F8F8FFF8F8FFF0FFF0CBB2F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF86969ECDD67B6F4F7FFF7FFF7F7F7F7FFFFFFF8F8F8
F8FFFFFFFFFFF3FFFFFFFFF7FFF7F3F7F7FFF8F8F8F4FFF8
FFFFF8F8FFEDE7F8D6C6FFD4F0FFEDF3F7F7F7EFE8E7E7E8
E1DCE2EEFFF8F8F8FFF8F8FFFFF8F8FFF8F4F8F8F4F4F8FF
FFF8F8FFFFFFFFFFF4FFF4FFF8F4F8F8F8F0E8A4BCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFF8F8FFF8F8F8F8FFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFF8F8FFF8FFF8FFF8F8F8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF832B6E19290E7E8F7F7F7FFF7F7F7F7F7F7F8F8F8F8
FFFFFFFFF7F7ECF8FFFFFFFFF7F7F3FFFFFFF4F4F4F8F8F8
F8FFF8FFF8E8FFF8D0BDF8D4F0EFEFFFFFF0F0FFF7F8EFFF
F0F0F7ECE1E2EEF8FFF8F8FFFFF8FFF4FFF8FFFFF8F4F8FF
FFFFFFFFFFFFFFFFF8F8F4FFF8F4F8F4F8F4F8DCA7DFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFF8F8FFF8F8F8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFF8F8FFF8F8FFF8F8FFFFF8FFF8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFBD40D6A976E7EDECFFF3F7FFFFFFF7F7F7F7F8F8F4FF
FFFFFFFFF7FFF4FFF4F4F8F8F8FFF3FFFFF8FFF8F8F8FFF8
FFF8F8EFE1EFFFFFEFEDCBFFFFE8FFFFFFF0F0FFECECFFFF
F0FFF0FFFFF7ECEDF8FFFFFFFFFFF8F8F8E7EFFFF4F8F8F8
F8FFFFFFFFFFFFFFF8FFF8F8F8FFFFF4F8F8F4EDB5B5E7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF6C76F075B2E5ECF7F7F7F3F7F7FFF3F7F3F4F8F8F8FF
FFF7F3F3F3EFF4EDFFF8F8F8FFF8F3FFFFF8F8F8F8F8F8F8
FFE7E1E7FFFFD7D7FFF8DED6E7E8F8F8FFFFFFEFEFE8FFFF
FFF0FFF0FFFFF0E7ECEFFFFFFFFFFFF8F8ECECFFF8FFF8F8
F8F8F8FFFFF8F4F8F8FFF8F8F8FFFFF4F8FFF0F8E8B9C9FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CF8A39F86289F8E5EDFFF7F7F7F7F7F7F7F7ECF7F8FFFFFF
FFF3FFFFF8F8EFEFFFF4FFF8F8F4F3FFFFFFFFF8F8F8E7E1
E1EFDFDFFFFFD7AEC6BDB9B8C8DEEEE2D1DBDBCEE8EFF0EE
EEEEEEEEF8FFF0F0FFE8DBEFF8F8F8F8F4F7F7EFEFF8F8FF
FFF8F8F8F8F8F8F4FFF8F8F8F4F8FFF8F8F4F8F0F4CEA3BE
FFF0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFF8F8FFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8DE
8CC57A7B95E7EDF8F4FFFFF7F7F3F7F3FFF7EFF8FFFFFFFF
FFF7F7FFF4F8F4F8FFF4F8F0F4F8F3FFFFF8F4F8FFEFEFFF
FFE7F8F8E7F8E5CCE5E5EEE6E2E1EDECFFE8EFE8E9EEEEF8
E7E1EDF8EEE9E9E9F0F0F0ECF8F4F8FFFFEDEFEFEFFFF4FF
FFFFF8F8F8F8F4F4FFFFFFF4FFF4FFFFF4F4F8F8F8EEE59B
F8F0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF48A
84B9C64EF0EFF8FFFFF3F7FFF7FFF4F4F7F3F7FFFFFFFFFF
FFF7F7FFF4F4F8EEFFF4EEF8EEF8F3FFF8F8F8F8EFEFFFFF
FFE7E7E7D7CED0D7DFE2E1E5F4FFF7F7FFEFE8E8E8E1E8ED
EFFFEFE8E8EFFFFFE9F0E9E7F7F8F8F8FFEDEFEFEFFFF8F8
F8F8F8F4F4F8F4F4FFF8F8F4F8F8FFFFF8F8F8F4FFF8E796
F0F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8C46C
CDCE8D92E1F8F7F7F7FFF3F7FFFFF4F8EFF7FFFFFFFFFFFF
FFF3FFF8F8F4F4EEF8F4FFFFF8EEF3F8F8F8E7E8EFFFFFF8
F8F0E2D0D0CDE1E5F4DBC4BED6DED1DBE8E8E8E8ECF7F4F4
FFF8F8F8F8EFEDF8F0FFE9FFE7F3EDFFF4EFEFE8E8EFEFF4
F8F8FFFFF8F8F8FFF8F8F8F8FFF4F4F8F8F8FFF8F8F8EEA6
DEF4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE868D
D5CC28EFE5F8F7F7F7FFF7FFFFFFF8F8F4ECF8FFFFFFFFFF
F7F7FFF4F8F0F8F8EEEEF4F4EEF0F3F4F8F8E8F8F4F4F4E7
D6D0DBDEE1DFF8E2D6C5D7DEA795AEABB4C5BCACB5B6CBE8
F4F8F4F4F8F8F7ECEFF0E9F0E9FFEFEFF8E7EFECF7FFEFF8
F4F4F8FFF8F8FFF4F4FFF8F8F8F4F4FFFFFFF8F8F8FFF8C5
B4E5EEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFF8F8FFF8F8FFF8FFF8FFFFFFFFFFFFFF
F8F8FFF8F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8EE9584B2
CEE538E7F7F8FFF7F7F7F7FFF8F4F4F8EDF4F8FFFFFFFFFF
F3F8F8F4F4F4FFFFF7F7FFF0E6EFF4F4E5E8E7F0F4EDDBD4
DEE1D3DDF8EEB69FA9BAC4CA9476DEE8E2D6B19CDCCEBDBD
D6EDDCE5F8EEF8F4F8EFFFFFF0F0FFECF4F8EFF4F4E8FFFF
FFF8FFF4F4F4F4F8F8F4F8F4FFFFFFF8FFF8F4FFF4FFF8E7
B4CDF8F0F4EEF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFF8F8FFF8F8F8F8FFF8F8F8F8FFFFF8F8FFFFFF
F8F8FFF8F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8BC89BCBD
E5957BECF8FFFFF3F7F3F7FFF8F4F4F8E8FFF8F8FFFFF8F8
ECF8F8F0F8F4EFE8EDEDEFE9EDEDF4EDDFEED6DCE8E5D7DB
CBC5C1CEC1D3AFCBF4EDF4ECD6B6DBF8F8F8BDB2F4E8E9B6
BDC3D0C6DEE8E2E7F8F4E5F8FFF0F0F7F3F7EFECECFFEFFF
FFF8FFF4F8FFFFFFFFFFF8F8F8F8FFF8FFF8F4FFF4FFF4F4
DEA6F8F8FFF4F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFFFFFF8F8FFF8F8F8F8FFFFF8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF08DB4C0D1
DF70C9F4FFFFFFF7F7FFF3FFF8EEFFF4E8F8FFFFF8FFF8F8
ECF8F8F8F8F8E8FFF8F4E1E3E5F8E5D6E1DDE7F8F4DFB6C0
DBFFE5E1ADDEE89985858590A7ABB2D4EEEED6C9F4F8FFC0
C1C1DFC3CECFE5DEEFEFE8F4FFF0FFF0F7F7FFEFECEDE8FF
FFF8F8F8F8F8F8FFF8F8F8F8F4F4FFF4F8F8F4F8F8FFF8F0
F8AAD7F4F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8FFFFFFFFF8FFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8C5A6D0B9DB
9F7DE8F8FFFFF7F7F3FFF3F8F0F8F8F0DCFFF8F8F8F7F3F7
E5EEF8F8E7E1DEDBE2E5CFDFF4C1A7C5D7D3D0B97E66CD86
74B2EDCDC4DFDCFFC58A62516391A3D4C5A8CBCCA8978591
D0CBE2DDC6ACBDD7F4E5D5DBDCD3EDF8E7F3F7EFF7F7FFEF
FFF4FFF4FFF4EEF8F8F8FFF8F0F8FFF4FFFFF4F8F4F4F8F8
F4CBC6CFE2DCE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFF8F8FFFFF8F8FFF8F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD69BE9A8A7ED
69BCF3FFFFF7FFFFFFF3F7EEF8FFF8F0DCF8FFFFFFF7F3F7
DCFFF8EFE5F8F4EFE7D0DBF0C5B5D4D0B2C5ECB4563D5B8D
B285978597A7B4D486B6EDFFECF0F0CB8684838B85797D9F
DDDBAFCCE6DCE1F8F0DEF4DEEEEED6DED7F0F3EFFFF8F8EF
F8F8FFF4FFF4F7EFF4F8FFFFF4FFFFF4FFF8FFF4F8FFF8F8
FFE1DECBF8DDC6E5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8FFFFFFFFFFFFF8F8FFFFFFFFF8F8FFFFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFABAFD782C9A7
6CF4F7FFF7F7F3F7F7F8F4EEF8F4F4E9ECFFFFFFFFF8F8F7
E2F8EFE7F0F8E7E8E5D1E5A4A7C3B99CCDA4A9A4C4A495D7
FFC7A7B6D1BD9C9B86EDFFF8ECFFE9E9D0F8E5F8F0F8DEA7
848BE2A9B9CBF8E1E1CBF4F7E7F8E5FFEDE3F3EFFFF8F8EF
F8F8FFF4F8F8F3F7F7F8F8FFF4FFF8F8F8FFF8F8FFF8F8F8
FFEDE2C4DFC6E5E5DEF0FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF84C4C8A1F47B
A3ECFFF7FFF7F7F4F8F8F4F8F4F8F4DBF7FFFFF8F8F8F8F3
E9F4ECEEF8E7E7EDE5DEB4A4CBC9E7D47395D5C9E9E5D0FF
FFF7F4F4F8FFE8C5B9F4FFFFE8FFF0FFD0DCF0FFF0FFFFFF
F8A391DEF8E6D7DFF8B3F8F4F8DFF0E5E5DBECFFEFFFFFFF
EDF8FFF4F8F8F7F7F7F4F8FFF4FFF4F8FFF8F8F8F8FFF8FF
FFF4E1B3EEF4E2DFEFDEF8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFF8F8F8F8FFF8F8FFF8F8FFFFF8F8FFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5BB6CED3E15B
F0F4FFF7FFF7F7F4F8FFEEF8F4F8EEE5FFFFFFF8F8FFFFF3
E9F4E1F8E5E7F0DBE8BDA3C3D4EEE2CD73CDE5EEFFE3E8FF
FFF7F7F8F8EFEFE9DCF4FFF8ECFFFFE9DCDCE2E7E9E9F0FF
FFBFA477778DCED0C4B9E9DEE5E7DFF4E6D6EFEFFFEFFFFF
EDF8FFF8F4FFF4F7F7F8EDF8F8F8F8FFFFF4FFF8FFF8F8FF
FFF8E5BDC6F8F8E5E1E5F4FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFF8F8F8F8FFF8F8FFF8F8F8F8F8F8FFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0F0F0F0F0EEF4F8FFFFFFFFFFF845BDE5E5C155
E5FFF4F7F7F3F7FFFFF8F0F8F8F4E3F3FFFFFFFFFFFFFFF3
E3E7E5F8E1EEFFEDB9B9CEDEECE2CEA49FF8E8E9F0F0F0FF
E8E8F7EFF8E8E8E6DBEDFFF8ECFFF0D7D7D0DCE5F0F0FFF0
FFCBDEDDDBAB7094E8DFE5DDE8DEC6E5E5D7DEE7EFFFE8E8
FFF4FFF8F4F7F8F7F7FFFFEDF8F8FFF8FFF4F8F4FFFFF4FF
FFFFEDE2C8DBE7FFF8F8F8F4F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFF
F8F8FFFFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF0F0F0F0EEEEEEF0F8F8F4F8F8F8FFDE69AEE7EE947E
E8F8ECF3F7F3F7F7F7F4F4FFF8F4EEF7F7FFFFF8F4F8F7F7
D7EDF4E5E7EEF4C3CEE6E7F7F7C1DEA3D6DBCBFFE8EEE2F7
D7D7FFF3F4E8DEF7D7E8FFFFE8FFE3DBE5C4D6E5F0F0FFF0
F8D6DCFFF8F4DF67A5D4A3ACEDEFE7CFDFE5E5D6EDF7EFFF
EFF4FFF4FFEDFFF7FFF7FFF4F0F4F4F4FFF8FFF4FFFFF4F8
F4F8F4E5D7C4ACD1D6E5F8FFF4FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8FFFFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFF0F0FFFFF8F8F8F8F8F4F4F8F8FFE59584ABDED660C6
F8F3F7F7FFECF4F7EFF0F8FFF4F0F4E9E5FFFFF8F8F4ECEE
CCD6E2E1EEFFF09DF8EEE5EFF4BCCBD3CCD0CB8BAEDEE7C4
CCCFDFF7ECCEC6DDCFCDF4F4DDE3CFDFECD5ABD0F0F0F0FF
D6C5BDF8FFFFF8BC787F916390958DDED0BEE8CEC1D6F4E1
E8F4FFF4F8EFF7F8F8FFF7F7F4FFFFFFF8FFF4F8FFFFF8F8
F8F8F8ECE9DCA069A7C5DDEDEEF0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FF
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF4DE74A1D7F49B84EC
EDECF3F3F7F8F8FFF8EEFFFFEEF4F0F4D6FFFFF8FFF8ECEE
D1D0DBE8E9F4EE99DBEDF0E5EFC8AEF4D6CFBDE8CBD4E8E2
F4E8CCF0FFC5D6E2EED5DDE5D6DDCEDBEDF4E8D6DFF0F8F4
BDCD9CEDFFF7ECE5CEF0EDC89AA7B683CBE5E5ECDBD0E5ED
EFF8F8F4F8ECFFF4F8F8FFF7EFF8F8F8FFF8F8FFF8F8FFF8
FFF8FFEDE2E59D94CEE5D3D5EFE9FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFF8F8F8F8FFFFFFF8F8FFF8F8F8F8
FFF8F8FFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFDE9B5EAAEEFF70AEE8
F8FFF4F7FFFFFFF0E9F0F8F4F4EEF4F8D6FFFFF8F8F7F7E3
C1D4D1E8E9EEDEB5A9B2BDC7E5D6B9F8E5E5E5E8DECEDFF4
D4DBC4DBD1B4EFD6F8EDD3D0BDBEC4D6D6DBE5DFD4D6E1DB
ABD7ABD5F3EFF8DEDEDCFFECEEFFF89FC1D4F0F0DFC3DEF7
EFEDF8F8F4ECFFF4F8F8FFF7F7F4F8FFF4F4F0F8F4F4FFF8
F8F4F8F8E5EDBFB6DBE1EDE5CBCEF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFFFFFF8F8F8F8FFFFFFF8F8FFF8F8F8F8
FFF8F8FFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8D48D5982D7F8E25BDBE8
F4F8F4F7FFFFFFEEF8F8F8E3F8EEF8F8D6FFFFFFFFF7F4E3
C4D1CDF8DFDFDEE2CFC5B2918DB3DEEFF4F8F8EFE1D6C7C1
CEDBADC0C0B5D6D7E2F0FFE7ACC4DCE5D5DBD6DBD6D0D1CC
BCE5B6C9F4F8E7BDE5E5FFE8F4E7EFD1DBBAF7E5E8CDC5EF
F8EDF8FFE9F3FFF4F8F8FFF3FFF4F8FFF8FFF8FFF8F8F8FF
FFF4F4FFF3D7D6E8DFF4EDE8E5DBDFF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8DEA36363B4E8EDF3B96DEDED
F4FFF7F7F7F4F4F0F8F4F8E9F0EEEFEDD6FFFFFFFFF7EDE9
D1B9DCD6E5DEE8DDE2DCD6D0B9A8A2BAC9C6D0DCDCF4DDD6
ECEDEFD3E1EDEDDBCABDB4BDC9E2E8EFEFF4DBD0D6D6D1D3
DEF7D3B2EEEED6C9C5EFF4E1F4E5EDDBDBB9DCEFE7DFBCD7
EDEDFFF8EEECFFF8F4F8FFF3F8F8F8F8F4F8F4F8FFFFF4FF
F8F8F4FFF7D7BEF4E5D6D6F8EEF4E5E5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8DF746184C9E3EEE1F78682E8ED
F4FFF7FFFFF4F4F0F8F4F4F4F4F4E8D6E8F3F7FFF7FFEDEE
D0B8E8CBF0E5ECE2FFF8EDE1DBDED7C5CBDCD3D1D6CFC4C4
CBDBCAB8CADBDBDBE8EDEDDBCCE8EDE2F0F8F4FFE8D6D6E1
F4FFF8B6DDDDC6CEC5D6E8D6F0F0F4DBE9B3D1F8EDDFCEC3
EEE8F8F4F4E8FFFFF8F8FFF7EDFFFFF8F8F4FFFFF8F8F8F8
F4F8F0F8FFDBA8F4F8FFD0E9EEFFEFE8F8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8FFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF89856BCD6ECE7F8EDEF67ADE7F7
EFF7F7FFEFF4EEF8FFFFF0FFF0EFF4D6F4F7FFF3EFEFEDF4
D1BFF8B9E2EFF4EEF8EFF7FFF7F3ECECECE8E1DCDBE3E9E2
DCD3D6E9E2D6E5E2DFDFFFF0F0EFEDEDDFE9E9E8EDE7F8EE
EDE8ECCBD6D6C5E5DBC5E5D0D7D7F8C8E8B3D1F8F8EFD6C5
C2F3F8F8F8E5F7FFF8FFF8FFE8FFFFF4F8F0F8FFF8F8FFF4
F8F8F4F4FFE8B4C1EFF4DEE1E5F8F4E5E5FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8FFFFFFF8F8FFF8F8FFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF0E9DB2D95DFF4EDDEF4EDC456D6E8F4
F7F7F7F7F8F4EEFFF8F0F8F4F8EFECE5F4F7FFF7F8FFF0F0
DCCECED3BDE7F8E5E5F4FFF8F4F8F4F8F8F8F4F8F7ECE1DC
DCD6D6DCDCD3DBD0D4D0B9C6CBD1D1D1C8CAD1CCDBDBCCC9
C6D0E1EDE2CBDFFFE7BEBDC3CDC4ABB6CBCED1F4F4E7D7F7
ADB4E7F4F4F4ECFFFFF4F4FFECF8F8F8F8F8F8EDEFFFFFF4
FFF8FFF0F8ECC86E4E99DBF4F8F3EDEDEDF0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE9FFD21CF0EFECEDF8F0EC9673F7F8F7
F8FFFFFFFFF8EEFFFFF4FFF8F8F4EEF8F4FFF7EFF8F4EEF8
E1F4D3F0C0E1EEE8EFFFF8F4F8FFFFF4F8F8F4F8FFFFF4FF
FFFFF8F8F8F8EDE8ECF8F4F4FFF4F8F8FFE8E1DEE5E1DDED
FFF0E9E9E8E2DBE8E8EDEEEEDBE5DDE6E8F0DBF8DFE7F0E8
E89DF7E8DEF8EDF7FFEEEEF7EFF8F8F4F8FFF8EDEFEFEFF4
FFF4F8F8F4ECC8B4A7A3D1F4EDEEDEE5F8E9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDBD2A53CF3F4F4F8F8EFFF7694F3F4F7
F8F7F4F8F8F8F8F8F8F8FFFFF8F8FFFFF4FFF8FFFFF8EEF8
E1F8E5DEDEC5DEEEF3F8FFF8F8F8F4FFFFFFF8F8FFFFF8F4
F8FFF8FFF8FFF8FFF4E7EEEEF4EEF0FFFFF0F8E5EFF4E3DB
DCE1E8ECE5E8E6DEDEE3F8F4DFCFCFE2DFDBCDD0E2F0E9DD
E29DF8EDE5F4EDF7FFEEEEF7EDFFFFFFF4FFF4EFEFEFEFF4
FFF4F8F8F8E5E19BDB7389E8F8F4EEF4EEE9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFDBABB66DF7EDF8F4EEF3E559C1ECFFFF
F8F4F7F8F4FFF8FFF8F8F8F8F8F8F8FFF4FFF8FFFFF4F0F0
E1F4F4E1F4C9D6DBF3FFF8F4F4F4F8FFFFFFF4F4FFFFF8F8
F8F4F4FFF4F7FFF4EFE9F8F8F4F8F8F8F8F8F4F8EFECF3ED
F8F0F4F0F4EDECF3F3ECE1E2E3DECBBFBAB5A7AEB8B8CFDB
D4C8E3F3F4F4E8EFEFF4F4F7F8EFF8F4F8F8F8EFFFE8E8E5
FFF8FFF8FFE8F78BEDD66295EDF4FFF0E9E9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE958A9BDC19D8490A4BCCE5BE1ECF8F8
F8F8F8FFF4FFF8F8F8FFFFFFFFF8F4F8FFF8FFF8FFEEF4EE
E1F4F8E7DFE8D0DBE5EFFFFFFFF8F8F8F8FFF4F4FFFFF8F8
F8F8FFF8F7F4FFF7F7EEF8FFF4FFFFFFF7F7FFF7F7FFF7ED
F8F8F8FFF8FFF4FFFFFFFFF7F3F3EFEFF3ECEDE8E9EEE5E1
E5EFE6E5E7EEE8E8E8F4F4F3F7EDF4FFFFF8F4F8EFE8EFE1
F4F4F8F8F8E8F891C6BAE8739AEEFFF0F0F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE939C59C7086AEB2AA92B274EFF7F7FF
F8F8FFF8F8FFF8F8F8FFF8F4F8F8F8FFFFF8FFFFF4F8FFF4
E5F0F8F8E1F8CCD3F8E5F7F7F7F8F8F4F8F4FFFFF8FFFFF8
FFF8FFFFF4F4FFF7F7F8EEF8F8FFFFFFF7F7F8EFF7FFF3F8
F8FFF4F8F0F4FFF8F8F8FFFFFFFFF8F8FFFFF7ECE8E5E9EE
E9E3EEF8EFDBE8E8E8F8F8F7F7F4F4FFF8F4F4F8FFFFEFEF
F8F4F4FFFFE5EDB9E8DDB6BE91D7F0F0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8EE33D653DBF8F8EEE7CEBFA7EFE8EDF4
EFFFF8F4FFFFF8F8F8FFF8EEF8EDF3EFF8F7F7F8FFF4F0F8
E8F4F4FFE5E7EDBDF8EEEDF8F7FFF8FFF8F8FFFFF8FFFFF8
F8F8F4F4F8F8F8F3F8F4E6F8FFFFEFECF7FFF8F8F7F3F7F8
F8FFF4F8F8F8F8F4F8E7EFF8F8FFFFFFFFFFFFFFFFECF4ED
EDEDEFE8EFD6E1E8EDF4F8FFECF0F8FFF8F8FFFFFFFFEFEF
F4FFF8FFFFF4E59FBEB9CBC4D3BDF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEECE4FB58DF7FFF8F4E8E5E5DBECF4F4F4
F7F4F8F8FFFFF8F4F8F8F8EEF0F4F3F7FFF7F7F8F8FFF4F8
E5EDF4FFF4EFEFC4E5F4F8ECFFF8F8F4F8F8F8FFF8FFF7F7
FFF4F8F8FFFFF4F3F8F8EEF8EFEFE8EDF7FFFFFFF7F7F8F0
F4F4F8F8F8F8E5EDFFE8EDE8E1ECF7FFEFE8EFFFFFEFEFEF
FFFFEFFFE8D6E8DEE2F4F8F7EDF8F8F8F4F8F8F8FFFFEFE7
F8FFF8F0EEF8EC8BF894CBF0DCC1F8FFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8EEAABDA1DEF7F3F7F7ECE7F8E8F7F4F4F8
F8FFF8F8F4F4EFF7F7F7F7ECF4FFF7F3F7F7F7FFFFFFF4F8
EEECEEEEF0F4E7E8D7DEE8EFF3ECEFF8F4F4F4FFFFF4EFF7
FFF8F8F4FFFFF8ECF8F8EEF8EFFFEFEFECF7FFF7ECEDF8F8
F4F8FFF8F8EFFFF8F3F4F8F4F8FFEDE8F7F8EDECECF7FFFF
E8EFEFEFFFDBF8D4C4FFF7F7F4FFEEFFF8FFF8F8EFEFFFF4
FFFFFFF8F4EEE16DC58AA7CADBDFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F0DFB9DFF8F4F3FFF3F3F8E5F8EFECF4F4F8
F4F4F8F8FFFFF3F7FFFFFFF3FFF7F3FFF7F7F3F7F7F7EDF8
F0EFF3EDF4FFF8EDDEE5E7E8F8F7EDFFFFFFFFF8FFF8F4FF
F7F7FFF8F8FFFFEDEFF8EEF4F4F4F8F8F0EFECEDF8F8F4F4
F4F0F4F8FFEFF8F7FFFFEEF8F8F8FFFFF8F8F8F8F8EDE8EF
ECEDF8EDDBF0F0D3BDECEFF4F8FFEEF8F4EFEFEFFFEFFFF4
FFFFFFFFFFF0E856F4A99FA1D4FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8EEC8EFF8F8F8F3FFF3F7EDE1F8EFF7F4F7F8
F8F4FFFFFFFFF7F3FFF7F7F3F7F7F7FFF8F8F7F7F7FFEDFF
F4F8F8ECF0F8FFE7EFE8E5EEF0EFEFF8FFFFF8F4FFF8F4F7
FFFFF3F4F8FFF8F8F3F4F8F4E5F4F0F0F0EEF4FFFFF4FFFF
F8F8FFEFEFEFF4F8F4F4FFF8FFFFFFFFFFFFFFFFFFFFFFEF
EDEDF4F4DBF0DFF4CEF8F4FFFFF8F0F4F8EFEFE8E8FFFFF8
F4F8F8F8FFF0F063F4C0BEA7BDF8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE9B9F8F8F7F7F7F7F3F7F4E1FFE8E8EDFFEF
F4FFF8F7F7FFF7F3F7FFFFFFF8F8FFFFF4F4F8F8FFF3F4FF
F4FFEDF7F8F0F8F8F8EEE8EFF0F0ECF4FFFFF8F4F8F8F8F7
F7F7F3F4F4F4F8FFF7EFF4EEE7F4F0EEEEF4FFF4EEEEF4F4
F8EFEFECF4F4FFF8FFFFF8F8F8F4F8FFFFFFF8F8FFFFFFF8
F8FFF8ECF0F0EFDEF4F4F8FFF8F0F8F8EDEFFFEFFFEFFFFF
F8F8F8FFF8F0E762F8C5B3C6B2EEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDBC4F8F8F3F3FFF7F7F4E1DEF0EFF7FFEFF7
F8F8F4F7F7FFF3FFFFFFF8F4F8F8F4F4F8F4F4F4FFF7EFF4
F0F8EDF3F7EEF8F8EDDFE8ECF8EEE8F8F8FFFFFFFFF8F8FF
FFFFFFF7F3F3F7FFEFEDEEEDEFF4FFF4F4F4F0F4F8FFFFFF
EFFFFFF4F8F4FFF8FFF8F8FFF8F4FFF4F4F8F8F8FFFFF8FF
F8F8EDEFFFFFF0F0FFFFF8F8F4F8F8EDF8EFFFEFFFEFFFFF
F4FFFFF8F8F0E756E5C58C82668DF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0BCDFF4FFF3ECF4F4F4E8E5ECE2EFF4F8FFF8
F4F8FFF8FFF7F7F7F7FFF4FFFFFFFFF0F0F8FFFFF8FFF3F8
F8F4F8F8F7E5F8E7FFEDEEE7EFE9E8FFF8F8FFFFFFFFF8F4
F4F3ECF4F8F8F4ECEDFFF4EDEFF8F4F8F8FFF8DDECEFFFEF
FFF8EDF8F8FFF8FFF8F8F8FFFFFFF4F8F8F4FFFFFFFFF8FF
F8F8E1FFF8F4EEFFFFFFF4F4F4FFF8E7EFFFFFEFEFFFFFFF
F8F4F8FFF8EEF04CFFF7DED7A36DF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0CFCBFFF4F7F7E8F8F4F4DEEDF8D6F7F8F7F8FF
F8F4F8F8F7F7FFF7EFF8F4FFFFF0F0F0F0FFF8F8F8F4F7F8
F8F4FFF4FFECF0DFE7F4F4F4E8E9E8FFFFF4FFFFFFFFF8ED
E7EEEEF0F8F8FFFFFFF8F4F8ECF8FFFFFFEEEEDDEDEDF7EF
E7EFECEFFFFFFFF8F8F8F4F8F8F4FFFFFFFFF8FFFFFFFFF8
FFEDEFF8F0F4F8F8F8F8F8F8F8FFFFF4FFFFFFFFFFF8F8FF
F8F4F8F8F8F4E957F7FFEEE86D89FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCEF7F4F8F7F4E5EEEEE5EFF8E5E2FFECECF8F4
FFEDF3F3F7FFFFFFF4F8F8FFF0F0F0F0FFFFFFFFFFEDF3F3
EFF0F4F0F8F3F8EEFFE5E5F4DED7DEF7F8F8FFFFFFF8E7ED
FFE8E2E5EDEDF7FFF8F4F4FFEFEFF4F4F8F0F0E8DEEDF4E8
E5ECECE7F4F4F8FFF8F8FFF8FFF8F4F7F8F8FFF8FFFFFFFF
EDD7E9E6EEF8F8FFF0FFF4F8FFFFFFF8F8EFEFFFFFF4F4F8
F8F8F8F8F8F4F079D7D1CC8962B6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF0BDF4EFF7FFF7EDEDF4E3E1F0F8E1E9FFEDF7F8F4
F8F4F3F3F7FFFFFFF4FFFFFFF0E9E9FFF0F0F0FFFFF8F8F7
EFF8F8FFEEF7F4EEFFE7EFFFF8E5D4ECF4FFFFFFF8EFF4ED
ECFFF7F3F3F7F4F8F7EDF4F0FFEDF7F3FFF4F8F8F8E5DDED
EEEEF8F4FFFFF4F8F8F8F4F8F8FFEDFFEDF8F8FFF8FFFFEF
E7E6F4F8F8FFFFF8F4F4F8F8FFFFFFF8F8EFEFFFFFF4E5E7
F4F8F4FFF8E8DD84E5EFC56EADDFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE9C4FFF7F7F7F7F4EDDEDFF4F4F8E1E3FFF4F8F8F8
F4FFFFFFF3F8F8F8F8FFFFFFFFF0E9F0E9F0F0FFFFFFF8EF
EFF8F8FFF4F8EFE5F0FFF8FFF8F4D1EDEFF8FFF8F8F7F3FF
F7F7F3F7F7F3F3F3F7ECFFF8F0F8F8F7F7F4FFF8F4F4F8D6
DBF4E9F4FFF8F0F0F4F8F8FFF4FFF4F4EFFFF4FFF7E8E1E5
F0EEFFFFF8F8F8F8F8F8F8F8FFFFFFF4FFFFFFFFF8FFEDE7
F4F8F4FFFFE2C884F0E1BA8899B4F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFD4D2F8F8F8ECF8F8DBDEEDF4EEFFDBEEEDF4F4FFF4
FFF8FFFFF3F8FFF8FFFFFFF0F0F0F0F0F0F0F0FFFFF8F4EF
F7F4FFF4FFF8F8ECF4F8FFF8F8F8D0F0ECF4F8F8F8F8FFF7
F7FFF8F8FFFFF8F4F8F7EFFFEEFFF8F8F3F8F4F0F8FFF8FF
E7D3D0F0F4EEF4F8F8F8FFF8F8F8F8F8F4F4FFF4E8FFEEF4
F8F4F7F4F8FFFFF8F4F8FFF4FFFFFFF4F8F8FFFFF8FFF8F4
F8FFF8FFFFE9C097FFDFBC86675BB5F4F4F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8BDEFF8FFFFECF4F8D0ECEEEEEEF0E1F4EFFFEFF4FF
F8F8F7F3F7FFF8F8FFFFFFF0FFF0E9F0E9FFF0FFFFF8F8F7
F3EFF8F4F8F8F8E7EDF0F8FFFFFFD6F0E7E7F8FFF8FFF8FF
FFFFF4F4FFF8F8FFF8F8F7ECE7F8FFF4F3FFFFF4F8F8F8FF
F8FFEDCEE8EFE5EEFFF0F8FFF4F8FFFFEFEFF4F7EFF0F0F8
F4F8F3EFF4FFF8F4F4F8F8F8FFFFF8F8F4F4FFFFF8FFF8F8
F8F4F8F8F8E5AEA8F8F8F4EEE57A6AA7DEEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE5BDF4F8F8F8F3F4E5CBDEE6E6F0E8EDF4FFEFEFF4F8
F8F7FFF7FFFFF8F8FFFFFFFFF0F0E9F0F0E9FFFFFFFFF8F8
F7EFF8F4F4F4FFF4F7ECE7F8FFFFE2EFEEEDF7F8F4FFF8FF
FFFFF8F8F8F8F0F0FFF4FFF7EDF4F8F8F3FFFFF4FFF8FFF8
FFFFF8F4E5E5EFEDF4F8F8FFF4F4F8FFF8F4E7E5F4EEF8F8
FFF7FFECF4FFF8F4F8F8F8FFFFFFF4F8F8F4FFFFF8F8FFFF
FFF8F0FFF0ECADAFE2E9E8FFEDBC9B9DACDBF8F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8C3D6FFF4F8F8F3F8CBD6D6E5F8F4DCEEF8FFFFF8F8F8
F8F7F7F3FFFFF4FFFFFFFFFFFFF0FFFFF0E9FFFFFFFFF8FF
ECF8F8F8F0F8FFF8F4F3EDF8F8F8EEF3E3EFF7F8F4F8FFFF
FFF8F8F8F8F0FFFFF0F4F7F7EEF0F8FFF3FFFFF4FFF8FFF4
F4F8FFFFFFFFF4EFE7F8F8F4FFF8FFF8F4F7E5FFF8F0FFF8
F7FFFFECF4FFFFF8F8F8F8FFF8F8F8FFF8F8F8F8F8FFF8F8
FFF8F0FFEEE5C4BDC4D2DBD4DEE2BDC59DA5E5F4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFD6C3F8F8F8F4F4F4CBE5D7D6DEEFE8D6F0FFFFFFF4FFFF
FFFFFFF3FFFFF4FFFFFFF0F0F0F0E9E9F0FFF0FFFFF8F8F4
F8F3EDF8EEEEF4F8E8FFF8EDE7F0E7E5EEEFF7F7F7F7ECE8
ECECF4F4EFF0F0EEE6F8F3F8EEEDECE8E5E9E9EEF4F8F8F4
F4F8F8F8F8F4FFF8E8F4FFFFF4FFF8F8EFEFEEF4F0F8F8F8
F3F3F3F7F7F7F3EFF4F8F8F8F4F8F8F8F8FFF8FFFFF4FFFF
F4F8F8F8F0E5C4E5F4E1F8E8F0F4D6BD915B569DF0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8B6E7FFF4FFF7EFE8E1E8CBE1F0E1E9E1F8FFF8F4F8FFFF
F7F7FFF3F7F3EFF8FFFFF0F0E9F0FFF0F0FFF0FFFFF8F8F7
FFECF7F8F8F8FFF4E8F7F3FFF8ECF4E9F8EDFFFFFFF7F4F8
F0F4ECF7F4F4EDF4F7F3E7EEF0E5F8F8F8FFFFFFFFFFFFFF
FFF8FFF8F4FFEDEDECEEF8F4F0F4F8F4E7EEF0FFF4FFFFF7
FFFFFFF7FFF7F3F7FFF4FFF8FFF8F4FFFFFFFFF8F8F8FFFF
F8FFFFF0FFE5C4E7EEDEDEDBDBE5F8F4F7E39B96E9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EEB3F8F8F4F8EEDEDDF8F0CDFFF7D6E7E5F8FFEDF7F7F7F7
FFF7F7F7F3F7EFF8FFFFFFF0FFF0E9F0E9F0FFFFFFFFF4FF
F3F8F8FFF8F4F8F4EFF4FFF7F7FFF7D7F4E7EFFFFFF4F8F4
F8F8EDF3F7EFF8FFEFF8EEF8F4E8FFF4FFF8F8FFFFF8F4F4
F8F4F8F4F8FFEFFFEDEEF4FFF4EEF4ECF4F4F8F4F8FFFFF7
FFFFF7FFFFFFFFFFF8FFF8FFF8FFFFF8FFF8F8F8F4FFFFFF
F8F8F8F0FFE5D1ECF8F4DEE1DBC5DBDFCC8271BEE9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E2B9F8F4F4D6D6DEE6D1C8E7EFF8D4ECEEFFFFEDEFEFFFFF
FFF3FFF7F7F7F8F8FFFFFFE9E9FFF0F0FFFFFFFFF8F8F4FF
F7F7FFF8F4F4F8F8F8F4FFF8F4F4EFE2E7EDF4F7FFEDF8F8
FFF4F4FFF4F7F7F4F4F4F4EEF8ECF8F4FFF8F8E7E5F8FFF8
FFF8FFF7F7FFEFEFF8F8F4FFF4EEEDE7F0F8F4FFFFF8F8F7
FFF7FFFFFFF7F7FFF4F8F8FFFFF8F8EEF8F8F8F8F4F8F4F8
F8F8F8F0F0F3C4F8ECF7FFF0EED6C9C9847BC4E9F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C9C1F4FFD7C5D1C9CBE2F4F8EFDEEEECEEFFF8FFFFF8F7FF
FFF7F7F7FFF8F4F8FFFFFFF0F0FFFFFFFFFFF8F8F8FFF8FF
FFF3FFF8F8F8F8FFF4F4F8F8F8F8F8F8E9ECF8F7F7F8EEFF
FFEEFFF8F8FFFFFFF8F4F4F0EFF4F4F4F8F4F4EDEFFFF7EC
ECF3F3F7F4ECEDF8F8FFF4F8F0F4E8F8F4F8F8FFFFF4F4F7
FFF7F7F7FFF7F7FFF4FFFFFFF8F8F8F4F8FFF8F8F8F8F8F4
FFF4EEFFF0F3C4EFFFECEFEFEFEFE2AA7BD7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
B2E2EEF4D1DCFFE2F4F8FFF4E8E9F4ECEEFFF8FFEFF3F3F7
F7F7F8F8FFF8F4F8FFFFF0E9EEF8FFF8F8FFF8F8FFF4F7F7
F7EFF8FFF8FFF0F4F8F4F4FFF4F8F4E5EDF3F8EFF3F7EEF4
EEF0F8EFF3EDF8F0F4F8F8F4F4FFF8F4F8F8FFF7F3F7F3F8
F4F4F4F8F8FFF8F4FFFFF8F0F8E7E7FFF4F4FFF7F7F7FFF3
FFF7F3F3F7F7FFFFF4FFF8F8F8F8F8F8FFF8F8F4F4F4FFFF
F8F4EEF0E2F7C4E8E8F4F4EDECF7DE9FC4FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6
C1F8F8EED0E1F8EDEFF8F8EEE5EEF4E8F4FFF8FFECF7F3F7
FFFFF8F8FFFFFFF4FFFFE9F0EEF8FFF8F8FFFFFFF8F8F7F7
F3F4F8F4F4F8F4FFFFF8F8F8F8F8EDEFF7F7F4F8F8F3F8ED
ECF3F3F7F7F4F8F8F8FFF8F4F7F4FFF4F8FFF8F3F8ECF3F4
FFFFFFF4F8F8F8F8FFFFFFEEF4E8F8F8F8F4FFF3F7F3F7FF
F3FFF3F7FFF7FFF8F8F8FFF0F4F8F8F8F8FFF4F8F8FFF4F8
FFFFF8EEE5FFB9FFFFF4F4F8F7EFD796EEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6
DCFFFFE9D6E7E5EEF8F4F4EEE1F8E8EDF4FFEDEFF7F4F7F7
FFFFF8F4F8FFF8F8FFFFF0F0F0F0FFFFFFFFF8F4F8F7F7FF
F3EEF8FFF8F8F8F8FFF8F4F8F8FFECF8F4F4F8FFF8EDECF7
FFFFFFFFF3FFF8F8F4FFF4FFECF8F8F8F4F8F8F3F8F4F7F4
F8F4F8F8F8F8F8F8F8FFF0F8F4EFF0F8FFF4FFF7F7F7F3F7
F7F3F7F7F7FFFFF4F8FFF8F8F8F4F4F8FFF8F8F4F8F4FFF8
F8FFF8EEE7F7B9F8F8F8FFEFECEFD796EEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7BE
E7FFF8E5DBF8ECF8F4F8FFF0E1F0E5F4F4FFEDEFF7F4F7F7
F8F8F4FFF4FFF4FFFFFFFFFFF0F0FFFFFFF8F8F7F7F7F8E8
F4F0F4FFF8F8F8F8FFF4FFF8F0F8E8F8F4F4F8FFFFFFF8F4
F8FFFFFFF7F7F8F8F4F8F8F7F4F4F8FFF4FFF7F7FFFFF8F8
F8F8F4FFFFF8EEF4F4E2E5E1DBEEF8FFF8F8FFFFF3F7F3F7
FFFFFFF7F7FFF8FFFFF8FFF8F8F8F8E5E5FFF8F8F4F4FFF8
FFF8FFF0E7F7B3F8F8F8EDF7FFF8E3A6D0F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B2E5
FFEFE7E5DBF4E7EFF4F8EEEDE5EEECF8F4FFF8F7F8F7F7F7
F4F4F8F4F8F8F8FFFFFFFFFFFFFFFFF8F8F4F7FFF7FFECF4
FFF4F8FFFFF8FFF8F8F8F8FFFFF4E1FFFFFFF8F4F8FFF8F4
F8FFFFFFFFF3F8F8F8EEFFF7F4EEFFFFF4FFF7F7FFF8F8FF
FFF8F8FFF8F4F8F4EDF7F0F0FFFFF8F8F4F7F3F3F7FFFFFF
FFF7F7FFF3FFF4F4F4F8F8F4F8F8FFE5EDF8F8F8F8F8FFF8
FFFFF8E9F3F7BAF4F4F8EFEFF8F8F0B2BAF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4C4FF
F8E8E8E9DCFFF4E8F8F0EEE8E9F4E8F8F8F8EDFFF4F7F7FF
F4F4FFFFF8F8FFF8F8F8F4F4F8F8F4F8F8EFF7F7ECEFF3F8
F8FFF8F8FFF8FFF0EEE9EEEEF4FFDCFFFFF7F7FFF4F8F8F8
F8FFFFFFFFECF8F8F8EEF4F3EDF4FFF8F8FFFFF3FFF8F8F8
F4F4F4EDF4F7F3ECEFF8F4F8FFF8F8F8F8F3FFFFFFF7F3F3
F7F7FFF7F3F8FFF8F4F8FFFFFFF8FFF8F4F8F4FFF8F8FFFF
F8FFF8E9F3F7C4F8F8F8FFE1F8FFF8B9A0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0C1DEF8
F4E8ECE6DDF0F4E8F8F8F4E8E9EDEDF4FFF8EFF8F4F3FFFF
F4F8F4F8F8F4F8F8F8EDF7FFF8F8FFFFF7FFF7FFF4EFEDF8
FFFFF8F8F8F4F8F8F8FFFFEEF8F8EDEFFFF7FFF7F8F8FFF8
F8FFFFFFFFEFF4F7EDF4EDF4F8F8F8F4F7F7FFF3FFFFF8F8
FFFFFFECEFF7FFF8F4F8F8F8F8F8FFFFFFF7F7FFF8EFF3F7
F3FFF3F7F7F8FFF4F8FFF8FFFFF8FFF8F8F8F8FFF4F8F8FF
F8F8FFE9F3FFCAEDEDECE8E5FFFFF4DE82F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4CBE6F4
EEE8F7E2DBD7EDE8F4F8F8E8E9E8F4F4F8F8EDF8F8F7FFFF
F4F8F8F4F8F8F8F4F4F4F7FFFFF7F3ECEDEFEFF8F8F4F4F8
FFFFFFF8F8FFFFF8F8F8F4FFF8F4F8F4F7F7FFFFF3F7FFFF
FFFFFFF7F7F7F7F3E8EEF8E8F8F8F4F8EFF7FFF7F7FFFFFF
FFF8F4F4EDF8F8F8F4F8F4FFF8F4F8F7F7F7F7FFF8EFF7F7
FFF7F3F8F4F4F8FFFFF8F4F8F4F4FFF8FFFFF8F8FFF4F8F8
FFF8FFE9F3F7DDE7EFF8F8F4FFF8EFED94C9F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB9E5DBE8
D7E5F8D6D6E5EFECF0FFF8E8E9E1F8F4F8FFF4F4ECFFFFF8
F8F4F4F4F4F4F7F7FFFFFFFFEFF4EFF8F4F8F4F8F4F4EEF4
FFFFF8F8FFF8F8F4FFF4FFF8F0F8F8F8F4F8F7F3F7F7F7F7
F8F8FFF7F7F7F3FFEDEEF8ECF0FFF8F8F8FFFFFFF3FFF8F8
F8F7EFEFEFEDEFF8F8F8F4F8F8F8F8F3F3F3FFFFF7FFF7FF
F7FFEFF8FFF8F4F8FFF4FFFFF8F0F8FFF8F8F4F8F8FFFFF8
FFFFF8E2F7F3E3F8F8F8F4F4FFE5F4EDA3A7F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAEEED6FF
C6EFD6CEF4E6FFECF0F8F4EDDDE1FFF4FFF8F4F8F7F7FFF8
F8F4F8FFF8F4F4F4EFFFF7F3F4EFEDF8F4EEF4FFFFF8F0F0
F8F8FFF4F8F4F8FFF8F4F8F4F8FFFFF4F4EFF7F7F7F3F7F3
F8F8FFFFFFF7F7F3F8EEF4F7EDF4FFF8F8FFFFF7F7FFF8F8
F4F8F7EFEFEFE5F8FFF8F8FFF0F8FFF7FFF7F7F3FFF7F7F3
F7F3F4FFFFF4FFF4FFF8F8FFFFF8F0F8F8F4FFF4F8FFFFFF
F8FFE8E5F7FFCBEFF8F8F8FFEED0F8F8B68DF8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7B4CFC5DE
DEBAC9DEBAA7C4E8F4FFF8E8CFEDF8F8FFFFF8EFF7F3FFFF
F8F8FFF8F8F4F4E5EFFFF7F3F7F8FFF8FFF8FFF4F8F4F4F4
F4EEEEE9F4F8F4F0EEEEF8FFF8F4F8F4F4EFF7F3F7F7F7F3
FFFFFFFFF7FFFFF7F8F4F0F4F4F0F8FFF4F7F7F7F7FFFFFF
F7F7F3ECECFFF8F4FFF8FFF4F4FFFFFFF7F3F7F7FFF3FFF3
FFEFF8F8F8F4F8F8FFFFF8F4F8FFF8F8F4F8F8F8F8FFFFFF
F8F8F0E5F7FFA3C4C8DEF8EEE6CBF4F8DE89B5FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8BDC4C5FFE2
D7E5F8CDCDF8F7DDE8F4F8DCD1F4F4F8F4F4EFF7F7F7FFFF
FFFFF8F4FFF8F8F8F7ECECECEDF4FFF8FFFFF4F8FFF8F8F8
F4FFF8F4F8FFFFF8F8FFFFFFF8F4F8EDEFECFFEFF8FFF7F7
F7FFFFFFF7F7F3FFF4FFF4E8F8F0F8F8F8ECEFF3F7FFFFFF
FFFFF3F7F7FFFFF8F8FFF8F0F8F8F4F7FFFFF8EFF7FFF3F7
FFEFF4FFFFF8F4F8F8FFFFF8FFF8FFF8FFFFF8F4FFFFFFFF
F4FFFFDCFFF791FFE7C5DEEEEED7E5F8F8C386F0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6C3C5D6E1DE
E5D6D7A3DBEEF8F8E5ECEDD6DDEDF4F8F4F4ECFFFFFFFFFF
FFFFF8F8F4FFFFFFF7EFFFF0F8F8EEEEEEE9F4F8FFF8F8F4
F0EEF4FFFFFFF8F8F4F8F8F8F4EDE8FFF4F3F7F8EFF7F7F7
F7FFFFFFFFFFF3F8F8F8F0ECF4F4FFF4FFECF8FFFFFFFFF8
F8F7F8EFF8F8F8F8FFF8F8F8F4FFF4F7FFF8F8F8F8F8EFF7
F7F7F8FFFFF4F8F8F8FFFFF8F8F4FFF8FFF8EDEDEFEFFFF8
F8FFF8E1F7F397F4F8DBDFE5F0E6ECF8FFE77BD4FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8BDDECBE5F8E2
F4DCB4EFCBF8EEF0F8F0E5D0DDE5F0F8E8ECECF7F3F3F7FF
FFF7F7F8F8F7F3F7FFF7ECE1EDF8F4F4F0F4F0F4FFF8F8F8
E5E1E8EDEDF8F4F4F8FFF8F8F4EDE8F7FFECF7F7FFEFF4F3
F7F7FFF7F7FFECF8FFF4F4F3F4F4E7EDFFF3FFFFF8F8FFF8
FFECEFEFF4F4F8F8FFF4FFFFFFF4FFFFFFF8F8FFF8F8F8F8
FFF8F8F8F8F8F8FFFFF8F4F4F8F8F8FFF8F8EFEFEFEFF8F8
FFFFF8E5FFEDADF8F8E1E6E1FFF8EFECEFFF90B2FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E9B2E8C1EDF7D0
CBC9EFBECAE6F4F8F8F8E5CAD1E9F8FFF7F4F3F7F3F3F7FF
F8EFFFF7FFF7F3F7FFFFFFFFECEDE8E1DBDCE1EDE8DCE5EE
E7F3FFF7F4E1E8ECEDF0F4F4F4F8F8FFF7FFEFFFF7F8F4F3
F7FFF7F3F7ECEFFFF8F0F8ECF0F0EDEFEFF8F7FFF8FFF4F8
F8ECFFFFF8F8F8F8FFF8F8FFFFF8F4F4F8FFF4F8F8FFFFF8
F4F8F8F8FFF8FFF8F8F8FFF8F8F8F8F8F8F8F4F8EFEFF8F8
FFFFF8E5F7E5B2EFF8E1E6E5E5E7F8F4E5F4BD8DF8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8CCBDE5C4E1F4B9
D6DDBCFFBDF4F8F8F8F4EEC4D1EEF4F8F4ECF7FFFFFFFFF7
ECF4F7FFF3F7FFEFEFFFF8F4EFFFF7F8F8FFFFF3F3EFEFFF
EEF4EFF7F8F4F8F8EDE1E1EFFFF4F8F8EFF7F4F7F7FFF7F3
FFF7F7F3FFF8F4F8F4F4F7EDF4F4F7ECFFF8EFF8F8F8F8FF
F4ECEFEFFFFFF4FFF8F8F8F8F8F8FFFFF8F8F8F8F8F8FFFF
F8F8F8F8FFFFF4F8F8FFF8FFF4F8FFF8F8F8F4F8EFEFFFF8
F8FFE5EFE7E2BAF3F4EFEEE7EFE1F8FFE8F8DB84E5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0D0DBD6DCDBB6
E2A4ECDFE1CEC4DEF8E9F4BED6F4EEF8F3EFEFFFFFFFF8EF
F3F7FFF7F3F7F7F8FFE8E1E1F4F3F3FFFFFFF8EFF7EFE8E8
E7F4EEF7F3F7FFF4FFFFF8E2DBE5F8F4EDF7F4ECFFF3F7F7
FFFFFFECF4F8F8FFE9EFF7F4F4F4F7ECFFF4F4F8F8FFF4F8
F4F4F4ECFFF8F8FFF8FFF4F8F8F0F8F8F8F4FFF8F4F8FFFF
F4F4FFFFFFF8F8FFFFF8F8F4FFFFFFFFF8F8F8F4F8FFF7F4
F8FFE7E5EDF0C6ECEDECE8D6D1CDDFF8EFE5E190CBF8FFFF
FFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8C0C4CDF8CDB3B6
DECBB49FB6C6D3F4D6F0F4BED6EEF0F8F3EFFFEFFFF7ECEC
ECECF3F7EFE8EDE8EDF8EDE5F4F4F4FFFFFFF8FFF4F7FFEF
FFEFF0EEF8F7F3E8F8F8F4F8EEDBD6DFE5EFFFE8FFF7F7FF
FFFFFFEFEDFFFFF8E6F7F3E8F8F8F8F7F4F8F8F4F8FFF8F8
FFF7F3F7F8FFF4F8FFF8F4F4F4F0F0F0F8F8F4F8FFFFFFFF
F4F8F4F8F8FFF8F8F4F8F8F8FFFFFFFFF4FFF8F4F8FFF7F4
F8FFE7EDF0F0C6E8F8E2D6DCD6C4B9C3DCFFF89CA4F8FFFF
FFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEB6C1D6E1DD96CB
C5F0B2F4B9C6D6D6DCF0E6C4D1E9F8F8F3EFFFF8F7F7F3F3
EFFFEEE2E5F4F4F0EEDDD6EFEFECE5E1E1E8DBCBC8CFCAC1
C1CFD0D6F4FFEFEDF8F8F8FFF8F8F0DFE7F8F8ECF7F7FFFF
F8F8FFF7F7F8FFEEF4FFF7E2F8F4E7F4FFF8F4EEF4FFF8FF
F4EFF3F7F8FFF8F8F4F4F4F4F4F0F8F4FFFFF8F8FFFFFFFF
F4FFFFF4F8FFFFF8FFF8F8FFFFFFFFF8F8F8F8FFFFFFF8F8
F4FFE7E2F0FFCBE5EEEDF3F7F8F4E2DFDFE1E1B391FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2AEC1DFCBDF90DB
D7D4BDD0DBB2AAE2DDF8E9B9D6E9F8F8F7F4F7F4F4EFFFFF
F7ECE5E2E2EEF4F0F4C6AAB2C5C5BAC0BAAEBFCACACFD7E6
E6D0E2E2C8DBE7F8F8F4F8F8F8FFF8F4E5EEF8ECF7F7FFF8
FFFFF8F7F3F4FFEEF8EDF4EEF0F4F4F8F8F8FFF4F8F8F8FF
F4F8FFF7F3E8E8F7FFF7F4F8FFF4FFF8F4F4EEF4F8F4F4F8
F4FFF8F8FFF4F4F8F8F8F4F8FFF8F8F8F4FFF8F8F8FFF8FF
F8FFF0E9F0F8D6E8E9F4FFF3FFFFE5F0DBDBECC585FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0ABC4F8C6E191CB
D6C1DBCBE6E3EEEEEFE7EEB3D6EEF0F4F4F8F4ECEFF7ECF7
F7F7ECEDE5E6DBD0CBCCD6A79D9BB3C4CADBE7E7EEEFF7FF
FFECE1E1EDC5D0E7F0F4F4F8F8F4E2E1EDEEF8EFE8EFFFF4
F8FFFFF8F7F4F8EEF4EDF4F4F4EDF3F4F8FFFFF4F8F0F8F8
F4F4F8F8F8F4ECEFF4EDEFF8F4F8FFFFFFFFFFF4F4F8F8F4
F8F4F8FFFFF8FFFFF0F4F8F4F8FFF0F8F8F8FFEDEDFFF8F8
FFF0FFF0E9F8DBE1EEF0F4F7F7F3F7E9E8D1ECD07FF8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB9B9D1F8C6E8A3B8
EFC4F7E1E7F7FFE9FFE8F096D7F0E7F8F4FFEFECF4F8F8F4
F8F8EFFFF4F8E5E9E5DEAEE5E2E1DEE3EEE7DFF7EFE9D1C4
CAC8B9BFEDF8E6CBE1F3F3F3ECECD3E5F4F8F0F8F8F4F7F4
F8F8F8F8F7F3F7F4EEF4ECEEF0E7E8FFEDF8F8FFF8F4F4FF
F8F4F0F7ECF7F8FFF4F4EDE1E5EDEDEDEDF4F4F0F8F8FFF8
FFF8F4F8FFF8F8F4F8F8EEFFFFF0FFFFF8FFF8E7EFFFF8F8
FFF0F0F0F0F8DBE1F4EEF4F7F3F7F7F0DBDBFFDB7FF4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8ADC5D0FFB9F7B8AD
E6DBF8EFF7ECF4EEF8E5F784DEEEF7F4F7ECF7FFFFF4F4FF
F7F7EDE8E5EEE7D3C1E7DD9CBEF3FFECD0B29FABB6B6BAD6
C4AEBABAB2BFDDDFDBCBD0DEDBD6C1BAB9C8DFEEF8F8F3F8
FFF8FFFFFFFFECFFF0F4ECEEEEEFE8F8EFF8F4F4F8FFFFEE
EEF4F0ECFFF8FFF8FFFFF7ECEFECECF7F7EFEFEDE1E1DEE2
E5EEFFF8F8F8F8F4FFF8F4F8F4F8FFF8FFF8FFFFF8F8F8F4
FFFFFFF0F0F8D6E8F4E9FFF7F7F3F3F0E8DBE8E97FF4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4A8B6DEF4BFEDC18B
D6EFFFF4F7EDFFF4F8F4E1A2D1E9F4F4F4ECF4FFF8FFFFF8
FFEFFFF3F7F4F8F4E7BEBCDBADBCE5FFB3BADEEE9599BD89
7BDDF3EDEEEDD0CEF4EFF7E1DBDED1BEB9B4BDDFEEE8F7F8
FFFFF8F8F8FFECFFF0EEF3F8E6F4EDF4F4FFF8FFFFF8EEFF
F4EEEDEFF4F8F4E9E9E9E9E9E9DBDBEEF4E5E5E5E1E5EFF7
F4E2D7E3F4F8F8F8F8FFFFF8F8FFF8F8FFF8F8F8F8F8F8F4
FFFFFFF0F0F8D6EDEDEEF8FFFFF7F7E9F8D6E8EE7FEEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE5AEAEF4F8BAE2D06D
D6FFF8EFEFF8FFF4FFFFDBA2CBEEF4F8ECF4FFF4FFFFF8F4
FFECF3F8F4EDEFEFF8A0D7E5DEAF89A6F79A8DB270DB7ABE
8D94FFE8E9E8E3C1B6B2C1D3DEF0EDD6CFDFC0E1EEEDEFF8
FFFFFFFFF8FFF3F8EEF4F7F4EEF8EDF4F4F8F4FFF8F0FFF4
F0EEE5F8F0F0F4F8F4F4EDE8E1E1EDEEE9EEF4F8F8F0F4F4
F8F4EDF8F8EEEEEEF4F8F4F8FFFFFFF8F8FFFFFFFFF8F8F4
FFFFFFFFFFEDE2EDE5F8F8F8FFFFF0F0F4DCE8F47AEEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F4CBB6B9DEE5B2DDF07B
B5E1ECF7EEF4F8F8F8DFE290D0F8FFF4F7F3F8FFF8FFF8EE
F8ECF7EFF4F8FFEFFFC4D2E2CCE1BFEEB4D0D68B8DDD90D0
E161FFDBDFECF7CAA9EDCBC5DBE7E7E2E7CCBDDFEEEFEFF8
FFF8F4F8F4F4EFF7EEEEFFE8F4F4EFF4EEF8FFF4E7F3F3EC
DEE6E5F4EEF0EEF8FFF0E7F7EDDBE2F0F0F4F8EEEEF0F8F8
F0F8F8F4F8F8F8F4EEEEEEF8FFF8F4F4F8FFFFF7F7F8F8F8
F4F8FFFFF8ECE3E5EEF8F8F4F8EEF0F8E7D5EFF474F4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFDE8689DFB4D6EDB9F0EFA8
B2EEF7F3E7F0EEF4EEDEE89CE1F8F8F8F4F4F4F8FFF4F4F8
F8EFF3FFF3F8F7F4F4E8D7C5F0C6E5B4C5C5AEABBDE59F9C
B36CF8D6E7E5EDC5A9E6C8B4E2EFD6D7DEDBE1F8F4E8FFF8
F8F8F8FFFFFFE5F4EEEEF7EDF4F4E8F8EEFFF8EFF7FFF8CE
BDC1C1C6E6F0FFF0E9DFDED1CFDBD6C5CBD6D4E3E9EEF8F8
F0F8F8F8F4E5EEEEE9E9EEF0F4FFF4F8F7F7FFF7FFF7FFFF
F8F8FFF8EFEFD4EFF8F8F8F0F0F0F4EFEDDCF8F87AEEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF84E478DE19DE1F4BEE9FFD0
A3D6FFF3F7EEF4F8EEF0C8A7DCF0F4F8F8F8F4F8FFF8F8F8
F8F8F7F8ECF4F8FFF7EDEEE7D6F7C7DEDED6D7C6C3D3E5D7
C0B9F8E7DEEEF4BDB5ABC4DFF4E3EDE5D6EEE5EFF4E8F7F7
F8F8FFFFF0F0E5F4EEF0EFEDF4F4ECF8F4F8F8F7F3F7F4C6
E8C8C4B4D3D3D1D3D0D7DDDDE9D6D6E1DCD6D3D0DBE8EDF4
F8F8F4F8F7FFEFF4F8F8F8F8F4FFF4EFF7F7F7FFF7F7FFFF
F4F8F8F4F3F4D1F8F4F4F8F4F4EDF3EFE8F4E5ED7AE9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8A304D669E1B2CBEDBDDEEFE6
99B3EFEDEEFFF4EEF4E5DB9DD6F8F8F8F8F8FFFFFFFFFFF8
F8F8F7F4EFF3F3F3FFEDF8F0E7DEF8CFE5DEE5BFD1B2C5E1
DEDBD6E1E7F8F8D1E9E9F4F4FFF8F4CDD6F8F4ECEEEDFFF7
F4FFFFFFF0F0F4ECF8EEF8E8F4F4ECF8F4F4FFF0F0F3F8CC
D6F4D7B6EEF4F7E8F4EDECE8D6DEF8EDECECFFE8D0CBCFDB
EFF7F3F3F7F3F7F7F8F8F8EDEDEFF7F7F7FFF7F7FFFFFFFF
F8FFFFEFF7EED0F8FFF8FFF8F8E1F8F8EEF7F7EC74E9FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8EE7C3672E177C8D7A9A2B5F4F7F0
95ADEDE2F4F4F0F8F8E5DB91E8F8F4F8FFFFFFFFFFF8F8F4
F7F4F7F3F7F7F7FFF3F4EDF0EEE7DFEED7DEDBDFCBB4DFCB
CDDCDBD6D0D3E1DEEED6E1F7F8F8C5CCF0F8F0ECE9F8EFF7
F4FFF0E9E9F0F4ECF4EEFFECEEF4ECF4F8F8F8EEF4EFF7E6
D4CCDDA9CBADAE979198DFC9BDC4CBBDC4DDFFEDFFE5CFC9
C4E2EEEEEDEDF4E8E1E8ECF7F7EFEFF3F7FFFFF3FFFFFFF8
F4FFF8ECF4E6D0F4F8F4F4FFF8E1EEEEF4E8DBDF76D4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8F08D41AEE1ED85BDEFEDE8F7E5F4EE
97BEE5EEF8EEFFF8F4E2DB91E8F8EDF4F8F8F8F8F8F0EEF8
EDF7F4E8ECF7F3FFF7FFFFEDFFF0E5E7F4D0C9DBFFB6C1C9
CDDEF0EEF4EEF4E6F4E8F8F3FFE7C4F8F8F8EEE5EEFFEDEF
F8FFF0E9E9F0F4ECE6F8FFF3E9E5F4EEF8F8F8F8F4F0EFEF
F4DEF8AEAFE9EFF7CD61C5EEE8ECF8F8E5CCC4E1FFE5EDFF
DECFF4F8F4F4F4F8F8F4EEE9EEF8F4FFF7F3F3F7FFFFFFF4
FFF8F4EDFFE9D1F0EEFFFFF4EED6EEF8F7EFD1E985C0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8AC4795EFEDF48AC9DFE7FFEDE5F4F0
A3C8DFE5EDE3F7F7FFD1E991E2FFEFEFFFF8F4F8F8E3F4E7
F0F4FFF4FFF4F7F8F8F3F7F8EFFFF8E7DFDBE2E5DCE5E3E6
DECED6D6DDE1E2E7F3FFF3FFD5D2EDEEF8F4E5EDF8F8EDEF
F8FFF0E9F0F8E7EFEEF4F8F3E9E5F7F8F4F4FFFFEEF8F4F3
F8F8DEEC9ABDDCED8C99AAADE1ECE6E9E2D3E7D6F8F0F8F4
EFCBE1E1EDF4E5D6D6E1EDF8F8F8F4F7F7FFFFFFFFFFFFF4
F8F4ECF4F8DEDBF0E2EDF4EEF8C6E5E8E7E5CDDE8BB4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8F8FFF8FFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA53A74E7FFEDF8AC94BEDFDCBDC5CBB6
ADE5EEF7E7E6F7F7F8D6E97FF0FFFFFFFFF4FFF4F4DEDDCB
C1DBE8F4FFF7EFF4F7EDECF7EFEDEDE7E7E8DDDCE2EEEEF4
EEEDEFFFEEF8F4D5D1CAC4C4D6F4EEF0F8EDE7F0F4F0EFF7
F4F0FFF0E9F8E1FFF4FFF4F7E5F0E7EFF4F4FFFFF4FFF4E7
EFFFF7D6E3A7747994B19483C1E8DEFFECF8E1D6CDB9B2C5
D6EDE2DBDBDCEDEEEEEDDFDBD6DCECF7FFFFFFFFFFF8F8F8
F8F7F7EEE7E5E2F4EDF0C9D1EDC6D6F4EFBDE5E18BA8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0528DEEECF3E8FFEFBD9DB9D1C5E1CBD2
EDF4FFF4E6F8FFFFF4E2D685F8FFFFFFF8F8F8F7ECDFC7D5
E5CEDFEEF0F7EFF3ECF4FFF4F4EDF4EFE7F8F8F4ECF8F8F4
F0EEE5E1E1D6D6E7FFFFFFF8F8FFF4F8EFEFF8F4F8FFECF8
F8E9E9F0F0F8E8F8F4FFF4F7EDF4F4E8F8EEFFF8F8F8FFEE
F7EDEDE8E5E1F7E5D791E674B9E8C9E1F7E7EDD1C5EFE5D0
DEE5EDEDE7E5DEF0DFE7F0DBDBE8F7F8F4F4F4F8F8FFF8F8
F8F7F7E9E1E8F4F7EDFFDEFFE5BFD1FFD6C5EEED85A3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8BA3CD6F8E7F4E8FFFFE7BDAAB4D0D6D6ED
F4F4F8FFE9F7F7F7EDE9CA96EEFFFFFFF8F4FFF7ECF7E6C5
D7E7CEE5E7E7ECFFF7F8FFF8FFFFF8F8E8F8F4F4E5F7F8F8
FFF8F4EEFFF8F8FFFFF8F4F4F8F8F0EFEFFFF4F8F4F4E8F4
F0FFF0FFFFEDF7F4F4F8F8F3EEF8F4ECF4EEFFF4F8EEF4F4
F0EFF4D6F4F0EEDFDED58587C6EDC1DBE1E7EEBED0E2BCBC
DEFFDED1EEF4D6E5E5E8E3E3F4F4E5E7F8F8F4F8F8F8F8FF
F8FFF3E9DCEEF8EDFFEDDCF8F4AED6FFCBD1F4E885A3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF47E59EEF4FFF0E1FFFFF8E7D0B9C6E8EEE5
EFF0F0F8EEF7F7F7EDE2D796E9FFFFFFFFFFF8FFEFF4F8E5
CBE7DCEEDEDFF0ECFFF4F8F8FFFFF8FFE7EFFFFFEEEDE7F4
F4F4F4F4EEF4F8F8F8F8F8F8F8FFF0EFEFFFF4F8F4F4E8F4
F0FFF0FFFFEDF4FFEEF8F4F7F0F0F8E8F4F0F4F8F4FFF8F8
EEEEE2E5EDE5EFEEDBC5ECCCDDF4DFD6E5F8F8C6D6C1D5F8
EDDFE7FFE7D5D6EDFFF0EEF8F4E5F4E8F4F4F8F4F8F8FFF8
FFFFF3DBD6DEE1EFF4DCDEF8FF9DE1FFBFDBF8DC8CA3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8F8F8F8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF86274FFFFF8F8DCF8F4EEF4F4F4B9F3E9F4
FFE9F0F4F4FFFFF7EDE2D196EEF8F8F8F4F8FFF4F3ECF4F0
D3DFF8E5F0EDD3D6EFF4FFF0F0F0E8F8F8E7EFFFF8F8EDF7
EEF4F8F8FFF8FFF8FFF8F4F8F0F8F4F4F7EFF4FFF8EEECF4
FFF0F0FFF8E7EFF8EEF8ECFFFFF0F0E5EDEEFFF8F8EEEEF8
FFF8F8EED6F7E5E1E7E8D6CEC5C4CACADCF8F8E5D0DDF8F3
EDE7F8F8E7EDEEF8F8F8F8F0EFFFEFF7F8FFECEDFFFFF8F8
F8F7EFDDD1F8F7F8F4E1E7F8F891E5F4B8E9F0E17FAEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
F4F8F8F8F8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF04791F4F8F8F8DCEDF7FFF4F8F8BFEFF4F8
E9F0FFF8F8FFFFF7F4E3C49DF0F8F4F8F8F8F4F8F4F8F3ED
E7D7D3E1E8F4F8D4C5DEFFE9E9E9E9FFFFF8E7EFFFF4F8EC
F4FFF8F8F4F0FFF8E7E5E5E1DBE5EEF4F7EFF8F4F8F4ECF4
FFF8F8F8F8ECF8FFEEEFF7F7F4F4EEF8EFE5F8F4F8FFF8F4
EEF4FFEDF7D6E7F0DFE7D6F4E1DBDFE7DFE1E8DECFDFDDDB
D6E5F8DEE7F8F0F4F8F8F4F8F4F3F4E5EFF7F3F7F8F8F8FF
F8F3EEDECFF4EFEDF7EFE5FFF885EED6C1F0EEDB79C0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
F4F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDB3EBAF4F0F8F8DEEFF4ECEFF4EDD0F4FFE9
FFFFFFFFFFFFF7F7F8E3CA9CF4F8F8FFF4F8F4F4EFF4F7EF
EDDEC8EFF4F4F0EDCEBDDCD6EEF0F0FFF8EDE5E7EEF4F8E5
F0EEEEEEDDDBE8DDDEDDD6E1E5DEE5F0EFEFFFF8F4EFEFF4
F8F8F8EFF7ECF8F8EEF7ECF8E5F8F4FFF8E5EEF8FFFFF8F8
F4F8F4EFF0E8E7D6F4E5C6CFDBE5D7E6E8EEE8E7DED7E8E7
FFF0E1F8EFF8F8FFFFF8F4F4F8F7ECF4FFFFFFFFFFFFF8F8
FFF3DBD6EDEDF8E5E5D5E8F4F87FF8D0D0F8E9D16DD4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8F8F8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA747D6FFF4F8F8E9F8F0F0EDE8EDE9E8F0E9
F7F3F3F7F8F8F3F3F4E2DD96EDF4FFFFF8F8F8F4EFF8F7F3
FFE7C7D7E9F0EDF7E8B4AEA190918B7F858B7E859D9D9090
9DA8A8AEB9B5AFC0DCEDF4F4EDD6CEE7EEF7EFF4F8EFEFF8
F8FFF7EFEFEDF8F0F8F8F7EFF0F4F4FFEFEFEEF4FFF8F8F4
F8F8FFEDEFE8FFE8EEEEEDF7EDDBD3D1CBC9D6E1F4F4E5FF
EFECF8E2DEEEF4F4F8EDF3F4F4F3F3F7FFFFF8F8F8F8FFFF
FFE5D3D4E8E7F8E7E2EDFFF3E885E7D5D7FFE9BD66EEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8F8F8F8F8F8F8F8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF915CEEF8EEE5E5E7EFEEEEF8FFFFF4E9F0FF
E7F3F7F3F4F4F7F7F4E2E2A2DDF0F8FFFFFFF4FFF8F8FFFF
F3ECF8DEDCD7DFECE5F8EEF4F4EFF4F4F4F8E7F8E8E8E7F8
F8F4F4FFF8F4F0F4F4F8F8F8EDE5DBE8EEF4EFEEFFEFFFEF
F8EDEDF8F8F0F0F8FFF4EDF7FFF8EEFFEDF7F4FFF4FFF8F8
F8F4F0ECFFEFE8F8EFF8F8F8F8F8F3F8F4EEFFF8EDF4F4FF
E8DEE6F4EFF7F7F3ECEFFFEFEFFFFFF7F7F8FFF8F4F4FFFF
F7E2DCDBEDFFE5FFDBF8F3FFCF96DCE1E3FFE9AE74F4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9168E2F4FFF3F3F3F3F8F8F8F4F8F8EEFFE9
E9F7F7F7EFFFF4F8F4F0D0AED6F8F4FFF8F8F8F4F8F8F8FF
F7F4EFECEFE7D3D4D6DFFFF4F8F4F7F4EEFFFFE5EFFFF8F4
F0F8FFF8F8F8F4EFFFF8E5E5EDF0E5E5F0ECEEF8FFE8EFEF
F8E8F8FFFFF4F8F4F8F4F4F7F7FFEEF4F8F3F4F8F0F4F8F8
F4F4F8EFECF7F0E5EDF4FFF8F7F3EFF8FFF4F8F8FFF4E2DE
E9F0F7F3F8F8F7FFF8F8FFFFFFFFFFF3F3F4F4FFF8F8FFFF
ECD6D7D7EFF8EDFFDFE8F3F8B9AEE2E1E3FFE9A87AF4FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFF8F8FFF8F8F8F8FFFFF8F8FFF8F8FFFFFF
F8F8FFFFFFFF916EDCF8F4FFF7F3F3F4F4FFFFF8F4F8F7E5
EEF7F3F7F7EDFFF8F0F4D6A7D0F8F4FFF8FFF4F4FFFFF8FF
F7F7F3FFEDE5F0E5D3C3EEFFF8EEE2E5F8F0E2DBD4D6E1ED
FFFFF4F4F0F8EDE7F8F4EFEDFFEED6E6EFEFF4F4F8E8FFFF
F7EFF8F8F8F4F8F4FFF8F4F8ECFFF4E9FFECF8E5ECE5DCE1
ECE7EEF8F8EDDFF4F8F8F8F4EDE8E5E8EDE8E8E8DCE1E8F7
F4F7F3FFEFEFFFFFF8FFF8F8F8FFFFF3F3F4F4FFFFFFF8F4
E5E2DBDCF8EEE6F3ECDBF7F4A3D7E8ECE3F4E2A874F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFF8F8F8F8FFF8F8F8F8FFFFF8F8FFF8F8FFFFFF
F8F8FFFFFFFFA25DDCFFE8F3F7FFFFFFF7FFF7F7FFFFECE5
F8FFF7FFF3F4F4E5E1EDDDADD7EFF0F8FFF4FFF8FFF8FFF7
F7F7F7FFF8ECF8EDE7C6BCD1D1D6D6D1D6EDF3F4E1DBD6CF
D0D0D1D1CBC9D6E1E1D6D0D3D6D3CDE1E2EEEEEEE7EFFFFF
F7EDFFF8F8F8EEFFF4FFF4F4E8FFF4EEF8E8F8DBE6DEEDEE
E3DBDDE7F8FFEDECF4F8F8F8F4F8F8F4EDF4F7EFF8F8F8ED
EDF7F7FFFFF8F4F8FFF4F8F8F8F8FFECECF8FFF8FFF8FFEC
E9D6CEE5F8F8E3EFDEEDF7DDA4F8F8F3E3F4E2B97BC6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8BA51D6F8F4F7F7F7F7FFF3F3FFEFF8FFE8E8
FFF7FFFFF3F7EEE1F8EFE8BDD4E8F8F4FFF8F8F8F8FFFFF7
F3F7FFFFFFF7F3F7EFE7D6C6C6CCE3E2DBD7CFC9CBD0D7D1
B9C8DBD1D1BFB4B5B5B9B8BFCBD0E5EEF8F8FFF7EFFFEFEC
ECEFFFF8F8F8EEF8F8F8F0FFF4F7F8F0F0E5EEE1E6EDF4FF
F7EFE8DFE5F0F8F4ECFFF4F8F4F0F8FFFFF8F4F8F8FFFFF8
F8F4F4F4F8F4F8FFF4F8FFFFFFF4F8E7F8F7F4F8F8F8F8F3
E3C4EDEEF8F8EEF8E3E8DECBB9E9FFF3D7F3D6DDAD6CF8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFF8F8FFF8F8FFFFFFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8CC49C9EEF7F7FFF7F7F7F3F3EFFFF8FFECF4
F7F3F3F7F3F7F8DED7F8EEC5DCDEEFF8F8FFF8F8FFFFFFFF
F7F7FFF8F8FFF8F8FFEFEFFFFFE7DCE2D6C4CADBE1D6CFDD
EED6C9D6DCDBD1CAD6D3D6E5F4F8F8EEF4F8F7EFFFFFEFF4
F4F8F8F4F4F4F8F8FFF8F8F4FFF7F7F8EEEFDFDBEEF8F4F7
F7F7ECDFE7E7EEF8EFEFF4FFFFF4F8F4F8FFFFFFFFF8FFF8
FFF8F4F8F8F8F8F8F8F8FFF8F4FFFFF8F7EFF8F8F8F7F7EC
D4D6E8EEFFF8EEF0F0D7E5D0CBE9F7EFDDF3D6E5DE29EEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFF8F8FFF8F8FFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE24AB9F0E7FFF4ECF3FFF7F3EFF8FFFFF3F8
EFFFFFF7FFFFF8EEDBEDE7CBE1E2F4F8F4F0FFF8F8F8F8FF
F3FFFFF8FFF4FFF8F8F4E5DCDCDCDCDCE5F4F4F4F4F4E2D3
D0C6D6E1DCE1EDE8DDEFFFEFE8E8EDFFF7EDECF8F8FFEFF8
EDF4F4F8F0F0F8FFFFF8F8F8F8FFF7F7F0E2D3BDCBDEE3DE
EFF7F3F8D6C4C4C0C0B9B9DBE8E7F4F4F8FFFFFFF8F4F8F8
F4F8F8FFF4F4F4F4FFFFEDECF7F8F8FFF8F8FFF4FFF7FFDE
D3D6DFF8FFFFF0F0F0E2E5D0D3FFE5F4E2F7E3EFBD349CE7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFF8F8FFFFFFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEE50ADF4E3F7F8F8F7F7FFF7F3FFFFF8ECF4
F8ECF7FFF7FFF4F8E1F7E2D6DBDEEFF4F8F4F8FFF4F8F8F7
F7FFF8F8F4FFF8F4F8FFFFFFFFFFFFFFFFFFF0F0FFFFF0F0
F0F0E9FFFFFFFFF8F4F8FFFFF7F7F3F4FFF8F7F8FFEDF7F4
EDF8F8F8FFEEF4FFFFF8F8FFF4F8F8F7F3F7F4D4DECBDBDF
DEEDF8ECF8FFE8E1E1E1CDC4D7D6E5F4F8F8F8FFF4F8F8FF
FFFFF8F8FFFFF7F7F4E5EDF4EDECF3F4F8F8F8F4FFFFF3D7
D3DBF4FFFFFFFFF8E6F8F0DBD5DEEDE5DCF3D7E8CB6E97D6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFF8F8F8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F05CA3F8E3F8F7FFF7F3F7FFF7FFFFF8F4ED
FFEDF7F7F7F8F8F8E8F7EED6DCF0DEEFF4F4F0F8F4FFFFF7
F7FFF4F4F4FFFFFFFFFFFFFFFFFFFFFFF0F0F0FFF0FFF0E9
F0F0FFE9E9F0FFFFFFF8F4F8F4F4F7F7EFEFF7F7F8EDF4FF
F8F8FFF8F8EEFFF8FFF8F8F8F8F8F8FFF8F8F4DEDCCFC3C8
C4C6E9E7EFF8EEF4F8F0EDD6C5B2B1D2E5E7F8F8F8F4F4FF
FFFFF7F3F3ECEDEFDFE3E9DBD6DFF8E8F8F8F8F8FFFFF3C5
D3E6FFF8FFFFFFEEF4F4EDDFD3DBF4EDD6D3D7CAF0A392AC
F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8EE6191F4EEF0F4EFF7F7F3FFF7FFFFFFFFEC
F8F4F3FFFFF4FFF4F4ECF0D0E1F8E9EDDFF0F8F8F4FFFFFF
F3FFF8F8F4FFF8F8FFFFF0F0F0F0FFF0F0E9F0F0E9F0F0F0
FFE9F0F0F0F0F0F0F0FFFFF8F8F4FFFFF8F4FFFFF7FFECF4
F4F8FFFFFFF4F8F8F8FFF8F8F8F8F8F8F8F4F8F8FFFFE7DB
DECBC3DFE5DCE1E7F0F8F8F0F8F4CEB6B2BCD6E1E8EDEDEC
F3F3F7FFF8F0EEE3D7E8E8FFE5D5E5F7F8FFF8F8FFF7F7C0
D1F4FFEFF7FFFFE3F8F0E5E8DBD5DBECF8EFF4C4ECD0B69C
D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF687FF4F4F4F8F0F8FFF7FFF7F7F7FFFFF3
F4F8EFF7F8FFF4FFE8E5F8DBDEEDF4EFE7EEFFF8FFF4F8F7
F7F7F7FFF4FFF8F8FFFFF0F0F0F0F0FFE9FFF0FFF0F0F0FF
F0FFFFF0F0F0F0F0FFF0FFFFFFF4FFFFF8F4EFECF7ECEFFF
FFF8F8F8F4F8FFFFF8F8FFF8FFFFF8F4F8F8F8F4F4F8FFF7
E5F4D7C4D0E5EEDED6DBE5F4FFF8F8F4EFCED0D1D6DCE5E9
E3E3D7D1D0D6E1E8EFFFEFE7E8DDF8F4FFFFF8F8FFF3F8C5
CBFFEDFFEFF4F4E9F8EEEFF4E6DDEDD6CFCAD1DDECD0B69C
D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF747FF7F7E7F8EEF8F7FFFFF7F7F7FFFFF7
EFF8F4F3F8FFEEEDE7EDE7E1E3ECF0E1F4F4FFF4F8F4F8F3
FFF7F7FFF4FFFFFFFFFFFFFFF0F0E9E9F0F0F0F0FFFFF0FF
E9F0F0F0FFE9F0E9FFF0F0F0FFEDF7FFF7F4FFE5F8F4EFFF
F8FFFFF0F8FFFFFFF8F8FFF4F4F4F8F8F8F4F8FFFFF4FFF7
F8EDF0E7DBCBDBE1E1DEDEE5EDF8FFF8F4E7E5E9E6E9DEE1
E5E5E5EEF8FFF8F8FFF8E5E8DFF7F8F8F8F8F8F7F3EFF8B9
DBEFEFF3F8F4E5F8F0EEEFF3F3D5E2E9DDE2E8E8E1DBA197
F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8474F8EFECF8F0EDF7F3F7EFF8FFFFFFFF
F3F4F4F7F7F4F8E5F7EDE7DCEEECF4E2EFEEFFF4FFF7F7F7
F7FFFFFFF4FFFFFFF8F8FFF0FFF0E9F0F0FFF0F0FFFFFFE9
F0F0F0FFF0F0F0F0FFF0F0F0FFEDF7F8EFF4EFF4F8F3E8F8
F8F4F4EEF8FFFFFFF4F8F8F4F4F8F8FFFFFFFFF8F4F8FFF7
FFF7F8F0F8EFDBDBE6E7E5DEE5E5E8EFFFF4F7F7F8F8F8F4
F0F8F8FFF8F8FFF7EDE7E7E5F4FFFFF4F8F8EFFFF7F4F8BA
DDECF7F7FFFFF0FFFFF0F3F8F4E7E8E1EDEEF8EEE1C46FAC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFA250F4ECFFEDF8EDECF7F8F8F8F8FFFFF8
EFEFFFF8ECF8FFEEECF0F0E1EEE8F8E3F7E7F0F8F8F4F8F7
F7F7F8F8F8F8FFFFF4F4FFE9E9F0FFF0FFFFFFFFFFFFFFF0
F0FFFFF0F0FFF0F0F0F0FFFFFFF8F8F8F8FFF7F7F8EFEDF4
F8F8F8F4F8FFFFFFF8F4F8F4F4FFFFFFFFFFFFF8F8FFF7F7
F7F3F7F8EEF0FFEFE5DEE6E5DBD6DBDFEDFFF8F7F3EFEDED
EEEEEEF4F4F8FFF4F8DFE5EFF8F8F4FFFFFFF3F3ECF8F4B9
DBF7F7FFFFF0F0EEEEFFF3F8EEE8F4FFE5F8F0E7ED5985EE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF0A462E7F8F7F4DBF4EEF0F4F8F4FFF8F8FF
F8DDD0E1EDF8F8F4EDF7E9EDE2E8FFE6EDFFE5F8F4F4EDF7
F7F7F8F8F8FFF8FFF4F4FFE9E9F0FFFFF0FFFFFFFFF0F0FF
FFF0F0FFFFFFF0F0FFFFFFFFFFFFF4F7F3F3F3EFF7F7FFF8
F4FFF8F8F4FFFFFFFFFFFFF8F8FFFFFFFFFFFFFFF4F8EFFF
F7F7F7FFFFF0EEF8F8EFE5E2E3DED4C9C4C8D6E1ECF7F7FF
F3EDF4EEF0E5E1DBD3E5F7F8FFF4FFF8FFF7F7F7EDF8DFB6
F4F8FFFFF8EEEEF0EEFFF7F7E8E6EDECF4F4F4EDE234D7EE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE99090EDF7F7EDD0F0FFE9F4F8F8F8F8F8FF
F8E8F8EEF0F0EEEEEFF7E9F4E1E7EDF8E2F8F7EEF4F8F8FF
F7F7FFF8FFF8F8F8F8F8FFF0F0FFE9F0F0FFF0F0FFF0F0FF
FFF0F0FFFFF0F0F0F0FFF0F0FFFFF4F3EFEFFFF4F8F4F8F8
FFF8F4F4F4FFFFFFFFF8F4F8F8F8FFFFFFFFFFF8FFFFF8F7
F7F7F7FFFFFFF8F0F8F8F4EFF3ECE7F0EEDEE1E1DBE3E9E2
D6DBEEEDDDDEE2E5F7F7F7F8F8EFE7F8FFF3FFF8F8F4DCC6
FFF4FFFFF8EEF4F4F0F0F0ECF8F7EFF8F8EEF8F4DC73698D
C6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFF8F8FFFFD46CC1E8F8F4F4E7E7FFEEFFF8F4FFFFF8E8
E6F8F4F8F8EEEEF4EFF4EEF4ECF0DBF8E9ECFFEEF4F8F8F7
F7F3FFF8F8F8F4F8FFFFFFF8EEE9FFE9F0FFF0F0FFF0F0FF
FFFFFFFFFFF0F0FFE9F0FFF0FFFFEDFFF4F4F4EFF7F8F8F4
F8F8EEF0FFF8FFF8F4FFF4FFF8F4FFFFFFFFF8FFF8F4FFFF
FFFFF7F7FFFFFFF4F8F4F8F8F4F8EFE5EDEEE6E9E5E1DCDC
E1E8E1DBDEECEFF8FFF7EFF8FFEFEFFFEFF8F7F4F8E7D6D0
FFF4FFF0F0FFF8F8F0F0E9ECF8F3F8EFEDF4F4EEE5CDB28D
8AF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
F8FFF8F8FFFFB272D5E7E8E5E5EFDCFFF8F0F8F8F8F8FFE2
DDF4F8F4F4F8F8F8F8E1F4E8ECF4E2EDEEEFEDF8F0FFF8F7
F7F3FFF8F4F8F8F8FFFFFFEEE8F0F0F0F0FFFFFFFFF0F0FF
FFFFFFF0F0FFFFFFE9F0F0FFFFFFEDEFF4F7ECF8F8FFFFF7
EFFFEEF0FFF8F8F8FFF4FFF8F4F8F8F8F8F8F8F8FFEDF3F7
F7F3F3F7FFFFFFF8F8F8F8FFFFFFFFF8EDE8E7F4EEE9E2E2
EEEEE5E5F4F8FFF8FFFFF8F8FFFFEFECF8EFECF8F4E1DBE2
FFF4FFF0F0FFFFF0F0F0F0F7F3F7F7FFF4F0F8F8EED6F8A3
6EF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9089D6F7F8E5EDF4E1FFF8F0F8F8EEF8F8F3
F7EDF8F4F4F8FFF8F8E7EDE9EFE7E8DDF0F0E1F8F0F8FFFF
F7F7FFF8F4F8F4F4FFFFFFF0E9F0F0FFE9E9F0FFFFFFFFFF
FFFFFFF0F0FFFFF0F0FFF0F0FFFFF8FFE5EFF7F7EFFFF8ED
EDFFF4F8F0F8F8F8F8F8FFFFFFFFF8F8F4F4FFFFFFE8F7F7
F7F7F7F3F7FFFFFFF4F8F8F8F8F0F0FFFFFFEFE8E8E8F4F7
ECE5F4F4F4F8FFF8FFFFFFF8F4F7ECEFF7F7EDF0E5E5D6EE
FFF4FFFFFFFFFFEEF8E9FFFFF7F7F7E7F0F4F8EDF4CBF4B2
5ED7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF749BE1F3F3EDF8EFE8FFF8F8F8F8E9FFFFF7
F7ECF4F4F8F8F4F8F4FFEFDBFFE8F4E2EDF8DBF0F0F8FFF7
FFF3F7F8F8F8FFFFF8FFFFF0E9F0F0FFF0F0FFE9F0FFFFFF
FFFFFFFFFFF0F0EDE7FFF0F0FFFFFFF4ECF8F8ECF7EFF4FF
F8F8FFF4F8F4FFF4F4FFF8F8FFFFF8F4F8F8F4F8F8ECF3FF
F7F8F4F7EFF8FFF8F8F8EEF4F4EEF8F0F8EEEEF8FFF8FFF4
F4F8F4F8F8FFF8F8F8F4F8F8F4F7F7F7F7EFF8EEE1E6DBF4
FFF8F8FFFFFFFFEEFFEEFFF7FFF7FFF0F0F8EFF7F3D1F8E5
69A7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
FFFFFFFFFFFF5CB4E7EDEFF8F4E7E1FFFFF8F4EEF0F8F4F4
FFF7F0E9EEF8FFF4E5F0F8E1F0EFE5EEE5F4E1F4F4F8F8F3
F7F3F7F8F8F8F8F8F8FFF0FFE9F0FFE9F0F0E9F0FFF0FFFF
FFFFFFFFFFF0F0EDE7FFF0F0FFFFF8EFF7FFF8F7E8F4F8F8
FFF4F8F4F8F8F8F8F8F8FFF8FFF8F8FFFFFFF8FFF8F7F7FF
F7F4F8F3F8F8FFF8F8F8F4FFF0FFEEF8F8F4EEF8FFF8F8FF
F8F4F8FFF8F8FFFFF8F4F8FFFFFFFFF7F7F8F4DFE5E2EFF4
FFF8F8FFFFFFF0F0EEFFF8F3F7F7F7F4F8FFECF4E8D6F4EF
767EF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8
F8F8FFFFFFFF38D6DEE5FFEDEDFFEDEFFFF4EEEEEEFFF4F4
F7FFFFF7F7FFFFF7EFF4F0E8F4E7E7DEDFDDD2F4E7F4F0EF
F7FFFFFFFFF8F4F8FFFFF0F0FFFFFFF0E9E9FFF0F0F0FFFF
FFF0F0F0F0FFFFE9FFF0FFF0FFFFEDFFF4F8FFF8F4FFF8FF
F8F8FFFFF8F8F8F4F4FFF8FFFFF4FFF8F8FFF8F8F7F7F7F7
FFF7F7ECF8FFFFFFF8F4F8F8FFF0F4F0F8F4FFFFFFFFFFFF
F4F8F4F4F8F8F4F4F4F8FFFFFFFFFFF3F8EEDFE5E7DEF8F8
F8F8FFFFFFFFE9F0E7ECF4F3F7F7F7F8F4F7F4F4DBEFDBF8
916EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8FFFFFFFF22F4CBE5E8E5F4FFF4E5F4F8F4FFF4EDF7F7
F3F7F8EFEFF4F8FFEEF4F8E1F4F0DCD6DEF0C8F4E8FFF4F4
F7F7FFFFFFFFF8F8F8F8F0F0FFFFF0F0F0E9FFE9F0F0F0F0
F0F0F0F0F0F7EDFFF0F0F0FFFFF8F4FFF4F8F7F7F8FFF4F4
F8FFF8F4F8F4F7F7FFF8F4F8FFF4FFF4F4FFFFF8EFFFFFFF
F3FFF7ECFFF4F4F8F8F4F8FFF4F8F4F0F0F8FFFFFFF8F8FF
F4F4FFF8F8F8F4F4F4F8FFFFFFFFFFF3EEF0ECF4DCF4F8F4
F8F7F7FFF8EEFFE7F7F7FFF7F3FFFFF7FFF7FFF7DBEEF4DC
A36EF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF17F4CBE5ECFFEDF7EDF4F4F8F8F8F4EDF7F7
F7F7EFF8F8F8F8F4F8EEF8E8F7F0E5E2E7DECCE8E1FFF4F4
FFF3FFFFFFFFF8F4FFF8F0F0F0F0E9E9E9F0FFE9FFFFF0F0
F0FFFFFFF0E2F7FFF0FFFFFFFFF8F8F7F7F7FFEFFFFFEEF8
F8FFF4F0F4F4F7F7FFFFFFF8F4FFF4FFF8FFF7ECF4F7F7F7
F7F7F3F7F4FFF8FFF8FFFFFFF4F8EEF8F8FFFFFFFFF8F8F8
FFF8FFF8FFFFF8FFFFFFFFFFFFFFF7E7F0EDEFDFE7F4F8E5
F3FFF7FFEEF8E2F7F7F7F3F7FFF7F7F7ECF4F8F3E8EEF4DC
AE76DBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFF00E1EEE7F4F8EDF4F7F8E1F8F4F8EEF8FFFF
F7F7F7F3F7F8F8F8FFF8F4E8EDF7FFF7E2DECAE9DCF8F8F8
F4EFF7FFF7F7F8F4F8FFFFF0FFFFFFFFFFFFF0FFF0F0FFFF
FFFFFFFFF0E9FFF0FFFFFFFFFFFFF4FFF7F8F4F4F7FFF0F8
F8F8F8F8F8FFF8FFFFF8F8FFFFF8F4F8FFFFF7ECF4F7F7F7
F7FFFFF8F8F8FFF8FFFFFFFFF8FFEEFFF8F8FFF8F8FFFFF4
F8F8FFF8FFFFF8FFFFFFFFFFF7F3F7E9F8ECF4DCF8F0F0F4
F3FFF7F8EEF0E5FFF3F7FFFFF7F7F7F3E8F8F8F3F8FFE9E1
C57DBEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8F8
F8FFF8F8FFF005F7F3F4FFF4EDF8F7EDE5EFF8F4E6F8FFFF
F8ECFFF7FFF7F8FFF8FFF8DCF4EEE9E7EDE3C4E5DFDFF8FF
F8F8F3FFF7F7F8F4F8FFFFF0F0F0FFFFFFFFF0F0F0FFFFFF
FFFFFFFFF0F0F0F0FFFFFFFFFFFFF8F4F8ECEFF7E8F8F8F8
F8EEF8F4FFF4F4FFFFF4F4FFFFFFFFFFF7F7FFF8EFF7F7F7
F8F4F4FFF4FFFFF8FFFFFFFFFFF4F8F8F8F8FFF8F8FFF8FF
F4FFF8F4F8F8FFF8F4F8FFFFF3FFF8EEEDEFDFF0E8F0F8FF
FFF7EFF0F8DFF8F3F7F3F7F7FFFFFFF7F4FFF4F7F4F4E3E1
D67FB4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8F8
F8FFFFFFFFE932CBEEF8EDDCDCF8EFEDF4ECFFF4E2F4F8F8
F4EDF7F3F7FFF7F4FFFFFFD6F4F8FFF0E9EEC5E5EEE1EEF8
F8FFF7F7FFFFFFF8F8FFFFFFFFFFE9F0F0E9E9F0F0FFFFFF
FFFFF0F0E9F0E9FFF0F0F0FFFFFFFFE7E8FFF8ECF4F4F4F8
F8F4F8F8F8F8F8FFFFF4F4FFF8F8F7F7F4F4F8F4EFF8F0F0
F8F8F8FFF4FFFFF8FFFFFFFFF8FFF8F4FFFFFFFFF8F8F8F8
F8FFF8F4F8F8FFF8F4F8FFF7F7F8F0F0E5F8E2F8E5F4FFFF
FFF8F0FFE5F4F4F3F3FFF7FFFFF8F8FFFFF8ECFFF4F8F4DE
CF6EBDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FF
FFFFF8F8FFE93EDFDCF7E5E1E8F4FFF8F4F3F4E8E1F0FFFF
F8F4F3F7F7F4F4F8F4F4F4EDEDF8FFF0F0F4CBE5E2E8EEF0
F4F8FFF3FFFFF8F8F8F8FFFFFFFFE9F0F0E9E9FFFFFFFFFF
FFFFF0F0E9F0E9FFF0F0F0FFFFFFF8E8EFF7ECF8F8F4F4F8
FFFFF8F4F8FFFFFFFFF8F8FFF8F8ECECF8F8F8F4EFF8F0E7
F7F8FFFFF8F4F4FFFFF8F8F8FFFFF4F8F8F8FFFFF8F8FFFF
F8F8F8FFFFF8FFF8F8FFF7F7FFF4F4EDEDFFDBEFF4F4FFFF
F0E6F8E7EFFFFFF7F3F7F3FFF8FFF8FFF7F7F3FFF8F8F8DE
C15BDBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FF
F8F8F8F8FFDB33F8E1FFE1EDFFF3EDF8FFEFEFF7F7EEF8F8
F8FFEDEFF3F8F8F8F8E9F0F8DEE7F8F0FFF8D6EED6EDEFF0
F8F4F7F7FFFFF4EFF4F8F8FFFFFFF0F0E9F0F0FFFFFFFFFF
FFFFFFFFE9E9F0F0FFFFFFF8F4F4FFECF3F7F7FFF4FFFFF8
F8F8F8FFFFFFFFFFF7F7F7F7F7F7EFF8F7FFF7F3FFF3F7F7
F7F8F8F4F4F8F8FFFFF4F8F8F4F4FFFFF8F8FFFFF8F8FFFF
F8F8F8FFF8FFFFF8F8FFF3F8F4F0F8DBF4F0DBFFF8EEE9E9
FFDDDBEFF7F3F3FFF3F3F7FFF8F8F8F8F3F3F3FFFFF4F4D6
886EEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FF
F8F8FFF8F8D12EE8E5EDF8F7EFF3F4F8F4F8ECF8F8EEF8FF
F8FFF8EDF7FFF8F8F8F8F0F4F8E2F4EEF4F8DCF4DBE8ECF4
F8F0EFF7FFFFF8F4F7F8FFF8FFFFF0F0E9F0F0FFF0F0FFFF
FFFFFFFFE9E9F0E9F0FFFFF4FFFFF8F7F4F4F8F8F8F8FFF8
F8F8F8F7F7FFF7F7F3F3F7F7F7F7F7FFF7F7F7FFF3FFF3FF
F8FFF8F8F8FFFFF8F4FFF8F8F8F4FFFFFFFFF8F8F8FFF4F4
FFFFF4F8FFFFFFFFF7F3EFF8FFF4F8DCF8E7F8EDF8FFF8EE
F0F7F3F3F7FFF7FFF7FFFFFFF8F4FFEFFFF7F3FFF7EDF4AF
5DC1F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFF8F8F8
F8FFF8FFF8BD33F7EDEDFFF4F8FFF7F3EDFFEDF3F7F4F8F8
F8F8F4F8F4F7F4F8F8F8F8DEEDF8ECEEEEF4DCF8E5E7DEED
F8F8F4F7F7FFFFF8F8F4F8F8FFFFF0FFF0F0F0F0FFFFF0FF
F0F0FFFFF0F0F0E9F0FFFFF8F4F4F8F4EDEFEDF8F4F8F8F8
FFFFF4F7F7F7FFFFF7F3F7F3F7FFF7F7F7F7FFF7FFF3EFF4
FFF8F4FFFFF8F8F4FFF4F4F8F4F8FFFFFFFFF8F8FFF8F8FF
F8F8F8F4F8FFFFF7F7F8F8F8F4E7F4E8E9F3F4EDF8FFF8EE
FFFFFFFFFFFFF3F7EFF8FFF8FFF4F8F7F7FFF3F7EFDCDF91
6BF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFF8F8F8
F8FFF8F8FFA857F4EDEFEFF7F8F4EDECEDFFF8F8F7EFF4F8
F8F8F4F8E1ECF8F4F4F8EEDBECEDEFE9F8FFE1F8F8E5DEEF
E7F8F4F7FFF7F8FFF8F8F8FFF8F8FFE9F0F0FFF0F0F0F0FF
F0F0F0F0FFF0FFE9F0FFFFF8F8FFF4F3F7F8F7F8F8F8EEF4
F8FFF4FFFFF7FFFFF7F7F7FFF3F7F7F7F7FFF8EFEFF8F4FF
F4FFF8F4F8F4F4F8F4FFF8FFFFFFFFF8F8FFFFF8F8F8FFF8
F7F4FFF8F4FFFFF3F8F8FFF4F8F7F4E8E2EFFFF8F8F8F0F0
F7F3F3F7FFF7F7F8FFEFF4F8F4F7F7FFF7F3F7F3F4DBD67B
8DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FF
FFFFFFF8F4B45CF8F8DCEDF7F4FFFFEDEDFFFFF4F7FFE5F4
F8F4F4F8E8EDF8FFF0FFF8EFF4ECF8E9F8FFE1F4F8EDD4F8
E8F4F8EFFFFFEFF8FFF8F8FFF8F8FFF0FFFFF0FFFFFFF0F0
F0F0F0FFE9FFFFE9FFF0F8FFF8FFF4F7F7ECF8F4F4EEF4F4
F8F8F8FFFFF7FFFFFFF3F3F7F7F7F7FFF7F8F7F4F8FFFFF8
F8F4F8EEF8F4F4F8F4F8FFF8F8FFFFF8F8FFF8FFF8F8F8F4
F4F7F8F8F8F7F3F7F4FFF8F8F8F7ECD5F0EDF8F0FFF8F0FF
F3F7F3FFF3FFF7F8F8F7EDEFECFFF7F7F7F7F3F7F3EED06D
A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8F8
F8FFFFF8F8CB46EDEDE1E8F7EDFFF8F4EDFFF8F0E8EFF4F4
F8F8FFF8F8F8F8F0F8F4F4F8E8F4FFEEF8FFE8F0F8EFE2F0
E5F0F8F4F3F7F7FFFFF4F8F4F8FFFFFFE9E9F0F0F0F0F0FF
FFFFF0F0E9F0E9FFF0F0F8F8FFF8F8F7F3F7F8F0F8FFFFF8
F8F4FFFFFFF7FFFFFFF7FFF7F7F7F3FFF7F8F4EFF8F8FFF8
F8F4F0F8FFF4F8FFF4F8FFF8F8FFFFF8F4F4F8F4FFFFF8F8
F8F8FFFFFFF3F7F7F4F8F8FFF8ECF0E2F8E7F4FFF8F0FFFF
EDEDFFF7F3FFF7F7F7F8F7EFF7F7FFF3F7FFF7F7E7EED684
84FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8F8
F8FFFFFFEED634F8F4E8EFF4E8F0E8F4F7EFEDEFD6EDF7E9
F8F8F4F4FFF8F8F8F8F8F8F8E8F3E8F8FFF4ECF8F4EFE5EE
F4EFF0EEF7F7FFFFF7EFF8F8E8F0FFF0FFFFE9FFFFF0F0F0
E9F0FFF0F0E9F0FFFFFFFFFFF8FFF4FFF7F8F0FFF8F8F8F4
F4F4F8F8FFFFF3F7F7F3F7F7F7F7F7F7F7F7F7EFF8F8FFF8
F8F4F8FFFFF4FFF8F4F8F8F8FFF8F4FFF8F8F8F8F4F4F8FF
F8F8FFFFFFF7FFEFF8F4F8F8F4ECF4F0E1F8F4FFEEFFFFF0
FFF0FFFFF0E7F3FFF7F4EFFFF3F7F7F3F3F3F7EFF8EEE18B
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFF
F8F8FFFFE9C845DEE6E8FFEDF4E8F0FFEFEFEFEDE2EFF7E5
EEF8F8F4F8F8F4FFF4FFFFF8F8F7F0E7FFF4ECF8F4F8E1E9
F7F7EEF4F8F3F7F7F7F7FFF8E8F0F0FFF0E9FFE9E9F0F0F0
F0F0FFFFFFE9F0FFFFFFF8F4FFFFF4F7ECF0FFFFFFF8EEFF
FFF8F8F8FFEFF8F7F7F7F7FFF3F3EFF8F7F7F7FFF4F8F4F8
F4F4F8FFFFF4FFFFFFFFF8FFF8F4F8F8F8FFFFF8F8F8FFFF
F8F8FFF8F8F7F7F8F4F8EDE1ECEDE7DBE7FFF8F8F8F8FFF0
F0FFF8F4F8F0FFEDE5F7FFFFF3F7FFF7F7F7FFF8F8E3DC64
9DF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFF
F4F4FFFFEEC352F8E6E8F8E7EFEEF8FFFFFFFFF8F8FFF7ED
EEF8FFF4F4FFF8F8F8F8FFE5ECEFEFE2EFF7EFEDF4E8E7DE
EFF7EEF8F4F7F7F3FFF7F7FFF4FFF0F0FFE9F0F0E9E9F0F0
FFE9F0F0F0E9F0FFFFFFF8F8F8F8EFE8EFF8FFFFFFF4F4FF
F8FFF7ECE8F7F7EDEDE8ECF7F8F8F4F4FFFFFFF7EDFFF4F8
F4F4F8FFFFF4FFFFFFFFFFF8F8F8F8F8F4F8F8F8F8F8FFFF
FFFFFFF4ECEFEEE3DEEDECF0EEE8F4E5FFFFF4FFFFF4F0FF
F8F4F0F4FFEEF0F0F0FFFFFFF7ECF4FFF7ECECF7F8C65B5B
D6F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FFFF
F8F8FFFFEEE145E8FFE5EEF4E8F0F4F8F8FFF8EEF8EDF8EC
E5F4FFF4F8F4F8F8F8F8F8E5F4F4F4F0EDF4F8EFF4EEF0DD
E8EFEDF8F0F8FFF7F3F7F3FFF8F8FFFFF0F0E9F0F0F0FFF0
F0F0FFFFFFFFFFFFF8F4F4EFF7F7F8EDF8F8F8F8F8FFFFF4
FFF7F7F4F8FFFFF4F4F4F8F7EFEFFFF7FFFFFFFFF8F8F4F4
FFFFF8F8FFF8F8F8F8FFFFFFFFFFFFF8F8F8F8FFF8F8FFFF
FFFFF7F7FFF4F8F0EDF4E5E8EEE2ECE5F8F8F4FFF8FFF8E9
EEF4FFEEF8E8E5F7FFFFFFFFFFEDE8F3F7F4EDEFFF955DDB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFF8F8FFFFF8F8
F8F8FFFFE9E140F4EDF4E7F4E8F7EDEEEEFFF4EEF8E1ECFF
E5E6FFF8F8EEFFF8F8F4F8F4F7EDF4E9E8F8F0F0ECFFEEE8
EEEEE8F8F8F4FFFFF7F3F7FFFFF4FFFFF0E9FFFFE9E9FFF0
E9FFFFFFFFFFFFFFF4FFFFF7F7F3F4EDF8F8F8F8F8FFF8F8
FFECF4FFF8F8F8F7F4F8FFF7F7F7F7FFFFFFFFF8F8F8F8F4
F8F8F8F8FFF8F8F8F8FFFFFFFFFFF8F8F8F8F8F8F8F8FFF7
F7F7FFF7F8F0EEE5EDE7DEF8F7E7F8F8F8FFF8F8EEEEEEEE
EEE9F8EEF7F7F7F7F7F3ECECF3F4FFF4F4F7E7FFF86C77F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFF8F8FFF8F8
F8F8F8F8F0D345F0E5ECF3F4EDF8EFE9E3EDE5F8F8EDF8EF
F7D7FFFFEEFFF0FFF4F8FFF8F4E1F4EDD6F7E6E6E7F4EEE7
E5EEE1F8F8F4F8F8F3FFFFFFFFF8F8FFFFF0FFFFF0F0FFE9
F0FFFFFFFFFFF8F4F8FFF7F7EFF4F8F8F8F8F4F8F0F8F4FF
FFECEDF4F8F4F7F3ECF8FFF7F4F8FFFFFFFFFFF4F4F8F4F8
F8F8FFFFFFF4F8F8FFFFFFFFFFFFF8F8F8F4F4F8FFFFFFF7
F7F3F3F3F4F4F8EFFFDEFFFFEDF7F8F4F4F8F8EEFFFFFFF8
EFF3E7F8EFF3F7F7F7FFF8F8F8F8F4EDF4ECF8F8E96285FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FF
FFFFF8F8FFDB3EF0E1F3ECF8EDF4F4E8EEEFE8F8F4F8E5F4
F7DBF0FFEEF8F4F8F8F4EDF8FFE7DEE2D6EFE9F0E8ECF4F4
E1EEDCFFF4F8FFF8F4ECF7FFFFFFF8F4F4E6E6E8F0F0F0FF
FFFFFFFFFFFFF4FFFFFFF7FFF8ECF7F4F4F8F8F8FFFFEEFF
F7FFFFF7F8F4F7F4EDF4F8F7F4FFF8FFF8F4F8F4F4F4FFFF
F8F8FFFFF8F8F8F0F4F8FFFFFFF8F8FFF4F8EDEFFFFFFFFF
FFF3F7F7F4F4FFEDDFF8FFE7ECEDF4F4F4F8F8F4F8FFFFF7
F7F7F7F8FFF8F7EFF4F8FFF8FFFFFFF8FFF3FFF0E85C8BF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FF
F8F8FFFFFFDB51E2E8FFF4F8EDF3F7F4F8F0F8F8F8F8F4F7
F3E8EEF8F8E6F8FFF4F3F7E8F8FFDEF4F4F8F0EDE2EDEFEE
E8EED6FFF8F8F4FFF8F8F3FFFFFFFFFFF8F4F8F4FFFFFFF8
F4F4F4F8FFFFEDF7FFF7F7F7F7F7EFF8F8F8F8FFF8F8EEF7
F7F3F3F8F8F8F4F8F8F4F8F8F4FFFFF4FFF4F8F8FFF8FFFF
F8F8F8F4F8FFF8F8FFF4FFF8F8F4F8F4F8F8EDEFFFFFFFFF
F7F7F8EEEEE7E1E5E9EEE2F7F4EFFFF8EEEEF4F4F8FFFFF7
F3F7FFFFF8F8F3F8EDF7F4FFFFF8F4FFFFF3F8EEED42ABF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F8FFFF
F8F8F8F8FFDB70B9EEECF8F4F4EFF4F8EEF4FFFFF8F8F8EC
F7F4F0EEFFF0EEF8F4E5EFE5F8F4EFF4F8F4E9EDE2E5F8E2
E8EED6FFF8FFEEF0FFFFF7F7FFF7F7FFF4F8FFFFF4F8F8F8
FFFFFFF8EDE8F8F7FFF7F7F7ECF4F8F8F8FFFFF8FFF8F8F7
F4EFF7F4F4F4F8F8F4FFFFF8F4F8F4F8F8FFF8F8F4FFFFFF
FFFFF4F0FFFFF8F4F4FFF8F8F8F8F4F4F8FFFFFFFFFFFFF7
F7F8F0F8EFEFF8F4F0E7E5FFF4EFF8F8F4FFFFF7F3F7FFF7
F7FFFFFFFFFFF3F7FFF4F4FFF8FFF4F7F3F7EEE7E715DEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF8FF
FFFFF8F8FFF062BDEEE5F8F8FFE1EDF7EEFFF4F8F8F8F4F8
F7F8EFD7EEF8F8F0FFF8EFF4DDEDF4ECE8EEFFF7E7D6F0ED
E7DEDEEFF4F8F4F4F8FFFFF3F7F7F3F7EFF8F8EFF3EFF8F7
F3F3F7F7F7F7F8ECF7F7F3F7F8FFF4F8F4F8F8FFF8F8FFF7
EDF4F8F8F8F8F8F8F4FFFFF8F8FFF8FFF8F8F8F4EEF4F8FF
FFFFF8F4F8F8F8FFFFF8FFF4F8FFFFFFF4FFFFFFF7F3F3F7
F8E8F4FFE8F8EEE3E3E1FFF4F8FFF4F8F8FFFFF7F3F7FFF7
F7FFFFFFFFEFF8F7F3FFF8F8F8F8F4F3F8EEE8F49B3DF8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FF
F8F8FFF8F8FF4BD0F0E1FFF7EDD6E1F7ECE2E3F8EEE6ECEC
F7EFE8E8E9FFF8F8F0F8FFE1FFECF4F4E1F4F8F3F7EDDEE5
F0DBE6E5F0F8F8F4FFF8FFF7F7FFF7FFF7F7F3F7FFF3F7F7
F8F8F7F7F7F7ECF8F7F7FFF8F8F4F8F4F8FFFFF8F8FFEFED
FFFFF8FFFFFFFFFFF4F8F4F0F0F4F4F8F8F8FFF4FFF0F4F8
F4F4F8F8F8F4F4FFFFFFF8F4F8FFFFFFF4FFFFF7F7FFFFF8
F8EEF8F8E5F0FFEEEDEFF0F8F8F4F0F8F7F3F7FFF7F7F7F7
FFFFFFFFFFEFEFFFF3F8FFF4F8F8EFF7EEF0FFCD49ACFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF8F8FF
F8F8FFF8F8FF4BDDEFDEEFF7EDD6E8F7FFDBEEF8DEDEE8E8
FFF7FFF8CBEDF8F8F8EEF8ECF4EDEDF8E5F4EFF8EFE8F4E1
FFDEDEE7E5E5E6EEFFFFF8F8F8FFF8EFF7F7F7FFFFF3F7F3
ECF4F7F7F7ECEDF8F8F8F8FFFFFFEEFFFFFFFFF4EFEFE8FF
F8FFF4F8FFF8F8FFF8F8FFF8F8FFFFFFFFFFF8FFF4F8EEF8
FFF8F0F8F8F0F8FFFFFFFFFFFFF8F4F8F4F7F3EFF4F4F4F8
F8E7E8E5E7FFF8E9EDEDF4F8F8FFF4FFF3FFF7F3FFFFFFF7
FFFFFFFFFFFFFFFFF7EFF8F7F4F8F3F0E8FFFF8A61F0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFF8F8FF
FFFFFFFFFFFF46E2F7E9E8F7EFE1F8ECFFE8FFF4E3EEDDF7
ECF3F7EFD1F7F8F8F4F4EEE5E5F4ECF8EDE5EDF7E5E5EEE5
F7EEE1EEF4F3F8EEF8F0F0F8F4F8FFF8F7F3F7FFFFF7F3F7
F7FFF7F3F7EFF8F8F8F4F8F8EEF0EEF8F4F4F4F8ECF7F7F8
FFF8F4F0F4FFFFF4F4F4F4F8FFFFFFFFFFFFF4F8F4FFF8FF
FFF8F0F4F8F4FFFFF8F8FFF8F4F8FFF8F8F3FFF4FFFFFFF8
F0ECF7EDF8EFE5F3ECEFF8F8F8F4F8F7F7FFFFF7FFFFF7FF
FFFFFFFFFFFFFFFFFFF3F8EDEFF4F3E9F8F8DE6199FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFF8F8FFFFFFFF
FFFFFFFFFFFF60B9EFDFDEFFFFF4F8EDF3EDFFF4EEF8E2E8
F0EDEFF8F8E8FFF4F4EEEEF0EFE7E7EFEEEDE7F8E5F4E2F4
EFE5DEE5E9DEECE5F8F4F8F8F8F8F8F4F8FFFFFFFFF8F8F7
F7F7F3F7F4F4F4F8F8F8EEF8EEF4F4F4FFFFFFFFECF8F4EE
F8F8F8F4FFF4F8F4F4F8FFF8F8F8F4F8FFFFF4FFFFF8F0F8
FFFFF8F4F4F8FFFFF8F8F8FFF8F8F8FFF7F7F7EFF4F8F8F0
FFECF7EDF0EDF7FFF4F8F4F8F4FFFFF3FFFFFFF3F7FFF7FF
FFFFFFFFFFFFF7F3ECEDF8FFF8EFE7F0F8F4D056C5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFF
FFFFFFFFFFFF948EF4ECE6E7F7EFE5F8F8F8F8F8F8F4EEDD
EEE8F4E8E8E5EEF0EEEEF8F8F3F0F0F7F4F8E1EDEFEDF0DE
F0ECE9E1F4EEEEEFE7F8F8F0F8FFFFF8F8F7F4F4F4F7F4F8
F4F4F4F4FFFFFFF8F4FFF8F8F4EEF0F8FFFFFFF7EDF8F8E9
F8F8F4F4FFF4F8F4F8F4F8F8F8F8F8F8FFFFF4FFFFFFF8FF
F8FFFFFFF8F8FFF8F4F8F4F4EDEFF8F7F7FFF7EFEEEEF0F8
F4E1EEEEF8EDF7F8F0F8FFFFF8F8FFF3FFFFFFF7F3FFFFF7
FFFFF7F7F7F3EFF4F8FFFFFFF8ECE9F8FFE5BA58D4F8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFB474F4E8DBE5ECF7E1F8F8F7EFF4F8F4F4DF
EDECF8DBEDF7E8F0F4F0EEF8F7F3F4F4E7EFE1EDF7FFE8F4
E8DFE5E1FFF0EEFFECF8F8EEEEF4F4EEFFF4F7F8F8F4EFF7
EDF8FFF8FFF0EEEEF8F8F4F4F8FFF8F4F4F8F7EFFFFFF4EE
FFF8F8F4FFF8F0F4FFFFFFF8F8F8F4FFF8F8F4F8F8F8F4F8
EDE7F8F4FFFFF8F4F8F8F4F8F4FFF7F3FFFFFFF4F8F8F8F4
E8E7F4F8EFE7FFF4F4FFFFFFF8F8F7F7FFFFFFFFFFF7FFF7
F7F7ECEFEFF4F8FFFFFFFFFFF8E5EEF4EEF4906FEEF8FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFF8
F8FFFFFFFFFFCE5DE5D6DEE5ECF4ECFFF4EFFFF4F7E7EEF0
E1F4EFE8EEE3E9F8EEF4EEF8F4F7EFEDF8D7F0DCEDF4F8E5
E8F4DDDBD3DEE6EEEFE1DBEDF4F8F8F8EEFFFFF8F8F4F8EF
F4F4FFF8F8F8F4F8F8FFF8F8F8F8F8FFF8E7EDF8F4E6E9EE
F8F8F4F0F8FFF4EEF8F8F8F8FFFFF0F4F0F0F8F4F4F8F8FF
EFF8EDFFEDEDEDEDEDE5F8F7F7F3F7EFF4EEE3E3E2E1E1E5
F8F0EEE8DFF4F4F8F4F8F4F4F8F7FFF7FFF8F8FFF7F3F7FF
F7F7ECFFF8FFFFFFFFFFFFF8F8E8F8FFF8E25398F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFF8
F8FFFFFFFFFFF87B9FEFF8F4F4ECF3F4FFF4F3ECF4EDF8F8
EDF4ECF3E6F0EEF8FFEEEEF8F4FFF7ECF4EED6F8EFE5EDF7
F8E7EFECE5E5DDE5E6F8EEF7F3ECE5F4F8EEF4FFF8F8FFFF
F8F8FFFFFFFFF8F4F8F4F4F4F4F4F4F8F8E8F0EEF8F8F8F8
F8F8F8F8F8F8F8F8F4F8FFF8F8F8FFF8F8F8F8FFF8F8E7EF
FFEFFFE8FFF8F8F8F4F4F3F7F7F7F8F8FFF4F4FFF3FFF8F8
FFE2F3F7F4FFF8F4F0F8F8F8FFF7FFF7FFF8F8F7FFF3F3F3
F3F7ECF8FFFFFFFFFFFFF8EFECEFF8F0EEA444DEF8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFFFA290E1F4FFFFEDF7F4FFF8ECF3FFF4F4F4
F8E1EDFFEDEEF8EEEEF4EEFFF8F7FFEDFFF8F4DFF4EEF3F4
EFEDF8F8E7EDE6DBDFEEF4E9E9EEEFEFF4F8F8F4F8F4FFF8
F4F4F4F8FFF8F8FFFFF8F0F8F4F4F8F8F7EDEEFFF4F8F4F4
FFF4F4F8F4F8FFFFFFF8F4F4F4F8F8FFF4F8F4F4E7EDEFEF
FFFFEFEDF4EFEFF7FFF8F8FFFFF8F8FFF8F0FFF4F7FFF8F8
FFE7E7FFF4FFF4FFF4FFF8F8FFFFF3FFFFFFFFF7F7F8F8FF
F8ECE8FFFFFFFFFFFFFFF4F3F4F8EEF8F85673F8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFF
FFFFFFFFFFFFF8B687CBF0F8FFF4F7EDFFFFEDF8EDFFEEF4
F8E8FFECE8EEF8F8FFFFE8F8FFF8F3F8F8F8F4EFD7FFE2DF
F4F8F4E9E6E2E5EFDEDBD6E1E8E5E6E2E7F8EDE8EFF8F4F8
F8F4F4F8F0F4F8F4F8F8E7EFF4F4FFFFF7EDF8F0F8EEF8F8
F4F8F4F4FFEFEFEFEFFFFFFFF0EEF4FFF4F8F4F8EDFFEFFF
EFE8E8F4FFF8F8FFF8F8F4F8F4F8F8F4F8F4F4EFFFF8F0EE
E9E2E7F8F8F8F0F4F8F7F7FFF7F7F3FFF8F8FFFFFFF8FFF8
F8F7EFFFFFFFFFFFFFF8EFEFF8F4F0E7BD2ECEF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8DB8AAEEDF8F4EFFFF8EFFFF8E5E1F4EEFF
F0EDE5EDEDEEF8FFF4F8FFD7E5F4E7F3EFF8F8F0EDCCDBF4
E8E7F8F0F8F4F4EDDDDCE2E3E6EFECEFE5E8E5E9DEDCE5F4
EFF7F0E2EDF8F8EEF0EFF4F4EFF8FFF7F3E5EEDEDBE1E8EC
ECEFEDE8ECF7F7FFFFEFFFF8F8EFE8E1E5F4F8FFFFEFFFEF
ECF8F8EFF7FFF7F7F8F4F8F4FFFFF8F8FFF4F3F8EEE6E5F4
FFF3F8F0F4F8F4FFFFF7FFF7F3F4F4FFF4F7F8FFF7F3EFF8
F8F8FFFFFFFFFFFFFFEDF7EEF4F0EEF4565EF8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8A48DE5F4E6EFFFFFEDFFF8F4F4F8F8EE
F8F4E8F8F4F8F0F8F4FFF4D4EFDEE8FFF7ECF7F8F0FFDFE5
EFEFDFFFE9F0FFFFF8F4E8F4E7E8F8EDDEF8E7EFF8F8EFDB
E8F8E8EDECF7F3ECECEFF4F4F7F7ECEDEEE8E7E7F8F4EEE9
E9E5EDF8F0F0FFF7FFF8E5DBEDECF8F8E7E8ECECEFEFFFF8
EFFFF8F7F7FFF4EDF4F8F8F8F8F4F4F0F8E5EDF0F8F4F7E7
E8F4F4F8F8FFF4F7F7FFECEFF7F8F8FFF7F4F8FFF7F7F7F7
F4FFFFFFFFFFFFFFF8ECF0FFF0F4F4DE22B2F4FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC972E1F8EEF4F3F7EDFFF8F4F8FFF8F4
F8E9F7F7F8F4EEF4F8F4FFF8D7E7E8DBECF3EDFFF8E8F0F8
E5E1FFDDE2EEF8FFFFEFEDF4F7E9F8FFDCE7EFEFEDFFEEF0
DEE5EEEEE7DEDEE6F8F4F8E5F3F7F4F8E7ECE5F0F8F4F4F7
F8F8EEEEF8F4F8F8EDEFF4F8EDEFF8F8F8FFF4F4F8F4F4EF
FFFFF4F4F4F4F0F4F8F8F8FFF4FFF8F8F8E1F8F8F8F8F7E5
E5FFF8F8F8F8F8F7FFECF7EFF7FFFFFFFFFFF8F4F8F7F3EF
F8FFFFFFFFFFFFF8EFEFF4EEF8FFF8AC30E9F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE570BDFFF0F0ECF7F4F8F8F8EDF7F8F4
EEE9FFF3F0EEF4F0F8FFF8FFF8D7D3EDE9E3F4EFF4F4FFFF
FFF8E5E8F7F8F0F8F8F4F7FFFFF0EEF8ECE5F4F4DFE1E5E8
E7EDF4F8EEF0FFEEF0F0F0E6F8FFE6E5EFF0F0EDEFF8ECE7
E8F4FFF4F8F0F4F8F4EEF4F8F8F8FFFFFFFFF8EDEDF8F8F8
F4F4FFF8F8F8F8F8F8F8F8F8F0F4FFF4EDE7F8F8F8FFF3FF
FFEEF4F0F8F8F4F8F7EFF8F7FFF7FFFFFFFFF4FFF8F8FFF4
FFFFFFFFFFFFFFEDF7EEF4F8F4F4DB7B6CF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF89B72DBEDF4EDF8EFF8F0F8EDF7F7F3
E7FFEEEFE5F8F0F8F0F8FFEEE9E6FFDFD1D1FFE5F0F8F8ED
EDF4F8F8EEE9EEF0FFF4E8E1E8ECDEE9E2DEE9EEEEEEF0EE
DBD7DBDCD6D6DCDBDBEDF8F4D6D7CFDBDEE6E5E5EDECF4EF
F7F7ECE5ECECEDEEEEF4F4F0EEF0F8F4F8F8F4F8F8E9E3EE
F8F4EEF8F8F8FFF4EEE7E7F0EFF3E8DCEFF0F4E8F7EFEDF4
EEF0F8FFFFF8FFF4FFF3FFFFF7F7FFFFF8F4F8FFFFF8F4F8
FFFFFFFFFFFFEFE7F4F8FFFFEEDF8552B5FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE56DDBE5F0F0E7F8F3EDFFF4F7FFF7
F3E3EEF8E5E6F4F8F8EEF8F4F0F8F4F4F4E5EDF4F0F4EEE5
EDF8F4EEF8F0FFF4F4FFF8F8FFEDF4F4E5E8F4FFF8F8E7F4
FFF7EFF8EDEFEDE7F0E5F4F4F4EDE5F8F8EFEFF8F8EEE6E8
E2E9F4F4EEF8F7F3F3F7FFF8F8EEF0F8F8F8F8EEF4F8F4FF
EDF4F8F4EDEDF8F4F8F4F8F7EFF7F4FFF4E6E9E5F4EFF8F8
F4F8FFFFF8F4EDF8F7F7FFFFFFFFFFFFF4FFFFFFFFFFFFFF
FFFFFFFFFFFFE1F8F8F8FFF0F8AF739FF8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF87FB4E5E8F8F4F7F3EDFFF4F7EFEC
F7DBF4F4ECF0EEF0F8EEF8F8EEEDFFF8F8EDF8F8EEF4F4F8
FFF8EEF4EEEEF8F8F8F8FFF8EDEFF7F3EDF4EFF4F4EDECF4
ECFFFFEFECF7EFE1EDD5E1EFE8F0EEF4FFE7EDFFF8F0F0EE
F4F8F4EEF0EEFFF8F4EFF7F7F7F8F8F4F8F8F8F4F8FFF8F8
F3F7F3F3F7F7ECF4F7F7F3EFECEFF8F0EEEFECEDF8FFF8F8
F4F4F4F4FFF7F7FFF3F7F7FFFFF7F7F8F8FFFFFFFFFFFFFF
FFFFFFFFFFF8DBF4F8F0F0FFEE776ED7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFB98DD7D3F8EDF7FFF8F8F8F4EDEF
EFE5F0EEECF8E9FFF0F8EEEEF0EDEFE1EDEDF8FFEEF0F8F8
F8F8F0EEF8F8F8F8F4F8FFF4F7ECEDF8F8EFF4EDEDEDEDF8
F8EDE5E5EDF4F0DEEFEFE1CFDCEEF7F3ECF4F3F4FFFFF0FF
FFF8F8FFF8E6EEF4FFF4F4EDEFF3F3ECF4F4F8F8EFEFEDF3
F7FFFFFFF8F8FFF7EFEDEDF4F4F8F0FFF0F3F8F8FFF8F4F4
F8F8FFF8F7F3F7FFF3F7F7FFF8EFF7F8F8FFFFFFFFFFFFFF
FFFFFFFFF8EFEDF0F0F0FFF8EE37A7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE598B4D0F0E7F4FFFFF8F8EDF8ED
F4F7EEF8E8F8F0F0F0F8F8F8FFEDE8E7F4F8F4FFEEF0EEEE
E6F4E9F8F8FFFFEDE5F4F8F4F7E8F4F8F8EDEFFFFFF0F0FF
F0E9F8F8FFF0F8F4EEEEF4F4E5E8EFF4F4EDEDF8F0F0E9E9
E9F0F0EEEEF0EEEEEEEEF4FFF4EEF4F8F4E1E1E5EFEDE5F4
F8F8F4F4F8F8F4F4F8FFF8F4F8F0F0F0E7F7FFF4FFF4F8F8
FFF8EFF3F7F7F7F7F7FFFFFFF4F8F8F8F8FFFFFFFFFFFFFF
FFFFFFF8EFEFF8F0FFF0F8F8CE1DDEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8C591AEEEF8F4F7F7FFF4F4F3F3
F8F8F4F8E5F7F4EEEEF4F8F8F8F4EDFFF4FFFFF4F8EEEEF4
FFF0F4EEF4F7F3F8EFF8F8EDFFE8EEF8F8F0E9E9EEE5E5ED
D6EDF0E7E2FFFFF0EEEEFFFFFFF8FFF8F8F8FFFFEEF4F4F4
EEFFFFEDE8F7F7F7F8F4F8E9F8F8FFF4F4FFFFF4E9EEF8F8
F0F0EEF0F0EEF4F8FFF8F8F8EEF0F0EDF7F8EEEEF4F0FFF8
F8EEF7F7FFF7F7F3FFF8F8FFF8F4FFFFF8FFFFFFFFFFFFFF
FFFFFFF4F3F4F8F8F0FFEEF49C42F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFEEA29BDBFFF8EFF7FFF4F8EFFF
EFFFFFEEE9F3F4EEF4E3F4F8F8FFEFEDEEF8F4F8F8F0F8F8
F0F0EEF0E6E2DCE2EEF8FFE8E5EEF0F0F8F0F0F7EFECE8E5
DCF4E2FFE2F0E9E9E9F0F0F0F0FFF8F8F8F8F8F4F0EDE8ED
F8F8F4F4FFEFF7F3F7E5EDF7E7E9E9EEF0F8F0EEEDEDEEF8
F8EEF8FFE7ECE8E5E2EFF4F8F0F0EDE7F8F8F8F8FFF8F8F8
F0E5F7F7F7FFF7F7F7EFF8FFF8F8F4F8F8FFFFFFFFFFFFFF
FFFFF8EFEFFFF8F4FFF0F8F8647BFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF4BD81B6DEF8F4FFFFF8F8F8ED
F8EDF8F8FFE7ECE5EEF4EEE5E8E8ECE7E8F8FFF8EEEEF4F0
F8F8EEFFF4F8F4F4F8FFF8F4EFF4F8E5E5EEE5F7F7FFEDF8
E7ECFFEDEEF4DED6E5F8EDEDE9FFE7D6DBE9F8F4F8F7EDE7
ECE1EDFFF8F8EEEDEDF4EDEDEFF3ECECE8DBE5ECF4F7F3E5
E5F3E1DBEDF8F8E8E8DEDBECE1DBEDF4F0F4EEEEF4EDEDF8
F8F4F7F7F7FFFFFFF7FFF3F7F8F8F8F8FFFFFFFFFFFFFFFF
F8EDECF7F8F8F8FFEEF8F87432BDFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF8EE8BD0D3EEF8F4F8F7EDFFFF
E8ECF8F4E9F0F0F7EFE6EEDCF8EEE8EEF4FFFFF8EEEEF8F4
F8F4E8EEFFEEEEF4F8F8F8E9F4F0F8E1ECF7EFF7F4EFEFF4
ECFFF4EFF4FFE5E5E8F4E5F4DEEEF4E5F8E1DFE7F7F7E8F8
F4FFF4EEF4EEF8F4F8F8F8F8FFF8F4F4F4F8F4F8F8F8F8F4
F4F4F8F8F8F4EEFFF8F8F4EEF4FFFFF8F8FFF4FFFFF7F7F7
F7FFF7F7FFFFFFF7F7F7ECF4FFF8F4F8FFFFFFFFFFFFFFF8
EFF7FFFFF0FFF8F8F8FFAD41BCF8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE99BCBD3DBFFF8EFFFF8EFFF
EDF8E7FFF8EEF4F8F7F7F8EDE7E8E7EEFFF8FFEFEFF8EEF4
F4E9E6E5F7F4FFF4EEDDEDE6F8EEE7FFFFFFEFF4FFF4F7F7
ECF8F4EDEFF8EDF8E8D3F8E5EDFFFFEFF0E8F4F7F7F7F8EE
F8F8F8F8FFF4FFFFF8F8F8EEEEF0F8F4F4FFFFFFFFF4F4F8
F8FFF8F8F8EEF8FFF4F8F8F8F8F8F8FFF8FFF4F0FFFFFFF7
FFF7F7F7FFFFFFF7F7FFF8FFF8F4FFFFFFFFFFFFFFFFFFED
E7F0FFF0FFF0F4DFD6C35183F8FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEEBCAAD3D3F0F8EFEFECECF8
F8E5F4EDF4F4FFF8F4EFF3F7EFD6EDFFF8FFF4E7EFEFEFEE
F8F8FFEDEFFFF8F8F0D6DBEEF0F8ECEFF8EDE1F7EFF3FFF3
ECEFE8E8F7F4EFF7E1EFDFEDF7F8FFECF4EDF4F4F4F4EEF8
F4F8EEF4F4F8FFFFFFF8F8FFF8F0EDE5F8F4F8FFF8F8F8F8
F8F4FFF8FFFFF8F8FFFFF8F8F8F0F8F8F8F8EEE7F7FFF7F7
F7FFF7F7F4F4F4F8F7F4F8F8F8F8F8FFFFFFFFFFFFFFFFE8
F0F0F8F4EEFFEED6F4905DE5FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8D6B2C5CED4FFF4F4EDF8E7
F8EDF7ECFFFFF4F4EEE6EEE8E7EFDFF0F7EFF4F0F8EFEFF0
E9DDDDE9EEF8F8F0F4E5D3ECE5F4ECF7EFF8DCEDF7F7F3F7
F3F7EDEDF7F4FFE5F8E2DEF8F4EFE7ECF4FFFFFFFFF8FFF8
FFF0F8F8F8F8FFFFFFF4F8F8F4F8DFEFF4F8F8F8F8F8FFFF
FFF8F0F8FFFFF8F8FFFFF8F8F8F8F8F8FFF4FFF3F3FFF7FF
F3F7F3FFECF8FFF4F7F4FFF4F4F8F4FFFFFFFFFFFFF8EDEF
FFF8F8F8F8F8F4DBCF4CB4F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFDBBDCBE5BDF8F8F8F4EFEF
F8FFEFF7EEEEFFF0E6F8F0F8E5DBFFDBD3EDF0F4F8F4F4EE
E9E2E2E9EEF8F8F8F0F8D6F4EDEFF8FFEFEDEDF8F7F3F7FF
ECF8FFF0E1EFE5DBE1E1F8E1F8ECF4EFF8F8F8F8EEF4F4FF
F0E9F0F8F8F8F8F8F4FFF8F4F4FFF8F0F4FFF8F8F4F8FFFF
F8FFF8F8F8FFF8F8FFF8F8F4F8F4F8F4EDF8F7F7F7F3F3F7
F7F7F7F3EFF8FFF4FFF8FFF8F8FFF8FFFFFFFFFFF8F8F3FF
F8F0F4F8F8FFD6947280F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE9C8BCD6A9DEFFF8EFF4F8
FFEEF0F4E5F8F0F7EFE8F8F4F8F0D1CBFFDEE6F0F8FFF8F0
EDE1DCE5F8FFFFF8E6E9E1EDEDE8F3F7F7F7F3F3F3F7F7F4
E5F8F7E5D6E1F4EDF4FFEFEFECF7F0F4F8F8F8FFF0F0F8E9
F0FFFFFFFFFFF8FFF8F8F8F8FFF8FFF8F8F4F8F4F4F4F4F8
F4F8F8F4F8F8F8F4F8F8F8F8F8FFF7FFF7FFF7F7FFFFF8F8
F7FFF7F7EFF8FFF4FFF4F7F8F8FFF4F8FFFFFFF8F8F7F7F0
EEF8F0FFF4ED8D839DD7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF0D7BED0C4D6E7F4F7F4EF
F7EDEDEDF4F0F4EDF8ECDBDDF7F7F8E8D6D1F8DEDEF0F8EE
DDCBC6D7F4F8F4F8E9D6E5EDF4E5EFECEFFFF7F3F4ECF7ED
DBF0F3ECEFF8E8EEF8EDEDFFF4E8F4FFF0F8FFF4F8F8E9FF
FFFFFFFFFFFFFFF8F8FFFFFFF4F4FFFFF8FFF8F8F8F8F8F8
EFF4F7F7F8F4ECF4FFF8F4FFFFFFF7F7F7F7FFF7F7FFF8FF
F4EFEFEFF7F4FFF8F4EDF7F8FFF8F4F8FFF8F4EFF3F7FFF0
E2EDF0F0F8A4318AD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFEEDBB5ACDEDDE8F4F7F4
EDEFF4EEDBE5E8EDF7EFF8C8EDEFF7FFF7F7E8D6F4E5DCE7
F4EFECEFF0EEFFFFF0C9EEE8F7F4F8F8F7EFECF4F4F4F7F4
D1EEEDF8EDDCDBF4FFF4F4F0E6F8EEF8F0FFF4EEF0E9F0FF
FFFFFFF7F7FFFFFFFFFFFFFFF8F8F7F7FFF8F8F4F7FFF8F0
F3EFF8F4F8F3FFEFF4F8F8FFFFFFF7F7F7FFF7FFF7F3F3EC
EDFFFFF8FFF4FFF8F8FFF8FFF8FFFFFFF8EFF3F7FFFFF0F0
F7EFF8FFCC449BE9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8DEDB9DA3C5D4EDFFEF
F8F4FFEEE2F4F7F7F4EFE7E5E2E6EEF4F8FFFFF0DBD6D6E5
EECBC5D7DBEDF7F4F4CBEEE7F4F8F4F7F4EFEFEFEFFFF7EF
DCFFF4E5EDE7F4EDF0EEF0F8F4DEF0F4EEF4F0F0FFFFFFFF
FFFFF7FFFFF7F7F7FFFFFFFFFFFFF3F3FFFFFFF3ECF8EEEE
F7F7F7ECEFF3FFFFF3FFFFF7F7FFF7FFF3FFF7FFFFF7F7FF
F3F8FFF8FFF4FFF8F8FFFFF8FFF4F8F8EFF7FFFFFFF0FFF8
F4F8F4BE7B58E2EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0E8F0ACA4AEF8F7F7
F4F8F4FFFFEFFFF7F8F4F7EFF7ECE5EEF0F4F8FFFFF8FFF0
F4EDEDF4ECF3F4EFEFD7F0F8F8F7EFF7EFF8FFF8F4F3F7F7
F4EEF8F8F8F4E1E1F8F0EEF8E5F4EEE6F4F0F8FFFFFFFFFF
FFFFF7F7F3F7FFFFF7FFFFFFFFFFF7FFF7FFFFF7FFF7F4F4
F7FFF7F8F4FFF7FFF3FFFFF7FFF7F7FFF7F7F7FFF7FFFFF7
F7F7F8FFF8F8F4F8FFFFFFFFF4FFF4ECF7FFFFFFF0FFF0F8
F8FFE5906ABEF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEEDE1AF86EEF4F3
EFF8F8F0F8F8EDF8F3F7F4E8E7DCE8F8F8EEE6EEF4F7F4F8
EEE9EEF4E1F7E8E5ECE3EEF8F8EDF3F7F3F4F8F0F8F8F8FF
FFEEF8F4E9EEE8DBEEE9F0E9F8EEFFF0EEFFF0F8FFFFF7F7
FFFFF7F7F7F7F7F7F3FFFFFFFFFFFFF3F7F7FFFFF7FFEFF8
E7FFFFF3F7F3F7F7F7F7FFF7F7F3F3F7F7FFF7F7F7FFF7F7
F3F7F8F8F8F4F4F8FFFFFFFFF4FFF3FFFFF7F7F0F7EDF8F4
E8E2954BA5F0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F0E1D764F0E5F7
F7EDF8F0F8F8F8E8F7F7F4EFF4EEF8EEF8F8FFE8D3E2FFF8
F4FFEDE7E2F3EDEDEFE9F4F8F8F0F8F3F3F4F4F4EDEFFFF4
F7F4F8F0EEE6E8E3F0F8E8FFE9EEF8FFF8EEF8EEE9F0F7FF
F7FFF7F7F7FFF7FFF7F7FFFFFFFFF7F7FFF7F7FFFFF7FFE5
EEECECFFF3F7F7F7F7F3FFF7F7F3F3FFF7F3F7F7ECF4FFFF
F8F8F4FFF8F4F8FFFFFFFFF8F8FFF3FFFFEDDBEEE5D7E9F4
E5C6589CF0F0E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8D6F876C3D6EF
F7ECF4F8F8EEF8E7EDF4F0F8EDECDEE9FFF4E9DBF0E5DBE9
E9E3DFE5E2F3F4FFF8EEF4F8FFF4F8EFF7F4F4F4EDF7F4ED
F7E6E6F4F8E3F0F8E8E3EEF0F0EEEFF7FFF7E7E9E9F0FFF7
FFF7FFFFF7FFF7FFF8EFF7F7F3F7F7F3F7FFF7F3F3F7F7F8
F7E5F4F7F7F7F7F7F3F3FFFFF3F7F7FFF7F3F7FFF8F8F8F8
F8F8F4FFF4F8F8FFFFF8EDF4F7F3F7F7F7EEE9E9E9DEDBE5
CD6B7BFFF0F0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDEDB8BD6D6F0
EFFFF3F7FFF0F0F4F0F8EEF8E7EFF7EDF4F8FFF8E7E1F8EC
F7F0EEF4DCF7F7F4FFE9F8F0F4F0F4F0F8F4F4F4F8F4F0F0
F4E3F4E5F0F0FFE3EEFFF0E9FFFFF7FFF7F7F7FFFFFFFFFF
F3F7F7F7F7F3FFFFF8F8F3F7F3F7FFFFF3FFFFFFFFF7F7F7
F4F4F7F3FFF3FFF3F7FFF3F7F3FFFFFFF8F8FFFFF8F4F8F8
F4F4F8FFF8F8FFFFF8EFF7F7F7F7F3F0E8FFF8F8EFF7F4BC
7C6ADFE9F8EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8EE7FBECDD6
E6E7F7ECF4F8EDDBF4F0F8EDE8F7ECF4EEE3EEFFFFF4E8FF
EFE1D6D6D7E7F8E5FFE9F4F4E7EFF4EEE6F4F8FFF8FFF4F4
FFEEDEF8EDF0F0F0EEEEF0F8F8F7F7F7F7F7F7FFFFFFFFFF
F7F7F7F7F7F7FFFFFFF7FFF3F7FFFFFFF7F3F4F8FFFFF7F3
F7FFF7FFF3FFF3FFF3FFF7F7FFF4F8F8F8F8F8F8F8FFFFFF
FFFFFFFFF8EDE8E8ECF7F7F3F3FFECF4F4F4F7F4E2C8C563
63D6E9FFEEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB49DC5DE
E7E8E7F8EFF8EFF7EEFFF0ECF3F8F8FFFFF8F4E2E9F4EFE8
ECF7FFF8EEEEE5E1FFE9F4F4F7FFF7F7DBF8FFEEEEF0F8F8
F0F8EDCDF7EEF4E8F8F8F0F8F8ECECFFFFF3F3FFFFFFFFFF
F7F7FFFFFFFFF7F3F7F3F3FFF7F3F7FFFFFFECF8FFFFFFF7
F7FFFFF7F7F7EDE2E5FFFFF4EFF4FFF8FFFFF8F8FFFFFFFF
FFFFF8EDECF7F0F0FFF7F7F7E5EDF8FFFFF8F4E7E5E5F048
DBF0F0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B59AD6
E7E7E6EFEDFFF8F8F4E5F8E5EFF4F4F7FFF8F4E8F4F7E8ED
E7F4F8E8F4F4E8ECF8E9F8F8FFF3F3F7E8F8FFE9FFF0E9F0
E9F0D0C6F7EFE3D7F7F0F0F7F7EFEFFFF7F7F7F3F3F7FFF7
FFF7FFFFFFF7FFF3FFF7F3FFF7F3F7FFFFFFF7F4F8F8F8F3
FFF7F7FFF7F7E5EEE8E7FFF4FFF4F8FFFFFFFFFFFFFFFFFF
F8EDECF7FFFFF0E7F3FFF3F7F0F0F8FFF8F0E6E5DFF0ED3F
FFF0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE59FB4
E7E1EEF0F7EFFFF4E7FFE5EEF4FFE8E2F4F4F4FFF4E5DCE8
E5E1E7E8F4E5E7E8F8EEF8FFFFF3F3FFF8EEF0EEF8FFFFFF
F0F0D0DDE5F3E3D6F7F3F7F3F3FFF7F7F7F3F7F7F7F7F7F7
F7F3FFFFFFF7F7FFF3F7FFF7F7F7FFFFF8E6E8EFF7FFF8F4
EFF7F7FFFFEDF0DDDDFFE5F8F8FFFFFFFFFFFFFFFFF8F4ED
ECF7F0F0FFFFFFF3F7F7FFF8F4F4FFFFEEE8F8F3E3EDA578
EDF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8C59D
BECAFFF0E1ECF8F8EEF3ECF8F4EFDFFFEEF8FFF8EEE9E9F4
FFF8ECF4F4DCF8E1F8F0F8FFFFF7F7F7F3F7E9F8EEFFFFFF
FFFFE8F0D6F3F0EDF7FFF3F7FFF3FFFFF7FFF7FFFFF4ECFF
FFF7F7F8F4F8FFF7FFFFF7F3FFF3FFF0E6F0E8DED7F4FFF8
F4F7FFFFFFF0EDF3FFE5F0ECE8E8EDF4F8F8EDEDEDECF3E7
F0F0FFF0F7F7FFF7F7F8EEEEF4F4FFF0F0F8F7D6EDD286B5
E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0BE
9DA5CFE7DEF8EFF8F8EDF8E5F8EFFFDBE2FFF4F8F8F4F8F4
EFE5F4F4EED6F8E7E5F4F0F0FFF7F7F3F7F7F0E9F0FFFFFF
F7F7F7DFDDF7F7FFF7F7F7F7F7F7F7FFF7FFF7F7F3ECF4F7
FFFFF3F8F4F8FFF7F7F7F7F7F7F3FFF0E6EFEFF7DFDFF7FF
FFF7F7FFFFFFFFFFEDE5F7FFFFFFEDE5ECECF7F7F7FFFFF0
FFFFE7F7F3F3FFFFF0EEF8E9F0F0EEF8F8F4E7E2F4A991DB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0
B69DB5D6F8DFF4F4F8F8EFF7F8FFEFE1F8E1E5EEE9F0E5E2
DCCBEDEEF4D0FFF8E1EEF0F0FFF3F3F7F7F7F7FFFFFFFFFF
F7FFFFF7F7F7F7EDF0F7F7F7F7F7F3FFF3F7F7F7F7FFF4EF
F7FFF7F4F4F8FFFFFFF7F7FFF3F7F7FFE8D7F8F0E8C4CEF3
F7F7F7FFF7F3F7FFF0F0F0F0F0F0E9F0E9F0FFFFFFF8E6E6
F8F0F3F7FFE7EEF4F8E9E7F4EEE8F8FFF8E5EEF8CF88ADF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F0BD8984CFDFE6F4F8FFF8F4F4E8EFF8EFDCE5F4F4F4E8E5
E7EDE7DFE9DBF4FFECE8F0F8EEE7F7FFFFF7FFF7FFFFFFF7
F7F3F7F7FFF3FFE5F0FFF3F7F7F7F3FFF7F3F7F7FFF7F4FF
EFF7FFEFEDFFF4F8FFF7F3F7F7F3F7FFFFE3DFE7D2D6E6B6
A6C9F0E8DBE5F7FFF7F7F0E7E7F0F0E9E9FFE9F0FFF8E6E6
F8FFE6D1D7F4F0F4F8E9E2E5FFF0FFDEDCE7E79B548AE7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8D68DA1EFE7F0F4F0F8F8EDECF4F8F8EEEEF4F8F8E9DE
E1DCE1DFE9DBF8F4F7F4EEFFEEF0FFFFF7F3FFF7FFFFFFF3
F7FFF7F7F7EDE5ECFFFFF3F7F7F7F7F3F7F8F8F7FFFFF7ED
F4F7F7F0E5F8F8F8F4F4F8F3FFE8E3F0E8F8E3AFECDECBF3
D6EDD0E2F8E8E3DED7DDF0F7FFF7FFFFFFF0E9F0F7F7F8EE
E9E9EEF4DEE2FFEEF0FFF8F4FFF8F4E1FFE7A564BDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCE68F0EDDFF8F8F8FFFFF4F7ECEDEFDEE9F4F8EEE2
DCDCE1DBDBE1F4DCF8F8EEF8F4F8FFFFF3FFF3F7F7FFFFF7
F3F7F3F7FFE7E1F4F7FFF7F7F3FFECEFF7ECECF3FFFFF3EC
F8FFF3F0E5FFF8F4F8FFF4F7F3DBEFD6E8E2D0D7DEE5ECDE
EEDCD6EDFFF8F8FFFFF8E8E9E7E7F0FFFFFFFFFFF4E5F4F4
F8F4F8F0F4E5EEF8F8F4FFF4F8F8EFE5F8BC72B4F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF88195EDEDEFF4EEEEF8F4F7F7F7EFE7EFF8F4F4F4
F4F8F4EEE7F4EEE2F4FFEEF4F4F0F8FFF3FFF7F7F3FFFFFF
F7F3FFFFFFF7F7F7F3FFFFF3F7F7ECFFEFFFFFFFF7FFF7FF
F7FFF3FFF7F7F8F8F8F8F8F4F8E7CBE8EFEFF8F7E5CBE8EF
D3B3CBFFF4F4EEEEEEEEF8F8E6EEE9FFF0E9E9E9EEF8EEEE
E3F4FFF8EEF8FFFFF8DEE2F4DED6E8EEBE639DF8FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFDE858DE8F4EFFFF4F8EEEEEFF7F8EFEDFFFFE7E2
E9EEF8EEFFEEF8EFEFF4EFF4F8F8EEFFF7F7FFF7F7FFFFFF
F3F7FFF7F7F3F7F3F3FFFFF3FFF3F7EFF8F7FFF7F7F7FFF7
F7FFF7F7FFF3F8F8FFF8F4F4F8F8EDC6E6DCE8EDE1F4D5D6
E7F3DEC1CBCBC6CBD6D6DCE1E1DBD0C6DDF4F4EEE9E2EDF8
EEE8F0F8FFF8F4F4E5EFECF7EDEEFFC66295F4FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8DE839CE7F7EFF4FFFFF8F0EFF3FFEFF4F4EDED
F4F4F8DBE2F4E6EFEFECF3FFF4F8E8F0F0E7F7F7F7FFFFFF
F3F7FFF3F3F7F3F3F7F7FFF3FFF3F7FFF7FFF7F7FFF3FFFF
FFFFF7F7FFF7F7FFFFFFFFFFF7EFF4F4C6CCF4F8F8EFE8FF
D6CBC8CBDBEEF4EEF4F8FFFFF4EEEDE1E5E6E6FFEEDDD7DB
E1ECECEDEDECF3ECFFE5F4F7F7F4F8708AF4F8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCF8A83CFECF8F4F4F4F8F8F4ECF7E7EEF4F8
FFFFE5FFF0DBDFE6E5F7F7FFF4F8F8F0F8F8E7F7F3FFFFF0
E7F3FFF3F7F7FFF7FFF3FFF7F7F7F7F7F7F8F8F3FFF3FFFF
FFFFF7F7FFFFF7F7F8F8FFFFF3F7F3F3FFD6D3DEF4F8F4F4
D6DCF8F8F4D1B5B5BAC0D0E1E5E8F4F8F4E6DEE3EEEFECF4
FFFFFFF7F7F7ECE1E5F8EDECE5EED639DFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE7A15A6BC5F8E9EEF8F8F4F7E8EDF0F8F4
FFFFE5EFDFEDE2D7DFE5F8F8F8F8F4F4F0FFF8DDE6FFFFF0
FFF0F7F3F7FFF7F3F7F7F7FFF7F3F7FFF7EFF8F7F7F7F7FF
FFF7F7F3FFFFFFF7ECECF7F7F7FFFFFFE6DDF0DFC9D6EFF0
E9EEE5E5EFDDCBCBC0BACBE1E1D6DCE8ECF7FFF7F7F3F4EC
F3ECE1DCDCE8F8F8DED1DBF4CE85477CFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF09C56EFF4F8F4E3E6FFF8FFF4F8F0
F4F8F4EFEFE7DEDBF8CBF8F8FFF4F8F4F8F4F4F8EDCBD7FF
E3E8E9F0FFFFF0F0F7F4EFF7FFFFF3FFF3F7F3F7F7F7F7F7
FFF3F7F7F0F0FFFFFFF0E7F7FFF0E3E8E8E3F0F8E6EEEDEC
EFF0DEE7EED0CBD3CBBACBD0C6C5C5C6CBE2F4EDDEDBEDFF
F8F0F8FFF8F0EDECE2FFFFDE747BCEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF659DE1EFF4EEEEF8F8F8EEEEF0
F8F8F8EFF8ECD6CABEABE7FFFFF8FFF4F8F8FFF4E7E7DBE3
E6F8F4E6E3F0F0F0E8D7F4F3FFFFF7F7F7F7F0E7F7F3FFF7
F7F3F0F0E9F0F0FFF0F0EEE8FFF0E8E8D4F0F0E3E6FFF8F4
EFD1D0F8D0D0E3FFF0FFF0F0F0EEF0EEE9F8EEEEF8E6F8EE
EEFFF4F4D7E1F7F0F0F8DE7C7CDEF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFBE74B5DFE7FFF0F8FFF8F4F8F8
F0F4F8FFECF0E1F4ECB4E7E5F4F8F8F4F8FFF4FFF8E7EDFF
F8FFFFFFF8E6E8F0EEE8CBEDF8F8FFF7F3F7F0F0F7F7F0F0
F7F8DFFFD7E5E3FFE3F8F8E2CFF0F0E1EDC9D0DEE6F8FFF4
FFF0F8D0D3EFF8E6E3E9E3DEE6F4F0F8F8FFE2DDF4F4EEFF
F4E7EDE5F4EDF8EEFFBD707CDFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFB67894CBF4E6F8F4F8FFFFF8
EEF0F8F8DBF4DEE8F4D7CCDED7F4FFFFF8F8F8F4F8F4FFF8
F8F7F7FFF7F3DFE6EECBD6BCF8F8E9EDF7F0EEEEE9E9F0E9
E8D7EFEDCDFFD7DEF0D6C8F8EED0F8EFDFE5C8D2DBD6E7F8
E5E7EEE3EEF4F8FFEDE1F7F8F8F4F8FFF4E5FFEDFFE8DCDB
E1F8FFF4F4D3E2F8AD6292DEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFD78C74D2ECDEF8F4E8EDFF
F4EEF8E7E8EEF8F4FFEDD3E7DED6EDF8F8FFF4F8F8FFF4F4
F8E7FFF3F7F8ECFFE8E7BECEC7E9F0EDFFE7F8F0F4F4F8E2
E2E8D0C8DFD2D2E7DFD5E2B4E7DBABCEEFBDB2EDEEF8DFE1
EFE7E8EFEDE8ECF7ECF8ECFFFFF4EDE8ECF8F8DCDBE8F4F7
F4EDEDF0E8F7EFF84BAEF4F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE78D81B6C5E8EDECFFEF
F4F0F0E7E8EFFFE5E1EDE1E5F4F0DEE5E8E5EEF8F8FFEEF8
F4F8E5ECF7F4EFE8E8D7E2D6D4E7F0E8DBF0E7E8F8FFEDF8
F8E7E8E8DBC8CBEFEDEFBCE9DBCCD3C1B2D0E6E1D0DBE6F4
F8EDECFFFFF3F3F7F3FFF7ECECF3F7FFF8E5EFF4FFE7E8EF
F7E7FFF0EEDBE5B640F8FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7AC8D87E7EEF0EFF7
F7ECE2EFF4E7E1E7E5E5EDD3CDEDF0E6EEEDDCD6DEF4F4F8
F4FFF8F4E5F4F8F8FFEDDFEDDBC7D4F8F0DEE6F0E6E8E7E7
EDEDEFDBDBCFD7DFF4DCE1DBE8BDDCD7CBEEDBCBD1EDF8F8
F8ECEFF4F4E8E8E8EDF4F4EEE9F0FFF8FFEDF4E8DCEFFFFF
F7E7F0E7E5D77850A5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8D66B6086B2D4E3
E2E1DBF7EDF4D6C4D2D6DDE5F8CFCFDFEEEEF0E2C8B9BFD1
C9D1E1F4E7EDF8F8F0EEDEC9E5F4D1A7BFE1CBBADFD6C5DB
E5F8F8E7D6D7DFEED0E5DDDBDBCEE5CBDBEEF8EEEEF8F8F4
F8EDF4FFF8F8F4EDEDF4EDDCD1E8FFF4ECFFF7EFDDE1E8E8
E5F7E7B2311969C6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7C3A39BB4D1
D6F0EEF8F0EEEEF4F4E1E9F4F8E5EDE5E8DCD6EDF8F0E7EC
E1D0D4DBE1EFFFFFEEF8FFDEBAD4E5F7E2D3F4E5AED0CBCB
E6EDE7E7E7DEE2D7EFF0E1EEF0F8E7E5F8E6E9F8F8F4EEEE
F8F8F4FFF4EFF7ECEFF3F7EDDCF4F7EDDCE8F4EEE8EEF8F4
E8E77A58A4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8D7B289AD
B4C8E5F4F8F4F8FFF8E1EEEDEDF8DED6DFF4FFF4EFE5F8EE
F8E7FFDCD0D1DBF0F8EEEED3EEDFCBF0E2E6D6E5EEC8CDD6
C9E6F8EFEDE1E5F8D7EDDEE5FFF8F8F8F4EEF4FFF4EEEEEE
F4F4E5E8ECEDEDEFEDECECEDF8F7E5F8F8F8F4F8EEE6E8E5
F85868C5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8EEC4A7
A5C3E5E7F8F8F4F8F8E1F8F8EFF4DED6DFF4F8F8E8E7E5F4
FFE5EDF4F4FFEFDBD6E2EEEFD6D7EEEFEFD4DEDFDBE8C5C9
DEF4F8EFF8FFDED1D0C1D6EEDFFFFFF8F8EDE1E8ECE8E1E8
E8ECEDF8FFF4EDE1EDF4F4F4F4EEFFFFFFF4F8F0E7F3FFCD
6053E5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7
B483AACEE5F8F4F8F8EDDBE7E5E7F4F4E7EFF8FFEFE8EFFF
F4F8F8F4F8F8FFF0E6E2E1E1E7DFE7EEEEDEE1E8DEF4D6DE
F8EFEFEFEFF8F8FFF8EDD3C1EDEEF4F8F8F4F3F7F8F7EDED
E1EDF4E8ECECF4F8F8F4F8FFF8FFF4F4F8F4DFE5F7E79C54
6BDEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8C595A1ABD7FFE7EDEEEEECF8F8F0E8DFDDEEF4E5E5F4F4
EEF8EDE7F8EDE5F4F7EDF0EED6CBDEF4EEEDDBCFF4CDEFDB
CEE2E7FFEFE8E1E5F4F4F4ECE8EEEEDEE3EEF8F4E1F4F8F4
F8F4E8F4F4F8F4E9E9E6E2E8EDE8F4F4F0DBEEE5B1634CA2
EEF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCE9D82759FE1ECF8FFEDE5E1DEE2DDEFEEEED6E5E5D3
EDF4EFE5FFE7EFF8E7F4E5F4F8FFF8F4F0E5EFF7CEE2F4F4
DBECDEDBE9E9EEE5DCDCDCE2D4E2F8EEEEFFEEF4F8E5EDF4
EEF4F8F0E9E9E5E8E1E8EFEFFFF7DDDBE5EE9C57447ED7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F4DEA773452E5DB4E5F0F4E2D1CED7EFD0B4CFF8F4
E5DBE5EDE2DCEFF8FFDEE5F8F8F4FFF8F4F8EFE8DEEEEEE2
CDE5F4E7EFFFF8E5DCE7EFEFE7E7F8F0F4F0F8F8F0E2D0D6
D6D1D1DBE8E1E8F8F8FFE7D0D7D7EFB9601B3C9AE7F8F8FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8A4696996C1DFF4EDEDD3D4D6F4EFEF
F8EFEDEDE7EEDFEFF8F4FFF8EDEDFFFFFFEFE8EDDDD1F7DB
E5FFEFE5EFECF3F8E8F4EFECF4EDF4F8F4F8F4E1E1E5F4F8
F4F4F4EEF0F4F4EDECE1DEF4E9BC73567ECFF8FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFDFA7827B7E7A94BDC5D1D7EEDDDD
C4B4CCEEF0EDDED7EDEDE5EEF7EFE7E7FFEFECF7ECEFEDDB
E2F4F4EDEEEEE9E5DBE6F8EDECF7F4E8E1DCE8E8E9EEEEF4
F0E2DCDBE6DBCBDBEEEEEDCC8D527CCCF4F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF0C4A89D8266667A8B9DA2A6
ABC4B4CBDBDBDFD6C1DDE2E5ECE8D5E5FFFFF4E9E2E2EEE5
F4F3F3F7F8F4F8F4EEEEF4FFF8F4F0F8F8EEEEE8E3DEDEDC
E1FFF3F8E1E7FFFFF8DB6C5973C5F8F8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8EEEEEEE2E1EDE5
EFF8CCD7E1DDCFBDB3CBE7F0E9E3DFEDFFF8EEFFF8F8EEE5
D6E8E8F4F8F8F8F0FFF4F8FFFFFFF8F0F4F8F8F8F4F7F7F8
FFEFF3E5FFEED49C79706CDBF4F8FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F4F4
EEEEE2DBDBF0E1DFE8B99CB9E7EDDEDBDBE5DFEEF0EEFFE8
EDF8FFF4F4EDF7EDDEEEF4F4F4F8F8FFEEEEF8F8F8F3FFF8
F8F4E9EFB286697097B2D6F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F0F4F4F0DEE1EFF4EDF0DEC5ABB4BDC8D6E9DCBEC5DDE5E5
F4FFF8F4F4EFEDE5E5EFE5F8FFF4F8F8F8F8F8EFECEDF4FF
F4D499616991C1E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8EEF0F8EEE9EEF4F8F0E2D6CBC0A78B7A859DA2999D9F
A8A8B4D1D6DBDBDBE8F4EFF4E8E1D0C0BAB49D6D462E2228
28386BAAE5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8F8F8F8FFFFFFFFFFFFF8EEE2D0C0AE
A2A39B908B91ADA38C857A73746E6D7A7F8597B6D6E5F4F4
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F8FFF8F8FFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
F8F4EEE9E3C5BAC5D1D1D6E2E9EEF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=",
  ImageSize->{450, 140.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720000S2000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00D@3oool20??cl`h0oooo00<0lo?c0?ooo`3oool00P3clo<00`3oool0lO7a0?ooo`060?oo
o`050??cl`3oool0oooo0?ooo`3clo<00P3oool00`3Vi^H0bl_;0?ooo`0k0?ooo`030?Cdm03oool0
oooo0080oooo00<0m?Cd0?ooo`3oool05@3oool00`3?cll0m?Cd0?ooo`040?ooo`030?Cdm03oool0
oooo0080oooo00D0m?Cd0?ooo`3oool0oooo0?Cdm0020?ooo`80l_;b2@3oool01@3dm?@0oooo0?oo
o`3oool0l_;b00<0oooo00<0WYjN0?ooo`3oool03P3oool0103dm?@0oooo0?ooo`3dm?@X0?ooo`03
0?Cdm03oool0oooo0080oooo00<0m?Cd0?ooo`3oool05@3oool01036a/H0m?Cd0?ooo`3clo<30?oo
o`030?Cdm03oool0oooo0080oooo00D0m?Cd0?ooo`3oool0oooo0?Cdm0020?ooo`80m?Cd2@3oool0
103dm?@0oooo0?Cdm03dm?@40?ooo`0308b<S03oool0oooo00h0oooo00@0m?Cd0?ooo`3oool0m?Cd
=P3oool005l0oooo00<0lo?c0?Ogm`3oool00`3gmoL30?Gem@H0oooo00<0moOg0?ooo`3gmoL00P3o
ool0103gmoL0oooo0?ooo`3^k^hk0?ooo`030?Ogm`3oool0moOg00<0oooo0P3gmoL=0?ooo`030?Og
m`3oool0oooo00L0oooo00<0h>3P0?Ogm`3oool00P3oool30?Ogm`040?ooo`3gmoL0oooo0?ooo`80
moOg00<0m?Cd0?Ogm`3gmoL00`3fm_H0103dm?@0moOg0?Ogm`3oool30?Ogm`<0oooo00<0m?Cd0?oo
o`3oool0103oool00`3fm_H0fMWI0?ooo`040?ooo`050?Ogm`3oool0oooo0?Ogm`3oool00P3gmoL8
0?ooo`030?Ogm`3oool0oooo02<0oooo00<0n?Sh0?ooo`3hn?P00`3oool20?Shn0d0oooo00<0n?Sh
0?ooo`3oool01`3oool01@3@d=00n?Sh0?Ogm`3clo<0oooo00<0n?Sh00@0oooo0?Shn03oool0oooo
0P3hn?P00`3Xj>P0kno_0?Shn0030?Shn0040??cl`3gmoL0n?Sh0?ooo`<0n?Sh0`3oool00`3dm?@0
oooo0?ooo`020?Shn0040?Cdm03hn?P0m?Cd0<c<c0D0oooo00D0n?Sh0?ooo`3oool0n?Sh0?ooo`02
0?Shn0P0oooo00<0n?Sh0?ooo`3oool0<`3oool005d0oooo0P3gmoL30?ooo`040>[ZjP3emOD0oooo
0?Gem@80oooo00D0moOg0??cl`3gmoL0oooo0?Ogm`030?ooo`040?Ogm`3oool0moOg0?Ogm`80oooo
00<0iNGU0?ooo`3oool0=P3oool20?Ogm`@0oooo0`3gmoL50?ooo`<0moOg4@3oool00`3Ph>00oooo
0?ooo`020?ooo`070?Cdm03gmoL0moOg0?Ogm`3oool0m?Cd0?ooo`040?Ogm`040?ooo`3^k^h0m?Cd
0>o_k`<0oooo0P3gmoL00`3dm?@0moOg0?Cdm0020?ooo`030?Cdm03gmoL0oooo00@0oooo00<0k^k^
0?ooo`3oool0203oool00`3gmoL0oooo0?ooo`070?ooo`030?Ogm`3oool0oooo0080moOg7`3oool2
0?Shn0@0oooo0`3hn?P50?ooo`<0n?Sh4@3oool00`3@d=00oooo0?Ogm`020?Ogm`070?Cdm03hn?P0
n?Sh0?Shn03oool0m?Cd0?Ogm`020>o_k`80n?Sh00D0oooo0?Cdm03gmoL0moOg0?Shn0020?ooo`80
n?Sh00<0m?Cd0?Shn03dm?@00P3oool00`3dm?@0n?Sh0?Shn0030?ooo`030?Cdm03^k^h0oooo00T0
oooo00<0n?Sh0?ooo`3oool01`3oool00`3hn?P0oooo0?ooo`020?Shn380oooo001A0?ooo`030?Og
m`3clo<0oooo00L0oooo00@0moOg0=WIf@3AdM40hn?S0P3Zj^X00`3oool0mOGe0?Gem@030?ooo`05
0?Ogm`3oool0lo?c0?ooo`3clo<01P3gmoL01@3clo<0moOg0??cl`3oool0h^;R03P0oooo00<0moOg
0?ooo`3gmoL00P3oool0103gmoL0oooo0?Ogm`3oool20?Ogm`030?ooo`3gmoL0moOg00T0oooo00<0
moOg0?ooo`3oool0203oool00`3IfMT0m?Cd0?ooo`020?ooo`<0moOg0P3oool02P3gmoL0kNg]0>g]
k@3gmoL0l_;b0>g]k@3_knl0gMgM0>c/k03^k^h20?ooo`030>c/k03gmoL0moOg00D0oooo00<0moOg
0?ooo`3gmoL0103oool00`2h^;P0oooo0?ooo`080?ooo`030?Ogm`3oool0oooo02/0oooo00<0n?Sh
0?ooo`3hn?P00P3oool0103hn?P0oooo0?Shn03oool20?Shn0030?ooo`3hn?P0n?Sh00T0oooo00<0
n?Sh0?ooo`3oool0203oool00`3@d=00m?Cd0?Ogm`020?Ogm`<0n?Sh00`0moOg0?ooo`3_knl0n?Sh
0>o_k`3oool0k^k^0>SXj03gmoL0inOW0>k^kP3hn?P20?ooo`030?3`l03_knl0n?Sh00D0oooo00<0
n?Sh0?ooo`3hn?P00P3oool00`3hn?P0oooo09nOW`0:0?ooo`030?Shn03oool0oooo03h0oooo001A
0?ooo`030?Ogm`3oool0oooo00D0oooo00H0moOg0?ooo`3gmoL0lo?c0?Ogm`3oool20?Ogm`030??c
l`3oool0lO7a00H0oooo00<0moOg0?ooo`3oool00P3gmoL0103oool0moOg0?ooo`3gmoL30?ooo`03
0=WIf@3oool0oooo03H0oooo00D0moOg0?ooo`3oool0oooo0?Ogm`090?ooo`030?Ogm`3oool0oooo
00D0oooo00<0moOg0?ooo`3gmoL02@3oool01@3?cll0oooo0?ooo`3oool0moOg00<0oooo00@0moOg
0?ooo`3gmoL0m?Cd103^k^h20>g]k@080?ooo`3^k^h0h>3P0>GUi@3dm?@0oooo0?KfmP3_knl30?oo
o`030?Ogm`3dm?@0oooo00D0oooo00<0/;2`0?ooo`3oool01`3oool01P3gmoL0oooo0?Ogm`3oool0
moOg0?ooo`80moOg0P3oool20?Ogm`040?ooo`3gmoL0moOg0?Ogmal0oooo00D0n?Sh0?ooo`3oool0
oooo0?Shn0090?ooo`030?Shn03oool0oooo00D0oooo00<0n?Sh0?ooo`3hn?P02@3oool06P30`<00
oooo0?Ogm`3gmoL0n?Sh0?ooo`3gmoL0oooo0?Shn03gmoL0n?Sh0?Cdm03oool0n?Sh0?Cdm03`l?00
lo?c0?Ogm`3dm?@0n?Sh0>k^kP3`l?00m?Cd0?Ogm`3oool0l?3`0`3oool00`3hn?P0m?Cd0?ooo`02
0?ooo`040?Shn03dm?@0oooo0::RXPT0oooo00H0n?Sh0?ooo`3hn?P0oooo0?Shn03oool20?Shn080
oooo0P3hn?P0103oool0n?Sh0?Shn03hn?Pb0?ooo`00D@3oool00`3gmoL0oooo0?ooo`040?ooo`07
0?Ogm`3clo<0moOg0>?Sh`3clo<0oooo0?Ogm`020?ooo`0;0?Ogm`3oool0lo?c0?ooo`3alO40moOg
0?ooo`3alO40oooo0?Ogm`3clo<00P3gmoL01@3oool0lo?c0?ooo`3gmoL0lo?c0080oooo0P3gmoLi
0?ooo`030?Ogm`3oool0moOg00D0oooo0P3gmoL70?ooo`030?Ogm`3oool0oooo00d0oooo00<0e=CD
0?Ogm`3oool0103oool40?Ogm`0G0?Cdm03oool0moOg0?ooo`3Kfm/0i^KV0?Ogm`3dm?@0moOg0>k^
kP3gmoL0j>SX0?Ogm`3^k^h0l_;b0>CTi03_knl0moOg0?ooo`3gmoL0m_Kf0?ooo`3gmoL00P3oool0
0`3gmoL0j>SX0?ooo`070?ooo`H0moOg0`3oool00`3gmoL0oooo0?ooo`0U0?ooo`030?Shn03oool0
n?Sh00D0oooo0P3hn?P70?ooo`030?Shn03oool0oooo00d0oooo00T0^KVi0?Shn03gmoL0oooo0?Og
m`3oool0moOg0?Cdm03]kNd00P3_knl0303]kNd0moOg0>o_k`3oool0m?Cd0?Shn03dm?@0lo?c0?Cd
m03hn?P0moOg0??cl`80n?Sh00<0oooo0>GUi@3Xj>P00`3hn?P01`3dm?@0oooo0?Shn03hn?P0oooo
0?Shn03Rh^80203oool60?Shn0<0oooo00<0n?Sh0?ooo`3oool0=`3oool00540oooo00<0lo?c0?Og
m`3oool00P3oool20?Ogm`030?ooo`3clo<0moOg00H0oooo00L0moOg0?ooo`3oool0oooo0?Ogm`3c
lo<0moOg0080lo?c0P3emOD00`3gmoL0oooo0?Ogm`040?ooo`040?Ogm`3oool0moOg0?OgmcT0oooo
00<0moOg0?ooo`3oool0103oool00`3gmoL0oooo0?ooo`020?ooo`<0moOg00<0oooo0?Ogm`3gmoL0
3`3oool00`3Kfm/0moOg0?ooo`020?ooo`80moOg00<0oooo0?Cdm03dm?@0103gmoL20?ooo`050?Og
m`3bl_80m_Kf0?KfmP3oool00P3dm?@02@3gmoL0m?Cd0?Ogm`3/k>`0jn_[0?Ogm`3_knl0oooo0?Og
m`040?ooo`030>o_k`3gmoL0oooo03P0oooo00<0n?Sh0?ooo`3oool0103oool00`3hn?P0oooo0?oo
o`020?ooo`<0n?Sh00<0oooo0?Shn03hn?P03`3oool02P2i^KT0n?Sh0?ooo`3gmoL0oooo0?Shn03_
knl0oooo0>SXj03]kNd40?Shn080moOg0P3hn?P0103oool0n?Sh0?Shn03gmoL30??cl`060?Shn03d
m?@0n?Sh0?Shn03WinL0oooo0P3hn?P20?ooo`030?Shn03`l?00n?Sh04/0oooo001A0?ooo`050??c
l`3oool0oooo0?ooo`3clo<00P3gmoL;0?ooo`040?Ogm`3oool0oooo0?ooo`80moOg0P3oool00`3e
mOD0oooo0??cl`030?Ogm`80oooo00<0lo?c0?ooo`3Fe]H0>@3oool00`3gmoL0oooo0?ooo`0O0?oo
o`050=_Kf`3oool0oooo0?ooo`3dm?@00P3gmoL20?ooo`80moOg00@0m?Cd0?ooo`3gmoL0oooo0`3g
moL00`3clo<0moOg0?Ogm`050?ooo`030>KViP3fm_H0jn_[0080kno_0`3oool00`3gmoL0oooo0>GU
i@080?ooo`80moOg00<0m?Cd0?ooo`3oool0;03oool00`3hn?P0oooo0?ooo`0O0?ooo`090;no_`3o
ool0moOg0?Ogm`3Xj>P0kno_0?Shn03oool0moOg0080n?Sh00H0m?Cd0?ooo`3hn?P0moOg0?Shn03d
m?@50?Shn0090?ooo`3gmoL0oooo0?Shn03^k^h0oooo0?Shn03UiND0l?3`00<0oooo00<0l?3`0?oo
o`3@d=00203oool20?Shn0030?Cdm03oool0oooo03l0oooo001A0?ooo`030?Ogm`3oool0oooo00<0
moOg3@3oool01@3clo<0moOg0?Ogm`3oool0moOg00<0oooo00X0mOGe0?ooo`3gmoL0oooo0>GUi@3g
moL0oooo0?Ogm`3clo<0k>c/>P3oool30?Ogmah0oooo00<0m?Cd0?ooo`3oool00`3gmoL30?ooo`05
0?Cdm03fm_H0oooo0?ooo`3dm?@00P3oool01`3gmoL0oooo0>GUi@3WinL0moOg0?;blP3fm_H00P3g
moL20?ooo`030>k^kP3bl_80moOg0080moOg00D0oooo0?Ogm`3oool0m?Cd0<S8b0070?ooo`030?Og
m`3oool0oooo00<0oooo00<0moOg0?ooo`3oool0:P3oool30?Shn1h0oooo00<0g=cL0?ooo`3oool0
0P3_knl01P3hn?P0oooo0?ooo`3oool0m?Cd0?3`l080oooo00L0m?Cd0?ooo`3oool0n?Sh0?Ogm`3h
n?P0l?3`00<0n?Sh00<0moOg0?ooo`3oool00P3hn?P02@3oool0n?Sh0>o_k`3WinL0oooo0?Shn03o
ool0m?Cd0:RXZ0070?ooo`030?Shn03oool0oooo00<0oooo00<0n?Sh0?ooo`3oool0?03oool00500
oooo00@0g]kN0?Ogm`3oool0moOg4@3oool20?Ogm`80oooo00P0lo?c0?ooo`3emOD0lO7a0?Gem@3o
ool0lo?c0=WIf@<0oooo00<0moOg0<k>cP3oool0>03oool00`3gmoL0oooo0?ooo`020?ooo`040?Og
m`3oool0oooo0?OgmaP0oooo00@0bl_;0?ooo`3oool0moOg1@3oool40?Ogm`<0oooo0P3gmoL0203d
m?@0oooo0>CTi03dm?@0moOg0?ooo`3dm?@0kNg]103gmoL00`3fm_H0kNg]0>SXj0030?ooo`030?Og
m`2_[jl0oooo00D0oooo0P3gmoL40?ooo`030?Ogm`3oool0oooo00@0oooo00<0moOg0?ooo`3oool0
8`3oool00`3hn?P0oooo0?ooo`020?ooo`040?Shn03oool0oooo0?Shn1P0oooo00D0_Kfm0?ooo`3g
moL0kno_0?ooo`020?Ogm`030?ooo`3gmoL0n?Sh00<0n?Sh0`3oool20?Shn0040?Cdm03gmoL0m?Cd
0?Cdm080n?Sh00<0moOg0??cl`3hn?P00`3hn?P00`3oool0k^k^0?3`l0030?ooo`030?Shn02SXj<0
oooo00D0oooo0P3hn?P40?ooo`030?Shn03oool0oooo00@0oooo00<0n?Sh0?ooo`3oool0=P3oool0
04l0oooo00<0/k>c08n?S`3gmoL00P3gmoL@0?ooo`040?Ogm`3clo<0moOg0?ooo`80lo?c103emOD0
103oool0moOg0?ooo`3oool20?Ogm`80lo?c>@3oool30?Ogm`X0oooo00<0moOg0?ooo`3oool0403o
ool00`2VYZH0V9RH0?Ogm`020?Ogm`H0oooo00H0moOg0?Cdm03gmoL0oooo0?Ogm`3oool20?Ogm`80
oooo00@0moOg0>c/k03bl_80m_Kf0`3gmoL20?ooo`030?Cdm03clo<0lo?c0080oooo00@0kno_0?Og
m`3dm?@0]KFe1`3oool30?Ogmbl0oooo0`3hn?P:0?ooo`030?Shn03oool0oooo0100oooo0P2][Jd0
0`3hn?P0kno_0>o_k`060?ooo`0<0?Shn03dm?@0n?Sh0?ooo`3hn?P0oooo0?Shn03dm?@0oooo0?Og
m`3hn?P0k^k^0P3hn?P20??cl`80n?Sh00@0oooo0?Cdm03hn?P0m?Cd0P3oool0103`l?00n?Sh0?Cd
m02MWId70?ooo`<0n?Sh@P3oool004h0oooo00@0WinO0<O7a`21PH40f][J3`3oool00`3gmoL0oooo
0?ooo`020?Ogm`80oooo00D0moOg0?ooo`3oool0oooo0?7al@030?ooo`060??cl`3gmoL0moOg0?oo
o`3gmoL0lo?c>P3oool00`3gmoL0oooo0?ooo`030?ooo`030?Ogm`3oool0oooo00<0oooo00<0moOg
0?ooo`3oool03`3oool01024Q8@0^k^k08F5Q@3_knl20?ooo`030?Ogm`3oool0moOg00<0moOg00D0
oooo0?Ogm`3gmoL0oooo0?Ogm`020?ooo`060?Ogm`3oool0moOg0?Cdm03oool0m_Kf0P3oool20?Og
m`050?ooo`3]kNd0m?Cd0?Cdm03oool00P3gmoL0103_knl0moOg0?Ogm`3?cll90?ooo`030?Ogm`3o
ool0oooo02h0oooo00<0n?Sh0?ooo`3oool00`3oool00`3hn?P0oooo0?ooo`030?ooo`030?Shn03o
ool0oooo00l0oooo00P0SHf=0;fm_@2GUiL0oooo0??cl`3oool0n?Sh0?ooo`@0n?Sh00/0oooo0?Sh
n03dm?@0moOg0?Shn03oool0moOg0>o_k`3clo<0kno_0?Cdm0020?ooo`030?Shn03oool0oooo0080
n?Sh00@0k^k^0?Cdm03dm?@0oooo0P3hn?P0103Ogml0kno_0?Shn036a/H90?ooo`030?Shn03oool0
oooo0400oooo001=0?ooo`040?Ogm`3[jn/0moOg0>?Sha00oooo00<0lo?c0?Ogm`3oool00P3oool4
0?Ogm`060?Gem@3oool0oooo0?7al@3oool0lo?c0`3oool00`3clo<0moOg0?Ogm`0i0?ooo`80moOg
0P3oool20?Ogm`80oooo00@0moOg0?ooo`3oool0moOg4P3oool0103gmoL0m?Cd0?ooo`3MgMd30?oo
o`030?Cdm03oool0moOg0080oooo00<0moOg0?ooo`3oool00`3gmoL02@3dm?@0oooo0?Cdm03oool0
jn_[0>k^kP3fm_H0moOg0?Cdm0020?Ogm`80oooo00D0kNg]0?Ogm`3gmoL0l_;b0?KfmP020?ooo`03
0>g]k@3UiND0j>SX00l0oooo00D0moOg0?ooo`3gmoL0oooo0?Ogm`0U0?ooo`80n?Sh0P3oool20?Sh
n080oooo00@0n?Sh0?ooo`3oool0n?Sh4P3oool0103hn?P0m?Cd0?ooo`3Xj>P30?ooo`030?Cdm03o
ool0n?Sh0080oooo00<0n?Sh0?ooo`3oool00`3hn?P02@3dm?@0moOg0?Cdm03oool0k^k^0?Cdm03h
n?P0moOg0??cl`020?Ogm`040?Shn03oool0l?3`0?3`l0<0n?Sh00D0m?Cd0?ooo`3^k^h0gMgM0>;R
hP0?0?ooo`050?Shn03oool0n?Sh0?ooo`3hn?P0>03oool004d0oooo00<0EUIF08n?S`38b<P04@3o
ool0103gmoL0oooo0?ooo`3gmoL20??cl`030?Ogm`3oool0oooo0080mOGe00<0lO7a0?Gem@3oool0
0P3gmoL00`3oool0moOg0?Ogm`0l0?ooo`<0moOg0P3oool00`3gmoL0oooo0?ooo`0E0?ooo`03051@
D02QXJ40eMGE00<0oooo00D0moOg0?Cdm03gmoL0oooo0?Ogm`040?ooo`030?Ogm`3oool0moOg0080
oooo00P0moOg0?KfmP3bl_80oooo0?Cdm03gmoL0m?Cd0?ooo`80moOg0P3dm?@0103gmoL0oooo0?oo
o`3fm_H20?ooo`80moOg00<0kNg]0?ooo`3oool0>03oool30?Shn080oooo00<0n?Sh0?ooo`3oool0
5@3oool0301@D500[:b/0=oOg`3gmoL0lo?c0?ooo`3hn?P0m?Cd0?Shn03oool0n?Sh0?Ogm`<0oooo
00D0n?Sh0?ooo`3hn?P0oooo0??cl`020?Shn0080?Cdm03oool0lo?c0?Ogm`3clo<0oooo0?Shn03o
ool30?Shn0040?ooo`3dm?@0n?Sh0?ooo`80n?Sh00<0kno_0>k^kP3oool0B`3oool004/0oooo00D0
moOg04a<C03Fe]H0oooo0?Ogm`0?0?ooo`0;0?Ogm`3clo<0oooo0?Ogm`3clo<0oooo0?Ogm`3oool0
mOGe0?ooo`3emOD00P3oool0103gmoL0mOGe0?ooo`3oool20?Ogm`050?ooo`3gmoL0lo?c0>c/k03g
moL0>`3oool20?OgmaL0oooo00H0moOg03`l?03Lg=`0oooo0?Ogm`3oool20?Ogm`L0oooo00`0moOg
0?Cdm03gmoL0m?Cd0?Ogm`3Ti>@0k>c/0?KfmP3]kNd0j>SX0?Cdm03]kNd20?Cdm0080?Ogm`3_knl0
moOg0?Ogm`3oool0moOg0?ooo`3fm_H30?ooo`040?Ogm`3dm?@0eMGE0>o_kc/0oooo0P3hn?PG0?oo
o`060?Shn00o?cl0inOW0?ooo`3_knl0lo?c0P3hn?P20?ooo`@0moOg00d0oooo0?Shn03dm?@0n?Sh
0?Cdm03_knl0m?Cd0?Shn03oool0moOg0??cl`3oool0kNg]0080m?Cd00@0oooo0?Cdm03hn?P0n?Sh
0`3oool20?Shn080oooo00@0n?Sh0?Cdm035aLD0l?3`B`3oool004/0oooo00@0_;bl0<S8b01cLg<0
moOg4@3oool20?Ogm`050?ooo`3emOD0l_;b0?;blP3oool00P3emOD0103oool0moOg0?ooo`3gmoL2
0?ooo`080?Ogm`3oool0moOg0??cl`3oool0moOg0?ooo`3gmoLh0?ooo`030?Ogm`3oool0moOg0080
oooo00<0moOg0?ooo`3oool0503oool0102f][H0c<c<06a/K03gmoL30?ooo`80moOg1`3oool20?Cd
m080oooo00D0fm_K0=GEe@38b<P0fm_K0=7Ad@020>3Ph0040?ooo`3fm_H0m?Cd0?Ogm`L0oooo00<0
m_Kf0?;blP3oool00P3oool00`30`<00oooo0?ooo`060?ooo`80moOg;P3oool00`3hn?P0oooo0?Sh
n0020?ooo`030?Shn03oool0oooo01@0oooo00@0`L710<k>cP1[Jf/0kno_0P3gmoL00`3oool0n?Sh
0?Shn0040?ooo`030??cl`3gmoL0oooo0080m?Cd0P3oool02`3]kNd0emOG0=3@d03Ng]h0emOG0>WY
j@3^k^h0m?Cd0?ooo`3dm?@0n?Sh00D0oooo00@0m?Cd0?Shn03hn?P0n?Sh0`3oool00`2b/[80oooo
0?ooo`060?ooo`80n?Sh@@3oool004/0oooo00<0F5QH09RHV03clo<04P3oool01@3clo<0oooo0?oo
o`3emOD0l_;b0080oooo00H0i>CT0>k^kP3oool0oooo0??cl`3oool50?Ogm`030??cl`3oool0moOg
0080moOg>03oool30?OgmaT0oooo00<0EUIF0:NWY`3gmoL0103oool01P3gmoL0oooo0?ooo`3oool0
k^k^0?Ogm`<0oooo0`3gmoL00`3De=@0oooo0;bl_0020?ooo`0:0?KfmP3QhN40oooo0?ooo`3dm?@0
fMWI0?KfmP3oool0m_Kf0?;blPD0oooo00@0m_Kf0?ooo`3oool0moOg0P3_knlg0?ooo`<0n?Sh6@3o
ool01@10@400ZJVY0>g]k@3clo<0oooo0080moOg00<0n?Sh0?ooo`3oool00P3oool0103hn?P0oooo
0?ooo`3oool30?Shn0030>7Qh@3oool0bl_;0080oooo00<0l?3`0>c/k03oool00P3oool01`3]kNd0
oooo0?ooo`3hn?P0inOW0?Cdm03hn?P0103oool01@3hn?P0oooo0?Shn03]kNd0inOW04X0oooo001:
0?ooo`040=[JfP3Ng]h0OWin0??cl`L0oooo0P3gmoL60?ooo`0>0>?Sh`3oool0moOg0>KViP3clo<0
mOGe0?7al@3bl_80oooo0?Gem@3oool0mOGe0?Ogm`3clo<50?Ogm`80oooo0P3gmoL30?ooo`030>?S
h`3oool0oooo03P0oooo0P3gmoLF0?ooo`040<c<c03bl_80QhN70?Cdm0<0oooo00@0moOg0?ooo`3o
ool0oooo0P3gmoL02`3oool0i>CT0?ooo`3oool0moOg0=CDe03^k^h0oooo0:VYZ@2NWYh0b/[:0080
i>CT00T0hN7Q0?KfmP3fm_H0oooo0?KfmP3WinL0l_;b0?KfmP3^k^h00P3fm_H30?Ogm`<0oooo00<0
moOg0>o_k`2k^k/0203oool00`3gmoL0oooo0?ooo`0<0?ooo`030?Ogm`3oool0oooo0200oooo0P3h
n?PF0?ooo`040<o?c`3hn?P0RHV90>g]k@<0moOg00P0k>c/0?ooo`3oool0oooo0?Shn03_knl0oooo
0?Cdm080oooo00X0n?Sh0>7Qh@3Ogml0oooo0:j^[P2i^KT0b<S80>;RhP3Kfm/0j>SX0P3^k^h00`3h
n?P0l?3`0>SXj0020?Shn0030?Ogm`3_knl0n?Sh00D0n?Sh00@0oooo0?Shn03`l?00Xj>S203oool0
0`3hn?P0oooo0?ooo`0<0?ooo`030?Shn03oool0oooo0300oooo00190?ooo`040<S8b03Fe]H0T92@
0?Ogm`P0oooo00<0moOg0?ooo`3gmoL01@3oool01`3[jn/0moOg0?Gem@3^k^h0jn_[0?Gem@3gmoL0
0P3clo<30?Ogm`050>[ZjP3gmoL0moOg0?Ogm`3^k^h01@3oool0103gmoL0lo?c0?ooo`3oool20?Og
mcH0oooo00<0moOg0?ooo`3oool05`3oool0102`/;00dM7A09NGU`3gmoL30?ooo`030?Ogm`3oool0
oooo0080oooo0140m?Cd0>_[j`3oool0kNg]0?Ogm`3MgMd0oooo0?KfmP3]kNd0b<S80>CTi032`/80
fMWI0>3Ph03Xj>P0kNg]0?Cdm0040?Ogm`040>k^kP3_knl0m_Kf0?ooo`80m_Kf00D0oooo0?Ogm`3g
moL0oooo0??cl`020?Ogm`030>g]k@3UiND0oooo03D0oooo00<0n?Sh0?ooo`3oool05`3oool01034
a<@0cLg=09:BTP3hn?P20?Ogm`030?ooo`3_knl0oooo00<0oooo0140m?Cd0>k^kP3oool0k^k^0?Sh
n03WinL0oooo0?Shn03Rh^80d=3@0>GUi@34a<@0e]KF0=_Kf`3Xj>P0k>c/0?Cdm0030?Shn0080?oo
o`3WinL0kNg]0>o_k`3Xj>P0kno_0?Shn03oool30?Shn0050?Cdm03hn?P0n?Sh0>k^kP3Ng]h0B@3o
ool004P0oooo00<0moOg0<S8b03[jn/0103oool00`3gmoL0oooo0?ooo`030?ooo`030?Ogm`3clo<0
moOg0080oooo00h0lo?c0?ooo`3gmoL0alO70>GUi@3clo<0f=SH0??cl`3AdM40k>c/0??cl`3^k^h0
a<C40<k>cP80moOg0`3oool02`3gmoL0oooo0?Ogm`3oool0lO7a0?Gem@3oool0moOg0?ooo`3gmoL0
lo?c00<0moOg=`3oool01P3gmoL0oooo0?Ogm`3oool0moOg0?ooo`80moOg3P3oool0103gmoL0`l?3
0>CTi03UiND30?ooo`80m?Cd01d0moOg0?ooo`3gmoL0moOg0?;blP3dm?@0moOg0?Cdm03Ti>@0dM7A
0=gMg@3Ph>00aLG50<S8b03AdM40j>SX0>3Ph03/k>`0moOg0>KViP33`l<0c<c<0=7Ad@3UiND0m?Cd
0?ooo`3^k^h0k>c/0??cl`020?;blP040??cl`3dm?@0oooo0?Ogm`<0oooo00@0m?Cd0>CTi03gmoL0
kno_=`3oool01P3hn?P0oooo0?Shn03oool0n?Sh0?ooo`80n?Sh3P3oool0403hn?P0_;bl0>GUi@3/
k>`0oooo0?Ogm`3oool0m?Cd0>SXj03hn?P0oooo0>c/k03hn?P0m?Cd0>SXj03_knl20>g]k@030=KF
eP3UiND0fm_K0080`L7100<0bl_;0?Cdm03Fe]H00P3hn?P03@3dm?@0][Jf0<?3``3Ng]h0inOW0?Cd
m03oool0l?3`0?Ogm`3/k>`0kno_0?Shn03dm?@00P3oool0203hn?P0oooo0?ooo`3oool0m?Cd0=kN
gP3hn?P0l?3`A`3oool004P0oooo00@0_[jn0;Ng]`1jNWX0moOg0`3oool20?Ogm`@0oooo00<0lo?c
0?7al@3^k^h00P3^k^h04@3IfMT0?clo0<71`@3[jn/0g]kN0?ooo`3Fe]H0bl_;0<k>cP3[jn/0oooo
0>_[j`3Hf=P0moOg0=WIf@2b/[80oooo0080lo?c00L0moOg0>k^kP3oool0oooo0?7al@3oool0mOGe
0080oooo00@0moOg0?ooo`3oool0e]KF>03oool0103gmoL0oooo0?Ogm`3gmoLB0?ooo`040;Zj^P2f
][H0RXZ:0?Ogm`80oooo0P3gmoL06`3Xj>P0moOg0?ooo`3_knl0m_Kf0>GUi@3De=@0c<c<0<;2`P33
`l<0j>SX05mOG`21PH40g=cL0<o?c`3oool0Lg=c075aL@3De=@0ZZZZ0;Fe]@2GUiL0g=cL0=CDe03<
c<`0k^k^0=cLg0030?Ogm`060?ooo`3bl_80m?Cd0>g]k@3oool0kno_0P3oool20?Ogm`030?Cdm039
bLT0kno_0140oooo00<0moOg0?ooo`3oool08`3oool0103hn?P0oooo0?Shn03hn?PB0?ooo`060<G5
a@2i^KT0WinO0?Shn03oool0lo?c0P3hn?P04`3Lg=`0n?Sh0?Ogm`3UiND0n?Sh0>7Qh@3Kfm/0clo?
0<71`@35aLD0d=3@06IVIP26QXH0kNg]0<C4a03oool0HV9R06=SH`3De=@00P2XZ:P02P2ATI40bl_;
0<K6aP3GemL0iNGU0=cLg03]kNd0lo?c0?Ogm`3oool20?Cdm0030>k^kP3hn?P0n?Sh0080oooo0P3h
n?P00`3dm?@0clo?0>OWi`0A0?ooo`030?Shn03oool0oooo03<0oooo00180?ooo`030=7Ad@3bl_80
/k>c00@0oooo00`0moOg0?ooo`3oool0oooo0?Ogm`3clo<0mOGe0?Ogm`3Rh^80[Jf]0;Fe]@3Shn<4
0?ooo`030?Ogm`3oool0oooo0080oooo01P0moOg0?ooo`3clo<0h^;R0=kNgP2i^KT0_kno0?Gem@3c
lo<0oooo0>k^kP3gmoL0mOGe0?ooo`3gmoL0mOGe0?ooo`3gmoL0oooo0?Ogm`3oool0lo?c0=7Ad@3/
k>`c0?ooo`030?Ogm`3oool0oooo00@0oooo00<0moOg0?ooo`3gmoL03`3oool00`3AdM40moOg0:^[
Z`020?ooo`80moOg00h0m_Kf0?ooo`3oool0moOg0>SXj03dm?@0k^k^0>g]k@2XZ:P0b<S80<G5a@3I
fMT0kNg]0?ooo`80moOg00h0dm?C0?ooo`3dm?@0oooo0?Cdm03^k^h0oooo0:RXZ03^k^h0g=cL0;Jf
]P3clo<0k^k^0=_Kf`80oooo00<0m_Kf0>g]k@3gmoL00P3gmoL0203dm?@0oooo0?Ogm`3gmoL0oooo
0=7Ad@38b<P0i^KV<`3oool00`3hn?P0oooo0?ooo`040?ooo`030?Shn03oool0n?Sh00l0oooo00<0
a<C40?Cdm02SXj<00P3gmoL30?Shn00V0?Ogm`3oool0n?Sh0>WYj@3/k>`0inOW0>g]k@2d];@0bLW9
0=CDe03EeMD0iNGU0?ooo`3dm?@0n?Sh0<G5a@3oool0j>SX0?ooo`3Lg=`0l?3`0?ooo`2SXj<0n?Sh
0=oOg`2c/k<0n?Sh0?3`l03Kfm/0kno_0?ooo`3hn?P0m?Cd0?Ogm`3dm?@0oooo0?Cdm03oool20?Sh
n0040?ooo`2c/k<0h^;R0>o_kdH0oooo00130?ooo`80moOg0`3oool00`2`/;00ZJVY0?Ogm`030?oo
o`80moOg0`3oool20?Ogm`060>KViP3gmoL0ZZZZ0>[ZjP2a/K40moOg1`3oool02P3clo<0oooo0?Og
m`3gmoL0k>c/0<;2`P3AdM40jn_[0=WIf@1nOWh30?ooo`050?Ogm`3emOD0oooo0?ooo`3gmoL00P3o
ool20?Ogm`050?ooo`3Zj^X0f][J0?Ogm`3^k^h0<P3oool00`3gmoL0oooo0?Ogm`040?Ogm`80oooo
00<0moOg0?ooo`3oool0203oool20>o_k`060?Ogm`3oool0oooo0;^k^`2b/[80kno_0`3oool00`3g
moL0l_;b0?ooo`020?ooo`090>3Ph03QhN40kNg]0>k^kP31`L40e=CD09nOW`3/k>`0m_Kf0080oooo
00@0moOg0>c/k03oool0moOg0P3Ti>@20>k^kP0;0=WIf@3AdM40X:2P0=CDe03Ph>00/[:b0<_;b`3U
iND0oooo0?KfmP3gmoL00P3oool00`3gmoL0oooo0?ooo`020?Cdm0050?ooo`3Ph>00eMGE0?KfmP3T
i>@0<P3oool00`3hn?P0oooo0?Shn0040?Shn080oooo00<0n?Sh0?ooo`3oool0203oool20?3`l00;
0?Shn03oool0oooo0;fm_@31`L40iNGU0?Ogm`3clo<0oooo0?Shn03dm?@00`3oool04@3Shn<0iNGU
0>k^kP3]kNd0c/k>0>;RhP2TY:@0j>SX0?3`l03oool0moOg0?Shn03Vi^H0oooo0>c/k03GemL0d=3@
0080l?3`00X0bl_;0=_Kf`2DU9@0gmoO0>SXj036a/H0emOG0>o_k`3Xj>P0m?Cd0P3hn?P0103oool0
kNg]0?ooo`3oool20?Cdm0050?ooo`3Rh^80inOW0?Shn03dm?@0A@3oool004L0oooo00@0d=3@0<G5
a@1kNg/0lo?c0`3oool30?Ogm`80oooo00T0i^KV0>k^kP3gmoL0ZZZZ0=7Ad@2d];@0l_;b0>?Sh`3g
moL00`3oool04P3clo<0oooo0?ooo`3clo<0moOg0?ooo`3clo<0j^[Z0=[JfP3Rh^80moOg09ZJVP2?
Shl0S8b<0>;RhP3^k^h0lo?c0?Gem@<0oooo00X0lO7a0?ooo`3gmoL0moOg0?ooo`3emOD0VIVI0;Vi
^@3Zj^X0h^;R<P3oool00`3gmoL0oooo0?ooo`0=0?ooo`030?Ogm`3oool0oooo00@0oooo00D0c<c<
0<[:bP23Ph<0m?Cd0?ooo`020?Ogm`0=0?ooo`3dm?@0h>3P0?ooo`3gmoL0clo?0>GUi@3gmoL0R8R8
0=gMg@2n_[h0jn_[0=CDe0020=WIf@030=cLg03oool0kNg]0080k^k^00X0bl_;0?Ogm`3^k^h0oooo
0=cLg03_knl0kNg]0>o_k`2>SXh0XZ:R0P3IfMT01`3Ph>00l_;b0>g]k@3oool0m_Kf0?Ogm`3dm?@0
103oool01@3]kNd0V9RH0;no_`3Vi^H0fMWI00T0oooo00<0moOg0?ooo`3oool09P3oool00`3hn?P0
oooo0?ooo`0=0?ooo`030?Shn03oool0oooo00@0oooo00D0g]kN0=OGe`24Q8@0kNg]0??cl`020?Sh
n00W0?ooo`3dm?@0e]KF0?ooo`3hn?P0dM7A0=_Kf`3dm?@0VIVI0?3`l038b<P0m?Cd0;fm_@3De=@0
h^;R0<c<c03oool0h^;R0=gMg@3Fe]H0fm_K0?Cdm03Ogml0m?Cd0<g=c@3oool0iNGU0?3`l02JVYX0
][Jf0>GUi@3Kfm/0iNGU0?Shn03dm?@0oooo0?Shn03gmoL0n?Sh00@0oooo00D0kNg]09fMW@3>c/h0
eMGE0>WYj@090?ooo`030?Shn03oool0oooo03P0oooo00150?ooo`060>k^kP24Q8@0]KFe0?Ogm`3R
h^80moOg0P3oool40?Ogm`80oooo00/0j^[Z0?ooo`3bl_80k^k^0>_[j`3Ng]h0j^[Z0?Ogm`3bl_80
oooo0?Gem@020?ooo`030=kNgP3Zj^X0oooo0080j^[Z0100mOGe0?ooo`3gmoL0h^;R0?ooo`3clo<0
d];B0;Ng]`3?cll0d=3@0?Ogm`3oool0moOg0?ooo`3clo<0mOGe0`3gmoL20?ooo`030>[ZjP3/k>`0
moOg0380oooo00<0moOg0?ooo`3oool04`3oool01`3UiND0NGUi0;^k^`3gmoL0m?Cd0>CTi03oool0
0P3gmoL00`3WinL0jn_[0>3Ph0020?ooo`0;0<S8b03Kfm/0iNGU0>g]k@3IfMT0Y:BT0;bl_03AdM40
kno_0=7Ad@3MgMd00P38b<P03`2k^k/0b<S80>o_k`3clo<0c<c<0<_;b`3^k^h0k>c/0=CDe03gmoL0
m?Cd0>k^kP2SXj<0iNGU0;2`/0020?KfmP050?ooo`3fm_H0m?Cd0?Ogm`3dm?@00P3fm_H01P3gmoL0
oooo0>7Qh@3Vi^H0m_Kf0?Ogmc40oooo00<0n?Sh0?ooo`3oool04`3oool0>@3hn?P0Hf=S0;Bd]03c
lo<0kNg]0?Cdm03gmoL0m?Cd0?Shn03YjNT0k^k^0=KFeP3oool0moOg0=7Ad@3Lg=`0g]kN0=gMg@3F
e]H0Z:RX0;Zj^P3@d=00m?Cd0=KFeP3_knl0hN7Q0=_Kf`2d];@0bLW90>o_k`3dm?@0e]KF0=?Cd`3g
moL0k^k^0<W9b@3_knl0m?Cd0>g]k@2i^KT0inOW0;bl_03]kNd0n?Sh0?ooo`3hn?P0lo?c0?Shn03d
m?@0n?Sh0?Cdm03hn?P0oooo0;jn_P3UiND0n?Sh0?Cdm0140?ooo`00A@3oool0102CTi<0alO70>_[
j`3^k^h20?Ogm`@0oooo00H0k^k^0?Ogm`3oool0moOg0>_[j`3oool20?Ogm`<0oooo00L0moOg0??c
l`3[jn/0moOg0>_[j`3gmoL0oooo0080j^[Z00@0lO7a0?Ogm`3gmoL0i^KV0P3clo<20>_[j`040?oo
o`2MWId0e]KF0<O7a`<0moOg0P3oool02`3alO40oooo0?Ogm`3oool0moOg0?ooo`3Rh^80oooo0?;b
lP3oool0k^k^0300oooo00<0moOg0?ooo`3oool04`3oool00`2<S8`0eMGE0>GUi@020>o_k`030?Og
m`3oool0m?Cd0080oooo00P0k^k^0?Cdm03oool0moOg0<o?c`3oool0k^k^0>CTi080oooo01T0moOg
0=_Kf`3Lg=`0kNg]0=CDe03]kNd0e=CD0?ooo`3Ti>@0kNg]0?;blP3]kNd0i>CT0?Cdm03De=@0g=cL
0<S8b03Kfm/0l_;b0:^[Z`3[jn/0c<c<0>SXj03oool0moOg0080oooo00/0m?Cd0?Ogm`3fm_H0m_Kf
0?Ogm`3dm?@0`/;20?Ogm`3Xj>P0moOg0>3Ph00`0?ooo`030?Shn03oool0oooo01<0oooo00P0V9RH
0=KFeP3WinL0kno_0>OWi`3_knl0oooo0?Cdm080oooo00l0kno_0?Cdm03oool0kno_0=7Ad@3hn?P0
kno_0>k^kP3gmoL0lo?c0>c/k03QhN40hn?S0>;RhP3Fe]H00P3Rh^804P3oool0l?3`0>g]k@3YjNT0
kNg]0>k^kP3Xj>P0e]KF0>GUi@35aLD0emOG0?Shn02c/k<0n?Sh0=KFeP3clo<0n?Sh0?Ogm`<0oooo
00X0n?Sh0?ooo`3oool0n?Sh0?Cdm02d];@0kno_0>7Qh@3hn?P0iNGU@`3oool004@0oooo00D0g]kN
04a<C03Ogml0hn?S06MWI`020?Ogm`80oooo00X0moOg0??cl`3gmoL0moOg0?ooo`3gmoL0lo?c0?7a
l@3Rh^80lo?c2@3oool0303gmoL0lo?c0?ooo`3clo<0moOg0?ooo`3Zj^X0l_;b0?ooo`3/k>`0h^;R
0=KFeP80]KFe00L0b/[:0:>SX`3oool0moOg0?ooo`3gmoL0lO7a00<0oooo00L0moOg0?ooo`2a/K40
h^;R0=kNgP3^k^h0lo?c0300oooo00<0moOg0?ooo`3oool0103oool00`3gmoL0oooo0?ooo`0;0?oo
o`050<g=c@1<C4`0m?Cd0?Cdm01TI6@00P3gmoL04P3UiND0moOg0?KfmP3^k^h0m_Kf0?Cdm03UiND0
moOg0>7Qh@3[jn/0b/[:0>CTi03oool0moOg0?ooo`3gmoL0oooo0?Cdm080moOg00<0oooo0>g]k@3c
lo<00P3oool03`3]kNd0a/K60=WIf@3EeMD0fm_K0>3Ph03QhN40e=CD0<k>cP3IfMT0clo?08F5Q@3/
k>`0moOg0>_[j`020?Ogm`0:0?Cdm03bl_80m_Kf0?ooo`3gmoL0fm_K0>GUi@3Lg=`0i>CT0>c/k300
oooo00<0n?Sh0?ooo`3oool0103oool00`3hn?P0oooo0?ooo`0;0?ooo`060=_Kf`0l?3`0m?Cd0?Sh
n01fMWH0m?Cd103hn?P00`3oool0n?Sh0?Cdm0020?Shn00:0>7Qh@3UiND0aLG50>k^kP3oool0n?Sh
0?ooo`3hn?P0oooo0?Cdm080n?Sh0140oooo0>k^kP3dm?@0oooo0?3`l03_knl0fm_K0>7Qh@3UiND0
g]kN0>?Sh`3Ogml0clo?0=_Kf`3Rh^80jNWY09fMW@020>g]k@040>k^kP3gmoL0oooo0?Cdm080kno_
00L0oooo0?Shn03QhN40fm_K0>SXj03dm?@0k^k^04<0oooo00140?ooo`080=kNgP1[Jf/0Y:BT0;Bd
]01gMgL0f][J0?Ogm`3oool30?Ogm`@0oooo00@0jn_[0?ooo`3^k^h0j^[Z2@3oool00`3gmoL0oooo
0?ooo`020?Ogm`030?ooo`3emOD0moOg0080oooo0`3gmoL0203oool0lo?c0>c/k03clo<0moOg0?oo
o`3gmoL0lO7a0P3clo<01@3oool0moOg0?Ogm`3Ogml0lo?c0080dM7A<P3oool40?Ogma00oooo00H0
e=CD08J6QP2GUiL0YjNW06e]K@3_knl20?Ogm`040>k^kP3gmoL0m?Cd0?Ogm`80oooo00P0m_Kf0>CT
i03gmoL0moOg0=?Cd`3oool0moOg0?Cdm080oooo00L0moOg0?ooo`3dm?@0oooo0>g]k@3fm_H0oooo
0080moOg0P3oool0203^k^h0m_Kf0?KfmP3oool0m_Kf0>o_k`3Xj>P0iNGU0P3]kNd01`3dm?@0m_Kf
0?Ogm`3Xj>P0oooo0?;blP3fm_H00P3oool0103gmoL0l_;b0<c<c033`l<b0?ooo`@0n?Sh403oool0
1P3YjNT0W9bL0:j^[P2ZZZX0M7Ad0?Ogm`80n?Sh00@0oooo0?Shn03dm?@0n?Sh0P3oool0203hn?P0
iNGU0?Shn03hn?P0dm?C0?Ogm`3hn?P0m?Cd0P3oool01`3hn?P0oooo0?Cdm03gmoL0k^k^0?Shn03o
ool00P3gmoL00`3hn?P0oooo0?3`l0020?Shn00;0?ooo`3hn?P0oooo0>SXj03YjNT0hn?S0?Shn03X
j>P0n?Sh0?Ogm`3dm?@00P3hn?P01`3_knl0n?Sh0?ooo`3]kNd0j>SX0;jn_P3GemL0A03oool004@0
oooo00L0b<S807]kN`3gmoL0moOg0=WIf@3clo<0oooo0080moOg00<0oooo0?Ogm`3oool00`3oool0
103gmoL0oooo0?Gem@3alO4:0?ooo`80moOg00H0oooo0?Ogm`3emOD0mOGe0?Ogm`3[jn/20?ooo`05
0?Ogm`3oool0oooo0?ooo`3gmoL00P3oool20?Ogm`040?Gem@3clo<0oooo0?ooo`80moOg00@0fMWI
0?Ogm`3gmoL0dM7AAP3oool0302j^[X0PX:20?Ogm`3UiND0h>3P0?Cdm03oool0h>3P0?ooo`3UiND0
h>3P0>GUi@<0oooo00P0h>3P0>g]k@3oool0b<S80>GUi@3gmoL0m?Cd0?Ogm`80oooo00D0moOg0?oo
o`3oool0k>c/0?Ogm`020?ooo`030?Ogm`3]kNd0m?Cd0080m_Kf00@0oooo0?KfmP3clo<0oooo0P3f
m_H0103UiND0oooo0>g]k@3clo<20?Ogm`@0oooo00D0k^k^0?Ogm`3fm_H0m_Kf0<;2`P040?ooo`03
0?Ogm`3oool0oooo03l0oooo01<0c/k>08f=S@3hn?P0j>SX0=_Kf`3dm?@0moOg0?Shn03oool0n?Sh
0>k^kP3dm?@0oooo0?Ogm`3oool0iNGU0?Cdm03_knl0a<C40080n?Sh01H0m?Cd0?Shn03oool0moOg
0?Shn03oool0lo?c0>k^kP3_knl0kNg]0?ooo`3gmoL0l?3`0?Cdm03hn?P0kNg]0>SXj03QhN40moOg
0>SXj03oool0kno_0P3oool03@3Xj>P0m?Cd0?Ogm`3hn?P0m?Cd0?Shn03_knl0n?Sh0?3`l03/k>`0
n?Sh0?3`l031`L40103oool00`3hn?P0oooo0?ooo`0m0?ooo`00@`3oool00`3Rh^80dM7A0?ooo`02
0?ooo`030?Ogm`3Jf]X0moOg00/0oooo00<0mOGe0??cl`3gmoL0203oool0103gmoL0mOGe0?Gem@3e
mOD20?ooo`030>k^kP3oool0oooo00<0oooo00D0moOg0??cl`3gmoL0k^k^0>c/k0030?ooo`090?Og
m`3oool0oooo0?ooo`3gmoL0dM7A0?ooo`2MWId0k^k^04D0oooo00P0h>3P0>g]k@3UiND0oooo0?Cd
m03gmoL0kno_0?Ogm`D0oooo00@0moOg0?ooo`3oool0m?Cd0P3gmoL00`3^k^h0iNGU0?Ogm`030?Og
m`80oooo0P3gmoL01`3fm_H0i>CT0>GUi@3Xj>P0moOg0?ooo`3fm_H00P3oool0103gmoL0m?Cd0?Og
m`3gmoL20?Cdm080kNg]00H0iNGU0?ooo`3gmoL0k^k^0?KfmP3oool20?KfmP050?Ogm`3_knl0m?Cd
0:BTY03UiND0A@3oool0203^k^h0kno_0?Shn03clo<0kNg]0>o_k`3gmoL0n?Sh0`3oool01P3clo<0
moOg0?Shn03gmoL0oooo0?Cdm080n?Sh00<0inOW0>GUi@3_knl00`3hn?P00`3gmoL0lo?c0?Shn002
0?Shn0030>GUi@3`l?00k^k^0080oooo00@0n?Sh0>o_k`3hn?P0m?Cd1@3oool03`3]kNd0m?Cd0=oO
g`3hn?P0oooo0?3`l03hn?P0j>SX0?ooo`3dm?@0n?Sh0?3`l03dm?@0YjNW0?Shn0140?ooo`00@`3o
ool00`3Ng]h0fMWI0?ooo`020?ooo`80moOg2P3oool01@3clo<0oooo0?Gem@3emOD0moOg00H0oooo
00D0f][J0?Ogm`3gmoL0mOGe0?7al@080?ooo`050?Ogm`3oool0oooo0?ooo`3clo<00`3emOD02P3c
lo<0oooo0?ooo`3oool0moOg0?ooo`3Fe]H0g]kN06i^KP2?Shm50?ooo`050<g=c@3WinL0oooo0?oo
o`3]kNd00P3gmoL01@3UiND0oooo0?ooo`3oool0m?Cd0080moOg00/0m?Cd0?ooo`3_knl0jn_[0>o_
k`3fm_H0iNGU0>_[j`3gmoL0oooo0?Ogm`030?ooo`050>o_k`3Ti>@0moOg0?ooo`3gmoL00P3fm_H3
0?ooo`030?Cdm03gmoL0oooo0080moOg00H0oooo0?Ogm`3fm_H0k^k^0?Cdm03_knl20?KfmP040?oo
o`3fm_H0oooo0?Ogm`80kNg]00<0Ph>308J6QP3oool0A03oool01@3Kfm/0n?Sh0??cl`3gmoL0hN7Q
0080kno_00D0n?Sh0?Ogm`3oool0oooo0?Cdm0020?Shn00;0?Cdm03gmoL0l?3`0>g]k@3^k^h0n?Sh
0>SXj03^k^h0n?Sh0?ooo`3hn?P00P3oool0103clo<0oooo0>k^kP3_knl20?Cdm0030?Shn03oool0
oooo00@0n?Sh00<0oooo0?Shn03oool00P3hn?P00`3_knl0l?3`0?ooo`030?Shn0080>o_k`3oool0
m?Cd0?Shn03WinL0iNGU08:2PP2=SHe40?ooo`00@`3oool01@3IfMT0oooo0?ooo`3[jn/0mOGe0080
oooo00<0moOg0?ooo`3oool01`3oool01@3gmoL0lo?c0?ooo`3alO40moOg00<0oooo0`3gmoL02P3o
ool0moOg0?Ogm`3/k>`0oooo0?Ogm`3clo<0moOg0>c/k03oool20?Ogm`070??cl`3gmoL0moOg0?Og
m`3Shn<0mOGe0?ooo`020?7al@80moOg00P0oooo0??cl`3gmoL0oooo0<C4a03;bl/0VYZJ0<C4a4D0
oooo00L0kno_0?Ogm`3MgMd0i>CT0?Ogm`3oool0iNGU00<0oooo00<0m?Cd0?ooo`3fm_H00P3oool0
1`3dm?@0iNGU0??cl`3dm?@0kNg]0>_[j`3De=@00P3oool03P3gmoL0i>CT0>SXj03Ti>@0oooo0??c
l`3^k^h0moOg0>GUi@3MgMd0h>3P0>OWi`3_knl0m?Cd0P3gmoL02`3dm?@0moOg0?Ogm`3gmoL0gMgM
0>CTi03gmoL0oooo0?Ogm`3oool0l_;b0080oooo00H0m_Kf0?Ogm`3Ti>@0clo?09NGU`2`/;150?oo
o`0=0?Ogm`3hn?P0iNGU0>GUi@3hn?P0oooo0?Shn03oool0lo?c0?ooo`3dm?@0oooo0?3`l0020?oo
o`0K0>g]k@3_knl0m?Cd0??cl`3^k^h0iNGU0=OGe`3gmoL0oooo0?Shn03]kNd0h^;R0>g]k@3oool0
m?Cd0>o_k`3dm?@0l?3`0=kNgP3Xj>P0k>c/0?Cdm03oool0n?Sh0?ooo`3dm?@0n?Sh0080oooo00T0
emOG0>KViP3hn?P0oooo0?Shn03oool0n?Sh0?ooo`3dm?@00P3hn?P0103`l?00emOG08V9R@2f][I4
0?ooo`00@P3oool01`3gmoL0oooo0?ooo`3gmoL0oooo0?7al@3Shn<00P3gmoL:0?ooo`050?Ogm`3c
lo<0oooo0?ooo`3gmoL01`3oool20?Ogm`060?ooo`3gmoL0moOg0>?Sh`3emOD0k>c/0`3oool20?Og
m`D0oooo00`0mOGe0?ooo`3oool0moOg0?ooo`3gmoL0oooo09bLW03oool0Ogmo07AdM03^k^i30?oo
o`070>3Ph03UiND0iNGU0>GUi@3gmoL0oooo0>CTi0020>k^kP030?ooo`3gmoL0oooo00@0m_Kf00H0
moOg0?ooo`3^k^h0l_;b0>g]k@3oool20>o_k`80moOg00/0oooo0?Ogm`3oool0m?Cd0>GUi@3Ti>@0
oooo0?Ogm`3clo<0m_Kf0>CTi0030?Ogm`0=0?ooo`3_knl0kNg]0?ooo`3[jn/0m?Cd0?Ogm`3oool0
moOg0?Cdm03oool0m_Kf0?ooo`030?KfmP050;2`/03oool0R8R806e]K@3Ti>@0@`3oool01`3De=@0
n?Sh0>c/k03Kfm/0m?Cd0?ooo`3]kNd00`3oool00`3hn?P0oooo0?3`l0030?3`l0080?Shn03gmoL0
oooo0?Shn03/k>`0oooo0?Shn03`l?020?Shn0060?Ogm`3hn?P0oooo0?Cdm03_knl0k^k^0`3hn?P0
0`3oool0dm?C0?Cdm0040?Shn0030?Cdm03Xj>P0k^k^0080m?Cd00H0oooo0?Shn03dm?@0oooo0?Sh
n03oool20?Shn0060?ooo`30`<00oooo08J6QP1KFe/0m?Cd@`3oool00480oooo00P0moOg0?ooo`3o
ool0k^k^0?Gem@3alO40oooo0?Ogm`X0oooo00H0moOg0?ooo`3gmoL0moOg0?ooo`3gmoL70?ooo`05
0?Ogm`3oool0oooo0?Gem@3clo<00P3gmoL00`3Shn<0i>CT0?Ogm`020?Ogm`80oooo00H0moOg0??c
l`3oool0lO7a0?Gem@3oool40?Ogm`060?ooo`2QXJ40bLW90?Ogm`2/[:`0_[jn<03oool00`3gmoL0
oooo0?ooo`020?ooo`030?Ogm`3oool0oooo00/0oooo00T0fMWI0>GUi@3oool0fMWI0>3Ph03Xj>P0
oooo0>CTi03UiND0103oool20?KfmP<0oooo00H0moOg0??cl`3^k^h0kno_0?ooo`3^k^h30?ooo`80
moOg00T0m_Kf0?ooo`3Ti>@0lo?c0?Ogm`3oool0moOg0?ooo`3bl_800P3]kNd20?Ogm`050>g]k@3b
l_80moOg0?Ogm`3dm?@00P3gmoL00`3oool0l_;b0?ooo`020?KfmP80oooo00H0/[:b0=CDe03oool0
^;Rh0;:b/P3gmoL_0?ooo`030?Shn03oool0oooo0080oooo00<0n?Sh0?ooo`3oool02`3oool02P2m
_Kd0n?Sh0??cl`3;bl/0i^KV0>SXj03oool0m?Cd0?Shn03gmoL30?ooo`80l?3`0P3oool0203gmoL0
n?Sh0?Cdm03dm?@0inOW0?ooo`3_knl0moOg0P3oool20?Shn0040?3`l03oool0kNg]0?Shn080oooo
00L0n?Sh0?ooo`3UiND0kNg]0?Shn03dm?@0n?Sh0080m?Cd00<0n?Sh0?Ogm`3/k>`00P3hn?P00`3o
ool0m?Cd0?Shn0040?ooo`060:f][@3Rh^80oooo0;bl_02/[:`0n?Sh@P3oool00440oooo00H0moOg
0?ooo`3oool0lo?c0=kNgP3gmoL20??cl`/0oooo00<0moOg0?ooo`3clo<00`3clo<20?ooo`080??c
l`3gmoL0oooo0?ooo`3gmoL0oooo0?Gem@3oool30?Ogm`070?ooo`3gmoL0h^;R0>CTi03clo<0moOg
0?Gem@020?ooo`060?Ogm`3oool0mOGe0?ooo`3emOD0moOg0P3oool20?Ogm`060>GUi@3^k^h0a/K6
09^KV`3emOD0Xj>S;`3oool00`3gmoL0oooo0?ooo`0?0?ooo`080=7Ad@3^k^h0oooo0>3Ph038b<P0
h>3P0>CTi03/k>`50?ooo`@0m_Kf00@0moOg0?ooo`3^k^h0iNGU0P3gmoL01@3dm?@0iNGU0?ooo`3o
ool0k>c/00<0moOg00@0kno_0>k^kP3gmoL0oooo0`3fm_H00`3oool0m_Kf0>KViP020?Cdm0030>k^
kP3gmoL0oooo0080moOg00@0m?Cd0?Ogm`3gmoL0m?Cd0P3fm_H02@3oool0m_Kf0>o_k`3IfMT0oooo
0=WIf@3@d=00moOg09RHV00_0?ooo`030?Shn03oool0oooo00l0oooo00D0][Jf0?ooo`3gmoL0j>SX
0<_;b`020>7Qh@030?Shn03oool0moOg0080lo?c00<0oooo0?3`l03`l?000P3`l?00303hn?P0oooo
0?Ogm`3hn?P0m?Cd0??cl`3/k>`0jNWY0?ooo`3gmoL0n?Sh0>c/k080m?Cd00<0inOW0?3`l03hn?P0
0`3oool0203hn?P0m?Cd0>g]k@3^k^h0l?3`0?Shn03^k^h0m?Cd0P3oool0403gmoL0lo?c0?Cdm03h
n?P0m?Cd0?ooo`3hn?P0oooo0?Shn03`l?00a<C40>k^kP3Kfm/0iNGU0?Ogm`2FUYI20?ooo`00@@3o
ool0103clo<0oooo0>KViP3oool20?Ogm`030>k^kP3Shn<0oooo00/0oooo0P3gmoL01P3oool0moOg
0??cl`3oool0moOg0?ooo`<0moOg00@0lo?c0?Ogm`3oool0moOg0P3oool01`3^k^h0moOg0?Ogm`3T
i>@0lo?c0?Ogm`3alO400P3oool00`3gmoL0oooo0?Ogm`020?Gem@80oooo00X0lo?c0?Ogm`3oool0
oooo0>_[j`3oool0moOg0<C4a02@T900jn_[@@3oool0203De=@0lo?c0>3Ph03IfMT0iNGU0>3Ph03g
moL0i>CT1@3oool01@3bl_80oooo0?ooo`3oool0moOg0080oooo00T0i>CT0>c/k03oool0m_Kf0>3P
h03dm?@0i>CT0>k^kP3Ti>@00P3gmoL01@3clo<0oooo0>c/k03fm_H0oooo0080m_Kf00H0lo?c0?Og
m`3]kNd0iNGU0>g]k@3gmoL20?ooo`030?Ogm`3oool0oooo0080oooo00`0k^k^0?KfmP3fm_H0l_;b
0?KfmP3/k>`0h>3P0>o_k`3]kNd0e=CD08n?S`3Ph>110?ooo`080;Vi^@3dm?@0e]KF0>KViP3WinL0
e=CD0>k^kP3]kNd20?ooo`80moOg00<0oooo0>WYj@3oool00P3oool02`3hn?P0moOg0?ooo`3dm?@0
n?Sh0?ooo`3dm?@0h^;R0?Cdm03]kNd0n?Sh00@0m?Cd00@0n?Sh0?Cdm03hn?P0iNGU0P3hn?P03@3g
moL0kno_0?Shn03dm?@0kNg]0?Shn03oool0n?Sh0?Ogm`3oool0moOg0?Shn03oool00`3hn?P02@3d
m?@0n?Sh0?3`l034a<@0k>c/0?3`l03Fe]H0Q8B40>WYj@120?ooo`00@@3oool20?Ogm`050?Gem@3c
lo<0oooo0?Gem@3gmoL01`3oool20>?Sh`<0oooo00H0moOg0?ooo`3oool0moOg0?ooo`3gmoL20?oo
o`040?Ogm`3oool0oooo0??cl`@0oooo0P3clo<01`3gmoL0oooo0?Gem@3/k>`0lo?c0?Ogm`3emOD0
0P3gmoL01@3oool0lo?c0?ooo`3emOD0lO7a0080oooo00T0lo?c0?Ogm`3gmoL0lo?c0>KViP3gmoL0
oooo0?Ogm`3^k^h0<@3oool00`3gmoL0oooo0?ooo`0>0?ooo`040?KfmP3gmoL0iNGU0>OWi`80moOg
00D0k^k^0?ooo`3oool0oooo0?Ogm`020?ooo`0?0?KfmP3_knl0kno_0?ooo`3gmoL0oooo0>3Ph03U
iND0oooo0?KfmP3UiND0moOg0?Cdm03oool0i>CT0080oooo00T0jn_[0?;blP3_knl0k>c/0?KfmP3g
moL0m?Cd0?Ogm`3oool00`3gmoL01@3bl_80moOg0?Ogm`3gmoL0oooo0080moOg00@0m?Cd0>o_k`3g
moL0m_Kf0P3oool0103fm_H0i>CT0=WIf@3]kNd20>o_k`030>CTi03oool0oooo02l0oooo00<0n?Sh
0?ooo`3oool03P3oool01@3hn?P0k^k^0?Shn03_knl0k^k^0080m?Cd00@0oooo0??cl`3oool0n?Sh
0P3oool01P3`l?00n?Sh0?Shn03oool0n?Sh0??cl`80n?Sh00T0oooo0?Shn03hn?P0kno_0?Cdm03c
lo<0kNg]0??cl`3gmoL00P3hn?P01P3gmoL0m?Cd0?ooo`3hn?P0m?Cd0?ooo`80n?Sh00@0oooo0?Cd
m03hn?P0m?Cd0P3gmoL01@3oool0moOg0?ooo`3hn?P0l?3`00<0n?Sh00P0m?Cd0?ooo`3^k^h0^KVi
0?ooo`3hn?P0kno_0>k^kT<0oooo00100?ooo`080??cl`3gmoL0jn_[0?Gem@3IfMT0lo?c0>[ZjP3g
moL<0?ooo`040??cl`3gmoL0moOg0??cl`L0oooo00@0lo?c0?ooo`3gmoL0moOg0P3oool02@3gmoL0
oooo0??cl`3clo<0k^k^0?ooo`3emOD0oooo0??cl`020?Ogm`030??cl`3oool0lO7a0080oooo0P3g
moL20?ooo`030??cl`3Vi^H0moOg0080oooo00<0dM7A0?ooo`3oool0;P3oool00`3gmoL0oooo0?oo
o`0>0?ooo`080<W9b@3UiND0h>3P0>k^kP3Ph>00kno_0?Cdm03clo<20?ooo`80m?Cd00D0moOg0?oo
o`3oool0oooo0?Ogm`030?ooo`090>c/k03gmoL0m_Kf0>c/k03[jn/0oooo0?Ogm`3oool0m?Cd0080
oooo00<0k>c/0?Ogm`3dm?@00`3oool20?Ogm`80m?Cd00<0moOg0?ooo`3gmoL00P3dm?@20?Ogm`04
0?ooo`3gmoL0moOg0?Cdm080m_Kf0P3oool01`3fm_H0j>SX0<S8b03gmoL0oooo0?KfmP2k^k/0<03o
ool00`3hn?P0oooo0?ooo`0>0?ooo`080;:b/P3_knl0iNGU0>OWi`3dm?@0kNg]0>c/k03dm?@20?Og
m`80m?Cd00H0n?Sh0?ooo`3oool0oooo0?Shn03gmoL20?ooo`@0n?Sh00D0m?Cd0?ooo`3hn?P0oooo
0?Cdm0020?ooo`030?Shn03oool0m?Cd00@0oooo0P3hn?P0103dm?@0moOg0?ooo`3hn?P20?Ogm`09
0?ooo`3gmoL0oooo0?Cdm03hn?P0m?Cd0?ooo`3]kNd0n?Sh0080oooo00H0jNWY0;Zj^P3dm?@0kno_
0?Shn02j^[Y30?ooo`00@P3oool00`3gmoL0oooo0>KViP020??cl`80moOg2@3oool0103clo<0moOg
0?Ogm`3gmoL20?ooo`80moOg1P3oool00`3clo<0mOGe0??cl`020?ooo`030?Ogm`3oool0moOg0080
moOg0P3emOD0103oool0lo?c0??cl`3gmoL40?ooo`030?Ogm`3clo<0oooo0080oooo00H0lo?c0>_[
j`3oool0moOg0?ooo`3Hf=Pa0?ooo`80moOg3P3oool0403Kfm/0i>CT0=cLg03Vi^H0m?Cd0>SXj03g
moL0k^k^0?Ogm`3oool0m?Cd0?Ogm`3dm?@0moOg0?ooo`3gmoL20?ooo`090>c/k03^k^h0moOg0??c
l`3fm_H0oooo0?KfmP3gmoL0oooo0080moOg0`3oool0103clo<0moOg0?KfmP3_knl30?ooo`040?Og
m`3oool0l_;b0?ooo`80m?Cd00<0oooo0?Cdm03oool00P3gmoL20?ooo`080?KfmP3oool0oooo0?Kf
mP3oool0h>3P0=CDe03/k>`20?KfmP0309^KV`3oool0oooo02l0oooo0P3hn?P>0?ooo`0@0=kNgP3X
j>P0i^KV0?Cdm03hn?P0j>SX0>g]k@3oool0n?Sh0?ooo`3dm?@0n?Sh0?Cdm03hn?P0oooo0?Shn080
moOg00T0kno_0?ooo`3hn?P0m?Cd0?Shn03oool0n?Sh0>o_k`3oool00P3hn?P20?ooo`090?Ogm`3]
kNd0n?Sh0?Cdm03gmoL0oooo0?Shn03oool0kno_00<0n?Sh00H0oooo0?Ogm`3hn?P0lo?c0?ooo`3g
moL40?ooo`0:0?Shn03oool0n?Sh0?Shn03YjNT0b/[:0>g]k@3UiND0oooo08:2PT<0oooo00100?oo
o`070>KViP3oool0jn_[0?Gem@3IfMT0moOg0?ooo`020?Ogm`@0oooo00@0moOg0?ooo`3oool0lo?c
0P3gmoL50?ooo`030?Ogm`3clo<0oooo00H0oooo0P3gmoL40?ooo`<0moOg0P3alO420?Ogm`030?oo
o`3gmoL0mOGe0080mOGe00@0moOg0??cl`3oool0moOg0P3oool01P3^k^h0gmoO0??cl`3gmoL0k^k^
0=WIfCL0oooo00<0moOg0?ooo`3oool01`3oool0503/k>`0moOg0=CDe03gmoL0m?Cd0>g]k@3bl_80
k^k^0?Ogm`3oool0moOg0?ooo`3dm?@0moOg0?ooo`3gmoL0m?Cd0>_[j`3oool0k^k^0`3oool00`3g
moL0k^k^0?Cdm0070?ooo`050?Cdm03oool0oooo0?Ogm`3oool00P3_knl01@3oool0l_;b0?Ogm`3g
moL0m?Cd0080moOg0`3dm?@00`3gmoL0oooo0>k^kP020?KfmP80oooo00H0moOg0=WIf@3fm_H0m_Kf
0=CDe039bLTg0?ooo`030?Shn03oool0oooo00L0oooo00H0e]KF0>o_k`3>c/h0oooo0?3`l03]kNd2
0?ooo`080?Shn03oool0n?Sh0?ooo`3dm?@0kno_0??cl`3_knl20?Cdm080n?Sh00L0oooo0?Cdm03o
ool0n?Sh0?ooo`3dm?@0moOg0080lo?c0P3oool01P3clo<0m?Cd0>g]k@3hn?P0oooo0?Ogm`80n?Sh
00T0kno_0?Shn03hn?P0l?3`0?ooo`3gmoL0oooo0?Ogm`3clo<00P3oool03@3hn?P0oooo0?3`l03h
n?P0m?Cd0?ooo`3hn?P0iNGU0<_;b`3hn?P0oooo0=3@d02f][H0@`3oool003l0oooo00T0moOg0?oo
o`3bl_80dM7A0?Ogm`3AdM40h^;R0?ooo`3gmoL01P3oool40?Ogm`040?ooo`3gmoL0moOg0?ooo`80
moOg0P3clo<60?ooo`030?Ogm`3oool0lo?c0080moOg0P3oool01@3gmoL0oooo0?ooo`3alO40mOGe
00<0oooo103emOD00`3oool0lo?c0?Ogm`030?ooo`030??cl`38b<P0lo?c0080lo?c0P3gmoLo0?oo
o`090=CDe03oool0kNg]0=GEe@3gmoL0h>3P0=cLg03/k>`0i>CT00<0oooo00T0m?Cd0?Ogm`3oool0
moOg0?Cdm03^k^h0lo?c0?Ogm`3fm_H00P3oool0103bl_80k^k^0?Cdm03dm?@60?ooo`030?Ogm`3d
m?@0l_;b0080moOg0P3oool03P3gmoL0m_Kf0?KfmP3oool0m?Cd0?ooo`3gmoL0m?Cd0>o_k`3oool0
m?Cd0?ooo`3gmoL0m_Kf103oool01`3Xj>P0V9RH0=cLg03dm?@0cLg=0?Ogm`3_knl0?`3oool01`2m
_Kd0oooo0>GUi@3=cLd0moOg0>SXj03Lg=`00P3dm?@04P3gmoL0oooo0?ooo`3dm?@0n?Sh0?Ogm`3/
k>`0m?Cd0?ooo`3dm?@0n?Sh0?Cdm03hn?P0oooo0?Shn03oool0m?Cd0>g]k@80oooo00D0moOg0?oo
o`3gmoL0oooo0?Cdm0020?Shn00A0>c/k03gmoL0oooo0?ooo`3gmoL0n?Sh0?ooo`3hn?P0m?Cd0?oo
o`3gmoL0lo?c0>o_k`3oool0m?Cd0?ooo`3hn?P00P3oool02P3dm?@0oooo0?Cdm03Lg=`0TI6A0>OW
i`3^k^h0emOG0?Shn03`l?120?ooo`00?P3oool01@3clo<0moOg0>[ZjP2l_;`0[:b/0080jn_[00<0
];Bd0??cl`3oool00P3oool00`3gmoL0oooo0?ooo`020?ooo`060??cl`3gmoL0lo?c0??cl`3gmoL0
oooo0P3gmoL00`3oool0moOg0?ooo`020?Ogm`<0oooo00T0moOg0?ooo`3emOD0oooo0>k^kP3clo<0
moOg0??cl`3^k^h00P3gmoL60?Gem@030?ooo`3emOD0moOg00<0moOg0`3oool0103[jn/0a<C40>c/
k03clo<20?Ogm`030>?Sh`3oool0oooo03`0oooo00T0j>SX0>GUi@3dm?@0aLG50;^k^`3/k>`0jn_[
0<?3``3/k>`0203oool0203dm?@0kNg]0>g]k@3Ph>00iNGU0?ooo`3]kNd0inOW0P3/k>`00`3oool0
moOg0?Ogm`040?ooo`0>0>k^kP3gmoL0oooo0>o_k`3gmoL0oooo0?Cdm03oool0l_;b0?Ogm`3oool0
moOg0?ooo`3gmoL20?ooo`050?Ogm`3oool0moOg0>k^kP3gmoL00`3oool0203bl_80moOg0:j^[P3g
moL0i^KV0?KfmP3/k>`0XZ:R?P3oool02@3YjNT0j>SX0?Ogm`39bLT0_[jn0?Cdm03hn?P0b/[:0?Sh
n0030?Ogm`030?Shn03gmoL0moOg0080oooo00h0kNg]0=_Kf`3QhN40g=cL0>OWi`3oool0hN7Q0>c/
k03dm?@0n?Sh0?ooo`3_knl0n?Sh0??cl`80moOg00@0oooo0?Shn03`l?00kno_0`3hn?P02@3/k>`0
n?Sh0?Shn03hn?P0oooo0?Cdm03oool0n?Sh0?ooo`020?Shn0030?ooo`3hn?P0n?Sh00@0n?Sh00P0
oooo0>GUi@2b/[80n?Sh0>GUi@3WinL0iNGU08f=SD80oooo000o0?ooo`040>c/k02KVi/0^KVi06QX
J080_[jn00d0W9bL0?Ogm`3oool0moOg0?ooo`3gmoL0oooo0??cl`3gmoL0oooo0?Ogm`3oool0moOg
0080f][J00H0e]KF0?ooo`3oool0oooo0>?Sh`3Rh^840?ooo`040?Ogm`3oool0moOg0?7al@80moOg
00P0oooo0??cl`3oool0i^KV0?ooo`3gmoL0oooo0?Gem@80oooo00<0mOGe0?Ogm`3gmoL00P3oool2
0?Ogm`80oooo00X0jn_[0>k^kP3Shn<0bl_;0??cl`3;bl/0d=3@0?Ogm`3Ng]h0moOg?@3oool02P3D
e=@0dM7A0<;2`P32`/80R8R80<K6aP32`/80]KFe0>o_k`3oool30?Ogm`040?ooo`3dm?@0m?Cd0?Og
m`<0oooo0P3_knl01P3fm_H0moOg0>g]k@3dm?@0j>SX0=cLg0@0oooo00<0i>CT0?Ogm`3dm?@01P3g
moL20?ooo`040?Ogm`3dm?@0moOg0?Ogm`80oooo00<0jn_[0?Ogm`3gmoL00P3gmoL03@3oool0m_Kf
0?ooo`3gmoL0m_Kf0>g]k@31`L40moOg0=_Kf`2`/;00m_Kf0:^[Z`3gmoL03`3oool00`3gmoL0oooo
0?ooo`0[0?ooo`0;0<30`03=cLd0/k>c0<_;b`2OWil0dm?C0=KFeP2n_[h0l?3`0??cl`3_knl00P3/
k>`04@3gmoL0j>SX0>g]k@3UiND0m?Cd0?ooo`3hn?P0moOg0?ooo`3`l?00moOg0>SXj03dm?@0fm_K
0=oOg`3oool0moOg0080oooo00D0kNg]0?Shn03clo<0n?Sh0?Ogm`030?Shn0070?Ogm`3hn?P0n?Sh
0?Shn03dm?@0l?3`0?Shn0020?ooo`D0n?Sh00d0oooo0?Cdm03dm?@0moOg0?Shn03]kNd0a/K60?Sh
n03Lg=`0a<C40=cLg02LW9`0n?Sh00l0oooo00<0n?Sh0?ooo`3oool0;`3oool003h0oooo00/0moOg
0?ooo`26QXH0W9bL0;6a/@2?Shl0dM7A0;6a/@3gmoL0oooo0?Ogm`020?ooo`0;0??cl`3gmoL0l_;b
0<;2`P3AdM40_[jn0<k>cP3IfMT0gmoO0>_[j`3Rh^800P3bl_800`3oool0mOGe0=[JfP040?ooo`06
0??cl`3gmoL0mOGe0?Ogm`3oool0g]kN0P3gmoL20??cl`090>_[j`3^k^h0oooo0??cl`3oool0moOg
0?ooo`3gmoL0oooo0080moOg0P3oool20>k^kP080?ooo`3Rh^80e]KF0?ooo`3bl_80i^KV0>k^kP3T
i>@n0?ooo`0;0<S8b03De=@0R8R80<K6aP2m_Kd0YJFU0=cLg02f][H0moOg0?ooo`3gmoL00P3oool0
2`3Xj>P0kNg]0??cl`2e]KD0`/;20;Jf]P32`/80clo?0=WIf@3Kfm/0b/[:0080k^k^00@0oooo0?Cd
m03_knl0oooo0P3gmoL0103oool0k>c/0?Ogm`3^k^h30?Ogm`80oooo00<0i^KV0>OWi`3^k^h00P3o
ool01P3dm?@0moOg0?Cdm03fm_H0moOg0?Cdm080moOg00`0lo?c0?ooo`3fm_H0oooo0?KfmP3_knl0
eMGE0>SXj03dm?@0oooo0<W9b@32`/8n0?ooo`0H0:j^[P3Ogml0T92@0=CDe03@d=00ZZZZ0=gMg@2i
^KT0n?Sh0?Ogm`3dm?@0oooo0?Ogm`3Rh^80k^k^0?Cdm02b/[80aLG50;Zj^P2o_kl0clo?0>KViP3R
h^80fm_K0P3hn?P0103oool0m?Cd0?Shn03gmoL20?Shn0040??cl`3^k^h0m?Cd0?3`l0<0n?Sh00<0
oooo0?Shn03clo<00P3gmoL20?ooo`060?Cdm03hn?P0m?Cd0?ooo`3hn?P0m?Cd0`3hn?P02`3dm?@0
n?Sh0?Shn03hn?P0jNWY0=KFeP3YjNT0lo?c0?ooo`3Kfm/0aLG50480oooo000n0?ooo`080>_[j`3o
ool0_;bl09nOW`3Shn<0g]kN0>?Sh`1^KVh30?ooo`0C0??cl`3gmoL0lo?c0?Ogm`3AdM40VIVI0>c/
k03AdM40fMWI0:b/[02YZJT0Shn?0:2PX03AdM40iNGU0>?Sh`3Ng]h0j^[Z0?Ogm`040?ooo`080??c
l`3alO40jn_[0?Ogm`3emOD0lO7a0>[ZjP3oool30>k^kP80oooo00D0moOg0>_[j`3gmoL0oooo0?Ge
m@020?Ogm`<0oooo00@0i^KV0?ooo`3Shn<0c/k>0P3gmoL00`3clo<0l_;b0?ooo`0n0?ooo`080<K6
aP3oool0`/;20<G5a@3Ti>@0m?Cd0>c/k01cLg<30?ooo`0B0?Cdm03oool0m?Cd0>g]k@31`L40UiNG
0?Ogm`3EeMD0][Jf0;Rh^02i^KT0ZZZZ0:j^[P3MgMd0fMWI0=CDe032`/80gMgM0P3gmoL30?ooo`03
0?Cdm03[jn/0moOg0080moOg00<0g=cL0?Cdm03oool00`3oool01`3_knl0oooo0??cl`3[jn/0kNg]
0?Ogm`3oool00P3gmoL00`3bl_80m_Kf0?ooo`020?KfmP080?ooo`3Lg=`0m?Cd0?Ogm`3dm?@0h>3P
0>KViP3dm?@m0?ooo`080<G5a@3oool0^;Rh0=_Kf`3_knl0m?Cd0?Shn024Q8@20?Ogm`0C0?ooo`3d
m?@0moOg0>SXj03^k^h0`L7109bLW03clo<0d=3@09nOW`2f][H0a<C40;Zj^P2o_kl0gmoO0=3@d03F
e]H0^[Zj0=oOg`020?Shn0<0oooo00<0k>c/0>k^kP3hn?P00P3hn?P02`3^k^h0m?Cd0?ooo`3hn?P0
oooo0>o_k`3/k>`0kno_0>7Qh@3Ng]h0k^k^00@0n?Sh0`3oool02P3hn?P0oooo0?3`l03Fe]H0m?Cd
0?Ogm`3clo<0j>SX0>WYj@3dm?A10?ooo`00?@3oool01@3clo<0h^;R0=kNgP3gmoL0b<S80080moOg
00<0i>CT05aLG03oool00P3oool40?Ogm`0>0?ooo`3gmoL0hn?S09ZJVP3@d=00bLW90:BTY03oool0
fMWI0>_[j`3Zj^X0iNGU0=7Ad@3@d=050?ooo`0<0?Ogm`3alO40moOg0?Ogm`3/k>`0moOg0?;blP3g
moL0oooo0?;blP3/k>`0lo?c0P3gmoL20?ooo`0?0>k^kP3gmoL0moOg0?Ogm`3[jn/0k^k^0>_[j`3o
ool0jn_[0?ooo`39bLT0k>c/0??cl`3Rh^80moOg0340oooo00<0moOg0?ooo`3oool02P3oool02@3d
m?@0`L710??cl`3gmoL0fMWI0?Ogm`3oool0jn_[079bLP030?ooo`0B0?KfmP3gmoL0moOg0?Ogm`3o
ool0kNg]0>k^kP2ZZZX0fMWI0=GEe@2f][H0oooo0?Ogm`3De=@0gMgM0>GUi@3Kfm/0b/[:0P3gmoL2
0?Cdm080oooo0200kNg]0>OWi`3oool0eMGE0>c/k03_knl0kNg]0?Ogm`3UiND0m?Cd0>SXj03dm?@0
kNg]0?Ogm`3bl_80m_Kf0?Ogm`3]kNd0moOg0?KfmP3oool0k^k^0?KfmP3oool0m_Kf0=CDe03]kNd0
l_;b0>_[j`3MgMd0l_;b0?Cdm2l0oooo00<0n?Sh0?ooo`3oool02P3oool01P3dm?@0^KVi0>GUi@3`
l?00hN7Q0?Ogm`80n?Sh00@0T92@0?ooo`3gmoL0oooo0P3hn?P04P3_knl0n?Sh0?ooo`3Rh^80hN7Q
0;Bd]03Fe]H0gMgM0>7Qh@3oool0k>c/0<[:bP3;bl/0inOW0>;RhP2m_Kd0kno_0?Shn080m?Cd00l0
moOg0?ooo`3dm?@0m?Cd0?Shn03WinL0k>c/0>KViP3^k^h0n?Sh0?3`l03]kNd0h^;R0?Cdm03^k^h0
0P3hn?P03`3dm?@0n?Sh0>k^kP3hn?P0m?Cd0?Shn03gmoL0n?Sh0?Cdm03oool0hn?S0>k^kP3dm?@0
k^k^0>OWi`020?Cdm440oooo000l0?ooo`030?Ogm`1bLW80c/k>0080oooo00P0ZJVY0>;RhP3Rh^80
gmoO07MgM`3clo<0moOg0?ooo`@0moOg00l0oooo0>c/k03gmoL0k>c/0=WIf@3AdM40c/k>0>?Sh`3N
g]h0c/k>0>;RhP3[jn/0j^[Z0?Ogm`3clo<00`3oool20?Ogm`0=0?7al@3clo<0moOg0?Ogm`2l_;`0
clo?0=KFeP3Shn<0h^;R0=kNgP3Ogml0dM7A0=kNgP020>KViP0>0>k^kP3[jn/0oooo0?ooo`3^k^h0
jn_[0>k^kP3oool0k^k^0>KViP3Hf=P0lo?c0>c/k03AdM420?Ogmc`0oooo00<0moOg05YJFP2GUiL0
0P3oool0203EeMD0jn_[0?Ogm`3]kNd0UiNG0?Cdm03gmoL0iNGU103gmoL03`3oool0iNGU0>k^kP3I
fMT0e=CD0=7Ad@3;bl/0k^k^0?KfmP2j^[X0e=CD0>3Ph03Lg=`0k^k^0?Cdm0020?ooo`0=0?KfmP3g
moL0k^k^0>SXj03dm?@0oooo0>c/k02`/;00^[Zj0=7Ad@3De=@0iNGU0>SXj0020=CDe0050=WIf@3V
i^H0l_;b0?KfmP3[jn/00P3oool0103fm_H0k^k^0?KfmP3oool20?KfmP070<o?c`3/k>`0k>c/0?Cd
m03gmoL0iNGU0>SXj00k0?ooo`0;0?Shn017AdL0WIfM0?Cdm03oool0e]KF0??cl`3dm?@0k^k^0:NW
Y`3dm?@01@3hn?P03@3dm?@0moOg0>OWi`3gmoL0g]kN0=OGe`3Cdm<0`<300?Shn03^k^h0_Kfm0<C4
a03Shn<00P3UiND01`3Xj>P0moOg0?ooo`3`l?00m?Cd0>o_k`3dm?@00P3hn?P00`3clo<0a/K60<S8
b0020=?Cd`060=OGe`3YjNT0e]KF0=KFeP3Kfm/0kNg]0P3hn?P01@3_knl0n?Sh0?Shn03dm?@0moOg
0080oooo0P3dm?@01`3AdM40m?Cd0?Cdm03]kNd0j>SX0>g]k@3YjNT0@@3oool003/0oooo00l0moOg
0:>SX`3Ogml0moOg0>KViP3oool0KVi^0>[ZjP3alO40jn_[071`L03gmoL0oooo0?Ogm`3^k^h00P3c
lo<20?ooo`0;0??cl`3gmoL0mOGe0=kNgP2a/K40_[jn0<O7a`3Shn<0aLG50>k^kP3Jf]X00P3emOD4
0?ooo`0;0?Ogm`3oool0lO7a0?Ogm`3Ti>@0l_;b0?Ogm`3Jf]X0bLW90?Ogm`2@T9000P3Ng]h02@2l
_;`0l_;b0??cl`3:b/X0lo?c0>?Sh`3Ng]h0lO7a0?ooo`020?Ogm`0:0>k^kP3oool0oooo0<;2`P3Z
j^X0lo?c0:f][@3gmoL0jn_[0?OgmcX0oooo00`0kno_0:VYZ@3Ti>@0moOg0>KViP3gmoL0ZZZZ0?Og
m`3oool0moOg08J6QP3dm?@20?Ogm`030>c/k03dm?@0m?Cd0080oooo01@0m?Cd0>k^kP3dm?@0cLg=
0;Jf]P32`/80gMgM0>CTi03IfMT0oooo0=GEe@3_knl0j>SX0?ooo`3gmoL0m_Kf0?;blP3gmoL0oooo
0>SXj080m?Cd00d0iNGU0>o_k`3IfMT0^[Zj0?KfmP1gMgL0hN7Q0>_[j`3:b/X0k^k^0?Ogm`3;bl/0
moOg0080iNGU00h0j>SX0?Cdm03gmoL0lo?c0?ooo`3fm_H0kNg]0<S8b03bl_80lo?c0;fm_@3_knl0
kNg]0<o?ccX0oooo00`0l?3`0:j^[P3]kNd0kno_0>SXj03dm?@0_[jn0>k^kP3oool0m?Cd096AT@3]
kNd20?Shn0030>k^kP3]kNd0j>SX0080moOg02<0kNg]0?3`l03dm?@0bLW90;Jf]P3=cLd0l?3`0>k^
kP3Vi^H0n?Sh0>OWi`3hn?P0k^k^0?ooo`3_knl0l?3`0>WYj@3/k>`0oooo0>WYj@3^k^h0n?Sh0?Cd
m03_knl0g]kN0:n_[`3gmoL0HF5Q0>SXj03hn?P0c<c<0?ooo`3]kNd0clo?0?Shn0020?Cdm0040>WY
j@3dm?@0moOg0?Ogm`80oooo00P0kNg]0=7Ad@3^k^h0m?Cd0=KFeP3gmoL0jNWY0<30`440oooo000k
0?ooo`0<05QHF03gmoL0moOg0=[JfP3Vi^H0dM7A0=3@d03/k>`0moOg0>k^kP1mOGd0oooo0P3clo<0
0`3/k>`0e]KF0??cl`030?ooo`0=0??cl`3gmoL0h^;R0>CTi03clo<0dM7A0>?Sh`3Fe]H0_[jn0?Og
m`3alO40lo?c0?Ogm`030?ooo`0R0??cl`3gmoL0lO7a0??cl`3Ti>@0moOg0>c/k03oool0c/k>09RH
V02[Zj/0/;2`0=KFeP3UiND0g]kN0?;blP3Shn<0SXj>0;fm_@3UiND0fMWI0>_[j`3Vi^H0oooo0>KV
iP3^k^h0g]kN0=3@d03Zj^X0a<C409fMW@3gmoL0k^k^0=WIfBh0oooo1@3gmoL70?ooo`070451@@3o
ool0m_Kf0;:b/P3Vi^H0fm_K0>GUi@030?Ogm`0707UiN@3oool0k^k^0?Cdm03Lg=`0_Kfm0?Cdm003
0?ooo`0:0?Cdm03Ti>@0g=cL0>SXj03dm?@0i>CT0>k^kP3;bl/0`l?30?KfmP80iNGU00L0kno_0?oo
o`3oool0l_;b0>k^kP3bl_80iNGU0080m?Cd01<0m_Kf0=GEe@3oool0iNGU08Z:RP2`/;00b<S80=WI
f@3/k>`0fMWI0<G5a@3/k>`0`/;20>3Ph03dm?@0dM7A0>3Ph03bl_80oooo0080m_Kf00P0kNg]0=WI
f@3gmoL0clo?0;Jf]P3_knl0k>c/0;fm_Bh0oooo1@3hn?P70?ooo`0703Xj>P3oool0n?Sh0;jn_P3L
g=`0bl_;0>GUi@020?Ogm`080?Shn01oOgl0oooo0?ooo`3dm?@0gMgM0<71`@3dm?@30?Ogm`030>g]
k@3WinL0gMgM0080k^k^00l0kno_0?Shn03EeMD0a<C40?Cdm03`l?00inOW0?3`l03gmoL0oooo0>WY
j@3oool0m?Cd0>GUi@3_knl00P3dm?@0303WinL0oooo0>?Sh`1iNGT0/K6a0<71`@3Ng]h0n?Sh0<g=
c@2b/[80kNg]0=_Kf`80kNg]00@0fm_K0>c/k03oool0oooo0P3hn?P0203^k^h0h^;R0>g]k@3AdM40
a/K60>o_k`3QhN40Z:RX@@3oool003X0oooo00`0lo?c0=WIf@3[jn/0oooo0>k^kP1_Kfl0dM7A0=kN
gP3^k^h0moOg0=7Ad@28R8P20?Ogm`050?ooo`3gmoL0d=3@0??cl`3/k>`00`3oool0103gmoL0oooo
0??cl`3emOD40?ooo`040?Gem@3oool0oooo0??cl`@0oooo00D0lo?c0?7al@3clo<0moOg0?Gem@03
0?Ogm`030>c/k02e]KD0/k>c0080jn_[01@0f][J0<K6aP3AdM40mOGe0<O7a`3emOD0lo?c0?Ogm`3[
jn/0k^k^0?ooo`3^k^h0dM7A0??cl`3UiND0i>CT069RHP3[jn/0oooo0?OgmcT0oooo00`0m?Cd0>3P
h03_knl0oooo0=gMg@2MWId0k^k^0>SXj03]kNd0moOg0>g]k@2HV9P20>k^kP0>0?ooo`3gmoL0dM7A
0>g]k@3Lg=`0oooo0?Ogm`3oool0kno_0?ooo`3clo<0kno_0?Cdm03clo<20?KfmP80moOg0P3clo<0
2@3dm?@0m_Kf0?ooo`3oool0lo?c0>o_k`3Vi^H0moOg0>KViP020>o_k`040>k^kP3/k>`0`l?30=WI
f@80jn_[00H0e=CD0<c<c03Lg=`0oooo0<?3``3_knl20?Ogm`0<0>_[j`3oool0m_Kf0?KfmP3IfMT0
kNg]0?Cdm03[jn/0S8b<0<K6aP3?cll0]KFe>@3oool0303dm?@0k^k^0?3`l03oool0inOW0;Vi^@3^
k^h0l?3`0?Shn03gmoL0kNg]09JFUP<0oooo00X0n?Sh0<_;b`3^k^h0gmoO0?ooo`3hn?P0oooo0>OW
i`3oool0kNg]0`3dm?@20?Shn0030?ooo`3_knl0m?Cd0080m?Cd01L0l?3`0?ooo`3oool0m?Cd0?3`
l03Xj>P0l?3`0?Cdm03hn?P0k^k^0>g]k@3^k^h0aLG50=gMg@3Ogml0n?Sh0=KFeP3EeMD0gmoO0?oo
o`3Fe]H0l?3`0?Shn0030?Cdm080oooo00P0fm_K0>7Qh@3dm?@0n?Sh09fMW@2o_kl0g=cL0:>SXd40
oooo000j0?ooo`060>;RhP3^k^h0k>c/0?ooo`3Jf]X0hn?S0P3gmoL0403Zj^X0l_;b0>k^kP29RHT0
moOg0??cl`3gmoL0oooo0??cl`3[jn/0lo?c0=7Ad@3clo<0oooo0?Ogm`3Shn<20>c/k0070??cl`3V
i^H0fMWI0<_;b`3UiND0k>c/0?ooo`020?Ogm`<0oooo0180lo?c0?7al@3gmoL0jn_[0>CTi03gmoL0
oooo0>c/k03UiND0hn?S0<W9b@3AdM40e]KF0:2PX02`/;00k>c/0?Ogm`3Zj^X20?Ogm`030??cl`3V
i^H0i^KV0080k^k^00P0a<C40>c/k03Fe]H0f][J0451@@3/k>`0lo?c0?Ogmbl0oooo00<0moOg0?oo
o`3oool01`3oool00`3AdM40moOg0?KfmP020>k^kP040>CTi03gmoL0moOg0?Cdm080moOg0100V9RH
0?KfmP3dm?@0moOg0?ooo`3dm?@0kNg]0>c/k03;bl/0iNGU0?KfmP3dm?@0kno_0>c/k03_knl0m?Cd
0P3IfMT0103Kfm/0kno_0>o_k`3oool30?Ogm`0D0?ooo`3gmoL0m?Cd0>GUi@3oool0i>CT0>g]k@3_
knl0oooo0>o_k`3UiND0i>CT0<g=c@3;bl/0i>CT0<W9b@3De=@0kno_0?KfmP3Vi^H20?Ogm`030>KV
iP3fm_H0m_Kf0080oooo00P0bLW90>k^kP3Kfm/0kno_065QH@31`L40cLg=0=WIfBl0oooo00<0n?Sh
0?ooo`3oool01`3oool00`3Kfm/0m?Cd0?Shn0020>o_k`080>g]k@3oool0oooo0?ooo`3gmoL0n?Sh
09bLW03hn?P20?Cdm00L0?Ogm`3]kNd0kno_0?Cdm03>c/h0e]KF0?3`l03hn?P0iNGU0?Cdm03`l?00
k^k^0=_Kf`3MgMd0e]KF0=kNgP3`l?00oooo0>o_k`3dm?@0n?Sh0?Ogm`3hn?P0k>c/0>GUi@3oool0
iNGU0?ooo`80n?Sh00T0l?3`0=KFeP3UiND0fm_K0=OGe`3^k^h0g]kN0>SXj03`l?000`3hn?P03P3d
m?@0k>c/0?ooo`3oool0n?Sh0?ooo`3Fe]H0n?Sh0>GUi@3dm?@0Ogmo0=3@d03AdM40e=CD@@3oool0
03X0oooo00L0T92@0?ooo`3Bd]80k^k^0>_[j`3oool0k^k^0080moOg00@0j^[Z0=KFeP29RHT0moOg
103oool01`3^k^h0h^;R0?;blP3Zj^X0moOg0=WIf@3Rh^800P3gmoL0103^k^h0lo?c0>[ZjP3Ng]h2
0>_[j`D0moOg00D0oooo0??cl`3alO40oooo0?Ogm`020>[ZjP030??cl`3oool0moOg0080oooo00D0
i^KV0=SHf03gmoL0lo?c0=WIf@020?Ogm`040>KViP3^k^h0k^k^0?Ogm`80k^k^00P0oooo0=;BdP3Z
j^X0d=3@0>?Sh`1_Kfl0j^[Z0>KViS00oooo103gmoL60?ooo`0707UiN@3oool0g=cL0>o_k`3gmoL0
oooo0>o_k`020?KfmP80m?Cd00<0V9RH0?Ogm`3oool00`3oool02P3AdM40bl_;0>g]k@3dm?@0oooo
0>CTi03dm?@0h>3P0?ooo`3[jn/20?KfmP040>c/k03Ph>00i^KV0>GUi@80moOg00`0m?Cd0?Ogm`3f
m_H0lo?c0?ooo`3bl_80moOg0>o_k`3gmoL0j>SX0?ooo`3fm_H20?ooo`070>KViP3QhN40jn_[0??c
l`3Lg=`0m?Cd0?Ogm`020?ooo`0=0?KfmP3[jn/0m_Kf0?KfmP3gmoL0e=CD0>CTi03IfMT0oooo08J6
QP3Ph>00][Jf0?Cdm00_0?ooo`@0n?Sh1P3oool01`2ATI40n?Sh0>GUi@3_knl0n?Sh0?ooo`3`l?00
0P3clo<0103gmoL0m?Cd0::RXP3hn?P30?ooo`0:0??cl`3Ng]h0emOG0>GUi@3dm?@0kno_0?Cdm03W
inL0j>SX0?Shn0<0m?Cd00<0n?Sh0>GUi@3Xj>P00`3_knl0103]kNd0n?Sh0?Shn03]kNd20?ooo`05
0?Ogm`3dm?@0n?Sh0?Cdm03oool00`3hn?P01`3clo<0k^k^0>g]k@3dm?@0g]kN0?Cdm03gmoL00P3_
knl03@3oool0moOg0?Shn03oool0moOg0=_Kf`3UiND0fm_K0?ooo`2FUYH0hn?S0:j^[P3dm?@0@@3o
ool003X0oooo00l0Xj>S0>[ZjP3oool0oooo0?Gem@3gmoL0hn?S0>[ZjP3oool0k^k^0>CTi02?Shl0
k>c/0?ooo`3gmoL0103oool03@3gmoL0a<C40<k>cP3Shn<0dM7A0;Ng]`3AdM40fMWI0<71`@3:b/X0
dM7A0<g=c@3clo<00P3gmoL03@3oool0lo?c0?ooo`3oool0lo?c0>[ZjP3Shn<0moOg0>[ZjP3IfMT0
g]kN0>c/k03clo<00`3gmoL0103[jn/0oooo0>k^kP3gmoL20?ooo`0?0>k^kP3oool0oooo0>_[j`3V
i^H0k^k^0=SHf03Ti>@0h^;R0<o?c`35aLD0lo?c0>;RhP3^k^h0f][J02h0oooo00H0moOg0?ooo`3g
moL0oooo0?Ogm`3oool20?Ogm`040?ooo`3gmoL0oooo08b<S080moOg0P3oool02P3gmoL0i>CT0?Cd
m03oool0m?Cd0>3Ph02NWYh0iNGU0?ooo`3gmoL30?ooo`0@0?Ogm`3UiND0cLg=0=WIf@3QhN40m?Cd
0=CDe03<c<`0fMWI0;fm_@3<c<`0cLg=0=7Ad@3IfMT0i>CT0?Ogm`80oooo00/0iNGU0?ooo`3fm_H0
kNg]0>KViP3_knl0i>CT0>_[j`3IfMT0kno_0>KViP030?ooo`060?Ogm`3oool0m_Kf0?Ogm`3oool0
l_;b0P3oool03@3fm_H0moOg0?KfmP3bl_80j>SX0>3Ph03Ti>@0fMWI0=CDe03fm_H0h>3P0;bl_03<
c<`0;P3oool01P3hn?P0oooo0?Shn03oool0n?Sh0?ooo`80n?Sh00H0oooo0?Shn03oool0XZ:R0?oo
o`3gmoL20?ooo`0@0?Ogm`3/k>`0oooo0?ooo`3dm?@0hN7Q0:f][@3`l?00oooo0?Shn03oool0moOg
0?ooo`3/k>`0inOW0=7Ad@80e]KF00/0lo?c0=_Kf`3@d=00dM7A0<W9b@3QhN40d=3@0=?Cd`3QhN40
k^k^0>o_k`020?ooo`0?0?Shn03oool0m?Cd0>SXj03^k^h0j>SX0>KViP3^k^h0fm_K0?Shn03/k>`0
n?Sh0?Cdm03hn?P0m?Cd0080n?Sh0180moOg0?ooo`3dm?@0m?Cd0?Shn03oool0k>c/0?Shn03oool0
jNWY0>GUi@3Shn<0g]kN0=gMg@3hn?P0hn?S0;Vi^@36a/I10?ooo`00>P3oool03@3;bl/0f][J0?oo
o`3Zj^X0i>CT0?ooo`3AdM40i>CT0>c/k03Shn<0b<S809NGU`3/k>`00P3gmoL50?ooo`0<0=WIf@3c
lo<0g]kN0=SHf03Rh^80b/[:0>k^kP3Hf=P0jn_[0>;RhP3gmoL0lo?c0P3oool00`3gmoL0lo?c0?Og
m`020?ooo`080?Ogm`3emOD0moOg0>;RhP3clo<0moOg0=WIf@3Zj^X30?Ogm`030??cl`3gmoL0oooo
00<0oooo0P3^k^h03@3oool0moOg0?ooo`3gmoL0/;2`0>KViP3UiND0k>c/09JFUP3Rh^80lo?c0?Og
m`1>CTh0;P3oool30?Ogm`030?ooo`3gmoL0oooo00D0oooo00P0^[Zj0>o_k`3oool0moOg0?Cdm03o
ool0h>3P0?Cdm080moOg00<0eMGE0:j^[P3[jn/00P3gmoL20?ooo`040?Ogm`3oool0oooo0>3Ph0<0
fMWI00P0e=CD0?Cdm03IfMT0g=cL0=7Ad@3Ti>@0oooo0>CTi080oooo00D0moOg0>c/k03dm?@0m_Kf
0>_[j`020?ooo`090>k^kP3Ti>@0m?Cd0>g]k@3Vi^H0kNg]0>k^kP3oool0moOg0080oooo0`3fm_H0
403oool0m_Kf0?KfmP3fm_H0moOg0?KfmP3^k^h0a/K60>g]k@3dm?@0moOg0;Zj^P3/k>`0fm_K0=gM
g@0c<c<80?ooo`030?Ogm`3oool0oooo00@0oooo00<0moOg0?ooo`3oool0703oool30?Shn0030?oo
o`3hn?P0oooo00D0oooo00d0c<c<0>k^kP3oool0moOg0??cl`3oool0k>c/0??cl`3gmoL0n?Sh0=OG
e`35aLD0kno_0080n?Sh00<0oooo0?Ogm`3hn?P00`3oool0403WinL0e]KF0<[:bP3Fe]H0k^k^0<W9
b@3Kfm/0b/[:0=KFeP3hn?P0k^k^0?Ogm`3oool0m?Cd0?Shn03dm?@20?Shn0040?ooo`3hn?P0kno_
0>k^kP80moOg00D0inOW0?Shn03_knl0oooo0?Shn0030?ooo`D0n?Sh00D0oooo0?Ogm`3hn?P0moOg
0=CDe0020>k^kP060?3`l03@d=00jNWY0=gMg@3UiND0:BTY203oool00`3hn?P0oooo0?ooo`040?oo
o`030?Shn03oool0oooo02l0oooo000j0?ooo`0=0>_[j`3emOD0l_;b0?7al@3/k>`0lO7a0>GUi@3F
e]H0hn?S0>k^kP3Zj^X0ZJVY0=[JfP020?Ogma80oooo00<0moOg0?ooo`3oool00`3oool01`3clo<0
moOg0?Ogm`3Zj^X0aLG50;Vi^@3Ng]h00P3^k^h0602GUiL0W9bL0>GUi@3oool0k^k^0?ooo`3clo<0
jn_[0=SHf039bLT0hn?S0?ooo`3^k^h0moOg0;2`/03^k^h0i>CT0?ooo`32`/80_;bl0>GUi@2m_Kd0
ZZZZ0>?Shbd0oooo00<0moOg0?ooo`3gmoL00P3gmoL60?ooo`040>OWi`3oool0moOg0?Ogm`80oooo
00T0m?Cd0>3Ph03^k^h0moOg0>KViP31`L40g=cL0??cl`3gmoL00P3oool00`3dm?@0oooo0?ooo`02
0?ooo`80m_Kf00L0oooo0?KfmP3oool0m_Kf0?ooo`3dm?@0moOg0080oooo00<0m?Cd0?ooo`3oool0
0P3fm_H05@3bl_80m_Kf0?Ogm`3oool0hN7Q0<_;b`2m_Kd0kNg]0?Ogm`3[jn/0]kNg09nOW`3UiND0
oooo0>k^kP3oool0k>c/0>CTi03Kfm/0e=CD0?Ogm`020?;blP0;0?Cdm03:b/X0moOg0?Cdm03clo<0
dM7A0<g=c@3;bl/0`/;20:BTY03MgMd0;@3oool00`3hn?P0oooo0?Shn0020?Shn0H0oooo00@0l?3`
0?Shn03gmoL0moOg0P3oool0303dm?@0kNg]0?Ogm`3hn?P0j>SX0=KFeP3Ng]h0m?Cd0?Shn03oool0
moOg0?Cdm0@0oooo0P3`l?001@3oool0l?3`0?ooo`3`l?00oooo0080m?Cd0P3gmoL00`3]kNd0oooo
0?ooo`040?Shn00B0?ooo`3hn?P0g=cL0<S8b036a/H0kno_0?Cdm03`l?00aLG50;6a/@3WinL0n?Sh
0?Cdm03oool0lo?c0>g]k@3Shn<0fm_K0`3hn?P02`3clo<0dm?C0?Shn03oool0m?Cd0=oOg`3Kfm/0
e]KF0<[:bP2SXj<0l?3`0400oooo000k0?ooo`0>0>k^kP3/k>`0jn_[0?Gem@3gmoL0oooo0>k^kP3[
jn/0fMWI0>c/k03Ogml0fMWI0>CTi03gmoLB0?ooo`80moOg0100oooo0??cl`3gmoL0oooo0?Ogm`3o
ool0lo?c0?ooo`3emOD0oooo0<k>cP3Zj^X0hn?S0=KFeP3^k^h0dM7A0P3Fe]H04`2m_Kd0f=SH0?Ge
m@3/k>`0alO70>k^kP3Vi^H0moOg0=kNgP3AdM40j^[Z0=KFeP3/k>`0gmoO0:b/[02n_[h0fMWI0=7A
d@3^k^h0>P3oool01`3clo<0moOg0?ooo`3gmoL0oooo0>k^kP3/k>`00P3UiND01@3Xj>P0i>CT0>KV
iP3dm?@0moOg00D0oooo0`3fm_H00`3oool0l_;b0?KfmP020?;blP050?KfmP3dm?@0oooo0?ooo`3g
moL00P3oool01@3gmoL0oooo0?KfmP3bl_80oooo0080m_Kf0P3dm?@0203Cdm<0i>CT0=cLg03Ti>@0
m_Kf0>KViP3IfMT0dm?C0P3Ph>020?Ogm`0?0=gMg@3bl_80oooo0?Ogm`3]kNd0e=CD0?Cdm03]kNd0
moOg0>g]k@31`L40eMGE0>c/k03De=@0iNGU03T0oooo00`0moOg0?Shn03hn?P0oooo0?Ogm`3oool0
n?Sh0??cl`3^k^h0inOW0>7Qh@3`l?020?Cdm0030?Shn03oool0oooo00<0oooo0`3`l?000`3oool0
jNWY0?3`l0020>WYj@050?3`l03]kNd0oooo0?ooo`3dm?@00P3oool04`3hn?P0oooo0?ooo`3dm?@0
n?Sh0?Cdm03oool0moOg0>g]k@3Kfm/0hN7Q0=kNgP3]kNd0oooo0>OWi`3Vi^H0g]kN0>GUi@3^k^h0
0P3hn?P03`3Xj>P0n?Sh0?Shn03gmoL0n?Sh0=_Kf`3clo<0iNGU0?3`l03clo<0eMGE0=gMg@3Xj>P0
fm_K0?3`l0100?ooo`00>`3oool03P3Vi^H0e]KF0??cl`3Rh^80k^k^0?ooo`3Shn<0k^k^0?ooo`3[
jn/0dM7A0<k>cP3alO40moOg4P3oool20?Ogm`030?ooo`3gmoL0moOg00H0oooo01<0mOGe0?Ogm`3^
k^h0i>CT0=7Ad@3Ogml0k^k^0>c/k03Rh^80gmoO0>_[j`3AdM40f][J0?Ogm`3^k^h0i^KV0??cl`3R
h^80bl_;0080mOGe00H0jn_[0>c/k02e]KD0jn_[0>?Sh`1eMGDj0?ooo`030?Ogm`3/k>`0kno_0080
moOg00/0oooo0>CTi03^k^h0oooo0?Cdm03Xj>P0i>CT0?Ogm`3/k>`0moOg0?ooo`020?Ogm`030?Cd
m03bl_80m_Kf00<0oooo00D0m_Kf0?ooo`3oool0m_Kf0?ooo`020?Ogm`030?ooo`3gmoL0i>CT0080
moOg0P3oool04`3fm_H0l_;b0?KfmP3oool0moOg0>o_k`3]kNd0k^k^0=cLg03Cdm<0g=cL0?ooo`3g
moL0kNg]0>3Ph03/k>`0moOg0=gMg@3_knl00P3oool20?Cdm0090=CDe03oool0oooo0?Ogm`3fm_H0
gMgM0>7Qh@3/k>`0I6AT03X0oooo00<0m?Cd0>g]k@3]kNd00P3hn?P0203oool0kno_0?Shn03oool0
k>c/0>7Qh@3hn?P0moOg0P3hn?P01P3gmoL0n?Sh0?Shn03dm?@0jNWY0?3`l0<0oooo00D0l?3`0?oo
o`3oool0l?3`0?ooo`020?Shn0030?Ogm`3_knl0m?Cd0080n?Sh00<0oooo0?Shn03dm?@00P3oool0
1P3hn?P0moOg0??cl`3^k^h0kno_0=kNgP80fm_K01D0oooo0??cl`3]kNd0k^k^0?Cdm03oool0gmoO
0>o_k`3dm?@0oooo0??cl`3dm?@0fm_K0?ooo`3`l?00k^k^0?Shn03Xj>P0iNGU0>OWi`1IFET0@@3o
ool003X0oooo00H0dM7A0=[JfP3oool0hn?S0?Gem@3Vi^H20>k^kP060?Ogm`3Zj^X0g]kN0=3@d03Z
j^X0lo?c0P3gmoL@0?ooo`<0moOg00<0oooo0?Ogm`3oool0103oool20?Ogm`070?Gem@3oool0oooo
0??cl`3^k^h0moOg0>CTi0020<_;b`0C0=oOg`3Fe]H0i^KV0??cl`3^k^h0jn_[0?ooo`3Rh^80[jn_
0?ooo`3gmoL0hn?S0>;RhP3[jn/0iNGU0=KFeP3clo<0_[jn0:BTY00e0?ooo`090?Ogm`3oool0oooo
0<;2`P3Ti>@0m?Cd0>GUi@3oool0m?Cd0080moOg00T0oooo0>k^kP3/k>`0kNg]0>7Qh@3Xj>P0k>c/
0?Ogm`3oool00P3gmoL00`3oool0moOg0?;blP030?KfmP80oooo00<0m_Kf0?ooo`3oool00P3oool2
0?Ogm`030>CTi03/k>`0oooo00@0m_Kf01H0oooo0?KfmP3gmoL0moOg0?ooo`3dm?@0k>c/0?KfmP3^
k^h0kNg]0>3Ph03Kfm/0i^KV0=WIf@3clo<0kNg]0?ooo`3_knl0oooo0?Cdm031`L40oooo0P3gmoL0
1`3]kNd0k>c/0>c/k03]kNd0k^k^0<;2`P2GUiL0=@3oool02@3hn?P0oooo0?ooo`3De=@0j>SX0?Cd
m03WinL0oooo0?Cdm0030?Shn0080>k^kP3_knl0m?Cd0=_Kf`3YjNT0k^k^0?Shn03gmoL20?Shn003
0?ooo`3hn?P0jNWY00<0l?3`0P3oool00`3`l?00oooo0?ooo`020?ooo`080?Cdm03hn?P0m?Cd0>k^
kP3oool0n?Sh0?Cdm03hn?P20?ooo`040?Shn03oool0oooo0?ooo`<0m?Cd00T0kno_0>k^kP3UiND0
g=cL0>SXj03Kfm/0kno_0?Ogm`3hn?P00P3_knl0303dm?@0e]KF0?ooo`3`l?00n?Sh0?3`l03/k>`0
lo?c0>g]k@3^k^h0cLg=08Z:RT00oooo000j0?ooo`070861P@3^k^h0moOg0>CTi03gmoL0j^[Z0?Ge
m@020?Ogm`050>KViP3emOD0g]kN0<k>cP3^k^h04P3oool40?Ogm`P0oooo00L0moOg0?ooo`3emOD0
oooo0??cl`3gmoL0lo?c0080oooo0`3^k^h01`3oool0k^k^0>k^kP3gmoL0hn?S0<C4a03oool00P3e
mOD0203oool0moOg0?Ogm`3gmoL0hn?S0<_;b`1EEED0moOg=`3oool0201]KFd0oooo0?Ogm`3Vi^H0
m_Kf0>c/k03oool0kNg]0P3dm?@00`3/k>`0e=CD0>KViP020>k^kP80oooo0`3gmoL30?KfmP@0oooo
0`3fm_H0103oool0m?Cd0?Ogm`3gmoL20?ooo`050?KfmP3clo<0m_Kf0?ooo`3bl_800P3fm_H20?oo
o`090>o_k`3dm?@0moOg0>c/k03gmoL0i>CT0?KfmP3oool0l_;b0080m_Kf0P3oool0103_knl0moOg
0>c/k03Cdm<40?ooo`<0moOg00@0k^k^0<o?c`1YJFT0moOg=`3oool0101dM7@0lo?c0?Shn03Xj>P2
0?Shn0030?ooo`3/k>`0m?Cd0080m?Cd00@0fm_K0?Cdm03]kNd0l?3`0P3oool30?Shn0<0l?3`103o
ool01`3`l?00kNg]0?3`l03oool0m?Cd0?Shn03_knl00P3oool01@3hn?P0m?Cd0?Shn03oool0m?Cd
0080n?Sh00<0oooo0?Shn03_knl00P3hn?P00`3dm?@0n?Sh0>k^kP020?ooo`<0n?Sh00H0m?Cd0?Sh
n03gmoL0moOg0>k^kP3Kfm/40?ooo`80moOg00D0l?3`0?Ogm`3AdM40JFUY0?Shn00o0?ooo`00>P3o
ool03P1QHF40lo?c0>k^kP3gmoL0l_;b0=[JfP3Ng]h0oooo0>c/k03oool0k^k^0>GUi@37alL0_[jn
0P3gmoLB0?ooo`030??cl`3oool0oooo00D0oooo0P3gmoL20?ooo`80mOGe00<0oooo0??cl`3gmoL0
0`3oool30>k^kP0?0?ooo`3Vi^H0hn?S0=3@d03Ti>@0k^k^0?Gem@3Rh^80f][J0?ooo`3clo<0iNGU
0>_[j`3/k>`0Xj>S03D0oooo0P3gmoL00`3oool0@T920>g]k@020?Cdm00<0?KfmP3]kNd0m?Cd0?oo
o`3gmoL0oooo0>o_k`3]kNd0gMgM0<_;b`3clo<0kno_0P3oool02`3gmoL0oooo0?KfmP3oool0l_;b
0?ooo`3fm_H0oooo0?KfmP3oool0l_;b00D0oooo00@0k^k^0?ooo`3fm_H0l_;b0P3fm_H20?ooo`<0
moOg00@0m?Cd0?ooo`3gmoL0oooo0P3dm?@30?ooo`80m_Kf0`3oool0203gmoL0g=cL0>_[j`3gmoL0
oooo0>o_k`3UiND0oooo0P3dm?@00`3/k>`0k^k^096AT@0e0?ooo`80n?Sh00<0oooo03Ph>03UiND0
0P3]kNd06@3dm?@0k^k^0?Cdm03oool0moOg0?ooo`3_knl0j>SX0>OWi`3Ogml0m?Cd0?3`l03gmoL0
oooo0?Shn03oool0l?3`0?ooo`3YjNT0oooo0?3`l03oool0l?3`0?ooo`3YjNT01`3oool01P3hn?P0
m?Cd0?Shn03oool0n?Sh0?ooo`<0moOg00@0n?Sh0?ooo`3dm?@0oooo0P3dm?@20?ooo`040?Shn03d
m?@0m?Cd0?Shn080oooo00T0n?Sh0>GUi@3hn?P0n?Sh0?ooo`3YjNT0inOW0??cl`3gmoL00P3dm?@0
0`3_knl0TI6A0?ooo`0o0?ooo`00>P3oool01P0I6AT0moOg0>_[j`3^k^h0mOGe0?Ogm`<0oooo00P0
k^k^0?ooo`3Fe]H0mOGe0=[JfP3Zj^X0oooo0?Ogm`l0oooo00<0moOg0?ooo`3gmoL02P3oool20?Ge
m@80oooo0P3gmoL01@3oool0moOg0?ooo`3oool0i^KV0080k^k^00l0oooo0=WIf@3clo<0hn?S0??c
l`3IfMT0_;bl0??cl`3gmoL0k^k^0=oOg`3Ti>@0oooo0;bl_032`/80=`3oool00`000000kno_0?Cd
m0020?ooo`0<0?KfmP3oool0moOg0?Cdm03gmoL0oooo0>c/k03oool0fMWI0>g]k@3gmoL0m?Cd0P3o
ool0103gmoL0m_Kf0?ooo`3oool20?KfmP80oooo00<0l_;b0?KfmP3oool00P3oool00`3gmoL0oooo
0>c/k0020?KfmP080?ooo`3fm_H0oooo0?KfmP3oool0moOg0>o_k`3oool20?Ogm`030?ooo`3gmoL0
kNg]0080moOg00<0oooo0?KfmP3fm_H00`3oool03`3gmoL0k^k^0=_Kf`3_knl0m?Cd0>g]k@3@d=00
l_;b0?KfmP3^k^h0h>3P0?Cdm03oool0`L710:j^[P0g0?ooo`040000003WinL0kNg]0?Ogm`80n?Sh
00l0oooo0?Ogm`3clo<0n?Sh0?ooo`3Xj>P0oooo0>;RhP3YjNT0n?Sh0?Cdm03oool0moOg0?Shn03`
l?000P3oool20?3`l080oooo00<0jNWY0?3`l03oool00P3oool00`3dm?@0oooo0?Shn0020?Shn008
0?ooo`3hn?P0oooo0?Shn03oool0m?Cd0?Ogm`3oool20?Shn0030?ooo`3hn?P0k^k^0080n?Sh00@0
oooo0?Shn03hn?P0n?Sh0P3oool03`3gmoL0n?Sh0=cLg03`l?00lo?c0?Shn03UiND0lo?c0?ooo`3g
moL0j>SX0??cl`3oool0aLG50;jn_P0o0?ooo`00>P3oool04@0o?cl0k^k^0??cl`3gmoL0j^[Z0?7a
l@3^k^h0e]KF0>c/k03gmoL0oooo0=kNgP3emOD0oooo0>KViP3^k^h0moOg00h0oooo0`3gmoL0103c
lo<0oooo0?ooo`3gmoL20?ooo`0;0?Ogm`3oool0oooo0?Gem@3oool0lO7a0?Gem@3oool0moOg0?oo
o`3gmoL00`3oool0203^k^h0oooo0>k^kP3gmoL0g]kN0>[ZjP3Fe]H0mOGe0P3oool01`3[jn/0moOg
0?ooo`3^k^h0moOg0?ooo`3^k^h00P3AdM4d0?ooo`080?Ogm`3oool0oooo03<c<`3gmoL0j>SX0?Og
m`3/k>`20?Ogm`0:0>g]k@3dm?@0moOg0?ooo`3De=@0oooo0>KViP3Ph>00k>c/0?Ogm`80oooo00D0
moOg0?ooo`3oool0m_Kf0?;blP020?ooo`80m_Kf00`0oooo0?KfmP3oool0kno_0?Ogm`3Ti>@0moOg
0?;blP3fm_H0oooo0?;blP3oool30?Ogm`050>o_k`3gmoL0m?Cd0?Ogm`3oool00P3gmoL00`3oool0
m_Kf0?ooo`030?ooo`050?KfmP3gmoL0kno_0>GUi@3^k^h00`3oool02@3[jn/0m_Kf0?ooo`3^k^h0
m_Kf0?ooo`3gmoL0b<S80;fm_@0d0?ooo`0G0?Shn03oool0oooo038b<P3hn?P0g=cL0>o_k`3/k>`0
m?Cd0?Shn03]kNd0lo?c0?Ogm`3oool0e]KF0?ooo`3YjNT0iNGU0>k^kP3hn?P0moOg0?ooo`3hn?P0
0P3oool0103`l?00jNWY0?ooo`3oool20?3`l0060?ooo`3`l?00oooo0>OWi`3hn?P0m?Cd0`3hn?P0
2`3oool0m?Cd0?Shn03gmoL0m?Cd0>o_k`3`l?00n?Sh0?Cdm03hn?P0oooo0080n?Sh00/0oooo0?Sh
n03hn?P0oooo0?Cdm03oool0n?Sh0?Ogm`3`l?00iNGU0?Shn0030?ooo`040?Cdm03clo<0oooo0?Sh
n080oooo00<0n?Sh0<o?c`2m_Kd0?`3oool003X0oooo00H0EEEE0?Gem@3gmoL0jn_[0??cl`3emOD2
0?ooo`080=;BdP3^k^h0hn?S0>?Sh`3Zj^X0k^k^0>[ZjP3emODB0?ooo`030?Ogm`3oool0moOg00<0
moOg0`3oool30?Gem@<0oooo00<0lo?c0?ooo`3gmoL00P3oool04`3^k^h0i^KV0?Ogm`3gmoL0hn?S
0>;RhP3Zj^X0k>c/0>?Sh`3gmoL0k>c/0?Ogm`3oool0jn_[0?ooo`3alO40i^KV06e]K@3gmoL0=@3o
ool20?Ogm`0304Q8B03gmoL0moOg0080moOg00@0oooo0?Ogm`3oool0kNg]0P3gmoL20?Cdm0040>c/
k03dm?@0kNg]0?Ogm`<0oooo00<0moOg0?ooo`3bl_800P3fm_H20?ooo`80l_;b0`3oool0103UiND0
moOg0?Ogm`3fm_H40?Ogm`030?ooo`3dm?@0m?Cd0080oooo0P3gmoL00`3oool0moOg0?ooo`020?oo
o`040?;blP3fm_H0m_Kf0?ooo`80m?Cd00D0k^k^0>o_k`3^k^h0lo?c0>o_k`020?Ogm`030?KfmP3o
ool0k>c/0080oooo00<0kNg]06=SH`3gmoL0=@3oool20?Shn00402h^;P3]kNd0kno_0?Cdm0<0n?Sh
00@0oooo0>g]k@3hn?P0n?Sh103dm?@0203/k>`0n?Sh0?Ogm`3oool0moOg0?Shn03oool0jNWY0P3`
l?020?ooo`80jNWY0P3oool00`3gmoL0n?Sh0?Shn0020?Shn0@0moOg00<0oooo0?Ogm`3clo<00P3o
ool20?Shn00:0?ooo`3hn?P0oooo0?ooo`3hn?P0m?Cd0?ooo`3hn?P0oooo0??cl`<0n?Sh00@0kNg]
0?Shn03`l?00lo?c0P3gmoL01`3oool0m?Cd0?ooo`3oool0kNg]05eMG@3hn?P0?`3oool003T0oooo
00X0k^k^069RHP3Rh^80jn_[0??cl`3gmoL0lo?c0?;blP3Vi^H0oooo0P3^k^h00`3/k>`0g]kN0>k^
kP020>[ZjP030??cl`3oool0oooo00d0oooo00P0moOg0?ooo`3gmoL0oooo0?Ogm`3oool0lo?c0?Og
m`80oooo00<0mOGe0?7al@3oool00P3oool20??cl`0>0?Ogm`3oool0oooo0?ooo`3gmoL0oooo0??c
l`3Ti>@0hn?S0>;RhP3UiND0moOg0>?Sh`3oool20??cl`070>c/k03^k^h0lo?c0??cl`3gmoL0g]kN
0;Rh^00d0?ooo`070?Ogm`3oool0oooo0>CTi01WIfL0h>3P0?Cdm0020?ooo`030?Cdm03Ti>@0m?Cd
0080moOg00<0kno_0>k^kP3oool00P3dm?@00`3Ph>00i^KV0?Ogm`030?ooo`040?Ogm`3oool0m_Kf
0?ooo`80m_Kf00<0oooo0?;blP3gmoL00P3oool0103gmoL0kNg]0?;blP3fm_H20?ooo`050?Cdm03o
ool0oooo0?Ogm`3oool00P3gmoL00`3^k^h0moOg0??cl`020?ooo`0F0?KfmP3oool0oooo0?Ogm`3o
ool0m?Cd0?ooo`3gmoL0k^k^0>GUi@3^k^h0kno_0?ooo`3clo<0l_;b0?Ogm`3^k^h0lo?c0?Cdm03g
moL0kNg]09RHV3@0oooo00L0n?Sh0?ooo`3oool0m?Cd05aLG03Lg=`0m?Cd0080oooo00<0m?Cd0>GU
i@3dm?@00P3hn?P0203`l?00kno_0?Shn03hn?P0m?Cd0=CDe03Xj>P0kno_0`3oool0103hn?P0oooo
0?3`l03oool20?3`l0090?ooo`3YjNT0n?Sh0?ooo`3gmoL0n?Sh0>k^kP3dm?@0n?Sh0080oooo00<0
lo?c0?Ogm`3oool00`3hn?P00`3dm?@0n?Sh0?Shn0020?Shn080oooo0P3hn?P01P3gmoL0n?Sh0??c
l`3oool0n?Sh0>c/k0<0l?3`00H0lo?c0?ooo`3gmoL0n?Sh0>o_k`3oool20?Ogm`030>k^kP2RXZ80
oooo03l0oooo000i0?ooo`0:0?Ogm`1RHV80i>CT0>[ZjP3gmoL0lo?c0?Ogm`3emOD0k^k^0>KViP80
oooo00<0j^[Z0?Ogm`3clo<00P3[jn/00`3/k>`0moOg0?ooo`0>0?ooo`030?Ogm`3oool0oooo0080
moOg00@0lo?c0?Ogm`3gmoL0moOg103emOD0103oool0lo?c0?Ogm`3gmoL30?ooo`80k^k^00@0oooo
0?Ogm`3gmoL0cLg=0P3gmoL00`3emOD0k>c/0?Ogm`040?Ogm`040?ooo`3Jf]X0jn_[09bLW3D0oooo
00L0moOg0?ooo`3]kNd0B4Q80>KViP3]kNd0iNGU00@0moOg00D0m?Cd0?Ogm`3gmoL0lo?c0>CTi002
0?KfmP030?;blP3gmoL0kNg]0080oooo00P0moOg0?KfmP3oool0l_;b0?KfmP3bl_80oooo0?;blP@0
oooo00L0kno_0?KfmP3bl_80m_Kf0?ooo`3gmoL0m?Cd0080moOg00D0oooo0?Ogm`3gmoL0k>c/0?oo
o`020?Ogm`030?;blP3fm_H0l_;b00<0m_Kf0P3oool01P3dm?@0moOg0>OWi`3]kNd0moOg0?ooo`80
moOg0P3fm_H01P3gmoL0m_Kf0?ooo`3_knl0k>c/07inOSD0oooo00@0n?Sh0?ooo`3^k^h0=3@d0`3X
j>P20>o_k`030?Ogm`3hn?P0m?Cd00<0n?Sh00H0j>SX0?ooo`3hn?P0iNGU0?Cdm03^k^h20?Ogm`08
0?Shn03`l?00oooo0>WYj@3`l?00jNWY0?ooo`3YjNT40?ooo`050?3`l03hn?P0m?Cd0?Shn03oool0
1@3gmoL20?Shn0080?Cdm03oool0n?Sh0?Shn03oool0m?Cd0?Shn03dm?@20?Shn080oooo00@0m?Cd
0?Shn03dm?@0hN7Q103oool0203clo<0moOg0?ooo`3gmoL0lo?c0>o_k`3^k^h0Ogmo@03oool003T0
oooo0180moOg069RHP3bl_80k>c/0>k^kP3clo<0jn_[0=[JfP3Ogml0i^KV0>[ZjP3/k>`0h^;R0>k^
kP3IfMT0moOg0>[ZjP3/k>`20?Ogm``0oooo00<0moOg0??cl`3gmoL00P3gmoL30?ooo`80moOg0`3o
ool00`3emOD0oooo0??cl`030?ooo`0=0>k^kP3oool0k^k^0>k^kP3oool0g]kN0>CTi03Jf]X0j^[Z
0?Gem@3oool0jn_[0>GUi@020=kNgP80moOg00@0d];B0>k^kP3AdM40R8R8=@3oool02`3gmoL0oooo
0?Ogm`3]kNd0FUYJ0>g]k@3/k>`0m?Cd0?ooo`3]kNd0k^k^0080m?Cd00X0m_Kf0?Ogm`3Ti>@0k>c/
0>SXj03^k^h0kNg]0>o_k`3clo<0moOg0P3oool00`3gmoL0m_Kf0?;blP020?KfmP<0oooo00H0m?Cd
0?ooo`3dm?@0moOg0?ooo`3bl_830?Ogm`040?ooo`3dm?@0oooo0?Cdm080moOg0P3oool20?;blP03
0?KfmP3bl_80m_Kf00<0oooo00L0moOg0?ooo`3^k^h0gMgM0?Cdm03^k^h0oooo00<0m?Cd00L0i^KV
0?Ogm`3gmoL0h>3P0>k^kP3UiND0TI6A03D0oooo00/0n?Sh0?ooo`3hn?P0k^k^04E5A@3UiND0j>SX
0?Cdm03oool0k^k^0?Shn0020?Cdm080n?Sh00H0iNGU0?Cdm03]kNd0kno_0?3`l03Xj>P20?Shn005
0??cl`3oool0n?Sh0?3`l03YjNT00P3`l?030?ooo`0?0?Cdm03gmoL0kNg]0?Shn03oool0m?Cd0?Og
m`3hn?P0m?Cd0?Shn03_knl0moOg0?ooo`3hn?P0m?Cd0080oooo00@0n?Sh0?ooo`3oool0oooo0P3h
n?P20?ooo`080?Ogm`3hn?P0m?Cd0>SXj03/k>`0n?Sh0?ooo`3hn?P20>k^kP070>GUi@3oool0oooo
0>g]k@3gmoL0kno_09FEU@110?ooo`00>@3oool0103gmoL0HV9R0?Gem@3Jf]X20??cl`0>0?Ogm`3e
mOD0d];B0?ooo`3Zj^X0lo?c0?Ogm`3clo<0f=SH0=WIf@3Zj^X0jn_[0?ooo`3gmoL;0?ooo`0:0?Og
m`3clo<0moOg0?Ogm`3oool0moOg0?ooo`3clo<0oooo0?Ogm`80oooo00H0mOGe0?ooo`3oool0mOGe
0?ooo`3gmoL40?ooo`0C0>k^kP3clo<0oooo0>_[j`3Ng]h0oooo0=kNgP3/k>`0jn_[0?7al@3IfMT0
iNGU0??cl`3^k^h0moOg0>c/k03[jn/0k^k^06UYJ@0b0?ooo`80moOg01P0oooo0?Ogm`3gmoL0moOg
0>o_k`1JFUX0m?Cd0>c/k03gmoL0m?Cd0?Ogm`3oool0e=CD0?ooo`3[jn/0l_;b0?KfmP3/k>`0cLg=
0=cLg03[jn/0k^k^0?Ogm`3dm?@20?ooo`030?Ogm`3oool0oooo0080m_Kf0P3oool0303dm?@0oooo
0?Ogm`3gmoL0m?Cd0?Ogm`3oool0moOg0?ooo`3gmoL0oooo0>o_k`80oooo0P3gmoL20?ooo`030>k^
kP3oool0m_Kf0080oooo00l0m_Kf0?ooo`3/k>`0m?Cd0?KfmP3Ph>00oooo0?Cdm03/k>`0m?Cd0?oo
o`3_knl0m?Cd0??cl`3^k^h00P3gmoL00`3[jn/0moOg06IVIP0b0?ooo`80n?Sh00X0oooo0?Shn03h
n?P0n?Sh0?3`l015ADD0k>c/0>g]k@3_knl0kNg]0P3hn?P03`3GemL0oooo0?3`l03dm?@0n?Sh0?Cd
m03Fe]H0i^KV0>k^kP3UiND0n?Sh0?Cdm03clo<0oooo0?Shn0020?ooo`80l?3`0P3oool0303dm?@0
moOg0?Cdm03hn?P0m?Cd0?Shn03oool0kNg]0?Shn03clo<0oooo0?Cdm080oooo00D0m?Cd0?Shn03h
n?P0oooo0?Shn0020?ooo`040?Shn03dm?@0oooo0?ooo`80lo?c00T0n?Sh0=kNgP3oool0n?Sh0?Cd
m03^k^h0oooo0>o_k`3hn?P00P3gmoL20?Shn0030?Cdm03hn?P0HV9R0440oooo000j0?ooo`050861
P@3emOD0fMWI0>_[j`3Vi^H00P3gmoL02P3alO40i^KV0=[JfP3emOD0j^[Z0>?Sh`3/k>`0mOGe0?Og
m`3[jn/=0?ooo`80moOg00@0oooo0?Ogm`3gmoL0moOg1P3oool00`3emOD0oooo0?Gem@020?Ogm`03
0??cl`3oool0oooo0080k^k^00h0i^KV0?Ogm`3Shn<0mOGe0>?Sh`3oool0k>c/0>KViP3/k>`0mOGe
0>_[j`3gmoL0lo?c0?ooo`80mOGe00<0k^k^0>CTi00i>CT0=@3oool02P3gmoL0oooo0?Ogm`3oool0
O7al0?Cdm03[jn/0moOg0>KViP3oool20?Ogm`090>g]k@3Ti>@0moOg0>CTi03dm?@0oooo0>k^kP3f
m_H0inOW00D0oooo00<0m?Cd0?ooo`3gmoL00P3oool01`3dm?@0oooo0?ooo`3gmoL0k>c/0>k^kP3f
m_H0103gmoL30?ooo`80moOg0`3oool20?KfmP030?;blP3fm_H0m_Kf0080oooo0`3gmoL02@3Vi^H0
oooo0>k^kP3dm?@0moOg0?ooo`3/k>`0moOg0??cl`030?ooo`030>k^kP3Ti>@06QXJ03D0oooo00H0
n?Sh0?ooo`3hn?P0oooo071`L03/k>`30?Cdm0030?ooo`3hn?P0m?Cd0080k^k^00L0m?Cd0>GUi@3_
knl0n?Sh0>g]k@3hn?P0j>SX00<0oooo0P3gmoL00`3dm?@0oooo0?Shn0020?ooo`070>SXj03gmoL0
moOg0?Cdm03hn?P0oooo0?Shn0020?Ogm`070?Cdm03hn?P0oooo0?Cdm03hn?P0oooo0?Cdm0030?oo
o`040?Cdm03oool0n?Sh0?Cdm0<0oooo0`3hn?P02@3WinL0oooo0?Shn03dm?@0moOg0?ooo`3gmoL0
oooo0??cl`030?ooo`030??cl`3WinL05ADE0440oooo000j0?ooo`0906m_K`3clo<0moOg0>GUi@3J
f]X0k^k^0>CTi03emOD0moOg0080k^k^00L0hn?S0?Ogm`3[jn/0moOg0>KViP3^k^h0hn?S00<0moOg
103oool0103gmoL0oooo0?Ogm`3oool50?Ogm`D0oooo00@0lO7a0?Gem@3alO40mOGe0`3oool03@3g
moL0oooo0?Ogm`3oool0jn_[0?Ogm`3oool0e]KF0>[ZjP3gmoL0k^k^0?;blP3Vi^H00P3clo<0103g
moL0oooo0?Gem@3clo<20?Ogm`040>k^kP3Ng]h0W9bL0>k^kSL0oooo0P3gmoL01`1?Cdl0i>CT0??c
l`3Xj>P0g=cL0?Ogm`3Vi^H0103gmoL02P3dm?@0lo?c0>g]k@3gmoL0i^KV0?ooo`3Vi^H0i>CT0?oo
o`3gmoL40?ooo`030?Ogm`3oool0moOg0080moOg00D0k^k^0?ooo`3oool0moOg0?Cdm0020?Ogm`03
0?Cdm03gmoL0moOg0080oooo00@0m?Cd0?Ogm`3fm_H0l_;b0P3oool20?KfmP030??cl`3dm?@0m?Cd
0080iNGU00<0moOg0?Cdm03^k^h00`3dm?@0103gmoL0oooo0?ooo`3dm?@20?KfmP040>k^kP3UiND0
V9RH0>GUiCL0oooo0P3hn?P0201;Bd/0g]kN0>g]k@3Xj>P0fm_K0?Shn03Xj>P0moOg0`3hn?P02`3/
k>`0kNg]0>GUi@3hn?P0m?Cd0?ooo`3WinL0iNGU0?ooo`3hn?P0oooo0080moOg00@0lo?c0>c/k03g
moL0k>c/0P3hn?P30?ooo`030>o_k`3oool0m?Cd00<0oooo00@0n?Sh0?ooo`3oool0m?Cd0`3hn?P3
0?ooo`0:0?Cdm03gmoL0m?Cd0?Cdm03WinL0iNGU0?Shn03]kNd0n?Sh0?Cdm080lo?c103oool20?Og
m`040?Shn03Xj>P0RXZ:0?3`l440oooo000j0?ooo`0A07YjNP3Shn<0oooo0?Ogm`3Zj^X0jn_[0=kN
gP3Zj^X0moOg0?Gem@3oool0k>c/0>?Sh`3gmoL0oooo0>?Sh`3^k^h00P3Shn<00`3oool0lo?c0?Og
m`020?ooo`040?Ogm`3oool0oooo0?Ogm`80oooo0P3gmoL30?ooo`040?Gem@3oool0mOGe0?Gem@80
lO7a00@0mOGe0?ooo`3oool0oooo0`3gmoL02`3^k^h0i^KV0?Ogm`3oool0k>c/0?;blP3Ng]h0i>CT
0?Gem@3/k>`0oooo00<0moOg00P0l_;b0?Ogm`3[jn/0gmoO0?7al@3Shn<0k>c/07MgMcX0oooo01<0
GemO0=gMg@3oool0moOg0>g]k@3dm?@0hN7Q0>o_k`3fm_H0oooo0?Cdm03[jn/0i^KV0>_[j`3gmoL0
h>3P0>k^kP3UiND0i^KV00@0moOg0180oooo0?Ogm`3oool0oooo0?Ogm`3UiND0kNg]0?Cdm03bl_80
oooo0?Cdm03]kNd0m?Cd0?ooo`3dm?@0oooo0>g]k@3gmoL20?ooo`0=0?KfmP3oool0l_;b0?ooo`3f
m_H0l_;b0?KfmP3gmoL0m?Cd0?Ogm`3^k^h0kNg]0?Cdm0020>k^kP030?ooo`3fm_H0moOg00<0moOg
00H0k>c/0>3Ph03oool0i>CT0?Ogm`1cLg<j0?ooo`0C061PH03Ogml0oooo0?Shn03]kNd0m?Cd0>;R
hP3]kNd0n?Sh0?ooo`3dm?@0l?3`0>OWi`3^k^h0n?Sh0>;RhP3_knl0iNGU0=kNgP040?Shn0070?oo
o`3hn?P0moOg0??cl`3dm?@0n?Sh0>k^kP020?Cdm0070?ooo`3hn?P0k^k^0?Shn03oool0m?Cd0?oo
o`020?Shn080oooo00@0n?Sh0?ooo`3dm?@0oooo0`3hn?P01P3gmoL0m?Cd0?Shn03/k>`0kNg]0?Og
m`80n?Sh0P3oool02P3clo<0moOg0?ooo`3oool0moOg0>c/k03oool0kno_0?Shn01FEUI20?ooo`00
>P3oool06@3Fe]H0f=SH0>KViP3Zj^X0k>c/0?;blP3clo<0l_;b0>CTi03[jn/0hn?S0?ooo`3/k>`0
k^k^0=SHf03[jn/0h^;R0;jn_P3Shn<0lO7a0??cl`3oool0lo?c0?ooo`3clo<0103gmoL0103clo<0
oooo0?ooo`3/k>`20?7al@<0mOGe00@0lO7a0?ooo`3emOD0mOGe0`3gmoL20?ooo`0?0>k^kP3[jn/0
moOg0?Gem@3^k^h0h^;R0=oOg`3Rh^80i^KV0>GUi@3Vi^H0k>c/0??cl`3oool0moOg00@0oooo00@0
j^[Z0<_;b`3bl_80Z:RX=@3oool00`3gmoL0oooo0?Ogm`020?ooo`080;fm_@3QhN40moOg0>g]k@3_
knl0m?Cd0>c/k03clo<20>OWi`0A0>g]k@3fm_H0kno_0>k^kP3Kfm/0k^k^0>OWi`38b<P0gMgM0>o_
k`3[jn/0m_Kf0>g]k@3oool0m?Cd0?Ogm`3^k^h00`3gmoL20?KfmP0=0>o_k`3Ti>@0jn_[0>g]k@3f
m_H0i>CT0>o_k`3oool0kNg]0>k^kP3bl_80m_Kf0?ooo`030?KfmP80moOg00`0kNg]0>3Ph03Ph>00
i>CT0>OWi`3dm?@0moOg0?Cdm03gmoL0l_;b0?ooo`3fm_H40?ooo`040?Ogm`3Xj>P0oooo08n?ScD0
oooo00<0n?Sh0?ooo`3hn?P00P3oool0603>c/h0e]KF0>c/k03/k>`0kno_0?Cdm03^k^h0m?Cd0>SX
j03YjNT0k^k^0?Shn03_knl0n?Sh0=cLg03hn?P0j>SX0=_Kf`3Ng]h0kno_0>g]k@3hn?P0k^k^0?oo
o`80m?Cd00<0oooo0?Shn03hn?P00P3hn?P03P3oool0kNg]0>KViP3^k^h0m?Cd0?Shn03^k^h0n?Sh
0?ooo`3dm?@0l?3`0?Cdm03oool0n?Sh0P3]kNd02`3UiND0moOg0?Ogm`3^k^h0h^;R0>7Qh@3`l?00
j>SX0?Cdm03hn?P0m?Cd00<0oooo0P3gmoL30?ooo`040?Shn03Xj>P0n?Sh09RHV480oooo000k0?oo
o`0;0>_[j`3clo<0mOGe0?Ogm`3alO40lo?c0>[ZjP3oool0l_;b0?Ogm`3clo<00P3oool03@3AdM40
g]kN0?ooo`3Jf]X0c/k>0>?Sh`3Ti>@0mOGe0>[ZjP3oool0h^;R0?ooo`3gmoL0103oool00`3gmoL0
k>c/0?ooo`020?ooo`030?Ogm`3oool0oooo00<0oooo0P3gmoL01`3oool0moOg0?Ogm`3oool0moOg
0>?Sh`3^k^h00P3emOD02P3Jf]X0oooo0?;blP3oool0f][J0??cl`3gmoL0lo?c0?Ogm`3/k>`20?Ge
m@050?ooo`3^k^h0k^k^0>c/k03gmoL0=@3oool00`3gmoL0oooo0?ooo`030?ooo`040>SXj03oool0
moOg0?Ogm`80m?Cd00D0inOW0?ooo`3oool0m?Cd0?Ogm`020?ooo`090=CDe03gmoL0moOg0>o_k`3P
h>00gMgM0>SXj03]kNd0jn_[0080moOg0P3dm?@03P3gmoL0oooo0>_[j`3bl_80k^k^0>KViP3gmoL0
l_;b0??cl`3fm_H0oooo0?;blP3clo<0oooo0`3fm_H00`3oool0kNg]0?Ogm`020?ooo`0<0?Ogm`3^
k^h0oooo0?Ogm`3/k>`0oooo0>c/k03oool0kno_0?Cdm03fm_H0l_;b0P3gmoL30?ooo`040>k^kP3g
moL0oooo0?OgmcD0oooo00<0n?Sh0?ooo`3oool00`3oool02P3QhN40oooo0?Ogm`3hn?P0lo?c0?Cd
m03QhN40oooo0?Shn03^k^h30?ooo`0:0=oOg`3clo<0kno_0?Shn03]kNd0gmoO0>WYj@3^k^h0m?Cd
0?Shn0<0m?Cd00L0n?Sh0?ooo`3`l?00m?Cd0?Shn03^k^h0n?Sh00<0m?Cd01P0oooo0?Cdm03dm?@0
oooo0?Shn03WinL0kno_0?ooo`3dm?@0moOg0?Shn03oool0n?Sh0?3`l03gmoL0n?Sh0>OWi`3oool0
m?Cd0?ooo`3hn?P0lo?c0?ooo`3gmoL20?Shn0<0oooo00@0lo?c0?Shn03hn?P0n?Sh@P3oool003/0
oooo00l0[Jf]0??cl`3oool0lo?c0?;blP3oool0k^k^0?Ogm`3/k>`0f=SH0<C4a03Zj^X0mOGe0??c
l`3?cll00P3oool01P3emOD0d];B0??cl`3Ti>@0dM7A0>GUi@80moOg00T0lO7a0?Gem@3/k>`0mOGe
0?Ogm`3alO40jn_[0=kNgP3Ti>@00P3gmoL0103oool0lo?c0?ooo`3clo<30?ooo`<0moOg00H0lo?c
0>[ZjP3/k>`0j^[Z0>;RhP3oool20>c/k00>0>KViP3/k>`0k^k^0>?Sh`3gmoL0oooo0?Ogm`3clo<0
mOGe0?ooo`3Zj^X0oooo0>KViP15ADDl0?ooo`0<0::RXP3Ph>00oooo0?ooo`3dm?@0moOg0?Cdm03f
m_H0moOg0?Cdm03AdM40inOW0P3gmoL0303EeMD0moOg0?ooo`3^k^h0kNg]0?Ogm`3UiND0g=cL0>GU
i@3gmoL0kno_0>SXj0<0m?Cd0140moOg0>g]k@3^k^h0k>c/0>SXj03]kNd0moOg0>o_k`3Ph>00oooo
0>g]k@3/k>`0oooo0>o_k`3]kNd0moOg0>g]k@020?Ogm`0>0?Cdm03Ti>@0i>CT0?ooo`3dm?@0l_;b
0?Cdm03gmoL0k^k^0?ooo`3fm_H0oooo0?KfmP3dm?@20?ooo`040?Ogm`3oool0m?Cd02LW9c`0oooo
01P0SHf=0>KViP3oool0oooo0?Cdm03hn?P0m?Cd0?Shn03`l?00m?Cd0=CDe03Xj>P0moOg0?Shn03O
gml0kno_0?ooo`3`l?00n?Sh0?Cdm03Xj>P0g]kN0>OWi`3hn?P20>SXj00D0?Ogm`3/k>`0m?Cd0?Og
m`3]kNd0inOW0?Cdm03YjNT0kNg]0?3`l03gmoL0iNGU0>g]k@3hn?P0j>SX0>o_k`3hn?P0oooo0?Og
m`3]kNd20?Shn00>0?Cdm03UiND0n?Sh0?Ogm`3dm?@0n?Sh0?Cdm03oool0kno_0?Shn03gmoL0oooo
0?Ogm`3dm?@20?ooo`040?Shn03oool0m?Cd028R8T<0oooo000k0?ooo`030:ZZZP3/k>`0h^;R0080
moOg00h0mOGe0?ooo`3/k>`0j^[Z0>k^kP3Vi^H0moOg0<_;b`3Rh^80lo?c0>[ZjP3clo<0moOg0?Ge
m@80jn_[01D0f=SH0<W9b@3Ng]h0dM7A0<W9b@3=cLd0f][J0>?Sh`3IfMT0clo?0=KFeP3^k^h0jn_[
0=kNgP3Ogml0i>CT0?;blP3Zj^X0oooo0?Ogm`3Zj^X00P3Ti>@02`3Zj^X0h^;R0?Ogm`3UiND0h^;R
0=kNgP3Shn<0e]KF0=[JfP3UiND0oooo0080lo?c0P3gmoL02@3emOD0i>CT0?Gem@3oool0h^;R0=KF
eP3oool0f][J0=7Ad@0l0?ooo`0309FEU@3_knl0kNg]00<0moOg01l0oooo0>o_k`3clo<0kno_0>g]
k@3gmoL0clo?0>GUi@3gmoL0kNg]0?Ogm`3Ph>00moOg0>3Ph03_knl0hN7Q0=_Kf`3]kNd0c<c<0=7A
d@3>c/h0fMWI0?ooo`3De=@0dM7A0>3Ph03dm?@0moOg0>g]k@3/k>`0m?Cd00<0moOg01D0m?Cd0>g]
k@3WinL0kNg]0?Cdm03/k>`0iNGU0>k^kP3WinL0kNg]0>o_k`3]kNd0iNGU0?Ogm`3oool0m?Cd0?;b
lP3fm_H0moOg0?ooo`3dm?@00P3oool01@3^k^h0kNg]0?ooo`3MgMd0^[Zj03`0oooo00<0Vi^K0>g]
k@3]kNd00P3hn?P00`3gmoL0oooo0>o_k`020?3`l00>0>k^kP3oool0dM7A0>GUi@3hn?P0kNg]0?Sh
n03YjNT0oooo0>7Qh@3/k>`0h^;R0>WYj@3^k^h20=_Kf`080=KFeP3Kfm/0n?Sh0=OGe`3Kfm/0iNGU
0>c/k03_knl20>c/k0040>k^kP3dm?@0k^k^0?Cdm080n?Sh00/0k^k^0?Cdm03hn?P0m?Cd0>OWi`3_
knl0j>SX0?3`l03gmoL0kNg]0?3`l0020?ooo`060??cl`3oool0oooo0?Shn03oool0m?Cd0P3oool0
1@3_knl0m?Cd0?ooo`3Ogml0]KFe04<0oooo000l0?ooo`0:0>_[j`3clo<0jn_[0?Ogm`3emOD0e]KF
0??cl`3Ng]h0moOg0>k^kP80oooo0P3clo<06P3gmoL0lo?c0>_[j`3bl_80mOGe0>k^kP3[jn/0k^k^
0??cl`3Ng]h0k^k^0?Gem@3Zj^X0c/k>0>?Sh`3Ti>@0iNGU0>_[j`3Zj^X0oooo0=WIf@3clo<0jn_[
0?Ogm`3oool0k>c/0`3gmoL03`3[jn/0h^;R0=kNgP3bl_80hn?S0?Ogm`3Fe]H0mOGe0>k^kP3Vi^H0
mOGe0?ooo`3gmoL0lo?c0>c/k0040?ooo`040;jn_P3[jn/0mOGe07YjNSd0oooo01T0moOg0>o_k`3g
moL0moOg0?ooo`3_knl0fMWI0?Cdm03gmoL0oooo0?Ogm`3oool0moOg0?KfmP3dm?@0oooo0??cl`3/
k>`0lo?c0?Ogm`3_knl0m?Cd0?Ogm`3^k^h0moOg0080oooo0100h>3P0=WIf@3UiND0i^KV0?Ogm`3/
k>`0jn_[0?;blP3Lg=`0moOg0>_[j`3^k^h0oooo0?Ogm`3oool0m_Kf0P3gmoL03P3/k>`0m?Cd0>k^
kP3_knl0moOg0>o_k`3^k^h0moOg0?Cdm03gmoL0oooo0?KfmP3bl_80moOg103oool0103De=@0moOg
0?ooo`1hN7Pm0?ooo`090?Shn03UiND0n?Sh0??cl`3oool0kno_0=_Kf`3dm?@0k^k^0080n?Sh00L0
oooo0?Shn03hn?P0m?Cd0?ooo`3dm?@0k^k^0080n?Sh00L0kno_0>g]k@3_knl0kNg]0>c/k03oool0
moOg0080hN7Q00P0l?3`0?Cdm03]kNd0l?3`0>k^kP3dm?@0l?3`0?Shn080moOg00@0m?Cd0?Shn03h
n?P0n?Sh0P3gmoL01@3dm?@0moOg0>c/k03hn?P0kno_0080n?Sh0P3dm?@20?Ogm`030?ooo`3gmoL0
n?Sh00@0oooo00@0fm_K0?Shn03oool0MgMgA03oool003`0oooo00/0/;2`0?;blP3^k^h0oooo0?7a
l@3oool0lo?c0>_[j`3Shn<0moOg0>[ZjP020??cl`0@0>_[j`3Shn<0hn?S0>c/k03bl_80lo?c0>[Z
jP3?cll0k>c/0?Ogm`3Hf=P0mOGe0>;RhP3bl_80hn?S0=WIf@80j^[Z01H0moOg0>[ZjP3oool0fMWI
0?Ogm`3IfMT0h^;R0=kNgP3alO40i>CT0=oOg`3/k>`0gmoO0>_[j`3Vi^H0hn?S0>c/k03^k^h0j^[Z
0?Ogm`3Vi^H0h^;R0P3clo<0103gmoL0mOGe0>[ZjP3emOD20?ooo`050>[ZjP3Shn<0f][J0>[ZjP1V
IVH0?P3oool01@2PX:00k>c/0?ooo`3oool0m?Cd0080moOg01l0jn_[0?Ogm`3fm_H0kNg]0?Cdm03c
lo<0jn_[0?Ogm`3Ti>@0kno_0?Cdm03]kNd0h>3P0>o_k`3Ph>00i>CT0<g=c@3^k^h0kno_0>k^kP3g
moL0kNg]0?Ogm`3oool0k>c/0>k^kP3oool0kNg]0?Ogm`3/k>`0m_Kf0080m?Cd0180j>SX0>c/k03_
knl0k>c/0?Cdm03/k>`0i>CT0?KfmP3gmoL0i^KV0?ooo`3]kNd0moOg0?Cdm03clo<0m_Kf0?ooo`3g
moL30?ooo`050?Cdm03gmoL0i^KV0?Cdm01<C4`0?P3oool01@2ATI40k^k^0?Ogm`3oool0lo?c0080
n?Sh00@0m?Cd0>k^kP3hn?P0kNg]0P3dm?@03`3^k^h0oooo0>k^kP3gmoL0kno_0>g]k@3Xj>P0n?Sh
0>WYj@3UiND0e]KF0?3`l03oool0l?3`0?ooo`020?Shn0060?ooo`3dm?@0m?Cd0?ooo`3Xj>P0moOg
0P3hn?P0103dm?@0oooo0>WYj@3hn?P20?3`l080n?Sh00H0k^k^0?3`l03hn?P0m?Cd0?ooo`3^k^h2
0?Ogm`040?Shn03oool0oooo0?Shn0<0oooo00D0m?Cd0?Shn03`l?00m?Cd0492@P140?ooo`00?03o
ool09`3Rh^80fMWI0>_[j`3gmoL0oooo0?7al@3oool0k^k^0>c/k03Ng]h0hn?S0??cl`3gmoL0j^[Z
0?ooo`3[jn/0k^k^0>c/k03Ng]h0hn?S0>[ZjP3Shn<0oooo0>[ZjP3[jn/0moOg0?Gem@3clo<0jn_[
0>KViP3Fe]H0mOGe0?Ogm`3bl_80jn_[0?7al@3emOD0oooo0=kNgP030>KViP0?0>_[j`3oool0mOGe
0?Gem@3^k^h0oooo0>[ZjP3oool0moOg0?Gem@3gmoL0oooo0?Ogm`3Rh^80lo?c0080mOGe00L0oooo
0>?Sh`3oool0k>c/0?Ogm`1WIfL0moOg03h0oooo00l0g=cL0=WIf@3gmoL0moOg0?ooo`3]kNd0m?Cd
0>o_k`3^k^h0fm_K0>GUi@3bl_80m_Kf0>k^kP3oool00P3]kNd05P3^k^h0fm_K0>GUi@3dm?@0kno_
0?Ogm`3]kNd0m?Cd0?ooo`3^k^h0i>CT0>3Ph03_knl0gMgM0?Ogm`3fm_H0jn_[0??cl`3Vi^H0k^k^
0?ooo`3/k>`20?Ogm`0=0?Cdm03gmoL0m_Kf0?Ogm`3^k^h0lo?c0?ooo`3gmoL0oooo0?Ogm`3oool0
m_Kf0?ooo`020?KfmP0:0?Cdm03oool0oooo0?ooo`3^k^h0oooo0?Cdm03gmoL0C4a<0?Ogmch0oooo
00`0k^k^0=3@d03hn?P0n?Sh0?ooo`3/k>`0m?Cd0?3`l03_knl0g=cL0>SXj03dm?@30?Shn080k^k^
00@0n?Sh0>WYj@3`l?00k>c/0P3_knl00`3/k>`0m?Cd0?ooo`020>GUi@050>k^kP3UiND0gmoO0?Og
m`3hn?P00`3dm?@00`3hn?P0oooo0?Cdm0020?Shn080m?Cd00@0n?Sh0?ooo`3hn?P0m?Cd0`3oool0
1@3gmoL0oooo0?Ogm`3oool0moOg0080m?Cd0`3oool01P3_knl0oooo0?Shn03hn?P0@D510?Shn4@0
oooo000l0?ooo`040>k^kP2`/;00moOg0?Ogm`80j^[Z0140mOGe0?Ogm`3clo<0mOGe0>[ZjP3gmoL0
h^;R0>c/k03clo<0j^[Z0??cl`3gmoL0iNGU0=KFeP3Shn<0g]kN0?7al@020>[ZjP040??cl`3bl_80
f][J0?Ogm`80mOGe00<0jn_[0?Ogm`3^k^h00P3oool0103Shn<0moOg0?7al@3Ti>@20>c/k00;0?7a
l@3gmoL0mOGe0??cl`3oool0j^[Z0>k^kP3/k>`0j^[Z0?Gem@3[jn/00P3clo<02P3gmoL0j^[Z0?7a
l@3oool0mOGe0>[ZjP3Rh^80bl_;0>_[j`3IfMTd0?ooo`030?Ogm`3oool0oooo00P0oooo02P0i>CT
0;Jf]P3^k^h0moOg0>g]k@3/k>`0kNg]0?ooo`3dm?@0moOg0>OWi`3fm_H0i>CT0>o_k`3gmoL0kNg]
0?ooo`3UiND0i>CT0>c/k03oool0h>3P0?Cdm03/k>`0i^KV0?Cdm03gmoL0gMgM0?Ogm`3dm?@0m_Kf
0>_[j`3fm_H0kNg]0?Cdm03oool0moOg0?ooo`3Ph>00i^KV0P3^k^h00`3Vi^H0oooo0>k^kP020?oo
o`080>k^kP3gmoL0moOg0?Ogm`3oool0k>c/0?Cdm03clo<20?Ogm`<0oooo0P3gmoL00`3UiND0m?Cd
0<c<c00d0?ooo`030?Shn03oool0oooo00P0oooo01<0k^k^0:ZZZP3`l?00kno_0>c/k03UiND0kNg]
0?ooo`3dm?@0moOg0>g]k@3hn?P0inOW0>o_k`3hn?P0kNg]0?ooo`3`l?00k^k^0080n?Sh00T0hN7Q
0??cl`3/k>`0j>SX0?Cdm03gmoL0gmoO0?Shn03/k>`00P3dm?@0103hn?P0k^k^0?Cdm03oool20?Sh
n0080>GUi@3dm?@0n?Sh0?Shn03dm?@0oooo0?Shn03oool30?Shn080moOg00@0oooo0?Ogm`3dm?@0
m?Cd0P3hn?P30?ooo`050?3`l03dm?@0k^k^0?Cdm03UiND0A@3oool003d0oooo00<0g]kN0;jn_P3g
moL00P3[jn/0703/k>`0mOGe0>c/k03clo<0a<C40?ooo`3^k^h0moOg0>[ZjP3IfMT0moOg0>CTi03^
k^h0lo?c0?Gem@3alO40l_;b0?Gem@3bl_80iNGU0?Gem@3Hf=P0l_;b0>k^kP3gmoL0mOGe0>_[j`3a
lO420?ooo`090>_[j`3emOD0hn?S0=kNgP3Vi^H0hn?S0>_[j`3^k^h0i^KV0080k^k^0140k>c/0?oo
o`3/k>`0k^k^0?ooo`3gmoL0lO7a0??cl`3bl_80j^[Z0?Gem@3/k>`0k^k^0>;RhP3emOD0Ph>30:b/
[0110?ooo`0A0<k>cP2h^;P0oooo0?Ogm`3]kNd0m?Cd0?Ogm`3_knl0l_;b0<o?c`3oool0k^k^0?Og
m`3]kNd0i>CT0?ooo`3IfMT00P3dm?@02P3gmoL0m?Cd0?Ogm`3]kNd0moOg0>SXj03/k>`0h>3P0?Og
m`3/k>`20?ooo`070>g]k@3oool0oooo0?ooo`3gmoL0oooo0?Ogm`020?Cdm0<0moOg00@0m?Cd0?Og
m`3gmoL0moOg0P3oool03P3^k^h0oooo0?KfmP3oool0lo?c0?Ogm`3dm?@0oooo0?Ogm`3^k^h0kno_
0?ooo`2:RXX0V9RH@@3oool08038b<P0ZJVY0?ooo`3dm?@0k^k^0?Cdm03`l?00kno_0?Cdm03AdM40
oooo0?3`l03hn?P0kNg]0>GUi@3oool0i^KV0>g]k@3Xj>P0moOg0??cl`3gmoL0iNGU0?Ogm`3QhN40
kNg]0>o_k`3gmoL0m?Cd0?Shn03`l?00jNWY0`3oool00`3hn?P0oooo0?Shn0020?Cdm0<0n?Sh00@0
m?Cd0?Shn03hn?P0moOg0P3oool03P3hn?P0oooo0?Ogm`3oool0m?Cd0?Shn03dm?@0oooo0?Shn03g
moL0k^k^0?ooo`2=SHd0WIfMAP3oool003d0oooo00T0k^k^0;jn_P3Fe]H0mOGe0>c/k03[jn/0j^[Z
0?Gem@2n_[h00P3/k>`0503AdM40h^;R0??cl`3Shn<0iNGU0?Ogm`3/k>`0lO7a0>[ZjP3Ti>@0k>c/
0=SHf03UiND0b/[:0>[ZjP3^k^h0g]kN0>k^kP3Ng]h0lO7a0P3oool07@3clo<0oooo0?ooo`3^k^h0
k>c/0>k^kP3/k>`0mOGe0=[JfP3Shn<0f][J0>k^kP3Zj^X0moOg0>c/k03clo<0jn_[0?ooo`3gmoL0
lO7a0?Gem@3oool0mOGe0>[ZjP3^k^h0f][J0?;blP3/k>`0/k>c03L0oooo00<0moOg0?ooo`3oool0
203oool02@3Ti>@0^[Zj0=WIf@3gmoL0kno_0>g]k@3Xj>P0moOg0<71`@020>o_k`030=CDe03QhN40
l_;b00<0iNGU00d0k>c/0?Ogm`3clo<0k>c/0?Ogm`3?cll0h>3P0<g=c@3oool0m?Cd0>c/k03gmoL0
m?Cd00<0oooo00<0m?Cd0?ooo`3oool0103gmoL0103oool0kno_0?Ogm`3_knl40?Ogm`040?Cdm03[
jn/0oooo0?Ogm`@0oooo00H0moOg0>k^kP3Vi^H0m_Kf0?ooo`2MWIdg0?ooo`030?Shn03oool0oooo
00P0oooo00T0k^k^0:b/[03MgMd0moOg0>o_k`3^k^h0j>SX0?Ogm`38b<P00P3gmoL03P3Fe]H0g=cL
0?Cdm03_knl0k^k^0?3`l03Xj>P0m?Cd0?Ogm`3/k>`0m?Cd0=7Ad@3]kNd0g=cL0P3dm?@20?Shn005
0?Cdm03YjNT0oooo0?ooo`3gmoL00P3oool0403hn?P0moOg0?Shn03gmoL0l?3`0>o_k`3hn?P0kno_
0?Shn03oool0moOg0?ooo`3gmoL0lo?c0?ooo`3hn?P40?ooo`060?Shn03gmoL0l?3`0?Ogm`3oool0
Vi^KA`3oool003h0oooo00H0h^;R0;Fe]@3bl_80moOg0>k^kP3Ti>@20?7al@0;0>GUi@3[jn/0k^k^
0??cl`3[jn/0l_;b0?Gem@3Ng]h0oooo0>[ZjP3alO400P3gmoL04`3UiND0lo?c0>KViP3?cll0mOGe
0=KFeP3bl_80k>c/0?Ogm`3[jn/0k>c/0?ooo`3clo<0moOg0>c/k03clo<0moOg0>[ZjP3[jn/0103g
moL04@3oool0k^k^0?ooo`3gmoL0lo?c0?Ogm`3/k>`0j^[Z0?ooo`3emOD0lo?c0?ooo`3Jf]X0h^;R
0>GUi@1mOGd0moOg04<0oooo00d0h>3P0;Vi^@3dm?@0moOg0>o_k`3WinL0m?Cd0>g]k@3Xj>P0moOg
0>k^kP3bl_80k^k^0080moOg00`0kno_0?Ogm`3[jn/0m?Cd0?ooo`3fm_H0k^k^0?Ogm`3UiND0fMWI
0?ooo`3]kNd30?Ogm`040>c/k03gmoL0oooo0?;blP80moOg00<0lo?c0?Ogm`3dm?@00P3gmoL02`3f
m_H0moOg0?Ogm`3oool0k^k^0?ooo`3gmoL0l_;b0?KfmP3gmoL0m?Cd0080oooo00L0l_;b0?ooo`3V
i^H0m?Cd0>GUi@1BDU80kno_04<0oooo00L0kNg]0:n_[`3dm?@0n?Sh0?3`l03]kNd0lo?c0080j>SX
00X0n?Sh0>k^kP3dm?@0k^k^0?Cdm03gmoL0k>c/0?Shn03]kNd0lo?c0P3hn?P01P3oool0n?Sh0>k^
kP3Kfm/0l?3`0>k^kP80l?3`00<0oooo0?Ogm`3gmoL00P3gmoL20?ooo`050??cl`3gmoL0moOg0?Sh
n03oool0103gmoL00`3clo<0oooo0?Ogm`020?Ogm`0;0?Shn03dm?@0oooo0?ooo`3clo<0oooo0?3`
l03hn?P0j>SX04];B`3`l?00A`3oool003l0oooo00<0f][J0<k>cP3oool00P3^k^h0203UiND0oooo
0?;blP3Vi^H0h^;R0?Ogm`3emOD0lo?c0P3/k>`02@3gmoL0k^k^0?Gem@3clo<0k^k^0>KViP3[jn/0
k^k^0=7Ad@020?;blP030?ooo`3clo<0mOGe00<0moOg00d0oooo0??cl`3gmoL0moOg0?ooo`3gmoL0
oooo0=kNgP3oool0k^k^0?ooo`3clo<0oooo0080moOg00`0l_;b0>[ZjP3oool0mOGe0>?Sh`3oool0
lo?c0=7Ad@3^k^h0jn_[09JFUP3clo=50?ooo`0:0=CDe03IfMT0oooo0?ooo`3_knl0iNGU0?ooo`3g
moL0m?Cd0??cl`80moOg00D0l_;b0?Ogm`3fm_H0moOg0>o_k`020?ooo`050>_[j`3Ph>00m?Cd0>o_
k`3IfMT00P3gmoL0103oool0lo?c0?ooo`3gmoL20?KfmP0=0?ooo`3bl_80moOg0?Ogm`3oool0m_Kf
0?ooo`3/k>`0oooo0>k^kP3oool0l_;b0?ooo`030?Ogm`0;0?Cdm03oool0oooo0>k^kP3oool0l_;b
0>CTi03gmoL0m?Cd08n?S`3Xj>P0A@3oool0103Kfm/0e]KF0?ooo`3gmoL20?3`l0030?Shn03gmoL0
m?Cd0080n?Sh00@0moOg0?Cdm03gmoL0oooo0P3`l?000`3hn?P0m?Cd0?Cdm0020?Cdm0030?3`l03S
hn<0l?3`0080oooo00<0moOg0?ooo`3oool00P3gmoL00`3oool0lo?c0??cl`030?ooo`070?Ogm`3d
m?@0oooo0??cl`3oool0lo?c0?ooo`030?Shn00;0?Cdm03oool0oooo0>o_k`3gmoL0lo?c0>SXj03h
n?P0m?Cd07alO03YjNT0B03oool00400oooo0P3Jf]X0103gmoL0hn?S0>_[j`3Zj^X20?ooo`0:0=KF
eP3bl_80j^[Z0>_[j`3oool0k>c/0=kNgP3Rh^80fMWI0?Ogm`80lo?c00T0oooo0=7Ad@3bl_80k>c/
0>KViP3gmoL0lo?c0?Ogm`3clo<00P3oool20??cl`0:0?Ogm`3clo<0lo?c0?ooo`3gmoL0oooo0?Og
m`3Shn<0oooo0>k^kP80mOGe0`3oool02P3Ng]h0moOg0?Ogm`3gmoL0g]kN0?ooo`37alL0hn?S0>;R
hP3gmoLe0?ooo`030?Ogm`3oool0oooo00h0oooo00@0e=CD0=gMg@3gmoL0kno_0P3]kNd0303gmoL0
oooo0>7Qh@3_knl0kNg]0>KViP3/k>`0m_Kf0?Cdm03oool0g=cL0?Ogm`80m?Cd00T0lo?c0>GUi@3d
m?@0moOg0>KViP3gmoL0l_;b0?Ogm`3dm?@00P3oool20?;blP0:0?KfmP3dm?@0m?Cd0?ooo`3fm_H0
oooo0?KfmP3^k^h0oooo0>k^kPD0oooo00X0k>c/0?Ogm`3fm_H0m_Kf0?Cdm03oool0gMgM0>GUi@3A
dM40kno_=@3oool00`3hn?P0oooo0?ooo`0>0?ooo`0B0<G5a@3Xj>P0n?Sh0>o_k`3^k^h0k>c/0?Sh
n03oool0h^;R0>o_k`3/k>`0n?Sh0>k^kP3oool0m?Cd0?ooo`3Kfm/0oooo0P3`l?001`3]kNd0k^k^
0>SXj03`l?00k>c/0?ooo`3clo<0103oool20??cl`0:0?Ogm`3oool0oooo0?ooo`3gmoL0oooo0?Og
m`3Rh^80oooo0>o_k`D0oooo00X0kNg]0?3`l03gmoL0moOg0?Shn03oool0inOW0?3`l03Kfm/0l?3`
B03oool00400oooo01l0c/k>0>_[j`3Shn<0moOg0>_[j`3^k^h0f][J0=oOg`3Shn<0i^KV0?ooo`3g
moL0i>CT0>c/k03emOD0lo?c0>[ZjP3clo<0oooo0?Gem@3Shn<0jn_[0=SHf03^k^h0jn_[0?ooo`3g
moL0j^[Z0?ooo`3gmoL0i>CT0080moOg00D0oooo0??cl`3oool0d=3@0>c/k0020?Ogm`80jn_[00h0
e]KF0=kNgP3Zj^X0h^;R0>_[j`3/k>`0j^[Z0?Ogm`3IfMT0j^[Z0?ooo`3Shn<0h^;R0;2`/4P0oooo
00l0^;Rh0=_Kf`3UiND0moOg0>g]k@3gmoL0gMgM0>c/k03oool0j>SX0?Cdm03/k>`0fm_K0??cl`3o
ool00`3dm?@20?ooo`0;0>GUi@3[jn/0inOW0>k^kP3[jn/0oooo0?KfmP3clo<0oooo0?KfmP3dm?@0
0P3fm_H01`3oool0m?Cd0>k^kP3MgMd0moOg0?KfmP3gmoL00P3[jn/03`3Ph>00k>c/0?Ogm`3/k>`0
jn_[0?Ogm`3dm?@0moOg0>g]k@3gmoL0oooo0>GUi@3De=@0VYZJ0>o_k`170?ooo`0B0<G5a@3:b/X0
l?3`0?Shn03^k^h0n?Sh0=oOg`3^k^h0n?Sh0>WYj@3oool0m?Cd0=cLg03hn?P0oooo0?Ogm`3clo<0
jNWY0P3oool00`3Xj>P0lo?c0>g]k@020??cl`060?ooo`3gmoL0m?Cd0?ooo`3gmoL0m?Cd0P3gmoL0
3P3oool0l?3`0?3`l03GemL0n?Sh0?Ogm`3oool0lo?c0>GUi@3Xj>P0kNg]0?Shn03]kNd0lo?c0P3`
l?00203oool0n?Sh0>k^kP3oool0l?3`0=KFeP26QXH0inOWB@3oool00440oooo00D0UIFE0=3@d03b
l_80moOg0?Gem@020?;blP060=;BdP3gmoL0hn?S0>GUi@34a<@0i>CT0P3gmoL00`3clo<0k>c/0?Ge
m@030?Ogm`0@0>[ZjP3clo<0moOg0?ooo`3gmoL0oooo0>?Sh`3gmoL0i>CT0?ooo`3gmoL0lo?c0?Og
m`3Fe]H0iNGU0>_[j`@0moOg00h0oooo0?Gem@3gmoL0moOg0=KFeP3Zj^X0lo?c0=7Ad@3Rh^80k^k^
0>GUi@3Jf]X0oooo0<G5aDT0oooo00<0V9RH0=WIf@3dm?@00P3gmoL0203]kNd0oooo0>KViP3]kNd0
hN7Q0>3Ph03=cLd0h>3P0P3gmoL00`3dm?@0moOg0?ooo`020?Ogm`0A0?KfmP3dm?@0l_;b0?KfmP3o
ool0m_Kf0?ooo`3^k^h0m_Kf0?Cdm03oool0m_Kf0?;blP3gmoL0hN7Q0>GUi@3[jn/00P3fm_H20?Og
m`80oooo0P3gmoL02P3Xj>P0m?Cd0?;blP3UiND0kNg]0?Ogm`3clo<0kno_0?Ogm`2`/;190?ooo`0?
09fMW@3Fe]H0m?Cd0?Shn03gmoL0kno_0?Shn03^k^h0iNGU0=cLg03^k^h0d=3@0>7Qh@3`l?00lo?c
0080moOg00D0oooo0?Ogm`3oool0moOg0>g]k@020?Ogm`0=0?ooo`3gmoL0oooo0>o_k`3gmoL0m?Cd
0?ooo`3gmoL0lo?c0?ooo`3GemL0j>SX0??cl`020?Ogm`0<0?ooo`3`l?00l?3`0>WYj@3`l?00oooo
0>KViP3`l?00moOg0>k^kP3YjNT0m?Cd0`3hn?P00`2][Jd0oooo0?ooo`180?ooo`00@P3oool0403A
dM40k^k^0>c/k03clo<0mOGe0>[ZjP3IfMT0i^KV0=7Ad@3Ti>@0g]kN0?Gem@3^k^h0jn_[0??cl`3g
moL20?ooo`0C0?Ogm`3clo<0jn_[0?Ogm`3oool0k^k^0>_[j`3oool0h^;R0??cl`3Vi^H0i>CT0>[Z
jP3clo<0h^;R0>CTi03AdM40_kno0=KFeP020>k^kP0>0=kNgP3Rh^80lo?c0?Ogm`3AdM40fMWI0?Og
m`3IfMT0e]KF0>c/k03Ti>@0f][J0>k^kP38b<Q;0?ooo`0<0<;2`P3dm?@0k^k^0?ooo`3gmoL0kNg]
0>KViP3]kNd0g=cL0>CTi03Ph>00oooo0P3gmoL03`3clo<0m_Kf0?ooo`3oool0m_Kf0?Cdm03/k>`0
m_Kf0?ooo`3^k^h0jn_[0?ooo`3[jn/0l_;b0>KViP020?Cdm0060?;blP3]kNd0j>SX0=cLg03;bl/0
cLg=0P3^k^h03P3Ph>00k>c/0?Cdm03gmoL0inOW0?Ogm`3clo<0i>CT0>GUi@3/k>`0i^KV0>o_k`3^
k^h0/;2`B`3oool02`3>c/h0kNg]0?Shn03oool0moOg0>g]k@3YjNT0k^k^0=cLg03Kfm/0hN7Q00<0
n?Sh0P3clo<03@3oool0lo?c0??cl`3WinL0m?Cd0?Ogm`3oool0kno_0>c/k03oool0k>c/0??cl`3U
iND00P3dm?@00`3clo<0e]KF0>;RhP020=kNgP070=cLg03oool0oooo0?Shn03WinL0l?3`0?ooo`03
0?Cdm0070?3`l03^k^h0m?Cd0?Cdm03_knl0n?Sh0;Bd]01;0?ooo`00@`3oool06`27QhL0k>c/0>[Z
jP3^k^h0k>c/0?Gem@3Vi^H0lo?c0>?Sh`3IfMT0oooo0?Ogm`3oool0mOGe0>k^kP3gmoL0jn_[0??c
l`3gmoL0i^KV0?Ogm`3clo<0oooo0?Ogm`3clo<0oooo0?Ogm`030?ooo`070?Ogm`3Zj^X0d=3@0>[Z
jP3Shn<0YJFU0<k>cP020=WIf@0<0??cl`3emOD0gmoO0=SHf02][Jd0j^[Z0=KFeP3alO40moOg0?oo
o`3clo<0Z:RXC@3oool0101dM7@0k^k^0>_[j`3gmoL20>o_k`0E0?Ogm`3bl_80i^KV0>_[j`3gmoL0
oooo0?KfmP3oool0k^k^0?Ogm`3/k>`0lo?c0?KfmP3Vi^H0moOg0?;blP3oool0m_Kf0?;blP3oool0
m_Kf00<0oooo01D0m_Kf0??cl`3<c<`0fm_K0>GUi@2_[jl0fMWI0>3Ph03Lg=`0m?Cd0?Ogm`3Kfm/0
kNg]0<g=c@3/k>`0i^KV0?Cdm03_knl0oooo0?;blP2:RXX0C@3oool01023Ph<0inOW0?Cdm03hn?P2
0>o_k`0E0>g]k@3dm?@0fm_K0?Cdm03_knl0oooo0?Shn03`l?00moOg0?ooo`3clo<0oooo0?Ogm`3c
lo<0oooo0??cl`3oool0moOg0??cl`3oool0moOg00<0oooo01D0moOg0?Cdm03<c<`0n?Sh0?ooo`3;
bl/0fm_K0>k^kP3hn?P0m?Cd0>g]k@3Vi^H0k^k^0=OGe`3/k>`0kNg]0??cl`3UiND0moOg0?Shn02:
RXX0C03oool004@0oooo01/0Ti>C0<K6aP3Shn<0moOg0=kNgP3clo<0oooo0>k^kP3UiND0f][J0??c
l`3emOD0lo?c0=WIf@3/k>`0mOGe0>[ZjP3oool0iNGU0>k^kP3clo<0oooo0>c/k03clo<0oooo0?Og
m`3oool00P3gmoL03P3clo<0moOg0=kNgP3:b/X0mOGe0>[ZjP3Ng]h0[jn_0;Bd]03Hf=P0g]kN0?;b
lP3emOD0j^[Z0P3Ti>@0103^k^h0]KFe0>;RhP21PH5?0?ooo`0608R8R03<c<`0k>c/0?Ogm`3Xj>P0
moOg0P3oool04`3_knl0gMgM0?KfmP3oool0k>c/0>g]k@3gmoL0oooo0?Cdm03oool0k>c/0>k^kP3b
l_80oooo0?Ogm`3clo<0oooo0?KfmP3oool00P3fm_H01@3clo<0moOg0>OWi`3:b/X0moOg0080k>c/
00@0`/;20;fm_@3Ph>00fm_K0P3gmoL01`3dm?@0k>c/0=_Kf`3gmoL0b<S80>c/k01NGUh0C`3oool0
2P2QXJ40aLG50>k^kP3hn?P0j>SX0?Shn03oool0kno_0>g]k@3Ogml20?Shn00?0?3`l03hn?P0oooo
0?ooo`3gmoL0oooo0??cl`3gmoL0lo?c0?ooo`3hn?P0moOg0?ooo`3gmoL0oooo00<0moOg00X0oooo
0=gMg@39bLT0l?3`0>k^kP3_knl0bl_;0;Zj^P3QhN40g=cL0P3gmoL01`3dm?@0k>c/0=cLg03hn?P0
dM7A0?Cdm017AdL0C@3oool004D0oooo00H0[:b/0=[JfP3oool0moOg0?ooo`3IfMT20?ooo`030>GU
i@3Rh^80moOg0080moOg01/0k>c/0>_[j`3clo<0hn?S0>[ZjP2n_[h0hn?S0?Ogm`3/k>`0lo?c0>c/
k03Jf]X0iNGU0?ooo`3Rh^80dM7A0=WIf@3:b/X0mOGe0>;RhP3oool0cLg=0=KFeP3Ti>@0jn_[0>k^
kP3oool00P3Zj^X01@3Jf]X0moOg0>?Sh`3IfMT0T92@0540oooo02l0X:2P0=gMg@3oool0oooo0?Og
m`3/k>`0oooo0?Ogm`3UiND0i>CT0?Ogm`3fm_H0moOg0>GUi@3^k^h0oooo0>3Ph03gmoL0bl_;0?Og
m`3fm_H0moOg0??cl`3gmoL0iNGU0>g]k@3oool0iNGU0<c<c03IfMT0b/[:0?Cdm03Ti>@0oooo0=WI
f@3De=@0m?Cd0>3Ph03WinL0oooo0>_[j`3Vi^H0iNGU0>g]k@3_knl0bl_;07inOP1A0?ooo`0:0;jn
_P3Ogml0oooo0?ooo`3hn?P0l?3`0?ooo`3`l?00k>c/0>GUi@80n?Sh02<0m?Cd0>OWi`3hn?P0oooo
0>KViP3`l?00bl_;0?Shn03gmoL0l?3`0?Ogm`3`l?00gmoO0=OGe`3oool0n?Sh0<o?c`3QhN40bLW9
0>KViP3dm?@0l?3`0=?Cd`3Vi^H0jNWY0>KViP3`l?00oooo0?Cdm03^k^h0inOW0>GUi@3hn?P0_Kfm
07alO01>0?ooo`00AP3oool01@2@T900alO70?Ogm`3Zj^X0moOg0080k>c/00L0oooo0>;RhP3@d=00
k>c/0?Ogm`3oool0lo?c0080oooo01@0jn_[0<W9b@3Zj^X0h^;R0=WIf@3gmoL0l_;b0=KFeP3>c/h0
gmoO0=WIf@3AdM40fMWI0;Jf]P3^k^h0l_;b0=SHf03IfMT0hn?S0?ooo`80j^[Z00@0mOGe0<[:bP3g
moL0jn_[0P3gmoL00`2e]KD0moOg0?ooo`0l0?ooo`030?Ogm`3oool0oooo0180oooo00X0QhN70=7A
d@3gmoL0kNg]0?Cdm03^k^h0moOg0?ooo`3Ti>@0dm?C0P3gmoL40?ooo`0N0>k^kP3<c<`0moOg0>k^
kP3]kNd0k>c/0>o_k`3IfMT0d=3@0=WIf@3Lg=`0eMGE0<c<c02j^[X0k>c/0>g]k@3Ph>00fm_K0>c/
k03oool0m_Kf0>_[j`3oool0dM7A0?Cdm03UiND0k^k^0>o_k`2ZZZX0moOg?@3oool00`3hn?P0oooo
0?ooo`0B0?ooo`0^08b<S03Bd]80n?Sh0>g]k@3dm?@0inOW0>k^kP3oool0inOW0=KFeP3hn?P0m?Cd
0?ooo`3hn?P0oooo0?Shn03oool0_[jn0>WYj@3]kNd0n?Sh0?Cdm03Rh^80d=3@0=oOg`3WinL0h^;R
0>OWi`3>c/h0_Kfm0>k^kP3QhN40inOW0>g]k@3gmoL0n?Sh0?ooo`3]kNd0n?Sh0=_Kf`3dm?@0kNg]
0?3`l03_knl0[Zj^0?Shn4h0oooo00170?ooo`070>k^kP29RHT0b/[:0<k>cP3Jf]X0lo?c0=kNgP02
0>;RhP0H0>GUi@3Shn<0XZ:R0<[:bP3AdM40j^[Z0>_[j`3IfMT0h^;R0<k>cP2ZZZX0bl_;0?;blP3g
moL0j^[Z0=KFeP3Shn<0e]KF0>[ZjP3Fe]H0lO7a0?Ogm`3/k>`0moOg0P3[jn/20>KViP060?ooo`3F
e]H0dM7A0<?3``2o_kl0OgmoE@3oool06P3UiND0Ph>30<g=c@3IfMT0k^k^0?;blP3IfMT0i^KV0=WI
f@3Vi^H0iNGU0:ZZZP36a/H0e=CD0?Cdm03]kNd0g=cL0>_[j`2j^[X0_;bl0>7Qh@3Ti>@0iNGU0>KV
iP3WinL0i>CT0P3Lg=`01@3Vi^H0oooo0?Cdm03_knl0moOg0080m?Cd00P0g=cL0?ooo`3oool0g=cL
0>3Ph03]kNd0][Jf06EUIED0oooo01`0n?Sh061PH03De=@0h^;R0?Ogm`3dm?@0d];B0>GUi@3?cll0
k^k^0?3`l02i^KT0bLW90>7Qh@3]kNd0n?Sh0=kNgP3dm?@0YjNW0<_;b`3Fe]H0fm_K0?Shn03Fe]H0
k^k^0=gMg@3Kfm/0bl_;0P3^k^h01P3dm?@0kNg]0?Shn03]kNd0m?Cd0=7Ad@80oooo00D0gMgM0>SX
j03gmoL0/[:b06UYJ@1@0?ooo`00B@3oool06@36a/H0b<S80?;blP3oool0moOg0?ooo`3gmoL0k^k^
0??cl`3gmoL0oooo0?Ogm`3oool0e]KF0>_[j`3gmoL0k>c/0?Ogm`3UiND0fMWI0>c/k03[jn/0fMWI
0>c/k03IfMT00P3clo<03@3Zj^X0oooo0?Gem@3oool0i^KV0=kNgP3Zj^X0hn?S0=[JfP3Shn<0g]kN
06][J`3gmoL0F03oool0702^[Zh0^k^k0??cl`3oool0m_Kf0?Ogm`3/k>`0iNGU0?Ogm`3_knl0oooo
0?Cdm03oool0fMWI0>_[j`3^k^h0kNg]0>c/k03UiND0e=CD0>k^kP3[jn/0e=CD0>7Qh@3Lg=`0moOg
0?Cdm03]kNd20?Cdm00:0?ooo`3]kNd0moOg0>c/k03gmoL0k>c/0>GUi@3dm?@0De=C0?OgmeP0oooo
00<0a<C40:FUY@3WinL00`3hn?P03P3dm?@0gmoO0?Shn03WinL0oooo0>g]k@3oool0fm_K0>k^kP3G
emL0kno_0=kNgP3Xj>P0bLW90P3hn?P02P3AdM40e]KF0=oOg`3hn?P0kNg]0>c/k03Xj>P0k>c/0?oo
o`3QhN420?Cdm0060?ooo`3dm?@0inOW0?ooo`1CDe<0n?ShD@3oool004X0oooo00X0k^k^0;>c/`3S
hn<0jn_[0>CTi03Jf]X0k^k^0?ooo`3gmoL0oooo0P3gmoL06P3Zj^X0hn?S0=WIf@3oool0b<S80>c/
k03Ng]h0oooo0?Ogm`3Fe]H0lo?c0=[JfP3IfMT0i^KV0>GUi@3gmoL0iNGU0>?Sh`3Zj^X0k>c/0=kN
gP3Hf=P0_kno09ZJVP1WIfL0moOgFP3oool02@3UiND0/[:b0>GUi@3fm_H0j>SX0>g]k@3UiND0moOg
0>c/k0020?Cdm080lo?c01T0k^k^0=WIf@3dm?@0dm?C0>CTi03Lg=`0kno_0?KfmP3IfMT0jn_[0=gM
g@3Kfm/0kNg]0>SXj03gmoL0k>c/0>g]k@3Ph>00g=cL0>SXj03_knl0b<S80;:b/P1BDU80moOg05X0
oooo00X0n?Sh0:6QX@3GemL0kNg]0>c/k03hn?P0gmoO0>k^kP3UiND0k^k^0P3]kNd03`3dm?@0l?3`
0<_;b`3dm?@0fm_K0<g=c@3Kfm/0inOW0>o_k`3UiND0m?Cd0>SXj03Ng]h0k^k^0>7Qh@030?Cdm008
0>WYj@3Vi^H0kNg]0?Cdm03Kfm/0/K6a04a<C03hn?QB0?ooo`00C@3oool0103^k^h0NWYj0<[:bP3[
jn/20>[ZjP030?Ogm`3bl_80g]kN0080moOg00L0k>c/0?ooo`3/k>`0lo?c0>[ZjP3oool0jn_[0080
oooo00`0lo?c0>k^kP3UiND0iNGU0=7Ad@3;bl/0moOg0=WIf@3Fe]H0dM7A08Z:RP3AdM5P0?ooo`0>
0>GUi@1lO7`0`L710?Ogm`3Ph>00m?Cd0?Ogm`3dm?@0kNg]0?KfmP3oool0l_;b0?ooo`3bl_820>3P
h00@0?KfmP3gmoL0oooo0>o_k`3dm?@0k^k^0?ooo`3]kNd0h>3P0=_Kf`3fm_H0i^KV0=WIf@3Kfm/0
PX:20<?3`f00oooo0100n?Sh06UYJ@31`L40kNg]0=?Cd`3dm?@0n?Sh0>g]k@3^k^h0kno_0?ooo`3]
kNd0oooo0>SXj03AdM40fm_K0P3_knl00`3hn?P0kno_0?Cdm0020?Shn0090>7Qh@3hn?P0m?Cd0?3`
l03]kNd0hN7Q0>WYj@1cLg<0clo?05D0oooo001@0?ooo`0>0>k^kP3Vi^H0bl_;0>?Sh`38b<P0jn_[
0;bl_03gmoL0dM7A0>CTi03Rh^80oooo0;bl_03Hf=P20>c/k0050?Ogm`3clo<0h^;R0>_[j`3clo<0
0P3gmoL0103Rh^80];Bd0:RXZ03gmoMU0?ooo`0C0>GUi@3Kfm/0b<S80=gMg@2i^KT0k^k^0;Vi^@3^
k^h0hN7Q0?;blP3/k>`0moOg0=WIf@3Vi^H0m_Kf0>k^kP3gmoL0oooo0?Cdm0020?ooo`060?Ogm`3_
knl0moOg0:j^[P2?Shl0m?CdI@3oool06`3hn?P0k^k^0>7Qh@3_knl0c<c<0=gMg@2m_Kd0inOW0>?S
h`3]kNd0k^k^0?Shn03UiND0j>SX0?Shn03`l?00n?Sh0?ooo`3`l?00n?Sh0?Cdm03hn?P0kno_0?oo
o`2LW9`0L71`0?Cdm01G0?ooo`00D`3oool02`3gmoL0jn_[0=kNgP3Rh^80fMWI0;jn_P3IfMT0j^[Z
0?;blP3oool0moOg0080j^[Z00T0iNGU0?ooo`3gmoL0moOg0>[ZjP3emOD0i>CT079bLP3Jf]X0AP3o
ool00`3gmoL0oooo0?ooo`0Q0?ooo`0<0>o_k`3[jn/0eMGE0>CTi03;bl/0][Jf0=7Ad@3]kNd0m?Cd
0>c/k03gmoL0lo?c0P3[jn/20?ooo`060?Ogm`3Xj>P0moOg0>3Ph01]KFd0c<c<AP3oool00`3hn?P0
oooo0?ooo`0Q0?ooo`0<0?3`l03dm?@0hN7Q0?Cdm03Ng]h0];Bd0<S8b03Lg=`0gMgM0>GUi@3hn?P0
m?Cd0P3UiND0203oool0n?Sh0?Shn03/k>`0oooo0=CDe01YJFT0inOWF@3oool005d0oooo00D0i^KV
0=WIf@34a<@0dM7A0>_[j`1>0?ooo`80moOg9@3oool00`3gmoL0oooo0?ooo`030?ooo`050=_Kf`3?
cll0/;2`0;fm_@3Ph>00CP3oool20?Shn2D0oooo00<0n?Sh0?ooo`3oool00`3oool01@3^k^h0hn?S
0<G5a@3Fe]H0jNWY0600oooo003N0?ooo`030?Ogm`3oool0oooo07d0oooo00<0n?Sh0?ooo`3oool0
H@3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo
``3oool00?l0oooo``3oool00?l0oooo``3oool005L0oooo0d000000103ooom000000?ooo`3oool2
@00000<0oooo0d00001]0?ooo`9000000P3oool3@00000<0oooo0T0000030?ooo`90000000<0oooo
@000040000000P3oool00d000000oooo0?ooo`1X0?ooo`A000000P3oool3@00000<0oooo0d000002
0?ooo`900000F`3oool005P0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003o
ool0oooo@00006`0oooo00=000000?oood0000000`3oool01D000000oooo0?ooo`3ooom0000000@0
oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood00001[0?ooo`04@000003oool0oooo
@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003ooom0000005d0oooo001H
0?ooo`=000000P3oool3@0000080oooo00A000000?ooo`3ooom00000K03oool014000000oooo@000
040000020?ooo`04@000003oool0oooo0?ooo`=000000P3oool3@0000080oooo00A000000?ooo`3o
oom00000J`3oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3o
ool00d000000oooo@0000002@00005/0oooo001H0?ooo`05@000003oool0oooo@000003oool00d00
00030?ooo`=00000K03oool00d000000oooo0?ooo`020?ooo`A0000000@0oooo@000040000100000
0P3oool3@00000030?oood000010000000900000K03oool3@00000<0oooo00=000000?ooo`3oool0
0T000000103ooom00000@000003oool3@00005/0oooo001H0?ooo`04@000003oool0oooo@00000T0
oooo00=000000?ooo`3oool0JP3oool00d000000oooo0?ooo`200?ooo`04@000003oool0oooo@000
0080oooo00=000000?ooo`3oool0I03oool005L0oooo140000090?ooo`900000K03oool3@00007l0
oooo140000020?ooo`900000IP3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool0
0?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool0
0?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool0
08T0oooo0T00000[0?ooo`=00000o`3oool:0?ooo`00R`3oool00d000000oooo0?ooo`0Y0?ooo`03
@000003oool0oooo0?l0oooo2@3oool007d0oooo0d0000030?ooo`=000000`3oool3@00000D0oooo
00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`040?ooo`03@000003oool0oooo00T0oooo
0T0000030?ooo`90000000L0oooo@000003ooom000000?oood000000oooo00=000000`3oool2@000
00030?oood00001000000080oooo00=000000?ooo`3oool00T0000000`3ooom00000@00000020?oo
o`03@000003oool0oooo009000000P3oool2@00001@0oooo0T0000020?ooo`=000002P3oool3@000
00<0oooo0T0000020?ooo`=000000`3oool2@0000080oooo0d00000=0?ooo`9000000P3oool2@000
00030?oood00001000000080oooo0T0000030?ooo`9000000P3oool3@00000060?oood0000100000
@000003ooom00000Q@3oool007h0oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3o
oom000000080oooo00=000000?ooo`3oool01`3oool00d000000oooo@000000@0?ooo`03@000003o
ool0oooo0080oooo00=000000?ooo`3oool00T0000001P3ooom000000?oood000000oooo@0000080
oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003ooom0000000@0
oooo00I000000?ooo`3ooom000000?oood0000020?ooo`05@000003oool0oooo0?oood0000004P3o
ool014000000oooo0?oood0000020?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool0
0P3oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood0000000P3oool01400
0000oooo0?oood00000@0?ooo`06@000003oool0oooo@000003ooom000000P3oool00d000000oooo
0?ooo`020?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood000025
0?ooo`00OP3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oood0000000P3oool0
0d000000oooo0?ooo`070?ooo`03@000003ooom000000100oooo00=000000?ooo`3oool00P3oool0
0d000000oooo0?ooo`02@00000060?oood000000oooo@000003ooom000000P3oool00d000000oooo
@00000020?ooo`03@000003ooom000000080oooo00=000000?oood0000000T0000020?ooo`06@000
003oool0oooo@000003ooom000001@3oool00d000000oooo0?ooo`0A0?ooo`04@000003oool0oooo
@0000080oooo00=000000?ooo`3oool02@3oool00d000000oooo0?ooo`020?ooo`04@000003oool0
oooo@0000080oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000003oool0oooo@00000l0
oooo00A000000?ooo`3oool0oooo0d0000020?ooo`=000000P3oool00d000000oooo0?ooo`020?oo
o`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000Q@3oool007h0oooo0T0000030?oo
o`900000103oool3@00000X0oooo00=000000?ooo`3oool03`3oool00d000000oooo0?ooo`030?oo
o`90000000H0oooo@00004000000oooo@000003oool4@00000<0oooo0T0000000`3ooom00000@000
0002@0000080oooo0d0000000`3ooom00000@0000002@00000030?oood0000100000009000000`3o
ool2@00001<0oooo0T0000020?ooo`=000002P3oool3@00000<0oooo0T0000030?ooo`03@000003o
ool0oooo0080oooo0T0000020?ooo`A000003@3oool2@0000080oooo00E000000?oood0000100000
0?ooo`03@00000030?oood0000100000009000000P3oool3@0000080oooo0d0000260?ooo`00OP3o
ool014000000oooo0?oood00000C0?ooo`03@000003ooom000000100oooo00=000000?oood000000
9@3oool00d000000oooo0?ooo`0M0?ooo`03@000003oool0oooo01@0oooo00=000000?ooo`3oool0
6`3oool00d000000oooo0?ooo`070?ooo`03@000003oool0oooo00L0oooo00=000000?ooo`3oool0
QP3oool007d0oooo1D0000020?ooo`03@000003oool0oooo00l0oooo00=000000?ooo`3oool03`3o
ool3@00004H0oooo00=000000?ooo`3oool04P3oool2@00001`0oooo0T00000B0?ooo`900000R03o
ool00?l0oooo``3oool00?l0oooo``3oool00001\
\>"],
  ImageRangeCache->{{{0, 449}, {139.625, 0}} -> {-0.308828, -0.0234427, 
  0.00805715, 0.00805715}, {{38.3125, 154.688}, {136.688, 
  20.3125}} -> {-122.582, -12.7492, 2.59671, 2.59671}, {{166.313, 282.625}, {
  136.688, 20.3125}} -> {-454.88, -12.7492, 2.59671, 2.59671}, {{294.313, 
  410.625}, {136.688, 20.3125}} -> {-787.258, -12.7492, 2.59671, 2.59671}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After normalizing the image data in Fig. 8 between the values of  0 and 1, \
we convert the red, green and blue color sketch data into a color image data \
by means of the function \[OpenCurlyDoubleQuote]convertRGB\
\[CloseCurlyDoubleQuote]. Consequently, we can obtain a color sketch as shown \
in Fig. 9.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
normalizedCSD=Table[
\timageNormalize[colorSketchData[[i]]],{i,dim[[1]]}];
Show[convertRGB[normalizedCSD],
\tPlotLabel->\"Fig.9. Color sketch\",
\tAspectRatio->dim[[2]]/dim[[3]]];\
\>", "Input",
  CellLabel->"In[54]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[.5 1.0125 -59 0 ]
[.5 1.0125 59 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.9) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Color) show
141.000000 12.812500 moveto
(sketch) show
177.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
768 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3CFC6F3F4DCF3FFFFF3F4F4FFFFFFFFFFFF
FFFFFFFFFFF3FFFFF3FFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFF4F4FFFFFF\
FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFF3F4E8F3F4F4\
F3F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F3F2F4F3F2F4FFFFFFFFFFFFF3F2F4
FFF4F3FFFFFFFFF4F3F1F4F3F1FFFFF1F4F4F1F4F4FFFFFFF1F4F4FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4
FFF4F4F3F4F4F3F4F4FFFFFFFFF4F4F3FFF4FFFFF4FFFFFFFFFFF4FFFFF4F3F2F4F3F2FFFFFFF4\
FFFFFFFFFFFFFFFFF4FFFFFFFFFFFFE6F2FFE6FFFFFFF2F4FFFFFFCB9E8CFFE8DC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4C6FFEDDCFFF7F8F7F7F8FFFFFFFFFFFF
FFFFFFFFFFF3FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF4F4\
FFFFFFFFF7F8FFFFFFFFFFFFFFF7F8FFF4F4FFF4F4FFF7F8FFFFFFFFFFFFFFF7F8
FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFF7F7F7ECF7F7EFFFFFFFF3F4E8F7F7F8\
F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F7F6F8F7F6F8FFFFFFF7F6F8F7F6F8
FFF4F3F5FFF7F5F7FFF5F7F7F5F7F7F1EDEDF5F7F8F1F4F4F5F7F8FFFFFFFFF7F8FFF7F8FFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFFFFF
FFF7F8F7F7F8F7FFFFFFF4F4FFF7F8F3FFF8F7FFF8F7FFFFFFFFF8F7FFF8FFF6F8F7F6F4FFFFF8\
FFFFF8FFFFF8FFFFF8FFFFF4FFFFF8EEF2FFEEF6FFEEFFF8DEE5DED99F8AFFEFE7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0D0F3E0D0F3F7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFF4F4FFF7F8FFF7F8FFFFFFFFF7F8FFF4F4\
FFF7F8FFF4F4FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFF4F4
FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFFFF7F7F7ECF7F7EFF7F7EFF7F7EFFFFFFF\
FFFFFFFFF7F8FFF4F4FFF4F4F7ECEEF3EBEEF7F6F8F7F6F8F3F2F4F7F6F8FFFFFF
FFF7F7F5F7FFF5FFF7FFFFFFF5F4F4F5EFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF4F4
FFFFFFFFF7F8FFF7F8F7FFFFF3FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFF8F7FFF8FFFFF8FFFFF8\
FFFFF8FFFFFFFFFFF4FFFFF8FFFFF4EEF2FFEEF2F8EEF6F4C2BEB6F7BAA7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0D0F3E0D0F3F7F8FFF7F8FFFFFFFFFFF7
FFFFF7FFFFFFFFFFF3FFFFF7FFFFFFFFFFFFFFF7EFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF4F4FFFFFF
FFFFFFFFF7F8FFF7F8FFF4F4FFF7F8FFFFF7F7F7ECF3F4E8F3F4E8F3F4E8F7F7EFFFFFFFFFF7F8\
FFF4F4F7EEF0F7F6F8F7F6F8F7F6F8FFFFFFF7F6F8F7F6F8F5F7FFF5F4F7F5F4F3
F5F4F3F5F7F7F1FFFFF1FFFFF5F7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF7F8\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F7FFFFFFFFFF
FFF7F8FFF4F4FFFFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFF7FFFFFFFFF8F7FFF8F7FFF8FFFFFF\
FFFFF8FFFFF4FFFFFFFFFFF8FFF6F8EEFFFFEEF6F4F7EFF0D1B29CFFD9CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF7F8
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0D0F3E0D0F3F4F4FFFFFFFFFFFFFFFFF7
FFFFFFFFFFF7FFFFF7FFFFF7FFFFF3FFFFF3FFF4F4FFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFF\
FFF4F4FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8
FFF7EFFFFFF7FFFFFFFFFFFFF7F7EFF3F4EDF7F7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8\
ECEEF8F5F7FFFFFFFFF7F6F8F5F7FFF5F7FFFFFFFFF5F7F7FFFFF7F5F4F3F1F7FF
F5F7F8F5F4F4FFF4F4FFF4F4FFF4F4FFF7F8F7F7F8F7F7F8F7F4F4F7F4F4FFF4F4FFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFF7F7F8F7F7F8FFF7F8
FFFFFFFFFFFFF7F7F8F7F7F8F7F7F8F7FFFFF3FFFFF3FFFFFFFFFFFFFFFFF3FFFFF3FFFFFFFFF8\
FFFFF8FFFFF8FFFFF8FFFFFFFFF6FFEEFFFFEEF6F4F7D9CCD1B29CFFEFF0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0D0F3E0D0F3F4F4FFFFFFFFFFFFFFFFFF
FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFF7F8FFF4F4FFF4F4FFF4F4FFF7F8FFFFFFFFFFFF\
FFF7F8FFF7F8FFF7F8FFF4F4FFF7F8FFFFFFFFF4F4FFF7F8FFF4F4FFF7F8FFFFF7
FFFFFFFFFFF7F7F7EFF3F4E8F7F7EFFFFFFFFFFFFFFFF7F8FFF4F4FFF4F4FFF7F8FFFFFFFFFFFF\
ECEBF8ECF3F8EAEEF4F5F7FFF5F4F7F5F4F7F5F7F7FFEFF7FFEFF7F1F4F7F5FFF8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F7F7F8F3F4F4F3F7F8FFF7F8F7F7F8F7F4F4\
FFF7F8FFF7F8FFF7F8FFF7F8F7F4F4F7F7F8FFF4F4FFFFFFFFFFFFFFFFFFF7F7F8
F7F7F8FFF4F4F7F4F4F7F7F8F7F7F8FFFFFFFFFFF8F7FFF8FFFFFFF7FFFFFFFFFFF7FFFFFFFFF8\
FFFFF8FFFFFFFFFFF8FFFFF4FFFFF8EEF6FFE5EEEEE2C6B2D9C2B9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBC6F3E8DCF3F7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFF7FFFFFF
F7F7F8F3F4E8FFFFF7F3F4F4F7F7F8FFFFFFFFFFFFFFF7F8E3F7F4E3FFF8E3FFF8E3F6F8F7F2F8\
EAEEF4EAF7F4F2F7F8FFFFFFF5FFF7F5FFFFF5F7F7F5F7FFF5F7F7FFFFF7FFF7F8
FFF4F4F7F4F4F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F7F4F4F7F7F8F7FFFFF3FFFF\
F7F7F8F3F7F8F7F4F4F7F4F4FFFFFFF7FFFFF7F7F8F7F7F8FFF7F8FFF4F4F7FFFF
FFF7F8F3F7F8F7F7F8FFFFFFF3FFFFF3F6F8F3F6FFF7F6FFF3F6F8FFFFFFF7FFFFFFFFF8FFFFFF\
FFFFFFFFFFF8FFFFFFFFFFF8FFFFFFFFF6F8F3E7E3DEB298F7DCD6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0D0F3E0D0F7FFFFF7F4F4FFFFFFFFFFF7
FFFFF7FFFFF7FFFFFFFFFFF7FFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFF7F8FFF7F8FFF4F4\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7ECF7F7EC
F3F4E8F7F7F8E3F7EFD9EDF4F7F7F8FFFFFFE3F7FFE3F4F8E3EEF4E3F2F8E3F2F8ECF6F0F7FFF8\
F5F7FFF5F7FFF5F7F7FFEFF3FFEFF3F5EFEFFFF7F8FFF7F8FFF4EDFFF7F4FFFFFF
FFFFFFF7EFF0F7EDE5F7F4EDF3F4F4F7F4F4F7F4F4F7F7F8FFF7F8F7F4F4FFF7F8F7FFFFF7FFFF\
FFFFFFF3FFFFFFF7F8FFF7F8FFFFFFF7F7F8F7F7F8F7F4F4F7F4F4F7FFFFFFF4F4
F7F7F8F3F7F8FFFFFFF7FFFFF3FFFFF3F6F8F3F6F8F3F6F8F7F6F8FFFFFFF3FFFFF7FFF8FFFFF8\
F7FFF8F7FFFFFFFFF8FFFFF8FFFFFFFFF6FFF7D1C5D1AE98FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8\
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D9D0F7E4D0FFFFFFF3F4F4FFFFFFFFFFF7
FFFFF7FFFFF7FFFFF7FFFFF3FFFFFFFFFFF7FFF7EFFFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF4F4\
FFF7F8FFF7EFFFFFF7FFFFFFFFFFFFFFFFFFF7F7EFF7F7EFF7F7EFDAEFFFD9EDF8
F3F4EDF7F7F8D1EDEFD8F4EDE3F7FFE3ECF8E2EBEEEAF2EEF3F6F4EAF7EDEAEDE8F7EFF4FFEFF7\
F5E8ECF1EDECF5DDE7F5ECEEF5ECEEFFEEF8FFEEF8FFEEF8FFF7F8FFF4F4FFFFFF
FFFFFFFFFFFFFFFFF7F3E0E2F7ECF0FFEFF0FFEFE7FFF7EFF7FFFFF3F7F8F7FFFFF7FFFFFFFFFF\
F7FFFFF3FFFFF7FFFFF7FFFFF7FFFFF7F7F8F7FFFFF7FFFFFFF7F8F7FFFFFFF4F4
F7F7F8F7F7F8F7FFFFF7FFFFF3FFF8F3FFF8F7F7F8F7F4F4F3F7F8F3FFFFF7FFFFF7FFFFFFFFFF\
F3FFFFF3FFF8FFFFF8FFFFFFFFFFF4F7EFE6E2B89FD9CAC4FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8\
FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3CFC6F7F4DCF3F7F8F7F7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFF7FFFFFFFFFFF7FFFFF7FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFF3FFFFF3FFFFFFFFFFF7F7F7ECFFFFFFFFFFFFFFFFFFDAEFFFE2F4ED
FFE5F8F7EEFFE3F7F8DAF6F8DAEBF8E3F6F8F7FFF8F3FFF4F3FFF4EAF7EDF2EDECFFFFFFFFEFF7\
F5EFF4F1F7F4F1ECF0F5EEF4FFEEF8FFF7F8FFF7F8FFF7F8FFECF4FFECF4FFE5F0
FFF7F8FFF7F8FFE5F0F7FFFFF7E5F0F7EFF0FFFFF7FFFFFFF7EDE8F3EDEEF7FFFFF7FFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFF7F8FFF7F8FFFFFFF3FFFFF3F7F8
FFFFFFF7F4F4FFF4F4F7F7F8FFFFF8F7FFF8F7F7F8F3F4F4FFF7F8FFFFFFF7FFFFFFFFFFFFFFFF\
F7FFF8F7FFF8FFFFFFFFFFFFFFFFF8E2E1D4E3AE94F7EFF0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7CFC0FFF4E1F7F4F4FFFFFFFFFFFFFFFFFF
FFFFF7FFFFF7FFFFF7FFFFF3FFFFF7FFF7F8FFF4F4FFFFFFFFF7F8FFFFF7FFFFF7FFFFFFFFFFFF\
FFFFFFFFFFF7F7F7F8F7F7EFF7F7ECFFFFF7FFFFFFFFFFFFF7F7F8F7F7F4F3F4F4
E3E4EDE2ECEFF7EEFFFFFFFFFFEEF8F3FFF4F3FFF4F7EEF4FFEEF8FFEEF8F7EEF0F3EDEFF3EDF3\
F3F7F7F7F4F3FFEDF7F5EFEFF1FFF4F1EEEEF5FFF8FFEEF8FFE6F4FFE6F4FFE0EE
FFE5F0FFE5F0FFECF4FFECF4FFF4F4FFE4EEF7F6FFFFFFF7F3E0E2FFF6FFEEEDE2EEEDE2F7EFF0\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFF7F7F8F3F7F8
F7F7F8FFF4F4FFF4F4F7FFFFFFF7F8F3FFFFFFFFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFF8FFFFF8\
FFFFF4FFFFF4FFFFFFFFFFFFFFFFF8E3D5C0D9B0A2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBAF3F4E8F3F4F4FFFFFFFFFFFFFFFFFF
FFFFF3FFFFF7FFFFF7FFFFFFFFFFF3FFF7F8FFF4F4FFF7F8FFFFFFFFFFF7FFFFF7FFFFFFFFFFF7\
FFFFF7FFFFF7F3F4EDF3F4E8F7F7EFFFF7E7F7F4E1F3F4EDDAEFFFCBE8F3D9EDF4
E3E4EDD9E7F7FFE5F8FFE5F8F7E0F8F7EEFFF7EEFFF3E6FFF7E6F8F3EEF8F7FFF8F7E5EEF7F7EE\
FFF7F8F7F4F7F3FFF7F3F4F7F7F4F7FFF7FFF1EEEEFFEEF8FFE6F4F5EEF8F5FFFF
FFFFFFFFEEF8F5EFEFF1EFEDF5F7F4F5E5EEF5F7FFF7E4F0F3FFFFFFECF0EBE4E2E3E4EDF7EFED\
F3E8E2F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F7FFFF
F7F7F8F3FFFFF7FFFFFFF7F8F7F7F8F7FFFFF3FFFFF7FFFFF7FFFFFFFFFFF7FFFFF7FFF8FFFFF8\
FFFFF8FFFFF8FFFFFFFFFFFFFFFFF8E3C2A7D9C2B9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFD4C0F3F4E8F3F7F8FFF7F8FFFFFFFFFFFF
FFFFF3FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFFFF7\
FFFFFFFFFFFFF3F7E8F3F7EDF7F7EFF7F4E1FFF7E7F3F4F4D9EDF4D8F4E8E3F7EF
F3ECEFFFE5F4F7F7F8FFFFFFF7EEF7F7E4E8F7E4EDF7E4F4FFE5F8F7E0F8F7F7F8FFEEF8FFFFFF\
F7F6F0FFF6F4FFF4F8F7FFF7F7FFF7FFF4FFF5FFF8F1EEF0F5EEF8F5EEF8F5FFFF
F5EEF0F1FFF4ECEDECF7EDF3F5F7FFF5F7FFF1ECF0FFE0EEFFF7F8F7F2FFF7FFFFF7ECF0F3E8E2\
F7EDE8F7F7F4F3E8E2F7EFF0FFFFF8FFFFF8FFFFFFFFFFFFFFFFFFFFFFF8F7F7F0
F7F7F8FFFFFFF3F6F8F7F6F8F3FFFFFFFFFFFFFFFFF3FFFFFFF7F8F3F7F8FFFFFFF7FFFFFFFFFF\
FFFFFFFFFFFFF7F7F8F7F7F8F7F7F8D6AE9BF7D9D0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F7D4B9F7F7EFF3F7F8FFF7F8FFFFFFFFFFFF
FFFFF7FFFFF7FFFFFFFFFFF3FFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFF7F7F7EF\
F7F7F4FFFFF3F3F7EDF7F4E1F7F7EFF7F7EFF7F7EFE2F4EDE3F7EFF3F4EDF3F4ED
FFFFF7F7F7F8FFFFF7F7F7F4F7F7EFFFFFF7FFFFF7FFFFFFF7F7F4F7F7F4FFDBF4F3EEF8F7E6F8\
F7ECF8FFEBF8FFF7F4F7F4F7F3F4F3F3EFF3F7F4F7FFF7F4F5FFFFF1EEF8F1EEF8
F5FFF4F7F7F7FFEFF7F7EDF7FFE8F3FFEFF7F5F7FFF1F7F8F5EEF0FFEEF8F7F6FFF3F2FFF7F2FF\
F7EBF8F3E4E5F7EDE8F7F7F8F7EFE8FFFFF8FFFFFFF7F7F8F7F7F8FFFFF8FFFFF8
F7F7F8F3F7F8FFF6F4FFF6F4F3F7F8FFF7F8F7FFFFF7FFFFFFF7F8F3F7F8F7FFFFFFFFF8FFFFF8\
FFFFFFFFFFFFF7F7F8F7F7F8F3EDE5DEAF9BF7E8E2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8
FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F7D4B3F7F7F8F3F4F4FFFFFFFFFFF7FFFFF7
FFFFF7FFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFF7FFFFFFF7F7EFF7F7ECFFFFF3FFFFF7F7F7F8\
F7F7ECFFFFF7F3F4E8FFFFFFFFFFFFF7F7EFFFFFFFDAEFFFD9EDF8FFFFF7FFFFF3
F7F7F4F7F7EFFFFFF7FFFFF7FFFFFFFFFFF7FFFFF3FFFFF3F7F7F8F7E4EDFFFFFFF3ECF8F7EEFF\
F3ECF8F7EBF8FFFFF4FFFFF8FFFFF4FFF7F8F7F7F7F7F4ECFFEFEDFFEFEDFFEFED
FFFFF8F7F4F7FFF7F7F3F4FFF3F7F8F3EDEFF3F4F3F7EDF3F5EFEFF1EEF0F5EEF8FFEEF8F7EBF8\
F3F6FFF7F6FFF7EBF8F3E0EEFFF6F7F7EFE7FFFFFFF7F7F8FFFFFFF3F4F4F7F7F8
F7F7F8F3F7F8F7FFF8F7FFF8F7F7F8F7F7F8F7FFFFF7FFFFFFFFFFF7FFFFFFFFF8FFFFFFFFFFF8\
FFFFFFFFFFFFFFFFFFFFFFFFE2E1D6E3AE9BF7EFF0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFEDEEF7D9B8F7F7F8F3F4F4FFFFFFFFFFF7FFFFF7
FFFFF7FFFFF7FFFFF3FFFFF7FFFFF7FFFFF7FFFFF3FFFFF7F3F4F4F3F4E8FFFFF7FFFFF7F7F7F4\
F7F7EFFFFFFFF3F4E8FFFFFFFFFFFFF7EFE7F7F4EDF7F4EDF7F4EDFFF7F8FFF7EF
FFF7EFFFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFF7FFFFF7F7F7ECF7E4EDFFE5F4F7F7F8F7E4F4\
F7E7F0F7EBF4FFFFFFFFFFFFFFF6F8FFF2F8FFEBF4F7F3F4F7EDECF7EDF3F3EFF7
F7E8F3FFF4F7F7F7F7F7F7F7F7F7F4F7F7F4FFF7FFF3FFF7F7F4FFF7F4EFF5E5EEF5FFF8FFF3F8\
FFF6FFF7EBF8F3EEF8F3EEF8F7F3EFF3EFE7F7EFE7F3E8E2F7F4F4F7F7F8F7F7F8
FFFFFFFFFFFFFFFFFFF7FFFFFFFFFFF7FFFFF3FFF8F7FFF8FFFFFFFFFFFFF7FFF8F7FFF8F7FFF8\
FFFFF8FFFFFFFFFFFFF7F7F8EAD1B2DEAEA7F7F7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFE8E9F3DBB9F7FFFFF7F4F4F7F7F8F7F7F8FFFFFF
FFFFFFFFFFF7FFFFF7FFFFF3FFFFF7FFFFFFFFFFF7F7F7F8FFFFF7F7F7EFF7F7EFF3F4EDFFFFF7\
FFFFFFF7F7EFF3F4E8F7F7EFF3F4E8F7F4EDFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8
FFF4F4FFF7F8FFF7F8FFF4F4FFF7F8FFF7F8FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7F7F7F8\
FFE5F8F7F7EEFFF2F8FFF6F8FFF6FFFFF6F8FFF6FFFFF6F8F7F7F4FFF7F7F7FFF8
F7FFF8F3F4F7F3F7F3FFEFF7F7F4F3F3F7F3FFF7FFF3F7F3F3F7F3F3F4F3FFF7FFF5EEEEF5F7F8\
FFF2FFF5ECF4F5EEF8FFFFFFF7EBF8F7F6FFF3EDE5FFF7F8FFF7ECF7EFE7F3F4F4
F7F7F8FFFFFFF7F7F8FFF7F8FFFFFFFFFFFFFFFFF8FFFFF8FFFFFFFFFFFFF7FFFFF7FFFFF7FFF8\
FFFFFFFFFFF8F7F7F8F7EFF0E3BDA2E2CED1F7F7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFE8E9F3DBB9F3FFFFFFF4F4F7F7F8F7F7F8FFFFF7
FFFFF7FFFFF7FFFFF3FFFFFFFFFFF3FFFFF7F7F7ECFFFFF7FFFFFFF7F7EFF3F4E8F7F7EFF7F7F8\
F7F7F8F7F7F8F7F7F8F7F7F8FFFFF7FFF7F8FFF4F4FFF7F8FFF7F8FFF4F4FFF7F8
FFF4F4FFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFFFFFFFFFF7FFFFF7FFFFFFFFFFFFFFFFF7F7F7EF\
F7E5F8F7F7F8F7F6F8FFF6FFFFF6F8FFF6F8FFFFFFFFF6F8FFFFF8F7F7FFF7F7F8
FFFFFFFFF7F8F7F7F7FFF7F7F7F7F7F3EDF7FFF7FFF7FFF7FFF7FFFFF4FFF7F7F4FFFFF8F5EEF8\
F5E6F4F5FFFFF5EEF8FFE6F4F7F6FFF7FFFFF7EBF8F3E4E5F7EFE7FFF7EFFFF7EF
F3F4F4FFFFFFF7F7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFF7FFFFFFFFF8FFFFF8\
F7F7F4F7F7F4F7F7F8EBEDE2CEB6A6F7E8E2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFE8E2F3DBBFF3F7F8FFF7F8FFFFFFFFFFFFFFFFF7
FFFFF7FFFFF7FFFFF7FFFFF7F7F7ECF3F4E8FFFFFFF7F7EFF3F4E8F3F4EDF7F7F8F7F7F8FFFFFF\
FFFFFFFFFFFFFFFFF7FFFFF7FFFFF7FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF4F4
FFF4F4FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFF7FFF7EFFFF7F8FFF7F8FFF7F8FFF7F4\
FFEFE5F7E5EFFFF7F8F3F6F8F7F3F8F7EBF8F7FFFFFFF7F8FFEEF0FFF7F4FFF7F8
FFFFF4FFFFF8F7F7EDF7F4F4F7FFFFF7F7FFFFF4FFF7FFF7FFFFFFFFFFFFF7F4F4FFFFF8FFFFF8\
F5FFF4F5E6EEF5E6F4F5E6F4FFF6FFF7F7F8F3EEF8F3EBF8FFF7EFF7EFE5FFF7F8
F7EDE5F7EFF0FFFFFFF7FFFFFFF7F8FFFFFFFFFFFFF7FFFFF7F7F8FFFFFFFFF7F8F3F7F0F7FFF8\
F7F7F8FFFFFFF3F4F4D6E5D0D1AEA7F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFF7D9D0F7E4D0F7F7F8F7F7F8FFFFFFFFFFFFFFFFF7
FFFFF7FFFFF3FFFFF3FFFFF7F3F4EDF7F7EFFFFFFFF3F4E8FFFFF7F7F7F8FFFFF7FFFFFFFFFFFF\
FFFFFFFFFFF7FFFFFFFFF7F8FFF4F4FFF4F4FFF7F8FFFFFFFFFFFFFFF7F8FFFFFF
FFF7F8FFFFFFFFF7F8FFF7F8FFF4F4FFFFFFFFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFF7F8FFFFFF\
FFF7F8F7F7ECF7E4F4F7E7F0FFF6F8FFF6F8F7ECF4F7F6FFF7EBF8FFF6FFFFF6F8
FFFFFFFFEEF4FFEEF8FFFFF8FFF4F8FFF4FFFFF4FFF3FFF3F3F7F3F3F7F3FFF4FFFFFFF8FFFFFF\
FFFFF4F1EEF4F5FFFFF5FFFFFFEBF8FFECF4F7E6F4F7EEF8F3F3F8F3EDEEE5F4EC
E5F7F3F3E8E9FFFFFFF7F7F8F7FFFFF7FFFFF7F7F8F7F4F4F3FFFFF7FFFFF3F4F4F7F4F4F7FFFF\
FFFFFFF3F4F4F7F7F8D9DBC6DAB0A8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFF3CFC6F7F4DCF3F7F8F7F7F8FFFFFFFFFFFFFFFFF7
FFFFF7F7F7F4F3F4EDF3F4EDFFFFFFF7F7EFF3F4E8F7F7F8F7F7F8FFFFF7FFFFF3FFFFFFFFFFFF\
FFFFF7FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFF4F4FFF4F4FFF4F4FFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4\
FFFFFFFFFFF7FFFFF7F7F7F8F7E0F8F7E0F8F3ECF8FFF3F4F7F3F8FFECF4F7EEF8
F7F6F8FFEBF4FFEBF0FFFFF4FFF7F8FFF7FFFFF4FFF7FFF7FFF7FFF7F7F7FFF4FFFFFFF8FFFFFF\
FFFFF4F5FFF8F5E6F4FFE6F4FFF4F4FFF3F8F7F7F8F7F2FFF3F6FFF3F4F4E3F7ED
E3EDF0F7EFE7F3EDEEF7FFFFF7F7F8F3F7F8F7F4F4F7FFFFF7F7F8F7FFFFFFF7F8F7F7F8FFFFFF\
FFFFFFF3F4F4F7F7F8E2C6B2D9C2B9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFF3CFC6F7F4DCF7F4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF3F4F4F7F7EFF3F4E8FFFFFFF7F7EFF7F7ECF7F7F8FFFFFFFFFFF3FFFFFFFFFFF7FFFFF7\
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFFFFFFFFFFFFFF6F0FFF6F0FFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF4F4FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F4FFFFF7FFFFF7FFFFF7FFE5F8F7EEFFF7EEFFF3E7F0F7F6F8F7EEFFF7F7F8
FFEBF4F7F2F8FFF2F8FFFFF8FFF6F8FFF6F4FFF7F8F7F7F7F7FFF7FFF7FFFFFFFFFFF7F8FFFFFF\
FFFFF4FFFFF8F5EEF8F1F6FFF5EEF8FFFFFFFFFFFFFFF2FFF7F6FFF7F7F8F3EEF8
F3E0E2FFF7EFE5F7F7E5F7E7F7F7F8F7FFFFF7FFFFF7F4F4F7F7F8FFF7F8FFFFFFF7FFFFF7F7F8\
F7F7F8F3F4F4FFFFFFECC8A8E2C8CBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFDDCFF7DDC5F3F7EDFFFFFFF7F7F8F7F7F8F7F7F8F7F7F8
F3F4F4F7F7F8F7F7EFF7F7EFF7F7EFF7F7F8FFFFFFFFFFF7FFFFF7FFFFFFFFFFF7FFF7F8FFF7F8\
FFFFFFFFFFF7FFF7F4FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0FFFFFF
FFF4F4FFFFFFFFF7F8FFF4F4FFFFFFFFF7F8FFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F4FFFFF7FFFFF7FFFFFFFFFFF7F7F7F8F7F7F8F3F4F4F7EEFFFFFFFFF7EEFF
F3E6FFF3F2F4FFF2F8FFFFF8FFF6F8FFEEF4F7F4EFFFF7FFF3FFF3F7F4F4FFF7F4FFF7F8FFFFF4\
FFFFFFFFFFF8FFFFF8FFF7F8F5ECF4F5F7F8FFFFFFFFF2FFFFF6FFFFF6FFF7FFFF
FFECF0F7F7F8E3F4F4E3F4F4FFEDEEF7EDEEF7F7F8F7F7F8F3F4F4FFF7F8F7F7F8F3F7F8F7F7F8\
F7F7F8F3F4F4FFF7F8ECBD9BE2D1DBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFF7EFF0E2B8A7E2DCE2F7F4F4F7FFFFF7F7F8F7F7F8F7F7F8F7F7F4
F7F7EFF7F7EFF3F4EDF7F7ECFFFFFFFFFFF7FFFFFFFFFFFFFFFFF7FFFFF7FFFFF7FFF7F8FFF7F8\
FFFFFFFFFFF7FFF4EDFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF4F4FFFFFFFFFFF7FFF7F4FFFFFFFFF7F8FFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFF7FFFFF7FFFFF3FFFFF7FFFFF7F7E4F4F3ECF8FFE5F8FFF6F8
FFF6F8F7F3F4FFF2F8FFFFF4FFFFF8FFF4FFF3F7F7F3F7F7FFF7FFF3EDECFFFFF8FFFFF4FFFFF4\
FFFFFFFFFFF8FFFFF8F5FFFFF1F7F8F5EBF8FFF2FFFFF7F8FFF3F8FFFFFFF7F6FF
FFF7F8F7EDEEF7EFF0FFFFFFE3EDEDE5FFECF7EDE5F3EFF0F7FFFFF3FFFFF7F7F8FFFFFFF7F7F8\
FFFFFFF3F4F4FFF4EDDEAF96F7EDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8\
FFFFFFFFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFEEE5F0C8B2B6DECBBDE4DBE9F7FFFFF7F4F4FFFFFFFFFFF7F7F7F4F7F7EC
F7F7EFF7F7F8FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFFF\
FFFFF7FFFFF7FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFF7F8FFFFFFFFF7F8
FFFFFFFFF7F4FFFFFFFFF7F4FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8\
FFFFFFFFF4F4FFF4F4FFF7F8FFFFF7FFFFFFFFFFF7FFE4F4FFF7F8F3ECF8F7F4F4
FFF7F8F7F7F8FFF6FFFFF6F8FFFFF8FFF7FFF7F7FFFFF4F7F7F4F7F3EDF3FFF7F8FFF7F8FFF7F8\
FFFFF8F5F7F8F5F7F4F5FFF8F1F7F8F5ECF4F5F3F8F5F7F8FFF3F8FFF6FFF7F6FF
FFEEF8F3EDEEF7EFF0D9E8F0F5F7F7E3EDE5FFFFFFE5EDE5EEF7E7FFFFFFFFF7F8FFFFFFF7F7F8\
F7F7F8F7F7F8EEF4E1CEAFA3F7EDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
EEE5F8C8B2ADBEA194BDCAD5E2D9E3F3F4F4F7F7F8FFFFF7F7FFEFF7F4E1F7F7EF
F7F7ECFFFFFFFFFFF7FFFFFFFFFFF7FFFFF7FFFFFFFFFFFFFFFFF7FFFFF7FFFFFFFFFFFFFFFFFF\
FFFFF7FFF7EFFFF7F8FFF4F4FFF4F4FFF4F4FFF4F4FFFFFFFFF4F4FFFFFFFFF4F4
FFF7F8FFF7F4FFFFF7FFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFF4F4FFF7F8\
FFF7F4FFF4EDFFF4F4FFF7F8FFFFFFFFFFF3F7F7F8F7FFFFFFE5F8F7FFFFF7F3F4
F7FFFFF7F6F8FFF3F4FFEEF0FFF6F8F7F7F7F7F7F7F3F4F3F3F7F3F3EFF3FFF7FFFFF7FFF5FFFF\
F5F7F4F1F7F8F1F7F4F5FFF8F5FFFFF1FFFFF5F4F4F5FFFFFFF6FFFFF6FFFFF6FF
F3FFF8F7F3F4F7F4F4DAF4F4D9F4F4FFF7F8F3E8E2EEF7E5EEEDE2F7FFFFF7F7F8FFFFFFF3F4F4\
FFFFFFF7F7F8E5EDDCD1AEA2F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
B3A6AD8F876BBEBDB68F98ADF3E7E9F7F7F8FFFFF7F7FFEFF7F7EFF7FFF8F3F4ED
F7F7EFFFFFF7FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF7F4\
FFFFFFFFFFF7FFFFFFFFFFFFFFFFF7FFFFFFF7F7EFF7F7F8F7F4F4F7ECF8F3ECEE
F7FFFFF7F2F8FFEBF4FFEEF0FFF6F8F7F7F7F7FFF7F3F7F3F3FFF3F3F7F3FFF7FFFFFFFFF5F7F8\
F5F7FFF5FFF8F5FFFFF5FFFFF5FFFFF5FFFFF1F7F8F5F4F4FFECF4FFF3F8FFFFFF
F3F6F8F7F3F4F7F7F8FFFFFFF7F7F8F7F7F8FFFFFFF3E8E9F7EFF0F7EFF0F7F7F8F7F7F8FFFFFF\
F3F4F4F3F4F4E4D9D6F3B59DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDACCDF\
67504CA1958BB1C6CB88919DFFF4F4F3F4EDFFFFF7F3F7EDF7FFEFF7F7ECFFFFF3
FFFFF3FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFF7F8FFF7F8FFF4F4FFF4F4FFFFFFFFF7F8FFF7F8FFF4F4FFF4F4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF4F4FFF7EC\
FFFFF3FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFF3F7F7F8FFE5F8FFE5F8F7EDEE
F7FFFFF7F2FFFFF2FFFFF2F4FFFFFFFFF7FFF7FFFFFFF7F7FFF7F7F7F7F3FFF7FFFFF7F8FFFFFF\
FFFFFFF5FFF8F1F7F8F1F7F8F5FFFFF5FFFFF1FFFFF5FFFFFFF7F8FFF7F8FFFFFF
F3F6F8FFF6F8F3F7F8FFF7F8F7F7F8F3F4F4F7F7F8F7EFF0F7EFEDF7EFE5FFF7EFF7F7F8FFFFFF\
F7F7F8EEF7E7D1D4CBD9BDAEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DDF087756B\
716049EBECEE839DB29D9DA2F7EFF0F7F7ECF7F7EFFFFFF7F7F7F8FFFFF3FFFFF7
FFFFF7FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8\
FFF7F8FFFFFFFFF4F4FFFFFFFFFFFFFFF4F4FFF7F8FFFFFFFFF4F4FFF4F4FFFFFF
FFFFF7FFFFF7FFFFF7FFFFF7FFF7F8FFFFFFFFF4F4FFF7F8FFFFFFFFFFFFFFFFF7FFFFF7FFFFF7\
FFFFF7FFFFFFFFFFFFFFFFF7FFFFF7F7F7EFF7F7F4F7F7F8FFE5F8FFF6F8F7F7F8
FFF6FFFFFFFFFFFFF8FFFFFFFFF6F8F7F7FFFFF7FFFFF7FFFFFFFFF7FFF7FFF7F7FFF7F8FFF4FF\
F5F7F8FFFFFFF5F7F8FFFFFFF1F4F4F5F7F8F1F7F8F5F7F8FFF4F4FFF7F8FFF7F8
F7F6F8F3F6F8FFFFFFF7F4F4F7F7F8F3F4F4FFFFFFF7F7F8F3E8E2EEFFF4F7EFDFF7F4EDFFFFFF\
FFFFFFE5FFEFD1CDBFD9C2C0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F7F4F49F848D68523F\
C7BBBDF1E0DB94A7B2818597E3F7EFDAEFFFF7F7F8F7F7ECFFFFF3FFFFFFFFFFF7
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFF7F8FFFFFFFFF7F8FFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFF7F4
FFFFF7FFFFF3FFFFF7FFFFF7FFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFF7F7F7F8F7F7EF\
F7F7EFF7F7ECFFFFF3FFF7EFFFF7EFF7F7F4FFFFFFF7F4F4F7F7F8FFF4F4F7FFFF
FFF6FFFFF6FFFFF2F4FFF6F4FFFFF8F7F6F8F7FFFFF7FFFFFFF7FFFFF7FFF7F4F3FFF7FFFFF7F8\
F5F4F4FFFFF8FFFFFFF5F7F8F1EDEEF5F4F4F1F4F4FFF4F4F5F4F4FFF4F4FFF4F4
FFFFFFFFFFFFF3FFFFF3F7F8F3F7F8FFFFFFF7F7F8F7F7F8F7EFF0F7EFDFEEFFF4FFF7EFFFF7EF\
FFFFFFF7F7F8DEBDA8F3CFC6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFFFFFFFF7F8FFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB5A0A44937394D433AA2A7A4\
E3F7EDBCC5C97586898D92A2DAEFFFDAEFFFFFFFF7FFFFFFFFFFF7FFFFFFFFFFF7
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFFFFF\
FFFFFFFFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F4
FFFFF3FFFFF7FFFFFFFFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFF7F3F4EDF7F7EF\
FFF7EFFFF4F4F7E8E9F7F4F4F3F4F4F3EDEEF7E5F0F7ECF4F3F4F4F7F7F8FFF6F8
FFF2F4F7EBEDF7F3F4FFFFF8F7F6F4F7F6F8F7F7F7F3F4F3FFF7F7FFF7F7F7F7F7FFF4FFFFF7F8\
F5F7F4FFFFF8F5FFFFF5FFFFFFF4F4FFF4F8F5F7F0F5FFFFF5FFFFFFFFFFFFFFFF
FFF3F4FFF2F4F3F6F8F3FFFFF3FFFFFFFFF8FFFFF8FFFFFFF7F7F8FFF7F8F3E8E2F7EFE5ECF4F4\
ECEDE1F7EFE7D6AE9BF7D9D0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F84E3639B5AA9DEBF4F4D6DBDC\
F7FFFF58646686878CE3DDE8FFFFFFFFFFFFFFFFF7FFFFF7FFFFFFFFFFF7FFFFFF
FFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFF7F8
FFF4F4FFF4F4FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF4F4FFFFFFFFFFFFFFFFF7F7F7EFF3F4F4\
FFF4F4F7F7F8F7FFFFF7F3F4FFEBEEFFEBEEFFE5EEFFEEF4FFF2F4FFF2F4FFF6F8
FFFFFFF7F7F7FFFFFFF3F4F3F7F4F3F3F7F7F3F4F3F7F7F7FFFFFFF7F7F7FFF7F7FFEDF4F5FFF8\
FFFFFFFFFFFFF1FFFFF1F7F8FFEDF0FFF4F4FFFFFFF1F7F0F5FFFFFFF7F8FFF3F4
F7F7F0F3F2F8FFFFFFFFF6F8FFFFFFF7FFF4FFFFF4F7FFFFFFF7F8FFFFFFF7F7F8F3EDEEECEFE5\
E3F6F8F7E5DDDEAF96F7E8E2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8\
FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8DACCD7322620F3F4EDDAE5F0EBE4E1\
507684575359D1DDE5FFFFF7FFFFF7FFFFF3FFFFF3FFFFF3FFFFF3FFFFFFFFFFFF
FFF7F8FFF4F4FFF7F8FFF4F4FFFFFFFFF7F8FFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFFFFF
FFF7F8FFFFFFFFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFFFF7FFFFF3FFFFF3FFFFF7FFE0EE\
F3F6F8FFFFFFFFF6F8FFF6F8FFFFFFFFFFFFF7F4F7F3F7F3F7F7F7FFFFFFFFFFFF
FFFFFFFFFFFFF7F7F7F3F4F3F3F4F3FFF7F7FFF7F7FFF7F7F7F7F7FFF7F7FFF7F7FFEDF4F1FFF8\
F1FFFFF5FFFFF5FFFFF5F7F8F5F4F0F1F7F8F1FFF8F5FFF8F5F4F4FFFFFFFFF6F8
F3F6F8F7FFF4FFF6F4FFF6F4FFFFFFFFFFF8F7FFFFF7FFF8F7FFFFF7F7F8F7F7F8F7F7F8F3EDE5\
FFDDD7FFFFF4D8C1AAF7E8E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EDEE8471727F7F76F3EDE5ECECED7D7D84\
4D5362E2D5D6F7FFECFFFFF7FFFFF7FFFFFFFFFFF7FFFFF7FFFFF7FFF7F8FFF7F8
FFF4F4FFF7F8FFF4F4FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFFFFF
FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFF3FFFFF7FFFFF3F7F7F4F3ECF8\
F7F3F4FFFFFFFFF2F4FFF6F8FFF6F8FFF6F8F7EEEFF7F4F3F3FFF7FFF7FFFFFFFF
F7FFFFF3F7F7F3F4F3F3F4F3F3F4F3FFF7F7FFF7F7F7F4F3FFF4F3FFF7F7F5FFFFF5F4F8F5F7F8\
FFF7FFF1FFFFFFFFFFFFFFFFF1F7F4FFF7F4FFFFFFF5FFFFFFF4F4FFFFFFFFF6F8
F3F6FFF7FFFFFFF6F8FFF6F4F7FFF8F7FFF4F7FFFFF7FFF8F7FFFFFFFFFFFFFFFFFFFFFFFFFFFF\
F3E8E2F7EEDFD1BCADFFEDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8ACA095565050D6CAC3EBF4ED8FA1AC596467\
C8D5DFF7F7ECF7F7F4FFFFF7FFFFF3FFFFF3FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFFFFFFFF4F4FFF4F4FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFFFFFFFFFFFFFFFF7FFFFFFFFFFF3F7F7F4F7F7F8\
FFECEEFFF2F4FFF6F8FFF2F4FFF2F4FFF6F8FFF6F8F7FFFFF7F7FFF7FFF7F3F4F3
FFF7F7F3F7F7F7F4F3FFF4F3F7F4F3FFFFFFF7F7F7FFFFFFFFFFFFFFF7F8F5F4F4F5F7F8F5F7FF\
F5EFF8F5F4F8FFF7FFFFFFFFF1F4F8FFF4F8F5FFFFF5F7F8F5F7F8FFFFFFF7F6F8
FFF6F8F7FFF4F7F6F8F7F6F8FFFFF4FFFFF8FFFFFFF7FFF8F7FFF8F7FFF8F3F7F8F7F7F8F7F7F8\
F7F4F4FFF7EFD8AF96FFEDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8BEB9C4615954A0A0ABDEEDEFBEA9AB716D6BC8C3BD\
F7F7EFFFFFFFF7F7F8FFFFF7FFFFF7FFFFF7FFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFF4F4FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFF3FFFFF3FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFF7EFFFFFF7FFFFF7FFFFF3FFFFF7FFE5F8F7E0EEF7E4E6\
FFEEF0FFFFFFFFFFFFFFF6F8F7EEEFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7
F7F4F3F3F7F7F7F7F7FFF7F7F7F4F3F7F7F7FFFFFFFFFFFFFFFFFFF5F4F4F1FFFFF1F7F8FFF7F8\
F5F7F8F5F7FFF5F4F8F5FFFFF1F4F8FFF4F8F5FFFFF5F4F4F5F7F8FFF7F8F7FFFF
FFFFFFF7FFF4FFFFF8F7FFF8F7FFF4FFFFF8F7FFFFF7FFFFFFFFFFF3FFF8F7F7F8F7F7F8F3F4F4\
F7F7F8F7EDEEE2C8AEDACAC4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F8EEE5F06457568F867BF7EFE7A2B9C8627380ACC3C5FFF7E7\
FFFFF7F7F7F4FFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFF3FFFFF3FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFF7FFFFFFFFE5EFF7E4F4F3F4F4F7E7F0F3F6F8FFF2F8\
FFFFF8FFFFFFFFFFFFFFFFFFF7F7F7FFFFFFF3F4F3F3F4F3F7F7F7F7F7F7FFFFFF
F7FFFFFFF7F7FFF7F7FFF7F7FFFFFFFFFFFFFFFFF8F5F7F4F5F7F4F5F4FFF1FFF8F5F7F8F5F7F8\
F5F7F8FFFFFFFFFFFFFFF4F4FFF7F8F5F7F8FFF4F8F5EDF4FFF7F8FFF7F8FFFFFF
F7FFFFF3F6F4F7F6FFF7FFF4FFFFF8F7FFF8F7FFF4F7FFF8FFFFF8F7FFFFFFFFFFF7FFFFF3F4F4\
F3F4F4F3EDEEF7E5D6D8B9ACF7DDD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F8C8B2C64C3C3F695A49D0D4D6D6DCE7505961ACA9A4FFFFFFF7F7EC\
F7F7EFFFFFF3FFFFF3FFFFF3FFFFF7FFF7F8FFF4F4FFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFFFF7FFFFF3FFFFF7FFFFFFFFFFFFFFFFF7FFFFF3FFFFF7\
FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF4F4FFF7F8FFF7F8
FFF7F8FFF4F4FFF4F4FFF4F4FFF7EFFFFFF7FFFFF3F7E4F4FFFFFFF7EEFFF3ECF8F3F2F8FFF6FF\
FFF7F4FFF4FFF7EDF7F3E8F3F3E8F3F7EDF7FFF4FFFFF4FFFFF4F8FFF4F4F7EDED
F7EDEDFFF4F4FFF4F4FFF4F4F5F4F4F5F4F4F5F4F8FFF7FFFFF7FFF5EFF4F5F4EEF5F4F4FFF7F8\
FFF4F4FFF7F8FFF7F8FFFFFFF7FFFFF7FFFFF5EFF8F5F7FFFFF7F8FFFFFFF7FFF8
F7FFF8FFF6F8F7F6F4F7FFF8F7FFFFFFFFF8F7FFFFFFFFF8FFFFFFFFFFFFF3FFFFF7F7F8FFFFFF\
F7F7F8F3F4F4FFF7EFECD5C5D8B9A3D9CAC4F7EFF0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3EDEE7F696E83846CFFFFFFE5ECED8795A166757BF7EFE7F7F7ECFFFFFF\
FFFFFFFFFFF7FFFFF7FFFFF7FFFFFFFFF7F8FFF4F4FFF7F8FFF7F8FFFFFFFFF7F8
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFF7FFFFF7FFFFF7FFFFF3FFFFF3FFFFF7FFFFFFFFFFF3\
FFFFFFFFFFF7FFFFF3FFFFF7FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFF
FFF7F8FFFFFFFFFFFFFFFFFFFFFFF7F7F7F8F7F7F4F7F7F4FFE5EFFFFFFFF7EEFFF7FFF8F7F7F4\
FFF7F8F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F4F7F7EFFFFFF8
FFFFF4FFFFF4FFFFF8F5EEF8FFEEF8FFFFFFFFFFFFFFFFFFF5F7F8F5FFFFF5F7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFF7FFFFFFFFFFF7FFFFFFF7F8FFF7F8FFFFFFF3FFF4
F3FFF4F7FFF8F3FFF4FFFFF8F3FFFFFFFFFFFFF6F4F3F6F4F3F6F8F7F6F8F3FFFFF7F7F8FFFFFF\
F3F7F8F7F7F8FFF4F4F7F7F8FFDDCFDEC9B3F3D9D4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7F8BCB6C1524943C8CCCEEEF7F8ACBBBE736C6BBEC3C5F7F7ECF7F7EFFFFFF7\
FFFFF7FFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFF4F4
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFF\
FFFFF3FFFFFFFFFFF7FFFFF3FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFF4F4
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F4EDF7ECEFFFDBEDF7E0EFF7EEFFF7D5D7F3C3C6F7C8D0\
FFCFDCF3D4DBFFDBDEFFCDD7F5D1D7F5D1D7F5D1DBF2E0E9FFDDE5ECE5E7F2E0EE
F7E5EEFFFFF4FFFFF8F5EEF8F5F6FFF1F7F8F5F7F8F5F4F4FFF7F8FFF7F8FFF7F8F7FFFFF7FFFF\
FFFFFFFFFFFFF7FFFFF3FFFFF7FFFFF3FFF8F3FFF8FFFFFFFFFFFFFFFFFFF7FFF8
FFFFF8F7FFF4F7FFF8FFFFF8F7FFFFF3FFFFF7F6F8F3F6F8F7F2F4F3F2F8F7FFF8FFFFFFFFF7F8\
F3F7F8F7FFFFF7EFF0FFFFFFF7EFF0E4DCCBF7C0B2F7EFF0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7F8776569877969F5F4ECCED5DD6F6B67ACAAB6F7F7F4FFFFF7FFFFFFFFFFF7\
FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFF\
FFFFF7FFFFF3FFFFF7FFFFF7FFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFFFFFFFF7F8
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFE4EDFFDDE7FFF6F8F7D4D6F3C3C6FFFFFFF3CDD4F7E5F0\
FFFFFFF3EFEDFFE8F3FFEFF7F5E6F7F5E6F7F5E6EFF2E1E8FFD5E7ECD4E7F2E1E8
F7D1E1ECC8DCECD4E2FFE4EEFFFFFFF5F7F8F5F7F8FFF3F8FFF6FFFFF6F8FFF6F8F7FFFFF7FFFF\
FFF6F8F7F6F8FFFFFFF3F6F8FFF6F4F7F6F8F7F6F8F3FFF4F7F7F4FFF7F8FFFFFF
F7FFFFF3FFF8FFFFF8FFFFFFF7FFFFF7FFFFF3FFFFF3FFFFFFF6F4F7F6FFF7FFF4FFFFFFFFF6F8\
F3F3F4FFF7F8FFF7F8FFF7F8F7EFF0EAEDE8E3B8A4F3D1BCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEEE5F8584532B1B2B6E5E7E1608292909590F7F4E7F7F4E8FFFFF7FFFFF7FFFFF7\
FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFF7F8FFF7F8FFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFF7ECFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7\
FFFFF7FFFFF3FFFFFFFFFFFFFFFFFFFFF4F4FFF4F4FFF4F4FFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFDBE8FFFFFFFFF6F8D9D4D0E2BCBDFFF6F8F3CDD4F7E5F0\
F7EFEFF7EFEFFFFFFFFFFFFFF5F6F0F5F6F0FFFFFFF5E6F7ECF7F8F7EFEFFFFFFF
F5F6F0F7EEF0ECEDF7ECDCECE4D4E1ECD4E2F1E0EEF5F7F8F5FFFFFFFFF8FFF6F8F7FFFFF7FFFF\
FFF6F8F7FFFFF7F2F4F7FFFFF7FFF8FFFFFFFFF6FFF7FFF8F7F7F4FFF7F8FFFFFF
F7FFFFF7FFFFF3FFFFF3FFFFFFFFFFFFFFFFF7FFFFF3FFFFF7FFF8F7F6F8FFF6F4FFFFFFFFF6F8\
F7F3F4F7F7F8F7F4F4F7F7F8F7F4F4F7F7F8EAE0DCDEBBA7E3D5DFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFFFFF\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCEB6BD585640D9D4D698A7A95A6476F3E4E7F3F7EDF7F7ECFFFFFFFFFFF3FFFFF7\
FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFF7F8FFF7F8FFF4F4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFF7F4FFEEFFF7E4F4F7F4F4FFF7F8FFF7F8FFF7F8\
FFFFFFFFFFF3FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFF7F8
FFFFFFFFF7F8FFF7F8FFE5EFFFD4E1FFE5EFFFFFFFFFFFFFDAFFEFDAF6EDF3BCCBFFFFFFFFFFFF\
F3E8E8FFFFFFFFFFFFFFFFFFF5F6F0F5F6F0FFFFFFF2E1ECF2E1ECFFFFFFFFFFFF
F5F6F0FFFFFFF5F6F0ECF7FFE4F4FFFFEFF7F7E8ECEED9EDEBECF8FFF6FFFFF6FFF7FFFFFFFFFF\
F3FFFFF3F6F8F3F2F8F7F6F8FFF2E7FFF2EFFFFFFFF7FFF4F3FFF8F7FFF8FFF7F8
F7F7F8F7FFFFF7FFFFF7FFFFFFFFFFFFFFFFF7FFFFF3FFFFF7FFF8F3F6FFF7F6F8FFFFF8F7FFF8\
F3FFFFF7FFFFF7F4F4F7F7F8F7F7F8FFF4F4F7EFEDEAD4B5E2BDB5FFEFE7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF876D6C6D7776DEE4F05C6975ACA8B2F7EDE5F7F7ECFFFFF7FFFFF7FFFFF7FFFFF3\
FFFFF7FFFFF7FFFFFFFFFFF3FFFFF7FFFFF3FFF7F4FFF7F8FFF7F8FFF7F8FFFFFF
FFFFFFFFFFF7FFFFF3FFFFF3FFFFF3FFF7EFFFF7F4FFE4EDF7EEFFF7F7F8FFF7F8FFF7F8FFEEFF\
FFE5F8FFFFF3FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8
FFFFFFFFDDE7FFD4E1FFDDE7FFFFFFFFFFFFFFD4D7FFD4D7FFFFFFFFF6F8F7CADEF7C1D6FFDDE7\
F3E8E8FFFFF8FFFFF8FFFFFFFFFFFFFFFFFFF5E6EFEAEDEFF3E8E8FFFFFFFFFFFF
FFFFFFF5F6F0FFFFFFF5F6F0FFFFFFECF7FFF7EEF0EEEEE7F2E6ECF7EFEFFFF6FFFFF6FFF7FFFF\
F3FFFFF3FFFFF3FFF8F7F6F8F7EEECF7EEECFFF6FFF7F6F8F7F6FFF3FFF8FFF7F8
F7F7F8F7F7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8F7FFF8FFFFFFF7FFF8F7FFF8F7FFF8\
F7FFFFFFFFFFF7F4F4F7F7F8FFFFFFF7EFF0F7F7F8EAEDE8D8CAB9DACAC9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DACCCFA4938A573F39DEF2F84959627E8789F7F7F8F3EDE5F3F4EDFFFFFFFFFFF7FFFFF7FFFFF7\
FFFFF7FFFFF7FFFFF7FFFFF7FFFFF7FFF7ECFFFFF7FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFF3FFFFFFFFFFFFFFF7F8F7F7F8F7F7EFF7F7EFF7FFFFFFF4F4FFFFFFFFE5F8FFF7F8\
FFE4F4FFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFDDE7FFD4E1
FFD4E1FFE5EFE3EEDFE3EEDFFFFFFFFFFFFFFFD4D7F7A9AEF3C3C6EBB0BDE69EB9EBAAB8F3CAC8\
F7E5DEFFF2EEF5E4E2F1DBD1F1E4DBF1E4DBFFCCCEF2E1E8F7EFEFFFF6F0FFF6EE
F5F6EEF5F6EEF1F2EEF1F2EEFFFFF8FFFFFFF5F6F0F5F6F0E4F4FFF7E7E8F2D5DBF2DDEFF3F2F8\
F7F2F8F7F6F8F7FFF8F3F6F4F7EEF7F7EEF7FFFFEFF7F6EFFFF6F8F7F6F8FFFFFF
F7FFFFF7F7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF4F4FFFFFFF7FFF8F7FFF8F7FFF8FFF6F4\
F3F6F8FFFFFFF7F7F8FFF7F8F3F4F4F3F7F8FFEFF0FFF4F4F7E5CEE3BBA3DACCBE
FFFFFFF7EFF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8E2D4DE
90878CB9BEC58E787A596B7BAA9B95FFF7E7F7F4EDF7F7F8F7F7F4FFFFFFFFFFFFFFFFF7FFFFF7\
FFFFF3FFFFF7FFFFF3FFFFFFFFFFF7FFF7EFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7FFFFF7FFFFFFFFF4F4F3F7F8F7F4F4FFF7F8F7FFFFFFF4F4FFF7F8F7E7F0F7E4F4\
FFF7F8FFFFF3FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFE5EFFFE5EFFFFFFF
FFFFFFFFDDE7E3EFF8E3EFF8FFDDE7FFF6F8EEECE5EBCDCCF3EFE5F7EFE5FFF6EEECEBE6EAE0E2\
F1E0E1EAEDEDF2EDECFFFFFFF5E8E8F1EFEFF5ECE8FFF2E9FFF6EEFFF2EEFFF6F8
F1E5E7F5E0E1F5ECEDF5F6F8F1F2EEF1F2E9F1F2E9F1F2E9F7EEF0E4F3F0FFEEF0F5E1ECF3FFF8\
F7FFF4F3F2F8F3F6FFF3F6FFFFF2EDFFF6EFFFF6EFFFF6EFF7F2FFF7F6F4FFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF4F4FFF4F4F5FFFFF5FFFFFFFFFFF3FFF4F3F2FF\
F7F2F4FFFFFFFFFFFFF7F4F4F7F4F4F7F7F8FFF7F8F7F7F8F7EDEEF7EEE5D1AE9B
FFF7F8F7EFF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F4F48D828A
908F84CBC2B9DECDC6383E4EECE5F0FFF7EFF7F7F8FFFFFFFFFFFFFFFFF3FFFFF7FFFFFFFFFFF7\
FFFFFFFFF7F4FFF7F4FFFFF7FFFFF3FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF7FFFFF7FFFFFFFFF4F4F7F4F4F7F6F8F7ECEEF7FFFFFFF4F4FFEDEEF3F7F8F3EDEE\
FFF7F8FFFFF3FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFE5EFFFE5EFFFFFFFFFFFFF
FFFFFFFFDDE7FFDDE7FFDDE7F7D5D7EBD1CEEEC5D0FFD5D7ECDDDFEAE0E2F1E0E1EAE5E5F3F4F4\
FFFFFFF7F7F7F7F7F7FFFFFFF5EFEFF1E8E8F1E8E8F1E8E8F1E0E1EAE7E8EAEDED
F5EFEFFFFFFFFFEFEFFFE8E8FFE8E8FFEFEFFFFFFFFFFFFFF1F2E9ECF6F0ECEBE9F7DDE7EBE8F7\
EBEFF8FFF6F8FFFFF8FFFFFFF7F6EDFFFFEFFFFFEFFFF6EFFFF6FFF7FFF8F3FFF8
F7F6F8FFF6F8FFF7F8FFF4F4FFF4F4FFF7F8FFF4F4FFF4F4F5FFFFF5F7F8FFF7F8F3FFF4F3F6F8\
F3F6F8F7FFFFFFFFFFFFF7F8F7F7F8FFF7F8F7F4F4FFFFFFFFF7F8F7EFE7E2B596
EEE5F0FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8C8B0C47E796C
D6D1CDD1CACE66748D909792FFF4E1F7F7F8FFFFF7FFFFF7FFFFF7FFFFFFFFFFF3FFFFF7FFFFFF\
FFFFFFFFF4F4FFF7F8FFF7EFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF3FFFFFFFFE5F8FFECF8F7F4F4F7F2F4FFEBEEF3F7F8F7F4F4F7FFFFF3FFFFF3F7F8\
FFEDEEFFFFF3FFF7F8FFF7F8FFF7F8FFDDE7FFDBE8FFE5EFFFFFFFFFFFFFFFF6F8
FFF6F8F7F7F0EBEDE2EBD1D0F7C8D0F3CCCDFFE0E1F5E4E5F2F3F4F7E0DBEEC2C4EBBBBEEBD9D6\
EBDCDEF2D4D1F5E0DBFFE8E8F7E8E8EBE7E8EBE7E8F3EDECF7F7F7F3F4F4F3F4F4
FFFFFFF7F7F8F7F7F8F7F7F8F7F7F8FFEFEFF7EDEDF7F7F8F5F6F0EAF7FFFFE6E9FFFFFFF7EEE7\
F7EFF3F7EFEDFFF6FFFFFFF4F7F6EFFFFFEFFFFFE8EEFFE8EEF6EFFFF6EFF7FFF4
F7F6F8FFF6F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8F5FFFFF5F7F8FFF7F8FFF7F8F7FFF8FFFFFF\
FFF6F4F3F3F4FFF7F8FFF7F8F7F7F8F7FFFFFFF7F8F7F7F8F7F7F8F7EDEEEAC8A6
F7E5DEEEE4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2DCEE8D8086A0A58D
C7CBD5D1C8CC000B28F3F4EFFFF7E5F7F7F8FFFFF7FFFFF7FFFFF7FFFFFFFFFFF7FFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFF4F4FFF7ECFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7FFFFF7FFFFFFF7E4F4F3F6F8F7EEF0FFF6F8FFF6F8F7EBEEF7EBEEF7F2F4F7F2F4F3ECEE\
FFEFF0FFFFF3FFF4F4FFF7F8FFF7F8FFDBE8FFF6F8FFF2F4FFF2F4FFF2F4EEEFE7
EBC9D6F7C8D0F3D4DBF7D5DEF3E8E1ECE5DFEAF7F8E2E6E2EED9D6EEC1C5E3D4D7E2D9DEE2BAA7\
EEB295D1B7AEE2AAABFFAAB4F7BAC5D6BABCD1A8ACE4AFB5F2AEB6F3C2CBF7E8E8
F3F4F4F7F7F8F3F3F4F3F3F4F7F7F8F7F7F8F7F7F7F7EDECFFEFEFF7EEF0F7E6E9FFEEF0FFE6E9\
FFFFFFFFEFEFF3EFEFF3F2F8FFF2E7FFF6EFF7F3ECF7F7F7EEFFFFFFF2EFF3F6F8
F7F6F4F3FFF4F7FFF8FFFFFFFFF7F8FFF7F8F5FFFFF5F4F4F1F4F4FFFFFFFFF7F8FFF7F8F7FFF8\
FFF6F4F3F3F4FFFFFFF7FFFFFFFFFFF7F7F8F7F7F8FFF7F8FFFFFFFFF7F8ECD5C5
F2D1B4FFEFE5EEE4EEFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8EBE4EE998F95A39884BAB6B2
C8CCCECDDCE51D2838FFDDE7F7EEF7F7F7F8FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFFFF7F7F8\
F7F4F4FFF4F4FFF7F8FFF4EDFFF7F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF3FFF7F8FFF7F8F7F4F4F3F4F4F7F2F4FFFFFFFFFFFFF7F7F7F7F7F7FFFFFFFFEEF0F3E4E6\
FFF7EFFFF7F4FFF4F4FFDCE5FFDBE8FFEFE7F7F7F0F3E6F4EBE0EDEBC5DBEBC5D4
F7D5DEF3E8E1E3D9D3E4E0DDECF6F8E2ECEEEBC2B6E3A79FEAAAA9EAC0BAF3D1C4E4DBCAE59F94\
E39576E2E6DEF7EEE8DEF7E2EEE5D6CEB9B1D8B29CD8F4DCEBE4CEF7BDBDF3B8BD
C8D1D6C8EFEDE2D4DCE3D4E5F3ECF8EBECEEF7F7F8F3F4F4F7F7F8F7EFEFF7FFFFFFFFFFFFEEF0\
FFEEF0FFFFFFF3EFECF3E5F4FFF6F8FFF6EFF3ECF4F3F4F4FFFFE8FFF2FFF3F2FF
F7F6FFF3F6F8F7F6FFFFF3F4F5F4F4F5F4F4F5F4F4F1F7F8F5F7F8F5F4F4F5F7F8FFF4F4F7FFFF\
FFFFFFF3FFFFF7F7F8FFFFFFFFF7F8FFF4F4FFFFFFFFF4F4FFFFFFF7F7F8F7EFE7
E2C0B4E5E5CDEBEBF8EBE7F0EEE4F4F7EDEEF7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8BDA6BC8F8A89C8C3BCBEBABD
EBE4E57E8C9566717BFFE5ECFFE5F8FFFFFFFFFFFFFFFFF3FFFFF7FFFFF3FFFFF7FFFFFFF7F7F8\
F7F4F4FFF4F4FFF7F8FFF4E8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8
FFF7ECFFF7F8FFF7F8F7EFF0F3F7F8F7F2F4F7F7EFF3F4E8F7F7EDF7F7EDF7F7EFF7E6E9F7F4ED\
FFF4EDFFF4F4FFE4EDFFE6DFF7F3EEF3D1D6EED4DCF3F4E8FFDDE5FFD5D7F7E0DB
ECCBCBDEC8C5C7C5C1DAD5CEE5C8C1EAE4D3E2BDAFF3D1CBE3EFF4D8E8EDD8E8F4F7EEECF3E0D6\
EECCB6EEE5DBD1ECF8F7FFF8ECF7F8DAD1BDEAC1B2F3E6F4D1ECE8DEF7E9EEC3B6
C4C8BDC4CCC3F5D1D0F7D5C6CED1DEA4F4E8B3E6E2F7E5E7F7F7F8F7F4F4FFE5E5FFF7F8FFFFFF\
FFEEF0FFEEF0F7FFF7F7EFF3FFECF7FFF6EFF7F3ECF7F3ECFFFFFFFFF2EFF7F6FF
F7F6FFF7F2F8F7F6FFFFF3F4F5F7F8FFF7FFF1F4FFF5F7FFFFFFFFF5FFFFF5F7F8FFF7F8F7F6F8\
FFF6F8F7FFFFFFF7F8FFFFFFFFF7F8FFF4F4F7FFFFF7F4F4FFFFFFF3F4F4F3F4F4
F7E4DEEACEA6F7F6F8F7F7F8FFFFFFF7F3F4F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EFF08F808DBCC5B4C4C8C0DECFD1
E2DDDF696970A8B2C9F7F7F4FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFFFFFFFF3FFFFFFFFF7F8\
FFEDEEF7FFFFF7F4F4FFF4E8FFF7F8FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7F8
FFF7ECFFECF8F7ECF8FFF7F8F7F6F8FFF6F8F3F4E8FFFFFFFFEFF8FFE8F4F3E5E1F3E0E3FFEFE5\
FFF7F8FFDCE5EED5D6E6E0E1F3CBDDFFDDE7F7E5F8F3DBF4FFD5DFC7C3B6BDC8C0
D8DCDBF7EFFFE2DCE5E3D9E1F7C3ADDAE4DEF7E5E8F2A199F79C85DE9885DE9885F7A690F3BDA7\
F7CCABF7D4B2F3EDD4D1EDEEEAF4EED9E0D6ECD1C9F7EEF4D9EBF8DAF6FFF3BDC0
CECCC1D0CAC1FFE5DFEBD4C3D9CBCEDAC8CFCEE1E5C8D9DEEEF7EFFFEFEFFFE8E8FFF4F4FFFFFF\
FFEEF0FFFFFFFFEEF0F7FFF7F7E0F7FFF6FFFFF6EFF7EEECF7F7EDFFF6E8FFF6FF
F3F2FFF7F2F8F7FFF8FFF7F8FFF7F8F5F4F8F1EDF8FFFFFFF1F4F8F1F4F8F5EFF8FFF7F8FFF2F4\
F7F2F4F7FFFFFFF4F4FFF7F8FFF7F8FFF4F4F7F7F8F7F7F8FFFFFFF7F7F8F7EFF0
FFF7F8F2D1AAEAE5D7EBE4F4EEE4F4EEE5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8BEBAC5B4A6A6CED9D0B7B6B9EAD9DB
7A8A9F62737DD1DCE8F7F7F8FFFFFFFFFFFFFFFFF7FFFFF7FFFFF3FFFFFFFFFFF3FFF7F8F7EFF0\
F7F7F8F3F6F8F7EEF0F7E8DCFFFFFFFFF7F8FFF7F8FFF7F8FFFFF7FFFFF3FFFFF7
FFEFE5F7ECEEFFF6F8FFF6F8EEEEE7F3E5E1ECD9DEF1D4DBF1E0E2F2E5E5EECCCFF7E5DFFFE4F4\
EEC2C1E6A0A7EEC3C5FFCDD7F7D1D3D9E8D0C4D1B97F887E3F5F6699BACDC18186
C36A74E3B5B2EBDCEDE5CCCDDECFC4ECDDDFF1DBDCFFFFFFEAC0C5D9938AD67362CB6651CB7163\
D19C91D8B0A3CED4D4CBCBC5EBAAA8F5C8CBE3D9CCFFB5A8FF9F97FF9185EB9791
E2DBD0D8DCCBDEEBE2F1ECDDF7D4C6D9AAACF7B6BDD9CCD7C4EDF4B2EEE5C8DCD5F7D9DBFFDCDC\
F7D4D3F3F7EDF7FFF8F3ECE7F3F7F3FFEFF7FFFFEFF7F7F7F7F7F7EEFFFFFFF2EF
F3F2FFFFF2F4FFFFFFFFF4F4FFFFFFF5F4F4F1EDEEF5F7F8FFFFF8FFFFF8F5F7FFF5EFF8FFEEF0\
FFF6F8FFFFFFFFF4F4FFFFFFFFFFFFFFF4F4F7F7F8F7F4F4FFF4F4FFF7F8FFF7F8
FFF4F4EAE4CBFFD4C6D6C9CFE3D9E2FFE8DCFFEFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6C6D6A7A89BE2E8E9B0B5A8A4A3A7E5EDED
2C5A69C8BDBCFFFFF3FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFF3FFFFF7FFEDEEF7F7F8\
F7FFFFF7F6F8F7EEF0F3E8DCFFF7F8FFFFFFFFFFFFFFFFFFFFFFF7FFFFF3FFFFF7
F7E8DCFFFFFFFFF6F8EEEEEFF7E6E5FFEFF8F1F2F4FFF7EFFFEEE7E4CDD0F3E0DBFFEFF0EECBC5\
E3BAB5F1CAD4D9DBD0A3BDB2A7D0C5E3ECECEBC2B49951566A2E3D61405BDA8F8D
EBBDB2D19785D69797E28085E69297E6A7A7E3B6B4F1CAD4E28486F7C3B6FFF4EDFFFFFFFFF7EC\
F7EEF0F7EEF0F3D1CBE58C86F78584F38F83F39E8BCB8C85D98079E28B7DD1A69F
DEEDDDF5D4DBE2BEAFFFDCCCF1ECE6DEE0DCEEE4E1F7F7F8F3EFF0F5DCDEC7EFF4C5DDDEE2F2EE\
F7E4EEF7CBD6F7DCDEF7D5D7F7ECF0FFE8F3FFFFEFFFFFFFEEEFF8EEECF8F7FFEF
FFFFF8F7F6F8FFFFFFFFF4F4F5F7FFF5F7F4F7F7F7F7F7EFFFFFF4FFFFF8FFFFFFF1F4FFFFF4F4\
FFFFFFFFFFFFFFF4F4FFFFFFFFF7F8FFFFFFF7F4F4F7F7F8FFFFFFF7F7F8F7F7F8
FFFFFFDEEFE1EEE0DEEAF4CBE3E5F8D1D9DDDACCC6FFEDE5FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA49CABB3B6AFDADDD7938F82CAC5C97B92A7
5A6C6CF7E5F4FFFFF7FFFFFFFFFFF7FFFFF7FFFFF3FFFFF7FFFFF7FFF7F8FFF4F4FFEDEEF7F6F8\
F3F2F4F3F2F4FFE7E9F7F7ECFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFF7
F7E8E2FFF6F8EEEEEFF7E6E7FFEFF0F5F6F8F5EEE7F7F7E8F2F2E5EACFD1F7E7E5E29FA4E297A7\
ECB9C3B5B6B94A8C9C8CBACD9D9FA4D6A7A9CEA0A4D1C8C4BDA9A4C8A095F7E5D7
FFFFFFF7D4C7F3BBA7F7C8B6FFE6D1FFC8BDEEAE9CEB979BEB8F86FFF4EDFFFFFFFFF7F8FFF7EC\
FFFFFFF7EBE9F7EBE9D9D4D0E3EFF8ECF4E5E3E5F8FFF6F0E2EDF8E3E0DEE3AEA7
E38F84E5A08BCDE5E2F2AEA9F7C3B9DAD1CBD9ECF8E2E5E1EEE4E1E4CFCBCEE8F4ACEFF7D1E6E7\
ECFFF8F3E0E5FFFFFFEEF4EDFFE0E3F7E8F3F7FFEFFFFFFFEEEFF8EEECF8F7FFEF
FFFFF8F7F6F8FFFFFFF5EDF4F5F7F8FFFFF8F7F4F3FFF7F7F7F7F7FFFFF8FFFFF8F5F7FFF5EDF4\
FFFFFFFFF7F8FFF7F8F7F7F8F7FFFFFFF7F8FFF7F8FFFFFFF7F7F8FFF7F8F7F7F8
FFFFFFE5F7EDE5DBE2F3E4C4D8D1DFDACCC6E3EEE5D1CDE5DED1DEEEE5F0FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8A7984D1D1C4D6D0C89F9DA1F2F7F449657B
B3ABA3F7FFECFFFFFFFFFFF7FFFFFFFFFFF7FFFFF7FFF7F4FFF7F8FFF7F8FFF4F4FFF7F8F3F2F4\
F7F6F8F3F2F4F7E0DBFFFFF7FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFF3
F7E8E9F7F2F4F3F4ECFFE8EEF5F6F8F5EEE7EEEFE7F7EDEDF2F2E5ECDCDEE2A8B4D9A0A4CED1CB\
ADC8C9A3E5E7B5C5D4505A73999095E3D9D5F7D0C9FFF2E9FFEDE5FFE0D0FFFFFF
FFFFFFFFFFF7FFF7F4FFF4F4FFF7F8FFFFFFFFF4E8F7D3C5F7D3B9FFF4F4FFFFFFFFFFFFFFF4E8\
FFFFFFFFF6F0FFFFFFF3E0D0FFF4DCF7EEF0FFFFFFF7EEF0FFFFFFFFFFFFFFFFFF
E3EFF8F3A8A3CA8F91E2D9DEE2EEF8D1E0E6E3E5D7DEDCDFF7EEF8B9B6B3DAF4F8C4F4F4BFF3F8\
C7DDDFF5EEF0F3E0E5F3E5E5F3DBDBEBEFECF3EFFFFFFFEFEEFFFFEEFFFFFFF6FF
F7FFEDF7F6F8FFFFFFF5EDF4F5F7F8FFFFF8FFF7F7F3F7F7F7F7F7F7F7F4FFFFF8F5F7FFF5EDF4\
FFFFFFFFF4F4FFF7F8F7FFFFF7F7F8FFF7F8FFF7F8FFF7F8F7FFFFF7F7F8FFFFFF
FFFFFFFFF4F4EAECE1F3D1B3E3DCEEE3E4F4D1C8E2E3D5DFECE6EFDED1DEFFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6D5A5BACBBB6CECCCED1CDD3BCD4E13D4C5B
ECE5F0F7F7F4FFFFFFFFFFF7FFFFFFFFFFF7FFFFF7FFF7F4FFF7F8FFFFFFFFEDEEFFF7F8F3F2F4\
F7F6F8F7ECEEFFEFE5FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFF3
F7E8E9F7F2F4F3E5E1FFEFF8F1EBE5EEEFE7EEEFF0EBE6DBF3E0E8EAB2BDC79FA3B9C2C3B0C6D4\
CED9EEF7D4E2BFC2CDAD7C73DEDCCDF3EFE5FFF3EEFFFFFFFFEBE3FFEEE8FFFFFF
FFFFFFFFFFF7FFFFF7FFF7F8FFF7F8FFF7EFFFF7EFFFF2E9FFF2DCFFF4F4FFFFFFFFF7F8FFF7EC\
FFFFFFFFFFFFF7EBE9F7EDDCFFF4DCF3E6E2F7EEE7F3E6E9F3E6E9F7EEF0FFFFFF
FFFFFFE4CFBFEBA0A4E27777F37F77E39A8DD1DDCEFFD4D0E2C8C4CBAEB9D8E0E9CDD9DEBDEFE5\
ACE6E7C7DDDFE4FFF4EAE0E6F7D4D6F7FFEFF7E8EFFFF6FFFFF6EFFFFFFFFFF6FF
F7FFEDF7F6F8FFFFFFF5F7F8F5EDF4FFFFFFF7F7F4F7F7F7F7F7F7FFFFF8F7F7EDF5F7F8F1EDF8\
F5EFF8FFF7F8FFFFFFFFFFFFFFF4F4FFFFFFF7F7F8F7FFFFF7F7F8F7F7F8FFFFFF
FFFFFFFFF7F8ECEFE5FFD9BDF7DDC6E3E5F8FFF7F8DAD4E5D8CFE1F2EDE5EEE4F4FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7EFF0F7EFF0F7EFF0F7EFF0F7EFF0F7EDEEFFF4F4FFF7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFEEE5F8625345B0BBBDE4E4E5ECE4E5A9B2C14F4C55
F7EFE5FFFFFFF7F7F4FFFFF7FFFFF7FFFFF3FFFFF7FFFFFFFFFFFFFFF7F8F7EFF0F7F7F8F7F6F8\
F7F2F4F3E0E3FFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
F7E0E3EEEEE7F7E1E5F5F6F8F5ECE1E6EDEEFFFFFFF7EEEDD9BDB9BDB0B9AAC1CEC6D1DED9EFEC\
EAD4E2E2BACEB19FA4BEA89FD9EFF8F7ECE8FFF2E9FFF6F0FFF6F0FFF6F0FFFFFF
FFEEE8FFEEE8FFFFF7FFF7EFFFF7F8FFF4E8FFEEE8FFECE6FFEBDBFFF4EDFFFFFFFFF7F8FFF7EC\
FFFFFFFFF6F0F3E4D7FFE5D7FFE4D0F3E6DCF7EEE5F7EEF0F7EEF0FFFFFFF7EEF0
FFFFFFECD9CBF3EBDEEEE5DDC2D1DBC4A7ABB57970D1A094F5E4E8EBD4DFC1EFE5D6E5DDD9E0E8\
90C9DE7EB2C6D9DCE5E4E5E5FFCBD7EBD9DEFFDDE7FFE5EFFFF6FFFFFFE8FFF6E8
F7FFFFF7F6F4FFFFFFF5F7F8F5EDF4F7F7F7FFFFF8F7F7F7F7F7F7FFFFFFFFFFFFF7F7EDF5EFF8\
F5EFF8FFFFFFFFF7F8FFFFFFFFF4F4FFF7F8F7F4F4F7FFFFF7FFFFF7F4F4FFFFFF
FFFFFFFFFFFFFFF4EDEAE0E2F7EDC8F3E0DBDAD5E7EEEEFFF7F6F8EBECF8FFF7F8EEE4F4FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7EFF0F7EFF0F7EFF0F7EFF0F7EDEEF7EDEEF7EDEEF7EFF0EEECF8E6E0F8EEE4F4\
FFF7F8FFF7F8FFF7F8FFFFFFD6C6DE838069A8B2AEEAE5E7F3ECEE727C947B7C7E
FFF4E8F7F7F8F7F7ECFFFFF3FFFFF7FFFFF3FFFFF7FFFFF7FFFFF7FFF4F4F7F4F4F7FFFFF7F6F8\
FFF3F4F7EDEEFFFFF7FFFFF7FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFF7FFFFF7
EBD4D7F7F7EDFFE8F4F1EBE5EEEFE7F7DCEEF7E4F4D1AEC3C4C1CED0D4E6DAE5E7ECFFF7F5F7F7\
D8C2C1D6D4DEA8A4A3EBD5D6EBDCDBF7E0CBFFFFFFFFEEE8FFF3EEFFF2E2FFFFF7
FFE6D7FFE6D7FFFFFFFFFFF3FFF4F4FFF4E8FFE6DEFFFFF7FFE6D7FFF4E8FFFFFFFFFFFFFFF4E8\
FFFFFFFFEBE3F7E5DBF3DCE5F3CDC4F7E6D6F7EEE5F7EEF0F7EEF0FFFFFFF7EEF0
F7FFF8F7E0D6D8F6DCCBE8FFD9EFF8E2EFF4C8D5DF997367CDA0A5DEC1D4B492A3BCAAACC6E4ED\
D0E5EF6BD5E787BBCFC7DDDFEAE0E5EBE7E5F3C8D6F7EFEDFFEFF7FFFFEFFFFFFF
FFF6EFF3F6F4FFFFFFFFF4F4F1F4FFF7F7EDFFFFFFF7F7F7FFFFFFF7F7F7FFFFFFF7F7F4F5EFF0\
F5EDF4FFF4F4FFF4F4F7FFFFF7F7F8FFFFFFF7F4F4F7FFFFFFFFFFFFF4F4F7F7F8
F7F4F4FFF7F8FFF4F4F7EEE5EADCD7BEC2C4B5A8ACD1C8D1D6CED6D1CDE5F5F7F8FFFFFFEEE4F4\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFF7EFF0F7EFF0FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8EEE5F8E6DBF4EEE4F4\
FFF7F8FFF7F8EEEEFFD6CDE5ACA095959584B1AFABEADCDEC7CCD6434E60C8C2C6
FFF7F8FFFFF3FFFFF7FFFFF7FFFFFFFFF7ECFFF7F4FFFFF7FFF7EFF7EFF0F7F7F8FFFFFFF3F3F4\
F3EEF0F7F4F4F7E8E9FFEFE5FFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFF7ECFFEDEE
E6C9CCF5D9D6F1E0E2F5ECE1E6EDEEF7EEFFF7DDF0A8799DEEEFF8E2E4EEDAE4E5ECF7EFF2F4F4\
C3C1BCB3B6CBCEDCD3F5C2CCEBD4D0F7C8CBE6968BEEB2AEFFE5DEFFF6E7FFDCC4
FFD9CCFFDDCFFFEEDFFFFFF7FFF7ECFFE5CEF7CBC6F3D4DDF7D4CFFFE5CDFFF4F4FFF4F4FFEEDD\
FFEBE3FFDDCFF7DDDFEBE4ECEED5D5EBC2ABF3E0D0F7EEF0F7EEF0F7EEF0FFFFFF
F3E5D6E2CCC5F7D4BDD9EFF8DAEFFFFFFFFFE3EFF8C2B9BCC28178AB7E7FA388914F4A637B7790\
5B8095687C8DBEE5DE3DB2D06AA9BED0ECE8E4CBCEE3C5C1F7D5D6F7ECF4F7F6E1
FFF6E8F3F6F4FFFFFFF5EDF4F5F7F8F7F7EFF7F7F7FFF6F8FFF6F8FFFFFFF7F7F7F7F7F7FFFFF4\
F5F4FFF1F7FFF5F7FFF7F7F8F7FFFFF7F4F4F7F7F8F3FFFFF7FFFFF7F7F8F7F7F8
F7F7F8FFF7F8FFF7F8F5F4ECE2EEE9D1C8DCB0ABA07F7869ADB2A7D1CBC5D1CBDDE5E7EDEBE4EE\
F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFF
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFEBE4F4D0CCDE9C9674AA9EA1C5CAD7F7F7F46E839B7B8384F7F7EC
F3F4EDF7F7ECFFFFF3FFFFF3FFFFF7FFF7F8FFF7F8FFFFFFFFF7F8F7EDEEFFFFFFF7FFFFF7EDEE\
F7F4F4F3EEF0F7F2F4F7E0D6FFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF7ECFFEDEE
E6CFD1E2D9D0EEE5DBF7EDE8E3F4E9F7F7F4F7F7EEAA8899C2C6DBDFE1EDD1DDF0DAE4E5E3F7EF\
B4BEC8A8A9AEF2EBF4F1CCD6EED5CFE3D4BDF5E5E8EBBCCBF7D9D4FFF4E8FFD9E2
F7EBF4F7DDE8FFDCCCFFF6F0FFFFFFFFD9C5EBD1D6F3EDE2F7DBEEFFEED5FFEEDDFFF6E5FFEED6\
FFE6DDEED5CEF3CBDBF3E4EDF7F7F4F7E0E8F7E4D6FFEEDFF7EEF0F7FFF8F3FFF4
EBCDBDEADCCDDEB59CE2EDEDDAEFFFDAEFF7E3F7ECE2EDE5ECD9CEF7EFF0ECE5EDCECDC89A8E9A\
A29AA78FA2B64F6D8389B6CB8CD9E5DAD9E5E3E5ECE2D9DBEED4D0EEE0E5F7F6ED
FFF6EFF3F2F8FFF6F8F5EDF4F5F7F8F3F4ECFFFFFFFFF2F4FFF6F8FFF6F8F7FFFFFFF7F7F7F7EF\
F5F4F8F1F4F8F5F4F8FFFFFFFFF7F8F7F7F8F7FFFFF3F6F8F7F6F8F7FFFFFFF7F8
FFFFFFFFF7F8FFFFFFF5EDEDEAEBE2D9D0E599989D958E94B9BFCEE3E6E5F3EBD3EAE6D5EAE4EF\
E2D9E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFE2D4DEAC989B6E715EACA8AAEAECEEE3EEFF3F5D70C2B2AEF7E4E8
F3ECF8F7EEFFFFE5F4FFFFF7FFFFFFFFFFFFFFFFFFFFEFF0FFE8E9FFEFF0F3F6F8F3F3F4F7F4F4\
F7EDEEF3F2F4F7F6F8F7E0D6FFFFFFFFFFFFFFF7F8FFF7F8FFFFF7FFFFF7F7E0E3
E2C6C1DED9D4E6DCD1F3E8E8EBF7E9EEF7EEEEE5DED9AFB5C3AEA9BCC1B2BABBBDB5B2C7D6E0E5\
C5C8D6B7C1B9EAF6F8ECDBE5F5E7E5F1E7E5F1FFE8F7D1DEEBCCCEEEDDDFFFDBF4
EBE5D4EBDCDBEECAC4FFECDBFFE6D1EEC1B4EEE5EFE6E8D6FFE5F8F7E4EDF3E4D3F7D1D0EEBEBD\
E6B2BEEEB6C4F7D1D6F7D5D6F3D4DBF7D4E5EED5DFF7E0D4FFEDD6F7F4E1EBE4DB
E3B9ABF2CBD7E4A5ABEAECD5DAEFF3F7F7EFF7F7F8ECDCDEE2DCDEF3E8DCFFFFFFFFF7ECCBE0EE\
D8F2FFE2F3F899929FB9BBC1F7C8D4D0EEF0E3E5F0DAD5DFDEC2C3FFD4DEF7F3F7
FFF6EFF3F6EDFFF6F8FFF7F8F1EDF4F7F4ECF7FFFFFFF2F4FFF6F8FFF6F8F7FFFFFFF7F7F7F7F7\
F5F7F4F5EFF8FFFFFFF7F4F4F7F4F4F7F7F0FFFFF8FFF6F4F3F6F4F7FFFFFFF7F8
FFF7F8FFF4F4FFF7F8FFF7F8F7EEE5EEFFEDD1C8BFC8C2B6EBEBDBF3F2E1F7F6EDF3F3E5E6E0CB\
D0C2CEEEE5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
E3E5F8CABAD48F868D706B59748682C6CCD7D9EFF8C3DBE239475BF3ECDBDAE4E8
FFDBF4FFE5F8FFE5F4FFFFF7FFFFFFFFFFFFFFFFFFFFEDEEF7F7F8F3F6F8F7F6F8F3E0E3F7F7F8\
FFECEEF7F6F8F7F6F8F7E0D6FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F4F7E0E3
EAC3C4DED9D1EED4CDF7FFF8EBE5DFF3DCDFEADDDEF1E1E2F5C1CFF5BCC5E2AFB2AD8A918E8F8D\
B0B5B3D1E4DEF3EFEFECE4F4F5EFF8F5EFF8F5E8EFF5DDE1F5D9D6EEBAC7E6B9C1
EED1CEFFCCDBEEA0ADE6BDC0E6BDC0EEA9B5FFD4D6EEE6D7EBEDE2FFE5F0F3E6FFF7DDE7DAB2AC\
EABAC4F1DBDCF1E4E5F1D4D5ECE0DBF7D5D6F7D4DBF3D5D6F3CDD0F3CFD1ECC9CC
ECB2BCEBDCE5E2AEB6EBC6C9F3F4F4F7F7F8F7E5E7E2CBBDFFF3E5F7EFE5FFFFFFFFF4E8D9ECF4\
F5EEE7D9F6EFCECFD1E2DCDBCDA4BAEEF4F7CDE0E5D1D5E8C8CCCDEABDC5F3E4EF
FFECF8F3F6EDFFF6F8FFFFFFF1E8E9F7F4F3F7FFFFFFF2F4FFF6F8FFF6F8FFFFFFF3F4F3FFFFFF\
FFFFF4F1EDF8FFFFFFF7F7F8FFFFFFF7FFF8F7FFFFF7F6F8F7F2F8F7F6F8FFFFFF
FFFFFFFFF4F4FFF4F4FFFFFFFFFFF3F3E6D7F7EFD6ECE5E8EAE5DFFFFFF4F7F6EDFFFFE8F3F2E5\
EAE5DBDACCDFEEE5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8D6C6DE\
B59FA3847963787863B5BBB4D8E0E8E2EDEDF7F7F371A7B95D586DE2F4EDE3E4ED
F7E4F4FFFFFFFFFFF7FFFFF7FFFFF7FFF7F4F7F4F4F7EFF0F7F7F8F7F2F4F7F6F8F7E7E9F7EFF0\
F7EBEEF7F7EFF3F3EDF7E0D6FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F4EDF7E6E9
EAC8D1DEC8B9FFDBDCE6E0D6FFEBE5F2E5DEECEFE8EEEDDDEBE7E2EBD9DCEBD9D6F7C1D0ECB2B9\
DEA4A8E49DA2EABCBAF2C9C9FFC3C6F7D1D0F3E8DCEAEFDCF2EFF4FFD1DDFFD1D6
FFE8ECFFECEDF5DDEFF5C1D3FFC8E1FFDDEDFFDDEDFFC8DBF7BDCAE5BEBDDEBBB4EEB6BDEAC8C9\
ECE7E2F5ECE8FFEFEFF7EFEFEAF3F4E4D9DBEAC5D0EACCD6ECCFD6F5CDD1F5CBD3
EBE5DEFFEEF7ECC5D3DAB6B2F7ECEEF7ECEEECD4D6E2D4C9EBD1C5FFF7EFECEEF4ECE4E1F3F4F4\
EBF4E5D2EEEDD0DCDBDAD9DBB7A3B9E2E0DCE3F7EFCFE5E7BFCCDFD0B0BCEBDDD7
FFE8EDF7F6EDF7FFFFFFF6F8F1E8EEF7F4ECF7FFFFFFF6F8FFF2F4FFF6F8FFFFFFF3F4F3FFFFF8\
FFF7F8F5F7F8F5F4F8F7F4F4F7FFF8F7F6F4F7F6F8FFF2FFF7F6FFF7F6F4FFFFFF
FFF7F8FFF7F8FFF4F4FFFFFFFFFFF7F3E6D7EAE1BEF5F7F4ECE6E5E4DCD6E2DCD6F7F6F8F7F3EE\
FFF7F4D6D5E5EEE0E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8D6C9DF999074\
7677617D8684B9C6C9E2E0E3F7EEEED9E8E1E4F7F7367186988082F7F4E8F3F4ED
F3F4F4FFFFFFFFFFF7FFFFFFFFFFFFFFF7F4F7F4F4FFEEF0F7F6F8F3F2F4F7F2F4F7F3F4F7F3F4\
F7F2F4F3EDE8EBDBD6F7EDE8FFFFF3FFFFF7FFFFFFFFFFF7FFFFFFFFE4EDF7F7EE
E2CDD0DEBCB8FFE0E8E6D4CBF5EFF0F5E5E5F7F4ECF3E4E2F7EEFFF3ECF8F7E4EDF3E4E1F3D4DB\
F3CFDEEBC8D7EBAEC5EBC3CBE6E8DCF3D1D3FFC3D1FFC8D6F7C2CFF3B7C4F7BDC4
FFC3CBF7D1DBEAC6CAEAB0B8F7BDCAF7D1DBF7D1DBF7D1DBF3E8E8EAEDEDEAEDEDF7D1DBF1C6CC\
F1E5E8F1E5EDF5DCE2ECF6F0F3F7F8F3F4F4FFFFFFFFE0E8F2DBD6DED9D6E6DCE1
F7ECF4F7EEFFF7E5F8E5AEB6EADCDDEADCDDE3CCC6EECBCEEBC3C5F7D4D6E4E6E8DED4D6EEDDF0\
EEDDF0F3F4F4CED9DBE3E0E99DABB3EEC8D1E5EEF8EAF4EDC7DDDFBEB9CEC8BDC3
F7E6EEF7E5E8FFFFF8F7F6F4F1E8F4F7F4E8F7FFFFFFFFFFFFF6F8FFF6F8FFFFFFF7F7F7F7F7ED\
FFF7FFF5FFFFF5EFF8F7F7F8F3F6F4FFFFFFF7F6FFFFF6F8FFFFF8F7F6F8F7FFF8
FFF4F4F7F7F8F7EFF0FFF7F8FFFFFFEAECDBD9C2A8E6DBF4E6E0F8E6E6FFD0C9D0EBEBE9F7F3EE\
DAE5FFF7EFEFDEDCE8EEE5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8938C98616256\
A8AEBCC7D5D6F7ECECEBE5E7EEF7F8E6EDEDEEEFEF254C67C2AEADF7EFE7FFFFF7
F7F7EFFFFFF7FFFFF7FFFFFFFFF7EFFFF4F4FFEDEEF7F6F8FFFFFFF7FFFFF7FFF0FFFFFFF3FFF0\
EEEEEFF7F4F4EBD4D6F7F4F4FFFFF7FFFFFFFFFFF3F7F7EFF7F7EFFFE4EDF7F3F4
EBCFD1D8C1BFFFFFF8E6C1B9F1E1E2F7EEEFF7EBF4F7E4EEF3F7F8F7F7EFFFFFF7FFFFFFFFFFF7\
FFFFF3FFF7ECFFF7ECFFE5ECFFDBE8F7DBE1F3DBDCF3D4DBF3DCE3F3F4E9EBEDE2
E6E8DCF3D1D3F7D4D6F3F4E9EBEDE2F3D4D6F7DCE5F7D4E2FFD5DFFFD5DFFFFFFFF7E5F0EAE4F0\
EAEDEFEAEDEDEAEDEDECE5DFF1F2E9F1F2E9EAEEE8F7EDEDEBF4E7FFE5F8F7E4EE
EBF4EDE6F4E8EBF7ECEEC5CBF3D4D6F3D4D6E3C3C5F3DCE5EED4DBEBC8C5ECE5E5E2D9D0EBDBD7\
EBE0D7FFF2F8C4C9C8FFECE89DABB3E6C1D1E5F3F8D6EBF8D1EEEFC7CCD6B5A8C5
D1CBC2F7E8F3FFF2F8F7FFF8F1EFF8F7E6E5F7F7F7FFFFFFFFF6F8FFFFFFFFF6F8FFFFFFF3F4E8\
FFFFFFF1F4FFFFF4F4FFF7F8F7EEF0F7F6F8F7F6FFF7F6F8FFF6F8FFF6FFF3FFF4
F7F7F8FFF7F8F7F4F4FFF4F4FFFFFFE4F4E8E2C2B4DACAC1FFF7EFFFF4F4D8CDDEF2E8E1D6D5E5\
FFF7F8D9DCF4DEE1E5EEE0E5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F0E6DBE9D6C6DB3B302D9A9895\
D1DDDFE5ECF4D6ECEDD6DCDEE5F4F4E6F4ED8FB2C43B4656E3DDD6F7E4E8F7E4F4
FFFFF7FFFFF7FFFFF7FFFFF7FFF7F8FFF4F4F7EDEEF7FFFFF3F6F8FFEEF0F3EBF8F3F2F4FFF6F8\
F7EEEFF3ECECEBE4E5FFF4F4FFFFF7FFFFFFFFFFF7F7F7F8FFFFFFF7EFF0F3EEF0
F3DBDCE3D1CEE3DDCEEED9D3E2C3BDF3E5E7FFF2F8F3E7E5FFEFE5FFF7F4FFFFFFFFF7F8FFF4F4\
FFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFF4F4FFF7F8FFFFF7FFE5ECFFD4E1FFCFDC
FFCFDCF7CFD6F7CFD6FFCFDCFFCFDCD9D4D3E2ECDBF3C8D0F3CDD4E2D4D0E2BCB9F3C3C6F7C3CB\
FFC3D1FFC3D1FFC3D1F7BBC8F7BDCAFFC3D1EAC9CCDEE4DBDEEBDBDED3CCE3C9C9
D6D4C6D6E0D0EBEDE1F7ECEDFFD4E2EEC6CBEEDDDFFFFFFFF7DDE7E5BBBEEBD1BDEED4C3EBC3CD\
EBB6C4D1AEABD1BBB6F3C2CBA2C4CEC6BBD1E5F7F4D6ECF4D1E5E7ECD5D7D1EFF7
ACA0ADC8B0B4F7F6E7F3F2F4EAF3F4FFEDF4F3F4ECFFFFFFFFFFFFFFF2F4FFF2F4FFFFFFF3F4EC\
FFFFF8F1EDF8FFF7F8FFF7F8F3F7F8FFFFF8F7F2EDF7F6EFFFF2FFFFF6FFF7FFF4
FFFFFFF7F7F8FFFFFFFFEFF0FFF7F8ECF7ECACC1C8766D6E62524EAD9399E2D9DBE2ECF4FFFFF8\
DEE7F3F3EFEDDEDBEDEBE5EDF7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6DBE9FFFFFFD6C6D22C331CEEEFF0\
DAE5EFD6E4ECCEEDEDEAF4F8EAF4F0E5EDEC677F96837973FFFFF7FFE5F8F7EEF7
F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8F7EDEEFFFFFFF7FFFFF7F3F4FFFFFFFFECF8F7F7F8\
FFF3F4F7ECEEFFF7F8F7F4F4FFFFFFFFFFF7F7F7EFF7F7F8F7E4F4FFEBEEF7F6F8
F3E1E1FFECF4E2DDD3EEEFF0DEC8C0ECE1E1F7EEEEF3E4E8FFF7EFFFFFFFFFF7F8FFF4F4FFF7F8\
FFFFFFFFFFFFFFF4F4FFF7F8FFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFF4F4FFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8DAEDF8DADBEDFFE4E8FFE5ECDAE0F8DAE0F4FFE4F4F7EBFF\
F3E6F4F3EBF8F7F6F8FFF3FFF3E4E8EBE0E1FFCBDEF7CDE5F7D1E1ECE0DDEAF3ED
ECF7FFE4F3F0ECEBE9E4F2E9ECEEE8EBE0E2EBDCDBE6F4E8E6F4E8EBE4EDFFD5EEE3E6EEF5CDDB\
E4E4E5F7DCDDF3E4E6F3DCE8B6EEF0BDC8DBD6F4F8D6CADFD8E7E7F7E5F0F7DDE8
E3D5E89C809DFFEFF7FFFFE8EAEBDEF5EDF8F7F7EDF7F7F7FFFFFFFFEBEEFFEBEEF7F7F7F7F7EF\
FFF7F8F1F4F8FFF4F4FFF7F8F7FFFFF7FFF8FFF2EDFFFFEFFFFFEFFFF2EFF7FFF4
F7FFFFFFF4F4FFF7F8FFF7F8FFF4F4ECF7EC9CBEC8A9B0B4A8AEA7ADA6A3F3E8D1E2ECF4EEF6ED\
EBE4EEE2D4DEF5EFE5F3F2F8F3E8E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDECDDBCFD1D2ABA9A54C4C3CECF4F3\
DEF4F4DFF4F4E3F7F8E3F4F8D2E5EFEEFFFF676476969794FFFFF3F7F7F4FFFFF7
F7F7F8FFFFF7FFE5F4FFE5F8FFF7F8FFF7F8F7F7F8F7F7F8F7F6F8F7F6F8F3E6FFF3EEFFF3F6F8\
F7F6F8FFEEFFFFFFFFF7F4F4FFFFFFFFE5F8F7EEFFF7EEFFF7F7F8F7EBEEFFF6F8
F3E1E1FFF7F8F1EBE5E6E5DEEEE4DEE2CAC5F3E5DEF3E4EEFFFFF3FFF7F8FFFFFFFFF7F8FFF7F8\
FFF7F8FFF4F4FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF4F4
FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFFFFFFFF7F4F7EFE7F7EDEEF7EDEEF3F3F4\
F7ECEEF7EEF0FFFFFFF7FFFFF3FFF0F3F6F8F7E4E5F7EDEFF7DCF4F7CFE3FFC6DB
FFC3DCEAD9E1F3E8E8F1DCECF2D5E5E5ECE8EAEEE6FFDBDEECE0DEECE0E3F7F7F8E2EBF4E2E1DF\
D9D9CFD6D4CFDEE0E2D6D5DFB5CEDBA4BACDABBAD0B5D9E2C4EDF0CACFE9C4C3DD
D1CDE2A3859DF7EFF8FFECEDF3F6E5F1E8F4F7F7EDF7F7F7FFFFFFFFEBEEFFEBEEF7F7F7F7F7ED\
FFF7FFF1F7FFFFFFFFFFF4F4F7FFFFF7FFF4FFF2EFFFFFEFFFFFEFFFF6EFF7F6F4
F7FFFFFFF4F4FFF7F8FFF7F8FFF7F8ECEFE5B1DBE194969BE2E5DB907E73A49A89DEDCE8E6E0F8\
EEE4F4EBE0EEEBE4F4F3ECEEF3E8E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD8C8DBADB2ABC8C3B66D6D6DFFF7F7\
C1E5EDEAECF8EAECF4D2EDEEFFF4F3D2D9E53C5259BEBDC1F7F7ECFFFFFFF7EEFF
FFE5F8F7F7F4F7EEF7FFE5F8F7F4F4F7FFFFF3F7F8F7EEFFFFF7F8F7E0F8F3ECF8F3ECF8F3ECF8\
F3ECF8F7F7F8F7E6FFFFE4F4FFFFFFFFE5F8F7EEFFF7EEFFF7E4F4F3E7F0F7F6F0
F3E8E1FFF4F4F5EBF4E3F4E1EEF4F4DECAC9ECDDD6EBD4DBFFFFF3FFFFFFFFF7F8FFF4F4FFF4F4\
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFF4F4FFF4F4FFFFFFFFF7F4FFFFF7FFFFFFFFF7F4FFF7EFF7E8E9FFF7F8FFF7F8F7F2F4\
F7F6F8F7F6F8F7F6F8F7F6F8F7F6F8F7F2F4FFF6F8F7F7EFF3F4ECF3F4F3F7EDED
FFFFF8F7E5F0F2E0F4F1EBF0F5F6F4F5E6EDF2E1ECF3E8F3F2E1F3F2E1ECF3D9E1F7D9E2FFE0E3\
FFDBDEEBD4CBEBCFBFDEC1BABEBBB59FA1A79DAAAEA3AFB8B0AFB8CBD4CFE3D9DB
DEC9D4D9ABC8EEF7E3F7E7F3F3F6F4F1E8F4F3F4E8F7F7EFF7F7EFFFF2F4FFF2F4F7F7F7FFFFF8\
F7F7EFF1EDF8FFF4F4F7F7F8FFF6F8F7F6F8FFF2EFFFFFFFFFFFE8FFFFE8F7F2E5
F7FFFFF7F7F8F7FFFFFFF7F8FFFFFFFFF4E8D2EDF7898B8BF7ECEDDAD5D66B5A62999095F7F4ED\
F3F4F4FFFFFFF7EFF0F3E8E9F3E8E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDED4E9746C58B3AEA9B7BBBD84AEC1\
77939D668384557E905188A473A6BCAAC4CE3F4C5BF3E4E1F7F7ECF7F7F8FFE5F8
FFE5F8F7F7F8F7F7F8FFFFFFF7F4F4F7EEFFF3F6F8F3EBF8F7E0F8F7EEFFF7EEFFFFFFFFFFFFFF\
F7F7F8F7E4F4F7E0F8F7EEFFF7F7F8FFFFFFF7F7F8FFFFFFF7EDEEF7F3F4F7EEEE
F3E8E1FFF4F4FFEEF8F1ECE7EEE6DFEEEDE8F1D4D0EBD9DBF3EDE5F7F7EFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF4F4FFF4F4FFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFFFFFFFF7F8FFFFF7FFF7F4FFFFFFFFFFF7FFFFF7F7EDEEFFF7F8FFFFFFF7F2F4\
FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F7F7FFFFFFF7F7F7F7F4ED
FFF7F8F5FFF8F5F7F8F5FFFFF5EEF8FFF2FFFFF6F4FFFFFFF7FFFFF7FFFFFFFFFFF7EFF7F3E8F3\
F7E8F3F3E8EFEBE8EFF7E8F3EAE6ECEAF7EDFFE5E8F7E4E9F7E4EEEBE0E5DEE0E1
DEE7E5F2E4EFEAEFE6F3EDE5F3F6E7F1E0EEF7F4E8F7F4E8F3F4E8FFF2F4FFF2F4F3F4F3F7F7F7\
F7F7EDF1E8F4FFFFFFF3FFFFF7F6F8FFF6F4F7F6F8FFF2EFFFF6E8FFFFEFF7F2E1
F7F6F4F7F3F4F7F7F8F7F7F8F7F7F8FFF4E8D9F4F88E9391D8C3C6C1B6BAEAE4E87B7573AC979A\
F3EDEEFFFFFFF7EFF0F7EFF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDED4E95B4F39C4C1C56B869C406970\
7C8186A497AEC2ABB2B4A7AA758292899DB2776D74F7F7EFDAEFF7DAEFF7FFFFFF
F7F7F8F7F7F8FFFFFFFFF7F8F7F7F8F7EEFFF7E5F8FFE5F8F7F7F8FFFFFFFFE5F8F7F4F4F7F7F8\
FFF7F8F7F7F8FFFFFFFFFFFFF7F7F8FFFFFFFFFFFFF7E4F4FFF6F8FFFFFFF3F3F4
EBE4E5FFEFF0FFF7F8F5F6F8F5ECE1EEF7F8E3D4CCEAD3D3FFEEF8F3EDE5FFFFF7FFFFF7FFFFF7\
FFF7F8FFF7F8FFF4F4FFF7F8FFF4F4FFFFFFFFFFFFFFF7F8FFFFFFFFFFFFFFF7F8
FFFFFFFFF7F8FFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFFFF7FFFFF7F7F7F8F7EDEEF3F6F8FFF6F8\
FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7FFF6F8F7EEEFF7F7F7FFFFFFF3F4F3FFFFF8
FFF4F8F5FFFFFFF4F4F5F7F8F7EEF0F3F6F4F7F6FFFFF6F8F7F6F8FFF6F8F3FFFFF3FFFFF7FFFF\
F3FFFFF7F6F8F3F6F8F7FFFFF7EFFFEEE8F7F7E8ECFFE8E8FFDDE5F3E5E9F7E4EE
F7E0E9ECEDE3ECEFEEF3EDF8F7FFEFEADBDBF7F4E8F7F4E8F3F4E8FFF6F8FFF6F8F7F7F7F7F7F7\
FFFFF4F1E8F4FFFFFFF3FFF8FFFFF4F3F6F4F3F2F8FFF2FFFFFFFFFFF6EFF7F6EF
F7FFF8FFF3F4FFF4F4F7FFFFFFFFFFF7EDE5DFF7EDA2B5B9F3F2E8D6E5DDCEC6B6D1CCBEA89291\
D1C3D7F7EFF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8D8D4EE5C4F33D9D5D62C3F53E3D4DB\
FFE5F8F7F7F8FFE0EEEEF7E7ECD5CEC4C3BFB5AEA7F7F7EFE2F4E8E2F4EDF7F7F4
F7F7EFF7EEFFFFE5F8F7F4F4FFFFFFF7EEFFF7E5F8FFE5F8F7F7F8FFFFFFFFE5F8F7EDEEF7ECF8\
FFE4EDFFFFF3F7F7EFF7F7F8FFFFF7FFFFF7FFE5F8FFFFFFF7E4F4FFEFF0F3F7F8
EBE6E8FFF4F4FFF4F4FFFFFFF1EBE5EEEFE7EEF4EDEAC8BDF7F2F8F3ECEEF7E4EDF7F7F8FFFFF7\
FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFFFFFFFFFFFFFF7F8
FFF7F8FFF7F8FFF4F4FFF4F4FFF7F8FFF7F8FFF7F8FFFFF3FFE5F8FFE4F4F7E4E6F7F6F8FFFFFF\
FFFFFFF7F7EFF3F4ECF7F7F7FFFFFFFFF6F8FFF6F8F7F7F7F3F4F3F7F7F7FFF7F8
FFF7F8F5FFFFF5F4F4FFF6F8F3FFF8F7F6F8FFFFF8F7F2F4F7F6F8F7F6E7FFF6EFFFF6F8F7F6F8\
F7F6FFFFF6FFFFF6FFFFFFFFFFFFFFF7F6FFF7F2FFFFF6FFFFEFECF7EDF4F3F4ED
F7F4EDF7F7EDF3EDEFF7EEE8FFF6EFE4E4D6F7E5E1F7F4E8F7F7EDF7F3F4FFF6F8FFFFFFF3F4EC\
F5EFF0F5EFF8FFFFFFF7FFF8F7FFF8F7F6FFF7F6FFFFF6FFFFFFFFFFF6EFF7F6EF
F7F6F4FFFFFFFFF7F8F7FFFFFFFFFFF7F4F4DFF4E58B979FD1C8BEBCC2B9DAD4CBCBC2C4D1CAD3\
C4B6BDFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE4EEC8BACE76724F87A0B57B828DFFFFF7\
FFFFFFF7F7F8F7E4F4F7E5E8EEF7E5ECEEE5D9E0DBF7F7ECF3F4F4F3F4F4F7F7F4
FFFFF7F7E4F4F7F7F8F7E0F8F7E6FFF7FFFFFFE5F8F7E4F4FFE5F8FFE5F8FFE5F8F7E0EEF7EFF0\
FFE5F4FFFFF3FFFFF7FFFFFFFFFFF7FFFFF7FFE5F8FFE5F8FFFFFFF7E4F4F7F6F8
F7E0E5F7F7EDFFEDF4FFFFFFF5EBF4F5FFEFFFF7EFF1C8C4F3EBE5F7F3F4FFE5F8F7F7ECFFFFFF\
FFF7F8FFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFFFF7FFFFF7
FFFFFFFFF4F4FFF7F8FFF7F8FFFFFFFFFFFFFFF4F4FFFFF3FFE5F8F7ECF8FFECEEF7F6F8F7F7EF\
F7F7EFF3F4E8F7FFEDF7F4F7FFFFFFFFFFFFFFFFFFF7F7F7F7F7F7FFFFF8F5EDF0
F1F4F4F5F4F4FFF7F8F7F6F8F7F6F8F7F6F8F7F2E5EBF6EDEBFFFFFFFFE8F7F3EDF7F3E8FFF6E1\
F7EEECF7F3F7FFF2FFFFF6EFFFFFE8FFF6EFFFF2FFFFF6FFFFFFEFFFF6EFFFF6EF
F7EFFFF7E5FFFFF2EFFFFFFFFFE5E8E4DBD6FFEDE8F5DDDEF2E4E2F7F3F4FFF6F8F7F7F7F7F7ED\
F5EDF8F5F7F8F7FFF8F3FFF4F7FFF8FFF6F8FFFFF8FFFFFFFFF6FFFFFFEFF7F2E7
F7FFF8F7FFFFF7F7F8F7EEF0F7ECEEFFF7F8D9F7EC7C858BF7F6F8A2A294CBC8CBF7F6F0F7F7DC\
D1C2C1FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8DED9EEC9B6AAABC1BD8498A1E2DCDEFFFFF7\
FFFFF3FFFFF7FFFFF7FFE5ECF3E0E7E3ECF8D9EDE8DAEFF7D9EDF4F3F4F4F7F7F8
F7F7F8FFFFFFF7E0F8FFE5F8FFDBF4F7E4F4F7F7EFFFFFF7FFFFF7FFFFF7FFFFF7FFE5ECFFE5F4\
FFFFFFFFFFF7FFFFF3FFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFF7E4F4FFF6F8
F7E6EEF3F7ECFFEFEEFFEDEEFFE5F0F5EBF4F5EEE7F5E4E8ECD4D7F7E4DEF7E5E8F7F7EFFFFFF3\
FFF7ECFFF7EFFFF7F8FFF4F4FFF4F4FFF4F4FFFFFFFFFFFFFFF4F4FFF7EFFFFFF7
FFFFFFFFF7F8FFF7F8FFF4F4FFFFFFFFFFFFFFF7F8FFF7ECFFF7F8F7F7F8FFECEEF7F6F8F7F7EF\
FFFFFFF7F7EFF7FFEFF3F7ECF7F7F7FFFFFFF7F7F7F3F4ECF7F7EDFFFFF8F5EFF8
F1EDF4F5F7F8FFFFFFF3F6F8FFF6F8FFF2EFFFFFFFEBF7F8F3F4F3F3F4F4F7EFF8F7EFF4F3F4F8\
F7F7FFF7EEEDF3E6E8F3ECF7F7F7F8F7F7EDF7F7ECFFEFECFFEFF7FFF6FFFFF6FF
FFFFE8FFF6EFFFF6EFFFF2EFF7EFFFEACDDBFFFFF8F1D4D4E4C8C4FFFFFFF7F7F7F7F7F7F5F7F4\
F5FFFFF1E7EEF7F6FFF7F6F8FFF2FFFFF6F8FFF6F8FFF6EFFFFFEFFFF6FFF3F6F4
FFFFFFF7FFFFFFFFFFF3F6F8F3F3F4F3EDEEE6F7E15A656DADBBC571848AA49FA7EAE5CAD9CADB\
E3D5DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8F7EFF0D6D1DFDEDCB9BEC9DFF7F7F8F7E4F4FFFFF3\
FFFFFFFFFFF3FFFFF3FFF7F8F7EFE5F7F7F8F7F7EFE3F7ECD9EDF4F3F4F4F7F7F8
F7E4F4F7E4F4FFE5F8FFE5F8FFFFFFFFFFFFFFFFF3FFFFF7FFFFFFFFFFFFFFFFFFFFFFF3FFFFFF\
FFFFF7FFFFF3FFFFFFFFFFF7FFFFF7FFFFF3FFFFF7FFFFF7FFFFF7F7E4EDFFF6F8
FFEEF0EEEEEFF3F7F3F7F4EDFFF4F4FFFFFFF5F6F8F5F3EDF1DCDEF7E6E5F7E5E7F7E5E8F7F7F8\
FFFFF7FFF4EDFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFF4F4FFFFFF
FFFFF7FFFFF7FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF4EDFFF7EFF7F7F8FFECEEF7F2F4F7F3F4\
F7F7F4FFFFF8FFEFF8FFEFF0F7F7EFF3F4ECF7F7EDFFFFF8FFEFF8F5E8F4F1E8F4
F1EDF4ECF7F0F3F6F4F7F6F8FFF6FFFFF6EFF7F7F8F7F7F7FFFFFFFFFFFFFFF7EEFFF7F8FFFFF8\
FFFFF8FFF7FFFFF7FFFFFFF8F7F7F8FFEFF8FFEFF8F7F7F8FFEFEDFFFFE8FFFFEF
FFEFECFFEFEDF7F3F8F7F3EDEAE5DBF5E5F0F5E5F0E3D4D3D9C2BDF3F4ECF7F7EFFFFFF4F5F7F8\
FFFFFFF5E7EEFFF6F8F3F6F4FFF6EFFFFFEFFFFFEFFFFFFFFFFFEFFFF2FFF7FFF4
F7FFFFFFFFFFF3FFFFF7FFFFF7FFFFF7EFF0DEFFE8474D56DAEDF4969EA9A09E9FABA9A1D6C6D4\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8E2E0EEE2D9C8D1EDEFF7F7F8FFE5F8FFE5F8FFFFF3\
FFFFFFFFFFF3FFFFF7FFF4EDF7EDE1F7F7F8F7F7EFFFFFF7D9EDF4DAEFF7FFE5F8
F7F7F8F7E4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF3FFFFFFFFFFF7FFFFF7FFFFF3FFFFF7\
FFFFF7FFFFF7FFFFFFFFF7F8FFF7F8FFFFF7FFFFF7FFFFF7FFFFFFFFDBEDF7E6FF
FFF4F4F7F2F8FFF7F8F3EFECFFEFF0FFF7F8FFFFFFF5EEE7FFF7EFF5E5E8F3E5E5FFEBEEF7EFF0\
F7F7EFFFF7EFFFF7F8FFFFFFFFFFFFFFF7F8FFF4F4FFFFFFFFF7F8FFF4F4FFFFF7
FFFFFFFFFFFFFFFFF3FFF7F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFF3F7E4F4FFF6F8F7F4F4F7E4E5\
F7F4F4FFEDF0F5E5F0F5E5F0F5E8EEF5EDF4F5F4FFF5F7FFF5E8F4F5FFFFFFFFFF
F7FFF8FFF6F8F7F6FFFFFFEFEEFFEFEEEFEFF3F4F4FFFFF8FFFFF4FFF7F4FFF7FFFFF7F8FFF4FF\
FFF7FFFFF7FFFFFFFFFFF7FFFFF7FFF7FFFFF7F7FFF7F4FFF3EDFFF3F4FFF7EDEF
F7F7EDF7EDEDF7EDF4EEEDF4F2E0DBF1E4F0ECE5DFF2ECF4E3D1CEFFFFF8FFFFF4FFF7FFFFF4FF\
F1EFF8FFEEF0F7F6F4F7F6F8FFF6EFFFFFEFFFFFE8FFFFE8FFF6FFFFF6FFF7F6F8
FFF6F4F3FFF8FFF7F8F7F7F8F3FFFFF7EFF0D1EFF0555A63FFF4F4BEBBC0D1C8BE9DA4A7D6C6BD\
EEE5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDED4E9EAE1B9D1EDF8F7F7F8FFFFF7FFFFF7FFFFF7\
FFFFF7FFFFF3FFFFF7FFF7F4F3EDE1FFFFFFF3F4E8F7E4E8D9F3EDDAEFFFFFE5EF
F7E4F4F7FFFFFFF7F8FFFFF7FFFFF7FFFFFFFFFFF7FFFFF3FFFFF7FFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFF4F4FFF4F4FFF7F8FFF7F8FFFFFFFFFFF3F7E4F4F7FFFF
F7F3F4F3F6FFF3F3EDF7F7F7FFF7F8FFEDF0FFEFF8F5F6F8F5F6F8F1E4EEF7EDE8F7EEEFFFEEF0\
F7EFF0F7F7ECFFF4F4FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFFFF7
FFFFF7FFFFF7FFFFF3FFF7F4FFF4F4FFF4F4FFF7F8FFFFFFFFFFF7FFE5EFF3F3F4FFE4EEF7E4E7\
F7EDF4F5F7F0FFECEEFFECEEF5F4F4F5FFFFF5F4F4F5E7EEF5E4EEF7F6F4F7F6F4
F3F2F8F7F6EFF7FFEFF7F7ECF7EDF4F7F7F4F7FFFFFFF7F8FFF7FFFFFFFFFFF7F8FFF7F8FFF4F8\
FFF7F4FFF7F8FFFFFFFFF7FFFFF7FFFFF7F8FFF7F8FFFFFFFFFFFFFFF7FFF7F4F8
F7F4F8F7F7FFF7F7F8F3EFECFFEEF0FFEEF0F7FFEFF2EBDEF5F4F4FFF7F4FFF7F8FFFFFFF5F4F8\
ECF7F0F3F6F8F7F6F8FFF2EDFFFFEFFFFFFFFFFFEFFFFFFFFFF6EFFFF2FFF7FFFF
FFF6F8F3FFF8FFF7F8F7FFFFF3F3F8F7ECF0D6EDE7485462F7F4F8D1C5C5A9B6B3B7BCC6D6C6B2\
E6DBEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDECDDBEBDCC4D9E7F8F7F7F8FFFFF3FFFFF3FFFFFF\
FFFFF7FFFFF7FFF7F4FFEDE1EBE4DEF7EEF0F7F7EFF7EEF7F7EEFFF7F7EFFFFFF7
FFE5F8FFE0F8FFE4F4FFFFF7FFFFF7FFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8\
FFF7F8FFF4F4FFF4F4FFF7F8FFF4F4FFF4F4FFF4F4FFFFFFFFFFF7F7F7EFF7E4F4
FFEFF0F7F6F8F3EBEDF3F4F3F7F7F7FFEFEEFFEFF8F5F6F8F5F3EDF5DDDFF5E5E8F3F4ECFFF6F8\
F7EBEEF7E4E8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7FFFFF3FFFFF3FFFFF7DAEFFFD9EDEFF3F4EDF7E4EEF7ECEDF7F7EF\
F5F7F4FFFFFFF5FFF4F5FFF4F1F7F4F5EFF0FFF3F4FFF6F8FFFFFFF7F6FFFFF6FF
F7FFEFFFFFFFFFFFFFF7EDF4FFFFF8F7FFF4FFFFFFFFFFF8FFF7FFFFF4F8FFFFF8FFF7FFFFF7F8\
FFF7F4FFFFFFFFF7F4FFFFF4F7F7F8F7F7F8FFF7F8FFF7FFFFF7FFFFFFF8F7F7FF
F7F4F8FFF7F8F3E7EDF3F6EFFFFFFFFFFFFFF5EEF0F1EEF0FFFFFFF5F4FFF5EDF8F5EFF8F1EDF4\
F7FFF8F3F6F8F7F2EDFFF6F8FFF6EFFFF6FFFFFFEFFFFFFFFFF6EFFFF6FFFFF2FF
F7FFF4F3FFFFFFFFFFFFF7F8F7F3F8F7ECF0D6EDE73B4856DEEDE5CACCC57D8F8C6E8382576766\
8F868DFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EFF0EACDBCEAEEDFF7E4F4FFFFFFFFFFF3FFF7ECFFF4F4\
FFF4F4FFF4F4F7E5E8EBE4E5EEECECF3E0E2F7F7EFF7F7F4F7F7F8FFFFFFF7F7F8
F7E4F4F7E0F8FFFFFFFFE5F8FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFFFFFF4F4FFFFFFFFFFFF\
FFFFFFFFFFFFFFF6F0FFF6F0FFF7F8FFFFFFFFFFFFFFF7F8FFFFFFFFFFF3FFE5F8
FFF7F8F3F3F4F7F6F8F7F6F8F7F7F7F7E6E5FFEFF8F5EEE7FFFFFFF5F3EDF1E4EEF7E6E7F7F7EF\
F7EEE9F7E4E8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF4F4
FFF7F4FFFFF3FFF7ECFFF7F4F7F7F8F7F7F8FFE5F4DAF6ECD9F3EDF7EEFFFFE6F4F7F7EDF7EDEF\
F5FFF8FFF7F4F1F7F8F1F7F8F5FFFFF5F7F8F2D9DDF3EFECF7FFEFFFFFFFF3FFEF
FFFFFFFFEFF8FFEFEDF7EDF8F7FFF8FFF7FFFFF4F8FFF7FFFFF7F8FFF4F8FFFFF8FFF7FFFFF7FF\
FFF4FFFFF4F4F7F7F8F7F7F8F7F7F4F7F7FFFFFFFFFFFFFFFFFFFFFFF4F8F7FFFF
F7F4F8F7F4F8EEECE1F7F6FFFFF6F8F5F2F4F5ECEEFFF7FFF5F7FFF5F7FFF1EDF4F5F4F4F5F4F4\
FFFFFFFFF6F8F3F6E7FFFFEFFFF6FFFFFFFFFFF6EFFFFFEFFFF6FFFFFFFFF7FFFF
F3F2F8F3F2F4FFF6F8F7FFFFF7F7F8F3EDEECBECF0424F4CE4F4FFF3F4F7C9DCDEF7DDD793A4A3\
75666DFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7EFF0DACCCFE2E4CBF3FFFFF7F4F4FFFFF7FFFFF7FFE4E8F7ECF8\
F7F4F4FFF4F4EBE4DEF7F7EDFFFFF8EBD4D6FFFFF7D9EDF8DAEFF7F7F7F8F7EEFF
F7ECF8F7F4F4FFE5F8FFE5F8FFFFF7FFFFF7FFFFFFFFFFF7FFF7EFFFF7F8FFF4F4FFFFFFFFFFFF\
FFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFF7F8FFF7F8FFF7F8FFF7F4FFFFF7FFE5F8
FFF7F8F7F3F4FFFFFFF7F2F4FFFFFFF3F4ECFFEDF0F5E5DFF5EEE7F1F2F4F1F2F4FFE8F4F3F4E8\
FFE6E9F3F4E8FFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF4ED
FFDDE7F7E0EEF7EDEEFFE7F0F3ECF8F7F7F8F7EEFFF7EEFFF7EEFFF3ECF8F7ECF4F7F6F8F3EDEC\
FFF7F8F5F7FFF5FFFFF5FFFFFFE5EEF1EEEEEAD9DDFFFFEDF7E8EDF3ECF7F7F6EF
FFF6E7FFE5EFFFEFECF3F4EFFFF4FFFFFFFFFFF7FFFFF7F8FFF7F8FFF7F8FFFFF4FFFFF8FFFFF8\
FFF7F4F7EFFFFFFFFFFFFFFFF7F7FFFFFFF8FFFFFFFFFFFFFFFFFFFFF7FFFFF7F8
FFF7FFEBEDEDF7FFEFF5F6F8F1EEF0F5F4F4FFEFF8FFF7F8FFF4F8F5F7F8FFF7F8F5F7F8FFF7F8\
FFFFFFF7FFFFF7F6F4FFF6FFFFF6FFFFFFFFFFFFFFFFF6FFF7FFF8F7F2F8F3F2FF
F7F6F8F3F2F4F7F6F8F7F7F8F7F7F8F7F4F4CBE4E9425657E4F4F7F3F4FFE2F7EED9D9E8676C6D\
A08889FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7D9CCDAE0CED9EFF7FFF4F4FFF7F8FFFFF7FFF7F4FFDDE5F7E0EE\
FFECEEEBE4E5EEECEFF5F7F8F2F4E5F3DBE2FFFFFFD1EDECCBECECFFE5F8F7E4F4
F7FFFFFFE4EDFFFFF3FFFFF3FFFFF7FFFFFFFFFFFFFFFFFFFFF4F4FFF7F8FFF7F8FFFFFFFFF6F0\
FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4EDFFFFF3FFFFF3
FFE5EFFFE7F0F7F3F4F3FFF0F7F6F8F3F4F3FFF7F8FFEDEEFFFFFFF1EBE5F1EBE5F5ECF4ECD9DE\
F7D4D7F3DCDEFFFFF7FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFDDE7F7E4ED
F7EEFFF7E0E8F7E8E2FFE0E5F7E4EDF3F4EDFFFFF7FFFFFFF7F7F8F7E4F4F7F3F4F3F6FFF7EEEF\
F7EFEFF7EDF4ECF7F4FFFFF8FFE5F0F5E5F0F7E5E8F7DDDEF7EDEDF3EEF4F3E0E8
F7E0E5F7E7ECF3F4ECF7EFE7ECEFF4ECF7F4FFFFF8FFF4FFF7F7F8F7F7F8FFFFFFF7F7F8F7F7FF\
FFFFF8F3F4F4F7F7F7F7F7F8F7F7F8F7F7FFF7F7F8F7F7FFFFFFFFF7F7FFF3F7FF
EBE8EDE3DDD7F1E6E9F5E4E6FFF4EEFFF7F8FFF7F8FFF7FFFFEFF0F1FFFFF1F4F4F1F7F8FFFFFF\
FFFFFFF7FFFFF3FFF8F7F2F8FFF6EFFFFFEFFFFFFFFFF6FFF3F6F4F3FFF4F7FFF8
F7F6F8FFF6F8F7F6F8FFF7F8F7F7F8F7F4F4C4E4F0556779CBCFD7B6C8D1CBC8CC9A9789696C62\
C4B0B6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7EFF0F7D9BDF7F7F4F7F7EFFFFFF7FFFFFFFFFFF7FFF4EDFFF4EDF7F7F4\
F7E0E3F3E1E1FFEDF0F1F4F8EAE8E1F3E0E9F7EEFFD9F3EDD9E7F7FFE5F8F7E4F4
F7F7F8FFE5F4FFFFF3FFFFF3FFFFF7FFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFF6F0\
FFF2E9FFF2E9FFFFFFFFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFF7F8FFF7F8FFFFF7
F7F7EFF7E5F8F7F7F8F3EEFFF7EBEEF7F7F7F7F7F4FFE8EEFFFFFFF5EEE7FFF7EFFFFFFFF5F6F8\
F7E8E5EED4D4F7F7ECFFF4F4FFFFFFFFFFFFFFFFFFFFF7F8FFF7EFFFE5F4F7E4ED
F7F7ECFFFFFFFFFFF7FFFFF3FFFFF3FFFFF7F7F7F4F7F7F8FFFFF7F7E4EDF7E4F4F3ECF0FFFFFF\
F7EEEDF7F7F7F3EDF3F5F7FFFFF4F4F5F7F8FFF7F8F7EEF8EBE0E5EBDCDDF7EFED
EAF7EEEAEFEEFFF4F8FFF7F4ECF7FFECF7FFFFFFF4FFF4F8F7F7F8F7F7F8FFFFF4F7F7F8F7F7F8\
FFFFFFF3F4EDEEFFFFEEEFEDF7EDF8FFFFF8FFEFFFF7F7F8F7F7FFF7F7FFF7EFEF
F7F6E7F1E4E6FFF4F4FFF7F8FFF7F8FFFFFFFFF7FFFFF4F8F5F4F4FFF4F4FFF7F8F5F7F8FFFFFF\
FFFFFFFFFFFFF7FFF8F7F2F8FFFFEFFFF6EFFFF6FFFFFFFFF7F2F4F7F2E5FFF2E7
F7F6F4F7FFF8F7F6F4F7F6FFF7EEF8E3EFE8BAC9DD757C84EAE0E5E3E5EFE3D4C54B626E938AAD\
DACCDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3E8E9F3E6C4FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFF4F4FFF4EDF3E4DE\
F7DDDFF7F4F4FFF7F4F1EFF8F1E1E1EBE0E3F7EEFFF7E4F4F7F7F8FFE5F8F7F7F8
F7E4F4FFFFFFFFFFFFFFFFFFFFFFF3FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFF6F0FFF2E9FFF6F0FFF2E9FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8FFF7EF
F7F7EFF7E0F8F3EBF8F7FFFFF7EBF4FFFFF8F7F7EFF7E5E5FFF7F0FFFFFFF5F6F8FFFFFFF5F6F8\
FFE8F4EBE4D1F7E4EDFFF7EFFFF7F8FFFFFFFFF7F8FFF7F8FFFFF7FFFFF3FFFFFF
FFFFF7FFFFF7FFFFF3FFFFF7FFFFF7FFFFF3FFFFF3FFFFF3FFFFF7F7F7ECF7EEFFF7FFF8F7ECF0\
FFF2F8FFFFF8F3F7F7FFF4F7F5F7F4F5FFFFFFEEF8F7ECF4F7F4F4F7F6F8EEDDD6
E3E5DBF5F4F4F3FFE9F7FFF4ECF7FFEAF7F8F7FFF0FFF7F0FFF4F4FFF4F8FFF7F8FFFFFFFFFFF4\
F7F7FFFFEFF4F3F4F4EBF7EFF7F7FFFFEFF4FFFFFFF3F4F7EEEDE8F3E5E1ECF2E5
F1EEF0F5EDEEFFFFFFFFFFFFFFF7F8FFFFF8FFF7F8FFF4F8F5F7F8FFF7F8F5F7F8FFF7F8FFFFFF\
FFFFFFFFFFFFF7F6F4F7F6FFFFFFFFFFFFFFFFF6FFFFF2F8FFFFFFFFF6EDFFF2E7
F7F6F4F7FFF8FFF6F4FFF6FFFFF6FFEBEDE2AAB6C87A8584F7F7F0DEDBE1CAC3BA777F88978A99\
B0A3B4E3DDF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7E0D4F7ECD2FFE5F8FFE5F8FFE5F8FFE5ECFFF7F8FFF7F8F7E5DBEEDCDE\
F7F4EDFFF7F4FFEDEEF1FFFFEAE1DBEEEEEEE3E4EDD9EDF4F3F4F4F7EEFFF7E4F4
F7EEFFFFE5F8FFFFFFFFFFFFFFFFF3FFF7F8FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0\
FFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFF7F8FFF4F4FFF7EF
FFFFF7F7E4F4FFEEFFFFECF4FFFFFFF7F2F8FFF6F8F3EDECFFEDF4FFEFF8FFFFFFF5F6F8F5F6F8\
FFEFF8EBE1D0F7EFF0FFE5ECFFF4F4FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFF7
FFFFF7FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFF7FFE5EFF7EEFFF7E4EE\
FFFFFFFFF6F8F7FFF8F7EDF3FFF7F8F1F7F4FFE5F0F7F3F8F7FFFFFFF7F8F7F6FF
EBE4E7E3E4D3EBEDD0FFF7F0F5F7F4EAF7EEF5F7F4ECF7F8FFFFF8FFF7F8FFF7FFFFFFF8FFFFF8\
F7F7F8FFEFF8F7F7F8F3F4F4F7EDF4FFFFFFF7EDF4F7FFE8F7FFFFFFEBEEF1F4F4
FFF7F8FFF4F4FFF7F7FFF7F4FFF7F8FFF7FFFFFFFFFFF7F8F5F4F4FFF7F8F1FFFFF5F4F4FFFFFF\
FFFFFFFFFFFFF7F2F4FFF6F8F7F6F8FFF6FFF7FFFFF7F2F8FFFFFFFFF6F8F7F6F4
F7F6F8FFF6FFFFF6F8FFF6FFFFF6FFF3E8E99CB0C0728597FFFFFFDADDDFBCB8BC7F88866F7267\
746D5BC8B2B5E6DBF4EEE4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFD9BDFFF7EFFFE5F8FFFFFFFFFFFFFFE5ECFFF4F4FFF7F8F3D9D0F3ECEC\
FFEFEEFFEFEEF5EDEEFFEFF0EAE4E1F7EBF4E2ECEFDAEFFFF3ECEFF7E4F4FFFFFF
FFE5F8FFE5F8FFFFF7FFFFF3FFFFF7FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF6F0FFFFFF\
FFF6F0FFF2E9FFF6F0FFF2E9FFFFFFFFF6F0FFFFFFFFFFFFFFF7F8FFF7F8FFFFF7
FFFFF3F7F7EFF7ECF8F3EEF4F7EBF8FFF7F8F7F2F8F7F4E7F7FFEDFFEDF0FFF7F8FFFFFFFFFFFF\
FFFFFFF3D5D6F7FFF0F3E7E7F7EFE7FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFFFFF
FFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFF7F7F7ECF3E0E7\
F7F6F8FFFFFFFFF3F4F3F7F3FFF7FFF5FFFFF5F7F4FFF7F8F7F7F8F7F7F8F7FFFF
F7F7F8F7F6FFEBE6EDE3DCCEEBE8E8F3E0EFE3DCE5F5F4EEF7FFFFFFF4F0FFF7F8FFF4FFFFF7F4\
FFFFF8F3F4FFF7F7FFFFFFEFFFFFEFF7EDF4F7EFF7F7FFEFF5EEF0F1EEF0F5F7F8
FFF4F4FFF7F8F7F4F3F3F7EFF7F7F4FFFFFFFFF7F8FFF7F4F5EDF4FFF7F8F1F7F8F5F7F8FFFFFF\
FFFFFFFFF6F8F3FFF8F3F6F4F7F2F4F7F6FFF7FFFFFFF2F8F7FFFFFFF6F8F7F6F8
FFFFF8F7F2F4F7F3F8F7EEF8F7EEF8EEF4E59FAEAE8E91A8E3F7F8EBF7F8EEF4F4EEEDEEECE4E5\
7A7B7A857E6AC4B6A7DAD5DEEEE4EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEDE5F7D9BDF7F4F4FFF7F8FFE5F8FFE5F8FFFFF3FFF4F4F7EDE5EED9CBECDDDE\
F1E4E6F5E0E6F1EDF0F1E8E8F3EBEDFFF4F4FFFFFFF3ECEFF7F7EFF7E4F4FFE5F8
FFE5F8FFFFF7FFFFFFFFFFF7FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF6F0\
FFF6F0FFF2E9FFF6F0FFF6F0FFF2E9FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFF7FFE5EFF7F7F8FFE0F4F3F7F4FFF3F4FFF6FFF7EEF4F7F4F7F3EFECF7EFE7FFF7F8FFFFFF\
FFFFFFF7E1E2F7EEEFF7EBEEF7E4EDFFFFF7FFF7F8FFF4F4FFFFFFFFF7F8FFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF6F0FFF6F0FFFFFFFFF4F4FFFFFFFFFFF7F7E4ED\
F7EEF4FFF6F8FFF3F8F3F7F3FFF7FFFFF7FFF5FFF4F5FFFFF7F7F8F7FFFFF3F7F8
F3FFFFF7FFFFF7F7F8F7F3F4F7F2E5F7F6E5EBEBEFE3EDEDF2EDF4E4EDF8EAF4F8F3FFFFF7F7F4\
FFF7F4F7F7F8F3F4FFFFEFF8F7EDF4F7F6E7F7F2E5FFF2F4F1ECEEFFF7F8FFF7F8
FFFFFFF7F7F7FFFFFFF3F4ECF7F7F4FFFFFFFFF7F8FFF7F4FFF4F8F1F7F8F5F7F8F5FFFFFFFFFF\
FFFFFFFFF2F4F7F2F8F7FFF8F7F6F4F7F6FFF7F6FFFFF2F8F7FFF8F7F6FFF7F6FF
F7FFFFF7F6F8F7EBF0FFFFFFF7EFF0E5F4ECA1B2AD999AAFC9D4E2D1DBE9C8DDE8F7FFFFD6EDED\
ACB8BC97A09BACA89DBEB2ACDECDDBFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFDCC3F7E4D6F7EEFFFFE4F4FFE5F8FFE5F8FFFFF3FFF7F8EBD4CBF7D5D6E2D4D6\
EBECE5FFEFF8F5ECF4F1DCDCEAF2EEE3F4F8F7EEFFFFFFFFFFE5F8F7F7F8FFE5F8
FFE5F8FFFFF7FFFFF7FFFFF3FFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF6F0FFFFFFFFFFFFFFF6F0FFF2E9FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFF
FFF7ECFFE5F8F7F7F8FFE5F8F3E0F0F7F2F8F7F6FFF7F6F8F7F7F4F3F7F3F7F4EDFFF7F8FFF7F8\
FFF7F8FFEDEEF3F4F3F3E5E3FFE5EFFFFFF7FFF7F8FFF4F4FFF7F8FFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF6F0FFFFFFFFFFFFFFF6F0FFF4F4FFFFF7FFFFF7F3EDEE\
FFEBF0FFFFF8FFFFFFF3EDF3FFFFFFFFF7FFF5FFF4F5FFFFFFF7F8FFFFFFF7F4F4
F7F4F4F3F3F8F3F6FFFFFFFFF7FFFFF7FFFFFFF2F4F3FFEFDEE1E7EAF4F8EAF7F8F3FFF4FFFFFF\
F7F4F8FFFFFFFFFFF8F3F4F4F7EFF7ECF2E5F1FFFFF1F7F8F5F7F0FFF4FFFFFFF8
F7FFF7FFF7FFFFFFFFF3F4ECF7F7F4FFFFFFFFFFFFFFF7F8FFF7F8F1F7F8F5F7F8F5FFFFF5F7F8\
F5F3F8FFFFF8FFFFFFFFF6F8F7F6F8F7FFF8F3F6F8F3F6F8FFFFFFF7FFF8F7F6F8
F7F6FFF3FFF8F3EEF0FFF6FFF3E4EEF7EFE5CACDC4B0B2BD8BAEC4ADC6D2B4C5DB9FBDD4B3D4DE\
D9E1E2B4BABDC7CCC5A3A89DB5A0A5E3DCE5FFF4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE4D6F7DCC3F7F7F8FFECF8FFE5F8FFE5F4FFE5F4F7F7F4EBDCCBF7EFE5F2D4D7DEE0D6\
E2E5DEEAECEFF2E4E8ECD4D6DEF7F0E2ECFFF7EEFFFFFFFFF7E4F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFF6F0\
FFF6F0FFF2E9FFF2E9FFF6F0FFFFFFFFF6F0FFFFFFFFFFFFFFF7F8FFF7F8FFF7F4
FFF7F8FFFFF3F7E4EDFFE5F8F3E4EEF7E7EEF7EBF4F3F6F8EBECE8FFFFFFFFF7F8F7EDEDF7E5E7\
FFEDF0F7EFE7EEF7E5FFE0EEF7F7EFFFFFF7FFFFF7FFFFF7FFFFF7FFF7ECF7F4E8
F7F7ECFFF7ECFFF7F4FFF7F4FFF7EFFFF6F0FFF6F0FFF3EEFFECE6FFF7F8FFFFF3F7F7F8F7EDEE\
F7EBEDF3EDECF3E8E8ECE6E5F1EDE9F1EDE9F5F4EEFFF4F4FFF7F8F7F7F8F7F4F4
F7F4F4FFF3F8FFFFF8F3F6F8F3F6F8F7F2F4FFF6FFF3F6F8EEE5E8F3EFF4ECF7FFE4F4FFF5F7F4\
F7F4FFF7F7F8F3F4F8F7F7EFF3FFEFF5EBEEF1F4F4F5F7F0FFF7F8FFF7F8FFFFF8
F3F7F3F3F7F3F3F4F3F7F7F7F7F7F7FFF7F7FFF4F3FFEFEFF5F4F4FFF7F8F5F7F8F5F7F8FFF4F4\
F5EEF8FFF3F8FFF2F8F7F2F8F7F6FFF7F6F8FFF2FFF7F2FFFFF6F4F7FFFFF7FFFF
F7F2F4F7F6F8F7F7F8F7F3F8F7E5F0ECE6E5D9D4C4F3E8E5E2EEF4C7D1E1DEF7F8C4E0E8C4DDF0\
C7ECF4D1D3D6BCBBBD8F949163655B615856AA979DEEE5F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8F7D1B6FFDDE7FFEEFFF7F4F4FFFFFFFFFFF7FFE5EFF3E0E8F3E4E1F3ECE8DEC8CBF7EDE1\
F3F7F0F7E0E1EAE0E9F3E4E1E2F7F8E3F7FFF3ECF8F7E4F4FFE5F8FFFFFFFFFFFF
FFFFF7FFFFF7FFFFFFFFFFF3FFFFF7FFFFF3FFF7EFFFF7F8FFFFFFFFFFFFFFF6F0FFF6F0FFF2E9\
FFF6F0FFFFFFFFF6F0FFF6F0FFFFFFFFF6F0FFFFFFFFFFFFFFF7F8FFF7F8FFFFF7
FFFFFFFFE5ECF7EEF7F7F7F8F7F7F8FFE5F8FFFFFFF3F7F4EBECE8F7FFF7F3F7F3FFFFFFFFFFF8\
F3F4ECF7F7F4F3E5E9F7F7F8F7E4EDFFFFFFFFFFFFFFFFFFFFFFF7FFE4F4F3ECF8
F3E7F0F7E4F4F7F7ECFFFFF7FFF7F4FFF4F4FFF4EDFFF7F4FFFFF7FFFFF3F7EFE7F7EDEEFFEEF0\
F3E4E5FFF7F8F5F7F8F5F7F8FFFFFFFFF6FFF7F2FFF7F6FFFFFFFFF3F6FFF7F6FF
F7F6FFF7F6F8F7F2FFFFF6F8FFFFF4F7F2FFF3F6EDF7F6EDFFE5ECE2E6EEECF7F8FFFFF4E4F4F0\
FFF4F4F3F4F8FFE0F4F7F6E7F7EEEEF5EEF0F1FFFFF5F7F4FFF7FFFFFFFFF7F7F7
FFFFFFFFF7FFFFF7FFF7F7F7FFFFFFFFF7F7FFF4F3FFF7F7F5F7FFF5F7F4F5FFFFFFF7F8F5F6FF\
F5EEF8F5F4F4FFF6FFF7F6FFF7FFFFF7FFFFFFF6F8F3F6F8F3F6F8FFFFFFFFFFFF
F7F6F8F3FFFFF3FFFFF7EFF0FFFFFFDEE5E5E5D9C4F7E8E7EEFFEED9DDDED1D4DEC6D9DBBDD1DB\
9BD0E5EAF2F8F1F7F4F5F7F7DFE0E3A9AA9BA39896E6DBE9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFEDEEF3D4B3F3ECF8F7F7F8F7E4F4FFF7F8FFEDEEEEDCDEEBF4DDFFFFF8F5EFF0EAD4CDF7FFFF\
F3EDF7F3D4D6F1E6E7F3E5E5E2F7F8DAF6FFDAE4EDDAEFF7FFFFF7FFFFF7FFFFF7
FFFFFFFFFFF7FFFFF7FFFFF7FFFFF3FFFFF7FFF7EFFFF7F8FFFFFFFFFFFFFFFFFFFFF6F0FFFFFF\
FFF6F0FFF2E9FFF6F0FFF2E9FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFF
FFFFF3FFE5F8FFE5F8FFFFFFF7F7F8FFE4F4FFF7F8F7F7F4F7EBEFF7ECF4FFF7FFF7F7F7F7F7F7\
FFFFFFF7F7F7EBD4D7FFE5F4FFDDE7FFF7EFFFFFFFFFFFFFF7F7F4F3ECF8FFF3F4
FFF6F8FFF7F8F7E4EDFFFFF3FFFFF7F7F7EFF7F7F8FFFFFFF7F7EFF7F7F8F7E0EEF7F2F8FFF6F4\
F3E8E8F5FFFFF5ECF4FFF6FFFFF6F8F7F6F8F7FFFFF7F6FFF3F6F8F7F2F4FFF6F4
FFFFF8FFFFF4FFF6F8FFF6F4FFFFF8FFF2FFFFF6EFFFFFFFF7EDEDDEEDEEFFFFF4E3EEFFEAE4F4\
FFF4EEF3F4F4F7ECECF7FFF4F5ECF4F5FFF8FFF7F4FFF7F8FFFFFFFFFFFFF7F7F7
FFFFFFFFF7FFF7FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F4F8F5FFFFF5FFF8F5FFFFF5EEF8\
FFFFFFF5F6FFFFF7F8FFFFFFFFF6F8F7F6F8F7F6F8F7F6F4F3F6FFF7FFFFF7FFFF
FFF6F8FFFFF8FFFFF8FFEFF0FFFFFFE3EDE5EBE0D1FFE8ECF7EFF8F7EDF4E3DDDED8DBE1D1D1DB\
9AB1C5BFD1DBEEE6DFCECACC8F9582837E71B5B1BEEBE0E9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE8E2F3D4B9F3F7F8FFF3F4FFF3F4EEDCD6E6E0D6EEDDDEFFD9E6F2C8D1ECD1C8F7E5E7F3EDEF\
FFF6F8F7E0D4EAECECEEF7EEFFFFFFF3E6FFE3E4EDE3F7EFF7F7EFFFFFFFFFFFFF
FFFFFFFFFFF3FFFFFFFFFFF7FFFFF7FFFFF7FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF2E9FFF2E9\
FFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFFFFF
FFFFF7FFFFF7FFFFFFF7F7F8F7E4F4F7E4F4FFF7F8F7ECF8F7F7F8F7F2F4FFFFFFFFFFF8F7F6F4\
F7F6F4F7F7EFF3E0E2F7EFE7FFF4EDFFF4F4FFFFF7FFFFFFF7E4EDF3ECF8FFEEF8
F7F2FFF7F7F4F7E4F4FFFFFFF7F7F4FFFFF7FFFFF7F7F7F4F7E4F4FFE4F4F3F3F4F7EEEEF7FFF8\
F7E8ECF1FFF8FFECF4F7F6FFF7F6F8F3F2F8FFF6E7FFFFE5FFF6F8FFF6FFFFF6F8
FFFFFFEEF6F8EEFFFFF7F3F7F7F3F7FFFFFFFFFFEFF7F7EFF7EFF8E4EDF8FFFFF4E2ECFFF3E5F4\
F7F7EEF7EDEDF3FFE7FFEBF0F1F7F8FFF7F4FFF7FFFFFFFFFFFFF8FFFFF8F7F7F7
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFF7FFF7F7FFF7FFFFFFF5F4F4F5FFF8F5FFF8F5FFFFF5FFFF\
F5EEF8FFEEF8FFECEEFFF6F8F7F6F8F3F6F8F3F6F8FFF6F4F3FFF8F7F2F4F7F6F8
FFF6F8F7FFF8F7F6F8FFECF0F7EFF0E5F7F3EBE0C4FFEFF8FFEFECF7F7F7F7EFFFF7EDF0E3E5EE\
C4D4D687BAC9BDC6C9908F84867B7BC6AEC4EBE0E9F7EFF0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFD9C9F3D1C1F3F3F4FFFFFFEED5D7E3C9C5F1CFD1E2C9C9DEC9CBEAD4E2F3DBF4F7ECF8FFE8EF\
F3EBDEF5EDEEEAECECE2FFEEE3F7FFF3ECF8F7EEFFF7EEFFF7F7F8FFFFF7FFFFFF
FFFFFFFFFFF7FFFFF7FFFFF7FFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFFFFF
FFFFFFFFFFF3FFFFFFF7F7F8FFE5F8F7E0F8F7F7F8F3E6FFFFF3F4F7F2F4FFFFF8F7F6F8FFEEF8\
F7EBF8F7F6F8F7FFF8F3E0E9FFF7ECFFF7F8FFFFF7FFFFF7FFE5F8F7ECEEFFF6FF
F7F6FFF7E0EEFFFFFFF7F7F8F7F7F8F7EEFFF7EEFFFFFFFFF7E0F8F3F2F4FFF3F4FFEEF0F3F7EF\
FFEDF4F5FFF4F5F4F4F7F6F8FFF2F4F7F2F4FFF6EDFFFFEFEEFFFFEBF7F7F3ECEC
F3ECECF3F4F3F3F4F3F7F7F7F3F4F4F7F7ECF3F4EDF7EFF8ECEFF8ECF7FFF5F7F4ECF7F8F7FFF0\
F3EFF4F7EFE8F7F6F8FFECF4F1F7F8FFF7F8FFFFFFFFFFFFF7F7F4F7F7F4F7F7F7
FFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF7FFF7F7FFF7FFFFFFF5F4F4F1FFFFF5FFFFF5FFFFF5F7F8\
F5F7F8F5F7F8F7EBF4F7F2F8F7FFFFF3F6F8F7F2F8F7F6F8F7F6F8F3FFF8F7F2F4
FFFFFFF7F2F4F7EFEEFFF6FFF7EFF0E5F7F3EBE0C4FFFFEFFFFFFFFFEFECF7F7EFF7F7EFF7F7EF\
F7EFEFBCD9E2B0B2AA907D7BDACCD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
F7CDB2FFE7E2F7F7EEFFF3F4E6CFD1F1E6DCFFFFFFEED1E2F7F4F4F3E0F8F3E6FFF3EEF4F7E8E8\
F3E6E9F5F4F4EAF4ECE2F6EEE3F7FFF3ECF8F7EEFFFFE5EFFFFFF3FFFFF3FFFFF7
FFFFF7FFFFF7FFF7F8FFF7F8FFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFF6F0FFF2E9E3ECEE\
E3EFF8FFFFFFE3EFF8E3EFF8FFFFFFFFF7F8FFF7F8FFFFFFFFF4F4FFFFF7FFFFF7
FFFFF7F7F7EFF7F7F8FFFFFFF7F7F8FFFFFFF3E7F0F7F2F4F3FFF8FFF6F4FFF6F4F7F6FFFFF3F4\
F7FFF8F7ECF4FFE7E5F7E5EDFFFFF3FFF7F8FFF7EFFFFFF3FFFFF7F7E0EEFFF3F4
FFE7EEF7E5F0F7F7F8F7F7EFFFFFF3F7E4EDF3ECF8F7EFF0F7EBF4F7F2F8FFF2F8F7F7F4F7EFF4\
FFF7FFF5FFF8F5F4F4F7F6F8F7F6F8FFFFFFF7F7F7F3F4F3F3EDF7F7F4F3F7F7F8
F3F4F4F3F4F4F7F7F4FFFFF8F7F7F8F7F7FFF7F7F8F7F7F4E4F4FFFFFFFFEAF4F8F7FFF0F7EFF8\
F7EFE7F3F6E7FFF6FFF5F4F4F5F7F4FFF7FFF7F7F7F7F7F7F7F7F7FFFFFFF3F4F3
FFFFFFF7F7F7F7F4F3F7F4F3FFF7F7FFF7F7FFF7FFFFF7FFF5F4F4F1FFFFFFF7F8F1F7F8FFF7F8\
FFF7F8F5F7F8F7EEF8F7F6FFFFF6F8F7F6F8FFF6F4F3FFF4FFFFF4FFFFFFF7F2FF
F7FFF8F7F2F4F7EFEEF7ECF0F3E8E2FFFFF7F3DBC4FFFFE8FFFFE8F7EDF4F7EDF4FFEFEDF7FFEC\
FFF7F7DEDDDECDBB9FCEB6C4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DCD6
FFCBC1F7F6F8FFECF8F7F7EEEBC6D0F1EEE1F5E5F8F2E0EDF3E7EFF3EEF8F7FFF8FFF7EEEBE4E5\
F7ECEEF5F7F4EAEDE8F7EEF4F7EEFFF7F7F8FFFFFFF7F7ECFFFFF7FFFFF3FFFFF7
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFF2E9FFF6F0E3ECEE\
E3EFF8FFFFFFE3EFF8E3EFF8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFF7FFFFF7
FFFFF3F7E4F4F7E0F8FFE4F4F7F4F4FFE5F8F3F3F4FFFFFFF7F2FFF7F6F8F7F6F8F7F6F8FFF7F8\
FFE5F8F3F4EDF7F7EFFFFFF7FFFFF7FFF4F4FFF7F8FFF7F8FFFFF3FFE5F8F7E4ED
F7F7ECFFFFF3FFFFF3FFFFF7FFFFF7F7F7F4F3ECF8F3EBF8F7FFF8FFF6FFFFF2F8F3F7F4FFEFF7\
F5F7F4F5FFFFFFECF4F3F2F8FFF6FFEEFFF8EBF4F3F3F7F8F3F7ECF7F4F3F3F4F4
F7F7FFF7F7FFF7F7FFF7F7F4FFFFF8FFFFF8F7F4F8F5F7F8FFFFFFECF7FFE4F4FFFFF7EEF3F7F4\
F7EFE8F7F2F8FFF7F8F5F7F8F5F7F4FFF7FFF3F4F3F7F7F7F3F4F3F7F7F7F7FFFF
F7F4F3FFFFFFF7F7F3F3F7F7F7F7FFFFF7F7FFF7FFFFF7F8FFF7F8F5F4F8FFFFFFF1EFF0FFF4F4\
F5F7F8FFF7F8FFF7F8FFF6F8FFFFFFF3F2F4F3FFF8F7FFF8F7FFFFF7FFF4FFF2F8
F7F6FFF7FFFFF3F3F8F3E4EEF7EFE5E5F7FFE6D9B9F7EDFFF7EDFFFFEFF4F7EDF4FFEFF8F7FFF7\
F7EFEFEBE0D7D1B096EEE4EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7D4C6
FFDCDCF7EEFFFFEEFFF3EEE9F3CED6F5EEE7F7E4E5ECE6EEF7E6F8F7EEF4E2F7F4EAEFEEF3E0E1\
F7F7F8F1EDE8F3E5EDFFECF4FFFFFFF3F4EDF7F7EFFFFFF7F7F7F4FFFFF7FFFFF7
FFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0FFF6F0\
FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFF7FFFFF7FFFFFF
FFFFF3F7DBEEF3EEF8F7FFFFF7ECF8FFF6F8F3ECF8FFF7F8F7F2FFF7EBF8FFF3F4FFF7F8FFE5F8\
FFFFFFF7F7ECFFF7F8FFF4F4FFF4F4FFF7F8FFFFFFFFF7F8FFF4EDFFF7ECFFFFF7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFE5F8F7E0F8F7F3F4FFF6FFFFF6F4F7FFFFF7EDEC\
F5F7F8F5F7F8FFF3F8F3F6F4FFFFF8EEFFF8EBF4F3F3F7F8F3F4F4F7F7F7F3F4F4
F2F4F8F5F4F4F7FFF8F3F4F8F7F7F8EAEDF8ECF4F8EAF7F8EAF7F8ECF7FFE3F7F0F3EDF8F7EDF4\
F3E5EFFFEEF0F5F7F8F1FFFFF5F7F4FFF7FFF7F7F7F7F7F7F7F7F7F3F4F3FFF7F7
F7F7F7FFF4F3F7F4F7F3F7F7F7FFF7FFFFFFFFF7FFFFF4F4FFF4F8F5F4FFFFF7F8F1F7F8F5F7F8\
FFF4F4FFF4F4FFF6F8F7F6FFF7F2F8F7F6F8FFF6F4FFF6F8F7F6F4FFF6FFF7F2F8
F7F6F8F7FFFFF3F7F8F3EDEEF7EFE7E5F7F7E6CFB9FFF7F8F7F4F8F3F4F8FFEFFFFFFFEFFFEFEC\
FFFFEFEBE0D7C2AA96FFEDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DDD7F7D4BE
F7DDE7F7EEFFFFECF8EBF3E5F7D1DBFFEEF8EAF7ECF3F4F8EEECF4ECECF8F7FFFFE2F7F0FFDBE1\
F3EFF0EAE5E5F7F2F4FFF4F4FFFFFFF3F4EDF7F7EFFFFFF7F7F7F4FFFFF7FFFFF7
FFF7F8FFF7F8FFF4F4FFFFFFFFF4F4FFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0\
FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFF7FFFFF7FFFFF7FFE5F8FFDBE8
FFE5F4F7E5F0F3F7F4FFFFFFF3ECF8F7F7F8FFEEF8F7EBF8FFFFFFF7ECF4F3E6FFF3EBF8F7EFF0\
FFE5F8F7E4E8FFF7F8FFF4F4FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4
FFF7F8FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7F7F7F8F7F7F8F7F4F4F7F2F8FFFFF8F7F7F7F7F4F4\
FFF4F4F1F7F8F7FFFFF7F2F4FFFFFFF7F7F7F7F7F7FFFFFFFFFFFFF7F7F8F7F7F8
F5F7F8EAF7F8F3FFF4F7F7FFF7F7FFF2F4F8ECEDEEF7F4F4F7F4F4F7EDE2F7E8E5F7DDE1F3E6DB\
ECECEEF5F7F8F1FFFFFFF7F8FFF4F8FFF7FFFFFFFFF7F4F3FFF7F7F7F4F3F3F7F7
F7FFFFF3FFFFF7FFFFFFF7F7FFF7F7FFF7FFFFF7F8FFF7FFF5F7FFF5FFF8F1FFFFFFF7F8FFF7F8\
FFF7F8FFF7F8F7F2E5FFFFE5FFF2FFF7F2F8F3FFF8F3FFF4F3FFF4FFFFFFFFFFF8
FFF6FFF7F6F8F7FFFFF7EFF0F7EFE7FFFFF7EBC3B3F7FFF8FFF7F8F3F7F8FFEFEDFFEFF7FFFFFF\
FFF6F8F3E0E3DEC1A6F3D5D0F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF0F3C9B2F3E4E5
F7FFFFF7E5EFFFEFE7EBE0E5F7D9DBFFE6F4F5EEE7F5FFEFD9E0F4EEEEF8EAF7EEF3EFEDEBDCE5\
ECEDEEEAF4ECFFF2F8F7F3F4F7EEFFF7F7F8FFFFF7F7F7F8FFFFF7FFFFF7FFFFF7
FFF4F4FFF4F4FFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFFFF7FFFFFFFFFFF7FFFFFFFFE5ECFFDBF4
FFFFFFF7E4F4F3ECF8FFFFFFF7EEFFF7F7F8F3EBFFF7F6F8F7EEF8F7F7F8F3ECF8F3EEFFF7FFFF\
FFEBF4F7DBE1FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFF7F8FFF4F4
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F7F8F3ECF8FFF6F8F7E6EEFFF7FFF7F7F7F7F4F4\
F5EDEEF5FFFFF7FFFFF7F2F4FFFFFFF7F7F7F7F7F7FFFFFFF7F7F8FFFFF8F7F7FF
F7F7FFFFF7F8FFF7F8F3F4FFF3F4F8F7F7F4F7F7F8F3F4F4F3F4EDEEF7F7F3EEF0F7EEF0FFFFFF\
F5FFFFF5F7F8F1F7F8FFF7F4FFF4F7FFF4F3F7F7F3F3F4F7F7FFFFF7F7FFFFF7FF
F7FFFFF7F7F7FFF7F7F3FFFFF7F4F3FFF7FFFFF7F4F5F4F4F5F4F4F1F7F8F1F7F8FFF4F4FFF7F8\
FFF3F8FFF6FFF3F2E5F7F6EDFFF6F8FFF2F8F7FFF8F7FFF8F7FFF8FFFFFFFFFFF8
FFF6FFF7F6FFF7FFF8F3E8E9E5F7F3E5F7F7E6C8BAF7F7F4F7F7F4F3F7F8FFE8EFFFFFEFFFF6F8\
FFF6F8F7EFF0E2C9B2D1BBBAF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0D4F7CDC4F7FFFF
F7ECF8F7F4E8FFE4E8F3E4E9F3E8DCFFFFFFFFE6F4F1FFE8D6EDF8F7FFF0EAF7EEF3E8E8E3E6E9\
F1F4F4F3F4E8FFEBF8F7ECF8FFE5F8F3F4EDFFFFFFF7F7F4FFFFF7FFFFF7FFFFFF
FFF4F4FFF4F4FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF4F4FFF7F8\
FFF7F8FFF4F4FFF7F8FFF7F8FFF7EFFFFFF7FFFFF7F7F7ECF7F7EFFFFFF3F7F7F8
F3ECF8FFFFFFF3ECF8FFE5F8FFFFFFFFF6F8F3EEFFF7FFF0FFEBEEFFE6E9F7EBEEF7ECEEF7ECF4\
F7FFFFF3E0DCFFFFFFFFFFFFFFFFF7FFFFF7FFFFFFFFF4F4FFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFF7F7ECF7F7F8FFE5F8F3ECF8F7E4EEF3F6F4F3F4F3F7EDED\
F1F4F4FFFFFFF7F6F8F7F6F8FFFFFFEEFFFFF3F4F3FFFFFFF7F7F8F7F7F8F3F7F8
F3F7F4F7F7F4F7F7F4F7F7EDF7F7F4F7F7F7F7E7F3FFECECFFFFEFF7F6F8F7F3F4FFF7F8FFFFFF\
F5FFF8F1F7F8FFFFF8F5F7F8FFE8F3F7FFFFFFF7FFF7F7FFF7F7F7F3F7F3F7F7F3
F3F7F7F7F7F7FFFFFFF3F7F7F7F4F3FFFFF8FFF7FFF5F7F8F1F4F4FFF7F8F5FFFFFFFFFFFFFFFF\
FFF3F8F7F6FFFFF6F8F7FFF4F3F6F8F3F2F4FFFFFFFFF6F8FFF6F8FFFFFFFFFFFF
FFF6F8F7F6FFF7F6F8F3E0E9E5F7F3E5F7F7EBC8C4F7F7F8F7F7F8F7F7F8FFEFFFF7FFE1F7F2F8\
FFFFFFFFF6F8F7D1B9D1AAA0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF0FFDCC1FFDBDEFFF6F8
FFF3F4FFE4E8FFE5ECF7DCE6EBDCDDFFF7F0FFE6F4F1FFE8E6F4F8E4F4F8E4F4F4F3E8E8E3E6E9\
F1EDEDF3F7EDF7EEF4F7EEFFF7F7F8F7F7EFF7F7F8F7F7F4FFFFF3FFFFFFFFFFFF
FFF4F4FFF7F8FFF4F4FFF7F8FFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFF4EDFFFFF7FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFF7FFFFFFFFFFF7FFFFFFF3F4F4F3ECEFF7E4EDFFE5F8
F7EEFFF7EEFFF7F7F8F3ECF8F7ECF8F7F3F4FFEEF8FFF6F8FFFFF8FFFFFFFFFFFFFFEBEEFFEBF8\
F7F6F8FFE4EDF7F7EFFFFFFFFFFFF7FFFFFFFFFFF7FFF7F8FFF7F8FFFFFFFFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFF7F7EFF7F7F4FFFFF7F7F4EDFFECF4F3F3EDF7F4F4F5F7F8\
FFF7F8F5F7F8F3F6F4FFECF7FFEFF7EEFFFFF3F4F3FFFFFFFFFFFFFFFFF8F7FFF8
F7FFFFFFFFFFF7F7FFF7EDECF7F7EFF7F7F7FFF6FFF7FFF8F7F6F4F7F2F8F7F7F8FFF7F8F5FFF8\
FFF7F8F5F4FFF5F7FFF5F7FFFFF4F7F7F7F7F7FFFFF3FFF8F7F7EFF3F4F3F7F7F7
F3F4F3F7FFFFF7F4F3FFF7F7FFF7F7FFF7F8FFF7FFFFF7F4F5F7F8FFFFFFF5F7F8FFFFFFFFFFFF\
FFF7F8F7F6FFF7F2F8F3FFF8F3FFF8F3F6F8FFFFFFFFF6F4FFFFF8FFF6F8FFFFFF
FFFFF8F7F2F8F7F6FFF3E0E9E5F7F3D9F4FFEBD4CAFFEFEDFFECEDFFECECFFFFE8F7F6E5F7F6FF\
FFF6FFFFF6F4F3E4DED89B82FFEFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0D4FFE4CBF7E4E6F3F2F4
F7F7EEFFE4E8FFFFF7FFE8E2E6D4DBF5E5D7F1F6EDF5F7E8E6F4F4EAF7F8F2F7F8F7E8E8E3E6E9\
F1E8E8F3F6F4F7EBF4FFE5F8F3ECF8F7E4EDF7F7F8F7F7F8FFFFF7FFFFFFFFFFFF
FFF4F4FFF7F8FFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFF4F4FFF4F4FFF7F4FFFFF7FFFFFFFFFFFF\
FFFFF7FFFFF3F7F7ECF3F4EDF7F7EFF7F7EFF7F7F8F7F7F8F7E4F4F7E4F4FFE5F8
FFFFFFF3E6FFFFFFFFF7FFF8FFF3F8FFF6FFFFFFFFFFF6F8FFFFF8FFFFF8FFFFF4FFF6FFFFFFF8\
F7EBF4FFE5F8F7F7F4FFFFF7FFFFF7FFFFFFFFFFFFFFFFF3FFFFF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFF7FFFFF7FFFFF3FFE4E8F3EEEEFFFFF8F3E8E8F5F7F8\
FFF7F8F5F4F4F7F6F8F7ECEFFFEFF7EEFFFFF7F7F7F7F7F7FFFFFFFFFFFFFFFFFF
FFFFFFF7F7F8F7EDF4EEEFF4EEFFEDEEFFF8FFFFF8F7F6F8F7FFF4F3F6F8FFF4F4FFFFFFF5FFF8\
FFF7F4F5F7F8FFF7F7FFF7F7FFF7F7F7F7F7F3FFFFF7FFF8F7F7EFF3F7F7FFF7F7
FFFFFFFFF7F7F7F4F3FFF7F8FFF4F4FFFFF4F5FFF8F1F7FFF5FFFFF5F7F8F5F4F4FFF7F8FFF3F4\
FFF3F4FFF6FFF7F2F8FFFFFFFFF6FFF7FFF8FFFFF8FFFFFFFFF6F4FFF6F8FFFFF8
FFF6FFFFFFF8FFF2FFF3E0E9E5F7F3D9F4F7EBE4DDFFF2E7F7FFEFF7FFF8FFF2F8F7F6F4F7FFFF\
FFF2F8FFEFEFF7E5EDD9AA94D9C6C9F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4B9FFDCE5EBE5DBF3F4E8
EBDBD7FFEFE5FFF7F8F7D9D6EBD9D6F1EBE5F5FFEFF2EFECE3F7F0ECF7FFF5F7F8EEE8E8E3E6E9\
EAE8E1F7F2F8FFF4F4F7F7F8F7EEFFFFE5F4F7F7F4F7F7ECFFFFFFFFFFFFFFF7F8
FFF7F8FFF4F4FFF4F4FFF4F4FFF4F4FFF4F4FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFF7F7EF\
F7F4F4FFF7EFF7F7F8F3F4F4FFEEF8FFE0F4FFE5F8F7E4F4F7E4F4F3EDEEF7F4F4
F7EEFFF3E6FFF7FFF8F7F7F8F7FFFFFFF6F8FFF6F8FFF6F4FFFFFFFFF6F4FFF6FFFFFFF8F7F6F0\
F7ECF8F7F7F8F7F7F8F7F7F4F7F7F8FFFFF7FFFFF3FFFFF7FFFFF7FFFFF7FFFFF7
FFF7F8FFF7F8FFFFFFFFFFF7FFFFF7FFFFF7FFFFF3FFFFFFF7E4EDF7EEEEFFFFF8F3EDECFFEFF0\
F1FFFFFFF7F8F7F6F8F7F6F8FFFFFFEBEFFFF7EFFFF3F4F3FFFFFFFFFFF8FFFFF8
F7F7F8F7F7F7FFFFEFEEFFEFEBEFEFEBEFEDFFF6EFFFF2F8FFFFF8F3F6F8FFF4F4FFF7F8F5F7F8\
FFF7F8F5FFF8FFEDF3FFF4F3F7F7F3FFF7FFF7F7FFF7F4F7F7FFFFF7F7F7FFFFFF
FFF7F7FFFFFFECEFEFF5F7F8F5FFFFF5F4F8F5F4F4F1F7F8F5F7FFFFF4F4FFFFFFF7FFFFF7F6F8\
FFEEF0FFF7F8F3FFFFF3F2F8F3F6F8F7F6F4F7F6F8FFF6F8FFFFFFFFFFFFFFFFF8
FFF6FFFFF6FFFFF6F8F3E0E2FFFFF7FFFFF3F7E0E3F3F2F8F7FFF8F3F6F8F7F6F4FFF6F4F7FFFF\
F7EBE5F7EDF4FFE8EDDAC8A3D9AAA7F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFAEFFE0EEE6ECD6FFFFFF
E6CFC6FFF7EFEEDDD6EBD4CEF7F4F4F1EBE6F5F7FFF2EFECD9F4F0F5F7F8F1F4F4F7EDEDDFDBDD\
E4EDE1FFF2FFF7F3F4F7EEFFF7F7F8F3F4F4F7F7F8FFFFF7FFFFF7FFFFFFFFF7F8
FFF7F8FFF4F4FFF7F8FFFFFFFFF7F8FFF4F4FFF7F4F7F4F4F7F7EFFFFFFFFFFFF7FFFFF3F7F7F4\
FFF7EFF7F4EDF7F7F8F3F4F4F7E7EEF7EBF4F7EEFFF7EEFFF7FFF8FFEBF0FFEBF0
FFEEF8FFEEF8FFFFFFF7ECF4F7EBF8FFFFF4FFFFF8FFFFFFFFFFF8FFF6F4FFF7F8FFE6F4F7E6F8\
F7EEFFFFFFFFF3F4F4F7F7F4F7F7EFFFFFF7FFFFF7FFFFF7FFFFF3FFFFF7FFFFF3
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFF3F7F7F8F7E0EEFFFFF4F7F4F7F7F4ED\
F1F4F4FFFFFFF7FFF8F7F2F8FFFFFFF7EFFFEEF7F7FFF7F7F7FFFFFFFFF8FFFFF8
F3F4F4FFEFF8FFEFF7EEFFEFF7EFEFF7EFEFFFF2E5F7FFF8F3F2FFF7F2F8FFF7F8FFFFFFF1F7F0\
F1F4F8F1F7FFFFF4F7FFFFFFF7F4F7F7FFF7F7F7F3F7F7FFF7F7F7FFF7F7F7F4F3
F7F7F7F7F4F3F5F7F4F5F4FFF5F7FFFFF4F4F5F4FFF5F7F4FFF7FFF5F7F8FFF7F8F7FFFFFFFFFF\
F3F7F8F3EEF0FFF6F8FFF6F8F7FFF4F7F6FFF7F6F4FFF6F8FFFFFFFFFFFFFFFFFF
FFFFF8FFFFFFF7E4E8EEF7E5E3F4F7E3F4FFDFD9CBEBF3EFF3F6F8FFFFF8FFF6F8F7F6FFF7EFEE\
EED4D0F7F7F8FFEFF8D9C9B6E3A28DFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7DDD7F7CCB4EECCCFE3C9C5F5DDDE
EED9DED6B0BAD6BAC9E4D9DEA9B8BA8FAAA7A8C2C4CEE0E8E5F4F4ECF7FFF5F7F8ECE8E8D9CDCF\
EAF7EDFFEBF8F3EBF8F3E6FFFFFFFFF7F7F8F7F7EFFFFFF7FFFFF3FFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF4F4FFF4F4F7EDE5F7F7EFFFFFFFFFFFF7FFFFF3FFFFF7\
F7F7F8FFFFFFFFE5F8F7EEFFF7ECF8F7EEFFFFF4F4FFF7F8FFE6F4FFFFF4FFF6F4
FFF7F4FFEEEEF7EEEEF3E6E9F7F7F4FFF6F8FFFFF4F7FFF0F7EEEEF7EEEEF7E6F8F7EEFFF3ECF8\
F3F4F4F7F7F8F3F4F4F7F7F4F7F7EFFFFFF7FFFFF3FFFFF7FFFFF7FFFFF7FFFFF3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFF7FFE5F8F7E5F4F7F6F0F7ECF4F7F4F4\
F5F7F0F5F7F8F7F6FFF7F6F4F7F7F7EBF7F7EBF7F7FFF7F7F7FFFFFFFFFFFFFFFF
F7F7F7F3F4F7EBEDF3EBF7ECF7F7ECFFFFFFFFF6F8F7F2F4F7F6FFF7F6F8F7F2FFFFECF4F1F7F4\
F5F7FFF5FFFFFFFFFFFFF7F7FFF4F3FFF7F7FFF7F7FFFFFFF7F4F3F7FFFFF7F4F3
F7FFFFF5EFEFF5F4F8F5F7F8F5F4F8F1F4F4F5F4F8F5FFF8F1FFFFF1FFFFFFF7F8FFF4F4F7F3F8\
F7F6FFF7F6F8FFF6F8FFF6F4F7FFF8FFF6F8FFFFF8FFFFF8FFFFFFFFFFFFFFFFFF
FFF6F8FFF2F8F7ECF0EEF7E5E3F4F7E3F4FFEEB2A3EBB5C4EBBDC8EBE5DEF7F7F8F3F4EEF7EDE6\
F3C3CBF7FFF4F3F7F8FFE5DED69589F7CCB5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8F7D4BDF7D9C4E3C9C5FFFFFFF5E7E2
E3D5D7F2EDE5F3EEF8D1D5CDBCCCCDECF7F8F7F7F7C7DCDDD1E0E8E2EBF4F7F6F8E2DCDCD6CFD1\
F3F6F4FFECF4F3ECF8F7E4F4F3F4F4F7F7EFFFFFF7FFFFF7FFFFF7FFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF4F4FFFFFFFFF7F8FFF7F8FFF7F8FFFFF7F7F7ECF7F7ECF7F7ECF7F4ED\
F7F4F4FFFFFFFFE5F8F7EEFFF7EEFFF7F3F4FFF7F8FFF6FFFFF7F8FFF6F8FFF6F8
F7F6F4F7FFFFF7FFF8F3FFF4F7F6F8FFFFFFFFF2FFF7F2F8F7ECF8F7EEFFF7EEFFF7EEFFF3ECF8\
F3F4F4F7F7F8F3F4EDF7F7EFF7F7ECFFFFFFF7F7EFF7F7F8FFFFFFFFFFF7FFFFF7
FFFFF7FFFFFFFFFFFFFFFFFFFFFFF7FFFFF7FFFFF3FFFFFFF7E4F4F3E6FFF7F7F4F3ECE8FFF4F8\
F5F7F0F5F7F8F3F2F8FFFFF8F7F7ECEEFFEFF3F4F3F7F7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF3F4F3EBF7F7F7F7F7FFFFFFFFFFFFFFF6F8F7F2F8FFF6FFF7EEF8FFE5F0F1FFF8\
F5F4F8F5F4F4FFF7F7FFFFFFFFFFFFFFF7F8FFEFEFFFF7F7FFFFFFFFF4F3F7F7F7
F7FFFFF5EFEFF5F4F4F5FFFFF5FFFFF1F7F8F5F4F4F5F7F8F5F7F8F5FFFFFFFFFFFFF7F8FFF6FF\
F3F7F8F3F6FFF3F6F8F7FFFFF7FFFFFFF6F8FFFFF4FFFFFFFFFFFFFFFFFFFFF6FF
FFFFF4FFF6FFFFFFFFF3E8DCFFFFFFE5F7F7C89891E3FFFFF3DCE7EBC9C5F3EEDEF3F4EEF7EDEE\
F3CDD7F7EFE5F3F7F8F7F7F8E2BDC3E3A386F7EFF0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE4D6FFDCC3E6C6C5F1D9D6F1EEE1E3E0DE
E3E5E5DED4D6D0D4D787A0A3CACDDBDEE4EEECF7F8F7F7F8D9E5E5E6EDECE3EEEDCACFD6E4DBDD\
F3EBEDFFF4F4F7F7F8F7F7F4F7F7F4F7F7ECFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8F7F4F8F7F7F4FFFFFFFFFFFFFFFFFFFFFFF7F7F7EFFFFFFFF7EFF0F7F7F8\
F7F7F8F7EDEEF7E4EEFFE6EEF7E6E9F7EBF4FFEBF8FFFFFFFFF7F8F7F6F8F7EEF4
F7EBF0ECF2EEE3F2F4FFF6FFFFF6FFFFFFFFF7F2F8F7F2F8FFECF4FFF7F8FFF7F8FFEEF8F7ECF4\
F3F4EDF3F4E8FFFFFFF7F7F4FFFFF3FFFFF7F7F7F8F7F7EFFFFFF7FFFFF7FFFFF7
FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F7F7F8FFF7F8F7F7F8FFEBF0F3F4ECF5F4F4\
F5F4F4FFF6FFF3F6F4EEFFFFEBF7ECF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFF8FFF7F7F3EDF8EEFFEFFFFFF8EEFFF8EEFFF8F7F2F8F3F6FFF7F7F8FFEEF8F5F7F8F5FFF4\
F5F7FFFFEDF4F5F7F7FFF7FFFFF4F8F5F7F8F5F7F8FFF4F8F5F4F8F5EDEFFFEDF7
F5EFF7F5EFF7F5F4F8F5F7FFF5F7FFFFF4F4FFF7F8F5F7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8\
F7ECF4FFF6FFF7F6F8FFFFFFFFF6F8FFFFEDFFFFEDFFFFEFFFFFEFFFFFFFFFF6F8
FFFFF8FFFFFFF7F3F8EEF4E1E5F7F7E5F7F3C59D97EAF4F4E3FFF8EEC9DBF7DDDFFFF6E5F7EFF0\
F7ECE6FFE0ECFFFFF8F7F7FFFFEEE7DE937BF3D9D4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFD9BDFFE5DEE6C8CBF5E6E5F7F7F8CFEFE2
ECF7F4D1DBDC99AFB4E3E6EFB4BCCBF7EEF8D6E4EED9E4F0E3EEF8EAEFF0EAEFE5B9C1D0D6DBDD\
EBF3E5F3E7F0F7F7F8F3F4E8F7F7ECF7F7ECFFFFF7FFFFF3FFFFF3FFFFF7FFFFFF
FFFFFFFFFFF7FFFFF7F7FFF8F7FFF8FFFFF7FFFFF3FFFFF7FFFFFFFFFFF7F7F7ECF3EDE1F7F4ED\
FFF7F8FFF4F4FFECF4FFEBF0F7F2F4F7EBF0E3EBF4E3F3FFFFEBF8F7FFF8FFEEF8
F3E4E5EAE6E1EAEBE8F3EEEDF3EEEDF7F6F8F3FFF4F3F6F4FFF7F8FFF6FFFFF7F8FFEEF8F7ECF4\
F3F4EDF3F4E8FFFFF7FFFFFFF7F7ECFFFFF7FFFFF7FFFFFFF7F7EFF7F7F4FFFFF3
FFFFF7FFFFF7FFFFFFFFFFF7FFFFF7FFFFFFFFF7ECF7E5F8FFEEFFF7F4F4FFF2F4F3EDF3F5F7F4\
F5F4F4F7F2E7F7FFEDEEFFFFEBEDF3F7F7FFF7FFFFF3F7F8F7F7F8FFFFFFFFFFF8
FFFFFFF7F4ECEEFFEFEBEFEFEEFFF4EEFFF4EEFFF8F3F2F8F7F6FFF7ECF4FFFFFFF5FFFFF1F7FF\
F5FFF4F5FFFFF5F4FFF5FFFFF5F4F8F1F7F8F1FFFFFFFFF8F1FFF8F1FFF8F5F7F8
FFFFFFFFF7F8FFFFF8FFFFF8FFFFF8FFF7F8FFF7F8F5FFFFFFFFFFFFF7F8F7ECF4F7ECF4FFF7F8\
FFF7F8F3F7F8F7FFFFF7F2F8FFFFF8FFFFEFFFFFEFFFFFEFFFFFEFFFFFF8FFFFF8
FFF2FFFFF2FFF7EBF8EBF7E5F5F7FFE3EDEDC4A9ADECF7F8ECF7F8F3D4E1F7E8E6F7EBE1FFFFFF\
F7FFF8F7E4EFFFE8ECF7EDEFF7EDFFD1A390F7BAB2FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFF7F7F8F3E8E9F7D1B2F7E5E8E2C6C1F5EEEDEAF4F7C4D5D0
BDC8CBBCC5C9E6EEEFACBBBEC4C2CAD1D9E6EBECF4F7F7F8EBEBF8F7F7F8F2EDE5B4C3CAD6CFD1\
EBEEE9F3ECF8FFFFFFFFFFF7F7F7F4FFFFF3FFFFF7FFFFF3FFFFF3FFFFF7FFFFFF
F7FFF8F7FFEFFFFFFFFFFFF7FFFFFFFFFFF7FFFFF3FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFF7F7EC\
F3F4EDF3F4E8F7F4E1F7EDDBF3E8DCF3EDE1D9EDEDD9E8E8F3E0DCF7E0E5F7E6EE
F7E5E7FFF4F3FFFFFFFFF7F7FFF7F4F7EDE1F7EDE8F7E7ECF3ECEDF7EEF0FFECF4FFECF4FFECF4\
F7ECF8F3ECF8FFFFFFFFFFF7FFFFFFF7F7EFFFFFFFFFFFF7F7F7F8F7F7F4FFFFF3
FFFFF7FFFFFFFFFFF7FFFFF3FFFFF7F7F7ECF7E5EFF7FFFFF7FFF8FFEBF0FFEEF8F3EDECF5F7F0\
F5EEF0F3F6EDFFFFEFFFFFEFEEEFF8F3F4F7F7FFFFF3F7F8FFFFFFF7F7F4F7FFF8
F7FFF8F3F4ECEBEFFFEBEFFFEEFFF8FFFFF8FFFFF8F7F2F8FFFFFFF7F7F8FFF7F8FFFFFFF5FFFF\
F5F7F8F5F7F4F5FFF4F1F4F8F5FFFFFFF4F4FFF7F8F5F7F8F1FFFFF5FFFFFFF7F8
F5F7F4F5FFF8FFF7F8FFF7F8FFFFFFF5F7F8F5FFFFF5F7F8FFF7F8F7F7F8FFF6FFF7EEF8FFF7F8\
FFF7F8F7F7F8FFF6F8F7FFF8FFF2F8FFF6F4FFFFF8FFFFEFFFFFEFFFFFF8FFFFF8
FFF2FFFFF2FFF7EBF8EBF7E5F5F7F7E3EDE5C4AEB2ECEFEFECF7F8F7CFE1F7F4E6F3E6E5FFF6E5\
F7F6E7FFF6F8F3F2F4F7ECE5FFEFF4D9C2BDE3A28DFFF7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFF7F7F8EBD1CCF3D9BDEBEBE5EAC8C4F1EEE1E2F6F4A4AEB9
BED5D6BEDBDDBEB8BCFFFFFFA0AEBDF3F3F4FFF6F8F7F7F8E5ECF8D9E4F4EAEDEEBDC3C4D6CFD1\
F3EBEEF7F4F4F7F7F8F7F7F4F7F7ECFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF7
F7FFECF7FFF4FFFFF7FFFFFFFFFFF3FFFFF7FFFFFFF7F7EFF7F7EFFFFFFFF7FFF8F3FFF4F7FFEF\
FFFFFFFFFFF7F7FFF8F7FFF8FFFFFFFFFFFFFFFFF3FFFFF3F7F7EFF7F7EFF7EEFF
EEEEEEF3FFF4F3F7EFF7F7F7FFF7F8FFFFF4FFFFF8F5F7F8F1EFEDEAE8E1EAE0E1F7ECEFFFF2FF\
E2F6F4D9E7F8F7F7F8F7F7EFFFFFF7F7F7F4FFFFF7FFFFF7FFFFFFFFFFF7FFFFF3
FFFFFFFFFFF7FFFFF7FFFFF3FFFFFFF7F7F8F7E4F4F3ECF8FFE6F4FFF7F4F7F7F7F7F4EDF1F4F4\
F7F6F4F7ECF7FFEFECF7EFFFF3EDF8F7F7EFFFFFF8FFFFF8F3F4F8F3F4F8F3F7FF
F7F4F4F7EDECE6FFEFFFFFEFFFFFFFEEFFFFEEF6F4F7F6FFF7F7F8F7F7F8F7F7F8FFF7F8F5F7F8\
F1F7F8F5FFFFF1FFFFF1F7F8F5F4F8F5FFF8F5FFF8F5F7F8F1FFF8F5FFFFFFFFFF
F1F7F8F5F7F8F1F7F8F1F7F8F1FFFFFFFFFFFFF4F4FFF7F8F7F7F8FFF6FFF7F3F8FFFFFFF7F4F4\
F7F7F8F7F6FFFFFFF8F7F6F8FFF6F8FFFFF4FFF6F8FFFFEFEEFFEFEEFFFFFFFFF8
FFF6F8FFFFFFEBECE5FFF7EFEEF7E7F3E8E2C4B5BAFFF4F3E4E4F4F7E5EFF7EFEEF7E5E7F3ECEF\
F3EEE1F7F6F8F7FFFFF7DBE8F7F7F8F7DBDBD89D84FFEDE5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFF7CFC0FFE0D0EBDCDBF1D9D6EAEEDCC3DDDB8FA7B6
DAE5E2819CA4F3ECECDADDDFCED9E1B4C1CEB5B9C4F3DCDEDEEDF8CED4E9D9EDF4BDBCBED6D5D6\
F3F2F4F7EDEEF7F7F8FFFFF3F7F7EFF7F7EFFFFFFFFFFFFFFFFFFFFFF7F8FFF7EF
FFFFF3FFFFF7FFFFFFFFFFF7FFFFF3FFFFF7FFFFF7F7F7F8FFFFFFF3F4E8F7F4E1F7F7E1F7FFF4\
FFFFF3FFFFF3FFFFFFFFFFFFFFFFFFF7FFF8F7FFEFFFFFF7F7F7EFF3F4E8E3E4E8
E2EBE7F7EEF4F3FFEEF7F7F7FFEDF3FFF4F7FFF4FFF5FFF4F5FFFFFFFFFFF5FFF8EAEDE2E4DCDB\
F3EBE5D9EEF8F3F4F4F3F4EDFFFFF7F3F4F4F7F7ECFFFFFFFFFFF3FFFFF7FFFFF7
FFFFFFFFFFFFFFFFFFF7F7ECF7E4F4FFE5F8F7F7F8FFFFFFF7E0E9F7F4EFF7F7F7FFF7F4F1F4F4\
F7F6F4F7ECF7FFEFECF7EFFFF7F4F4FFFFF4F7F7F8F7F7F8F3F4FFF7F4F4FFF7F8
F7F4F4F7F4F4F3F4F4EBF7ECEEFFFFEEFFF8EEF2F8F7FFFFF3F7F8FFFFFFF7F4F4FFF7F8FFF7F8\
F5F7F0F5FFF8F1FFF8F1FFF8F5F7F4F5FFFFF5F7F8F1FFF4FFFFF8FFFFFFF5FFFF
FFF4F4F5F4F4F5FFFFF5FFFFF5FFFFFFF7F8FFF7F8FFFFFFF7FFFFF7F3F8FFEEF8FFF4F4F7FFFF\
FFFFFFFFF6FFFFF6FFF7F6F8FFF6F8FFF6F8FFF6F4FFFFF8EEFFFFF7F7F7F7F7F4
FFF6F8FFF6FFEEF7E7E3EDE5F7EFEDF7EFF0CBC1C6F7EDECE2DCEDD6DBECE2DBE8F3C8D6F3C3D1\
E5CCCDEEE5DFF7F6F8F7E4EFF7F7E5F7E4E1DEA290F3D5CBF7F7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8FFD4C0EBD4C4ECD1CDFFEEF8EADDCD9BC2B39BAEB6
B5D5DEB9C2CB86A8B468889F8FA3B6B9BDC6BEC6D3DAEBF4BEC2D6ECE5F0DAEDF49CB5BED6D5D6\
F3EBEEF7EFF0F7F7F8FFFFF3F7F7EFFFFFFFF7F7EFFFFFFFFFFFF7FFF7ECFFF7EC
F7F7ECF7F7ECFFFFF3FFFFF7F7F7EFF3F4E8D9EDEDD9E8E8F7F4EDF7F7F8F3F4EDFFF7E5F7FFF4\
F7FFF4F7FFF4FFFFFFFFFFFFFFFFFFF7FFF8FFFFFFD9EFF4DAEFF7FFFFFFD9EDEF
DAEFFFF7E0EFD6F6F0EAF6EEF7FFF8FFF7F7FFEDF3FFEDE8F1F7F8FFF7F8FFF4F4FFF7F8FFEDEE\
E3E8DBD8DCD6E2DCDFF3E4E5F7F7EFFFFFFFF3F4E8FFFFFFFFFFF7FFFFF7FFFFFF
FFFFFFFFFFFFFFFFFFF7F7EFF7E4EDF7EEFFFFFFFFFFF7F8F7E4E6F7F4F7F7F4F3FFEDE8F1F7F8\
FFF2F8F3FFF8F7F7F7F3F4F4F7F7F8FFFFF8F7F4F4FFF7F8F7F7FFFFF7F8F3F7F8
F7FFFFFFF7F7F3F4F3F7F7F7E6FFF8FFFFFFFFF2F4FFFFF8F7FFFFF7F7F8F7F4F4F7F4F4FFF4F4\
F5F7F0F5F7F0F5F7F0F5FFF8FFF7F8F5F7F4F5FFF8FFFFFFF5FFFFF5FFFFFFFFFF
F7ECF4F7EBF8F7ECF4F7F7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF4F4FFF7F8FFF7F8F7F7F8F3FFFF\
F7FFFFF7FFFFF7FFFFFFF6F4FFF6FFFFFFF8FFFFF4FFF6F8FFF6FFEBF7F7EBF7F4
EEF6F8FFF6FFEEF7E7E3EDEDF7EFF0F7EFF0CBC1C6EBE8E8F3F7F8EBE0E2D6D4D6CBDBDCCBCDD6\
D0B0C4DAB6B9EBCBC3F7F6DCFFEFFFF7FFF8DEAB9CEBB2A4F7F7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFEDEEFFD1B6E6C9C1F1D9D6F1EEE1F7E0DD818F96BCCECB
97BDC5D9E5F07B9DB2EBEBF493A0B9D6CCC6D9DDD6BCC8D6BECFDCFFEEF0DAE0E6ADBDC4CBCFD1\
F3E6E9F7F7F8F7F7F8FFFFF3F7F7EFFFFFFFF7F7F8FFFFF7FFFFF7FFFFF3FFFFF3
F7F7EFFFFFFFF3EDEEF3E8E2F7EDE5FFF4F4E3EEF4ECF2F0F3EBEEEBDBDDEEDDD6F7FFEFF7FFEF\
F7FFECE3EFE5D9E8E1F3EDE1F7E4E8E3D4DBDECFCBEAD9C8E2D9CFD8CFCAD6C6C1
D6C6C1D8DCCFD9E1D0E2E1D6F2F7F4FFFFFFFFEFEFF5EDEDF5F7F8F5F7F8F5F7F8FFFFFFFFF7F8\
FFF7F8FFEFF0EAE6DFF7E4E7FFF7F8F7F7F8F7F7ECFFFFF7FFFFF7FFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFF7FFFFF7F7F7F8F7EEFFF3ECEEFFF2F4FFF7FFF3FFF7F5E1E2F5F6F8\
F7FFF4F7F6E7F3F4F4FFFFFFFFF7F8F7F4F4EAEFEEE2F7F4ECFFFFF7F7F8FFFFFF
F7F7F4F7F7EFF3F4F3EBF3F7EEF2F8FFF2FFFFFFF8FFF6F8F7FFF4F3F6F4F7F2F4F7F2F4F3F2F4\
F3EEF0F3F7F8F7F4F4FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
F3ECF4F7F2FFF7F6FFF3F4F4FFF7F8FFFFFFFFFFFFFFF7F8FFFFFFF7F7F8F3F7F8F7FFFFF7FFFF\
F7F6FFF7F6FFF7FFF8FFF6F8FFF6F8FFFFF8EEFFFFEEF6FFFFF6FFEEFFF8E6FFF8
EEF6F4FFF6FFEEF7E7EBEDE2F7EFF0FFFFFFCBC8CBE6E4E5FFEDEEF7EBEDF2F4F3F5F7F7FFEFF8\
DFEDF4E2D9E2EECCDFF7D5DFF7FFE1F7E8E1DEB7B3EBAA91FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFE8E2F7C8AEE2C6C1FFD4DFF5CCCBF7E6DF868890BED5DB
A8CDD79CC6D49CAEBDB1BDD0D1D4DB9DB0B28FA5AAD1E1E2D1DCDDE4ECF8C7D9E9B1B6B9C3CFD6\
F3E6E9F7F7F8F7F7F8FFFFF7F7F7F4FFFFF7F7F7F4F7F7F4F7F7EFFFFFFFFFFFFF
FFFFF7F7F7ECF3EDE5F3E8E2F3E8E2F7EDEEFFECF4F7EBF0F2F3F4BEC4C6A4A6AAC2B5B2D8C8C5\
D1C2C5DAC2BADEC8C0BEB6BABDB5AECEC2BFDFC8CAD9CFCAD9CFCFD9CFD7DFD9E6
DFD9E6D9C8D0EBDBE2EBDBE2D6BDC8E2CADBEADDE7F2EEF8FFF7F8F2F4F4F2EEF8FFF2F8FFF6F8\
FFFFFFFFF7F8F5F4F4ECE4E5E2EEEEDAEFF8F7F7ECFFFFF7FFFFF7FFFFFFFFF7F8
FFFFFFFFFFFFFFF7F8FFFFF7FFFFF3F7F7F4F7EEFFF3ECEEFFF2F8F7F7EDF7F7F4F5EDEEF5EEF0\
F3EFF4F7E7F4F7F7F8FFFFF8FFF7F8F7F4FFEAEFF4DEF7F8EAEFF8F7F7F8F7FFFF
F7F7F4F7FFF8FFFFFFF7EEF7F3E6F3F7EBE8F7EEE8F3E7F7EBE4FFEBEEF7F7F7F4FFFFF8EEFFFF\
EEF2F4FFFFFFF7F7F8F3F4F4F3F4F4F3EDEEF7F4F4FFF7F8F7F4F4F7F4F4FFF7F8
F3F4F4FFF6FFF7F3F8F7F7F8FFFFFFFFF4F4FFF4F4FFF7F8FFF7F8F7F7F8F3F4F4F7F7F8F7FFFF\
FFF3F8FFF3F8F7F6F8FFFFF4FFF6FFFFF6F8EEF6F8EEFFF8EEFFFFEEFFF8FFFFFF
FFF6F8FFF6FFF7EFF0E2EFE9E3FFF0EEF6F8D6D5D6E6E6E8FFE8E9F2F2F4FFFFFFF2F4F3FFFFFF\
E6FFFFEAE4E5ECE5F0EEC9DBEBE6DBF3E8ECE4C2C5E69D85FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFE0D0EBC1ABEAC8C4F5E5F8F5C5C6F3E8E19D9891B0C2CB
B0CBD66AABC1DAD0DBA3B5CBB5D4E6B4D4E3D1E4EEDAE4EEDAEEEFEEEFE7EAE0EE97ABB3C3CFD6\
F3EBEEF7EFF0F7F7F4F7F7F4F7F7F8F7F7F4F7F7ECF7F7EFFFFFF7F7F7ECFFFFF7
FFFFF7FFFFF7F7F7ECF3F4EDF3EDE5EEE4E6F3E0DBE2D1D0D1C9CBC2CACCD1CDD68996A7708C9D\
7D8A9B9CA1B3BDBCC4CBC8CAD0D9DBD6EDE7DEEDE7EAEDEEECF7EFFFFFF7FFFFFF
FFFFFFFFF7ECE6EDE1E6EDE1F2F4EDD6D4C5DEDBD0EBE5E7EEDCF0F3E4F4F7F6F4F3FFF8F3F6F8\
F3F2F4F2E1E2EAE8E1F2EFEDEAF6EEE3ECF8F7F7EFF3F4E8F7F7EFFFFFFFFFF4F4
FFF7F8FFFFFFFFFFFFFFF7F8FFFFF7F7F7F4F7F7F8F7EDEEF7EBF4F7F7EDF7F7F4F5F4F4F5F4F4\
F3E4EDF7EDF3F3F4F4F7F7F8F7F7FFF3F4FFEAEFF4EAF7F8F7EDF0FFEDF8FFF7F8
FFF4F4F7F4F4F7F7F8FFFFF8FFFFF8F3F4F4EBF7ECF3EDEFEBEFF4EBF7EDF7EEEFFFF6F8EEF6F4\
EEF6F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F4F4F7F4F4FFF7F8FFF7F8F7F4F4
F7F7F8F3ECF4F7EEF8FFFFFFFFFFFFFFF7F8FFFFFFFFFFFFFFEFF0FFF4F4FFF7F8F3F4F4F7F7F8\
FFFFFFF7F7F0FFF6F8FFF6F8FFF2F8FFF6FFFFF6EDFFFFEDEEFFFFEEFFF8E3FFF8
E3F6FFE3F6F0DAEFFFE3FFF0E2EFE9EEF2F8D6E1DBEBE0E1F7EDEEF5EEF0F2F3F4F7F7F7F7F7F7\
F3F4F3EBF7F7F1E6E9F3DBE8EBDCD1FFEDECF2D4D0DE987FFFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFD4B9E6C8B9F1CFD1F5E5F8F5C5C6F3EDE8A9ABA39CAAB8
DAE5EF83ADC4ECF7F7B1D4E1B1DCE7F2F7F7F1FFFFE6E8E9E4F2FFEEF4E8E5E5F0828C96C4D1D7\
F7EEF0F7EFE7F7F7F8F7F7F4FFFFFFF7F7EFF7F7ECF7F7F4F7F7F8F7F7F8F7F7F4
F7F7F8F7F7F8F7F7EFFFFFFFFFF4F4F7F6F8F2ECE5EAE8E9E6E0E5D9DCDEA3A0AEC8DCE5FFE6E2\
EAE4E1C1D1DEC4D1E3EAEDEED9E5E7FFEEDFDAF7F7E3FFEFE2E0E9C3CFD1CBCFC4
C3CFCABDC8C8B4BDB9BDC3BFDEE7EDF7FFF8EAE7E6CED1CBDEF4E1EEF4F3F7EDF3F7EDF3F3EDEC\
F3EDECE2D1D3ECEDE5F7F7F4F3FFF8FFEBF0FFF7F8F7F7F8F7F7F4FFFFF7FFF4F4
FFF7F8FFF7F8FFF7F8FFF7F8FFFFF7FFFFF3FFFFF7F7F4F4F7E6EEFFFFF4F3F4ECF5EDEEF5EEF0\
F3F6E7FFFFE8EEFFFFF3F4EDF7F7F8F3F7F8ECF7FFF5F7F8F5F4F4F5F4F4FFE8FF
F5F7F8F2E1F4ECEDF0E2F4F7F3F4ECF7F7F7EEFFF8FFFFFFEEFFF4EEFFF4EBF3EDF7F3E1EEF6E5\
EEE4EDFFE4EDF7EBEDF7EBEDFFF2F4EEF2F4E5EBF0F7F3F8F7F7F8FFFFFFF7F7F8
FFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFF7F8F5FFF8F5F7F4FFF7F8F7F7F8F3EDEEFFFFFFFFFFFF\
F7EEF0FFF2FFFFF6FFFFF6F8FFF6FFFFF6F8EEF6E7E6FFEFEEFFFFEEFFF8F5FFF8
E3F2FFE3F6F0E3F6F0F7EFF0F7EFF0EEF2F8CEE1DBEEE0E1F7F4F4F7ECEEF3F3F4F7F7F7F3F4F3\
F7F7F7EBF7F7F5EEF0EACCDBF3E5DBF3F7FFFFE0DBD89E7FFFF4F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8F7CDADEBC6C5F5C0D0FFFFFFF2BDB9F7F7F7BCC2B88A9DAD
D0E4E69FC5DBEEEEF8E3E4EFD1ECF7D9EDECDEF4F4F7F4EEE3ECF8E5E4E5EEFFF76E7384CAD4DE\
F7EDEEFFFFF7F7F7F4FFFFF7F7F7ECFFFFF7FFFFFFFFFFFFF3F4F4F3F4F4FFFFFF
F7FFF7F7FFF7F3F4EDF3F4E8F3EDE5F7EDEEECE5E7DED9D3D1C1C1EEE5E7DADDDD99979CB5BBBE\
ECF7F3ECF7FFDAE5ECD1D5D0D8CCB2D9B69FECB6ABBCC3B6ACB8B6AAB7BAB0CAD6
A9B9C497A4AE8FAABA9AAEBAA2AAB2A0AEBFBED4DDD1DDDFEAD9DBE3C8CBE5D9D0E5EFDEE2DDDB\
E3D4D6EEC1C1DEC2BADEC6B9E2D5C8EADDDFF7ECEEF7F7F8F7F7F8FFFFF3FFF7F8
FFFFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFF7F7ECFFFFFFF7E5F0FFEEF4F3F4ECFFEDEEF1EBEE\
F3F6EFFFF6E8EBF7F8F7F7EFF7F7F8F7F7F4F3FFF4F5F7F8FFEFFFFFFFFFF1DCEE
F5E6EEEAF4F4EAF7F0ECEDECFFFFFFEEFFF8EEFFFFEEFFF8EEFFFFEEFFFFEBF7F7F7F7ECEEFFEF\
EEEFECFFEFECF7F7F7F7F7F7FFFFEFEEFFEFEEFFEDF7F3E1F7EBE1EBEBDEDFE0E2
EBE4E5F7EDEEFFFFFFFFF7F8FFF7F8FFF7F8F5FFF8F5F7F4FFFFFFF7F7F8F3F4F4F7F7F8F3F4F4\
FFF6F8FFF2FFFFFFF8FFF6FFFFF6F8EEFFFFFFFFFFE6F6F8EEF6F8E6F6F8E6F6F4
FFF6FFFFF6FFFFF6FFE3FFF0E3F6F0EEF6F8CEDCD6EBE6E8F7F4F4F5E6E9ECFFFFF7F7F7F7F7F7\
F3F4F3F3F4F3F5EEF0F2E0E8EBD5DBF3EFE8FFE6E9D89E7FFFF4F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF4F4F3C8A8EABAB6F5CCDEF1DBF4EAD4BFF3F4EDCACDC15C7F8B
C8CBD6B5DCEFCBF7FFDEF3F4E3EEF7D6EDEDFFFFFFEAEEF4EAECF8D6E6F4EBE4E17C91A2C1C8D1\
F3E8E9F7F7F4F7F7F4F7F7F4F7F7ECF7F7F4FFFFFFFFF7F8F3FFFFF3FFFFFFF7F8
F7FFFFFFF7EFFFFFFFFFFFF3FFFFF7F3F4F4FFF7F8FFF4F4ECE5E7D9C8BEE3D1BCE5DCDB9AA0AD\
B1AEBCCEDCE5E3F7FFA3ABB3D9CDBAD8E0DEECF7EE979495D9B299BCBBBD8A8A89
7E7B7BC8DBDDB2DBF3ACD4EDDEE7EEF3ECEDD8C6D0B5CCCEE3F4F4ECEFEFE2EEF7D9CFE1DEC9DB\
D9DBDEC4C8D1BEAFBEBDA2B9C6AFB4D9CABDF3E5DFFFECEEF3EDE8FFFFF7FFF7F8
FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFFFFFF7F7ECFFFFFFF7EFF0FFE4EEF3F7F3FFF7F8F1E4E6\
F3F6F4FFF2EDF3F4F4FFFFF4F7F7FFECF7F8E4F7FFFFEFFFFFFFF8F5E6EEFFFFFF
FFFFF4F2F4EEECEDEDEEF7EFE6F6F4EEF6F8F7EEF4F3E6E9F3E6E9F3E6E9F3E6E9F3E6E9F3E6E9\
F3E6DBF3E6DBF3EBEEF3F2F4F7F2E5FFF6E5FFF6E5F7EEE1F7EEE5EEF6EFEBF7F7
F7F3F4E3E0E2EBD9D7F3E8E3F7F4F4FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFF7F7F8F7F7F8\
FFFFFFFFFFF8FFF6F8EEF6FFEEF2F8EEF2F8FFF6F8E6F6F8EEF6F8E6F6F8EBF6F4
E3F6FFFFF6FFFFF6FFE3FFF0E3F6F0EEF6F8D6DCD6DEE6EDEAF4EDEAECEEEAF6F8FFFFFFFFFFFF\
EBF7F7F7F7F7F1E6E9F7F7F8EBC8D6F7EFE8F7EBEED89D7FFFEDEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFEDE5F7C8AEDEB6AEF1DBF4F1E5F8EAC1BAEBEDE2D6D9D03B606D
CBCFD6CBF4FFD6EEF8F5E5EFD9EFEFEEF7F8FFFFFFECECF4FFFFFFECF6FFDFDCDB7C91A2D8C8CB\
D9E8EEF7F7F4F7F7F8F7F7ECF7F7F4FFFFFFF3F4F4F7FFFFF3FFFFF3F7F8FFF4F4
FFFFFFF7F7ECFFFFF3F7F7F8F7F7F4F3F4EDF7F7EFF7F7EFFFF7F8C4A9A0EBDCD7EEE5E5E5E4DE\
B5B0AF978C897690A6F5F7F7989A9AAAA38DD2C2B2837D70E2EEDB97847ADACCBE
6D808D8F9394FFFFFFB8DBE8B6CFE9EBDDE8D1D9E3E2C6C1C4C2B6F3C1B2EEC6C1EBD1D3F2DCDE\
D6EEF0E2ECEDFFD4D6EBCDCFDEC8DFD2CDC0EAE5E1F7EBEEFFF4EDF7F7EFFFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFFFF3F7F7F8F7EDEEFFEBF4F3F4F7FFF4F4F1EDEE\
F7F6F8F7FFEDF7E7F4F3F4F4F7F4F8E3F7F4E4EDFFFFFFF8ECDDF0F3F2FFF7F6F4
F5EFF0EAEDEEDAE4E5EEF2F8F7E5F0F3E4F0F7E6F4FFF7F8FFF4F4F5F4F4F1EDEDF5EDE8ECEDE1\
ECEDE1FFF4EDFFEDEEFFE8E9F7EDEEF3ECF4F7F3F8F7F3F8F7F3F0F7F6F4F7F2F4
EEF6F8EBF3F4F7EEEDFFFFF8F7F7F8F3EDEEF7EDEEF7EDEEF7F4F4F7F7F8F3F4F4F7F7F8FFFFFF\
F7FFFFF7FFFFFFFFF8EEF2F8EEF6FFFFFFFFEEF6FFE6F6FFEEF6F8E6FFF8EBFFF4
FFF6FFE3FFFFFFF6FFFFFFFFFFF6FFE6EEEDDED9E2E5ECEDF2EDE5F7F7F8F7F6F8F7F6F8FFFFFF\
EEFFFFE6EEF0E2EEF0F3F4F4F3DBDCF7E8E8F7F2F4D8987AFFEDEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
F7F7F8F3F4F4F3D5CBEBC9B6E2C1B9EBD4DEDEF3E5D9B6B2EBEDDDF7F7F052707B
8FA0B5C8D9E1DEE4ECF7F7F7E2F7EEEBF7F4F7FFF8FFF7F8E4EBF8E5DDDFEBE0E25C7290E2D1D0\
E2F4F8FFFFFFF7F7F4FFFFF7FFFFF3F7F7F8FFFFFFF7F7F8F7EEFFF7F6F8F3EDEE
F7F7F8F7F7ECFFFFF7F7F7EFF7F7F4F7F7F8FFFFFFF7F7EFFFFFFFD9C0C4E2D1D2F7EDE2EED4CC\
E3EEE1EECCBFE2EFEE9AAAB4ADC8D0D0D9D688918BA2988DC9D5DDA09A90AFC2D0
A4B6E1767961FFFFFFCADBDBADCFDFD9F7ECEBF7F7EBD4CAABAFA9F5F3EDEADDCBE3D4C5D1DCDB\
E5E5E7CBE5E7D1DBE2C2D4E7C4C1CCD0CABDECDDDFF7ECEEFFF7EFF7F7EFFFF7F8
FFFFFFFFF7F8FFF4F4FFF7F8FFF4F4FFF4F4FFF7EFFFFFF7F3EDEEFFEBEEF7FFFFF7EDE8F1EDF4\
FFF2F4F3F6EFF7E7F4F3F7EEF7FFF8ECF7FFEAE5F4ECD5E7F7ECF3FFF4F3F7ECEC
ECDDDEF2EFE6EBE6E5F7F7F4F7EDEEFFE5F0FFE4EEFFF7F8FFFFFFF2E5F0EADDE7F5F7F7ECF4ED\
E3E5DBF3E8E2F7EFF0F7EFF0F7F4F4FFF7F8F7EDEEF7EDEEF7EFF0FFF7F8FFF7F8
F7EBF0FFF2F8FFFFF8EEF6F4EEF6F8F7F7F8F7F7F8F7F4F4F7EDEEF7EDEEF3EDEEF7F7F8FFFFFF\
EBF6F8EBF6F4EEF6F4EEFFF8EEF6FFE6F6FFEBEEF7F7EBF7EEF2F8FFF6F8FFF6F8
EBFFF4DEF2F8FFFFFFFFF6FFEEF6F8EEF4ECC9D4E3F2EFE5ECEDEEECF7F8FFF7F8F3F2F4F7F6F8\
E2EBEED8EEF0DAF7F8F7DDE7EBD5D5F7EFEFFFF2F4D89274FFF4F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
E2D4DE9C8C86AD9D89F2EFDFE3AFB4DEDCD6FFEEEDDEBEB9F5EEF0F7F7EF9DB0A8
7A96B2D1EDEEE3EEF7E6E6F3E2EEE7F3F4F0EAF7EEDEF4F4DAE4EECED3DEECEDE868839CE4E0E1\
FFF7F8F7F7F8F7F7F8F7F7F4F7F7F4F7E4F4FFE5F8FFFFFFF7E4F4F7E4F4F7F7F8
F7F7F8F7F7EFFFFFF3FFFFFFFFFFF3F7F7F8FFFFF7F3F4F4F3F4F4EEE5E8E3D5D7E2CCC5FFF7F0\
F7CBC6D2E0E5B0AAB4A4B0C5B5BEC5819BAE7A9CABB3BABDF5EDE5C6AA9FBAA29C
ACB9B37E8C6CECF7F8D8E0D6C2D1E7C7E1E5DEE1EDEAC8C5B2B6A9DED9E6E5D5C8D8C6B4EBE7E2\
CBEEEFBFCBD6D6CBD7F3D9DEE4E0DBF3ECE1FFF6F8FFF4F4F3F4E8FFFFFFFFF7F8
FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFF7EDE5F7F7F4F3EDEEFFEBEEF7F7F7F7F7EDF1E8F4\
F7F2F4F7FFE8F3F4F8FFF4EEECF7FFECF7F8F7EEEFF7EEF7FFFFFFEEFFF8CEBBCE
B2A2BDA8B2C1C2B2C1D1C2C6F3E4E6F7EFF0FFFFFFF7E5F0F3DBE9EEDDDFEBD9DEDFC8D1DFD4CF\
D1D9DBD1D4D6D1C2C5D9C8CBD2D4D6CAD1D4E3E0E3F3E8E9F3EDEEF7F7F8F7F7F8
F7F3F0FFF6F8FFFFF8E6F2F8EEF3F4E5E5E5F3F4EEF3EDEEF3E8E9F3E8E9F3EDEEF7F7F0FFFFF4\
EEF6FFEEF6F4EEF6F8F7F7F7EBF3F7EEF6FFF7EEF7EEF6FFF7F3F7FFF6FFFFFFFF
E6F6F8EEF2F8FFFFFFEEF2F8F7F7EFEAEFEFC9CDD4F5F7EFF2F7F8EAF7F8FFF7F8F7EEF0FFEEF0\
DEEFF0EAF4F4F7E5EFFFE4EDEBE8DCF3FFF8F7F2F8D8987AFFEDEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8\
5E4C4E725A4777848DDEE6E1CE979DE3ECE1FFFFF4E6C3BEF1E6E9FFFFFFC4D1D0
6A88A3A9D5D6F3F3FFE2EBF3E3EEF7EBF4EEE2F7F4EBF7F8DFEDEEDEE4F0CEC6C87797A7E4DBDC\
F7EFF0F3F4F4F7F7F8F7F7F8F7F7F8F7E4F4FFE5F8FFFFFFF7F7F8F7F7F8F7F7F8
F7F7F8F7F7F8FFFFF7F7F7F8F7F7ECF7F7F4F7F7F8FFFFFFFFFFF7F3F4EDF7ECEEECE5E7E3D5D6\
F7EEF7DACCC7EADCDEECD9DED1DCD6D9D4D7B3BAC6B1B9C3D1D1D3D1DCE5E5DCD7
CECBC0B0C1B9E3EEF8DEF3E7D2D9DEDEF6EEEEF6F4CEBABDC5C2B5C9C2ABE2D4C4EADDDFE2F4F4\
EBE0E3E2E6EDEADCE5EBDBD6EAE8EEF7EEE5F7EBEFFFECF4F3F4E8FFFFF7FFFFF7
FFF7F8FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0F7EDE5F7F7F4F3EDEEFFEEF0F7EEEFF7F7EDF1E8F4\
F3F6F4FFECECF3F4F8ECEDF4F7FFF8F5F7F8F3EBF7F7ECF3F7EEF7EBF7F4BCB0C6
E4EDE8CFBAC8B4B6C4A3A9B4D6D1D3DFD1D3DFCFD1E3D4D3E6E8D0E2E5D7DEE4DDDEE4DDDEE8E9\
D1D4D6DFD4D6DFE0E1D1DBDCD1D4D6DAD1D3D9CDD0DED9DBE6E6E8E6E6EDE6EBF4
E6F2F8E6F2F8EEF6F4EEF6F8E6EBF7F7FFFFEBEBEFEEF6F4FFFFF8FFFFF8FFFFF8FFFFF8FFFFF4\
FFFFFFEEF6F4E6EBEFEBEEF7FFF7F7F7EEF7EEF6FFF7F7F7EBF7F7FFFFFFFFF6FF
EEF6F4EEF6F8EEF2F8E6F6F4F7F4F3DEF4F4D8CFD1F7F7F8F3ECF4EAECF4FFF7F8ECECF4E2ECF4\
D1F4EDE2EEF3FFE5EFF7F7E8F7E8F4FFEFE5F7E5EDD1977AFFE8E9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8B59FA3\
1B0204C8D1D6475669EBECE1D6B0B2E3D9CBF7FFEDE2AEBDECDCDEF7EDEFECE4E6
6081997CA4B3EEEEEFDEEDEDEBF4EEFFFFFFE6F4F4E3F7EED6F4F4EAE0E5CBD4DB708C9DE4D4D6\
F7F7F8F7F7F8F7F7F8F7F7F8F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8
F7F7F8F7F7F8FFFFF7F7F7F4F7F7EFFFFFF3FFFFF3FFFFF3FFFFFFF3F4EDFFF7F8F7EEF0ECE5E7\
EAE5DEF5F7F8E3D5CFEAEDE5E3D9DEDEE4E5CEC8BFB8C8D1A2A7B2C8CCC5D6E8E1
CBD9DE93BDDB9DC2D6BCD5E1C8DDE7EEF6F8E6F6F8BDC8D1E2F6E9DEEEE9D8F4F4F3F4F4E3FFFF\
ECF7F8E4E4F4E3CCCDE3D4D6FFF7F8F5F7F4F7F4ECF7E6EEF3F4EDFFFFFFFFFFF7
FFF4F4FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFF4F4F7F7ECF7F7F8FFECEEF7F6F8F7F4E8F1E8F4\
F3FFF4FFE4ECF3F4F8ECEDF4F7FFF4F5F7FFF2E5F0F2E5F0F3E6F3F7F7F8B3C9CC
DACCD6F7ECF4F1D4D7B8B5B6E3ECEEECF4F4F7FFF7ECEDE8E2F4F4DEE5EDE3ECECDEE7E8D1D4D6\
D6DCDEEAF7F8EAF4EDECF7ECF5F7ECE3F7FFD9E7E8C3CDD0C9C8CBDED4CFE4DCDB
ECEDEFFFF4F7EEECF3E6E6F3E6EBF7F3ECF3F3F7F7EEEEF7E6F2F8EEF6F8FFFFF8F7EEEDF7EEED\
F7EEEFF7F7F7EEEEF7F7F7F7FFFFFFF7F7F7FFF7F7EEF6FFEEF6FFEEFFFFEEFFFF
E6F6F8EEF6FFEEFFFFE6F7EFFFF7F7DEEDEECEC5D0F3F3F8FFF6FFEAEEF8EAFFFFECF3F8E3F3F8\
B0D9E1F3E4F8FFF7F8EBF7EEF3EDF7F7E8F7F7E8ECD19174FFE8E9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8EBE4EE8F7D7C4B3636\
7B7372C2CCE1395D77E5D1C8EECBD7DAABA9DE9EA2DAA9B5F7F6F4F7F7F7FFEFF0
6283956291ADDFE0EDDEEDE2F3FFF4DEF4F4F5FFF0EBF7F8E3F7F8E4E0E5CBD4DB708691E4E0E8\
FFF7F8F3F4F4F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F3F7F8F7F4F4
FFFFF7F7F7F4FFFFF7FFFFF3FFFFF7FFFFF7FFFFF7FFFFFFFFFFF3F7F7F4F3F4EDF7EFF0F7ECEE\
F7E5E7ECE6DFF2F4EEE3D5D7EADCDECECFDBCADCDFD1D4CB90A4B4D9D9DFAAB6CB
B8C5CDCAD4DCBFD4DBCEDBD6BAC6D0CED1D3D6E8E1B3C9DED8E4EED1D3D6D1D9E1F7EEF7ECF7F8\
ECF7F8C4B6C5D9CDCCF5E5F0F1EDF8F1EDF0F7F4ECF7E6E9F7F7F8F7F7EFFFFFF7
FFF4F4FFFFFFFFF6F0FFF2E9FFF2E9FFF6F0FFF4F4F7F7ECF7F4F4FFEBEEF7FFFFF7F4ECF1E8EE\
F3F6F4FFE5ECF3EDF4FFF7F8E4F4F8FFFFF8F5E6EEF5E6F4F7EEEFF7EEF7E2E4E6
BECDD4C3B9CCE5D5DDC4B5A9E2D5CBE3C6ADEBBCAEDEA997D1AA91CEB698C4DCDFB1BDC9BDAEBD\
C2B5C4B5C1CBB1BDBDBAC2C4E3DDDDFFFFFFF5F4EDF7EEFFD9DBE5BDCDCFC4C6C9
C7C9C4E4E4E2E4EDEEE4EDEEE4EDEDE3F7EDE3F4F4EAEDE8F7EFE1EEECE8E6E0ECEBEEF7EBEEF7\
EBF6EFEBF6EFF7ECF3F7F7F7F7FFFFF3FFFFEBECF3FFFFFFEEF6FFEEFFFFE6FFF8
EEF6F4EEF6FFE6FFF8EEEDECECF4F4EAE4E6BEC1D0EEEEF4F3F2F8EBEEF4EBEEF4F3F2FFF3F3F8\
B6C8E1EBFFEEF3FFEEF3EDF4F3F7E8EEE1DBEBE5DFDE9676F7D9D4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F7EFF090878D6B5241A3A9AE\
E5E0E1DFE4ED2D5B85D9C8BDF7F7EFEBEBEDE6E6E8F7F7F7EBE4E5FFF7F4F5E0EE
698B976EAABEC8DCE5EAF7EEF3F7F8D8EDEEF1FFFFEEF7F8EBF7F4EAE0E2CBD4DB708691E4E0E8\
F7F7F8F7F4EDF7F7F4FFF7F8FFF7F8F7F7F8F7F7F8F7F7F8F7EEF0EEECEEF7F7F8
F3F4EDFFFFF7F7F7F4F3F4E8F7F7ECFFFFF7FFFFF3FFFFFFFFFFF7FFFFFFFFFFFFF3F4EDFFFFFF\
F7EEF0F3E4E5ECE5E7F5F4F4E5CDD0DECDC9F2E8DBF5F7FFB1B6B6B0B6C1BEC2C9
BEC2CDE2DCDEC7DDF0BCD9EEE5ECF4E3E4EEE6E6F4C5D9E6EBF7F4EBE0E8EEFFF8F3E6F3FFFFFF\
DAD5E7CEC5C4F5EFF8F5EFF8FFEFF8F5E8EEF3ECE5FFECEEFFFFFFF3F4EDFFF7EF
FFF7F8FFFFFFFFF6F0FFF2E9FFF2E9FFF6F0FFF4F4F7F7ECF7E4E6FFF6F8FFFFFFF3F4F3F1E8E9\
F3F2E5F7EDF4F7F4EEFFF7F8E4F4F8FFFFF8F7F6F8F2E5F4F5E6F0F3EBEFF7EFEF
EBF7F4DAD9DEDEF3F8CEB6AEC9BAAFEBE0E9F7F6EFF7F6F7CECBCD907761D9BDC5D2E4EEDEE1E8\
D6E5ECDEEBF8EEFFF8E5EFE5BCCACCB5C2C4E5E4E1F2EEFFDAE5E5F3F7EDF3F3FF
C8D4DECACBCFE2ECF4F3F7F8F3F4F4E3E5F4E3E5F4D9F4F8D1E5F8DEE5F4EAEDEEF1E8E9EAEDEE\
ECEDF8FFF4F4F3FFFFF7F7F7F3F4F3F3F4F3F7F3F7FFF6FFEEFFFFEEFFFFEEF6F4
FFF6FFEEF6F8EEF3F4FFEDEDE4FFFFE3E0E9C2C8D1F7ECF0EAF2EEECFFFFF7FFFFF3F3F4E3E4EE\
ADBDD6DEF7EEFFEFF8F7EFF7F3FFEFEBDCD1EBEDE9D89885F7CFC0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8BFA8AC5B50479A9895ECE6EF\
EEEBEDEBF2F433558AD6D4C9EEDDDFEEEEE7FFFFFFEBEBEDF7E5E5FFEDF4EAE4F0
7D98A38FBBC8D9DDDFEAE0E5EAEEEDEBEDE3F7F7F7ECF7F7E5F7FFD9D4D1C4DBE9778691E4DBE2\
F7FFFFF3F7EFFFE5EFFFEEFFFFF7F8F3F4F4F7F7F8F7F7F8EBE0E3F7F3F4F7E5E7
F7EFF0F3F4F4FFFFFFF3F4F4FFFFFFF7F7F4FFFFF7F7FFF8F7FFF8FFFFF3FFFFF7F7F7F8F7F7EF\
FFFFFFFFF7F8F7E5E7ECDDDFE3D9DBF3E7E2EAE6E5ECE1DCEBECE5E3E0E3F7EDE6
D1DDDEC8CBCEDED4D6CFD4D6CDD9DDCAD9E1CBE1E2D1DDE7F3E6F3FFFFFFF3E6F3F5F7FFD6C5D5\
D1D4D2F7F6EDF1E4EEF5F4F8F5F4F4FFE5E5F3F3EDFFEEF8FFF7F8F3F4EDFFF7EF
FFF7F8FFFFFFFFF6F0FFF2E9FFF6F0FFF7F8F7EFE7FFF7EFF7ECEEFFF2F4F7F6F8F7F4F3F1E8E9\
F3F2E5F7F7F7F7F7F8FFF4F4E4F4F4FFFFFFF3F2FFEADCEEF5E6F8F7F6F4F7ECF3
F7F7F8F7F7F8C8D4DEF2EDECBEA79AC8BBBDEBE4DCDEE6EDA09B8CCAAE99B5AAAAA8B1ADB5D1E1\
B5DDECB1DDE6C8ECE9ECEDE2D9D9D3F5EEE7BFD1D6C9F7F8EBEEF0EEEEF8EEF7F4
DAEFEFBFCBCBD1DCE1EAE0E1EAE6EDDEE6F4DEE0E5DED4D6E2D9D6EEE6E1EEEBEDF7F6F8EAF4F8\
EAFFF8F7F4F4EEEEF7EBF3F7EEFFFFEEF6FFE6F6FFEEFFFFFFF6FFEEF6FFE6F2F4
FFF2F8FFF2F4E6E6ECECF4F4E3F7F8DED9DED9D4DBFFEEF0EAE0E2E2EDEDF7F3F4F7EBEEF7F7F8\
97AFC6E2E6E5F7EFE8F7F6E7EEECE5EED4CDEBE4DEE38F8BDAC2B4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB5A0A558413A6B7674E3DDE7F7FFFF\
EEEBEDF7F6F86A85AC618194DAB2BEEEDDDFE6E6DCD1C3BDD8CDC5D1DBCBB3B9B6
7B98ADD0E5E5EAEEEEECF7F7E5E0E7EBF4E6F7F7F7ECF7F7EEF7F8D6D4D6C4DBE97D797FDEE4F0\
FFFFFFFFFFFFF3EEFFF3EEFFF3F4F4FFFFFFF3F4F4F3F4F4E6DBDEECDCDDD8C8CB
D6BDC1EAD9DBEEE5E8F3F4F4FFFFFFFFFFF7F7F7EFF7FFF4FFFFF7F3FFEDF7FFECFFFFF7F7F7EF\
F3F4EDF3F4EDF7EFE7F7E4E7EAECE8E2DCDDEADCDCEAE1E2E4E8EEF2EFEEFFF4F4
F3F4EEDAE5EDD1E4EFE2F4FFEAEFEEE3EEF8E2E6F4D6CBD5D8CFD1CBC6CABEC3C4CAC9C4E3E5D6\
F7F6F4FFEBEEF1E5F0FFF4F8F7EDEDF3E5E7F7EBF0FFECF4F7EFF0F7F7EFFFFFF7
FFF4F4FFF6F0FFFFFFFFF6F0FFF2E9FFF7F8F3EDE1F3EEFFF3F3F4FFFFFFF7F2F4F7F7F7F1E5E5\
F3EEF0FFF6E7F3F4EFFFF4F4E4F4F4FFFFFFF7F6FFF7F6F4FFFFFFF5E6F4ECD5E7
EEE5EFFFFFFFF3EEF7C6CCD6CEE5E3ECC0A7AA8F74988A79B3A894ABB0B1B59F94626F83B0C8C1\
DEE6E8D6D9DED6ECFFC7EDECE5ECF8EBE4E1EBDBD6DED9CDE3D4B9F2C5B2D8D3C5
D2DCD6E3ECEDAACFE28EC2DBA4C8DBB2CFDCBDE0EDD9E5EED9DCEEE5F4EDE3DDDFD9D1DBE2D4D6\
EBDBDCEBE0ECF7EEF7E6F2FFEEF6FFFFFFFFFFFFFFEEF6FFE6F6F8E6F6F8EEF6F8
EEF6F8F7F3F7EBEEF7DEEDEEEEE5E7C6DCE5D0D9E2DEF7F4EAF7EDE4E4F0DAC8C9C4CFD1DAEFED\
9DB6C6E2DBD6F3F2F4F7EFEFEBBBBDFFE0E5EEECE1EA918BD9BDA8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3DDF07661528A8F8DEBE7EEEBEDECF3F4F3\
DAE0E8DAF7FFE5E5EF68A7BD7D989DD9B0B9F1CFD1C4BAC5D1D4E1CABACBA2B8D2
A9D9EDF1F6F4E2EEFFEBE0F4E6E4E6E2F7F8F5FFFFF5FFFFE6F4F4D6DBE2CECDD66D7885DAF4F8\
F7FFFFF7FFFFFFFFFFFFF7F8F7F7F8F7F7F8FFFFF7F7F7ECEEE5DFDAC3C7DED4D5
E3E4E5DACCCEEADDDFFFECEEF7EFF0FFFFF7F7F7EFFFFFF3F7FFECF3FFF4F7F7FFFFF4F4FFF4F4\
F7F7EDF7FFF4F7F7EFF7E5E7FFF3F8F7F6F8F3F6F4F7F4ECFFFFF8F5FFF8F1F7F4
ECEFF0F3F7EEEBEEE5E6ECE1EBE7E1E2D4D6E2D4D6EEEFE7F3F2FFF7F6FFFFFFFFFFF6F8FFF6F8\
F5FFFFF1EDF4F5F7F8FFF7EFF3EEEFFFF6F8F7F3F4F3ECF8FFFFFFF7F7ECFFF7F8
FFF7F8FFF2E9FFF2E9FFF6F0FFF6F0FFF7F8F7F4E8FFE5F8F7F3F4FFFFFFFFF2F4F3F7F7F1EDED\
F7F4F4F7F2F4F7F7E8F3EDF8F2F7EEF5F7FFFFFFF8ECF7F8EAE5F8FFFFFFFFEFEE
ECE5F7EBE4EDEBE4EDF7ECE8ECE4E5D9E0E1CEECF7CEEDE5E2D5D7979291D9DCE64E5A74B6C8B9\
D8E6E8C4C2C9EAE8E1D9F7F7F7EFE7EEF4EDEBDBD1C1C8C5F5F7EFE5EEE5C4CDD0
D1DCDEEAEDE5ECF7EDECF7EDEBEFE7F3EDE5EBD9DED9ECF0C8D5DFE3E5E7EAECF0E2D9DBE2D9DB\
F3E6E8F7EEF7FFFFF8EEF6F4EEF6F4EEF6F4EEF6F8EEF6F8FFF6FFFFF6F8E6F2F8
FFF6F8F7F3F7EBEEF7D8E8E9D9D9E1C4D5E8EEEEF4FFFFF7F7F4EDEAF7FFC7DBDEECF6FFC4D9E5\
9DB6BFE2D4D1F3FFFFEBDBD6E3BCC5ECE0EEEEECEDEA8385D9BDA3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8C4AEBA6D5A3CCBD1D6EAEEF8E3E6E7E3F4F4\
DAE0E8FFFFFFDAF7FFBDD3E7449FBD6195AA9CA4B4A3BDD0ADC9D6A9D1D6B5F4ED
D9ECF4F3F2F4F3F3F8EBEDFFFFFFE9EAF7F7F7F7F7F2F7F7D6EDEDCBDBE9DEC8CA688A96E3E4EE\
F7FFFFF7FFFFFFEEFFFFE5F8F7F4F4F7FFFFFFFFF7F7F7ECFFFFF7EBE4E6D1C1C5
DADDD7E3E5E7DACCCEE4E4E5ECE5E7F7EFE7F7F7ECFFFFFFFFFFF7FFF7F8FFFFFFFFF7F8FFFFFF\
F7F7FFF7F4F8FFF7F8F3F4E8FFF7F8FFF4F4FFECF4F3E5E5FFF7F7F5F7F8F5F7F8
F5F7FFF5EFF8FFF4F4FFEBEEF7F6FFF3F6F8F3F6F8F7F6FFFFFFFFFFF6F8FFF2F4FFF2F4FFF6F8\
F5F7F8F5EDF0FFF7EFF7EEEFF7FFFFFFF3F4F7ECF8F7E4F4F7E4F4F7E4E8FFF4F4
FFF6F0FFFFFFFFF6F0FFFFFFFFFFFFFFF4EDFFFFF7F3F4F4FFF4F4FFF6F8F7F6F8F7F4F3F1EDEE\
FFF7F8F3F6F4F7F3ECF3EDF4F7FFEEF1F4FFFFFFF4ECF7F8F2E1EEF2E1F4F2E6F4
F5E6F0E2DCEFEAE4F4E3D4D6E2F4F4ECEFF0EAECEEC8D5DFADCADEECECD5BEA285777B87BDCFC6\
DEECEDC8C2C1CFCDDBDAE7E1EEF7E7DEEEEED6C6BEC1CDD0E3EBE2C8C2BCB3B0BC
EBE1DEDAF7FFDFDCDED2CFD1D6E0EED6E0F4B9CCD6BCDCE5DAE4E5EAE5E8EAE8E3EAE8E3F7F7F4\
E3F4F4F7E5E5F7EEE7FFFFF8FFFFF8EEF6F4EEF6F8FFF6F8E6F6F8E6F6F8FFF2FF
E6F6F8EEF6FFEEECF3D8E8E9C4CFDCD6E0EEF7F7F8F3F4EDECF7FFE2F7EDD8DBDCE4F6F8DAECF4\
6D9DAEF3DBD6F3FFFFE6D4CBECC2D1ECECF4EEECE8E29185DAB0A3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F4F494787E6E6159D9E0EEECF3F4EAF7FFEBEFF0\
D6DBE1FFFFFFDAF7FFD9F4F8EEDDE77DB2D06F9DB9A0BAC6C4E1E8D1EEEEE5E5E5
D6DCEFDEE8F0E3EFF0EEEDF8EBF7EEF2F7F7F7F7F7F7F7F7D1EDEDD6DBE2BCC8D7889896E4DBE9\
FFFFFFF7EEFFFFFFFFF7EEFFF3EEFFF7E5F8FFFFFFF7F7EFF7F7F4F7F7F8F7D9E5
D0D1CBEEEFE7E3DBDCF3EDEEE3DCDEECDCDFF7E5F0F7F7ECFFFFFFFFF4F4FFF7F8FFF7F8FFFFFF\
FFFFFFFFF7F8FFFFFFF7EFE7F7F7EFFFFFFFFFFFFFF7E6EEF3F3EDECE5E7F5F7F4
F5EFF4F5EDF4FFF4F4FFF3F4FFEBEEFFF3F4FFF6F8FFF6F8FFF6F8FFF6F8FFF6F8FFF6F8F5EFF8\
F5F7FFF1EDF0FFF7EFF3EEEFFFFFFFFFF3F4FFF7F8F7F4F4F3F3F4F7E4E8FFF4F4
FFF6F0FFFFFFFFF6F0FFFFFFFFFFFFFFF4EDF7F7F4FFFFFFF7E7EEFFFFF8F3F3F4FFF7F7F1EFF0\
FFEFF0F3FFF8F3E6E8FFF7F4F7F7F0EAF7F4ECF7F8F5E6F4F5F7FFF7FFF8F7EFF8
F7E8EEF7EFEEECD1E2E2DCE5F7EEEDEBE0E5D6E5EFECECEED6D9DBB5C3C5D1EFECC4C1CCB3D9DD\
EAF3F4EBEBDFD1E5D6E4DDE5EBEBF8DAEEF8D1C8C6DAD4D6B9BBC1C6CCD5EEEEF8
EEECEDD1DCDFEAE5E7F5FFFFE5ECE7C8D4D5C7C3D6E5E1EDF7FFFFF5EFF0F5EDEEF3F7F8E2ECF4\
EAE4E5F7F7F4F3ECE8EBEBF4F7EEF4EEF6F8EEFFF4EEF6F8FFF6F8FFF6FFEEFFF8
EEF6FFEEF6FFFFF4F3D1D9DBB4C1D6D9DCDEF3EDE1F7F7EFE5F4F4C7D9DCE3DCDEE4EBF8EEFFFF\
628C9DEBE7E1FFF2FFEBC6BFECD1DBECF6F8FFCFDCC49E8CF7B5A3FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F86D5A62867874F7FFFFECF7FFFFF7F8EAF4F8\
BDD4DCDAEEF8FFF2F4F7EBEED9EEF4D1FFF4D1F7F48AA9B9CFEDF3F3E6E9DEECF4
D9E5FFF1FFE9E3EFF0E3F4F4D8F4F4FFFFFFFFFFFFF5F7F7DEEDEDD6DBE2B7C3D1839196ECE4EE\
FFF7F8F7F6F8FFE5F8F3F4F4FFE5F8F7EEFFF3F4F4FFFFF3F7F7ECF3F4F4F7E5F0
EAC9D3DAE4DFF7F7F8EBE4E5F7EFF0EAF4EDE2D4D3EEDDD6F7F7EFFFF4F4FFFFFFFFF6F0FFF6F0\
FFF6F0FFEEE8FFF7F8FFF7F8F7EFE7F7F7EFFFFFFFFFEEF8FFF7F8EAECEDF5FFF7
F5EFEEF5EDF4FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFF6F8F7F6FFF7FFF8F7F6F4F7FFF8F5E5F0\
F5EFF8F1E8F4FFFFF4F7F7F7F7EEEFFFF3F4FFFFFFFFEEF8F7E7EEF7F7ECFFF4F4
FFFFFFFFF6F0FFF6F0FFFFFFFFF7F8F7EFE7FFE5EFFFE5F8F7E7EEFFFFF8F3ECECFFFFFFF5FFFF\
F5EFF0F7EFF0EEEBE5F7F7EDFFF4EEECF7FFF7EFF8F5F7F8F5E6EEF5E1EEF7EFF8
F7F7FFF7F4F8F3F4F8F5E6EEE3DDD6F7EEF7DAE5E5D6E0E1EBE5E7C4DDE8ACC3D6A7B8CE93AEC5\
6EAAC483B6CABCC3CAECD9DCF1ECF8F3F7F8D6E0E5C6D1D0DFE0DDE2F7F8DEF7F3
D9E4EDB5D5E7E3F3F8E3F3F8D1DDE7E2ECEDECDCEEF2E6F8F7F7F8EAF4F8EAEDF8FFEDF0EEE5EF\
F7FFFFF3EEEFF3F4F7EBF7F8FFF6FFF3E6ECF7F7EDEEF2FFFFFFFFFFF6F8EEF6F8
EEFFF8EEEEF7ECEFEFBCD4DDC1C3D1E6F7F8EEFFF7DEF4F8EBFFF4ECE4E1ECE5E7D6E6F8FFFFF8\
678091DFE5E5F3EEF4EBBDB8F5E7E9ECE5F0FFD9E1C48C7FF7C8AEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8
FFF4F4FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EFF05B4C47A99691EBF7F4EBF7F8F5F4F8F7F7F8\
D2D4DCFFEBEDF7F7F7EBFFFFEEEBF4F7F4F8D9F4F8B5B6BFECEEEFEEECF4E5F4F8
FFFFE9F5FFF0F7F7FFD9EFF8D9EFF8F7F7FFF5FFFFF5F7F7EEF4F4BDD4E3D8C3C4688B9DF7EEF0\
FFF7F8F7F4F4FFF7F8F7F7F8F7F7F8F3F4F4F7F7F8F7F7F4F7F7F8FFFFF3F3F4ED
F7DDE7ECD5D7D6D9D3EBE5E1EED5E8F7F4F4F5F3F8DEC9D4DACCC5F3E6DEF3F4FFF7EBE9FFF2E9\
FFF2E9FFF2E9FFFFFFF7F7FFF3F7F8FFF7E7F7F7EFFFFFFFFFECF4ECEBF8F2EEEC
F5F7F4F5F7FFFFF7F8FFF7F8FFF4F4FFEFF0FFFFFFF7FFF8F7F6E7F7E4E5F7DBE5F3E0E1EBE0DB\
F7E4E5F5E4EEF5F7F4FFF7F7F3F7EFF7EEF8F7EBF4FFF7F8F7ECF4F7F7ECFFF4F4
FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8F7F7ECFFE5F8F7EEFFFFECEEF7EEEFF7F7F7FFF7F7F5F4F4\
F5F4F4F7EDEEFFF6F8E6EEEFF3EDE5F5F7F8F3EDF4EAEFF8ECEDFFECEFF8F7EDF4
FFF4EEFFFFF4FFFFFFEAE7EDF7EEF7E3DDD6F7EEE7F7EFF0EEDDDFD9E5E7D6D4D6D9EFF4DFE0E1\
D9D4DBC7D5DFD6E4E7DADDDFF5E4E1CDD9E8C4D1DEBDC2CFD6DCDFCEDDDDC1CDDB
AFC1D6DEE5E5EAF3F8CED3DEEAE5E7EBF6F8F7EEF0EAE5F4EAEDF8EAEFF8F7EDF4F3EDF8F7F4F4\
EBE6F3F7EEF4F7F3E5E6FFEFF7F7F7F3F4F3EBF3F7E6F2F8FFFFF8EEF6F8FFF6FF
E6F6F8FFF4F3DEEDEEBDD1DEDECDCFE6F7F4ECEEEFF7F3EDF5F7F7ECEEEFF5E4E5DEECFFEEF2F8\
557485EBEBEEEEDCD6F3BBC1F5EEF0ECE0EEF7E0DBCB8C79F7CFC0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF7F8
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2D1DB534B3EC1B5BAEEF7F4EEEFF0F5EEF8ECF6F8\
CBD9DEFFEEEFE3F4F4F3EDECDAEEEFEAF2F4E3E4EDE5D0D0EBEBF4F7F7FFEAF4E9
ECF7FFF7F7FFF3F4FFEAF4FFF7F7FFF2F7FFF2F7F7ECF7F7EEF7F8BDD4E3C1C3CA89989CEAEBF4\
F7F7F8F7F6F8F3EEFFF3F4F4FFF7F8F7F4F4F7F7F4F7F7EFF7F7F4FFFFF7F7F7EF
F3F4EDEED1DED9D1C8EBEDEFF3E0F4F3ECF4E5E5F0E6ECEDD1CBCEE2CBBDF7E4DCF3E5D6FFF3EE\
FFF6F0FFF6F0FFFFFFF7F4F8F3FFEDE3EFE5E2EDE7ECE4EEECECF4ECEEF8EAE5E5
ECEFF0F3F4EEF3F4EEF3F4EEEBE0DDE6D9DBE6E6E8D9D9DDDEDBDED6D5DDCBDBD6D1DBE1D9E5E5\
E5EFDEF3DCE5ECEFF0F5EFEFF7F7EFFFFFFFF7FFF8FFE6F4F7F7EFF7F7EFF7F7F4
F7F4F8FFF7F8FFF7F8FFF7EFFFFFF7F7F7ECF7F7F8FFF7F8FFEBEEF7F7F7F3F4ECF7FFF8F1E5E5\
FFF7F8F3F4F4F7FFFFEBF6F8EBE4E5F7F7EEDEF7F8E4EDFFECF7FFECEFF8F7EFF8
FFF7F4FFFFF8FFFFF4F7EEEFECEFF0EAE7E8F3ECE7E5E5D6FFF7F4E3E4E5BFC3C6C3C8CFC9CDDB\
E5E0E5D1CBD7CBD9E6B5D5E8D6E4EECEE5E8DEE5E7A0C9DEADC8D7B0D4E8DADDE7
FFFFFFECEFF0DAE1E1F7F6F8F3EEEFE3F7F8EAE6F8ECEFFFFFEFFFF7F7F8F7F7F4F7F7F4F3F7F8\
F3EEF7F3E6ECF7F3F4E6F6FFEEF6FFEEF6FFE6F6FFEEFFFFEEF6FFEEFFF8EEF6F8
EEFFFFFFF4F3D1D9DBC4C9D6D6E4EDDAECEDECEEF8E5E4E5D6DBE5DAD4D5DFE8E8DAEFF4F1F4F8\
41617FFFFFF8F3D9D0ECC1D0ECF6F8E4DBE9F3CDD1D18F6DF7D9D4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA88FA7555847E3D4D6F7FFFFF3F4F4EAF3F8F5F7F8\
CBE0E9E5F7F8DAE5F0DAE5F0CEEDEDD9E8E8F3EFEDF3ECE9E3E4E8F3F4F0DEEDE9
EBECF7EEEEF3F7F7F3F7F7F7DEF4F8E2F7F8F3F4F3E4F4F3DFF4F4D1DBE2C4CDDD889196E4E6ED\
F7F4F4F7EEFFF3EEFFF3F7F8F7F7F8FFF7F8F7F7F4F7F7EFF7F7F8FFFFF7FFFFF3
FFFFFFF7E5E7E3C3C7E2D9D7EAE4E9F7E4F0CEE5EDD8E8F7D0D9E8B0BBB4A3A7AEA398A19C8B90\
9C8C9190868B97867F978C8590858B8F777E837F857C919D7C919D688390778590
838B9D8A91A89097A89797AE9DA4B99DB0B597AAAFB8BCC0D2CDDCD6DCEDEBF4F4F3F4F4E2DCED\
CED4D6D9CBCEEEE5E7ECEDEEF5F4F7F7EFEFF7EEF4FFEEF8F7F7EFF7F7EFF7FFF8
F7FFF8FFFFFFFFFFF7F7F7EFF7F7EFF3F4EDFFF7F8FFEEF0FFF6F8FFF6F8F7F3F7F7F7EFF1EFF0\
FFF4F4F3F4F4FFF6FFF7EBEFF7EEEFFFF7EEECEDF4EAF4FFEAE5F8EAE5F8F7EDF4
F7F4F8F3F4F8F7F7FFF7EEEDF7EEEFF3E6E8F7F7FFE3EEE8FFEEEEF3F4EEEBECEDE6EBF7D6E4ED\
C4D4DBC2C9D3CBCFD1ADC2CB97B2C9B4C1D6CEDBE1E5F4F4BCE4F4BCD3E5FFFFFF
FFEEEFEEECECE3E6F8E4D1E2E2DCDEEAEDEEF3F4F4F3F4F4EBF7F8EBF7EDF3F4F3F3F4F4F3F4F4\
F3F4F3F3F4F3F7EEF7FFF6FFEEF2FFEEF2F8FFF2F8EEF6F8E6F2F8FFFFFFEEF6FF
FFFFFFE3E5E5B5C9D3B5C9D4DAEDE8E4E4E7F7F6F8DEE0E7E5E5E2E6EDEDFFFFFFE3EDF3DEE7E8\
4D6785E3DDE7EAD5D5E4CCD7FFFFFFE4DBE9EBBCBDD19166FFEDEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9079917F775CE2E4EEFFFFF8E3F4EEDFE5E5D2DCE5\
E3DDE7EEEFEFD2E4EED2E4EEEBF7F8FFFFFFFFFFFFFFF4F4E6E8E9EEEFF0F2F7FF
D9E4E7F7F6F3F7F6F7F7F6F3CBE8F4DEF4F4EAF4F7EAF4F7D6F4F4D1DBE2CED4E28998A2E2DCDD\
F7EEF0F7F7F8FFFFFFFFFFFFFFEEFFF7E4F4FFFFFFF7F7F8F7F7F8FFFFFFFFFFFF
FFFFF3F7F7ECFFEEF8EED1DEEAD4DCE2CBD7BED5DFCAE1ECF2EDE5F3F7F8EAEDEEEAF4F4EAF4F4\
F7FFEFECF4F4F3F4F4D9E4F4D1E4F8E2F4E7EBF7F8EEE8E8F7E0E8EEE4E7F7F6F8
F7FFF8F3FFF4EEEBF4F7EBFFFFF6F8F3F6F4EBFFF0EAF6F4ECECF4ECF7F8DEECF8E3ECF8EEE4ED\
EBE0E5DED9DBEBE6E8F7EDEEF1F7F4F7E5EFF7ECEEFFFFFFF7F7EFFFFFFFF7F7EF
FFF7F8F7F4EDF7F4EDF3F7F8F7F7F8F7EFF0FFEEF0FFF6F8FFFFFFFFF6F4F3F3EDFFF7F7F1FFFF\
FFF7F8F3EDEEFFF2FFEBF7EDF7F7F7FFF7F4F7F4FFEAEFF4FFFFFFF5F7F8EAF7F8
F5E6F8F3E8F4FFF7F0EBEBECFFFFFFF7EEEFF3E6E8F7F6F8F3EBEFFFFFF8FFFFF8FFFFF8FFFFF8\
FFFFF8E6E6F3FFF7F8FFF4F4D8E1EEF7FFFFF7F6F8F7EBEDF7F3F4F3F3F4F7FFFF
E5E6E8D9DCDEEAE4E6F7F4F4FFEFEFF7F7F7F7F7F7F3F4F3F7F7ECE6FFEFEEFFFFEEFFEFFFFFEF\
FFFFFFEEF6FFF7F7F7F7EBF7EEFFF8EEFFFFEEF6F8EEF2F4FFF6F4EEF6FFEEFFFF
FFF7F7D8E1E2B7CFDCD2D4DBECECEDECF6FFEAE4E5F7FFFFD0D9DBEBF7F8ECF4F3E3FFFFAAC2CF\
6F8696D8DCDCEAE0E1EAE0E3FFFFFFE4DBE9E6B6AED89274FFF4F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF978691897968D9DBE2E3F7F4E5F7FFFFF4F3FFF4F3\
EAF4F3EAF4F3EEF7F8EBF7F8E3F7F8E6F4F4EEF7F8FFF7F8DEEDEEF5FFFFF3F4E9
DEEDE9F7F7F7F7F6F7FFFFF7D1E5EFECF7FFD6EDF4DEF4F8DEF4F4D6E4F0BAC5D096A4AEDED5D6\
F7F6F8FFF4F4F3FFFFF7F7F8FFE5F8F3ECF8F7F4F4FFF7F8F7F7F8F7F7F8FFFFFF
FFFFF7F7F7F4F7F7EFF7F7ECF7F7EFF7DDE7E2C9D3D1CDD4CED4D6DAE6DFDAEEFFD9E0F4D9E6F8\
C4E4F4D8EDF7F7F4F4DAE4EED8F4FFD8F4FFD9E6E5E6EDEFF3EBFFF3F6F8FFF2F4
E2E4F0ECE5F8F7EEFFF7EEF8FFFFF8F3FFF8F3F7F4FFF7EFECEEFFFFF3F8D6DBE5D1D3E5EEEEED\
F7F7F0D8E5E5EBE4E5F5EFF0F5EDECEBF6EEF7ECF8FFFFFFF3F4E8F7F7EFF7F7EF
FFF7F8F7F4E8FFF7F8FFEEFFF7EEFFFFF4F4FFF6F8FFF2F4FFF6F8FFF6F4F7F6F4F7F7F7F1F7F7\
FFFFFFF7EDEEF7EBF4EBEFF8F7F4F3F7F4F4ECF7F8F5F7F0EAF3F4E4ECF8F5F7F8
ECF7F4EAEDF4F7FFF8EBE4EFF3E6ECF7EEF7F7F7F0EEE5E5EEEEEDF7FFF4FFFFFFFFFFF8F7EEF7\
F3E6F3F3EEEFF3F7F8F7F7FFDEDCF4E3E6F8DEE5F8E2F7FFEAF3F4D8DBE2CBD9DE
D6E8E9ECEFF0F3F7F7F7F4F3F7F7F8F7F7F8EBF7F7EEF6FFEEF6F8E6F6F8FFF6FFFFF6FFEEF6FF\
EEF6FFFFFFFFF3ECF3F3F4F3EEF2F4EEF2F4FFF6FFFFFFF8E6F6F8EEFFFFEEF6FF
E5E7ECCFD4D6B4C2D7CECBD7E3E5EFF7F4F8E5ECEDEEEEFFD0DDDFEBE5E8ECF4F3ECF6F889A4B9\
90A4AEDEE1E2F2E0E1E2E0E3EEFFFFEAE0E9DFAAA8D8987AFFF4F4FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF9786917D796EEADBDCE5F7F8EBF4F4F7FFFFFFF7F7\
ECF4F3ECF4F3EBF4F4E5F4F4F5FFFFFFFFFFEEF7F8E6F4F4E2F7F8F2F7F7DEEDE5
DEF4EEF3F4F7FFFFF3F7F6F7F7F6F7CBE8EDFFFFFFEEF7F8EEEFF0E4EEF4C4D4D68F96A7CECDD0\
F7F6F8FFF4F4F3FFFFF7F7F8FFFFFFF3F4F4F7F4F4FFEEFFF7EEFFF7F7F8FFFFFF
FFFFF7FFFFF7FFFFF3FFFFFFF7F4EDF3EDE5F7E5F0ECE0E5DECBD3B0C6C3E2ECEEDEF3FFE2F6F8\
DEEFEEE3E0E2F7E6E5F7F7F8EEF2F0FFEBE2DEDBDBCFD4D4ECD9D6D9DBE1DEE8ED
F7F6FFFFFFFFE4DBF4E4DBF4E4E0F0E3EEF8F7F7EDECE5E7E4E6F8E3ECF4EBEFEFF3EBEDFFFFFF\
EAEDEEC7DCD6EAEEE6F5EDEFF7F7EFF3F6F4FFF3F4F7F7F8F3F4E8FFFFFFFFFFFF
FFFFF7F7F7EFFFF7F8F7ECF8F3ECF8FFF4F4FFF6F8FFF2F4FFFFFFFFF6F8F7F2F4FFFFF8ECEDEC\
F5F7FFFFF4F4E3E6E9EBEFFFF3F7ECE3F7F8E2E4E5E6E6ECE3DCE5DFD5DCDFD4E1
EBE0ECEAD4E7EAE7EEFFEDF8F7F7F8F7EEEDEEE5DFF7F7F4F7FFF8FFFFF8F3FFF8F7FFF4F3EEED\
EBE6E8F3E6E5F3E6E8EEF6EDDEECE8DEECE8EEF3E8E2D4DCDED4E1F7E7E8F3F4F7
F3F4F4F7F7F7F3ECF3E6F6FFE6FFEFEEF6EFE6F2FFFFFFFFEEFFF8FFFFFFEEFFF8EEF6F8EEF2F8\
E6F6FFFFF6FFF3F4F3F3F4F3E6F2F4EEF6F4FFFFFFFFF6FFE6F6FFEEF2F8EEF7F4
CEDCE5CEDBE2BAC8DBD6DBDCF7FFF8F7F4EEFFF3E6D6E4F3DEE4ECD9DCDBECF7F7FFF3F46188A3\
B9CDD7EADCE8D9EEECE2E0E3EAF3F4EAE0E2D9A4A8D89274FFF7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFA38CA26F735DF5E0DCEAF7FFF3E8E8F3F4F3FFF7F7\
FFFFFFFFFFFFF7FFFFECF7F7F5FFFFF7F7F7F7F7F7FFFFFFF1FFFFE3E4ECC5DCE5
EBF7F8EAF4FFFFFFF7FFFFFFF7F7F3DEF4F4EEF4F4ECE4E5E4E0E1DAECEDDEDCDD8F9EADD2D4D7\
EAECEFECE5F0F7F7F8FFFFFFF7F4F4FFFFFFF7F7F8F7EEFFFFE5F8FFFFFFFFFFF7
FFFFF7FFFFF7FFFFF7FFFFFFFFF7F8FFF7ECF7F7F8F3F4EDF7E5E7B5B2C6B7BBBCC4CDD1BED5D1\
CED9D6CAD4D6BECFD1E3E1D6F5EDEDD1F4F3D1EDF4B3DCE1B7D4DBC9D4D6D6D9CF
D1CCD0BCBDD0D9D9D1D9D9D1CBC8CBC1BDC9BEC1D6CACCE1D9DBE1CED4D6D1CDD0D6D1D3D1D5D6\
CDD1D3DAD5CDF3D9E1F3D9E2F7E6EEF7E4EEFFEDEEFFEFE7F7F7EFFFFFFFFFFFFF
FFFFF7F3F4EDF3FFFFF7F7F8FFE5F8F7F6F8FFEBEEFFFFFFFFF2F4FFF6FFF3F6F4F3FFF4EAEDE8\
F5F7FFFFF4F4E3E6EEEBEFF8F7EFE8EAF7F8E6D9DBEAE4E6E2DCDEDEEBEDD9EBEE
DEE0E3DED9DBD1D4DDE4D4E7ECEFF8F7F7FFF7EEEDF3E6ECF7EEF4F7FFF8F7FFF8F3FFF8F7FFF4\
F7FFF8F7FFF8F7FFF4F3EEEDEBF7F4EEF7F7F7EEEFFFFFF8FFFFF8EEF6F8EEF2ED
EEF6EDF7F7F7F7F3F7FFFFFFEEF2FFFFFFF8FFF2F4EEFFF8FFFFFFEEFFF4FFF6F8FFFFF8EEF2F8\
E6F6F8FFF6FFF7F7ECEBF7ECE6F6F8FFF2FFE6F6F8E6F6FFFFFFF8EEF2FFEEECEC
D8E8E9B4C0D6CECCCEE4E0E5E3F7F8E2F7F8E2E4E3E3E5EFCFD9DEEAF4EDF5F7F7C5D4DD5A8CA4\
F3F6F8DEECF8D9EEF3E2E0E3EAF3F4E2D9E2EEBCB9C8927BDACCC6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8BDA4BA606651EBDBD6D9EFF8EBF4F4F7F7F7FFF7F7\
FFF7F7F5F7F7F2FFFFE4F4F3EAF4F3E3FFFFF7EFEFEEF7F8F5FFFFD2DBE8D2DBE8
F5FFFFE4F4F7FFFFFFFFFFFFF7F7F3ECF7F7DEEDEEE4E0E1EEF7F8EEF7EFF7E4E88EA7BDCAD1D4\
ECF4E8ECEBF8FFF4F4F3FFFFF7F7F8F7F7F8F7F7F8F7F7F8FFFFFFFFFFFFFFFFF7
FFFFF3FFFFF7FFFFFFFFFFFFFFFFFFFFFFF7FFFFF3FFFFF7F7F7EFF7E5E7E2D5D6E2D9C6E2D4C6\
C5D1CCDED9E3F3DBE2C5D1DBBDCDD7CEC8CFE3CDC9E2D4CBD1CDD0D2D4D7B9C8D1
D2BDB9EBD4C8C4D4DBBDC6D1D9CFD1D2C2BFC3BDB4C3BDB5C3BDB5C1BBB9CBBDB8D1C8BFDED5CB\
EAD1D0F7E7E5F7E0EEF7F7F8F7F7F8FFFFFFFFFFF7F7F7EFFFFFFFF7F7EFF7F7EC
F7F7ECFFE5EFFFEEFFFFF7F8FFE5F8FFF6F8F7EBEEFFFFF8FFF2F8FFF3F8F7EEF0F7FFFFEAF7F4\
F1F4F7F5FFF8F7E5F0EEDDF0EEEDE5EAEDEED9E0E1EAE0E6F7F7EDF3F7F4EEFFFF
DFF7F7D6EEEFCEE5E8D1DDDFE2D4E5E3E5F0F7F7F8FFFFF4F3E6ECFFFFFFF7FFF4FFFFF8F7FFF4\
F7F7F0FFF7F8FFFFFFFFFFFFF3F6F8F7F6F4F7FFF8F7FFF8FFFFFFFFFFFFFFFFF8
EEF6F8EEF2F4EEF2F4EEF6F4FFF6F8FFFFF4FFF2F8FFF6FFEEF6F4EEF6F8FFFFFFFFFFFFFFF6FF\
FFF6F4EEF2F8FFFFE7F7F7F8F7F7F7EEF6F4EEF6F8FFF6F8EEFFF8EEF2F8EEECF3
B9D9E3B9B5C4D6ECEDDAE4EED9EFF8E2F4F8EAF7EEF3ECF8E2E5E3E3E5E8D1DCDE93BECB86A9B9\
ECF7E9F5F7FFF3E6F3F7D4D7F3F4F3E3C8D6F5E0DDC7BDAD87716CF7F7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8CBBACC6F6449CDBDC9DAEFEEDEF4F7ECF7F7FFFFFF\
F7F7F7EAF7F7EAF7F7EAF4F3E4F4F3DAEFEFFFFFFFEEF7F8FFFFFFD1E0ECE6E6F4
EAF7F7E4F4F3ECF7F3ECF7F7FFFFF3F3F4F7E3F7F8CDDCDEC8D5D7E5EEF8DEE0EE97AEC5D2DBDC\
E3E5DEECEBEFFFF7F8F7F7F8F7FFFFF7F7F8F7F7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7FFFFF7FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFF7F7EFFFE5EFD9E0FFD9E0FF\
F3D9E7EAD4DCDEE4E2DED9D6DED4C4D8D9CACAD9DBCADCE1E2D4D6EBD1CFEBE7DD
CAF4EEC4E5D6EED9C9F3D9D6DEE4DCD8DCDBEBD1D1EBD1CADED4D6EAE5D3E2E4D6F7E0E5FFE6F4\
F7FFF8F7FFF8F3E4EEF3F4F4F7F7F8FFFFF7F7F7EFFFFFFFFFFFFFF7F7EFF7F7F4
F3F4F4F3ECF8F3ECF8F3F4F4F7F4F4FFF4F4F7F2F8FFF6F8FFF6FFFFF7F8FFEBF8F7FFF4F7FFFF\
F5EDF7FFFFF7F5FFF8F3E4EEF7EEEFE3E6DFCED9DBE2E4EEF7EBF8EBF3F4F3F4F7
F7EFF7F7EDF7EBE0ECD1D5DFD9E6E7DAD5E7E2DBEEEAEDF8EEE5EFF7EEEFFFFFF4F7FFFFF7FFFF\
F3F4F4F7F7F8F7F4F4F7F7F8F3FFFFF7FFFFF7FFFFF7FFFFFFF6F8FFF6FFFFFFF8
FFFFFFFFF6F8FFF2F4FFF6F8FFF6F8FFF6F8FFFFF8FFFFF8EEF6F8EEF6F8FFFFFFEEF6F8E6F2F4\
EEF6FFFFF6FFEEF6F8F7F7F7F7F7EFEEF2F8FFF6F8E6F6F8EBF3F7F7EEF7D6E0EC
B0C6D4CACDD6D6E0E8E6EDEEEAF7FFE2F4F8E5F4EEECF7F0ECF7F0C3CFD7ECE4E596BAD0A2BACB\
E2ECE9F3E4F7DEE5EFF3DBDDF3F4F3E5CCD6F7DDE58FC2DE4E3329E2DCEEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD9D1E26D5F4AC4AFB9F5F7F0C1E5E7E3FFFFEBF4F4\
F3EDECE4F4F3F1FFFFECF7F7E4F4F3DAEFEFEEF7F8FFFFFFFFFFFFDEECF3F7F7F8
DAE5EFFFFFFFFFFFFFF5FFF7EAF4FFEAF7FFE2F7F8DEEDEED6D9DBD6E5EDE2E5E79FBDCBD9E4E1\
D9E0E2EAECF4F7F6F8FFF3F4FFEEF0F7FFFFFFF7F8F7F7F8FFF7F8FFF7F8FFFFFF
FFFFF3FFFFFFFFFFFFFFF7F8FFFFFFFFF4F4FFFFFFFFF7F8FFF7F8FFF4F4F7EDE5F3E8DCF3E8DC\
F3E8DCF3E8DCF7D9DCFFDCE5DAE5F4DAE5F4DAE5F4DAE5F4FFF4F4DAE1E2DACDD3
FFC8D0FFC1C6DACFD6D9E1E1F7D9DCFFDCE1DAE5EDF7F4E8E3EEDDDAE0EFDAEFFFF7F7EFF3F4E8\
F7E4E8F7E4EDFFFFFFFFFFF7F3F4EDF7F7ECFFF7F8FFF7F8FFFFFFF7F7EFF7F7F8
F3F4EDF7F4F4FFF3F4FFE5F8F3EFF0F7EEF0FFFFF8FFF6FFFFFFFFFFF6F8FFFFF8F7F6F8F7FFF8\
F5F7FFF5EDF7F5F7F7ECF7F0EADBE2E2CDD3C8BABDC4D9CBCEDCDECED9E3D6DCDE
EEEFEFFFF4F7FFF4F3E5EEF8BCC8D6A2B6C49CB5C49DAFC096A9C096A2B9B0B2B9E2D9DBF3E6E8\
EEE5E7F3F4F4F3F4F4F3F7F8F3FFFFF7FFFFFFFFFFFFFFF8FFF6F4EEFFF8EEF6F8
FFF6F4EEF6F8EEF6F8FFF6FFEEF6F4EEF2F4FFF6F4EEF6F4FFFFFFFFFFFFEBEBEDF3ECECF7F7F7\
EBECF8EBE4F8E6F6FFFFF6F8EEF6F8FFF6FFFFF6F4E6F2FFEBF7F7FFF6FFB9CBDE
AAC1D3BECBD6DADDDFE3F7F8FFFFFFF1FFFFFFFFF0ECF7F0ECF7F0D1D4E2F5E4E59DBAD0B0C1D3\
F7F7FFF3E4E5DAF4F4F7E0E2F7F7F7E2E0E3D9EEEF7BA5BD554634A8979CFFEFE7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBE0EE686150CAAEADEBEBF4D2E0E3F2F7F7E3F7F8\
EEF7F8EAF7F7F2F7F7FFFFFFE4F7F7F7F4F3F5FFFFF5FFFFEBF7F8D6EDECE6E6F4
EEEEF8D6E4ECECF7F7F2F6FFE2EEF7FFFFFFE6F4F4FFF7F8E4E0E1E6FFF7F3DBE2A9C8D6E5E1DB\
D2E0DEF1EDEFF3F2F4FFF6F8FFF3F4F3F7F8F7FFFFF7F4F4FFF7F8FFF7F8FFFFF7
FFFFF7FFFFFFFFF7F8FFF7F8FFF4F4FFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFF6F0FFF6F0
FFF6F0FFF6F0FFF2E9FFFFFFFFFFFFFFFFFFFFFFFFE3EFF8E3EDF4FFF7F8FFFFFFFFFFFFFFFFF7\
FFFFF7FFFFF3F7F7F4FFFFFFF7F7F8FFFFF7FFF7F8FFFFFFF7F4EDFFFFF7F7F7F4
F3F4EDF7F7F8FFECF8FFF6F8F7FFFFFFEBEEFFF2F4FFFFFFFFFFFFFFF6F8FFF6F8FFF6FFF3F6F4\
F7FFF8F3F7F8F7F7F7F5EDF3F5F7F7F2F7F4D9CAD4E2D4DECEC9CBCED9DBD1D4DF
D1DDDEEBF4EDF3F4F8DEEDECFFF7F8EEF6FFD6E0E8CBE0E1C4E1E1C2D9E1AAC0CDA8B8C4CAD4D7\
D9D3D6EEF6E5FFFFF4FFFFF8F7F7F8F7F7F8FFFFFFFFFFF4FFFFF8EEF6F8FFFFFF
EEFFFFEEF2FFFFFFF8EEF6F8E6F2FFE6F6FFF7F7F7EBF3F7EBF3F4D9E4E5E3EDEDE2F4F4DEEDED\
E3F7ECFFF4F3EBF3F4EEFFF8FFFFF8FFF2F8EEFFF4FFF6FFFFFFFFF3F4F3B7CFD7
B0C8D3D1D4DBDEF4F4FFFFFFF5FFFFFFFFFFEAF7FFE3F7F8D9DDE6F7FFF8F3EEF0C1CDDBADC9D5\
D8D9DED9E4EDEEE4E5F3DBDCF3F4F3F3D4D7D6E0E888B5CB7C736E8B8F97E3D1D6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8EBE7F07A6D5CB7ABA3F5FFF8C8D9E3DAF7F8F2F7F7\
F7FFFFF1F7F7F3F4F3ECF7F7ECFFFFF1F7F7F1FFFFF5FFFFEBF7F8E5F4F4D6E0ED
FFFFFFD6E0EDECF7F7E3EEF7EEEEF7EBF7F8EEF7F8FFF7F8EAE6E8DEF7F7F7E4EEA9C1D6D8E1DC\
E5E5F0DADCDEECEEEFF7F3F4F7F4F4F7EFF0F7F7F8F7F4F4FFFFFFFFFFFFFFFFF7
FFFFF7FFFFFFFFF4F4FFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFF6F0FFFFFFFFF6F0FFFFFFFFF6F0FFF2E9
FFF6F0FFF6F0FFFFFFFFF2E9FFF2E9FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFF7F4\
FFF7F4FFFFF7FFFFF7F7F7EFF7F7EFFFFFF7FFFFF7FFF7F8F7F4EDF7F7F4FFFFFF
F7F7F8FFF7F8FFFFFFFFF7F8FFF6F8F7F7EEFFFFFFFFF6F8FFFFFFFFF6F8FFF2F8FFF2F8F3F6F8\
F7FFF8F3F7F8F7F7FFF7FFF8F7FFF8F3FFF4E2E6DEEAE1DCEBD9CFD6C9C3C5CBC8
B9C1C4B9BDC6D6E0E9D1DDE7DEEDEFDAE5F8E6E6EEEEF7F4FFF2F8EEEBF0D6E4EDB3CCD697B7C5\
8398B29C9FB1BDC5D2D6E0E5E5E5E7F7F7F8FFFFF8FFFFF8EEEEF4EEEEF4EEF6FF
EEF6FFFFFFFFEBEBF7F3ECF3F3ECF3F7E7ECEBE4EDF7EFEFCFD5DFD8DBE3DEE0E9C9D4DBE2D4D6\
E3DDDFE3F7F8EBE6E8FFF2F8EEF6F8EEF6F8EEF2F8FFFFFFEEFFFFF7F4F3ADBAC5
B0CAD3C5D9E6F5FFFFEEF7F8F1FFFFF5FFFFE4F4FFCBE1EEFFF3F4F7ECF4E6EFEDC2D1DFB4CDD3\
BCCDDBECF7F4EEE5EDE5CBD6EED1D3F7D4D7BDC2CAB7DCF0AAA4A39F9D92B5A9AC
E3DDF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8F7EDEE766161A39791E6ECF4DEE4EED9E5F0E6F4F4\
EBEFEFFFF7F7EAF7F7EAF4F3EAFFFFF5F7F7F5FFFFFFFFFFFFFFFFFFFFFFD1E0EC
F7F7F8EBECF4DEECF3FFFFFFF1FFFFD8F4F4FFFFFFECECF4D9EEF4E3EFECECE5F0A8BAD0DEE5E1\
EEEEF8E3E7E9F5EDEDEADDDFF7EEF0F7F7F8F7F7F8F7F4F4FFFFFFFFFFFFFFFFFF
FFFFF3FFFFFFFFF7F8FFF7F8FFF4F4FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0FFF6F0\
FFF6F0FFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFF6F0FFF2E9FFF6F0FFF6F0FFF6F0
FFFFFFFFF2E9FFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFF7F8FFF7F8\
FFF4F4FFFFFFFFFFFFFFF7F8FFF7F4FFFFFFFFFFFFFFFFF7FFFFFFF7F7ECF7F4F4
FFE4F4F3ECF8F3EEFFF3EEFFF7EEFFF7F3F4FFF6F8FFF6F8FFF6F8FFFFFFFFF2F8FFF6F8F7FFF8\
F3FFF8F7FFF8F7FFF8F7FFF8F3FFF4F7FFF8ECF7F8F5F7FFF5F7FFF5E6E7EED1DB
E3D4DECECBCBBCC9C3C8D4DFE3E5E5D6EDDCD1E8E1D1DDE7E6EBF0EEF2F8FFFFF8EEEBF0EEF3F8\
DAECF4B3C1CEADABB6A8A9B2AAAFBCCBD4D6D6DBE1E6E4E8EEE4EDEEE4EDE6E0EC
EBE6F3EBE6F3EBEEF7F3FFFFE2F7F8DEEFF0E4ECEECDDBE3D0D5D7E3EDE8E3EDE8FFFFFFD6E5E5\
D9E4D5D9E4E5EEF7F7FFF6F8E6FFFFE6F6F8FFF6F8EEFFFFEBF7F7F7F7F795B0C0
C1C8D1DEECF4FFFFFFD0E5EFEBEEF7FFFFFFF7F7FFD6D9E3EEECF8EBEDF0F7EDE5B2CFE8D6DCDB\
BAC2D5E6CCDBEBE0ECF7F7F8F3ECEFEEF3F4ADBAC4D9F4ECC4C8D0CEC5B69DA39C
E2CFD4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7561689C8A7FE6ECF4E6F4F4E4E6F4FFF7F8\
E3EFF0EEF7F8F1FFFFF7F7F7F7FFFFF5F7F7ECF7F7ECF7F7FFFFFFFFFFFFDEECF3
EBECF4F7F7F8D9E4EFEAF7F7EEF7F8F5FFFFEBF7F4E3EEFFDAE4E8EBE4E5EAEEF8C2D1DBCDD4DE\
EBEEEDD9ECF4FFF7EFE4E4E7FFECEEF7FFFFF7F7F8FFFFFFFFF4F4FFF7F8FFFFF7
FFFFF7FFFFF7FFFFF7FFFFFFFFF4F4FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0FFF6F0\
FFF6F0FFF6F0FFFFFFFFF2E9FFFFFFFFF6F0FFFFFFFFF6F0FFF6F0FFF6F0FFFFFF
FFF6F0FFFFFFFFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFF6F0FFFFFFFFFFFFFFFFFF\
FFF4F4FFFFFFFFFFFFFFF7F8FFF7F4FFF7EFFFF7ECFFFFF7F7F7ECFFF7EFFFFFFF
F3EEFFFFE5F8FFE5F8FFF6F8F3F4F4F7F7F8F7FFFFF7FFFFFFF6F8FFF6F8FFF6FFF7F6F8F7F6FF\
FFF6FFF7FFF8F7FFF4F7FFF8F7FFF8F7FFF8EAF7F4E4F4F4F2F7F8F5F7FFF5F7F7
F7EDE5F3ECF4DAD5D7BECAC4C4C1D0D8D4E5D6DBEEC4D1DEBEC8D6BDD1DBD6E4E5EEEBF4FFFFFF\
FFF6F8EEF2F8DAEDF4DEEDEFB5C3CECAC5D0C9CFD1C3C6D6D1CDDCD8E4E5DEE7E9
E2E0E3E2E0E3D6D4D7CBCFD1CDCDD0D8D4D6D8E0E1E3EDE8FFF7EFFFFFFFFFF7EFDAE5E7D0DDE8\
E2E5DDF7E4F8EEF2F4E6FFFFFFFFFFEEFFF8EEFFF8E6FFFFF3F4F3E2F7F886AEC5
CEC1CBF7FFFFD6EDEDF2F6FFD0E5EFDEF4F4DEF4F4F7ECE9F3ECF8EBF4EEEEEFEFC2E0F4CFE0E6\
C1D1DDEAECEDEBD4D6D9C5CFCAC1CAC5C8D1A9CCDDF2F4ECC4C8D0D6CDB68F979C
EBD4D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8A6D748A8C7FEEFFF7FFFFF7DAE5E7ECF3F8\
EEEDEEEBF7F8F2F7F7E2FFFFF5FFFFF7F7F7F7F7F7ECF7F7FFFFFFFFFFFFECF7F7
DAE5EFEEEEF8EBECF4EBECF3E2F7F8FFFFFFD9E5EEDEE0EDECE5E7DFE5EDEAE5E7DFE8E1B6CFE3\
F5F7ECD9E4F0F7EDE1E4E6F4FFF4F4F7FFFFF7F4F4FFF7F8FFF4F4FFF7F8FFFFF3
FFFFFFFFFFF7FFFFF7FFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0\
FFF6F0FFF2E9FFF2E9FFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFF6F0FFFFFF
FFF2E9FFF6F0FFF6F0FFF6F0FFFFFFFFF2E9FFF6F0FFF2E9FFFFFFFFF6F0FFF6F0FFF6F0FFFFFF\
FFF4EDFFFFF7FFFFFFFFFFF7FFF7F4FFFFFFF7EFE5F7F7F8F7F7F4FFF7EFF7FFFF
F7F7F8FFFFFFFFFFFFFFEFF0F3F7F8F7FFFFF7FFFFF7FFFFFFF6F8FFF6F8FFF6FFF7F6F4F7F2F4\
F7F2F4F7FFF8FFFFF8F7F6F8F3F6F4F7FFF8FFF6FFFFF6FFF3FFF4FFFFFFF5F4F7
F5F7F8FFF4EDF7E5F0E5E4E7CED3DBCACDCBDAD9DBEAE4E1ECEDE1E3DCDEC7D4DECEE5E5D6E4ED\
E6EBF8EEF6FFEEF7F8E6F4F4D1E6E7D1DCE5D9DBE9D6D9E6D1DBE9D6D3DEE2E7E1
C2E7E5BDE0E5D0DCE5D8E0EEEBF4F8FFFFFFF5F7F8F2ECF8F7EEFFECF7F8DEE5E5C7DDE8E2E6DF\
FFF7F7EEF2F8EEF2F8E6FFF8EEFFF8EEFFF8F7F7F7F3F4F3FFFFEFDEEDF890A4B9
D1D4DBDAEFEFDAEFEFEAF4F3EBF7F8D6EDF4D6EDE5E2F4F8ECF7F0EAF7EEEBEFEFDFEDF3D1E8F3\
ACC1D5C4D1E2C1D9E9BED5DDCAD5E2C5E0E8D9ECE8EAE8E1D1D4DBBEB6A19B8F97
EEE5F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9079848F8574EEF7F8E6F7EFEEF7ECD6EBF8\
EBEDF0F3F4EDDEF7F7EAF4F3EAF7F7F7EFEFEBF7F8F5FFFFF5FFFFFFFFFFFFFFFF
E4F4F3E6E6F4F3F4F4EBEBF7EAF4F7D6EDF4ECEEF8EAE5E5EBF7F7E5E5EDF2E5E7DEE8DCBCD4EE\
ECF4ECE6EBF4F3E8E2EAECEFF7ECEEF3EEFFFFE4F4FFFFFFFFFFF7FFFFF7FFFFF7
FFFFF7FFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF6F0FFFFFF\
FFF6F0FFF2E9FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF2E9
FFF6F0FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFF6F0FFFFFF\
FFF4EDFFFFF7FFF7F8FFF7EFFFF7F4FFF7EFF7F7F4F7F7F8FFFFF3F7E4E8F3ECF8
F7F7F8F3F4F4F3F4F4F7EDEEF7F7F8FFFFFFFFFFFFFFFFFFFFF2F4FFF6F8FFF6F8FFF2F4FFF6F4\
F7FFF8F7F2F8FFF2FFFFFFFFFFFFFFFFF6FFF7F6F8F7F6F4F3FFF8FFFFFFFFF7F7
F5F7FFF1F7F7F5FFF8F7EFF0F7EEF8EEEEEFCEE5DBCAD9DBCFD9E6DEE4E7D0DDE5DFD9DED1DCE5\
DEE5E5D6E8E8D6EFEFE6FFFFEEF4F4ECF7F7ECF7F7F7F7F8F7F7F8EEEEF8DEE0F4
F2ECF0E5FFF8EEEEF8EEF7FFE6ECF8E5FFF8DAF7FFF2EEF7E3E4EDDAE5E7D9E5E7ECE5E5EBF7F4\
FFFFFFEEF6FFFFF6F4FFFFF8EEFFF8F7F7EFEEFFFFF7F7F7F3F4F4DEE6F88FA4BA
C5D4DDD6EDECF7F7F7EAF7F7F5FFFFF7F7FFF7F7F0FFFFFFF2F7FFEAF7F0F2F4F3DAF6F8E5F2F4\
CED3E7EAE4E8E2E0E1E2E7EDD9ECEEEEF6F8EEEBEEEBEDE1CEC5C482796FB5A8AC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA38CA2887350E6F7F4E6F7ECFFFFFFD6ECED\
E3ECF8F3EFEDD9EDECEAF7F7E2F7F8E3F7F8EEF7F8E3F7F8F5FFFFFFFFFFEEF7F8
D9EFEFE3E4EFFFFFFFEEEEF8D9ECECDAEFF8FFFFFFEAE6EEEBF4ECE5E5F0F7E5F0D1E8E1D1DBEE\
EAEFE8CEE4F8F3E8E3F1F7F7F3E5E7F3FFF0F7ECF8F7F7F8FFF7F4FFF7F8FFFFF7
FFFFF7FFFFF7FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF4F4FFF4F4FFFFFFFFF2E9FFF2E9\
FFF6F0FFFFFFFFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0
FFF6F0FFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFF7FFFFF7F7F7F8F7F7EFF7E4EDF7E4F4
F7F7F8FFF7F8FFF7F8F3F4F4F7F7F8FFFFFFF7FFFFF7FFFFFFF6F8FFF2F4FFFFF8FFF6F4FFF6F4\
FFFFFFFFF2FFFFF2FFFFFFFFFFF6FFFFF6FFF7F6F8FFFFF8F7FFFFFFF7F7FFF7F7
FFF7F7F5EFF3F5F7F7FFF7F8F7EDEEF7E4F0FFF6FFEEEEEFDAEDE5E4DCDECFDCE6D1E0E5D1D3DB\
DFD4D6DFDCDBDAE6DFECEDEDEEFFFFEEF7F8ECF7F7ECF7F3EAF4EFE2EDEDF3F4ED
E3E4EEDFE0EEDFE0EEEBECF4EBEEF4EEEEF8D1F7FFE4F7F4DAEEF8DADDDFF5E5E5F7EFEFE6FFF8\
EEFFF8EEFFF4E6FFFFE6FFFFFFFFFFF3F4F3F3F4F3EBEDECE3F7F8E2F4F48AA4B9
CBD4DBEAF7F7ECF7F7F5FFFFF1FFFFF1FFF0F5FFF0E3F7EEEBF7EEFFFFFFEAF4F3ECF6F8C7ECEE\
B5DDE8BAE6F4CEF3FFEBE1E5FFFFF8F1F3F0E3ECE7EBF4ED756459877F85F3EDEE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EFF0A897A4887962EEEFE7EEF7F8FFFFF7EBF4F4\
E2D9DBF7F7F4EEEDEEEBEFF0DEF4F4EEF7F8E6F4F4FFFFFFEEF7F8EEF7F8FFFFFF
F5F7F8C4D4DDB5C5D0D2DBE1CAE4EDFFF7F8FFF7F8ECECF4E5ECEDEEFFF7EADBE9C9E8EDDEDBE2\
EAEFE8CEE4FFF7EFE6EAEDEDF7FFFFEEE4E5FFF7F8F7F4F4F7F4F4F7F4EDFFFFF7
FFFFF7FFFFF7FFF7F8FFF7F8FFF7F8FFFFFFFFF7F8FFFFFFFFF4F4FFF4F4FFFFFFFFF2E9FFF2E9\
FFF6F0FFFFFFFFFFFFFFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFFFFF
FFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF4F4FFFFF7FFFFF3FFFFF3FFFFF3F7F7EFFFFFF7F7EEF7F7EEFFF7F7F8
F3F4F4F7FFFFFFF7F8F7F7F8F7F4F4F7FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFF6FFFFF2F8FFF6F8\
FFF6FFFFF2FFFFF6FFFFF6FFFFF2FFFFF2FFFFF6FFF3FFF4F7FFF8F7F7EFFFF7FF
FFEFF7F5EDF7F1F7F7F1F7FFF5F7FFF7E5F0F3E7EEF7EBF8EEF6F8EEEEEFF5E6E5EAE8E2CDD9E3\
BDCFDEC1BDD4BDB5C9A3B5C498BBC8B1C8D6C4D4E1DEE7ECE3EFF7ECF7F7ECF7FF
ECF4F3EBEDEDE6ECF4D6E0EED6E0F0CED3E5D6E0E1D6D9DBDED1D3E2E5E5EBF7F7E6FFF8FFFFFF\
EEFFF4FFFFFFEEFFF8EEFFFFF7F7F7F7F7F7F3F7F7FFEDEDDEF7F8D1D5DF8FA2B6
E5ECF4E3F7F8F5FFFFF5FFFFEEF7F8EBF7EEEEF7EEF7F7F0D6EDEEECF7FFF7F7F7ECF7F7ECE5E8\
E4E4E6C7EBEDD6ECECD6EDF4DEF7F4F3F3F4EAEEEDEBE8E24E4834D1C4D7EBE4EE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2D9E9A8A2909D8B90EEF4EDEEFFF7FFFFF7F7F4ED\
D8D4D0F7F7F0F7F7FFDEEDE9D8F4F4EEF7F8EEF7F8EEF7F8EEF7F8EEF7F8FFFFFF
FFF7F8E5E5E8EBECF8EAF7EEECF7F0F7ECF0F7EBEEF3EBEEDEECEFEEFFF7E4DBE9CBE8F4EBE0E1\
E3E6E7D9E5EDE3F6F8EAE1E2F2F6F8F7F7F7F7ECEEF7F4F4F7F7F8F7F7F8FFFFFF
FFFFF7FFFFF7FFFFFFFFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF6F0FFF6F0\
FFFFFFFFF2E9FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFF
FFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFF\
FFFFFFFFF4F4FFFFF3FFF7EFFFF7EFFFFFFFF7F7F4F7F7F8FFE5F4FFE5F8F7F7F8
FFFFFFF7F7F8F3F4F4F3F4F4F7F4F4F7FFFFFFFFFFFFFFFFFFFFFFFFF6F8FFF2F4FFF6F8FFF6F8\
FFF6F8FFFFFFFFF6FFFFF2FFFFF2FFFFF2FFF7F6F8FFFFFFFFFFFFFFF7F8F7F7F7
FFEFF7F5EDF7F5FFF7FFF7FFF1F4FFFFFFFFFFF7F8F7E5F0F7F3F8EEF2F8E6F3F4E6ECEFEEF4F3\
EEF4ECD9EFE7DEEFF0ECECEEE2DCDED1E0E1DAE5E1E5E0DBD6D9E3D9DBE9CAD4E2
C1C8D6CECDDBDEE4EEE2EDEDD9DCDDE2DCDEF1E1E2F2E5E5F7F7F7EBF7F7F7F7F7EEFFF8F7EFF8\
F7EFEFFFFFE7FFFFF8FFFFFFF3F4F3FFFFFFF3F7F8ECF7F8E2F4F4BCCFDCB0B6C6
FFFFFFE6F4F4FFFFFFF5FFFFEBF7F8E3F7EEDEF4F4D9EFF4ECF7F0E3EFF0F7F7F0D9E4ECEEEEF8\
F7F7F7D9EFEFEEF7F8EEF7F8EEEDEEFFF7F8EAEBF4E3E1DC7B8373868069978D8D
DACCC6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFD1C2D4988F6CCABBC1DAE4E8F7F7F8F7F7F4FFF4F4\
D9E5E7E3E5E7F7F7FFE2EFEEF5FFFFEEF7F8E6F4F4FFFFFFFFFFFFEEF7F8E5E5E8
E5E4E6EEF7F8F7F7F4F7FFF8F7FFF8F7EEEEEAEEEEF2F6F4DEECEFF7F7F4E2E0EED0EDF4D0E5EC\
E2E5F0EAE1DBDEF2F8F3E8E9EAECECF7FFFFF7ECEEF7F4F4F7F7F8F7F7F8FFFFF7
FFFFF7FFFFF3FFFFFFFFF7F8FFF7F8FFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF3EE\
FFF2E9FFFFFFFFF2E9FFF6F0FFFFFFFFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFF2E9FFF6F0FFFFFFFFF6F0FFFFFF\
FFFFFFFFF4EDFFFFFFFFF7F4FFF7F4F7F7F4F7F7EFFFFFF7F7F7F8F7F7F8F7E4F4
FFE5F8FFF7F8FFECEEF7EEF0F7FFFFF7F7F8FFFFFFFFF6F8FFF2F4FFFFFFFFF6F4FFF6FFFFF6F8\
FFF6F4FFF2FFFFF6FFFFFFFFFFFFFFFFF6F8F7F6FFF7F6F8F3F6F4F7F7FFF7F7FF
FFFFFFF5F7FFFFEFF7F1F4F7FFFFFFF1F4FFF5F7FFFFF4F4F7F7F8F3ECF4F7F3F8FFF2F8EEF6F4\
EEF2F8F7EEEFEBEDE5EAEDEDE4EDEEEAE4E6DEE0E9CBE0E5D2E0E1CBDBDCCBDBDC
D2E0E1DFE6E8DEE0E1D6D9DBE2ECDEEBE4ECE6F3EFEEFFF8EEFFFFF3EDF7F3EDEFEEFFF8F7EFFF\
F7EFEFEBEFEFF7EFFFFFFFEFF7F7F8F7F7F7E2F4F4F5F7F8E6E5E7AFC1D6C4C5D0
FFFFFFE6F4F4FFFFFFF7F7F0F7F7F0F1FFFFE3F7F8D9EDF8E2EDF0ECF7F0DEEDE9EBECECF7F7F8\
E5ECF3EEF7F8D9EFEFD6EDEDF7F7F4F7F7F4F3EEEEE2DCE5BEC2CDBAB2B28F858D
A4978AFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFC4AAB2898A72E3D4D5ECE5E7F3F4E8F3EDE5EEEFE5\
F3F7EFE2E0DCE4F2FFECEEF8EEEFF0EEF7F8EEF7F8EEF7F8EEF7F8FFFFFFE3E0E2
E3DBDDEEF4F4EEF7F8E6F4F4E6F4F4EEF7F8ECEEF8ECF3F8D6EBF8F3EDE1EBECF4E4DDE8DFEDEC\
D8E6F4E4E1E2E6EBEDF3EDEEF5EFEFEAEBEDF7F7F8F7EFF0F7FFFFF7F7F8FFFFF7
FFFFF7FFFFF3FFFFFFFFF7F8FFF4F4FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF3EEFFEEE8\
FFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFFFFF
FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF2E9FFF6F0FFF6F0FFFFFFFFFFFF\
FFFFFFFFF4EDFFF7EFFFF7F4FFFFF7F7F7ECF7F7F8F7F7F8FFFFFFFFFFFFF7EEF7
F3ECEFF3EEFFF3F7EEF7EEF0FFFFFFF7F7F8FFF6F8FFF6F8FFFFFFFFF2F4FFF6FFFFF2F8FFF6F4\
FFF6F8FFEBF8FFF3F8FFF6F8FFF2F8FFFFF8FFF2F8FFFFFFF3EEEDFFF4F3FFF7F7
FFF7F7FFF4F3F5F7F3F5FFF7F5F7FFF1F4FFF5F7FFFFF7F8FFF7F8F7F7F8F7F7F8FFF6FFFFF6FF\
FFF6FFFFF6FFEEFFF8EBF7EDEBF4E8D9EFE7E2F4F4EAEDEEE4E8E9E4EDE2E4EDE2
E4EDEEE4EDEEF2E5E5EBEDE5F3EDF4EBE4F8FFF2FFEEFFF8FFFFFFF7EFFFF7EFF8EEFFF8F7EFFF\
EBEFFFF7EFEFEBFFECFFEFF8F7EFEFFFEDECDEF7F8F3F4F4D9E0E1B7C8DBCBDBE2
FFFFFFE6F4F4FFFFFFF7F7F0ECF7F0FFFFFFF5FFFFF7F7F0DEEDF0ECF7F0EAF4F0F7F7F7F7F6F3\
E5ECF7ECF7F7FFFFFFDEF4F4F7F7F0F7FFF8F7FFF8ECF4EEC9D4D6F3F7F8A89DA3
7C736EFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA88A90939C89EAD4D6EEFFF7F7F7F8EBEDE5EEF4ED\
EBF7F4E3E4E1ECF2FFEAFFF8F7EEF0FFF7F8FFF7F8E6EDEEEEF7F8E3F7F8E4F4F3
EAF7F7E6EDEDEBF7F8DFF4F4E6F4F4EEF7F8FFFFFFF7F7F8F5EEF8E3E5E7EBF4EDE2DBE9DAEFEF\
D1DDE7D0DDE8D6D9DDF7F7F0F7EFF0E4E0E1FFF7F8F3EFF0FFF7F8FFFFFFFFFFFF
FFFFF7FFFFF7FFFFFFFFF7F8FFF4F4FFF7F8FFF4F4FFF4F4FFFFFFFFFFFFFFFFFFFFF6F0FFF2E9\
FFF6F0FFF6F0FFFFFFFFF2E9FFF2E9FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFF\
FFFFFFFFF7F8FFFFFFF7EFE5F7F7EFFFFFF7FFFFF7F7F7EFFFFFFFF7F7F8F3F4ED
F3F4EDF7EEFFF7F3F4F7F7F8F7EEF0FFF6F8FFF6F8FFF6F8FFFFF8FFF6F8FFF6FFFFFFFFFFF6FF\
FFF6FFFFF7F8FFF7F8FFF2F4FFF6F4FFF6FFFFFFFFFFF2FFF3F4E8FFF7F7FFF7F7
FFF7F7FFF7F7FFF7F7F5F4F3F5F7F7F5F7FFF5F7FFF5F7FFF5F7F4F7F7F8F3F3F8F3F3F8F7F3F8\
F7EFF0F7E4F0FFF2FFFFF6FFFFF6FFF7EEEFF3ECE8F3ECE8F3ECE8F3E4F4F3EDF7
F3EDECF3EDE5EBF7F4EEF6F4EEF6F4FFF6F8EEF6FFEEFFF8FFFFFFEEFFFFEEFFFFEEFFF8F3EDF4\
F3EDF7EEEFECFFFFEFE6EFF7F7EDF7F7F7EDE4EEF0EBE4E5D0DCE5BDCDD6D6E0EE
FFFFFFE6F4F4F5FFFFF1FFFFF5FFFFF1FFFFEAF7FFE2F4EEF2FFF8EAF7E9F7F7FFF7F7FFFFFFF7\
F7F7F7FFFFF7E3EFE7F2F7F0E6F4F4EEF7F8D6EDEDEBF4F4BEC8CBF3F4F4B5B2B2
67615EF7DDD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF816D74ADA79BF7E4E1EEFFF3EEFFF3EBF4EDF7F7F8\
FFF7EFE4E6E8ECFFFFEAF6F8F7F6F8F7F4F8EAECF8D6E0E9FFFFFFF5FFFFEAF7F7
E3F7F7F7EDECE5F4F4F7F4F4FFF7F8EEF7F8E6F4F4E5F7F8F5ECF4ECF6FFEEF7EFDED4DBF2FFFF\
E5E8E8CEE6F4CED9E2EEEEEDF7F7F8DED9DBFFEEF0F7EFF0F7F7F8FFFFFFFFFFF7
FFFFFFFFFFF3FFFFF7FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFFFFFFFFFFFFFF6F0FFF2E9\
FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFFFFF2E9FFF6F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFF6EDFFF6E7FFFFFFFFF6F0FFF6F0FFFFFF\
FFFFFFFFFFFFFFF4F4F7F7ECF7F7F8F7F7F8F7F7ECFFFFF7F7F7EFF3F4F4F7FFFF
F7F7F8F7F7F8F7FFFFF7F3F4FFF6F8FFF2F4FFFFFFFFF3F4FFEBF4FFF6FFFFF6F8FFF6F8FFFFFF\
FFFFFFFFF6F8FFF2F4FFF6F8FFF6F8F7F2F4F7F2F8FFF6F8F3F4ECFFF4F3FFFFFF
FFF7F7F7FFF8F7F7F4F5F7F7FFEFEFFFFFF8F5F7FFF5F4F8F5FFF8FFF7F8FFE4EEFFECF4F3ECF4\
F3E7EEF7F7F8F7EFF0F7F3F8F3E4EEF3E4EEF7F3F8FFF6FFFFFFF8FFFFFFEEF6F4
E6F6F4EEF2F8FFF6F4EEF6F8EEF6F8EEFFFFEEF6F8EEF6F8EEFFF8FFFFF4EEFFF8EEFFF8F7F7F4\
F7F7F7EEEFF7EEEFF7F7F7F7F7EFEFECF7F8E3ECEED9E1E1C4D5E6C4D3DBECECF4
FFFFFFEEF7F8E2F7F8F5FFFFF1FFFFF7F7FFF5FFFFDEF4EEFFFFFFDEF4EEFFFFFFF7F7F7F7F7FF\
F7F7F7EAF4FFF2F7F0F7F7F0EEF7F8DAEFEFE3EEF7DEECF3CBCFD1F7F7F8DADCE5
556969C6A7A7F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF765B5CBCBCB4F3E5E7F3F4EDEBF7EFF7F7F8EBF4F4\
F7EFE7E3E4E1ECF6FFECF6FFEAF2F8EEECF4EAECEEDAE5F0EEF7F8E6F4F4E5F4F4
E3FFFFF7F7F7EEEFF0E6E8E9E6EDEEEEF7F8FFFFFFEEF4F4D6DCE5DAE5F0F5FFF8CDDCE1ECE5F0\
F3EFEFCBD9E5E2EDEED6E0E5F7F7F4E4E1E1F7F2F4FFF4F4F3F7F8FFF7F8FFFFF3
FFFFF7FFFFF3FFFFF7FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFF6F0FFFFFFFFF2E9\
FFF6F0FFFFFFFFF2E9FFF6F0FFF6F0FFF2E9FFF6F0FFFFFFFFF6F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFF6EDFFF6E7FFFFFFFFF6F0FFF6F0FFFFFF\
FFFFFFFFF7F8FFF7EFFFFFF7FFFFFFF7F7F8F7EEF7F7E4E8F7F7F4F7F7F8F7E5F8
F7EEFFF7F4F4F7F7F8F7EBF4FFFFF8FFF6F8FFF6F8FFF7F8FFF7F8FFF2F8FFF6FFFFF6F8FFFFFF\
FFF6F8FFF6F8FFFFFFF7FFFFF7FFFFF7FFF8F7FFFFF7FFF8F7F7F7F7F7F7F7FFFF
FFF7F7F7F7F4F7FFF8F5F4F3FFF7F8F5F7F8F5F7FFF5FFF8FFF7F8FFF7F8FFF4F4FFFFFFF7EFF0\
FFFFFFF3EDEEFFF7F8F7F7F8F7F4F4F3EDEEF7F7F8FFFFFFFFF2F8FFF2F8FFF6FF
FFFFF8FFF2F4EEF6F8FFFFFFEEF6F8EEF6F8EEF6FFFFF6FFFFFFF8EEFFF4EEFFF8EEFFFFEEFFFF\
EEFFFFFFFFFFF7F7F7F7F7F7F3F7F8DEF4F4E3DDDFD1DCE5C5D4E2E5F3EFECECF4
FFFFFFE3F7F8E3F7F8F1FFFFECF7FFF5FFFFECF7F0ECF7F0F2FFEEF7F7FFE3F7F8F7F7F3F7F7F7\
FFFFF7E2FFF7EBF4F4EEF7F8F5FFFFD9E4ECEBECF4C4DBE8D6D4D6F3F4F4F3F7EF
83837694787EF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF614238CFDCD6DFD9DEF3EDE5EEFFFFEBF4EDEEF4ED\
F7FFFFF7F4EDE4EBEFECF6FFF2F6F4F2EBEEDAEDEEE6EDEEF5FFFFDEF4F4DEF4F4
EAF7F7FFFFFFFFFFFFECF7F7ECF7F7FFFFFFFFFFFFFFF7F7EEEFEFE5ECF4F7EEF0E5EDE8E3EEF4\
E2E5E7C7DDE7CED1DEBECBDFD1D9DDE2D1D2F7F3F4F7E5E7F7F4F4F7EFF0FFF7EF
FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0FFFFFF\
FFFFFFFFFFFFFFF6F0FFF2E9FFF2E9FFFFFFFFF6F0FFF6F0FFF6F0FFFFFFFFFFFF
FFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFF2E9FFFFFFFFF6F0FFFFFFFFF6F0FFFFFF\
FFFFFFFFF4EDFFFFFFF7F7F4F7F7F8FFFFFFFFE5F8F7E4F4FFFFFFF7F7F8F3EEFF
F3F6F8FFF7F8FFFFFFFFF2FFFFF6F8FFF6F8FFF6F8FFF2F4FFF2F4FFFFFFFFF6F8FFF6FFFFF6FF\
FFF2F4FFFFFFFFFFF8F7FFF8FFFFFFF7F7F8F7F7F8F7F7F7F7F7F7FFF7F7F7F7F7
FFFFFFFFF7F7FFF7F7F5EDECFFF4F8F5F7FFF1F7FFF5FFFFF5FFF8F5F7F4F5FFF8FFF7F8FFFFFF\
F7EFF0F3F4F4F7EFF0FFF7F8F7F4F4F7FFFFFFFFFFFFFFFFFFF6FFFFFFFFFFF6FF
FFF2F4FFFFF8EEFFF4EEF6F4FFF6F8EEF2F8EEF6F4FFF6F4FFFFF4EEFFF8FFFFFFFFFFFFEEFFFF\
FFFFFFE6FFFFF3F4F3E3F7F8D6EDEEDADDDFD0DCE5D1DDE7C4D3DEE4EBF8ECEEF8
EEF7F8EBF7F8F5FFFFF5FFFFEAF4FFF3F4FFE2EFE9F2F7F0DAE5E7CEE0ECD9ECF4FFFFF3FFFFF7\
F3F4F7ECF7F7D8F7F8E5F4F4EAF7F7E6E6F4EBECF4BDD1DBECEEEFE3DCDBEBF7F8
A391918A736EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF493122F1F4F4D2C1CBDEE4E5EBF4E8EBEDE5EEF4F4\
EBFFFFF3F4F4E2E4E5F3F2F4F7F6F8F2F2F4ECFFFFFFF4F4E2EDEDF2F7F7F2F7F7
F3F4F3ECF7F7EEF7F8D2EDEFD2EDEFE6F4F4EEF7F8FFFFFFE6EDEEECECF4ECEEF8EBEDE1F7F7F4\
F7E5F0E2E0DCDFDCD6DED9DEDAEFF0C4C6C8F5F4F4F3ECE8FFF6FFF7F4F4F7F4F4
FFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF6F0FFF6F0FFFFFF\
FFFFFFFFF6F0FFF6F0FFF6F0FFF2E9FFFFFFFFF2E9FFF6F0FFF6F0FFF6F0FFF6F0
FFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFFFF7FFF6EDFFFFFFFFF6F0FFF6F0FFF6F0FFFFFFFFFFFF\
FFF7F8FFF7F4FFFFFFF7F7F4F7F7F8FFFFF7FFFFF7FFE5F8F7EEFFF3F4F4FFF4F4
FFF7F8F7FFFFFFF7F8FFEBF4FFF6F8FFF6F4F7F7F7F7F7F7FFFFFFFFF6F8FFF2F4FFFFF8FFFFFF\
FFF6F4FFFFFFFFF6F4F7F6F4FFFFFFFFF7FFFFF7F8F7F7EFF7FFFFFFFFFFF7FFFF
FFF4F3FFFFFFFFF7F7F1EDECF5F7FFF5F7F4F5F4F4F1FFF8F5FFF8F5F7F4F5FFF8FFFFFFFFF4F4\
FFF7F8F7F4F4F7EFF0FFEFF0F7F7F8F7FFFFFFFFFFFFFFFFFFFFF8FFF6F8FFFFFF
FFF6F4FFF6F4FFF2FFFFFFF8FFF6F8FFF2F8FFF6F4FFF6F4FFFFF4FFFFF8EEFFFFF7EFFFF7EFFF\
FFFFFFE6FFFFF7F4F3DEEDEEE2E5F0F2EEECC3E8F4EADBDCCBE6F4FFF7F8EEF4F4
E3F7F8EAF7F7EAF4F7F3F4FFE3F7F8D8EDEEF7F7FFD1DDE7EEEEF7EEEEF7F3F3FFF7F6F7F3F3F3\
ECF7FFF2F7FFFFFFF7F5FFFFECF7F7F3F2FFE2EBF7D6D9DBFFECEEECECF4D6E0DC
B09DA37C726EFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3B1D17F2ECF4D2C1CBEBE4E5EEF7ECFFFFFFEBF4ED\
FFFFF7F3F4EDF2F4F4F2F3F4F7F6F8F7F6F8F7F6F8FFF4F4EBEDEDF7F7F7F7F7F7
DEF7F7E4F7F7EEEFEFDFF4F8DFF4F8EEF7F8EEF7F8E6F4F4FFF7F8DAE4EEECEEF8E6F4E8FFFFF7\
F7E5F0F5EEE5D1D9E2D0DCE7EBE4DEC4C5CCEAEDE8F3ECE1FFF6FFFFF4F4F3F4F4
FFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFFFFFFFF7F8FFF6F0FFF6F0FFF6F0\
FFF6F0FFF2E9FFF2E9FFF2E9FFF6F0FFFFFFFFF2E9FFFFFFFFFFFFFFF6F0FFF6F0
FFF6F0FFFFFFFFFFFFFFFFFFFFF6F0FFF2E2FFFFF7FFFFFFFFF6F0FFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFF7FFFFF7FFFFF7FFFFFFF7F7EFF7EEFFF7EEFFF3EDEEF7F7F8
F7F7F8F7FFFFFFF3F4FFEEF0FFF6F4FFF6F4F7F7F7F7F7F7FFFFFFFFFFFFFFFFFFFFF6F8FFF6F4\
FFF6FFFFF2F4FFFFFFF7F6F8F7FFFFF3F7F7F7F4ECFFF7F4F7F7F7F7F7F7F7F7F7
FFF7F7FFF7F7FFF4F3F5F7F7F5F4F4F5FFFFF5F7F8F5FFFFF5F7F8FFFFFFFFFFFFFFFFFFFFF4F4\
FFF7F8F7EDEEFFF7F8F3F7F8F7FFFFFFFFFFFFFFFFF7FFFFF7FFF8FFFFF8FFF6F8
FFF2FFFFF6F8FFFFFFFFF6F8EEFFFFEEF6FFEEFFF8EEFFFFEEFFFFEEFFFFEEFFFFF7EFFFF7EFFF\
E6FFFFF7F7F7F2E6E7E2EFF0E5E6EDDAEFEFC7D5DFDADDE7D9EBF4FFF7F8D6E5E5
EAF4F3FFFFFFF7F7F7F7F7FFD8EDEEECEEF8C3DBE2EEEEF7F7F6F7EBECF7EBECF3FFFFF7F3F3FF\
ECF7F7EAF4F7F3F4F7E3E4ECE6E6F4F7F7F8DEECF3EEE5E8EEECEEECECF4D6E0DC
B7AFAE897C76E2D1DBF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF190000DADCE1DFE4EEF7EFE7EBF7F4EEF7F8EBF4ED\
F7F7F4EEFFF7F7F7F8E3E4E1F5FFF8F3F2F4F7F6F8EEEDEEEEF7F8FFFFFFFFFFFF
ECF7F7FFF7F7ECF7F7FFF4F3FFF7F7EEF7F8EEF7F8EEF7F8FFFFFFEEF7F8ECECF4D6ECE8F7E5ED\
FFFFF7F5FFFFECF7F7DAD9E2C8D5DEBDBBCAEAEDE9EAE0DCFFF7F8FFF7F8F3F7F8
F7F4F4F7F7EFFFFFF7FFFFFFFFFFF7FFFFF7FFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFF6F0FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFFFFFFFF6F0FFF6F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF2E9FFFFFFFFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF4F4FFFFFFFFFFF7F7F7F8F7F7F4F7F7F4FFFFF7FFFFFFF3E7F0F7ECF8
F7ECF8F7F6F8FFF6F8FFF6F8FFF6F8FFFFFFFFF6F8FFFFFFFFFFFFFFF6F8FFF6F8FFFFFFFFFFFF\
F7F6F8F7F2F4FFF6F8FFFFFFFFFFFFF3F7F7F7F4ECFFF7F4F7F7F7FFF7F7FFEFF7
FFF4F7FFFFFFFFFFFFFFF7F8F5F7F8FFF7F8F5FFFFF5F7F8F5FFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFFFFFF7EDEEFFFFFFF3F7F8F7F7F8FFFFFFF7F7F8FFF7F8FFFFFFF7FFFFFFF6F4
FFF2F8FFF6F8FFFFFFFFF6F8EEF6FFEEFFFFE6FFF8E6FFFFEEFFFFEEFFFFEEFFFFEEFFFFEBF7F7\
F3F4F3FFF7F7E2E8E9D9EEF8F2EEECBDE8F4F3DBDCDEF4F8EAEBF0E3EFF0E2F4F4
F3F4F3FFFFFFF7F7F7D9EDF8EAF7EEDEECF0BCD0E5FFFFFFF3F2F3F3F3F7F7F7FFF7F6FFF7F6F7\
EEEEF7F7F7F7F7F7F3DFE0E8EEEEF8EEEEF8E4F4F3EEF7F8FFFFFFD9E0E9DEE8E1
BCC1C5A08F7DC2AEBEF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFF7EFF0130605DEF7F7E6FFF3EBF7F4FFFFFFEBF4F4EBF4ED\
EBF7F8EEFFF7F3F4EDF3EDE5E4EBEFF7F6F8F3F2F4E5E4E6EEF7F8FFFFFFFFFFFF
EEF7F8D6EDECECFFFFECF7F7F7FFFFF7F7F7EEF7F8FFFFFFEEF7F8FFFFFFFFF7F8D1DBDCEEECF4\
F5ECEEECE0E9FFEEE7FFEEEDD2D4E3B4BAC4E5E5E5E3DDDFECDDDFF7F7F8FFFFFF
FFF7F8F7F7F8FFFFF3FFFFFFFFFFF7FFFFF7FFF7F8FFF4F4FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0\
FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8FFF4F4FFF7F8F7F7ECF7F7EFFFFFF7F7E4E8FFE5F8F3ECF8F7F6F8
F7F6F8F7F7EEFFF2F8FFF6F4FFFFFFFFF2F4FFF2F4F7FFFFF7FFFFFFF2F4FFF2F4FFFFFFFFFFFF\
F7FFFFF7FFFFFFFFFFF7F7F7F7F7F7F3FFFFF7FFF8F7F7EFFFF7F7FFF7F7FFF4F7
F5FFF8F5F4F4FFF7F4F5F7FFF1F4F4FFFFFFF5FFFFFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF4F4F7F7F8FFF7F8F3F7F8FFF7F8F7FFFFF3F7F8F3F7F8F7FFFFF7FFF8FFF2FF
FFF6F4FFF6FFFFFFF8EEF2F4EEF6F8EEF6F8FFFFFFEEFFF8FFF6F4EEF6F8EEFFFFEEFFFFF3F4F3\
FFFFFFE2F7F8E3EDEEE5E6EDE5EFEFC6D5DFE5E5F0DAE4E8DAE5F0E2F7F8FFFFFF
FFFFFFF7F7F7D9EDEFE3EFF0E3F7F8D1DDDFF3F4F8F3F2F3F7F6F7F7F6F3F7F6F7F7F6F7FFFFFF\
FFFFFFF7F6FFFFFFF7EEEEF4FFFFFFEBECF4F2F7F7DEF4F4E6F4F4D2DBE3E5E8E1
CACFD6978B7FC4B0B4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFF3E8E93F3332DED1CBE6EDEEEEF7F8F3F4EDF3E8DCF3E8DC\
F7F7F8F7F7EFF3F4EDF3F4F4EAECECECF6FFF1F7F4EAE0E2E6F4F4EEF7F8EEF7F8
E6F4F4D6EDEDE4F7F7ECF4F3F7F7F7FFFFFFF7F7F7E6F4F4FFFFFFFFFFFFFFFFFFDED4D6DEF7F4\
F7EEF8F5FFFFFFEEF0FFE6E9DFE0EEB6C2C5E6E0E5F3F4EEEAE0E1EEECEEFFF7F8
F7F7F8FFFFFFFFFFF7FFFFF7FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF2E9FFF6F0FFF6F0FFF2E9FFF2E9FFF6F0FFF6F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFF2E9FFFFFFFFF6F0FFF6F0FFF6F0FFFFFFFFFFFF\
FFFFFFFFFFFFF7EFE7F7F4E8FFFFFFF7F7F8F7F7ECFFE5F4F7E4F4F3F4F4F3F7F8
F7F7F8FFF3F4FFF2F8FFF2F8FFF6F8FFF6F8FFF6F8F7FFFFF7FFFFFFF2F4FFF2F4FFFFFFFFFFF8\
FFFFF8F7F7F7F7F7F7F7F7F4FFF7F4FFFFF8F7F7F4FFF7EFFFFFF8F5EFF0F5EFF0
F5F7F8FFF7F8F1F4F8FFF7FFF1F4F4FFFFFFFFFFFFF5F7F8FFFFFFFFFFFFFFFFFFFFFFFFF7F7F8\
F7FFFFFFF7F8F3F4F4FFFFFFF7FFFFF7FFFFF7FFFFFFF6F8F7F6F8FFFFF8FFF6F8
FFF6F8FFFFFFFFF6F8EEFFF4EEFFF8EEF6F8FFFFFFEEF6F8FFFFF4EEF6F8FFFFFFF7F7F7FFF7F7\
F3F7F8DEEFF0E2E5F0EAE5E5D2EDF8E4DBE2D6EEF8ECE4E5E6F4F4F5FFFFF5FFFF
FFFFFFE3F7F8ECF7F0FFFFFFD1E4E5EBECF4EBEBF4F7F6F3F7F6F3FFFFFFF7F6F7FFFFFFFFFFFF\
EEEEF8EBEBF8FFFFFFF7F6FFF7F7F8E3E4ECFFFFFFD8F4F4EEF7F8DEECF4E5DCDE
D1C8CF837F6ED1BDBDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFF3E8E954483EE2DCDFEEE8DCEEFFF7F3EDE5F3EDE1F7F4E8\
F3F4F4FFFFFFF7F7F8F3F4F4F1F4F3F2F6F4ECECE8E4E0E1EEEFF0FFFFFFFFFFFF
EEF7F8E6F4F4ECF4F3E4F7F7ECF7F7EBF4F4EBF4F4EEF7F8EEF4F4FFF4F4FFF4F4E4E6EDD9EDED\
E5ECF8ECF7FFF2EEF0F7EEF0EBF7F4B0C1CBE2DCE5EBE4E2F1E8E8F3EBEEF7EFF0
F7F4F4FFF7F8FFFFFFFFFFF3FFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFF2E9FFF6F0FFF6F0FFF2E9FFF2E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFF2E9FFFFFFFFF6F0FFF6F0FFF6F0FFFFFFFFFFFF\
FFFFFFFFF7F8F7F4E8F7F7EFFFFFF7F7F7ECF7F7F8F7F7F8F3F4F4F3F4F4F3F7F8
F7FFFFFFFFFFFFF6F8FFF2F4FFF6F8F7FFFFF7FFFFFFFFFFFFFFFFFFF6F8FFF6F8FFFFFFFFFFF8\
FFFFF8F3F4ECF3F4ECF7FFF8FFFFF8F7F7F8F3FFF4FFF7EFFFFFF8F5EFF0F5E6E7
FFF7F7F5F4F8F5F7FFF5FFFFF1F7F8FFF7F4FFF7F4F5FFFFFFFFFFFFF7F8FFF7F8F7F7F8FFFFFF\
F7FFFFFFF4F4F3F7F8F7F7F8F7F7F8F7FFFFF7FFFFF7F6F8F7F6F8F7FFFFF7FFFF
FFFFF8FFFFF8FFF2F8FFF6FFEEF6FFEEFFF8E6FFFFE6F6F8FFF6F8EEFFFFF7F7F7FFF7F7F7FFFF\
FFF4F4E4F4F4DEE6EDEBEDEDD9F7FFD9D4DBD6EBEFFFF4F4E6F4F4F5FFFFFFFFFF
E2EFF0DAE4E6EEEEF8DAE5E7D1E5EFFFFFFFF7F6FFFFFFF7F7F6F3FFFFF7F3F2F3F7F6FFEEEEF8\
F7F6FFF7F7F8F7F6FFF7F6F7F7F6F7F3F4F3F5FFFFEBF7F8EEF7F8F7F7F8D6D9DE
CBC2C17C725BDECDDBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFD9CADB4B4533EBEEF8EBEDE1E3F7FFEAE8E1F3F4EDFFFFFF\
E6FFF3F3F4EDF7F7F8F7FFFFE3EFEFECEEEFEAF3F7EAF3F7F7ECEEEEF7F8EEF7F8
EEF7F8FFFFFFD2EDEDD1EFEFE4F4F3EEF7F8EEF7F8EEF7F8F5F7F8DEE8E9EEEFF0EAF3F8ECDCDE\
EEEEE7E5ECF8F2EEF0EEF7FFE6EBF8BEC1D6E2EDEEDFD4D6F1EDEDF7EEEFF7EEF0
F7F7F8F7F4F4FFFFF7FFFFF7FFFFFFFFFFFFFFF4F4FFF7EFFFF7F4FFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF2E9FFF2E9FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4\
FFF4F4FFFFFFFFF7ECFFFFF3FFFFF7FFFFF7FFFFFFF3F4F4F7FFFFF7FFFFFFF7F8
FFF7F8FFF6F8FFF6F8FFFFFFFFFFFFF7FFFFF7FFFFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F3F7F7FFF7EFFFFFF8F7F7F7F3FFFFF7F4F7F7F7F3FFFFFFFFF4F3FFF7F7F5F7F7
F5EFF7FFF7F8F1FFF8FFF4F4FFF4F4F1FFF8F1FFF8FFFFFFFFFFFFFFF4F4FFF7F8F7F7F8F7F4F4\
F7F4F4F7FFFFF3FFFFF7F7F8F7F7F8F7FFFFFFFFFFF7FFF8FFFFF8F7FFFFF7FFFF
FFFFF8FFFFF8FFF6F8FFF6FFEEFFF8FFFFFFFFFFFFFFFFF8E6FFF8EEFFFFF7F4F3F7F7F8FFF4F4\
ECEFF0E3F7F8D1D0DBD0ECF4D1E5F0E5DCDBE4F2FFFFF7F8EEEDEED1E0E9D1E0E9
FFFFFFD2DBDDC4D9DBD9ECEFF3F2F7F3F2F3F3F2F3F7F6FFFFFFF3F7F6F3F7F6F7FFFFFFF7F7F8\
EBEBF8EBEBF8EBEBF8F7F7F3F7F7F3F3F4F3F1FFFFFFFFFFE6F4F4ECECF4D9D9D6
8A9288846F6EEBE4EEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8D1BDD155482EEAEDE8F2EFE5F5F7EDE2F4F8EEFFF7F7F7EF\
E6FFF3EBF7F4F7F7F8EBF4F4F3F7F8EAEDECF5FFF8F5FFF8F3EBEEFFF7F8FFFFFF
EEF7F8FFFFFFE5F7F8D2EDEDECF7F7FFFFFFEEF7F8EEF7F8E3F7F8EBF7F8EEEFF0E3F4F4F1ECF8\
EBE7E2EAF4F4EAE4EEEEECF4E6ECF8BEC8DCEAF4F4DFD4DBECEFE8F5EDECF3F2F4
FFF7F8F3EFF0FFF7EFFFFFF7FFFFFFFFFFFFFFF7F8FFF7F4FFFFF7FFF7F8FFFFFFFFF7F8FFFFFF\
FFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF2E9FFF2E9FFF6F0FFF2E9FFF6F0FFFFFFFFFFFFFFF4F4FFFFFF\
FFFFFFFFF7F8FFFFF7F7F4F4F7F7F4FFE5F8FFE5F8F7F7F8FFF7F8FFFFFFF7F7F8
FFEEF8FFFFF8FFF6F8F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F3F4F3F3F4F3F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFF3FFF7FFF4F7F7F7F7FFFFFFFFF4F3FFFFFFFFF4F3F5FFFF
FFF4F8F5FFFFF5FFF8F1F7F8F5F7F8F5FFFFF5FFFFFFF7F8FFF4F4FFFFFFF7F7F8F7F7F8FFF7F8\
F3F4F4F3FFFFF3FFFFFFFFFFFFFFFFFFFFF8F3FFF8F7FFF8F7F6FFFFF2F4FFF2F4
FFF6FFFFF6FFFFF2F4EEF6F8EEFFFFE6FFFFE6FFFFE6FFFFF7F7F7F7F4F3F7F7EFF7F4F8ECFFFF\
E3F4F4E3EEF8CED4DCE2EFF8EBE5E7EEF7F8EAEEEDEAF2F8ECF6FFECF3F8DAE4EE
E3EFF0EAF4F7F7F7F3F7F7F3FFFFF7ECF7FFECF7F7FFFFFFF7F6F7F7F6FFFFFFFFFFFFFFF7F7F8\
EBECF4F7F6FFE3E4EFFFFFFFF7F7F7F3F4F3F1FFFFFFF7F7E6EDEDE4E6F4B3B6AF
6D635DCEB6C1F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFF7F8FFFFFFFFF7F8C2A7BD675333DEF7F7F7F3EDEAEEEDE3F7FFF7F7F4EBF7F8\
EEFFFFE6FFF7E6FFF3F3F4EDFFFFFFEAEDEDF1F4F3F5F7F7F2F2F4ECF7F8FFF7F8
EEF7F8EEF7F8E6F4F4EEF7F8E5F4F4ECF7F7E6F4F4EEF7F8EEF7F8EBF7F8E5F7F8D2DCDEF7F4ED\
DAEEF8E5F4ECEAE4EEE3E4EED9EFF4BDD4DCF5F7F8E2DCE5EEE5E7EAE5DEF3EBED
FFF7F8F7F7F8F7F4F4FFFFF7FFFFF7FFFFFFFFFFFFFFF7F8FFF7F8FFF4F4FFF7F8FFF7F8FFFFFF\
FFFFFFFFF6F0FFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFFFFFFFF6F0FFFFFF
FFF6F0FFF6F0FFFFFFFFFFFFFFF6F0FFF6F0FFF6F0FFF2E9FFF6F0FFFFFFFFFFFFFFF7F8FFF4F4\
FFF4F4FFF7F8FFF7F4F7F4EDF7F7EFF7E4EDF3ECF8F3F4F4FFE5F8FFECF8F7F7F8
F7F6FFF7FFFFFFF6F4F7F7F7F7FFF7F7F4F7FFFFFFFFFFFFF7F7F7F3F4F3F7F7F7F3F4F3F7F7F7\
F7FFFFF3F7F7FFF7F7F3F4F7F7FFF7FFFFFFFFF7F7FFFFFFFFF4F3FFEFEFF5F4F4
FFF7FFFFF7F8F1F7F4F1FFFFF5FFFFF5FFF8F5FFF8FFF4F4FFFFFFFFF4F4F7F4F4FFF7F8F7F4F4\
F7F7F8FFFFFFFFFFFFF7FFFFFFFFFFFFFFF8F7FFF8F3F6FFF7FFF8FFF2F8FFF2FF
FFFFF8FFFFF8FFF2F8EEF6F4EEF6F8EEF6FFFFFFFFF7F7F7FFF7F7F7F7F8EAF4F8E4EFF8EAF4F4\
EBE5E7EAEEF4D2E8E8EADBE9FFFFF3E6F7F4EAEEEDEAF6F8E4F2FFFFF7F8D6E8EE
EAF4FFF7F7FFF7F7FFF7F7FFF7F7FFF5FFFFECF7F3F7F6F7EEEEEFF7F7F8FFFFFFECF7F8F5FFFF\
EBECF4EBEBF8F3F3F7F7F7F7F7F6FFE5ECF3F7F7F7D6E5EFC6D5DCDEDCDF969B91
896B6BF7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFB898A86F6D57F7F7F4D9ECEDE4ECEFE3F4EFFFFFF7F7F7F8\
EBF4F4F7F4EDEBF7ECF3F4EDF7FFFFEEF7F8F7F7F8F5F7F7FFEEEFF2F3F4F7F7F8
EEF7F8EEF7F8E6F4F4FFF7F8CBE1E1D6EDECEEF7F8E6F4F4E6F4F4F7F7F8EBEDEED6D9DBE5EEEC\
E5ECEDCBEDEFFFE6E9D2EDF8DAF7FFBDDBE1EBF7F8EAF4F8F3E4E5E4E0DEF7EEEF
F7E5E7FFF7F8F3F4F4FFFFF7FFFFFFFFFFF7FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFF2E9FFF6F0FFF6F0FFFFFFFFF6F0FFF6F0FFF6F0FFF6F0FFFFFF
FFF6F0FFF6F0FFF6F0FFF6F0FFFFFFFFF6F0FFFFFFFFF2E9FFF6F0FFFFFFFFFFFFFFF7F8FFF7F8\
FFFFFFFFF4F4FFFFF3FFFFF7F7F7F8FFFFF7F3ECF8F3ECF8FFE5F8F7F7EEFFF2F4
F7F6F8F7F6FFFFF6F4FFFFFFF7F7FFF7F4F7F7FFFFFFFFFFF7F7F7F7F7F7F7F7F7FFFFFFF3F7F3\
F7F4F7F7F7F7F3F7F7FFF7F7FFFFFFFFF7F8FFEFEFFFEFEFFFF4F8F5F7F4FFFFFF
F5FFF4F1F4FFF5F4F8F5EEF4FFEEF8F5F7F4F5F7F4FFF7F8FFF4F4FFFFFFF7F7F8FFFFFFF7FFFF\
F7FFFFF7FFFFF7FFF8F7FFF8FFFFFFFFFFFFFFFFF8FFF6F8FFF6F8FFF6FFFFF2F8
F7EEF7F7EEF4EEF2FFEEFFF8FFFFF4EEF6FFEEFFFFF3F4F3F3F7F8ECF7F8FFFFFFF5F4F4DAEEF8\
F2FFF7DEEEF4D6E8E8F3DBE2EEF7EFE3F7FFEAF2F8ECF3F8E3ECF8EBEDF0D6E5F0
FFFFF7F7F6F3F7F6F3F7F7F7FFFFFFF7F7F7F7F6F7E3EEF8F5FFFFEEEEEFF3F3F4F2F7F8E2ECF4\
F7F6F7F7F6F7F7F6FFFFFFF7F3F3F3EBEEF7EAF4F3EBECF4C2D1DBD1D4D67F887B
A0838DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8EEE4F4CAB5B462675CF7F7F8F7F7F8E2E0DCDAECEDEEFFF7EBF4F4\
F7FFFFF3FFFFF3F4EDF3F4EDF7FFFFF7FFFFF3F4F4F5F7F7FFFFFFF2E4E5EEF7F4
F7FFF8E6F4F4E6F4F4FFF7F8D6E8E8D6EDEDEEF7F8FFFFFFEEEFF0F7FFFFF7F7F8ECEEEFD6EEF4\
EBF7ECDEFFF8EAE0E9EEF4F8FFFFFFC5DBE1EAF4F4E3FFF8EBE8EDEAE0D4F5F7F8
F3E6E8FFF4F4F3F7F8FFF7EFFFFFFFFFFFFFFFF7EFFFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFF6F0FFFFFFFFFFFFFFF6F0FFFFFFFFFFFFFFFFFFFFF6F0FFF6F0
FFF6F0FFF6F0FFF6F0FFFFFFFFF2E9FFFFFFFFFFFFFFF2E9FFFFFFFFF6F0FFF7F8FFFFFFFFF7F8\
FFFFFFFFF4F4FFFFF7FFFFF7F7F7ECF7F7F8F7E4F4F3F3F4FFEDEEF3F3F4F7F2F4
FFF6F8FFF6F8FFF6F8FFFFFFF7FFFFF7F7F7F7FFFFFFFFFFFFFFFFF3F4F3F3F4F3F7F7F7F7FFF7\
F7FFF7F7F7F7FFFFFFF7F7F7FFF7F8FFF7F7FFF7F4F5FFF8F5F7FFF1F7FFF1F7F8
F5FFF8FFF7F4FFFFF8F5E5EEFFEEF8FFF4F4FFF4F4FFF7F8F7ECF4F3F3F8F7FFFFF7FFF8F3FFF8\
FFFFFFF7FFFFFFFFF8FFF6F8FFF6FFFFF6F8FFF6FFFFFFF8FFF6F8FFFFF8FFF6F4
F7F7F4F7F7F7EEF6F8FFFFF8EEFFF8EBF3F7F3F4F3FFF7F7F7F4F4E4FFFFECF7F8E3F7F8EAEEF8\
F5FFF7E2EEECC9D1D5E5E5F0EEF4EDEAF6F8F7EEF0FFFFFFEBF4F8E3EFF0ECF7FF
FFFFF3F7F6F7F7F6F3F3F3FFF3F3F3FFFFFFF3F2F7ECF7F8ECF7F8F7F6F7EBECEDEEEEEFE5E5EC\
F3F3FFF7F6F7EBEBF7F3F4F7FFFFF7F3F4F3F7F7F7EAF4F3DEEDEECBCDD075786D
B898A2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFFFFFFFF7F8EEE5F8CEC6CB625546F3F4EDF3F4EDDEE0E1E4E6E8EEFFF7F7F4ED\
F3FFFFFFF7F8F7F7F4F3F4EDFFFFFFF7F7F8EEEFF0E4E7E8ECEEEFF2F3F4EEECF4
F7FFF8EEF7F8FFFFFFEEF7F8EEF7F8EEF7F8EEF7F8EEEFF0FFF7F8F3F4F4F2ECF4EAF3F8DEE0E8\
F7F7F4F7FFFFD8E0EEF7F7F8EEF7FFC2E0E8F7EEF0EAF7F8EEE8EFE3EBE2F1EDF0
F3ECE5FFEEF0F7F7F8F7F4F4FFFFF3FFFFF7FFFFF7FFFFFFFFFFFFFFF4F4FFF7F8FFF4F4FFF7F8\
FFFFFFFFFFFFFFFFFFFFF2E9FFF2E9FFF6F0FFF6F0FFF6F0FFF6F0FFF6F0FFFFFF
FFFFFFFFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFF2E9FFFFFFFFF6F0FFF6F0FFF7F8FFF7F8FFFFFF\
FFF7F8FFF7F8FFFFF7FFFFF3FFFFF7F7F7F8FFEFF0F7F7F8F7FFFFF3FFFFF7F6F8
FFF6F8FFF2F4FFFFFFFFFFFFF7FFFFFFF7F7FFFFFFFFFFFFFFFFFFF7F7F7F7FFFFFFF7F7F7F7F7\
FFF7F7F7F4F3FFFFFFF7F7F7FFF7F8FFF4F4FFEDEFF1F4F8F1F4F8F5F7FFFFF7F8
F5F7F8F5ECF4F5E5F0F5F7F8F5FFFFFFF4F4FFF7F8FFFFFFF7ECF4F7F3F8F7FFFFF7F6F8FFF2F8\
F3F6FFF3FFFFFFF6F8FFF6F4FFF2F4FFF2F8FFF2F4FFFFFFFFF6FFFFFFF8FFF6F8
FFF6F8EEF6F8EEF6FFEEF6FFFFF6FFF3ECF3F7F7F7F7F7F7ECF4F4ECF7F8F7F7F8F7FFFFECEEF8\
F2EEECE3E5F0B0D1E2EEF7F8ECE5E7ECECF4F7F7FFEBF4F8E3EFF0F2F7FFF7F7FF
F7F7EDF3F4EDF7F7FFF7F6F7F7F6F3FFFFFFF3F2F7F7F6F7F7F6F7F7F7F8F7F6F7E5E5EFF7F6F7\
EEEEF7F7F6FFF3F3F3F3F4F7F7F7FFFFFFF7F7F7F7D9E6E7EEEDEECBD4D68E8A84
9C7E84FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFF7EDEED1C8D6624834F7F7F8EBF7F4E4E6E8E4EBEFEBF4F4EAEDE8\
EEEEF0F7E5E8F3F4F4EEFFF7F3F7EFEBF4EDF7F7EFD1D4D6EAEBEDF5F7F7F3E6E9
EEF7F8EEF7F8E6F4F4E6F4F4F7FFFFF7F7F8FFF7F8FFF7F8FFF7F8F7F7F8EAF3F8EAF3F8ECE6E8\
DEF7F3F7E4E8E4EEF8F3F6FFDEE7F4CEE4ECEBF6F8F1F4F4EEE8EFEBF2E5ECE8EE
ECF7F4F7EEEFF7EEF0F7EDEEFFFFF7FFFFF7FFFFFFFFFFFFFFFFF7FFF7EFFFF7F8FFF7F8FFEEE8\
FFF6F0FFFFFFFFF6F0FFFFFFFFFFFFFFF2E9FFFFFFFFFFFFFFF6F0FFF6F0FFF6F0
FFF2E9FFF6F0FFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFFFFFFFF7F4FFFFFFFFFFF7F7F7F8FFEFF0FFFFFFF7F7F8F7F6F8F7F6F8FFF2F4
FFF2F4FFF2F4FFF6F8FFF6F8F7FFFFF7FFFFF3F4F3F7F7F7F7F7F7F3F7F3F3F4F7F3F7F7F7F7F7\
F3F7F7FFF7F7F7F7F7F7FFF7F7FFF7FFF7F7FFEDEFF5F7F8F5F7F8F5F7FFF5F7F8
F5F7F8F5ECF4F5EEF8FFFFFFF5FFFFFFECF4FFF6FFFFF7F8FFF4F4F3F7F8F7F6F8F7FFF8F7F2FF\
FFFFF8F7F6F4FFF6FFFFF6F8FFF2F8FFF2F8FFF2F8FFF6F4FFF2F4FFF6F8FFF6FF
FFFFF8EEF6F8FFFFFFEEFFFFE6FFFFF7F7F7FFFFFFF7EFEFE4F7F8F7F4F4EEF7F8F7F7F8D6E6F4\
E3F7ECCDE7F4D2E4F0F7EDE1E4EBF8FFF4F4F7F7FFE5F4EEFFFFFFF5FFFFF7F7F0
ECF7FFF5FFF0F3F4FFF7F7FFF3F4F0F7F7E7F7F6F3FFFFFFF7F6F7EBECF4E3E4EFF7F7FFE6E6F3\
F7F6F7FFFFF7F7F6F3FFFFF3F7F7F3F3F4F7DAEFEFF5F7F8EBECEED1E0E18E8A8B
9C7E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFF3E8E9D1C1C85B5445F3E4DEE3E4E6E4E6E8E4F2FFF5F7EDF2F4F4\
E5E5E8EEEEF0FFFFFFF7F7EFF3F7EFF3F7EFF7F4EDD6E0E2ECEEEFF5F7F7EAE4E5
E6EDEEEEF7F8EEF7F8E6F4F4F7F7F8F7F7F8FFF4F4FFFFFFFFF4F4FFFFFFECF6FFEAF2F8F7F6F8\
E2F4F7E5E5F0EAE5E7DFF3FFEBECF4CEE4ECF3F6F8EAF4F4EBEDF8F7EBE1EAE8E9
F5F7F7F3F7F7F7EBEEF7F4F4FFF7F8FFFFF3FFFFF7FFFFF7FFFFF7FFFFF7FFFFFFFFF7F8FFEEE8\
FFF6F0FFF6F0FFFFFFFFF6F0FFF2E9FFFFFFFFF2E9FFF2E9FFF6F0FFF6F0FFF6F0
FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFF2E9FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFFFFF\
FFFFFFFFF7F4FFFFF7F7F7ECF7EFF0F3EEFFF3EEFFF7FFFFFFECF8F7F7EEFFFFFF
FFFFFFFFF6F8FFF6F8FFF6F8FFFFFFF7F7EFFFFFF8F7F7F7F7F7F7FFF4F7F7F4F7F7FFFFF3F4F3\
F3F4F3F7F7EFFFFFF8F7FFF7F7FFF7FFF7F7F5F4FFF5F7F4F5FFF8F5F4F4F5F4F8
FFF7F4F5F4F4F5F7F8F5FFFFFFFFFFFFECF4FFF6FFF7F6FFF3F2FFFFF6FFF7F2F8FFF6FFF7F6F8\
F7F2F4FFF2F8FFF6F8FFFFF8FFF6FFFFF2FFFFF6F8FFFFF8FFF6F8FFFFFFEEF6FF
EEF6F8FFFFF8E6FFFFE6FFF8E6FFF8F7F7F7FFF7F7F7F7F8E4F4F4F3F7F8E3ECEDEBE0E1E2EEEC\
F2EDEDD0DDE7E3DCDBF7EFE7E4F2FFFFF7F8FFF7F8E3F7F8EEF7F8F5FFFFFFFFF0
F5FFF0F5FFFFE2F4F8D1EDF4E3F7F8F7F7F0EAF4FFDEECEDDEE6E5EEEEF7F7F7FFF3F4FFF3F3F3\
FFFFF7FFFFFFF7F6F7F7F7F7ECF7F7F1FFFFEEF7F8EBF7F8DFE0E3BCD4DC7F7064
B59C9DF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF
FFF4F4FFF4F4FFFFFFFFFFFFF7EDEECEBDC35E6152EBF4F8DFE4E6ECECE8FFF7F8ECE5E7FFF7EF\
EBEDEEF3F7F8F7FFFFFFFFFFF7FFFFF7FFFFF3F7F8EEF7F8FFFFFFEEFFF7D6E6ED
EEEDEEEEF7F8FFFFFFE6F4F4FFF4F4ECFFFFECF7F8FFF7F8FFF7F8FFF7F8ECF6FFF3ECE5DEEDEC\
E5EFEFEBF7EFE4DBE2E3EDEFF3ECF7CBDCEFEBEBEDE3F3F4E3E5E8EEE5E7E2DCDE
F5EFEFF7F7F7F7EEEEF3EEF8FFF4F4FFFFF7FFFFF7FFFFF3FFFFFFFFFFF7FFFFF7FFFFFFFFF4F4\
FFFFFFFFF6F0FFF6F0FFFFFFFFF2E9FFF6F0FFF6F0FFF2E9FFF2E9FFF6F0FFF6F0
FFFFFFFFF2E9FFF6F0FFF6F0FFF6F0FFF2E9FFF6F0FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8\
FFF7F8F7F7EFF7F4E8F7F7EFF3F7F8FFEEFFF7EEFFF7FFFFF7F4F4FFF3F4FFFFFF
FFF6F8FFFFFFF7F7F7F3F4ECF3EDE8F7F4F7F7F7F7F7EFEDF7EFEDF7F4E8FFF4ECFFF7F7FFFFF8\
FFFFF8F7FFF4F7FFF4FFFFFFFFF7FFFFF7FFF5F7F7FFF7EDF5FFFFFFF4F4F1F4F8
F1F7F4FFF4F4F5F7F8F5FFFFFFFFFFFFF4F4FFFFFFF7F6FFF7F6FFF3F6FFF3FFFFFFF6F8FFF2F8\
FFF2F8FFF6F8FFF6F8FFF2F4FFFFF8EEF2F8EEFFF8FFF2F8EEF2F8EEFFFFEEF6FF
EEF6FFFFFFFFE6FFFFEBF7F4EBF4ECF7EFEFFFF4EEEAE4E3E3DCDEE3E6EDF2EEECECEFF0CDE8EE\
D9DDE8DEECF4EBEDE5FFFFFFDEEBFFF7F7F4FFFFFFFFFFFFDEF4F4F1FFF0F5FFFF
E3F7F8D8F4F4F5FFF0DEF4F4FFFFFFE2F7EEFFFFF0F1FFF0F5FFF0F7F7FFF7F7FFFFFFFFF7F7F7\
D6E7ECD6E7F4F3F4FFFFFFF7DEE4ECD1E0ECEBEEF7E2F7F8B5BAC662645B87655B
D9CCD6F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFF7EDEEDED4E1625A45ECDDE8EBFFFFF2EDE5F2E6EEF5ECF4ECECE8\
EEEFF0EEF4F4F7F7F8F7F7F8F3FFFFF7F7F8EBEDEEF7F7F8EAECEDDAEEF8E5EEEC
EAE4E5DFF4F4FFFFFFE6F4F4FFF7F8EAF3F4EAF6F8ECF7F8ECF7F8FFF7F8FFF7F8E2E4E5E2F4F4\
F7F4F4EEECF4EAE5F0D9E8EDEAE4F4D6E4F8F7EEEFEBF3F4EAEBEEEAEDF0EBE0DD
ECEFE8F5EFEFF3F3EDF7F3F8F3EFF0F7F7F8FFFFFFFFFFF7FFFFF3FFFFF7FFFFF3FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFF6F0FFF6F0FFF2E9FFF6F0FFF6F0FFF6F0FFFFFFFFF6F0
FFF6F0FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF4F4FFF7EFFFFFF7\
FFFFF7F7F7F8F7F4EDF7F7F8F7F7F8F3F7F8F7F7F8F7F7F8F7FFFFF3FFFFF7F2F4
FFFFFFF7F7F7F7F7F7FFFFF4FFF7F8FFF7FFFFFFFFFFF7F4FFF7F4FFFFF4FFFFF8F7F7F7F7F4EF\
F7F4EFFFF7FFF7FFF7FFFFFFFFF4FFFFF4FFF5F7FFFFF7F8F5FFF8F5F7F4FFF7F4
FFFFFFF5FFFFF5F7F8F5F7F8FFFFFFFFF7F8F7F3F8F3F2F8FFFFF8FFF2FFFFFFFFF7FFFFFFF6FF\
FFF6FFFFF2FFFFF2F8EEFFF8EEF6F8EEF2F8EEF6FFFFFFF8EEF6F8EEFFFFEEF6FF
EEF6FFEEFFFFF7F7F7FFF7F7F7FFFFECF4F4DEFFF8E3ECF0F3EBEDE4EEF4F2EFE5DADDE8E2EEEE\
F2E0E2EAF4ECEBEDE5F5EEF8E5F6F8F7F7F4FFFFFFEEF7F8FFFFFFEBF4F8ECF7E9
E5F4EEF7F7F4EEEFFFDEF4EED9EDF8CEE4E8DEE6E5EBECF7F7F7FFF7F7FFF3F4FFF7F7FFF7F7FF\
D2E0EDCADBE8EBECF3EEEEF7EBECF4E3E4EDD1E5EFF5FFFF88919577695DE2D1DB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFFFFFFFFFFFF3E8E9DED4E15C4E40EEF4F4EBF4EDF2F7F4F5E5E7F3F3F4E4E6E8\
EEFFF7EEF4EDF7ECEEEBECEEF7FFFFF7F4F4EBEDEEF7F7F8DEE0E1EAECECFFFFFF
F1E4E5D9E4E6FFFFFFEEF7F8EEF7F8EAE6EEECF6FFF5F6F8ECF7F8FFF4F4FFF7F8F3F2F4D8F4F7\
FFF4EDF7ECF4EADBE9C7D5E8D9F4F8D6F4F0ECEFF0EBECECEEFFFFE2E4EEEBE0E8
F3F7EEF5EDEEEAE6E8FFF7F8F7F7F8F7F4F4FFFFFFFFFFFFFFFFF7FFFFF3FFFFF7FFFFFFFFFFFF\
FFF4F4FFFFFFFFFFFFFFF6F0FFF2E9FFFFFFFFFFFFFFF2E9FFF2E9FFFFFFFFF6F0
FFF2E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFF7FFFFF7\
FFFFF3F7F7F4F3F4EDFFE5F8F7F6F8F3F7F8F7F6F8F7F6F8F7FFFFF3F6F8F7F6F8
FFFFFFF3F4ECFFFFF4FFFFFFFFFFF8FFFFF8FFFFF8F7F7F7F7F7F4FFFFF8FFFFFFF7F7F7F7EDF7\
F7EDF7F7F7F7FFFFFFFFFFFFFFF7FFFFFFFFF1F4F8F1F7F8F5FFF8FFF7F8FFF7F4
F5FFF8F1FFF8F5F7F8F1F7F8F5FFFFFFEEF8F7F7F8F3F6F8F7F2F8F7FFFFFFF6FFF7F6FFFFFFFF\
FFF6FFFFF6F8FFF6F8EEFFF8EEFFF8FFFFF8FFFFF8FFFFF8EEF6F8EEFFFFEBF7F7
EBF3F7EBF3F7FFFFFFF7F7F7FFF7F8EAEFF0F7ECEEF7E4E5E3E6EDDADDE7E3DDDEE3FFF8ECF7F7\
F7E5E7EEF7F8EEF7F8EAEBF8F7FFFFFFF7F8EEF7F8EEF7EEEEF7EEE2F4EEF2FFEE
F7FFEEEBEDE9E6EDF8D6EDEEF7F6F7F7F6F7EEEEF7EBECF7F7F6F7E6E6F3DFE0ECE6E6ECF3F2F3\
F3F3F4FFFFFFEBEBF4EBEBF4EEEEF7C8DDE7F5FFFFFFF7F859686C947577F7EFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8
FFF7F8FFF7F8FFF7F8FFF7F8F7EFF0D6C6D3625A45E5E5F0EBEDE5F5F4ECF1F4F3F2F6F4DAECED\
F7F7F8F3F7EFEBE6E9DFE0E3F3F4EDF7EDE5F7F7F8F7F7F8EAEDEDF5FFF8FFF7EF
F5F7F7D2D4D7FFFFFFFFFFFFE6EDEEECF6FFEAEBF0FFFFFFF3F2F4EAF6F8ECFFFFF7F6F8D9EEF4\
EBEDE1F3ECF4F7E5EDD8CDD6F7F7F7F7E5E6D9DCE6ECE5E7EBF3F4EAEBEEE2DCE7
EBEEE5FFEDEEE4E0E1FFF7F8F7F7F8F7F4F4F7F7F8F7F7F8FFFFF3FFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFF6F0FFFFFFFFFFFFFFF6F0FFF6F0FFFFFFFFF2E9
FFF6F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFFFFFFFFFF7FFFFF7F7F7EF\
F7F7F4F7F7F8F3F7F8FFECF8F3ECF8F7F4F4F7F6F8F7EEF0F7F7F8F7F2F4FFFFFF
FFFFFFF3F4ECF7F7EDF7F7F4FFFFF8F7F7F4F7F7F7F3F7F3F3F7ECFFFFF8FFFFFFF7F7F7F7EFF4\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF5F7F4F5F7F4F5F7F8FFF7F4FFF7F8
F1FFF8FFFFF8FFFFFFF1FFFFF5FFFFFFECF4FFEEF8FFEEF8FFF6FFF7FFFFF7FFFFFFF6FFFFF6FF\
FFF6FFFFFFF8FFFFF8FFFFF8FFFFF4EEFFF4EEF6F8FFF6FFEEF6FFEEFFFFF7F7F7
F7F3F7F3ECF3F3F4F3FFF4F3ECF4F4F2F4F4EBF6F8E3ECEFF7FFFFDEE0DEEAF7FFFFFFFFEAE4ED\
FFFFF7DEF4F8EAEEF4ECECF4FFF7F8F7FFF8EBF4EEF5FFFFF5FFFFF1FFFFE3F7F8
D9EFEFE4F4F3ECF7E7E5F4F8D1E5EFF3F2F3F3F3F7EBECF7EEEEF7FFFFFFF7F7F8F7F7F8ECF7F8\
ECF7F8F3F4F4E6E6EDEBEBF4D6E0ECEBF7F8EEF7F8D6E0E96966629D8685FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFDECDDB615A3EECE5F0DADCE1EBF7F3F5F4ECF7F6F8DAECED\
EBF7F4F3F4F4E3E5E8E6ECEEF7F7EFEEEDE8FFF7F8F3F4F4F7F7F8F2EDE5F1F7F4
F5F7F7D6D9DBEBEFF0F5FFFFE6EDEEF7F6F8F7F3F4EAF2F8F5FFF8F1F3F4EAEBEDEAF2F8FFFFFF\
E3E5E7DFD9DEF3DBE2D8CDD6FFEFEFF3E6E9E5E5F0DADDE8DEEDECF3F2F4E4E8F4
EBE6E1F7F4EEE4DBDCFFFFFFFFF4F4F3F7F8F7FFFFF7F7F8FFF7F4FFF7ECFFFFF7FFFFFFFFFFFF\
FFFFFFFFF7F8FFF4F4FFF4F4FFECE6FFECE6FFEEE8FFF6F0FFF6F0FFF6F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4FFFFFFFFFFFFFFFFFFFFFFF7FFFFFFF7F7F8\
F7F7ECFFFFF7F7F4F4FFF4F4F3F7F8F7F7F8F7F7F8FFFFFFFFFFFFF7EBEEFFFFFF
F7F7F7FFFFFFFFFFFFF7F7F7FFFFF8F7F7F4F7F7F7F7FFF4F7FFEDFFFFF4FFFFF8F7F7F7F7F7F4\
FFFFFFFFFFF8FFFFFFFFF7F8FFF4F4FFF4F8F5F7F4F5F7F4F5F7F4FFFFFFFFFFFF
F5F7F8F5F7F8F5FFFFFFFFFFFFF7F8FFF7F8FFF7F8F7EEF0F7F2F4F3F2F8F7F6FFF7F6FFFFF6FF\
FFF6F8FFFFF8FFF6FFFFF2F4FFF6F8EEF6EDFFFFEFEEF6FFEEF6FFEEF6FFEEF6FF
FFF6FFF7ECF3F7F7F7FFF7F7E4F4F4F3F4F4EEFFFFEAE6EDEEE5DFDAEFF8F2F7FFF7E5E7DAEFEC\
E6F4EDD9EEF4F7F3F4FFF4F4FFF7F8F7FFF8EBF7F4E3F7F8FFFFFFECF7FFF3F4F7
F7F7F7FFFFF7EAF4F7E2F7F8F7F7FFD9EDF8F3F3F7E3EEEFEAF4F4F3F3F8F7F6FFF7F7F8F5FFFF\
F5FFFFFFFFFFEBEBF8F7F6FFE5ECF3F5FFFFEEEFF0C5DCE872665CA08B8BF7F7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFDECDDB706751E4E0E2E5E4E8E3F7FFF1F7F4EAF2F8D6E6ED\
E6FFF3EEFFF7EBF4F4F7EEF8E5E5F0F3F7F8F7F7F8F3F7F8F7F7F8F2F4F4F5F7F7
F1F4F3ECECE8D0E4EEEBF7F8EBF7F8DAE4E6F5FFF8FFFFFFF2F6F4F1F4F3F5F7F7F7ECE8ECF3F8\
E4F2FFDFDCDEF7EEF4E3ECF4DEEEF8EAEEF0F5EEEDD9DBE2DEEDEDEEEEEFDEE0EE
F3ECE8F3EEEEE4D4D6FFFFFFFFF7F8F7F7F8F7F4F4FFFFFFFFF7F8FFF7F8FFFFF3FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8FFF4F4FFF7F8FFF4F4FFFFFFFFFFFFFFFFFFFFF7F8
FFF4F4FFF4F4FFF4F4FFF7F8FFFFFFFFFFFFFFF4EDFFFFF7FFFFFFFFFFF7FFFFF7FFFFF7FFFFF7\
FFFFF7F7F7EFFFF7F8FFF7F8F3F7F8FFF7F8F7FFFFF7F7F8FFF7F8F7EBEEF7F7F7
F7F7F7F3F4F3F3F4F3FFFFF8FFF7F8FFF7F8FFFFF4FFFFF8FFF7F8FFF7F4FFFFF8FFFFF8FFF7F4\
FFF7FFFFF7FFFFF7F4FFF4FFFFF7F4FFF4F8F5F4F8F5F7FFF5FFF8FFFFFFFFFFFF
FFF7F8F5F7F8F5FFF8F5F7F4F7EEF8F7F2FFFFF2F8F7F6F8FFFFFFFFF6F4FFF6FFF7F6F8FFF2F8\
FFF6F4FFF2F8FFF6F4FFFFF8FFF6F8FFFFEDEEFFEFEEF6FFEEF6FFEEF6FFE6F6FF
EBF3F7EBEEF7FFF7F8F5EDEEEAEDEEEBE5E7EAE0E1D9DCE5E3E4E9EAF2EEEAE0E2ECF7F7E6F7F4\
FFF7EFECF6FFECF3F8EEEDEEE6EDEEE6F4F4E6F4F4EEF7F8F5FFFFECF7FFF3F4F7
F3F4F3F3F4F7FFFFFFF7F7FFE2F4F8E2F4F8E6E6F3ECF7F8E2ECEDF5FFF7DEECF4F5FFFFFFFFFF\
F7F7F8F3F4F4F7F6FFF7F6FFEAF4F3E3F7F8DAE4EED6ECED624E42C4AAABF7F7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFFFFFFFF
FFF7F8FFF7F8FFF7F8FFF7F8FFFFFFDECDDB817C70CEC1B9DFE4EEF5F4ECF5FFF8F3F2F4D9EBF4\
E2F4EFEBF7F4F7F7F8DFE0EEE6E6F4FFFFFFF7FFFFEEF7F8F7F7F8F7F7F8EAEDEC
F5F7F7F1F7F4EAEBF0E6EDEEF5FFFFEBEFF0DAE4EEFFF7F8F5F7F4EAE5E5FFF7EFEAE4E5F3F6F8\
F2EBF4E3F4EFE5F4F4ECFFF8F7ECF4F2E0E9F5EEEDD9DBE2E4E4E5F7F6F8D6D9E2
EBE7E8F3EEEEE4D4D6FFFFFFFFF7F8FFFFFFF3EDEEFFEFF0FFFFFFFFFFFFFFFFF7FFFFF7FFFFFF\
FFFFF7FFFFF7FFFFFFFFF4F4FFF7F8FFFFFFFFFFFFFFF4F4FFF7F8FFF7F8FFF7F8
FFFFFFFFFFFFFFFFFFFFF7F8FFF4EDFFF4E8FFF7F8FFFFF7FFFFFFFFFFF7FFFFF7FFFFF7F7F7EC\
F7F7F4F7F7F8F7ECF8F3ECF8F7EEFFFFEEFFFFF7F8F7FFFFF7F6F8F7F6F8F7F7F7
F7F7F4F7F7EFF7F7F7FFFFF4FFF7F4FFFFF4FFF4F8FFF7F8FFF7F4FFF7FFFFFFFFFFF7F8FFFFF4\
FFF7F8FFF7F4FFFFF8FFFFF8FFF7FFFFF7F8FFF4F8F5F7F4FFFFFFFFFFFFFFFFFF
FFFFFFF5FFFFF5F7F4F5EEF0F7FFFFF7F2FFF7F6F8F7F6F4F3F6F4F3F6FFF7F2F8F7FFF8FFF2F8\
FFF2F8FFF6F4FFF2F4EEF6F8EEF6FFEEFFFFEEFFFFEEFFFFE6FFFFE6FFFFF7F7F7
FFF7F7F7F7F8F5EFF0E3F7F8EBEEEFEBEEEFF5F7F8E2EDF4DEE5F0E3E6E7F7E4E5FFFFFFE6F7F4\
FFF7EFECEEF8ECEEF8E6F4F4FFFFFFFFFFFFECF7F7E4F4F3EAF7F7F5FFFFEEEEF7
EBECF7F3F4FFF7F7FFF7F7FFF7F7FFF7F7FFF3F3F3F3F2F7FFFFFFEAF3F4E4F4F4F5FFFFECF7F8\
F5FFFFF3F4F4F7F6F7EEEEF3EAF7F7E6EDEEE4E4E7E6EFE7391A15E2D4DEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFFFFFFFF7F8FFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFEEE5F0756762D1CEBDE3E0EEEBEDE5F5FFF8F7F6F8ECF6FF\
EAE8E1EAEDEDF5F7F7E3E4EEFFFFFFEBECF4F7F7F8F7F7F8F7F7F8F2F4F4F7F7F8
F5F7F7F5FFF8E4ECEFD1D5D7E6EDEEEEF7F8EBF7F8D0E5F0FFFFFFFFF7F8E4EBEFF3F3F4EADCDD\
F5ECEDF1F7F4D6EFECF5ECE8F7E4EEECF7FFE4F4F7D1DDE7D1CBD6E3EFF0DEECED
E3DDE7E3DDDEEADCDEF7EEEFFFF4F4FFF7F8F7F4F4F7F3F4FFE5F8FFFFFFFFFFFFFFFFF3FFFFF7\
FFFFF7FFFFF3FFFFF7FFF7EFFFF7F8FFF7F8FFF7EFFFFFF3FFF7EFFFF7F8FFFFF7
FFFFF3FFFFF3FFFFF7FFFFF7FFFFF7FFFFF7F7F7F8F7F7ECFFFFF7FFFFF7FFFFF3FFFFF7F7F7F8\
F7EEFFFFDBF4FFF7F8F3F3F4F3F6F8F3F6F8F3FFFFF3F6F8FFF6F8FFFFFFF7F7F7
F7EFEDFFF7F4FFFFF8FFF7F8FFF4F8FFF7F8FFF7F8FFF7F8FFF7F4FFF7FFFFFFFFFFF4F8FFF4F8\
FFF7FFFFF7F8F5F4FFF5F4F8FFF7F8FFFFF8F5F4F4FFF4EEFFF4F4FFF7F8FFFFFF
F5FFFFFFFFFFFFF7F8FFECF4FFF3F8FFF7F8F7EEF8F7F6FFF7F6FFFFF2F8F3F2FFF7FFF4FFF6F8\
FFFFFFFFFFFFFFF6FFEEF6F4EEFFFFE6FFFFE6F6FFEBF3F7F3F4F3F3F4F3FFF7F7
E3F7F8E4E5E8E2F3F4EEFFFFF7E6E8ECF7F8E2E4EED1D4E3C6D1E3F7E4E1EEFFFFE6F4F4EEF7F8\
ECF6FFECECF4EEF7F8EEF7F8FFFFFFF5FFFFF2F7F7F3F4F3FFFFF7F7F7FFEEEEF7
E2ECF7E4F4FFEAF4FFF3F4FFF7F7FFEEEEEFEEEEF8FFFFF7F3F2F3F7F6FFF3F3F8ECF7F8F7F7F8\
F2F7F8EBECF4F7F6F3D9EDF8CDEDEEC5DDE8D6EEF4A3A09B553B3DF7F7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF6F4F4BCDD9D0EAE4F0E3E5E1D8F4FFE2F4F7F7F3ED\
DEDBD6DEE1E1F5F7F7E5EFECEBE0E2D9DBE3F7F7F8EBECEEE3E4E6EAECECEAECEC
F5F7F7FFF7EFECEDE8E4E7E8E2E7E9F5FFFFE3F7F8EBF7F8DAE5F0FFF7F8E4F2FFD9E7E1EEFFFF\
EAEDECF1FFF4EBF7F4DADCE1F7ECF4FFF7F8FFFFF3E4F4F7EBECEDD9D3DED9E4E5
ECEEF0DAD9DBDAE4E6EAE4E5FFEEF0FFF7F8F7F7F8F7E4F4F7EEFFF7F7F8FFFFFFFFFFF7FFFFF7\
FFFFFFFFFFF7FFFFFFFFFFF7FFFFF7FFFFF3FFFFF7FFFFFFFFFFF3FFFFF7FFFFF7
F7F7F8F7F7F8FFFFF7FFFFF7FFFFF7FFFFF7F7F7ECF7F7F8FFFFF7FFFFF7FFFFFFF7F7F8F7F7F8\
F7E4F4F7EBF8F7F3F4F7F7F8F3FFFFF3FFFFF7F6F8F7F6F8FFFFFFF7F7EFF7EFED
FFFFFFFFFFFFFFF7F8FFF4FFFFF7FFFFF7FFFFF7FFFFF4FFFFFFF4FFF7F8FFF7F4FFEFF0FFEFF0\
FFFFF4F5FFF4FFF7F8F5F7F8FFF7F8FFF7FFF1EDF4F5FFFFF5EFF0F5F4F4F5F7F8
FFF4F4FFF4F4FFF7F8FFF7F8FFF7F8FFF4F4FFF4F4F7FFFFF3FFFFFFFFFFF7F6F8FFFFF4FFF6F8\
FFFFFFFFFFFFFFF6FFEEF6F4E6FFFFEEFFFFEBF3F7EEEEF7F3FFFFF3FFFFF7F7F8
ECF7F8EAECEEF7F6F8ECEEF8EAE5E5E3E5F0E5F7FFF7EBEEE4E4EDEEF7EFE3E5F0F5EEF8ECEEF8\
ECECF4EEEFF0E3F7F8EAF7F7E4F4F3F2F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F5FFFFF1FFFFF5FFFFF5FFFFECF7FFE3E4EFEBECEFF7F7FFEBEBF3EAF3F8F2F6FFEAF4F4ECF7F8\
F3F3F8E5E5EFEAF4F7C4E5EEF7EEF0E3F3FFD6D4CD785C49B3A6ACFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF
FFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFF6F4F4BDEE7DDE2E4EFF3E4DEE2F4EFE2F4F7F7F3ED\
DEDBD6E5E8E8F5F7F7E3F7FFDADCDBEBECEEEEF7F8D9DBDED9DBDEE4E6E8E4E6E8
FFFFFFF5F7F7FFFFFFF7F7F8C1C8CBDEEDEDEEF7F8EEF7F8EEF7F8DAE4EEEAF6F8E3F4ECF3F4F4\
EAEDEDF7F3EDF7F6F8EBEDE5EEF4F4FFF7EFF7F7F8E3FFEFE2EDE8E6E6F4DEE0E1
EEFFFFEAD5DEDFEBDEE3E6E7EAE4E5F7E4E5F7E4E6F7EDEEF7FFFFF7FFFFFFF7F8F7F7F8F7F7F8\
FFFFFFF7F7F8F7F7EFFFFFF7FFFFF7FFFFF7FFFFFFFFFFFFFFFFF3FFFFF7FFFFF3
F7F7ECF7F7F4FFFFF7FFFFF7FFFFF7F7F7ECF7F4EDFFF7F8F7F7F8F7F7F8F7F7F8FFFFFFF7EEFF\
F7EEFFFFEDEEF7FFFFF7FFFFFFFFFFF7FFFFFFF2F4F7F7EFF7F7EFF3F4E8FFF4FF
FFF7F8FFFFFFFFF7F4FFF7F8FFF7FFF5EDF8F5F4F8FFF4FFFFF7F8FFFFF8FFF7FFF5EFF8F1F7F8\
F5F4FFF5F4FFF5FFFFF5FFFFF1FFFFF5F7F8F5FFFFF5F4F4F5F7F8F5EDEEFFF7F8
FFFFFFFFF6F8FFEEF0FFEEF8FFF2F8FFEEF0F7F7F8F7FFFFF7FFFFFFFFFFF7F6FFF7F6FFF7F6FF\
FFF2F8FFF6F4FFF2F8EEF6F4EBF3F7F3F4F3FFEFEFF7F4F4FFF4F4FFF4F4ECF7F8
EAF7F8D6E5E7F3E6E8EAE5E5EEE5E7E5F7FFF7F7F8FFE6E9D6E4EDEEF4EDF1E6F4F2EEF8ECEEF8\
FFFFFFE6F4F4F1FFFFF3F4F3FFFFFFF7F7F7F3F4F3FFFFFFF7F7FFF7F7FFF7F7F7
FFFFFFFFFFFFFFFFFFF5FFFFF5FFFFFFFFFFF3F4FFF7F7FFF7F6F7DAE5EFECF7F8F7F6F7F3F3F4\
EEEEF8EBECF3E2EFF0DEE5E8FFF6FFE3F7FF9C988A836561EEE5F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF624846EBEDE2F2F4F7E2E0E9DEE8E8F5F7F7FFF7EF\
EAE8E1F7F7F8EAEDECFFFFFFDEE8E8F7FFFFE6F4F4DFE0E3EBECEED9DCDDF5F7F7
EAECECF1F4F3F5F7F7ECEFEFD9CFD1F5F7F7E3F7F8EEF7F8E6F4F4EEF4F4F3ECEEF1E5E5EBEFE5\
EBF7F4EAECECF5FFF8EAE6EDE2E4E5F3F4EDFFFFF7F7EFE5CEE5E5E5E4EED9DCE5
EBF7F7E4E1EEE6E4E1EAF4EEF5F4F4F3F4F3FFF6F8F7ECEEF3F7F8F7EFF0FFEFF0F7F7F8F7F4F4\
FFF7F8F7FFFFF7F7F8FFFFF7FFFFF3FFFFF7FFFFFFFFFFFFFFFFF7FFFFF3FFFFF7
FFFFF7FFFFFFFFFFF7FFFFF3FFFFF7F7F7EFF7ECF8F7E5F8FFE5F8F7E4F4F7F7F8FFF7F8F7ECEE\
F7E7F0FFEDEEF7F6F8F7F2F4F7F2F4FFF2F4FFF6F8F3F4ECF7F7F7F7F7F7FFF4F8
FFF7FFFFF7F8FFF7F4F5EDF0F5E8F4F1F7FFF1F7FFF5E8F4F1E8F4F5E8F4FFE8F4F5F7F8F1F4FF\
FFFFFFF5F7FFF5FFFFFFFFFFF1FFFFFFF4F4F1F7F8F5F4F4F5FFFFF5F7F8FFFFFF
FFFFFFFFF6F8FFEEF0F7EEF4F7F6F8F7F2F4FFFFFFF7FFFFF7F6F8FFF6F8F7FFFFEBF6F8EBF6F4\
EEFFF8E6F6FFEEF6F8EEF6F8F3ECF3F7FFFFF7F4F4FFFFFFECFFFFECFFFFE4F7F8
E2E5F0E3EEECE3FFF7DEEDEDEEF3F8F3F7EFECE5E5E4F4F3D6EFECFFF7EFF5EEF8EAEEF8EEF7F8\
E6F4F4EEF7F8EAF7F7EEEEF7F7F6FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FF
F7F7FFF3F4FFF7F7FFFFFFFFFFFFFFFFFFFFF7F7FFF3F4FFF7F7FFE6E6F3F7F7F8EBECEDEEEEEF\
EBECF4E2ECF3CDE8E9EAF2F8F7F6F8CBD9DE837961AD8F99FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7A5F60C6CAB9F7F7EFE3DDDFCDD4DEFFFFFFFFFFFF\
F2F4F4F7F7F8EAEDEDF1F4F3EAEDEDF7FFFFEBF4F4E6EDEEFFF7F8DEE1E2EAE6E8
EAEBF0EAEFEDECEFEFF7F6F8FFF7F8DAE5E8F5FFFFEEF4F4FFF4F4F7ECEEFFECEEECEBF0E3F4EF\
FFEFE7E3E6E7ECEEEFF7EBEEEAE7EDF3EFE7FFF7F8F3EDE5DEF7F4E3E0E2D1E8F4
EEEEEFDAE4E5D9D3DEE3E5E5E4EDE9E3E6DEF3F4ECF7E4E5FFF7F8F7F4F4F3F7F8F3F7F8F3F7F8\
F7F7F8F7F7F8F7F4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFF7F7F8F7F7F8FFFFF7
FFFFF7FFFFF7FFFFF3FFFFF7F7F7F4F7F7F4F7E4F4FFE5F8FFE5F8F7ECF8FFEDEEF3F7F8F3EDEE\
F7F4F4FFF4F4F7F2F4FFFFFFFFFFFFFFFFFFFFFFFFF3EDECFFF4F8FFF7F4FFEDEE
FFEDF8F5EFF8F5F4F8F5F4F4FFFFFFF5F4F4F1F7F8F5F4F4F5F4F4F1F7F8F5FFFFF1EFF8F1EDF8\
FFEFF8F5F4F4F1F7F8F1FFFFF5FFFFFFF4F4F5FFFFFFFFFFFFF7F8FFEEF0FFF6F8
FFFFFFFFFFFFFFF7F8F7F7F4F7F2F4F3F2F8F3FFFFF7FFFFF7F6F8F7F6F8F7F6F8EEFFFFEEF2F8\
EEF6F8E6F6F8FFF6FFF7F7F7F7F7F7F3F7F7FFEFEFFFF4F4E4F7F8ECF7F8ECEEF0
E2F7FFF2EEECE3FFF7DEEDEDEBECF0F7EEEDE4F4F7FFFFFFE6F4F4F5EEF8EAE6F4ECEEF8E6F4F4\
FFFFFFFFFFFFE4F4F3F7F6FFF7F6FFFFFFFFF7F7F3F7F7F7F7F7FFF7F7F7F3F4FF
F2F7FFEAF4FFF7F7FFF7F7FFF3F4FFF3F4FFEBECF7E6E6F3DFE0ECE3E4EDECF7F8F1FFFFF2F7F8\
E3E4EFD9E6E7D6E5F0ECF7F8EEF4F4C4C5D0777356D1B5C5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA38594A8AE8EF7F7F4EAEDECDEE0E6E3E6E7F5F7F7\
FFF7EFEBEDE5EEF7F8F7F7F8F7F7F8F7F7F8F3F7F8F7F7F8F7F4F4EBEDEEE2DCDD
F2EEEEECEDE8F2F4F4EAE6E8EAE6E8EAE4E5DEEDEEE3EFF0EEEDEEF7EBEEFFF6F8DAEEF8EBF7F3\
EEEFF0FFEFF0E3F7F7F2F3F4EAF2F8D6E4E1F7F4EDF3F7EFE3F7EDFFEEF0C7D4DE
E3E5F0EBECECD1E0E9F3E6E1FFFFF4EAEFEEF5EFEEF7EEEFF7E5E7FFF7F8FFF7F8F7EFF0F7F7F8\
F7FFFFFFFFFFF7F7F8FFF7F8FFFFF7F7F7F4F7F4F4F7F4F4FFFFF7F7F7F4F7F7F8
F7E4F4FFE4F4F7F4F4F7F4F4F7FFFFF7FFFFF7FFFFF7F7F8F7E4F4FFEEFFF7F7F8F3F7F8F7F4F4\
F7EDEEF3EEF0FFF6F8FFFFFFFFFFFFFFFFFFF7F7F7F7EDEDFFF7F8FFF7F8F5E8E9
F5EFF8F1EFF8F1F4F4F5F4F4F5FFFFF5EDF4F5F4F8F5F4F4FFF7F8FFF4F4FFEFF8F1EFF8F1F7F8\
FFF7F8F1F7F8FFF7F8FFFFFFF5FFFFF5F4F4F5FFFFFFFFFFFFFFFFFFF6F8F7FFFF
F7F2F8FFF6FFFFFFFFFFFFFFF7F2F8FFF2F8FFFFFFF3FFF8F7FFF4FFFFF8EEF2F4EEF6F4F7EBED\
F7F7EFEEFFF8F7EEF7FFF7F7F3FFFFF7F7F7FFEFEFF5EDEEF2EDEEF7EEF0E3EEF8
EAEBF4EAE0E1E2E4EEDEE0EED9F4F8EAECEDECF7F7EEF7F8E3E5F0ECEEF8F7FFFFFFFFFFEEF7F8\
EEF7F8F5FFFFEAF4F3FFFFFFF7F6FFF3F2FFEEEEF7F7F7F3FFFFFFFFFFFFF7F7F7
ECF7FFF5FFFFEEEEF7F3F3F7F7F6F7F3F2F3EEEEEFEAF4F4EAF7F8F1FFFFF5FFFFFFFFFFEAF7F8\
D9E0ECCDE0E9FFF7F8ECF6FFCBE0E5C4BABA6F6958DACAD4F7F7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBD9DB4909874F3F7F4E2EDE8D9D9DBEEEDE5EEF7EC\
F5F7F7E2E8E1EEF7F8F7F7F8F5F7F7ECEFEFEBF4F4F7F7F8F7F4F4F3F3F4D9DDDF
F2ECEDEAECECF7F7F8DED9DBECECEDF5F7F7DAE5E8EEEFF0DEF4F4FFEEF0F7EBEED9EEF8DEF4F7\
EBF7F3F7F7F4F3F4F4E3E5E7ECEEEFD1E0E1F3F4EDEBFFF7DAF7FFF5ECE8E4F3F4
DADDE8DAD4DFD1DCE5D9E0E1F7FFFFF7F7F0F1EDEEFFFFFFF7ECECF7F6F8FFF7F8F7EDEEF7EDEE\
FFF4F4F7F4F4F7EDEEFFFFFFF7F7F4FFFFF7FFF7F8FFF7F8F7F7F4F7F7EFFFFFF7
F7E4EDF7ECF8FFEEFFF7ECF8F7FFFFF7EFF0F7EDEEF7EDEEF7ECF8FFF6F8FFF4F4FFF4F4F7F7F8\
F7FFFFF7F2F8FFFFF4FFFFF4FFFFF8F7F7F7F7EFEFFFFFFFFFFFFFFFF4F4F5EDEE
F5FFFFF5EFF8F5F4F8F1F4F4F5FFFFF5EFF8F5E5F0FFECF4FFF7FFFFF7FFF5FFFFF5EFF8F1F6F8\
F5F6F8F5EDF4F5F7FFF1F7F8F5F7F8F5F4F4FFF6F8FFF6F8F7FFF8F3FFF4FFF2F8
FFFFEDF7F6E7F7F2F8F3F6F4F7F2FFF7F2FFF7FFF8FFF6F4FFF6F8FFF6F8EEF6F4EEFFF8F7F7F4\
FFF6FFEBF3F7F3F4F3F3FFFFFFFFFFFFFFFFECF4F4EAF7F8F3F7F8EEF6F8E5ECF4
F7ECE8DADDE7EEEBF4ECF6F8E3EFEFF7E5E7FFFFFFE6F4F4F1E6F4F3FFFFFFFFFFFFFFFFEEF7F8\
EEF7F8EAF7F7F7F7F7F7F6FFF7F6FFFFFFFFF7F6FFF3F2FFF3F2F7F7F6FFFFFFF7
F7F7F7F3F4F7E3E4ECEEEEEFEEEEEFEAF4F4EAF7F8F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFE2EEF8\
C5DCE5E5E7EEECECF4F7ECEED1ECF4A2979089706FF7EDEEF7F7F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6BDCE83795DEAECE5D8E1D6D9D9DEFFEDE5E6F7EC\
F1F7F4EAEDECFFFFFFF3F4F4ECEFEFFFFFFFF2F4F4F2F7F7E3E6E7F3ECEEEBEEF0
E2E0E1F2F3F4ECEFEFE4E7E8EBECEEDFE0E3EBE7E9E3F7F8E3EDEEEEF4F4EEEDEEFFF6F8EAF3F4\
EEFFF7ECEFEFF3F4EDEEEEF8CACCD7EEEEF0D8DBDCEAECEDEBF4F4EBEEF8E2E5E5
E2E7E8D0ECF4D0D5DDBEC8DBCECCD3E3DDDEEAEDE6EAEDEEF1EFEFEAE1E1EAD9DBF3EBEDF7F2F4\
FFF6F8FFF7F8F7F7F8F3EDEEFFFFFFFFFFFFF7F7F8F7F7F8F3F4F4F7F7F8F7F7EF
F7F7F4F3F4F4F7EEFFF3ECF8FFF7F8F7F7F8F3F4F4F7F7F8F7F7F8F3FFFFF3F7F8F3F7F8F3F7F8\
FFF6F8FFFFF8FFF6FFF7FFF8F3F7E7ECEFEDF5F7F8F5F4F4F1E4E6F1E6E9F1EBEE
F5F6F8F5EFF8F5EDF4F1EEF0F5F6F8F1FFFFF5F2F4F5E4EEF5EFF8F5EFF8F1EFF8F5F6F8FFFFFF\
FFFFFFF1E5F0F5EDF4F5EEF0F5EEF0F5F7F8F7F2F4F7F2F4F7FFF8F3F6F8F7F6FF
F3FFEFF7FFF8F7FFEDFFF6FFFFF6EDFFF6EDFFF2EDFFF6EDFFF6EDEEF6E5E6FFF8EBF7F7EBF7F7\
EBF4F3F7F7F7F7EFEFF7F4F4F5EDEEEAE0E3ECE0E3EEE0E2E6E0E1E2E0E1EAE4E5
F5F7F8DFE4F0F3ECEEE2E7E8E5DDDFE6F4F4E6F4F4EEF7F8EAE6F4E5F7F8E6F4F4E6F4F4E3F7F8\
EAF7F7ECF7FFFFFFF7F3F2FFF7F7F8F7F7F8FFFFFFF7F6F7F3F2F3F7F6F7FFFFFF
FFFFF7FFFFF7EBEBECFFFFFFECF7F8F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFEAF7F8E2EBF8\
CBE8E8FFF7F8ECF6FFF2FFF8C9D4E27B6953A88F98F7F7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F894797BB9B89FEAEFEFEAEBF8FFF4F4EBF4F4\
EAEDECF1F4F3F3F4F4FFFFFFF3F4F4F1F4F3EAEDECF2F4F4E5EDEDFFF7F8F3F7F8
F2EDEDF1F7F4F5F4ECF1F4F3DFE0E6F2F7F0E2F4EEF3F7F8F7F7FFEEEDEEF7F4EEF3F3F8F2F3F4\
FFFFFFEEFFF7F2F4ECEBECF4EBE6EECBD4D6F7F6F8E4EBEFEBEFE5F3F4EDF7FFF7
F7EEF8E3E5E7D6EDEFE2EFECD9E4E5D1DDE5EBE0DDE5E5E5F3EDE6F2FFF8F5EFEEFFF7F7F7F4F3\
EAECECEAE4E5F7F3F4FFF7F8F7EDEEF7F4F4FFFFFFFFF7F8F7F7F8F7FFFFFFFFFF
F7F7F8F7F7F8FFFFFFFFFFFFF7FFFFF3FFFFF7F7F8FFF4F4FFF7F8F7F4F4F7ECF4F7EBF4F7F3F4\
FFF2F4FFF2F4FFF2F8F3FFF8FFEDE8F1E5F0F5ECEEF5F7F8FFF6F8FFF6F8FFF6F8
F5F6F8F5F7F8F5F7F8F5F6F8FFF6F8F7FFF8F7F2F8F7F2F8F7F6F4FFF6F8FFFFFFFFF6F8FFF6F8\
FFF6F8F5FFFFF5F6F8FFF6F8FFF6F8FFF6F8F7FFFFF7F6F8F7F6F8F3F6E7F3F6EF
F7F6FFFFFFEFFFFFFFFFFFE8FFFFFFF7F7F8F7F7F8F7F7F8F3F4F4F3F4F4F7F4F3F3F7F7F3F7F7\
F7F7F7F7F7F8FFF7F8ECFFFFE2F4F4F3F2F4E3F7FFEBF7F3FFFFFFF5F7F8F5F7F8
FFFFFFD9DBE2ECF7F3ECF7F7E6F4F4FFFFFFF5EEF8F1E6F4D9E5F0EEF7F8EEF7F8EEF7F8F1FFFF\
F7F7F7F7F7FFF7F6F7FFFFFFEEEEF8EEEEF8F3F2F7FFFFFFF3F2F3F3F2F3F3F2F3
F3F2F3F7F6F7EBEBECF7F7F8F1FFFFF5FFFFF5FFFFFFFFFFFFFFFFFFFFFFEAF7F8EEEEEFD1E5EC\
DAEFEFFFF7F8EAEBF0FFEBEEA39EA46F5344E2D4DEF7F7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA891A2ADA990EBE8E1E4E6F4FFFFFFF3FFFF\
EAEDEDF5F7F7F3F4F4FFFFFFF7F7F8EAEDECF1F4F3FFFFFFF3F4F4F3F4F4EBF4F4
F3F7F8EAE7E1EAEEEDFFFFFFE2E4EDE2EFEEF2FFF8F3F7EEF7F4EEEEF4F4F7EEEEF3F7FFF7F6F8\
F5F7F7FFFFFFEAEDEDFFFFFFF3F7F8F2ECF4D1D4DFF5F7F4D9E5EEDEF7F3EEF4F4
FFF7EFF3ECEDC8E5F8DAEFF8ECE5E7CEE0EDC9D9E6D9D1DBE3DDDFEAEDEEEAEDF4E4E8E9EAE8E9\
F5EDEEF5EFEFEAECEFEAEBF4F7F6F8FFF7F8FFF4F4FFF7F8E2F7F4E2F7FFFFF7F8
FFF4F4FFF4F4F7F4F4F7F7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFF7F8FFEBF0FFFFF8FFF2F4\
FFF2F4F7F6F8F7EEF8F3F4F7F5EDEDECE6EEF3F6FFF7F3F4FFF7F8FFF2F4FFF2F4
FFFFFFFFF3F4FFF3F4FFF6F8F7F6F4F7FFF8F7F6FFFFFFFFF7F6FFFFF6F8FFF2F4FFF2F4FFF3F4\
FFF7F8FFF6F8FFFFFFFFF2F4FFF6F8F7F6F4F7F6F4F7F6E7FFF6EDF7FFEFF7F6EF
F7F6FFFFFFFFFFFFEFFFEFEDF7EDF4FFFFEFFFFFEFF7F7F7FFFFFFFFFFF8F7FFF8FFFFFFF7FFFF\
F7F7F8E3F7F8E4FFFFF5F7F8EEEEF0FFFFFFE5ECF4F5FFF7FFFFFFF5F7F8F5F7F8
E5F7FFDAECE7EAE4E7FFFFFFE6F4F4ECF6FFF2ECF4FFFFFFD9F4F4FFFFFFEEF7F8DAEFF8F2F7FF\
FFFFFFF3F4F3F7F6FFF7F6FFF7F6FFFFFFFFF3F2F7F7F6F7F7F7F8F7F7F8FFFFFF
ECF7F8E2EBECE6E6E8F5FFFFF5FFFFF5FFFFF5FFFFFFFFFFFFFFFFF5FFFFE2ECF4EEEEF3D1EDF4\
EEF7F8EEEDEEF7F6F8ECFFF8656556947173F7F7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8C2A7B6969387E6DCCBEAE5F0F7EEF8F3FFFF\
F3F4F4EEFFF7F3F4EDF7FFFFF7FFFFEAEDEDF5FFF8FFF7EDF7F7FFEBEDEEF3F4F4
F7F7F8E4E7E8ECF6FFF5F4ECE4E6E8EEEDEEEEF7F8EEF7F8FFFFFFECF7FFDADDE8F7F7F8F7F7FF\
EEEEF8F1F4F3F7F7F8F7F7F8F7F7F8E6ECF4E3EFEFD1CBD7F7FFFFEAE0E2DADDDF
EEF4F4F7F7F8EAECF4D1D9E9D6D9E6E5E0E2D9E6E5E5EEEFD9D3DECED4DBDFD4D6EBE0E1EBE6E8\
DFE4E5E3E4E6F3E8E2ECE6E7EAECF8E4E6EDE4E6E8ECEEEFE3FFF8E3F7F4FFF7F8
F7F6F8F7F2F4E2F6F4E2F4F8F7EEF0F7F3F4FFF6F8FFF3F4FFF7F8FFF6F8F7EEE7F7F7EFFFF2F4\
FFF2F4F3FFFFF7F7FFF7F4F7F1EDEDF7EEF8F3EBF0EEF7F8E3EBEEF3F6F8F7F6F8
F7F2F4F3FFF8F7F6F4F7F2F4F7F6FFFFF2EFFFF2EFF7F6EFF3FFEFF7FFFFF7F6FFF7F6FFFFEEF0\
F7EBEEF7F2F4FFF6FFFFFFF4FFF2F8F7F6F4FFF2F8F7F6EDF7FFFFF7FFEFF7FFFF
F7FFEFFFFFE8FFFFE8F7EDF4FFFFFFFFEFF8FFEFF8F7F7FFF7F7F8F3F4F8F7F7F4F3F7F8FFF4F4\
FFF7F8EAF7F8F3F4F4FFF7F8DAEBF4E5ECF4F7EEEFFFFFFFF5F7F8E3E5F0DFE0EE
E5E0E9EAE0E2F7E5E7EEF7F8EEF7F8EAEBF8F7F7F0E5F7F4E5F7F8ECF7F7EAF7F7F7F7FFF5FFF7\
F3F4F7EEEEF3F3F2FFEBEBF8EBEBF8F7F6FFFFFFFFFFFFFFF7F7F8F5FFFFECF7F8
ECF7F8F2F6F7EEEEEFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAF7F8EBEBEFD9EDEFE3F7F8\
EEF4F4EEEFF0F7E6E7B3BABD40332ED9C2CEF7F7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F8D9C8DB97988AC8C0AEECEDEDECEEF8EEECF4\
E5EFEFE3F7FFF7F7F8FFF7EFFFFFFFEEF7F8F2EDE5F5EDE1FFF7F4EEEDEEF7FFFF
EBEFF0F5EDEDF7ECE5EAEEEDEAEBEDEEEDEEEBF7F8F1FFFFDEF4F4DAEFF8ECF7FFD9D4D7D9DCE5\
F2F7F4ECE5E7F1F4F3ECEFEFF7F7F8F3F7F8E5E5F0D9EDEDC1C1CCE2D9DBF5F4F4
DAECE8EEEFE7F7EEF8F5EEF0E3EFF8EBEBF4D9EFF4D0E5EDDEDCDDD6DBDCD6E0E2DEE0E3E2E4E6\
F7EFEFEBECECF7EEEFF3EDE5FFF4E8F7EDE5F3E8E9E3DCDEE4DBDCE4E0E5E4E6F4
EAECEFECF7F7EAF6F0F3E6E2F2ECEDF7F6F8F3F6F8F7EEEEF7EBF0F3EEEFF7F7F4F7F7F4F7EEEF\
F7F6F8F7FFFFFFF7F7F5F4F3ECE5E5F3ECEEE3DCDEEEE0DBF7E8E1EBEDE8EBF4EC
F3F7ECF7ECEFEEE4EDEEEEE8F3EDECF7E8F7FFEFF7FFFFFFFFFFFFF7F6EFFFFFFFFFF6F8F3FFF8\
F7FFEFF7FFE8F3FFE1F3F6E5F3FFF4F3F6F8F7FFFFFFFFFFFFFFEFFFFFFFFFFFEF
FFEFECFFE8F8FFE8F8F7F7EFFFEFF7F7F7FFF3F4F7F3F4F7F7F7F8F3F4F4FFF7F8F7F4F4ECFFFF\
ECFFFFEAF7F8F3F7F8EEFFFFECEBF4EBF7F3FFFFF8ECEFEED9DCE6E3E4E5F7F7F4
FFFFFFE4F4F3EEF7F8EEEEF0F5EBF4ECEEF8E3F7F4E5F7FFFFFFFFECF7F7F5FFFFEAF4F7E3EEF3\
EAF2F4E2F6F4FFFFFFF3F3F4F7F6F7F7F7F8FFFFFFF7F6F7F3F2F3E3EEEFECF7F8
F7F7F8F7F7F8FFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFE2ECEDE3EEF7D6E5EEEEF4F4\
EEEFF0EEEDEEF3F4F45D56567F5E5EF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8B0A3A4ADA28DEBEDE5F1F7F4F3E0E6\
DEEFEFFFFFFFE3F7FFF3F4EDF3FFFFEBF7F8F2F4F4F5F4F4FFF7F8FFF7F8E6EDEE
EEF7F8EEF4F4EAE7E8F7F6F8F2F6F4EAECF8ECF7F0E3F7F8D8F4F4FFFFFFDEF4F4C4D1D4ECEEEF\
E2DCDEEAE7E8FFFFFFF5F7F7EAEDECF5F7F7F3F7F8E2E5F0FFFFFFCFD5DFD9E4E5
FFF7EFDAEEEFE5DDDFFFFFFFF2E0E9F5EEF0F7FFFFE3F7FFD2EDF8D9EDF4E2EDE8F3F7F4E3E5E7\
E4E5E8E3F7F8DEECEDD1DCDEF7F7F8E5E5E7EEEEEFF7F7F8F7F7F8FFF7EFF7EDDB
F7EFE8F5F4F8F1E8E8F5EDEDF5EFECF5F4F7F5F4F3ECF4ECECF4ECF5EFEFF5F4F4F5F4F4F7F7F7\
F7F7F7F5EDECF1EDEDECEDEEE5E5E8EBEEE7E2E5E7E4F4F8DEECF4E2E4EEE4E8E9
DEE1E9EAEDE5F7EDEDEEEFF8F7F7F0F7F7F0F7F7FFFFEFF7FFFFFFFFECF8F3E0E5F3EFDBFFFFED\
FFEFECF7EDF8F3EDF8F7E0E7FFECE8FFEFECFFEFECFFFFEFFFFFEFFFFFFFFFEFF8
FFFFEFF7EDFFF3F4F8F3F4F7F7F7F7FFFFFFF3F4F4F7EDEDF3F4F4F3F7F8F7F7F8FFF7F8EAF7F8\
F5F4F4ECF4F4FFEEF0F3F6F8EAE4E5E2EDEDE2E4F0E2E4F8EBECF4FFFFF7F5EEE7
EAE7E8ECF4F4E6F4F4ECF2F8EAF4F8F7FFFFE6F4F4FFF7F7FFF7F7ECF7FFDAE5ECEEEEEFF7F6F7\
ECF6F8E3FFF8FFFFFFF7F6F7F3F3F4F7F7F8FFFFFFF7F6F7F7F6F7F7F6F7F7F6F7
F3F4F4FFFFFFF5FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFEAF7F8E3E4ECD9E6F0FFFFFFEEEFF0\
E6F4F4E6F4F4B1D4DE452722C6AEB2F3F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4B5C99D8A72E6EDE1F1F4F8F3E6EE\
E6F4F4F1F4F3F5F7F7EAEDEDF7FFFFF3F7F8F3F4F4F7F7F8FFFFFFFFFFF8EBEDF4
F7F7F8E6E8E9F5F7F7F5F7F7F2FFF8EAEEF4F7EEEED8F4F4E3F7F8DEF4F4F5FFFFFFF7F8C7D5D7\
E3E5E7E5E7E8D6D9DBEAEDECF1F4F3EAEDEDFFFFFFF7F7F8DADDE8EAE5F0EEF7F8
D9E4E5EAE7E1EEFFFFE5DDDDF3DBE2EAE0EEECEEF8FFFFFFEEF6FFE3E7EFDEEDEDEAF4F4DEF7F7\
E3E0E9ECF7F8FFFFFFE3E0DCD9E4E7EEEEEFEEEEEFEBECEDE3F6FFD9ECEEE5EEF0
E5E5DED9E4E5D2E6EEE3ECEEF7EFE7F2EDDEF2E0DEF5E4E6F5F7F8F5F4F4ECF7F8EAE5E5F5F4F3\
F1F7F7F5F4F4F7EEF8E5E4E7EEECECE2DDE5DEE4F0F7F6F8FFF2F4F3F3F4EBEEF7
F7FFF8ECF7F8E4EDEEEAEDEEEAF7F8FFF7F4F7FFF8F3F4F8F3F4EDF7EDEFF3FFF4F7EDF8F3F4ED\
F3F4EFF7FFF8FFF7F8F7F7F8F3F4FFF3F4F4F7EDF4F7F7F8F7EDF4F7EDF4F7F7EF
F7F7FFF7F7FFFFF7F4F7F4F4F3F4F4F3F4F4FFF7F0F2F7F4F5F7F8FFF7F8FFF7F8ECFFFFF2F4F4\
F3FFFFFFF6F8E3EEF8DEECF8ECE4E1EEEEF8EEEEF8FFFFF8F3F4F8FFFFF7EAECE5
F7E4E5EEFFFFEEF7F8E4EBF8FFF7F8EEF7F8EEF7F8FFF7F7ECFFFFFFE5ECDAFFF7EEEEEFFFFFF7\
F7F6FFF7F6FFFFFFFFFFFFFFFFFFFFF7F7F8F3F4F4F7F7F8F7F6F7F3F2F3EEEEEF
F7F7F8FFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFECF7F8DAE5EFD1E5EFE3F4F4E6EDEEEEF7F8\
FFFFFFFFF7F894A6AC5B3830F3E8E9F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6CDE5978870D1CEBDEAF7FFF7EEF0\
E3E5F0EAEDECF5F7F7F2F4F4F7F7F8F7F7F8F7F7F8E2EDEDECF7F7FFFFF8F7F7F4
EBEDEEE6E8E9FFFFFFF1F4F3F3EEF0ECEEEEEAE6F4ECF7F0E2F7F8FFFFFFE3F7F8F5FFFFF5F7F8\
D1D4D7C5C9D3EAECEDE6E7E9DFE0E3F2F4F4ECEFEFF3F4F4F3F4F4F7FFFFF3FFFF
F7FFFFF7F7F8F3EDE5EBF4E8FFFFF7FFF7F8ECE5F0ECEEF8EEF3F8DFECF4C6EFF7DEF7FFFFFFFF\
E3E5F0DEE4EEF7F7F8EEE5ECF7EDE5ECF4F4ECF4F4D1DDDFE3E4E1EBE7E5D6E0E8
D6E4E7DEEBEDF5F7F4EEF6F8DFEBEEDFEBF0DFF6FFE3EBEEF7EFF0F7E5F0F7F3F0EAEDE6F5F7F8\
FFFFFFE5E4E6DFE5E5EEF7EFF5EFF0DEECF0F3F3EDEEEEEFE3EEF8DEEFECE3E5E7
EBE6E8EBEBF4F3F2FFF7F6F4EAF3F8DEECF0ECEFF4FFF4F8FFF4F4EAEFEEEAF7F4FFF7F8FFF4F8\
FFF4F8FFFFFFFFF7FFFFF4FFFFFFFFFFF7F8F7EFEDF7F7EDF7F7F8F7F7F8F3F4F8
F3EDF4FFF7F4F7F4FFFFFFF8F7FFF8F5F7F8EAF7F8EAF7F8F7F7F8EAF7F8EAF7F8F5F7F8FFEEF0\
F7F2F4F7FFFFEAEBF4ECECEDF7EFE7EBEBF8FFFFF8F7F7F8E3EFFFECF7F3E4F4FF
FFFFFFDEE4EEEAE6F4F5EEF0F7FFF8EEF7F8E6F4F4EEF7F8EAF7F7F5E5EFECEEF8FFFFF7FFFFFF\
FFFFF7F3F2FFFFFFFFFFFFFFFFFFFFF3F4F4FFFFFFF7F7F8F7F7F8FFFFFFF3F4F4
F5FFFFF1FFFFF5FFFFFFFFFFFFFFFFFFFFFFF5FFFFE2ECEDE2ECF7E5F4EEEBF7F4F7FFF8EBF7F4\
E6F4F4C6D9DB6F747B87706CFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8AA959BAC9772D0D9DBECEFED\
EBE6F4E2EDEDF5FFF8FFF7EFF7F7F8EEEFF0F7F7F8E2EDEDECF7F7F5F7F7F1F4F3
E3E6E7FFFFFFEBEDEEECEFEFE5E0E5DEECF8EAF3F0F7F4F8EEEFF0E2F7F8F1FFFFE6EDEEEEE7E9\
E3E0E6F7F7FFDADDDFCBCFD1CBCFD1FFFFFFE2E5E5EBEFF0EBF7F8F3F7F8EAEDED
EAEDEDF3F4F4F7F7F8F3F7F8FFEDEEF7E0E9F3E0EEF2EEF0F5F7FFFFF4F4F3E7E8EBE0E1DFE8E8\
EBEFECD6D9DEE3EFE9D8E1E2C3CDDEC9DBE9D8E4EEE2EDEEDEEDEEE3EFF0F7ECEE
D1CCDBAFC1D7C9D1DBD8DCDCC9CED6CDCED6E4DCDCDAD9DBDFD9DBEBF4EDE3FFF8D6E6F4D9D4D6\
D9D4D7DACCCFCFD1DBBDCFDEC3D9E6D6E0E5E2D3E5D9DCEDEEF4ECF1F7F4EBF7EF
D9FFF7EBF7F7DEEDECD6E4E5DFECECE5ECECE3E5EDE4F4EEE4F4EEF7FFF4F2F7F4EAF7F0EAF7EE\
F3FFF0F7F7F8FFF7F4F7F7F8F7F4F8FFF7F4F7F7F8EAEDF8E4E8E9DEE0E3E4E7EE
EAF4F8E4EDF4EAEDEEEAF4F8EAF4F8F5F7F8ECF7FFE2ECF4ECECEEF7E5E7F7E5E7F7EEF0E5EEEF\
E6F4F3E2E7E8E4DBDCF7EEEFDEEDF0E2F6F4EAF3E8E3EFF7DAEFEFD6EDEDD6EDF4
DEE4EEDAE5F0E5F7F8E5F7FFE5F7FFEEF7F8FFFFFFDEF4F4F5FFFFF3F4F3F7F6FFF3F2FFF7F6F7\
F7F6F7F7F6FFFFFFFFF7F7F8F3F4F4F7F7F8F5FFFFF1FFFFEAF7F8E4F4F4EAF7F8
F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2EEEFC8DDE7D6EDF4F7FFF8FFFFFFFFFFFFEBF4EE\
DADDDF7E8785685152D1BAB5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDACCE598806DD6E0DBE2EDE5\
EAE4F0EBEFF0F7EFE7F5FFF8EBF7F3F3F4EDFFFFFFF3F4F4F5F7F7FFFFFFF5F7F7
F1F4F3DFE0E3EBECEEF7F7F8D6DCE5EBE5E6EEF4F4FFF7F8F7F4F8DEF4EEE2F7F8EEF4F4ECEBF0\
F2FFF8F2F3F4F2F3F4F2F3F4EAECE5E5E8EDF3F3F4E5EEF0EEF4F4EEEDEEDEE5E5
E5EDEDF7F7F8F3F3F4F3ECEEEEF7F8E5E5F0F3F2FFF7F6F4F2F6F4EAF6FFEAF6F8F2F6F8F3FFFF\
DEE8EDEAEEF4D6E6F4EAE5E5ECF7E8F2FFF4E3EEFFDEE6F8DAE5F8EEE5E7D6ECF4
CEF7FFEBFFF7F7EEEFECEEF8EAE6EDEEEEEFDEE6EDD9E5E7DEEFF0DAE4E5F5FFF4EBECF4ECF7F4\
E4EDEDE2E5E5E5EEF8ECEEF8FFF7EFFFF7EFE3EEF8E3EEF8E3E4EED1D9E6E3E0E8
E2E0E2DEE0E9DEE7F4E2EDF4ECEFEEEBFFF8EEEEF7EBE6F3EBE6F3ECE5F7F1F4FFECEEF8ECEEF8\
F1F4EEEAF4F0E4F4F8F5F7F8F5F7F8E4F4F8EAF4EEF5F7F4FFFFF8F7F6F4FFFFFF
EBEBEDEBEBF4F3F2F8F3F2F4F3EBEDF3EBEDF3F6F8F7F2F4FFF6F8FFF3F4F7F6F8F3F7F7E2ECEF\
F5FFF7F1F4F4EEF7FFDEE7F4D9DCE6F5E6E9F5EEE5E4EDF4E6F7EFF5EEF8F5EEF8
F1E6F4E3F7F8FFFFFFFFFFFFEEF7F8EEF4F4E6EDEDEBF7F8F2F7F7F7F7F7F7F6FFF7F6FFF7F6FF\
F7F6FFFFFFFFFFFFFFF3F4F4FFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFBCD9E1DAEFF8E3F7F8F2FFF8FFFFFFF7F7F0EEF7F8\
9CABAF6F6F73B59D9FFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8A0807FB9B8B4EBEFE5\
DEDBE8F3F7F8F3F4F4F5F7F7EBF7F3F3F4EDF7FFFFEBF4F4F5F7F7F5EFEFF1EDEC
F5F7F7D6D9DBF3F3F4F3F4F4E4EDECEBE6F0DEF7EEE3EFF0F7FFF8E2EFEEE3F7F8EEF7F8DAE4EE\
F7F3EDFFFFFFFFF7F8FFF7F8F2F4EDEEEFF8F3F6F8E6ECEEF3F4F4F3F4F4F3F7F8
F7FFFFF3F7F8F3ECEEF3F3F4EBECEEEBECEEF7F6F8F7F6F8F2F3F8F2F3F8F5FFFFF5F7F8F3EDED\
EEEFEFDFF7F7F2F7F3EBF4EDE3F7F4EEF7EFF2FFF4F2FFF4F3EEEDE2EEECE2F7F4
DEF7ECFFFFFFEEFFFFF7EEEFF2EEECF5FFF7FFF7EFEAE0E1F3ECEDD9D4D5CED9E1E5F3EFE4EDE8\
E3E5F0DEE0EEE4E6F4FFF6FFECEFE7E5F7EDEEF7FFEBF4F8EBECF0F5EEF0EAEBEE
EBEBF4F3F2F8FFF2F4F3EEEED9DCF0D9E5EEF3FFFFF3F7F8F7F4F4EBE5EFEBEBF7F7EEF7F7EEF7\
F3F2F8F7F6F8FFFFF4ECF7F8ECF7F8FFFFF8F7FFF4F7FFF8F7FFFFF3F6F8F7F6F8
F3F4F3F7F7F7EBF4F3E6F4F3EBF7F7EBF7F7EBECECE2ECF4DEF4F7DEF4F7E5F7F3F3EEEFF2EEEC\
FFF7EFE3EFF8EEEEF0F7EEEEF7F7EFDAEFECCBE8EDD6EFF8EEFFFFF5EEF8F5EEF8
EAE6F4EEF7F4EBF7F4E6F4F4FFFFFFF5F7F7F5F7F7FFFFFFE4F4F3FFFFF7F7F6F7F7F6FFFFFFFF\
F7F6F7F3F2F7F3F3F8ECF7F8F5FFFFF5FFFFFFFFFFF5FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAF7F8BED4DBEBF7F4EBF7F8F2F7F0ECF7F0F5FFFFE6EDEE\
7A78777F6C6EF7DDD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4AEB9A29F8DEEE5D7\
D1CDD3F3F7F8F3F4EDEEFFF7FFFFFFF7F7F8EEF7F8F3F7F8F2F4F4F5EDEDF5EFEF
F2EFEFD9E5E5EBECF0DFE4EEF1EDECE3EBF8DEEFE9FFFFFFE3EFF0F7F6F8F3EEEEF7F4EEEEEFF0\
EAEBEDFFF7EFECE8E1E5EDEDF2EDEDEEF7F8F7FFFFE3ECEEEEEEF0ECFFF8ECFFF8
F7F7F8EBF7F8F3EEF0EBEBEEECEEF8EAECF8F2F3F8F7F6F8EAEBF4F2F3F8EAFFFFF7F4F4D9F4F7\
E3EFECEAEDEDD0EFF8D2F7F8EEF7EFE3F7F4E2E8EDE3E8EDE3E8EDE3E8EDD6EDF8
D6EDF8E3E8EDE3E0E5EBE4E5F5F4EDF1F4F4E3E5F0D9D3DEF7EEEFF7EEEFEBE0E1D6CDCFDEDBDC\
DEE0EEF5FFF7E3F7F3D0EFECEAF7F4D9F4F3F7F4F4F3FFFFF3FFFFF2EEF0FFFFFF
F5FFFFF2F7F8ECFFF8F3F7FFF7F6F8CED9E6E2EDEEE2F4F4E4FFFFECF4F4F3F7F4EBEFEDF3EFEF\
F3F4F3EBECF3EBE6ECF3EBF4F3F6F4F3F6F8EEF6F8EBEEEFEBEEEFEBEBEDE6F4F3
EBF7F7F3FFFFF7FFFFFFFFFFF2F7F8F2F7F8F7FFFFF2FFF7FFF7EFE3EDEDE3EDEDF1F4F4F1F4F4\
E3EFF8E5E5F0EAF7FFF2ECF0ECF7F3E5F4F8EEF7F8FFFFFFF5EEF8F1E6F4F1E6F4
EAEEF8F7FFF8E5F7FFEEF7F8FFF7F7EAF4F3ECF7F7F5FFFFDEECF3F7F6F7F3F2F7FFFFFFF7F7F8\
EEEEEFF3F2F7F3F3F8ECF7F8F5FFFFF1FFFFF5FFFFF5FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFECF7F8DAE5EFDEECEDF7F7F0F7F7F0F2F7F0F5FFFFD9F7F8D9EDEE\
493F37B0A0A7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD6CDE5A9A398C6CBB4\
C1CDD0EBEBF0F7E5E7EBF7F4FFFFFFFFFFFFF7F7F8F7F7F8EAEDEDFFF7F8F5EDED
ECF4F4ECF7F7E3E4EEEBEEF8EAE8E8F7F6F8F3ECF0ECF7F0F5FFF0E5E5F8F7FFF8F3F3F8FFFFFF\
EAEBEDECEDE8F7EFE7F3F4F4EEF7F8EBF4F4FFFFFFEBEBEEEEEEF0D6E6EED6E6EE
DEE5E6E3F7F4E3E6E9FFFFF8F5F7F8F1F4FFF5F7FFEAECEDE2E4E5ECEEF4F2F7F8F7F4F4D9F4F7\
C7D9E8F3ECF4D0EFF8DAF4F8F7EDEDF7EFEFF2FFFFE4FFFFDEE5F0DEE5F0F5FFFF
ECE5F0E2E0E9F3F7F8E3F3F8D9F4FFDFECF0DAF7F8D0ECF4DEE8EEEAEDEEE2EDF4E2EDF4EAE4E5\
F7ECE8EEEFEFE2EDF4E3EDF4D2E8EDEEEDEDF2F7F8EAE5F0EAE5F0F5E6E9F1E6E9
F1E6E9EAECF0E2E0F0ECE5EEF7ECEEE5E5F0E6E6EEE6E6EEE3E4EEE2EDEEEAEFF4F7F4FFF3F4F4\
F3EFEEF7F7F4F7F7F8EBF7F4E6ECE1E6ECE1EBECE5F3EEEFEAECEDEAE4E5F1F4F4
F5F7F8F5F7F8F1F4F4F1F4F4F5F7F8F5F7F8F1F4F4F1F4F4F5F7F8EEF7FFFFF6F8E6E6F4EEEEF8\
E6ECF0F3ECF0F5EEF0F7E5E7ECF7F7FFFFFFE6F4F4FFFFFFF1E6F4FFFFF8F7FFF8
F7FFFFEEF7F8F7EFEFEAF4F3E4F7F7F5F7F7F7F7F7F2F7F7E2EBF7F7F6FFF7F6FFFFFFFFF3F4F4\
F7F7F8F7F7F8ECF7F8EAF7F8F1FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFECF7F8E3EEEFD1E4EFEEF7F8EBEFF0F7F7FFEAF7F0E3F7F8D9F7F8CFC2CE\
3D271DE3D4DEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8C8B2C5B0A091\
BCBEAEF2ECEEF3EEF8EBF4F4EEFFF7EEFFF7FFFFFFF3F4F4F3F4F4F1F4F3F1F4F3
FFF7F8FFF7F8F7F4F4F3F7F8E2E5E5F5F7F7EBEBF4F7F4EEE3F7EEDEE4F4F7F7F8F7F6F8F7F6F8\
F2F3F4EAEDEDFFFFFFF3F4F4F7F6FFF7F6FFF3F3F4F7F7F8EBEBEEEBEBEEF3F2F4
E3F7FFD9ECF0F7F3F4E3E4EEF7F6F4ECEFF7E4E8F3F5F7F8F2F4EFF5FFF8F7F7F8F3EDEDFFFFFF\
EAE0E8ECE4EED9F4F8CFEFF8F5EEF0ECE0E9EADBE9F3E0EEF7E4E5F7E4E5DEE7ED
D8CDD6E4E4EDF5EEF0F5EEE7ECE0E2E2EFFFF7F7FFF2EEF0EBEEEEDFE5EEE3F7FFE3F7FFDFF4FF\
D9EDF8D9F7FFEAF7F8E2EEF8EAEEF8EAFFFFF7FFFFEAE0EEF7ECF4EAEEF4EAEEF4
EAEEEEE4F4FFFFFFFFDEEDEDD9EDE8FFFFF7F7F7F7F7F7F7EEEEF8E6EEF4D9ECF8D8E0E9E2F6F8\
F1F4F8EAF7FFDEF4F4E4EDF4F1F4FFF1F4FFEAEDF4E4E8E9E2E4EEDFECF8DFECF8
E3E5F0ECEFF0EBECEEDFECF0DFECF0E6E6EEEBECF4EBF4F8E6F4FFE6ECF8EEEEF8F7F7F8E3E4EE\
E3E4F0ECF6F0EAECEDECF7F7EEF7F8DEE4EEE2E0EEEAE6F4F2EEF0F7FFFFF7FFF8
FFF7F8E6EDEEF2F7F7E2F7F7FFFFFFF7F7F7F3F4F7F7F7F3F7F6FFF3F3F8F7F7F8F7F6FFEEEEF8\
F3F4F4F5FFFFFFFFFFEAF7F8F5FFFFF5FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF5FFFFEAF4F4E2EBF3D6EDF4E3F7F8F5F7F8DAE6F0F7F7FFCDEDEEEAF4F49B939C\
664C42FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6DBEEB4AAA2\
ADAE9BDED4DBFFFFFFEBF7F8F7F7EFEEFFF7FFFFFFF3F4F4F7F7F8ECEFEFFFFFFF
F5EFEFFFF7FFFFF7FFE6EDEEE6E8E9F1F4F3F3F2F4EEEDEEDEF4F4F5ECE3EEF3F4F7F6F8F7F6F8\
FFFFFFECEFEFEAEDEDEBEDEEF3F2F8F2F3F4EAECF8ECEEF8EEEEF0F7F7F8F7F7F8
EEEEF0EEEEF0EBEDEEEEEFF0E3E4E6D9D9E2D1CFDCD1D4E2E2E4EEF5F7F8F3FFFFFFE8E8E2DCE5\
E4E0EEEAE5F0E4E5F0EAEEF8F1EEF0D6E4F0EEFFF7EEF7EFEEF7ECFFF4E8E2D9E5
D9D4DCE3EEF4EADBE2ECF7FFF2E0E2F7E5F0F2E0E9EAE0E9EAE0E9ECE5F0F5EEF0F5EEF0F2EEF0\
F2FFFFF5F7F8F5F7F8F7EEF8FFF7F8F3EBF8EAE6F4ECE5F0FFF4EDFFF4E8EEF4ED
DAF4F8E3FFF8F7F7F4EEF7F4ECF7FFD6EDEFE4F4F7ECF7F3FFFFF7FFEEE5F7ECEDF3F4F7E3E4E7\
D9DBE9D9DBE9E6E6EEEBEBF0DFECF8D9E4F0DFE0EEE6E6EDEBECEDF7ECEEF7F7F8
E5F7F8E3E4EEE2F7F8F2F7FFEAE4E7D8E8ECD1E0E8DEE0E5F3E6E2F3F7EFF3F3F4F7F7F8F5EEF0\
EAECF0F7E5EDEAE4E7EEF7F8EEF7F8F5EEF8F5EEF8F3FFFFF3FFF8F3FFF8EEF7F8
EEEFF0E6E5E5F1F7F7F7F7F7F7F7F7F7F6FFF7F6F7FFFFF7F7F7F7E3E4EFF7F7F8F7F6FFEEEEF8\
F7F7F8EAF4F4F2F7F8ECF7F8F5FFFFF5FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF5FFFFECF7F8E5E5EFD0E5EFF5FFFFE3F7F8D6EDF4F5FFFFC6E6F0E5F7F8F5F7F86D6464\
A07C7BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE4F4C8BABD\
9F9581BEBBB6E3DCDEF7F7F8EBF4F4FFFFFFFFFFFFF7F7F8F7F7F8F7F7F8ECEFED
FFFFF8F5F4EDFFF4F8EEF7F8FFFFFFE3E6E7EAECECEAE4E5F7ECEEE6F4F4E6EDEEEAE4E5EAE8E8\
EAE8E8F1EDECE3E6E7E5E5E8F7F6F8F5F7FFEAECF8E2E4EEF3ECEEECECF4E2E4F0
F3F3F8F7F7F8EBEDEEFFFFFFEBF4F4F7F7F8F3ECF4E6E6F4E3EEF8FFFFFFECF7F8E2ECF4ECEFEF\
E2E6F4EAEEF8F3E0E5EAE5E5F7E6EEE5E4E5EEFFF7DEF7F7E3F7FFEEF4EDF3EEF8
DADDE7E2F4ECEEFFFFE5E5EDF3E0EEF3E6F4E5DCDEDFD9D6EBE6E5ECFFF8EAE4EDEAE4EDF2E0E9\
F5FFFFECE5E7E3D4D6D9D4DBEBE0E9FFF7F8EEF4F4E6F7F8E6FFF7D6E5EDDEE4E7
E3F4ECEBEDE1E5EDEDE3F7FFDEF4F8E3F3F8E6ECEED6EDEDCBE8EDCBE8F4CBE8EDCBE8EDD6EDEF\
E4F4F3E4EDECDEE5ECD8E1E8DED9DBE4E4E5E4EDECE4EDF4E4F4F7E4F4F3E4E4E5
DEE0E5C4E5F3CBD9E1D2D9DBD6EDEDEEF7F8EEF7F8D6E7E8CBE0E8CBD9DECBD9DBD6EDECD9E0E1\
DFDCDBD6EDEDC4E4F4E5EBF0F5EBF4F1E6EEDAE5EEDFF4F4E3EDEDE3EDEDEEF7F8
EBF7F8EBF4F4EAFFF7F3F4F7EEEEF7F7F6FFF7F6FFF7F6FFF7F7F7F3F3FFF3F2F3F7F6F7F7F7F8\
F7F7F8F7F7F8F2F7F8F5FFFFF5FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
ECF7F8E2ECEDD9E4ECEBEEF7E2F7F8F5F7F8F7F4F8FFFFFFD1E5EECDEFF8EBECF87C7474503132\
D1BABDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8E2DCEE\
A3918BD9D9D0C4D1D3F7ECEEEBF7F8F3F4F4F7F7F8F5F7F7EAEDEDFFFFFFF3F7FF
F1EDE8F1EDECFFF7F8FFF4F4E6E8E9EEEFF0EEEFF0F5F7F7ECEEEFE5E4E6EEECEEDEDBDCEEF7F8\
E6ECEEE3E5E8EBEDEEF3F2F4FFFFFFFFFFFFF7F6F8EBEBEEF3ECEEEAEEF8E5E6F4
FFFFF8F3F2F4E5E5E8EBEDEEF7FFFFEEEDEEF7E4EEF3E6F4ECEEF8FFF7F8F5F7F8DEDBE9EEECF4\
E3E5F0DAEEF8F3E4E1EAF4ECEAF7F7E3EFEFDEF7F7EBF4F4FFF7EFE3EFEFEBF4F4
EAEDECE3F7FFEBF4F4EEF7EFEBF4F4F7FFFFE6EDE5F5EEE5DEE7E8F7EEF4F3E4E5EBF4F4E3DCDE\
EBE0EEF7EEF4E6EFE5ECEEF8D6E0E1D6DDDFFFEFE7EEFFF7F5F7F7EAE6E8F7F6F8
EAEBF4E4F2FFF2EBF4E2E4EEEBF3F4F7EBEEEAECF8F1E6F4F5EEF8F5EEF8F5EEF8EEF7F8FFFFFF\
EEF7F8EEF4F4DEECF4DEECF4E6F7F8E6F4F4E6F7F8E6F7F8DEF4F8DEF4F8E6F4F4
E6F4F4EBF7F4F5FFF8FFF6F8FFF6F8E6F4F4DEE4EEF5F7FFFFF6F8F5EEF8F1E6F4E3E4EEEEF3F4\
FFFFFFFFFFFFEAEBF8F5F4F8EAF7FFE3F7F4E5F7FFFFFFFFF7F7F7F7F7F7ECF7F7
F7F7F7F5FFFFE4F4F7F7F6F7F7F6FFFFFFFFFFFFFFF3F2F7F7F6F7F7F6F7ECF6ECE2F6F4FFFFFF\
F7F7F8F3F4F4EAF7F8F5FFFFFFFFFFF5FFFFF5FFFFF5FFFFFFFFFFFFFFFFECF7F8
E3EEEFE3EEF7F7F7FFFFFFFFECF7F0F7F7FFECF4F8DAEFF8F7F7F8EAF7FFAAAFAD674C41D1B9BC\
F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBE0E9\
B09D9BD1D1CBD8D9D3E2D9DBF7FFFFF3F7F8F7F7EFE3F7FFF7F7F8ECEFEFF7FFFF
ECEDEDF7F6F8ECE5E7FFFFFFEEF7F8EBEDEEF3F4F4F7F7F8F5F7F7ECF7F7F3F6F8EAECEDE3E6E7\
DEE0E8DADDE7EBEBEEFFFFFFF7F6F8F5F7FFEAEDEFECEFEFF7F6F8EBEBEEF3F3F4
F3F3F4EBE6E9E5E4E6E2E5E5F5F7F7F3F4F4F7FFFFFFF4F4F7E4EEC4CFDDD1E4EDD1D9E6DEFFF8\
F2ECEEF7E5E7FFFFFFFFFFFFFFFFFFDEEDEFF1F7F4FFFFFFF1F7F4F5F7F7F5F7F7
EAECECF7F6F8F2F6F4E5ECEDF7F7EFEEF7F8E2EDEDEEF7F8F7ECE8D1CBD3F7EEF8EBEDE5F7F4ED\
EEFFFFEBFFFFFFF7EFDAE5F0EAE6E8F5F3F4D9F4F7E2F4F7F5F7F7F7F6F8F7ECEE
FFF7F8FFF7F8F7F7F8F7F7F8ECF6FFECECF4F7FFFFF3FFFFEAEEF8F2EEF8F5EEF8E2E0EEE2E0EE\
E3E5F0EEF7F8F1E6F4F1E6F4FFFFFFFFFFFFFFFFFFFFFFFFF5F6F4F5F6F4ECEEF8
ECEEF8FFFFFFFFF6F8ECEEF8EAECF8E2E0EEEEF7F8FFFFFFF1E6F4F5EEF8F7F7F8ECFFF8EAECF8\
ECEEF8F5EEF8FFFFFFEAEEF8FFFFFFEEF4F4EEEFF0F5FFFFF5FFFFFFFFFFEAF7F7
F5FFFFECF7F7EAF7F7EBEBF7FFFFFFFFFFFFFFFFFFF3F2F7F3F2F7F7F6FFE2F6F8DAF7FFF7F7F8\
EAF4F4F1FFFFFFFFFFFFFFFFF5FFFFFFFFFFF5FFFFF5FFFFFFFFFFFFFFFFDEECED
E3EEE7ECF7F0F1FFFFEAF7F0FFFFFFE3EFF0D2EDF4E2DDDFE4D4D6B5B8C37D6B51A48083FFF7F8\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE4EE\
C5B6BCB0B6AADADCD3D6D1D3F7EEF0EBF7F8F7F7EFF7F7EFEAEDECEAEDECF7F7F8
F3F4F8EAECE5F2F3F4F5EDEDFFF4F4F7F4F4F7FFFFF7F7F8F3F4F4ECEFEFF1F4F3F5F7F7EAEFEF\
BECCD6EAE7EDFFFFFFF7F6F8FFFFFFEAEBF4E2E4E7F7F7EFEAEDEFECEFEFF3EBEE
F3F7F8F3F7F8F7FFFFEAEDEDE3EFEFF3FFFFFFF7F8F7F7F8F7E5F0C1C8D6BEC9DBE5E4EEDEE4F0\
D6ECF8EBF7ECF7F7EFE3FFF8E2F7EDDEE0E1EAF3F7FFF7EFF1F4F3FFFFFFF1F4F3
EAECECECEEEFEAE6E8D6E0E8EEFFF7F3F4F4ECEFEFF2F7F7DEE0E1ECEFEFDADDDFF7F4EDEEFFF7\
F7F7F8F7FFFFF5F4ECD9ECF4EAEBEDF5F6F4F5F6F4EBEBF4EBEBF4F3EBEEF7F6F8
FFF4F4EEF7F8EEEDEEFFF4F4FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFEBF7F8E3F7F8F3FFFFF7FFF8\
F5EEF0F5ECEDF1E0E5F2EEF8E4E6F4ECEEF8FFFFFFECEEF8E4ECF8E4ECF8ECEEF8
EAEEF8F1E6F4EAF3FFECF4F8F7FFFFF3FFFFECEEF8F5EEF8F7FFFFF3FFFFF7F7F8F7F7F8FFFFF8\
F5EEF0EAEEF8EAEEF8ECEEF8EEF7F8E6EDEEF7E6E7ECF7F7FFFFFFEAF7F7F2F7F7
F7F7F7F5FFFFF2F7F7EBECF7F3F3F4F3F4F4F3F4F4EEEEF8FFFFF7F3F3F4F7F7F8F7F7F8F7F7F8\
ECF7F8EAF7F8F5FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFD6E0E8
EAF7F0F5FFF0EEF7F8E2F7F4E5F4EEF2F7FFCBE5EED8D4D6EBF4F47F8890906C5DD9CCE5FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
D1C2D6C6BDB2C7CBC5C7C4CED9D1D4F3FFFFF3F4F4F3F4F4EAEDEDF5FFF8F7EFE7
FFFFF8ECEFEDF2F7F7EAEDECFFFFFFFFFFFFF7F4F4EAF7F4E5EEEEE3E4E6EBEDEEEAEDE8F7EFE7\
E2EFEFD9DDDFEEEEF0ECEFF7E3E5EFEBF3F4E5EEF0ECEEF8EAEDEFECEFEFF7EEF0
EBE6E9D2D4DDD2D4DDE6E6E9F3ECEEFFF7F8F3EEF8F7E5F0EEECF4E2DCE5DECDD3FFF7ECF3E4E5\
EBECF4EBF7ECEEFFF7DAF4EFE2FFF8D8DBDCD6E6EDEEFFF7F5F7F7F1F4F3F5F7F7
EAF4F3ECF7F7EAECEDEAECEDF5F7F7F3F4F4FFFFFFE2E4E5F7F6F8EAE0E2E3DCDEDAEEF8EBF7F4\
FFF7EFEEEFE7E2EDECF2F6F4ECF6FFECF6FFECF6FFF3F4FFF3F7F8FFFFFFF7FFF8
F3F4FFF3F4F0F7FFF8EEF7F8EEF7F8EEF7F8FFFFFFFFFFFFFFFFFFE6F4F4EEF7F8EEF7F8EBF7F4\
D9F4F8DADDDFECEEEFE5F4F4EEF7F8ECEEF8E4EBF8ECF3F8FFF7F8FFFFFFFFFFFF
F7FFFFE3F7F8EBEFF0F7F7F8F7FFFFFFFFFFEBF7F8E3F7F8F7FFFFFFFFFFEEF7F8EEF7F8F7FFF8\
F7FFF8EEF7F8EEF7F8FFFFFFE6F4F4FFFFFFEAF4F3EAF4F3F1FFFFF7F7F7FFFFFF
F3F4F3EEEEF7EBECF3F3F4FFEBEBECF7F7F8FFFFFFF3F4F4F7F6F7F3F3F4F5FFFFEAF4F4F3F4F4\
F7F7F8EAF4F4F1FFFFF5FFFFFFFFFFFFFFFFFFFFFFFFFFFFECF7F8E2ECEDD9E4EF
FFFFFFEEF7F8E3F7F8DAEFF8D9EDF8E2F4F8DAF4F4D1D9DBBECBCF674C4CD1B9B4F7F7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
DECDDBD6C6BDC3D4CBE2E1E5D1C6BDEBEEF8F3F7F8F3F7F8F3F4F4FFF7EFFFF7EF
F7F7F8FFFFFFE3EFEFECF7F7EEEDEEEEEDEEFFFFFFF5F7F0DEE5E6F7F7F8EEEEF0E2F4F8D1E1E5\
D6D9DBF7FFFFCED9DBC4C9D3E5E7EDE5EEF0EBF3F4F7F6F8F3F2F4F3F2F4EBEBEE
E6E6E9D6D9E2D6D9E2EBE6E9EEECEEF3F7F8EBEEF8F7EEF8E3E5F0ECFFF8D6D4D6E6F7F4F3F4ED\
F7F7EFF7F7F8E3F7FFE3EFEFE2EDEDEAECEDE2F3F8E2F4F7F1F4F3F5F7F7FFFFFF
ECF4ECF2FFF8F7FFFFFFEEF0E4E0E1FFF7EFF3EDE5DED9DBE4E0E1ECE4E1EAF6F8D6D9E1F7F7F8\
F5F4ECF1F7F4ECEEEFE5EBF8EAECF8F7F4F8F7F4F8E2EFEEE2F7F4FFF4F4F3F4FF
F7F7F0F3F4E9F7F7F0EBF7F8EBF7F8EEF7F8EEF7F8EEF7F8E6F4F4FFFFFFEBF7F8DEF4F4E6F4F4\
F5FFFFDAF7F8EBEFF0EEF4F4FFFFFFEEF7F8FFF7F8FFF4F4FFF7F8FFFFFFFFFFFF
EEF7F8FFFFFFEEF7F8EBF7F8EBF7F8FFFFFFEEF7F8EEF7F8FFFFFFEEF7F8EEF7F8E6F4F4EEF7F8\
E6F4F4EEF7F8EBF4F4EBEDEDEEF7F8ECF7F7FFF7F7FFF7F7EAF4F3F3F4F3F7F7F7
FFFFF7F7F6F7F7F7F7F3F3F3EBEBEFF7F7F8F5FFFFEAF4F4FFFFFFF7F7F8F5FFFFF7F7F8F2F7F8\
FFFFFFEAF7F8FFFFFFF5FFFFF5FFFFFFFFFFFFFFFFECF7F8ECF7F8EBEBF3F2F7FF
EEF7F8E3EFF0E3F4F4D9EDF8DAEFF8ECF7FFCACBD6A29594907D72A48080FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
E6DBE9DECEC8B9C1BCD1D4D6BEB8A9D6D9DEF7FFFFEEF7F8F7F7EFEBF7F4F7F7F8
FFFFFFEBEDEEEBEFF0ECF4F4D9E5E5E2F4F8F5F7F0F5F7F7ECEFEFE3E5E8EEF7F8F3F2F4F7F6F8\
EEEEF0C4CFD1C1CACBFFFFFFD9DCDEE3E4E6EEEEF0F7F7F8FFFFFFF7F7F8EEEFF0
EAEDEDDEE0E1D8DBDCD9E4E5F3F7F8F7FFFFF3FFFFF7F7F8E4D9E6E3E0E9D9E8E1EEF4EDF3F4ED\
F3F4E8EEFFF3E3F7F7F5F7F7F5F7F7F1F4F3F1F4F3F1F4F3F2F7F7ECF7F7F5F4F4
F5EDE5ECFFF8F2F7F7E5E0E5CBCFD6E5E8E1EAF7F4F5ECEDF2F7F4E3EEFFD8E0EFE3E5EFDEE4EC\
F2F7F7F7EEF0EEECF4FFF7F8F7FFF8F7FFF8F7F7FFF5FFF0F5FFF0E6EDF8EBEDE9
F7F7F0F5FFFFF1FFFFFFFFFFFFFFFFF5FFFFEEF7F8FFFFFFEEF7F8EEF7F8EBF7F8EEF7F8F5FFFF\
E3F7F8FFFFFFE3F7F8EEF7F8DEF4F4E3F7F8E6F4F4E6F4F4E6F4F4DEF4F4E3F7F8
E6F4F4EBF7F8E3F7F8E6F4F4EEF7F8EEF7F8EEF7F8E6F4F4EEF7F8EEF7F8EEF7F8EEF7F8EEF7F8\
FFFFFFECF7F7E3FFFFF7F7F7FFFFFFEAF7F7F5F7F7ECFFFFFFFFFFEEEEF8EBEBF8
F7F6F7FFFFFFF7F6F7F7F6F7EBEBEFF7F7F8F1FFFFE4F4F4FFFFFFF3F3F4F7F6F7F2F7F8F7F7F8\
F5FFFFEAF4F4ECF7F8F5FFFFF5FFFFFFFFFFECF7F8ECF7F8EEEEF7EEEEF7ECF7F0
E2EFEEE3F7F8DAE6F0F5FFFFD6EDF4EBEDED838A8D999783AC989DDACCD7FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
EEE5F0DACCD7C7C4BED1D4D0D6CCC4D1D5D6D9DDE7EBF4F4EEFFF7EBF7F4F7F7EF
EEFFF7EBEDEDF2EDEDDEEDEDEAF4F4F2F7F0ECF7F4ECEDEDFFF7F8F1EDECD9D9DBD6D9DDECEFF7\
ECEFF7FFFFF8E5E7E8CBCFD6BEC3D1ECEEF8D9DCDED9DCDEEEEFF0E2F4F8F2F4EE
D9DBDDC4C8CBBEC1C6D2D4D7F7F7F4EBF4F8E6F4F4EEF7F8EADBE9CDC8D6E2E0E5DAECEDEBF7F4\
EBEFE5DEF4EFEBF4ECFFF7EFFFFFFFECF7F7EAF4F3F5F7F4E4F4ECEAF7F7ECEDED
E4D9DBF7EEF0E4F4F3DEE4ECD9EDEFF3F6F8E2E7E8EAEEEEDEE6F8E2E5EDEAEEEDF7F7FFF3E6F4\
E2E5E8DEECF4FFFFFFE3EFF0DAEFF8FFFFFFDEF4F4E3F7F8EEF7F8F5FFE9F1FFFF
F1FFFFF5FFFFFFFFFFF5FFFFF5FFFFF5FFFFF1FFFFE2F7F8EBF7F8F5FFFFF5FFFFF5FFFFDEF4F4\
E6F4F4F5FFFFF5FFFFEEF7F8F5FFFFEBF7F8EEF7F8EEF7F8EEF7F8E2F7F8E3F7F8
D9EFEFEBF4F4F7F7F7ECF7F7EBF7F8DEF4F4EAEDECEBF4F4FFFFFFEEF7F8D6EDF4EAF7FFF5FFFF\
F5FFFFF2F7F7F2F7F7EAF7F7ECF7F7F5FFFFECF7F7F7F7F7F7F6FFF3F3F8FFFFFF
EBECF4EBEBEFEBEBEFEBEBEFF7F6F7EAF4F4F5FFFFEAF7F8EAF4F4E2ECEDF7F6F7F2F7F8F5FFFF\
ECF7F8EAF4F4EAF7F8FFFFFFECF7F8E4F4F4DAE5EFE6E6F3F7F6F7F2F7FFF7F7F0
D1E0E2E6E7EDDEEDF0E5EDF0EEF7F899A0A44630319F828ADACCD7FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFEEE4EED9D1DBB5BAB5BEBAACE3ECDED6D9DDE3E5E8F2F4F4F5F7F7EBF7F4
F3F4EDECEFEFF2F4F4EBEDEED6D9DBEAE4E5EAE8E8F2EDEDF5F7F7F2EFEFF3F6F8BEC1C8D1E0ED\
E3E5EFECEFF7FFFFFFECEFF7EAEDF7E3E4E8D1D4D6FFF6F4D6E5E5E2E1DCD8E5E7
F3F2F4ECEFEFE4E8ECE3E5EFE3E4F0E5E5EEFFFFFFE6FFFFF7E5F0BABDC9EBE7EEECECE8F5F7F7\
F1F7F4F5FFF8F5FFF8EAF3F7ECEEEFE4ECECEAF3F4F5F7F4ECF7F4ECF7F7F3F4F4
D8CFD1FFECEEE5E0EDEEE5F8E5E0EDCACDDCD8D9DBEAFFF4E3EEFFF3FFF4EEF4F4E2EDF0E2E5E6\
DEECF8F2FFEEEEF7F8E3EFF0F7F7FFDEF4F4EBF7EEFFFFF0F1FFE9F5FFF0FFFFFF
F7F7FFF7F7FFFFFFFFF7F7F7F3F4F7F7F7FFFFFFFFFFFFFFF5FFFFFFFFFFFFFFFFF5FFFFEEF7F8\
E3F7F8EAF7F7ECF7F7FFFFFFEEF7F8EEF7F8E5F4F4ECF7F7FFFFFFEBF7F8F5FFF0
F3F4F3DAEFEFE3F7F8E2F4F4E3F7F8F3F4F3E3FFFFDAEFEFEBF4F4EEF7F8D6EDF8F7F7FFEAF7FF\
F1FFFFF7F7F7F3F4F7F7F7F7ECF7FFECF7F7F1FFFFF3F4F7F7F6F3EBEBF3E3E4EC
EBECEDFFFFFFFFFFFFF7F7F8FFFFFFEAF4F4F1FFFFECF7F8EAF7F8F5FFFFEAF7F8FFFFFFECF7F8\
FFFFFFF5FFFFFFFFFFEAF7F8E3EEEFEBEBF3EEEEF7FFFFFFF2F7FFDAE6F0DEEDF0
F2F6F7D1E5EFFFF7F8ECFFFFA4C1CC4C4E44B39D9BF3E8E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFF7F8DED1DEE3DCDBBFAA9DBEB0A3C7CCC5CED1D4EAEDEDFFFFFFECEFEF
F7F7F8F3F4F4FFFFFFEEEDEEE5E0E2F5F3F4F2F7F7F5F7F7F7F4F4E3EFEFEAE5E7F7ECE5E2E5E2\
E3E4E6EBEBEEF3F2F4F7F6F8FFFFFFFFFFFFE5E5F0CAD4DBC4D5D6CAD5D6E2E5E5
EBECEEC4C8CBB7BDC5CACDD7D2D4DBE3E4EDEEFFF7F7F7F4F3F4F4B8C8CBD2E4EEF5E5E7F1F7F4\
F5FFF8F1F7F4F5F7F7F3F2F4ECEEEFECEEEFECEEEFECEEEFFFFFFFF5F7F7ECEFEF
CECDDCEEEFFFEEF4F4DEDBE5D9DBEDCBD4E7EAF7F4DEDBEDEAF4F0DEF4EEF5FFF0E2F4F8F3F7F4\
EAEFDEEBF7F0F7F7F4EBFFEED8F4F4F5FFF0F5FFF0F1FFFFFFFFFFF5FFFFF5FFFF
F7F7FFFFFFFFF3F4F7FFFFFFF7F7FFF7F7F7F3F4F7F7F7F7FFFFFFF2F7FFF2F7FFF5FFFFF1FFFF\
FFFFFFEAF4F3EAF4F3F5FFFFFFFFFFFFFFFFE4F4F3D9EDECEBF7F8EEF7EEE2F7EE
F3F4F7FFFFF7F7F7F7F2ECECF5EEEFF3F4F3FFFFFFE3FFFFE4F4F3F1FFFFF7F7FFECF7F7ECF7F7\
F7F7FFEAF4F7F7F6FFF3F2F3F7F6FFEAF4F7F5FFFFF3F4FFFFFFF7F3F4F7F3F4FF
F7F6F3EEEEF8FFFFFFF7F7F8FFFFFFEAF4F4F5FFFFF7F7F8EAF7F8FFFFFFFFFFFFECF7F8FFFFFF\
E4F4F4ECF7F8EAF7F8EEEEEFEEEEF7FFFFFFF3F4FFF2F7FFE3EFF0F5FFFFF7F4F8
D6EDF4EEF7F8E5F4F4ACB2BEAC977B7B5C58E2D9E2F7EDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8\
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFEEE5F0E2D9E8EEEEF0C8BBACBCBAA4BDB0AEEBF7F8F5F7F7F5F7F7
F3F4F4F7F7F8F3F4F4F7FFFFF7FFFFE3EFEFF7FFFFF5F7F7F7F7F8F7F4F4F5F7F7F5EFEFF2F7F7\
DEEDECD9E5E5EBEDEEEEEEF0F3F2F4F7F6F8FFFFFFFFFFFFF7F6F8FFFFFFEEEEF0
EBF4F4F5EDEDF5EDEDF7F4F4EAEDECF1F4F3EBF7F4FFF7EFF3F7EFC2CFD7EBEFF0EAF3F8EAF2F8\
EAF3F7FFF7EFF5F7F7ECEEEFF3F3F8F3F4FFF7F3F8EAF3F4F1F4F3F5F7F7F5F7F7
D2DBF4E6F7EEEEF7F8E5E5F8F3FFF8EAFFF4ECE4E1D6D4E1E2F4F8ECF7F0E2F7EEEBF4F8EAF7E5\
F7FFF4D6EDEEEBF4E6EEF4F4F5FFF0E3F7F8F5FFFFF5FFFFF7F7FFECF7FFF5FFFF
FFFFFFF3F4FFFFFFF7F7F7F7F7F7F3FFFFF7FFFFFFF7F7FFF7F7F7F7F7FFFFFFFFF3F4FFF7F7FF\
F1FFFFE4F4F7F7F7FFECF7F7F1FFFFF1FFFFF7F7F7F5FFFFECF7F7DEF4F4D8F4F4
EBECF7F3F3FFF7F7F7EAF2F8E5EBF4FFFFFFF7F7F7FFFFFFEAF4F3F5FFFFF1FFFFE4F4F7FFFFFF\
EAF4F7EAF4F7F7F6FFF7F6F7F7F6F7EBECF7FFFFFFF3F4F7FFFFFFF7F7FFF7F7F7
FFFFF7F3F2F7F7F7F8F5FFFFECF7F8ECF7F8EAF4F4F7F7F8F1FFFFFFFFFFFFFFFFFFFFFFE4F4F4\
FFFFFFEAF3F4E2EBECEEEEF7FFFFFFF7F7FFECF7FFDAE6F0F5FFFFDAE6F0D9EFF8
EEF7F8F7FFFFC6DCE59A899086756AACA0BEFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFE3D4DEE2E0EDE3DCE1B5B9AF9B8F86E3E4EEF2F4F4EBF7F3
F7F7EFF7F7F8F7F7F8EEEFF0FFF7F8FFF7F8E4E7EDECEEF8F1F4F3F5F7F7FFF7F4F1EDE8E2E6E7\
CBDCDCE5E8E8F7F7F8EBF7F8E6EDEEE3E4E6EEEEEEECEFF4ECEFF7F3F2F4E2F4F8
EBEEEED9E6E9DFECEEF2F7F4ECE8E1F5F7F7ECEDE8EBEDE5DEEFECC8D9E3EEEDEEFFF7F8FFF7F8\
EAEBEDEBF7F3EEFFF7F1F4F3E6E6F4F7FFF8FFEEF0EBEEF8F7F6F8F3F6F8F7FFFF
E5EEFFF3EEEEF3F7F8EBF7F4EEEEE9E6E5EED9D9E8CFD9DBEAF7EEE4F4E9F5FFF0F5FFE9EEF7F8\
D6EDEEF3F4FFF2F7F0E5F4EEF7F7FFECF7F0E3F7F8FFFFFFF7F7FFF7F6F7EBECF7
F3F4FFF7F7FFECF7F7ECF7F7FFFFF7FFFFF7F7F6F7F3F2F7EEEEF3F7F7FFF7F7FFF3F4FFECF7FF\
FFFFFFF2F7FFF3F3F3EEEEF7F7F7F7FFFFFFF5FFFFEAF4F7F7F7FFD9EFEFEBF7F8
E2ECE7F7F7FFF7F6FFEEEEF3F7F6F7F3F4F3F7F7F7F7F7F7ECF7F7F7F7F7F5FFFFE4F4F7FFFFF7\
F7F7F3EEEEF3F3F2F7F7F6F7FFFFFFEEEEF7EBECF7F7F7F7F7F6FFF3F2F7F3F2F7
F3F2F3F7F6F7ECF7F8ECF7F8ECF7F8EAF4F4EAF4F4EAF7F8F5FFFFFFFFFFFFFFFFF5FFFFEAF4F4\
FFFFFFF3F2F3F7F7FFFFFFFFF7F7F7ECF7F7DAE6F0ECF7F7E2EDEDE2F4F8D6EDF4
E5E5E8DAE0E2A098957D524BBEAAA5F7EFF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFF7F8E6E0F0F1E8E1E3DCD7818364E3E5F0D9DCE5EEFFF7
E2F4F7EAEDEDF7F7F8EEEFF0FFF7F8EEF7F8D9DDF8F2ECE8F5F7F7F5F7F7FFF7F4F5EFEFEBEDF4\
EBEDEEF3F6F8DFECEEEEF7F8FFF4F8F7F7FFDEE0E8C1C6D3D9DBE2FFFFFFDAEEF8
D9EBF4FFFFFFEAECEDC7DDE7E2E5E2F1F4F3F7F3EDEAEEEDFFF7EFD9E0E9EEF4F4FFF7F8FFF7F8\
F7EEF0DAEEF8EBF7F3F1F4F3E6E6F4F3FFF4F3FFF4DEE0EDDEE6EFEEEEFFEAF3F4
F5F7F7E6E6F4F7FFF8EEFFF0F7EEEEEEE4E6E3E4E8D6E4E3EAF7F0F2FFF8F5F7E8F1FFFFFFFFE9\
E5F4EEE3F7F8FFFFFFE3F7F8D8EDEEE3F7F8E5F4EEF5FFE9F7F7F0F3F3F7FFFFFF
F7F6F7FFFFFFECF7F7ECF7F7F7F6F7F7F6FFF3F2F7FFFFFFF7F6F7EBECF7FFFFFFFFFFFFF5FFFF\
F5FFFFF7F7F7F3F3F7FFFFFFEEEEF7F7F7F7FFFFFFF7F7FFF7F7F7ECF7FFE5F4E5
D9EFEEE6E6ECE3E4ECF7F7FFF7F6F3EBEBF7EEEEF7F3F4F7F7F6F7E2ECF3F1FFFFEAF4F7FFFFF7\
FFFFF3F3F2F3FFFFFFF7F6F7F3F2F3F7F6F7F7F6F7EBEBECF3F3F4FFFFFFFFFFFF
ECF7F8ECF7F8E4F4F4F5FFFFEAF7F8EAF4F4EAF7F8FFFFFFFFFFFFFFFFFFF5FFFFECF7F8F7F7F8\
F7F6FFF7F6F3F7F7FFF7F7FFE3EFEDD1DCDBF3F3EEDEEDE5D0DCD7E2E7E9FFF4F4
D9E4E5BEC4C6715958AC979CF7EFF0F7EFF0F3E8E9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFEEE5F8E2D1D6F3F4F88F8F76D9D4C3CED1D6ECEFEF
F5F7F7EAEDECF3F4F4F7F7F8F7F7F8EBEDEEEEF7F8E3E6E7F5F4EDFFF7F4EEEFF0EEEDF8ECF7ED\
DEEDECD1DCDEDFE7E9FFFFFFE6EDF4DFE0E9D9DCDBF5F7F0DEE5E5CED9DBDFE0E9
DFE0E9D9E0E3D1DDDFE2E4E5D6E1E2EAF4F3F2F3F4ECF6FFF7F6F8DAE4EEE6F4F4EEF7F8FFFFFF\
FFF4F4F7F6F8ECEEEFF5F7F7E6E6F4F3FFF4F3FFF4DEE0EDDEECF7F7F6F4E2E4ED
ECF7F7D9E0E6F2F7E6F3FFF4F3ECF8E6E0E3F2F7F0F7EEF8EEE5E8F2F4E3ECF4EEFFFFF0F1FFF0\
E3F7EECEE4EFEEEEF7F7F7FFF3F3F7DAE5E7F2F7E9F1FFE9F7F7F0F7F7FFF7F6F7
FFFFFFF7F6F7FFFFFFFFFFFFF7F6F7F7F6FFF3F2F7FFFFFFF7F7F8E5E5EFEBECF7F3F4F7F3F4F3\
F7F7F7F7F7F7F7F7F3F3F2F7F7F6FFEBEBF7E6E6F3EBECF3F7F7F7FFFFF7DAEFF8
F7F7F7C6D9E5F3F3F4F3F3F7EEEEF7F7F6F7EBEBF7FFFFF7EEEEF3F3F3F3F3F4FFF7F7FFF7F6F3\
F3F2F7F7F6F7FFFFFFF7F6F7F3F2F3F7F6F7FFFFFFF7F7F8F7F7F8ECF7F8ECF7F8
ECF7F8ECF7F8EAF4F4FFFFFFEAF4F4F7F7F8EAF7F8FFFFFFFFFFFFECF7F8E2ECEDEBEBF4F3F2F7\
F7F6F3FFFFF7F7F6F7EAF3F7D9EDEEEAECE9EAECE9EBF7E9E5E4DECED9DBCBE1E5
ACC3CD87756B8F7B7BFFFFFFF7EFF0F7EFF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3D4DEDAD4DBA3988BE2E0D6CED9D6E3E5F0
E3EFEFFFFFFFEBF7F3EEFFF7FFFFFFEEEFF0EEEFF0EBF3F4E5E5F0FFFFF8EEEDEEFFFFF8DAE6E7\
EAF7EFF2F7F7F5EDEDE6F4F4F7F6F8FFFFFFE2F3F8D8E5E7D9E1E1F7F7F8F1F4EC
F5F7F7EEEDF0E3EBEEF3F2F4D1DCDCECF7F7F5F7F7F2F6F4ECF6FFE6E8E9EEF7F8F7F7F0EBF7F4\
EEEFF0FFF4F4EAEBF0F5FFF8E6E6F4F3FFF4F3FFF4EBECF8EEEBF4FFEEF0F3ECF0
E6E0F4E5E4E3EBF4F4E2EFE5F3F4F0EEEFF0EAF7FFD1D9E3DEE0EEF7F7FFF2F7F0F1FFE9FFFFFF\
F2F7FFEAF3F7FFFFFFF7F6F7F7F6F7F3F3F7ECF7FFF5FFFFF5FFFFECF7FFF7F7FF
F3F2F3F7F6F7F7F6F7F7F6F7F7F6F7F7F6F3F7F6FFFFFFFFF7F7F8F7F7F8F3F2F3FFFFF7F7F7F3\
FFFFF7F7F7FFF7F7FFEBEBF3FFFFFFFFFFFFFFFFFFF7F6FFF7F6F7FFFFF7FFFFF7
D9EDF4DEECF4EEEEF7EBEBF3FFFFFFEBEBF3F7F6FFEEEEF3F7F7F7FFFFFFF7F6F3F7F6F7F3F2F3\
FFFFFFFFFFFFFFFFFFF7F7F8F7F7F8FFFFFFFFFFFFF7F7F8F3F4F4F2F7F8F7F7F8
EAF4F4EAF4F4EAF7F8FFFFFFF2F7F8ECF7F8F5FFFFFFFFFFECF7F8E3EEEFF7F6F7FFFFF7FFFFF7\
F7F6F7F3F2F3E3EFF0D1E4E8ECF7FFEBF4F8EEF7F8D9EFEFEAF7F7EBF4F49BAEBC
968F7C98736AE3D5DFF3E8E9F7F7F8F7EDEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8E3DCEE987D7FDACBBED0DCCDDAD5D6
E5E4E6E3E6E7EEFFF7F2F4ECF3F4F4F7F7F8EBEDEDD6D9DBF7F3F4EEEDF0FFFFF8E5EDEDE5EDE8\
F5F4F7F1EDECF5F4F4EEEDEEDFE0E3EBECEEFFFFFFE3F7FFEBF7F4F1E8E8F7FFFF
ECF7EFDEE5E1C4D5D6B5C6D6D2D1D7EAE5E7F3F7F8E2E5E5ECF6FFE6E8E9E6F4F4E2F7F4E2EFE7\
DAEFEFE6F4F4D6E4EEDEE5E6F3EBF4FFF7F8FFFFFFF7F4F8F3F4FFF3FFF4E6F4F4
F3F4FFF3ECEED6DCDEF7FFF8E4F4EDEBEFF0D9E6F0E2EDF0F5F7EEDEF4EEEAF4F0EBF4F8E2F4F8\
EEEEF7F3F3F7EBECF7F3F3F7F7F6F7F7F6F7F7F7FFF7F7FFF2F7FFF2F7FFF3F4FF
F7F6F7F7F6F7F7F6F7F7F6F7F7F6F7F7F6F7FFFFFFFFFFFFFFFFFFF7F6F7FFFFFFF3F2F3EEEEF7\
F7F7FFF7F7FFF3F4FFF7F6F7EBEBF3F3F3F4F7F7F8FFFFFFF7F6FFF3F2F7F3F2F3
EEEEF7F3F4FFF3F3F7FFFFFFEBEBF3FFFFFFE6E6F3F7F7FFF3F2F3F7F6FFF3F2F7F7F6F7FFFFFF\
EAF3F4ECF7F8F7F7F8ECF7F8ECF7F8F7F7F8ECF7F8EAF7F8F1FFFFF1FFFFF5FFFF
F5FFFFF5FFFFFFFFFFF5FFFFF2F7F8E5ECEDD8E6E8D8E6E8E2EBECF7F6F7F7F6F7F3F2F3F7F6F3\
EAF3FFCAE0ECEBEEF4E2F7F4D1EDF4F5FFF7EBF4F4CBE0E293BEC87FAEC5696D63
7E6D63DACBD6F3E8E9FFFFFFF7EDEEFFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3A6B4B5A19DDAD4C5D0DCDE
D9E4E7DADDE8E3E6E7F7F7F8ECEFEFF3F7F8E3EFEFF5F7F7EBEDEEF7F7FFEEEDF0EAEDECEAF4F3\
FFF7F8FFF7F8FFFFFFFFFFFFFFF7F8E5F4F4D6E1E2EBEDE9F5F7F4F2EFEFE2E8E8
EAEDECEAF7F7FFFFFFEBE6F8EBFFEEFFECEEDEE4E5E3E4E1ECF6FFDEE8E9DEF4F4DEF4F4ECF7F7\
E2FFFFF7F7F7ECF7F7D9DCDBF3ECF8F7F7FFF3F7EEEEF7EEF3F4F0F3F7F8EEF7F8
F3F4F0F3ECF8FFF3EDCBE1CDF7F7F7D1E5EEDEF4F4F2F4E8D9EFF8E5F4F8ECF7F0D9EDF8E2F4F8\
E6E6ECE3E4ECF7F7FFF3F4FFF3F2F3F3F2F3FFFFFFF3F4FFF7F7FFF7F7FFF3F4FF
F7F6F7F7F6F7FFFFFFFFFFFFFFFFFFFFFFFFF7F6F7F3F2F3F7F6F7F3F2F3F3F2F3FFFFFFF7F6F7\
F3F2F3F3F3F7F3F4FFF7F7FFF3F4FFEBEBECF7F7F8FFFFFFFFFFFFFFFFFFF7F6F7
F7F6F7FFFFFFFFFFFFF7F6F7F7F6F7EEEEF7EBEEEDE3EEE2EBEBE5FFFFFFFFFFFFF3F3F4EEEEEF\
EAF3F4F5FFFFF7F7F8F1FFFFF5FFFFECF7F8EAF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFECF7F8DEECEDE2EBECF7F6F7F7F7F0F3F4F0F7F7FFF7F6F7F7F6F7F7F6F7E3EEE5\
F7F7EDDEF4F8F7F7FFFFFFFFE3F7F8E2F4F4C7DDE7C6DDE5B5D4E5E3E5F0936948
E2D1DBF7EFF0F7EFF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F0B3A8B5C8B09ADEDCD6
EBEFE7E2E4E7E3E4E6ECEFEFEAEDEDF7FFFFF3F7F8F7F7F8EAF4F4D9E5E5FFF7F8E3E5E5ECEFEF\
F7F7F4ECF7F4ECF7F7FFFFFFFFF7F8E5F4F4DEE8E8F7F4F4ECF7F7DEE8E8EAEDED
ECE5E7DAE4F4E6E0F8E2E4E8E2F7F4ECECF4DAECE8D9ECECF7F6F8DEE8E9EBF7F8E3F7F8ECF7FF\
E2F7F3EAF4F3EAF7F7D6EDE8F7FFF8FFFFFFF3F4E9F5FFFFECF7F0F7F7E9F5FFF0
ECF7E9E5EDF0DEE7D0C1D1C6F7F7F7D9EDEFF5ECE3D1D4D7E3EEF7EAF7F0F2F7F0FFFFF7F7F7F7\
E3E4EFEEEEEFF3F4FFF3F4F7F3F2F7F7F6F7F3F2F3EBEBF3EEEEF7F7F7FFEEEEF7
FFFFFFF7F6F7FFFFFFFFFFFFFFFFFFF7F6F7FFFFFFF3F2F3FFFFFFF7F6F7F3F2F3FFFFFFF7F6F7\
F3F2F3F3F3F7F7F7FFF7F7FFF7F7FFF7F6F7EAF3F4ECF7F8ECF7F8ECF7F8F3F2F3
FFFFFFF7F6F7F7F6F7FFFFFFF7F6F7F7F6F7E2EBE5F7F4EEEAEFE8E3EEE7FFFFFFF3F3F4F5FFFF\
EAF4F4ECF7F8F1FFFFF5FFFFFFFFFFF1FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFF
ECF7F8DEECEDD9E4ECEBECF7F3F4FFF3F4FFF7F7F0EEEEE7EBEBF3FFFFFFEBEBF3F3F3F7EAF4F0\
ECF7F0E3F7F8ECF7FFEBF7F8E2EFF0BEDCE6C4DCE5DADDDFD9E4F0F5F4ED83543F
F7F6FFF3ECF0F7EFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDAD4E5AC9D9FBEC1B4
E3EEE7E2E5E1E3E5EEE5E5F0F5F7F7ECEFEFFFFFFFF3F4F4DAE6E7F7FFFFE3E5E5EEEDEEF7F4F4\
FFF7FFD9E0E8DEE0E2FFF4F4F7F4F4F3F4F4E3F7FFF2F7F4D6E5E5CBDCDCE5EDE8
ECEEE5D6E0E1D6D9E7E3E5E8DEF4F4E4E0E5EBEFE7D6E7E8F7F6F8EEEDEEEEF7F8F1FFFFF7F7FF\
F7F7F3EAF4F3F5FFFFE2F7F8EBF4EEF7F7F0F3F7EEE2F7F8F5FFFFF5FFFFF1FFFF
F1FFF0F1FFF0C9D4D0D1D4DDE5ECE5EBECF3DEE4E3C4CCD6F7F6F7EEEEF3F7F7F7EBECF3EEEEF3\
FFFFFFF3F3F7EEEEF7F7F7F7F7F6F3F7F6F7F7F6F7F7F6F7EEEEF7F3F3F7F7F6F7
F7F6F7F3F2F3FFFFFFFFFFFFFFFFFFF7F6F7F7F6F7FFFFFFF3F2F3F7F6F7FFFFFFF7F6F7F7F6F7\
F7F6F7FFFFFFF3F4FFE2F4F8D6E8E6ECEFE8E3EEEFF7F6F7FFFFFFECF7F8EAF3F4
E3EEEFF7F6F7F7F6F7FFFFFFF7F7FFEBECEDF7F7F0E2E4DDDEE7DDF5FFFFEBEBE5F7F7F8EAF7F8\
F5FFFFF5FFFFFFFFFFFFFFFFFFFFFFF5FFFFF5FFFFF5FFFFEAF7F8E4F4F4DEECED
E2EBECEEEEF7ECF7F0F5FFF0F7F7FFF3F4FFF3F4FFF3F3F3F3F2F7F7F6F7F3F4FFE2F4F8D1EDF4\
D1EDF4ECF7FFF7FFFFD2E4EEC5DCE8DAEEF8DEEDF3D9DCE3E3EDEDD0BBA58F7878
EBECEDEEE5F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8CEB8C5ADA09D
DED4BEEBDBCAECFFFFE3E5F0D6D9E1EAEDECF7F7F8F7F7F8EBEDEEF1F4F3F1EDECEEF7F8EEF7F4\
F2EDEFDADDDFF7FFFFDFECEEF7F7F8F3FFFFE3FFF8F2F4EEE6E8E9E6E8E9EEF7F4
FFF4FFFFF7F8D6E4ECF7ECF4EBF7F4E4DBDCF7F7F8EAE7E1ECF3F8EEEFF0EEF7F8F5FFFFF5FFFF\
F3F4F7F3F4F7F7F7F7EAF4F3ECF7F7F3F4E9F7FFF8DEF4EEFFFFFFF2F7FFF2F7FF
F5FFFFF5FFFFE3E5E8EBEEF0D8E0D6EBEBF3E2EFF0D8E7EDF3F2F7FFFFFFEEEEF3F3F3F7FFFFFF\
EBEBF3F7F7FFFFFFFFF7F6F7FFFFFFF7F6F7FFFFFFFFFFFFEAF3F4E2EBECFFFFFF
FFFFFFF7F6F7F7F6F7ECF7F8E4F4F4ECF7F8FFFFFFF7F6F7FFFFFFFFFFFFF7F6F7F3F2F3FFFFFF\
F3F2F3FFFFFFF3F4F0E2F4E6FFEEF0DADDE8E4E8DED0DDD7EAF3F4FFFFFFECF7F8
EAF3F4F7F6F7FFFFFFFFFFFFF7F7FFF3F4F0F7F6EDEBEBF3FFFFFFEBEBE5FFFFF0DFE0ECD6E0E8\
D8E6E8DEECEDE4F4F4EAF7F8EAF7F8DEECEDDEECEDE2ECEDEBEBECEBEBF3EBECE7
F3F4F0ECF7F0F7F7FFEAF4F0EEEEF7F3F3F7F7F7FFFFFFF7F7F7F7D9EDF8D8EDEEEAF7EEEBF7F4\
E6F4F4FFFFFFD9E5F0E3E5F0EEF7F8ECF7F7E2D4D6DEEEEDF7E4D2B09A86C2AEB5
FFEFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F0ACAABE
9EA19DBEB2A5EEE0CFEAEDE7D6D9DEF7F7F8ECEFEFF7F7F8F7F7F8ECEDEDFFF7F8E3E5E5EEF4F8\
F5EFEFF7F7FFD6D9DBD9E1E2FFFFFFF5F7F4E5FFF8F7F7F8FFF7F4FFFFF8FFF7F4
F5EDEFEAE4E5E5F4F4F7ECF4E5F4EECDD4D6F7F7F8F7EFE7E4E0E5DEF4F4F2F7F0F7F7F0EAF7FF\
F7F7F7F3F4F7F3F4F3FFFFF7EAF4F7ECF7F0F3F4E9F2F7F0F5FFFFF3F4FFF3F4FF
F7F7F7F7F7F7F7F7F7EAEFDFD8E0DDF7F6F7E3EEF7F5FFFFF7F7F7F7F6F7FFFFF7F3F3F7EEEEF7\
F7F6F7F7F6F7FFFFFFF7F6F7FFFFFFF7F6F7F7F6F7F3F2F3E2EBECEAF3F4F7F6F7
FFFFFFFFFFFFF3F2F3ECF7F8E4F4F4ECF7F8FFFFFFF7F6F7F7F6F7F7F6F7F7F6F7F7F6F7F7F6F7\
F3F2F3FFFFFFF7F7F0EAEDE6E6ECEFE6ECEFDAE5F7C7D5DFE3E5DFF7F6F7FFFFFF
FFFFFFF7F6F7F7F6F7FFFFFFFFFFFFFFFFFFF7F7FFFFFFFFEBECEDE6E6E5F7F6F7F7F7FFF7F7FF\
EAF4FFE2ECEDE6E6E5DFE0ECE6E6ECEEEEF7EBECF7EBECF7F7F7FFF7F7FFF7F7F0
F5FFFFF7F7FFECF7E7FFFFF7F3F2F3E6E6F3F3F4FFF7F7FFE3EFF0EAF7EEEEF7F8E2EDE9EAF4F0\
EEEFF0DAE4EEECEEF8EEF7F8E5F4F4D1DDE7D6DCE2F2F7F4C9B6A9B9A391DECDDB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F0
C8B2B695989DD6CBB5D0D9D6DAEEF8DADDDFF2F4F4F3F4F4F7F7F8FFF7F8ECEFEFF5F7F7FFF7F8\
FFF7FFF2EDEFECE8E1F2FFF8D6E1E1F3ECE5D2E6EED9E6E9E3E5F0F7EDE5EEE8E2
E3E1DCEADCCBEAF3EDE5E0EEDEF4F4C4CDD0FFFFFFF7F7F8E4E0E1DEEDEEF2F7F0F7F7F0EAF7FF\
F7F7F3F7F7F3FFFFF7F3F4F7FFFFF7ECF7F7F5FFFFF5FFFFF5FFFFF7F7FFFFFFFF
F7F7F7F7F7FFF7F7FFECF7F7EAF3F7F7F6F7F3F2F7EAF4EDEAF4F0FFFFF7F3F2F7EBEBF7F7F7F7\
F7F6F7F3F2F3FFFFFFF3F2F3F7F6F7F7F6F7F7F6F7F7F6F7FFFFFFEAF3F4E3EEEF
F7F6F7FFFFFFF7F6F7EAF3F4E4F4F4ECF7F8FFFFFFFFFFFFFFFFFFF7F6F7F7F6F7FFFFFFF3F2F3\
F7F6F7F7F6F7F7F7FFF5F7E8D6E1D7EBE0F8F5F7F0E5E5E8AABAC4D1DCCEEBEBF3
F7F6F7F7F6F7F7F6F7FFFFFFF7F6F7F3F2F3F7F6F7F7F7FFF3F4F0F7F7F0F7F7F0F7F7F0FFFFF0\
F5FFF0F5FFE9FFFFF0FFFFE9F7F7F0F7F7FFFFFFFFF7F7FFE3F7F8D6E8E6D9EDE6
EEF7F8EAF4F0F7F6F3F3F2F7F7F7FFD1DDE7D1E5EED1EDF4F2FFF8E2EDE9DEEDE7EEF7F4C4DCEE\
C5DCE8E5F3F8FFFFFFDAEFF8C8DDE5D9E4EEFFF7F8F3E4CFB09A88C5B0ADEEE5F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7EFF0ACA9BD9C8D89B5A184CFD9CFD0DCDFD9DCE6F3F4F4F3F7F8F7FFFFFFF7F8F7F4F4F5F4F4\
F1E8E8ECEFEFF2FFF8DEEDEFCBDCDCD9E5E5D9EBF4D9EBF4F3F3F4E6EEE8F7F3E5
FFF7E7E6EFEDE3E5E7EADDDFFFE6E9D8D9DBF3F4F4FFFFFFEAECECE3E4E8F7F7F0EEF7F8E3F7EE\
ECF7E7F7F7F7F7F7FFF3F4FFF7F7F7F3F3FFE3EEF7FFFFFFF5FFFFF7F7FFF7F7F7
FFFFF7FFFFF3FFFFF7FFFFF7F7F7FFEBEBF3F7F6FFE3EEE5F5FFF0F7F7FFF3F2F3F3F2F7FFFFF7\
F7F6F7F3F2F3FFFFFFF7F6F7F3F2F3F7F6F7F7F6F7FFFFFFF7F6F7EAF3F4FFFFFF
E3EEEFF7F6F7F7F7FFDAE5EFDEECEDFFFFFFE4F4F4ECF7F8FFFFFFF7F6F7F3F2F3F7F6F7F3F3F7\
EBEBF3F7F6F7F7F7FFF7F7FFD9DCE3DAD5DFE5E6E7DFDDD2BFC5D6EAECE6B6BDB6
B0AAA6CEC9C9F7F7F0ECEFE8DEE4DBDEE6E5F3F3F7FFFFFFF7F6F7EEEEF7F3F4F0EBECE7EBECE7\
F3F4F0F3F4F0F3F4E9F7F7E9F5FFFFF1FFE9F5FFF0F7F7FFE3F7F8D6E8E6D6E8E6
D9EDF8F5FFFFD1D9E6BEC1D1C2CCD7E2F3F4E3EFF0D8F4F4F5F7F8CBDBE9B0CFE2D6E1E5ECF6FF\
DAE5F0FFFFFFDFDCDED0E1DCE3E4E7F2EFE7CEB29B936754A4888ADAD5E7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8D1C2D6A3878DBCB0A1EEF7EFDAE5E7E3E5F0EBF4F4EEEDF0F7F4F8F7F7F8F2EDED\
EAEDECF5F4F4F7F7F8F7F7F8E6EDEEEBECEED9EBF4E2F3F8EEF7F8DFE7E9D1DCDE
D9E1E1D1DCDCD6E1E1ECDDDFFFE6E9D8D9DBF3F7F8EBF4F4F5F7F7EBEBF4EBEFEEFFFFFFEEF7EE\
F5FFF0EAF7FFECF7FFFFFFF7FFFFF3F7F6FFF3F3F7EAF7FFF1FFFFF3F4FFFFFFF3
FFFFF7FFFFFFFFFFF7FFFFF7F7F7F7F7F6EDEBECE5E6E6ECF7F7FFF3F4FFF3F2F3F7F6F7F7F6F7\
F7F6F7F7F6F7F3F2F3F7F6F7F7F7F8F7F7F8F7F6F7FFFFFFFFFFFFF7F6F7DEECED
E4F4F4F7F6F7EEEEF7FFFFF0EBEBE5ECF7F8ECF7F8ECF7F8E4F4F4EAF4F4F7F7F8F3F2F3F7F7FF\
F5F7E8EAEDE3F3F4F0F3F4E8FFFFF8D9DCE3BEBAAFEEF7ECBDC8DEE3DBCBD9E0F3
E5D9D6CFDDEDB6BDD0D6D9E2EEECF8E3E5E8DEE4E3D6D9DEDEE0D7E5E7DDF7F7F0F7F6F7FFFFFF\
F7F6F7FFFFFFFFFFFFF7F7FFEAF4F0E4F4E9EAF4F0EBECF7F7F6F7D9EDF8D1E8EE
D1E1E9D6E1E9DAE4EEECF6F4D9DCDEC4D9E2F7F7FFD8EDEED0E5F0FFFFFFE4EBF8ECECF4ECF6FF\
ECEEF8E6F4F4E2E0E1DAF7FFEEE5E7CDBBA57E6D64D1BABDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD1C2CE7A6968F7FFF0EEF4EDDADDDFECEEF8EEEFF8EBF4F8F3FFFFFFFFFF\
F7F4F4F5F7F7E4EDECEAEDEDECEFEFD1DCDED9E6E9EBF3F4EEF7F8E6EDEED6E1E2
D1DCDCD1DCDCD6E5E1E4E4DBECE0DBDEE0E1EBF4F4DEE1DCF5FFF8F7F6F8F7ECEEEEF7F8E6F4F4\
EBF7F8F5FFFFEAF7FFF3F3F3F3F2FFF7F6F3FFFFF7EAF4F7FFFFFFECF7FFF7F7F7
FFFFF3FFFFF7F7F6F3F7F6F7FFFFFFF3F4E7DFE0E1EBECF4EEEEF7F3F4FFF7F6F7F7F6F7F3F2F3\
FFFFFFEBEBECEEEEEFF7F6F7EBEBECEBEBECF3F2F3FFFFFFFFFFFFF3F2F3E2EBEC
ECF7F8FFFFFFF3F2F3F3F4F0E6E6E5FFFFFFECF7F8E4F4F4ECF7F8F5FFFFEAF4F4F7F6F7F3F2F3\
DEE4DBEBF7EFE2EDD6F1F4E8E4E8E2E2E5D0CBCFD7D1DCDEDEEBE5EBEFECBFCBDE
F5F4EED6CDDCD6C8D6DADCEDEEEEFFFFF7F8FFF7F8EEEEFFEEEEFFDEE0F8D9DDE8E4F4E9E2ECE7\
EBECE7F3F4F0F7F7FFFFFFFFF7F7FFF3F4FFEAF4FFD1E7F4D1E4E5D9F7F4EEF7F4
EEEEF8F7F3F4EAECF8D9E4F0ECF4F4BCE1E5D6E5EEECEEF8FFF7F8ECECF4ECF6FFE4E6F4ECEEF8\
EEF7F8DAEFEFD1DCE5EEEEF8ECD4BC957B72C8B0B4F7F7F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8826F81B0A795EAF6EDF3F4EDE3E5EFE4E6F4E2E4EEE5EEEEF2FFF8\
FFF4F4F5F7F7ECF7F7F5F7F7ECEEEFEAE5E7F5EDEFEEEFF8EBF4F4EBF4F4E6F4F4
E6F4F4EEF7F8EBECF4DFE0EED9E5E7EAF4F4EBEDEEEBE8E2F1F7F4FFFFFFF3EBEEF7F7F4F7F7F4\
E3EFF0EBF7F8F5FFFFDEE6F3FFFFFFF3F2F7F7F6F7EEEEF3EAF7FFF1FFFFF7F7FF
F7F7F7FFFFF3F7F6FFF7F6FFFFFFFFF7F7F7F3F3F7F7F6F7EBEBF3FFFFFFF7F7FFF3F2F3F7F6F7\
F7F6F7EBEBECF5FFFFE3EEEFFFFFFFFFFFFFFFFFFFF7F6F7FFFFFFF7F6F7FFFFFF
F7F6F7FFFFFFF3F2F3F7F7FFF3F3F7F7F6F7ECF7F8ECF7F8ECF7F8ECF7F8ECF7F8E4F4F4ECF7F8\
E3EEE7CEDCCBE4E0E8D6D9EFF7F6EFE2ECF8EAF4F7DFD4E5D9CCCBE5E5E8F5F7EF
BFC2D3D6BDB3DAC9CBEEEEFFFFF4F4EEE4F4FFECEEEBF7EEDEE5EEEEE0EEF7EEF8F7F4F8F5F4E6\
F1F7EEF5FFE9F2F7FFDEEDF0D6E5E9D8E8E9DEE8E9EEEDEEF7F4F8F3F4EED6EDEE
D6E0E3EBF3F4F7F7FFEBF4F8EEEDEEECF7F8ECFFFFECF6FFECF3F8E3DCDED9E0E2E6F4F4DFDCDE\
D9D4D6E3E7E8E6ECEEEAD1BE997663AC989DFFF7F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD9CCDE9A7F859F9F8DFFFFE8F3F7F4EEF7EFF1F4FFD9EBF4DEF4F8\
E6EDEEEEEDEEF5EFEFECF7F7F7F6F8EAEEEFF5EFEDFFF7FFF7FFFFF7F7E7E5ECE2
D9E6E9E3EBEEEEF7F8DFECEEF7FFFFE5EFEEECFFF8ECEFEFFFF7EFF1F7F4EAEEEFF3EBF4F3F3F8\
FFF7F8E6EDEEFFFFFFE2EEF7EEEEF7F7F6FFFFFFF7F7F6F7EAF4FFF5FFFFFFFFFF
EBECF3F7F6F7FFFFFFF7F6F7F7F6F7F7F6F3F3F3F7EBEBF3F3F2F3F7F7FFFFFFFFEBEBF3FFFFFF\
F3F2F3F7F6F7E3EEEFECF7F8F7F6F7FFFFFFF7F6F7F7F6F7F7F6F7FFFFFFF7F6F7
F7F6F7FFFFFFF7F6F7F7F6F7FFFFFFF3F2F3ECF7F8ECF7F8FFFFFFECF7F8E4F4F4E4F4F4ECF7F8\
ECF7F8DEECEDABBBC6D9DDE6E3D9DCEBF4E8E5ECEDE6EDE1ECECF4CBCDD5BFCBD6
FFF7E7D9F2F3D1DCDEC4BEC1ABB0CBABB0CBD2C8C6D6D4CBCDD4D6DADCD6D9DCDCCBD4E1B8C8E1\
BDC6DBC3CFD0C3CFC6D9DBDDF3EBF4FFF3F4E3EDEED8E8E9D1E1E2DEEDEDEEF7F8
DEEDEEE5E5E8F7EEF0FFF7F8FFFFFFF7F6F8F3F2F4F3F2F4E2E4E5DAEEEFF7F7ECFFFFF7EAE4ED\
ECEBEEFFFFFFD6CAC6906462A39095F7F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F8E2D4DE877483A8B09CECEEE7F7F7F7E3EFEFEAEBF4FFFFFF\
FFFFFFEEF7F8EBEFF0ECEFEFEAF4F3F7FFFFF5EFEFF5F7F4EBF7F4E6F7EDEBF6ED
F3F2F4D9EBF4F5FFF8E3E6DBE3EBE2D9EBF4DEE5E6ECEFEFFFF7EFF5F4ECEAF4F3F7FFFFF3F2F4\
FFF6F8EEE5E8EEEFF0F5FFF0E3EEE7EEEEF7F7F6F7F7F6F7F7F7FFF2F7FFF5FFFF
EBECF3FFFFF7F3F3FFEEEEF3F7F6F3F7F6F7EBECF3E6E6F3F7F6F7F7F6F7F7F7FFEBEBF3FFFFFF\
F3F2F3F7F6F7FFFFFFF7F6F7FFFFFFF7F6F7F7F6F7FFFFFFF3F2F3FFFFFFFFFFFF
FFFFFFFFFFFFF7F6F7F7F6F7FFFFFFF7F6F7F7F6F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F6F7\
E3EEEFE4F4F4EAF3F4C8C3C6D0CCCCEAEEF4EADBF8EADBF8DADDEFEBF4E8E3E5FF
B5BCD6A5AFCBCAC5C8DED9CBCED9DBD6E7EEF7F3F4D9E0EEE6E8F4D9DCF8E2E4FFF7F7FFF3F4F4\
EEEFEEF5F7EDEAECE1D9DCE5DFDBE6DEE4E6FFFFFFD8EDEECBDBDDADCDD7C3D4DB
E4E0E1EAECECEAECECD6E6EDD6E6EDEAECECF1F4F3EAEDECE3F7FFF7EFE5EEF7F4FFFFF7E4F4F7\
F3F4F4F3F2F8978870A88A8AF7F4F4F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDAC3CFA3868AACA083F7E5CFEBF4ECEAECF8F3F3F4\
F3F4F4EBF4F4F3F7F8F7F7F8F7F4F4F1EDECF2F7F7F7EFE7EBEFEEEBF4F4E2F4F8
E3F7FFD8F4FFD6E6E5FFFFFFEEF7F0EEF7DBFFEEDFE3E4E6E2E5E5F5F7F7F5F7F7F7FFFFF5F6F4\
ECFFF8FFF6F8EBEDF0EBF4F8E2F4F8D9E4E7F7F6F7F3F2F3FFFFFFEAF4FFF7F7F0
E2EFE7E3EEF3F3F3FFF7F7F3FFFFF7FFFFF7F7F7FFEBEBF7FFFFFFF3F2F3F7F7FFEBECF7EEEEF7\
F7F6F7F7F6F7F7F6F7F7F6F7ECF7F8ECF7F8F3F2F3FFFFFFF3F2F3FFFFFFFFFFFF
FFFFFFFFFFFFF7F6F7F7F6F7FFFFFFFFFFFFF7F6F7F7F6F7ECF7F8ECF7F8FFFFFFFFFFFFEBEBF3\
EEEEF7F3F2F3F3F2F3FFFFFFBECBD6B6C2D3D9D5DEF2E5F4FFF7F8DEE6F4D6DBF4
D9C8D6DFD9DCE5E6F8E3EEF8D8E0F4C3C8D1A8B0B597ABB5A3B7BAA9BDC0BCC8D0D1D9E1DEE4E5\
E4E6E8F2F3F4F7F6F8E3E4F4D9DBE6D2DBDED9E0E3F3EBEEECEEEFE5EFECEBF7F4
FFFFFFFFFFFFFFFFFFEEFFF7EEFFF7EEFFF7EEF7ECF7EDE1EBEDE5EEF7F8E6F4EDE3EFECD1DCE5\
DFE0EEF3DCD6754E39E3D5DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDAD5E79388A167585A82796BC6CCC5EEEEF8\
E6E6E9E3ECEEF3F7F8F7F7F8F7F4F4F2F7F7DEE8E8E2EDEDEBEFF0F3F7F8EAF7F4
FFFFFFFFFFFFD9EBE5EEFFEFFFF7DFE5EFEDE5E5E2F7EED7DADDDFE2E5E5F7F6F8F3F6F8ECF2F8\
F5FFF8F3F2F4EBEBF4F3ECF0F7F7FFD9EDF8BECFDDCAD9E6ECF7FFF3F4FFECF7F0
F5FFFFE3EFF0EAF4F7F3F4F3F7F7F7FFFFFFF7F7F7E5ECF3E3EEF7F7F6F7EEEEF7F3F4FFF3F3F7\
F3F2F3F7F6F7FFFFFFF7F6F7E3EEEFECF7F8F7F6F7F7F6F7F3F3F7EEEEF7FFFFFF
FFFFFFF7F6F7F7F6F7F3F2F3FFFFFFFFFFFFFFFFFFF7F6F7E2EBECE2EBECF7F6F7F7F6F7F3F3F7\
F7F7FFFFFFFFF7F7FFE5E7E6DEE7DDEAF7F0E5D5DFCACAC9C4D1D6DADDEFF5F7F0
F1F4E9EAECEEEAF4E5FFF3E5DEECEFC3CDDDB6C2CBAFC2CBA9BDC0B4BDBACDC8CBD6D9E1D8E0E1\
D1D4D6DEDBDCF1E8E8F1EDECF2F7F7F3FFFFF2F7F7F5F7F7F1F4F3EAF4F4E4EDEC
EAF4F3E4ECECE4E0E1E4DBDCE4DBDCDAE4E8EEF7F8EEF7F8D6DCDEB5C8D1C4CFDBE2ECF4DED0CE\
BEA685815E47907E7CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7EFF0AC979C716156DEEFEF\
ECFFF4F3F2F8EAECF4D6D9E3E5E4E6F7FFFFF3F7F8F7FFFFF3F4F4F7F7F8EEEEF0
D9EBF4E2F3F8F3F2F4EEFFEFEEFFEFECE6E7FFF4DEECEDDBF7F6F8CECDCBF5FFF8F7F6F8FFFFFF\
F3F2F4F7F6F8F3F2F4F7F6F8FFF4F4F7F7F4EBECF8F2F4EDC4D1CBE2EDD7F5FFFF
E2E4E3EEE5E8EAF4E9EAF7F0EAF7FFECF7FFEAF4F0FFFFF0EBEEF7EBECF4EEEEEFF3F3F7F7F7FF\
FFFFFFF3F2F3FFFFFFF3F2F3F3F3F7EBEBF3F7F6F7F7F6F7EEEEF7F3F3F7F7F6F7
FFFFFFF3F2F3F3F3F7F3F3F7F7F7F0F7F7F0FFFFFFFFFFFFFFFFFFF7F7F0EEEEE7F7F6F7F7F7FF\
F3F4F0EAEDE3F5F7E8EAEDE8E4EDE3ECF7F0EBE5F8D1D4E6E5E4EED9DDEDC3CFEC
DADDEFF5F7F0EEDDDEE4ECE7CBDBEEBCC6D0BDC8CBBCC8D3B1BDCBB4BDBAC9C3CBBEC3D0B0C3C6\
B9C2C5BCC2C5B6BDC6B0BDCBD1D4E2F3E6F4E2E0EDD6D9DED9D9DBECECEDF3FFFF
F3F6F8FFEEF0FFF7F8F7FFFFEAEEF8DAE5F0D6EDEDD6EDECD1D9E2FFFFFFF7EEFFEBE6DEA18674\
9A7E7BD9C2CEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF755865DAC49D\
E3E8E1E2E4EFEAECF4E5E6EEEBECEEEBF7F8F7F7F8F7F7F8EBEDEEEBEDEEDEECF0
DAEEF8F7F6F8F7F6F8EEFFEFDAEFF8E4E8ECE3DDD6DED4CAD1C8BEC6B8ABDEE4E7FFFFFFFFFFFF\
F7F6F8FFFFFFF3F2F4F7F6F8F7F4F8FFFFFFF3FFF4ECE5E7F7F7E7CFDCDBDEE4E3
EBE0E6F7EEF8F3E6F4EBE0E6EBE4E3E3EFF0F7F7F0F5FFF0F5F7E8DADDD7EBECF4E6E6F3F3F4FF\
F7F7FFEEEEF7F7F6F7F7F6F7EEEEF7F5FFF0E3EEE7F7F6F7F3F2F3F7F7FFEEEEF7
F7F6F7F3F2F3EAF4F0EAF7F0F2F7E9F7F7F0F7F7F0F7F7FFF3F4F0F7F7F0E2E4EED9DCE8FFFFFF\
F7F7F0F1F7E8EAF4E8E2E5D4F7F7F0ECF7F0D9DDE3DEDBE6EEEEFFEBE4F8EEE5F4
CFDDEFC3C8D1CFD9D0E3E4F8B6C2D0CDD9D0F1F7E3F7F7FFF2F7F0FFFFFFF2F7F0F7F7F0EAF7F0\
F2FFEEF5FFF0D6EDEED1E1E9D9EDF8F3F7EEF3F7EEEBF4F8E5E4E6EAEEF8F5EEEE
F7ECEEECF6FFE4E6F4D9E6F4D6CBD7EBE4E1E4F4F7FFEEF0E3ECF0EBEEF8EBE6DEAC867C907E7C\
E2D4DEF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFACA0BE907574\
D1CBB5DADDDFDADDE7FFFFFFEBEFF0F3F7F8F7FFFFF3F7F8F3F4F4FFF7F8F2FFF8
D9ECF0D9EBF4DAEEF8FFFFFFE4E8ECFFF7F0F3EBE1EAF7F4E5E5ECC4C1B4E3E5E7E2E4E5F3F3F4\
F7F7F8F7F6F8F3F2F4F7F6F8F7F7FFF7F7F4FFFFFFF7FFF8ECE5E7E5E6EDF7F7FF
EBEEF8F3FFFFF3FFFFF3FFFFEBEEF8E3E0E6E3E5E8EAF7F0F2FFEED9E5E8BECBCBF7F6EDE3F7F8\
E3F7F8F7F7FFF7F6F7F3F2F3F7F6F7ECF7F0F5FFF0EBECF7F3F3F7EAF4F0ECF7F0
EEEEF7F7F7F8DAE5DFEAF4FFE5EDD7E2EDE5ECEFE3FFFFFFF2F4E3F5F7F8E2E5F8F2EFE2D1CCCF\
ECF7F0F5FFF0D9D9E1CDD4EDCACAC9D6E1D0EAEDDEF5F4E6FFF7F8EEEEFFE2E4F4
FFFFFFFFFFF0E3E5F8C9CDD0CDD9D3E5ECEFE6E0F8D6D4E6D8E0E3E4F4E9D1E0E3D2D4DEEBE0E6\
EBE0F4EEE7F0F7F4F8F7FFF8FFFFFFE5E0E2DEDBDDEAEBF4F5F7F4EAE6EEFFFFFF
E4E6F4DAE5E7E6F4EDF7EDE5EEECF4F5EEEDE3EFF8F3EBEEFFFFFFD9CBBD9F8370907E7CE3D5DF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB5AAB6\
8A7978ACA894DAD1CBD9EBF4E3E4E6F7F7F8F3F4F4F7F7F8FFFFFFF7FFFFF7F7F8
EEEDEEF5F7F0F7F6F8DAEEF8ECEDDBECEFF4F7ECDEE2EBE8E3F3F4D6D4D7E6E0CCD9DCDEE3D5D7\
F3F3F4FFFFFFECFFFFECF7F8F7F4F8F7FFF8F7F7F4F7FFF8F3FFF4F7F7FFEBECF8
EEEEF8F5F7F7F5F7F7F7FFFFF2F7F7EAF4F3D6D9DFEBE5E6EBE4EED2C8CBDAD1D6C7C3BCD9EDF8\
EBF4F8E4F4E9EAF3EDF7F6F7ECF7F0D6EDEEE2F4EEECF7E9E2EFE9ECF7F0F1FFE9
F2F4E8D9DCD7EBECEFE2ECEDD1D9CDEEEEFFE3EFD7EAEDDEECF7F0E3DDD6DED1C8EEE5F8F5F7EE\
E3DCD0F7F4F8E3E5EFE5D5DFE4E6E5CEC1C8C4C8D2CAD4DBD9D4D6D9D9E7D6E0F8
DEE0E5E4EDE7EAF4EEEAF4E3F2EEEEE6DBF4E6E0F8EBEEFFE5ECEDD8DBE1F2F4F7F7F6F8FFF6F8\
FFF2F4FFF6F8ECF6FFEAEBF4EAE4E5FFFFFFEAEBEDECF6FFF7ECE8D6DBDCD6DCDB
E6EDE1EEF7F8ECF7FFDEF7F4C5E4F4D9CDD3F7E0E2F7F6F8D1BBAD7E6C629F8A92E2D4DEFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
DACCD790878CA89874C7D1D2DEE0ECD1D4DEF7F7F8F2F4F4E4E8E8EAEDEDF7FFFF
F7F4F4F2F4EEF7F6F8ECEEE7E5EDE8ECF7EEFFFFF8FFF4F4FFFFFFEAECEDDEDCD3E2E4E7CFD4DE\
D0D3D6ECEBEDECF6F8ECF7F8F7F7FFF7F7F4F7FFF8FFF7F8FFFFFFF3FFF4F3EEF4
F3FFF8ECE5E7FFFFFFEAF4F3ECF7F7FFFFF8D9E4ECEBEEFFEEE5E8F2EFE7C9CCBEB5C2CEDADDC7\
EAF7E9FFFFF0E2EEEDF7F7FFE3EEE7D9EDF8ECECF0F2ECF4F7ECF4EEE5F8F2EFE2
F2F4E2EBECE8D6D9D0D6D9C8CED0DFECE5D2DAD4D2DFD9E7E5D5DFDFD4D5D9DCE2BFB0B4D1D5E7\
C4CFDBBDB5ABD9CCCED9DDEFB6BABDCFC6B2F2F4EDEEECEECBE0F8DADDDFF2EDE1
DEECEFD8E0E7D1DBE8D9E0EFD9DBEDCBCFE8CBD4ECE3ECF7F1F4ECFFFFF8EAECECEAF6FFEAF6FF\
F3F2F4EAEBEDECECE8F5F4ECF5FFF8EAF3F8D1DBDCCAD1DBD9E0E8F7F4F4F7FFF7
EEF7F4EBE5EDEAECEDF7EEF0D6DCE8DEF7F7F7EFEFFFF6F876594BB5AAAEF7F4F4F7F7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFDACCE7AC8F8DACA081D9D9B6CEC9C5E5E5E8EAEDEDEAEDECFFFFFFF5EFEF
F7F4F4F5F7F0DEECF0F7F6E7E5EFE8ECEFEFFFFFFFF7ECE5EBEBE1F3F3EDF3EBE1D1E0E5DEEBF4\
EEEFF0D1DCDEDEE4E5E4E6E8EAE4E5F7ECEEF7FFF8FFF7F8F7F7FFFFECEEFFF7F8
EEE4F4E5E5F8EAE4E5EAECECF5F7F7F7F7F4EAEDEFE2EDE8E4F4E8D0DDD7D9E6E2DFDCD6C4C9D4\
F7EFE7ECF7F0F5F7E8E3E5DBF7F7F0D9E4E7E2E4E8FFF7F8EEEEFFEEE4EDEBE5F8
E6E0F8EBE7E7EAECE8D6D9E8EBF4DBDECFC8E2DCCBFFF6EFE5F7EDDEE7EFD1CBBCEEE7E9FFE6DB\
CAC9CCE4E5D3A8B0C1A8AEB2C4D1D0E2ECE6D9D4E1C8C9D0CAD4DBE3E4E6F5F7F4
FFFFF8F5F7EDF1F4ECFFFFFFFFFFFFF1F4F3F1F4F3F5F7F7F1F4F3FFFFFFF5F7F7F5F4ECF5F4EC\
F1F4F3F5F7F7FFFFFFF7F7F8EBEDE5D9EFEFE5EEF4FFFFFFF7E5E7F7F4E8F7F7EF
EEFFF7D9E4E7DAF7FFEBECF0E2E7EEC7D1DBDEE0E5C2C3B6724640FFF7F8FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFDAD5E7AA97AC9B988DA2A087D9DCE7DEE0EEE5E5F0ECEFEFF5F7F7
ECF7F7E2EDECDEE1E2EEFFEFE3F2F4E3E5E7ECEDE1F3EBE7F3ECE5F3ECE5F3F3EDBFCAD3C4CCCD\
EAECEDEEEEF0E3E4E6EBEDEEEAEDEDD8DBDCCACDD6DED9DEF3F6F4F3EBF4F3F6F8
E5E4F4F7F7FFF3F7F8EBEBF4E2E5E5F7F7F4F3F4F8EBEDF8F7F7FFDEE8EDC8CCDFEBEDEDE3ECDB\
ACBBC7D9E1D4EEF7F8E3EEF0C8D3DEF2F3E6EAF4F0D6DCE6FFEBE8F7EFE7EAE7E7
F5F3EDF7E4EDE4E0EFF2ECDBDECCDBD1C3CFDADDD7E3D4DFEAE5F4F3EDDCE4DCE1F7E4DBEEF3E8\
D1CDBDC7D9DCCBE0D7DAE0CBE6E0EEABBBDBC2C5CBEBDCD1EAF4EDFFF7F8F7F4F8
F7F7F8F1F4ECF7F6EFEAECF4F2F4F4E4E8E8E4E8E8DEE8E8DEEDEDEBF4F4F3F4F4EBEDEEE6E8E9\
E6EFF0E6FFFFE6F7F8D9F7FFEAF7EDE5F4F4D2E0E8EBE0DCFFF7EFFFFFFFECF7FF
E4F4F7D1DDE7FFEEF0D1DDE7DEE4E5F7DDD7958A78685150B5A0A5FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFEEE5F8CEBDD687746B898360A0A686CEC9B2CACDD4D2D4E3
CED9E2D1E1E1CFD1DBDAEEF7EBF6EDF3F2F4ECE6D6DED5C4DED9D2E3DDD6DEE0DDE2E6E5F7F7F8\
E2D9CFDED5CFE3DDDFE5E6EEE2E4EEE3E5F0D8DBE2BCC2C8A2AAB9A9B0BFC3C8D1
CAC6C9CAC8D1D1D4E1F2ECF4D9E6E7EAF4EDF3F4F8EBEDF8E3E4F0EBEBEED9DCDECAC6C9EAE4E5\
E2EBF4CBC8D1CEBAA7E3CEBFE3DCE1AABCCBA4B6BAFFF7DFCBE1D6CABCC5F2E4DB
ECDDE5E4E0F8F7E5F8ECEEE7EAE6D6DADDD7FFEFDFD6E7EED6D9D0EAEBE5E3E4DDD0DDDBD6DCDB\
E3DCCEF5EDE5EADCCBF5ECDBD6E6EEF7F6F8D9E7EEF1FFEEECFFF8F7FFF8F7F4F4
FFFFF8ECEFEDEAECF4E3E5FFF7F7F8F7F7F8F3F4F4EBF4EDEEF4EDEBF4F4F3F4EDF7E8DCE6DCD1\
E6EDE8E6FFFFEEF7F4ECF4ECFFFFFFD6F4F7CBEDEFD6DCDDDEE0E1D1E0E8DEE7E8
F2ECE5C3EDF7C3DCE7BFB6B2553B314121197F6569D1BBC6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDAD5E7CEB9C3A2A0A3A8A79BD1D4B4E2E5D1
E3E5D6F7EEF0EAE6EEECEEF8EEEEF0EBECEEEBEBEED9EBF4D9EBF4DEE0E1ECFFE9E2ECF4E3F7F8\
E2E6E5F7F3EDECE5E5EAEDE8DEE0DCDED9D6F7F4EDFFFFF8FFF7F0F7EFE7EAEDEC
DEDBE1D1CDD0CED1D4CED9DBD6E5E1EAF4EFF7F7FFF7F7FFEBECEEDAEEF8FFFFFFF7F3DEE3D9BA\
EBE7D4F3F2E5E5F6F7CED9E2D0CCD3E3F3F4F3E5E5B3B8AEC4D1D0CECBCBD6CCCB
E3E0E6EAF4EDEAE0E7EAE0E7F7EDE7F2E4DEDEE0E2DADDD7EEF7EFEEF7F0EBF6E1D9E7EEECF4F0\
EBEDF8E2E5E7F7EDE5ECFFF8E3E4E6E6E7E9F7F7F8E6F4F8EBEDF4E6E7EEDFE4EE
EBF7F8EBF7F8E6F4F4EBFFFFF3F4F4EBF7EFEEFFF7EEF7ECFFF7EFE6FFF3EEFFF7EBF4EDF3E8DC\
EBF4F4D6F7F7DEE4EDEADBDCE3E7E8F3F4F4E3E4EED2DCE8DEE5EEECF6F8E5EBF4
E2E7E8D8EDE77A867A736458BEA9A4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8DACCD7BCAEB29E9589B4B5AD
B9B8B4C1CDC8E2E5E5F3F2F4F3F3F8EBECF4F7F7F8E3F7FFDAEEF8DEE0E1FFF7EEF7F3EDEAF3ED\
ECF7F8EEE4DEE6E0D6EEE5DFF3F4F4F7FFFFF7F4F4F7F7EFF7EDE5F7F7F8F7F4EE
FFFFF8F7EFE7F5F7FFDEDBDCCAC6D0BEC3D1D2D4DBEEEEF0ECFFF8E5EEEEEBEBEEEBEED3E5EDEE\
E3DDDFF7ECCBEEF7F0E5E5E2DEECE6D2DCD6D9EEE5E3E5EED1C9C8DACCCDBDC2D6
E3DBC9EAF7E6ECEEF8FFF6EFECF3EDEAECE1F5EDE5D1ECF8F7EED7E5EFEDE2DCDEEEEDE5F3F7FF\
F7F7F8F7F7F8EAFFF8E5F7F4EBEDEEF3F4F4F7FFFFEBF4F4E6EDEEDFE7EEDFE4EE
E6F4F4E6F4F4E6EDE5DEEDE8DEF4ECE6F4EDEEF4EDFFF7EFEEF4EDEBF7ECF7F7ECF7F4EDE2FFF8\
EAF7F7E4E5E5F2F7F8F2F6F8F3F6F8EEEBF4FFF6F8D9E0EED6D9E6D9E0E8D6DCE5
DEF7F88A7958876C68D1BAC5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8E6DBEEC6AEC4B3A6A7
C8BBA5D6D3C3CADCE5F2F3E7F5F7F8FFFFF8F3F2F4F7F6F8F7F6F8DEE0E1FFF7F8FFF7F8F7F6EF\
F7ECF4EEE4DEE6E0D6EEE5DFF7F4F4F3F7F8F7F7F8F3F4E8F7EFE7EEEDE5F7F4F4
FFFFFFF7EDE5F7F4EDFFF4F4FFF4F4FFFFFFECEFEFD6D9DBD9DCD6EBECE2EBEBEEEEFFEFE2DCD6\
F7EED7E4EDEEECEDEFEEF7EFEBE7D4F7ECDEFFEFDFEEE8DBE5E5E8D0C1C5D9D4C9
FFF7DEE4ECF4ECEEF8F7F6EFEBEBF8E3ECFFEBDCDED9D4D1CACDD0C1BEC1ECE1D6CADBEED9DCDF\
FFFFFFFFFFFFF3F7F8F3F7F8F3F4EDE2E5E1E4E8E8EAEDECF5EDE8FFEDE1FFF4E8
FFF4E8F5F4ECF5F7EDF5FFF8FFFFFFEBF7F4E6F4EDE6EDE1D6EDEDDEF7F4EEECF4E2E7F4EAECF4\
ECE6EEE3F7FFF7FFFFF7FFFFDAECF4F2F7F8E3E5F0E3E5E7CDEDF3DEF4FFD1D4CD
6F71606B5353D9CCE5F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDACCE7
B3A6B4A29783A3A8AAD2D9CEE2E4E5FFFFF8F7F6F4F3F2F8F7F6F8E5EDEDCED9DBECE6E7F7ECE5\
F7EEE7FFF4F4FFF4F4F7EEE7F7F6EFFFF7F8FFFFFFF7F7EFF3F4E8F7F7EFFFFFFF
FFF4F4FFF7F8FFF7F8F7F4F4F3F7F8F3F7F8F7FFFFE3EEF0B5D3E6CAD5E2E4E1E1DEE0E1E3E5E7\
E3DDDFE3E5E7ECF7EED6EDEED1D5DEE5E6E1E5E5E8ECEDDED9E6F4D0D5D6E2E0DE
DADDF8DEE4EFDEE4EFEAECEFDAE5EFE6E6F8FFF6F8EBEDFFE3E4F8DEE0EDC5C8D3B9BDC1F3F4ED\
E2E4EEF3F4F4F7F7F8F7F7F8EBF7F4EBF7F3F5F7F7F5FFF8F5F7F7EEF4EDEEF4ED
F7EDE1E5EDEDDEF4F4E6F4E8DEF4ECE3EFECFFF7F4ECF4F8FFF7F8F7F4F4DEF3F8ECFFFFF7F6F8\
F3FFFFDAECF4E3ECF4EEF3F8F2F3F4C7D5DFCDDCE5C9EDF7ECE5E7B3AE9C745954
84696BD9CCDEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EEE5F8BCB6C5978F95B3B2A1C7CCABE3E5D7F7F6FFEBF6E7EBF6EDE3EBEEE3EBEEE4E8ECDAEFF8\
DAEDF8FFFFF0F7F6E8EEE5DFEBE0DDFFF7EEFFF4F4F7ECE5F7ECE5FFF4F4FFF7F4
FFF4EEFFF7F8F7F4EDEEEFE7F3F7F8F7F3EDF7ECE5EAF3F4ECFFF7EAF2EDE3EEF0FFF7EEE2E4D6\
D9D9CBDED9DEFFF4F4FFF7EEF7F3EDC8D3DBD9D9CFEAECF4ECE4CDD9EDEFDEDCDB
E3DCCEEEE7E2FFEFE7EAECFFF7F6EFEAF4E8DEE4E1D6D9E5DFE0F4E6E6F4F3EBF4E4ECECDADDE8\
E5E7EEEBECEED9DBDEDFE0E3E6EDEEEEF7F8EBF4F4E5E8E1EBF4F4F7F7F8F7F7F4
D9F4F8E5ECF4F7E4E8FFF4F4E3EDF4E3F4F8F7ECF4EAE0E9EAE0E9ECDCE6F7E0E2E3E0E8DEE8ED\
EEE8E8D8EFF4D8E8F4EBECF0BFC8DBD6E0EEE2E4E59AB2B16F716367524C988DA2
F3EDEEF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD1C2CE98849D7F7482939275C1C29FCED9E1DEEDECEAECF8F5F7FFE2E4EDEAECE5\
E5E6E1ECEDDEF7EEE2EBE0DDDAE5EFECF7EEFFF4EEEAE1D6EAE1E5EEECE5EBE4D3
F7F6EDF7F4F4EEF7EFF7EDE5FFFFFFF7EEE7F3F6EFF3F7F8F7EEE7EAF3F4E5EBE5E2F3F4DEEBF8\
D0E5FFE2EFF8F7F4F4FFFFF0F3ECE5FFF6EFE3E5F7D6D3CEE3E5E2FFF4F4ECEDF4
ECEDDBDEECECC4D4DEB9BDDBC4C8E9D9DBE9D9DBEED6D9E5D8DCDCD8DCDCD1DCDCD6E1E2EBE0D4\
E3E4E2FFFFF8F3EBEEF7ECEEFFFFFFEBE7EEEBECF4F3EEF8F3E4E5F7F4EDEEECF4
F5ECEEEAEEF4ECF6F8DEE4F0EAE0E9EAE0E9D0DCE5D2E8E8CEE1E1CEE8E8E6F7EFE5FFEFFFFFFF\
DEFFF7E2DDDDC7D1DBDEE4E5EEE6EEA49D9C7974577B564494757EDACCD7F7F7F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7F8F7F4F4DACCDEA48CA77561735C49455B472E8D825DCACBB4F7F3E5D9E1F0\
D1DCF4DEE0E2CBCFD1C4D4CEDEE0D7ECEFEFD6DDD0BCC2B4D1CFCFF7F7F8F3ECF4
F3ECE5E2E0DBE3EBE5E2F2EDDEE6E2EBE6DCF3F6EFF7F7F8F7FFFFEBE4DEEBECE5E3F6F8ECF6F8\
E4F2F4FFFFFFF7F7F8F3F4F4F7F7F8FFF6EFFFF2E8F3ECDEF7FFEEE2ECEEDEE6E2
D9D4CDE2E5E5F3F4F4EEEFE7ECEFEFF1F4FFF1F4F8E4E7E5D8DBDCD8E4E7D8E4EFD8E4EFD1F6E7\
CEF6E7D9F7F8D6E5F0C4E4F4CEE0F0E2F3F8D1ECF8D6E4F0D6D9E2C4C8D0D1D9D6
D1D9D6CBCFD1BECDD1C4D9DBBEE0E8CEE0E1D1E4E8E5EEF8D6F7F8EEF6FFCAD9E7C4C8D0AAC3D7\
B7C3D7EAEDEFD6C5B98B79604E2C1B61413CA48C9ADACCE7F7F7F8F7F7F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8988DA45559697A7C698F9796\
CAC1C1FFEEDFF3F4F4EBF7EDEBF6EDEAE0D3D6DDD4D6DCD6EAF4F4EEE5EFEEE5EF
F7F7F8F5F7EFF2F4EDF2F4EDF7EFE7DEEDEEE3E5DFF7F6EFF3F7F8F3F4F4F7FFFFF7F7F8E3F2ED\
ECF2EDFFFFFFFFFFFFFFFFFFFFF6EFECF2E8DEF2EDD9E6DDF3E0D1ECFFF7EAE0DB
F7ECE5FFFFFFFFF6EFF7ECE5EBF7EFEBF4ECF3F4F3FFFFF8F3F4E8F7F7F4FFEFEFF7EDECF3F4F4\
EEE7EDEBECF4EEEEF8DFEEF4E5FFF8F3F4F4EBEDE1E5EDE1E5EDE5ECECF4D1E0F8
CBDBF4CBDBF4D9E0F4F3EBEEF7F6F0E2F3F4E2F3F4D9E6EDE3EFECD6D9E1BEC8DEECECF4D1DBE9\
B0BDBC8A827373625690757ED1C3CFF7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDACCDFA48CA7867882\
6F787B908F7EA39E7AB9B294D8CFBDE3DCC5FFF4D1D6D9D7DEEDEED9E5DDD9E5DD
C9D1C4C9C8B4D8D9CCDEEDEEE3EFF0F7F4EDE2E5DED6DDD7E4F2EDECF2EDEAEBE5D8EBEEEAFFF7\
FFF6EFE3E6E7E2E6E7F7FFFFFFF6EFE4F6ECF7FFF7F2F7ECEAF7EFE4EEEDEAE0DB
EAE6E2E4F2F4E4F6F4E4EEEDECECEEF7F4EEF3F4E9EBEFE5D6E4DBE2ECE6F7FFF8EBF7EDEBF4EC\
F7F7F7F3F7F4E6F4E8E6EDE1E6E8DCD1EDE8D8ECE8EAEBE9EAF2EEE2F6EEE2F3F4
C4E0F0B8D4E2B2CFDCC4DBDBD1E6E6B0C5DB9DAFCBA9C1DBC1D9EEF3E6EEE4EFEDE2D9CCACA88D\
7F5D5294717CD9C1CCF7F4F4F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F0\
BCB6C4968AA88A799D776D826F6D666F6D6668667A90858BC4AF9DB8AAA2B8AFA6
C4B8ABC1C2C4CEC2B4E3DCCBDAD4DBD9D4DBF7E5DFF3E5D6EBD5C1D9E1DDE2E8E2EAEFE5ECF6EC\
FFF2E8DEDCD5D8E5E5F7FFFFF7FFFFE2F3F4D8E6E9D8E6E2D8E6E2DEEBEEEBECE5
EBF4F4F7F7F3F3F4F3F7F7F7ECF6F8E4F2F4ECF6F8FFF4F4ECECEEEAF3EEF7F7F4FFFFFFF7FFF8\
F3FFF4F7F7F0E3F4F8E3FFF8F7F4EEEAF4EED8ECE8DEE6E3D8E6DECBE0DED6D9DC
EEE8E1FFFFFFF3F4F3F5F7F8DED9E1E3DDE7FFFFFFFFFFFFE3EEF8D9D9DB9A7E6C685F59766173\
D1BAC5F7F7F8F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFEEE5F8E6DBEEE6DBEEEBE0EED9D1E2CBC8E1DEE0EDEAE5E5
E3DDEFE5E0F8C8B9CCDADDD7EAEDE1EBEEDDC8CBCFBCB9BDC1B9B3E3DCCBF7EEE7E3EFF0D8E8E9\
D1E1E3E5E6DFE4F2EDFFFFFFEAF6F8E2ECEEF3FFFFF7F7F8FFF7F8EAF4EEBCD9E5
C4E0D6D6EBE8D8E6E8EAF3F4ECF6F8ECF6F8ECF6F8ECEEF0F7FFFFF3F4F4F7F7F8F7FFFFF3FFFF\
F7FFFFFFF7F8E2F4F0D9F7F4EBFFF8F7FFF8F7FFF8F3FFF4F7F7F7F7F7F7F7F7F8
F7FFFFF7EFEFF3F4F3F5E4E5E2F7FFE4E0EED6CDD4B4AE9CB4A379A88F70876D6CE2D1DBF7F4F4\
F7F7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8EEE4F4E6DBF4
F3ECEEF3ECEEE5DBE2D9D1DBDFD9DBEBECF0E3ECE1E2E4DFEBE4E8B4AEB9B4AB9CD1C8B9F7EEE7\
F7F7EDF3EDDEE2E0DBD8E0DBF3ECE5F7E5DFECECEEEAEEF0D8EBEECFE5FFDEF4E8
F3F4EDF3F7F8F7FFFFE2F3F4EAF3F4E4F2EDFFFFF7EAF3EDE5E4DEE2ECEEFFF4F4FFF4F4F3F4F4\
F7F7F8F7FFF8FFFFFFF3F7EEF3F7EEF7FFF8F7FFF8F7FFF8F3F4F3F5F7FFEAECF8
EAF3F8EAECF4E4DBE9E2F4EFF3D1B2B3AE869493698774708A7397A493B2D9CCD6F7F7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7EFF0EBE4F4EBEBF4E5E0F0D9CCDEDED5E1DED9EFE2E4F4D9DCEDEBE7F0D9CBDEBEBAC5C4BAAB\
BEB6B4C4BCBDD9D1C8EAE4D6FFF7E9EAEDDCDED4BEEBD9C5F2F4DDDEE5E5FFECE5
F7F4F4F7FFFFF7F7F8E2F3F4EAF3F4EAF6EFDEF2EDEAEBE5EAEBE5F5F7EFE5EBE5EAF6F8FFFFFF\
FFF4F4F3FFF8F7FFF8F3F7F8F7F7F8F7FFF8E3EFEFEAE8ECE3E4EDEAEBF4F5F7FF
EAECF4E4E0D4B9B2998A8161726D69837591BDA3C1DACCE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF7F8F7EDEEF7EFF0EEE5F8EBE0EEF3E8E9EBE0EEEEE4F4FFF7F8F7EFF0D9D1E2CBBDD6\
CBB7CBC4B0C0A897A781738B7C677A967E85A99E9DA3A3A2B0AA99A8AA9DB0B69F
D1C8A8CBBBA8CBC2B4DEDBD1E2E0D6D1E0DBE2EBDBECF2DBDEEBE8EAF7F4DEE0EFEAF7F4FFF2E8\
FFEBE1E2D9D0D6D4C0CECDBACBC8B4B4B29D7C7F6D70614655412E3A2F22463B28
4936284F36386D536BA48CAADACCE5FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEE5F8E6DBEED6C6E2CBB7D0CBB0C0A48FAE
9086A2A29EA3B0A49BA99890AA988BBDA791B4B1ADA8A4A3B19D8C948A85837F7A817C73757474\
75746E7F716D7C677A816D7F907385A08397CAAEB6D1C3D6DAD4E5EEE4F4EEE4F4
FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFF4F4FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFF7F8FFF7F8FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF7F8EEE4F4E6DBEEE6DBE9D9CFE3C2B2C5BEAABAC4B0C5D1BDD1D8C3D1D1BDD6D6C6E2EBE0E9\
EBE0EEEEE5F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F4F4F7F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7F8FFF7F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00703oool20?odm0/0oooo0P3om?@n0?ooo`040???
aP3cm=`0looo0??dm0<0oooo0`3ooo<40?ooo`060?odm03oool0oooo0?odm03oool0ooCd2`3oool2
0?odm0<0oooo00<0ooCd0?ooo`3oool00P3oool00`3cm>P0loCd0??dm0040?ooo`030?odm03cl_@0
lo;d0080oooo00H0lo;d0?odl`3oool0ooCc0?7dl`3aool20?7dm0030?ooo`3am?@0oooo00d0oooo
0P3om?@20??dm0050?ooo`3om?@0lood0?oom03oool00P3ooo@00`3cl_@0lo;o0?oom0020?ooo`08
0?oom03oool0oooo0>Kbo`3Vool0oo;d0?ooo`3;WX`20?oXg2T0oooo0P3om?@70?ooo`80ooCd703o
ool00140oooo103omoP70?ooo`80ooOh2`3oool20?ogn0L0oooo103omoP00`3oool0ooOh0?ogn00=
0?ooo`80ooOh8@3oool0103ge<H0ongL0?ogn03gmoP30?ooo`030?ool`3oooL0ooog00<0oooo0P3o
moP20?ooo`040?ogn03om?@0oooo0?ogn080oooo00@0ooOh0?odm03om?@0ooOh0P3oool80?ogn005
0?oom`3gmn`0moO_0?ooo`3cm>P00P3gmoP40?ooo`040?odm03gm_P0moKh0?ooo`80moKh00<0ooCc
0?Gom`3emol00P3emoL01@3akNd0mOOh0?7dm03emoP0oooo0080ooOh0P3oool20?ogn0<0oooo0`3o
moP03P3om?@0oooo0?ogn03gmoP0mooo0?odm03omoP0looh0?Oon03gool0oooh0?Oon03om_P0moKd
103oooP01`3ooo@0oooh0>kbo`3^m_l0k_oh0=kUgP3IWhX00P3oknLI0?ooo`80ooOh2@3oool20?og
n0030?ooo`3omoP0ooOh00@0ooOh00<0oooo0?ogn03omoP0103omoPL0?ooo`003P3oool00`3om?@0
ooOh0?ooo`040?ogn0030?ooo`3omoP0ooOh0140oooo0P3omoP20?ooo`80ooOh00<0oooo0?ogn03o
moP0103omoP00`3oool0ooOh0?ogn00=0?ooo`80ooOh1@3oool30?ogn1T0oooo00@0on3@0??Pd03c
moP0ooOh0`3oool60?oom`080?odm03omoP0ooOh0?ooo`3omoP0ooCd0?ogn03om?@20?ooo`030?og
n03om?@0ooOh0080ooOh00<0oooo0?odm03om?@00`3omoP01@3oool0ooOh0?ooo`3oooL0moO/00<0
moO_0P3oool01@3omoP0ooCd0?odm03gk>h0ln_^0080moKh00T0lo;d0?Ofn03oool0ooOg0?Ggo`3e
ooL0oooo0?Gdm03eknl0103oool20?ogn080oooo0P3om?@30?ooo`@0ooOh00H0ooCd0?ooo`3omoP0
ooOh0?Ooo`3cool30?ooo`030?Ooo`3gooP0mooh00<0oooh00T0oooo0?oom03oooP0oood0>kbo`3^
l_P0k_Kd0<:n]P3g^ZL03P3oool20?ogn0/0oooo0P3omoP90?ooo`80ooOh00<0oooo0?ogn03omoP0
0P3oool20?ogn0030?ooo`3omoP0ooOh0080ooOh0`3oool20?ogn1T0oooo000>0?ooo`030?odm03o
moP0oooo00D0oooo103omoP20?ooo`80ooOh203oool20?ogn0030?ooo`3omoP0ooOh0080oooo0P3o
moP00`3oool0ooOh0?ogn00E0?ooo`80ooOh103oool30?ogn1T0oooo00D0on3@0??Pd03cmoP0ooOh
0?ooo`020?oom`030?ooo`3ooo<0ooog0080oooo00<0ooO_0?ogn03omoP00`3omoP0103oool0ooOh
0?ogn03oool50?ogn0040?ooo`3om?@0oooo0?ooo`80ooOh00@0ooCd0?ogn03oooL0moO/0`3cm>P0
1@3gmnl0oooo0?ogn03om?@0mnk`00<0moKh00D0oooo0?Ofn03gm_P0mOOo0?Gdm`020?Gdl`050?Gg
m`3aool0lOoo0?Ggn03omoP00P3oool30?ogn0030?odm03omoP0oooo0080ooOh1@3oool01P3gmoP0
mooo0?ooo`3omoP0ooCd0?ooo`<0mooo0P3oool03`3gool0oooh0?Oon03gooP0oooo0?oon03ooo@0
oooo0?oon03om_P0k_oo0>kfm03gko00dK:L0?oIc00>0?ooo`@0ooOh00@0oooo0?ogn03omoP0oooo
0P3omoP40?ooo`80ooOh00<0oooo0?ogn03omoP05P3oool20?ogn0030?ooo`3omoP0ooOh01H0oooo
000B0?ooo`80ooOh103oool20?ogn080oooo103omoP01@3oool0ooOh0?ogn03omoP0ooCd00<0ooOh
2`3oool20?ogn180oooo0P3omoP00`3oool0ooOh0?ogn00M0?ooo`030?oPd03ch=00loCd0080oooo
00<0ooog0?ooo`3oooL00P3oooL20?ool`050?odm03oool0oooo0?ooo`3om?@00P3oool01@3om?@0
oooo0?ooo`3omoP0oooo00H0ooOh00L0ooO_0?oom`3oool0oooo0?Ogk`3cm>d0moOh00<0oooo00L0
ooOh0?odm03omoP0k>kh0?Ggo`3oool0moKh0080mOOo00L0oooo0?Ggm`3oooL0mOCc0?7go`3emoP0
mOCd00<0ooCd00<0ooOh0?Ogn03gmoP00P3gm?@00`3om?@0ooOh0?ogn0050?ooo`80ooOh00@0oooo
0?Ogn03gmoP0ooOh0P3oool30?Ogn0030?Ooo`3cool0looo0080oooo0P3cool40?oon0070?ooo`3o
m_l0k_oo0>kfm03gfL`0dK:L0?o_l00@0?ooo`80ooOh00@0oooo0?ogn03omoP0oooo0P3omoP0103o
ool0ooOh0?ogn03oool20?ogn0030?ooo`3omoP0ooOh01T0oooo0P3omoPF0?ooo`00403oool40?og
n0L0oooo0P3omoP0103oool0ooOh0?ogn03oool30?ogn0030?odm03omoP0oooo00`0oooo0P3omoP0
103oool0ooOh0?ogn03oool20?ogn0l0oooo0P3omoPM0?ooo`030?oPd03ch=00loCd00<0oooo1P3o
ooL01@3omoP0ooCd0?odm03om?@0ooOh0080oooo0`3omoP03@3om?@0ooOh0?ooo`3om?@0ooOh0?od
m03omoP0ooog0?ooo`3oooL0moO_0??dj03gmnl00P3oool0103omoP0ooCd0?odm03omoP20?ooo`04
0>c[n03/loP0j^kd0?Ggo`80mOCg00H0mOOg0?o_m`3okoL0lOCg0?Gon03omoP50?ooo`80moOh00D0
loCd0??gn03omoP0moOh0?Odm0040?ogn0030?Odm03gmoP0ooCd00<0oooo0P3gmoP02`3om?@0moCd
0?Ogn03gmoP0oooo0?oon03gooP0oooo0?Ooo`3oool0mooo0080oooh00P0oooo0?oon03ooo@0oooh
0>kfo`3Uk^h0h/Jb0=W2^AX0oooo0P3omoPH0?ooo`80ooOh1`3oool40?ogn180oooo000@0?ooo`80
ooOh2@3oool20?ogn0X0oooo0P3omoP=0?ooo`80ooOh00<0oooo0?ogn03omoP0;P3oool0103oflH0
lnSL0??gn03omoP40?ooo`040?ool`3oool0oooo0?ooo`80ooOh103oool40?ogn0<0oooo0P3omoP0
203oool0ooog0?ooo`3gmoP0loCX0?oom`3cm?@0moOh0P3oool0503omoP0hoOd0>?on03SooP0hoKh
0?Obn03Zk_@0j_Od0?;gn03oool0mOog0?Goo`3emoL0mOOo0?Ggm`3oooL0ooOh0?odm03gm?@0moOh
1@3oool01`3gmoP0moCd0?Ogn03gool0looo0?Ogn03cmoP00P3gm?@04`3oool0mooo0?Ogn03gmoP0
ooOh0?odm03gool0ooOh0??gn03gmoP0oooo0??oo`3cm_P0loKo0?Ofo`3cm_P0oooo0?Ooo`3oooP0
0P3oool0203oooP0oooo0?oon03oool0ooKh0??Wh`3N/YP0mmcF603oool20?ogn0030?ooo`3omoP0
ooOh00@0oooo0P3omoP00`3oool0ooOh0?ogn0020?ogn0030?ooo`3omoP0ooOh00T0oooo00@0ooOh
0?ooo`3omoP0oooo0P3omoP00`3oool0ooOh0?ogn0040?ogn180oooo000?0?ooo`80ooOh1P3oool2
0?ogn0<0oooo0P3omoP30?ooo`80ooOh103oool20?ogn080oooo0P3omoPl0?ooo`050?oPd03ch=00
mooo0?Odm03oool00`3oooL0103oool0ooog0?ooo`3oool20?odm080oooo0P3omoP00`3om?@0ooOh
0?ogn0070?ooo`80moO/00T0loCX0?Ogn03Smnl0fNgd0?Ogn03oool0hoOo0>?dn03Sk_@00P3Sl_P0
1@3/m_00mooh0?Ggo`3emol0mOOg0080onoc00D0mNo_0?ogn03omoP0ooC]0?ogm0020?ooo`040?O_
l03gkND0moC]0??dm080moCd00@0moOh0?ogn03gm?@0ooOh0P3gool01@3oool0looo0?ogn03omoP0
oooo0080moOh0P3gm?@01`3gool0ooCd0?Ogn03cmoP0oooo0?Ooo`3cool00`3cm_P01`3gm_P0oooo
0??oo`3gooP0oooh0?Oon03gool00P3oooP01@3oool0ooKo0?OAa@3A[YP0ooOh01P0oooo0P3omoP0
103oool0ooOh0?ogn03oool20?ogn0040?ooo`3omoP0ooOh0?ooo`@0ooOh00<0oooo0?ogn03omoP0
0P3omoP80?ooo`80ooOh00@0oooo0?ogn03omoP0oooo0P3omoPF0?ooo`003`3oool20?ogn0<0oooo
0`3omoP00`3oool0ooOh0?ooo`020?ooo`80ooOh0`3oool20?ogn0@0oooo0P3omoP01P3oool0ooOh
0?ooo`3oool0ooOh0?ooo`80ooOh00<0oooo0?ogn03omoP0603oool30?ogn1X0oooo00D0mmW@0?OT
d03oool0loCd0?ooo`040?oom`050?ool`3oool0ooog0?ogk`3omoP00P3oool20?ogn0040?odm03o
moP0ooO_0?oom`<0oooo0`3gmnl04P3Jkol0fNgh0??dk@3gmoP0dNg_0=Sdk@3Smol0hnch0>;[kP3Z
l^h0loKd0>[gk@3ZkNP0mnod0?o_m`3ej>`0lNg/0?GMi`80mNc^0`3ok_P00`3omoP0ooCd0?ooo`02
0?ooo`080?oom`3ch>80mnc`0?o_l03oknL0ooO_0?Ooo`3cmoP20?Ooo`030?ooo`3gool0looo00<0
mooo00H0moOh0?Ooo`3gool0ooOh0?Ooo`3om?@20?Ogn080mooo0P3cooP0103gmoP0moCd0??gn03c
ool20?Ooo`090?ooo`3cool0looh0?oon03oool0oood0?O_iP3R^9l0fL[401X0oooo103omoP00`3o
ool0ooOh0?ogn00;0?ooo`80ooOh9P3oool00100oooo0P3omoP20?ooo`@0ooOh00<0oooo0?ogn03o
moP0303oool20?ogn0030?ooo`3omoP0ooOh0080ooOh00L0oooo0?ogn03omoP0oooo0?ogn03oool0
ooOh01L0oooo1@3omoPH0?ooo`040???aP3gm=`0loOh0?Ogn0@0oooo0P3oooL00`3oool0ooog0?oo
m`020?ogn0<0oooo0P3omoP20?ool`030?ooo`3oooL0moO/00<0oooo00T0f^oo0>;dk@3oiOP0mnko
0>?gn03Jm_P0f^_h0>?fn03gooP00P3coo@02@3Zmnd0l^g/0?ooo`3okoL0mNod0?7gm03ak?00mNkd
0?o^n0030?ogn080oncd00/0onG`0?ogn03omoP0onG`0?Ooo`3giO00mno`0?oom`3oool0mngX0??]
kP020?Ooo`H0oooo0140mooo0?ogn03omoP0oooo0??oo`3cmoP0oooo0?Odm03om?@0moOh0?oon03g
ooP0moOh0??dm03omoP0oooo0?Ooo`020?ooo`80mooh0P3oool0103oooP0h^7D0>>^U03gko0J0?oo
o`H0ooOh103oool20?ogn080oooo0P3omoP00`3oool0ooOh0?ogn0050?ooo`80ooOh00<0oooo0?og
n03omoP00P3omoP00`3oool0ooOh0?ogn0020?ooo`80ooOh503oool000h0oooo00@0ooCd0?ogn03o
moP0ooOh1`3oool20?ogn1P0oooo0P3omoPD0?ooo`80ooOh103oool20?ogn1P0oooo00<0mlo00?od
h@3gm?@00`3oool30?oom`060?ool`3oooL0ooOh0?odm03oool0ooOh0P3oooL30?ooo`050?oom`3g
moP0moO_0?Ogk03oooL00P3oool0203gmoP0moOd0??dm03Si>d0h^c_0?O^o`3oool0onkh0P3coo@0
3P3gk_@0onkh0?o^n03gk_00lng_0??]l`3cmoL0moCc0?o]m`3eknl0lOod0?7^kP3eooP0onkh0P3o
i_@00`3oh>h0onG`0?oUl0020?o/m0060?odm03oi>h0moKo0?oom`3ch>80ooKo0P3^kN800`3gko00
oooo0?ooo`030?ooo`@0mooo00<0moOh0??gn03gmoP00P3om?@0103gool0ooOh0??oo`3oool30?Oo
o`030?ooo`3oooP0oooh0080oood0P3oool00`3oooP0hmG00=V`XP0I0?ooo`80ooOh103oool20?og
n0@0oooo0P3omoP20?ooo`80ooOh00<0oooo0?ogn03omoP01@3oool20?ogn0030?ooo`3omoP0ooOh
0080ooOh00<0oooo0?ogn03omoP00P3oool40?ogn180oooo000>0?ooo`030?odm03omoP0oooo0080
ooOh0P3oool20?ogn0P0oooo0P3omoP00`3oool0ooOh0?ogn0020?ogn0P0oooo0P3omoP<0?ooo`80
ooOh2`3oool20?ogn1h0oooo00<0olnj0??dj03cm?@00`3oool02@3ooo<0ooog0?oom`3oool0oooc
0?ogn03om?@0ooOh0?ooo`020?oom`0?0?ooo`3oooL0ooog0?oom`3cm>d0loCX0?Ogk`3omnL0moCQ
0??dk@3Jkol0bnSc0=W]m03Si>d0fNOg0080onGh02<0mn3h0?O^o`3gk_l0lnKo0?OVn03ck_P0mooh
0?OUkP3gmnh0ooOh0?Odm`3cooL0loCg0?Odm`3omol0lNk^0?o^n03oi_@0mNkh0?Goo`3oool0onkh
0?G_k`3aknd0mOOd0?GUkP3emol0mnC`0??oo`3ok?00jnCR0>?Tk@3gknd0lnSR0?O_l0070?ooo`09
0?Ogn03gool0moOh0??oo`3gool0ooOh0?Ogn03gool0looo0080mooo00<0oooo0?Ooo`3gooP00`3o
ooP20?ooo`030?oon03S`ZL0fL:i01T0oooo0P3omoPV0?ooo`80ooOh4P3oool00140oooo0P3omoP2
0?ooo`030?ogn03oool0ooOh00L0oooo0P3omoP00`3oool0ooOh0?ogn0020?ogn0030?ooo`3omoP0
ooOh00D0oooo0P3omoP<0?ooo`80ooOh00<0oooo0?ogn03omoP09`3oool01@3omoP0omC00??dj03c
moP0ooOh0080oooo00<0oooc0?oom`3oooL01P3oooL30?ooo`0L0?oom`3oool0oooo0??gj03cmnd0
moO_0?Odh@3omnL0loCd0=W]m03Hm>P0hoO_0??/k`3oiO@0moOh0?ooo`3gk_L0mnCX0?OTk@3gi?@0
onGh0?OPn03gmoP0onkh0?ooo`3gm_00ooKd0?odn080moog00<0ooCo0?Gon03ak_000P3ek_P01@3e
ool0mNk`0?7om03/kN`0mngc0080mOOo00/0lNc`0?oPkP3omoP0mo;o0?Ooo`3gk?00lnSR0?O]j03g
mo@0lnSR0?O_l0020?oon0<0oooo00L0oooh0?Ogl03gmoP0oooo0??fn03gm_P0looo0080oooo00D0
looo0?ogn03cmoP0oooo0?Ooo`030?ooo`<0moOh00<0eZjK0?OId03oool05`3oool40?ogn080oooo
0P3omoP20?ooo`80ooOh2P3oool20?ogn2D0oooo000B0?ooo`80ooOh0P3oool20?ogn0l0oooo0P3o
moP00`3oool0ooOh0?ogn00C0?ooo`80ooOh9`3oool01@3om?@0mmBi0?Ogk`3cmoP0ooOh0080oooo
0P3oooL0103oool0oooc0?ooo`3oooL30?ooo`<0ooog00D0moO_0?Ogm03ooo<0loO]0?Odh@030?Og
k`090>;dk@3Smnl0loC]0??dk@3oooL0moOh0?oom`3gmo@0moO_0080ooog00l0oooo0?Ogm03gmo@0
om_d0??^n03gi_P0mnch0?o[n03omo@0moCg0??dl`3cko<0moCg0?ogm03eool00P3ak_P0503eoo@0
moOg0?o_m`3gkOL0onSc0?o_m`3emol0lOOh0?G^l03ok_P0moKo0??bo`3gl_l0mn_h0??Ti@3gkNP0
moOh0?O_j03oooP0oooo0P3gmoP20?oon0060?Ogn03cmoP0ooKd0?ofm03cmoP0ooOh0P3gool00`3o
moP0loOh0?Ooo`020?oon080oooo0P3gmoP00`3ckND0gZnK0?OXhP0H0?ooo`P0ooOh0P3oool40?og
n0P0oooo0P3omoPU0?ooo`004P3oool20?ogn0030?ooo`3omoP0ooOh0080ooOh00<0oooo0?ogn03o
moP03P3oool20?ogn3`0oooo00D0ooCd0?OD/`3gmoP0loCd0?ooo`060?oom`80oooo00X0ooog0?oo
o`3gmnl0moO/0?ool`3oooL0moOh0?Ogk03oooL0loCX0P3oool0203gmnl0oooo0=[_o`3IkOP0ooog
0?ool`3gmo@0moO_0P3oooL04@3oool0ooog0?ool`3ooo<0moOh0?OTk@3oool0lnch0?O^o`3ck?P0
mn_h0?oom03oooP0oood0?ogn03gmoL0moC/00<0ono]01L0oooh0?Odm`3omoL0loCo0??gn03ckNl0
loCc0?O]l`3eknl0lNk`0?G^n03ok_P0mn_h0??fo`3gm_l0mn_h0??PkP3om_L0mnoW0?ooo`3gmoP0
oooo0??dm0020?Ogn0030??gn03gooP0mooh0080moOh0P3gool01@3oool0mooo0?oon03oool0oooh
00@0oooo00<0h^7F0>>^V`3gko00703oool20?ogn0H0oooo0P3omoP_0?ooo`003P3oool0103om?@0
ooOh0?ooo`3oool20?ogn0030?ooo`3omoP0ooOh0080ooOh00<0oooo0?ogn03omoP05@3oool40?og
n0030?ooo`3omoP0ooOh00@0oooo0P3omoP00`3oool0ooOh0?ogn00W0?ooo`050?o]kP3gfKP0moOh
0??dm03oool0103oooL0203ooo<0ooog0?oom`3oooL0oooc0?oom`3cm?@0loCX0P3oooL0103gmo@0
moO_0?ooo`3cm>P20?ooo`050?O_i`3gm>d0moC]0?Odk@3omoP00P3omnl30?ogn080oooo0P3oooL0
1`3gmn`0mnC]0?oUm03gmoP0mnCd0?OWl03gjo@00P3oool02@3om_P0oo;h0?o[m03glo@0mng/0?O]
l`3ckoL0mnSc0?odm`020?Ogm`80moOd00T0ooOo0??om`3gm?l0moC_0?GUkP3eooP0oo?h0?ofo`3g
joP00P3ck_P01@3glnl0lnoW0?O_i`3cj>80moCd0080moOh0`3oool01@3gool0oooo0?Ooo`3cooP0
mooh0080oooo0`3gooP01`3oooP0oooo0?ooo`3gmoP0j]6b0=j^Y`3gmoP0E@3oool000h0oooo00@0
ooCd0?ogn03oool0oooo0P3omoPA0?ooo`80ooOh00<0oooo0?ogn03omoP01`3oool40?ogn0030?oo
o`3omoP0ooOh00@0oooo0P3omoP00`3oool0ooOh0?ogn00W0?ooo`040?oXj@3cfkT0mooo0?Odm080
moOh0P3oool20?oom`060?ool`3oooL0oooo0?oom`3gmoP0ooog0P3gmnl0203cm>d0ooog0?ooo`3g
mnl0loCX0?Ogk`3cm>P0moC]1@3omoP0103om?@0ooOh0?ogn03om?@20?ogn0H0ooog00/0moOh0?oU
n03gmnh0oo;h0?ofn03om_l0ooKh0?ofo`3om_P0moOd0?ogm`020?Oon0060??dm`3cmo<0onog0?Od
l`3cmo<0ooOo0P3cmo<04`3cm?<0ooOo0?G^kP3emoP0oo;o0?G/m03ek_P0oooo0?O[n03gm_l0lngU
0?ogn03omn`0mnoW0??dm03gmoP0oooo0?Ogn03omoP00P3oool20?oon080oooo0P3gool0203gooP0
oooo0?oon03gmoP0mno`0>>mXP3Rc]40moOhE@3oool001<0oooo0P3omoP30?ooo`80ooOh2`3oool2
0?ogn0030?ooo`3omoP0ooOh03h0oooo00@0onSY0??K^@3cool0ooCd0P3gmoP30?oom`0:0?ool`3o
ool0oooc0?oom`3gmn`0ooog0?ooo`3gmnl0loCX0?Ogk`D0moOh00<0ooog0?ogn03om?@00P3omoP0
0`3om?@0ooOh0?odm0020?ooo`80ooOh00@0ooCd0?ooo`3oooL0ooog0P3oool01P3oooL0moO_0?OU
n03gmoP0moKh0?ofo`80ooKh01/0oooo0?ofn03oooP0moOo0?Ogn03oool0ooOh0?Ogm`3omoL0moOg
0??]m`3omol0moog0?ogo`3om?l0moOd0?oon03ek_P0mNKd0?Goo`3ek_P0onKd0?Ofo`3gool0mn_h
0??Ti@3gknL00P3omnl01@3cm?@0oooo0?Ogn03omoP0oooo00@0ooOh00@0oooo0?Ooo`3oooP0oooh
0P3gmo@0103gmoP0jngR0<jfYP3gj>8E0?ooo`80ooOh0`3oool00`3omoP0ooCd0?ogn00i0?ooo`00
3`3oool20?ogn080oooo0P3omoP30?ooo`80ooOh00<0oooo0?ogn03omoP01P3oool20?ogn4<0oooo
00@0onSR0??K_`3cmoP0ooOh0P3oool50?oom`060?Ogk03cm>P0oooo0?Ogk`3cm>P0loC]0P3gmoP3
0?ooo`<0ooog103omoP00`3oool0ooCd0?odm0030?ooo`80ooOh00<0oooo0?oom`3omnl00`3omoP0
503omo@0onoU0?OUk`3omoP0loKh0?Ocn03gjoP0mooo0?ogn03ok_00ooOd0?ogn03ooo@0oooh0?Og
k@3gm?@0mooo0?Ogo`3om?l0moog0P3oool01@3gm?@0oooh0?oon03eoo@0mNK^0080mNKd00`0ooKo
0?Ogn03ck_P0ln_h0?ogk`3gknD0ooOh0?O]i@3gko00oooo0?Ooo`3omoP20?ooo`0<0?Ooo`3gmoP0
oooo0?ogn03cmo00mooh0?Ogn03oool0loCd0=KUd03A[ZL0mno`5@3oool20?ogn0060?ooo`3omoP0
ooOh0?ogn03om?@0ooOh>@3oool000h0oooo00<0ooCd0?ooo`3omoP02P3oool40?ogn0@0oooo0P3o
moP60?ooo`80ooOh503oool20?ogn2D0oooo00@0mmW@0?OTd03gmoP0moOh0P3oool20?oom`80oooc
00P0ooog0??dk@3gmnl0oooo0??dj03oooL0moOh0?oom`<0oooo00<0ooog0?ooo`3omoP00P3om?@0
1`3omoP0oooo0?ooo`3omoP0oooo0?ogn03oool00P3omoP0103om?@0oooo0?ogn03om?@40?ogn005
0?ooo`3omoP0moO/0?OTm03gio000P3om_P02P3gk?@0moKo0?O[n03om_l0ooKh0?ooo`3ok_@0onkh
0?oon03om?P20?odo`080??ol`3cmo<0loOc0?odo`3oooP0oooo0?oom03ak_@20?Goo`0;0?o[n03o
k?@0mnKd0?O^n03cloP0lng^0>Gdk03Umo<0lnSY0?ooo`3gmoP00P3gool0303gmoP0moCd0??oo`3g
ool0loCd0?Odm03gool0oooo0??dm03gmoP0fM_60=Z`Z1T0oooo0P3omoP30?ooo`80ooOh00<0oooo
0?ogn03omoP05`3oool20?ogn0030?ooo`3omoP0ooOh01P0oooo000>0?ooo`030?odm03omoP0oooo
0080ooOh0P3oool40?ogn0@0oooo0P3omoP<0?ooo`80ooOh503oool20?ogn2D0oooo00@0llo60?Od
g03cmoP0moOh0P3oool20?oom`060?Ogm03cm>d0loC]0?ooo`3gmnl0loCX0P3gmoP01@3oooL0oooc
0?ooo`3oool0ooog0080oooo00<0ooOh0?odm03omoP00`3oool40?ogn0<0ooCd00<0oooo0?odm03o
ool0103oool01@3om?@0oooo0?oom`3oooL0moOh0080mn3h02T0lnch0?ocm03gloP0oncd0?O^n03g
m_P0on_d0?o[l03ooo@0ooOh0?ogo`3om?l0moog0?ogo`3gmoL0ooCo0?oon03oool0oood0?Gon03e
i_@0onKd0?odm03oloP0moOh0?Obo`3cm_l0loCd0>?gk@3SkO00mnoW0??]kP3gool0moOh0??gn03g
m?@0mooo0?Ogn03gool0ooOh0?Ogn0020?ooo`040??dm03gmoP0h/Jb0=W2^A@0oooo0P3omoP80?oo
o`80ooOh00<0oooo0?ogn03omoP00P3omoPE0?ooo`80ooOh00<0oooo0?ogn03omoP0603oool00140
oooo0P3omoP20?ooo`@0ooOhC`3oool00`3cclH0moCL0?Odm0050?ooo`0:0??dm03gmnl0loCX0?oo
o`3gmnl0moO/0?Ogn03oool0oooc0?ooo`80ooog0`3oool20?ogn0030?odm03oool0oooo0080ooK`
00H0oooo0?odm03omoP0oooo0?ogn03om?@20?ogn0D0oooo00<0ooOh0?ogm03oooL00P3oooL06@3o
iOP0mnko0?O^o`3cio00moKh0?O^o`3gmoP0on_d0?Obn03ol_P0oooh0?ofn03om_@0ooOh0?Ogm`3g
ooL0ooOo0?ooo`3omoP0oooo0?oom03oooP0mNkh0?7fo`3ek_P00P3oool02@3ol_l0moKo0?Ogn03c
k_P0ln3R0?ogk`3UmoL0iOOW0?Ogn0020?Ooo`050?Odm03gmoP0ooOh0?ooo`3gool00P3gmoP0103c
m?@0oooo0>c8Z03Rb</D0?ooo`80ooOh3@3oool20?ogn380oooo000B0?ooo`80ooOh00<0oooo0?og
n03omoP0103oool20?ogn4X0oooo00@0omg?0?OMa@3cmnd0oooo103gmoP00`3cm?@0moOh0?Ogk`02
0?Ogk`060?Ogn03oool0ooog0?oom`3oool0ooog0P3omoP00`3oool0ooog0?ogm0030?ogn080oooo
0P3om_00203oool0ooCd0?ooo`3omoP0ooCd0?ooo`3omoP0oooo0P3om_030?ooo`060?ogn03omo@0
ooog0?oom`3oool0ooog0P3gmoP04P3cm?@0mnko0?ooo`3gk_l0lnKo0??bm03ol_P0oooh0?ofn03o
k_@0moC_0?ogo`3coo<0moCd0?ogm03omoP0oood0?ooo`80oooh00D0ooOh0?G/m03emoP0oooo0?ob
o`020?ofo`030?Ooo`3ok?00moOh0080hoCd00P0ong^0?O]kP3gmoP0moOh0??dm03omoP0moOh0??g
n080moOh00@0loCd0?ogn03/_I/0h]7K4`3oool20?ogn0<0oooo0P3omoPm0?ooo`003P3oool01P3o
m?@0ooOh0?ooo`3oool0ooOh0?ooo`<0ooOh103oool40?ogn0030?ooo`3omoP0ooOh00H0oooo0P3o
moPl0?ooo`050?O_l03R^:L0h]cR0?Odm03gool00`3gmoP01`3gmo@0moO_0?Ogk`3cm>d0moO/0?oo
o`3oooL00P3oool30?oom`80ooOh00<0oooo0?oom`3om>d00P3omoP60?ooo`070?odm03oool0ooog
0?ogm03oool0ooOh0?ooo`020?ofl0<0oooo0P3omoP0103oool0ooog0?oom`3ooo<20?oom`030?OT
m03ck?P0onGh0080ooKh00D0mo?d0?obn03ooo@0oooh0?odo`020??gm`030?ogo`3ckN`0oooh0080
oood01d0oooo0?oon03oooP0mOoo0?7gn03ejoP0oo;o0?ogn03oloP0oooo0?Ofo`3omoP0mng^0?O_
l03oool0hng]0>Gok03gkND0lno`0?Ooo`3cool0moOh0?ooo`3gmoP0oooo0??dm03om>d0gZnF0?O]
kP0A0?ooo`<0ooOh00@0oooo0?ogn03oool0oooo0P3omoPm0?ooo`003P3oool01@3om?@0ooOh0?og
n03omoP0oooo0080ooOh0`3oool20?ogn0030?ooo`3omoP0ooOh0080ooOh00@0oooo0?ogn03omoP0
oooo103omoP00`3oool0ooOh0?ogn00k0?ooo`0=0>kUl038/[H0g/^m0>CKj@3gool0moCd0?ooo`3o
ooL0moOd0?Ogk03gmnl0moOh0?ooo`070?oom`<0oooo0P3oooL00`3omoP0oooo0?ooo`020?ogn00:
0?odm03omoP0oooo0?ogn03oool0ooOd0?ooo`3omo@0oooo0?ogn0<0oooo0P3omoP00`3oool0ooOh
0?ooo`020?odm00B0?ogn03oooL0oooo0?oom`3oi?@0ooOh0??/n03gm?@0ooOh0?Ogn03om_l0ooKh
0?oon03omol0moOo0?odm`3gm?L0lngc0`3omoP05`3oooP0mOOh0?Ggm03eooP0lOOh0?G/m03eloP0
mOOh0?ocn03om_l0moKo0?o^n03ckNh0mno`0=WXl03emoL0hngU0?ooo`3UkND0k_OW0?ooo`3omoP0
oooo00<0moOh00<0k_CQ0<j_X`3gkNh04@3oool20?ogn0030?ooo`3omoP0ooOh00L0oooo0P3omoP0
0`3oool0ooOh0?ogn00A0?ooo`80ooOh0P3oool20?ogn1h0oooo000@0?ooo`@0ooOh103oool20?og
n0030?ooo`3omoP0ooOh00H0oooo103omoPm0?ooo`0?0>kUn038/Zd0_Z6D0;g:e@3RfN<0loCd0?Og
n03oooL0moo_0?Odh@3gmnl0moO/0?ooo`3oooL0oooo0080ooog0P3oool20?oom`<0oooo00<0ooog
0?ogk`3omoP0103om?@02@3oool0ooCd0?ooo`3om?@0ooOh0?ogm03oooL0oooo0?odm0040?ooo`0D
0?ogn03oool0ooCd0?ogn03omo@0ooC]0?odm03omoP0oooo0?ool`3gmoP0mooo0?oUn03gool0mo?d
0?Ooo`3gm_P0oo?d0?o^l03om_P20?Ogm`030??dl`3cmo<0lnoc0080ooOo00T0mOoo0?Ggm03amoP0
lOOd0?Gon03eool0lOoo0?Gdm03eool00`3om_l04P3cooP0mo?d0?Odm03Jm?@0fOCd0?ogn03cj>80
k_OU0>k]hP3gool0moOh0?ooo`3cm?@0oooo0?Ogn03UkM`0dJjR0?O_l1X0oooo0P3omoP0103oool0
ooOh0?ogn03oool20?ogn140oooo0P3omoP20?ooo`80ooOh7P3oool00100oooo103omoP00`3oool0
ooOh0?ogn00J0?ooo`80ooOh<@3oool03P2cYZd0ShM[0;jm]P2?V:d0lnOY0?Ogn03oooL0moo_0?Og
k`3gooP0loC]0?Ogk`3oooL0oooo0P3omoP90?ooo`040?ogn03oool0oooo0?ooo`<0ooOh00<0ooCd
0?ogn03omoP0103oool20?ogn080oooo0`3omoP0103om?@0ooOd0?ooo`3oooL20?ooo`0F0?oom`3o
ool0moO_0?Ogn03gm?@0mnch0??/kP3gool0mo;h0?o[m03ok_00ooKh0?Ogm`3gooL0loOc0??ol`3c
mo<0ooOo0?ooo`3emoP0mOOo0?Gon0@0mOoo00T0lOOh0?Gdm03ok?@0oo?h0?ooo`3cm_P0mo?d0?Og
n03oool00P3gmoP0103oool0lnSY0?O_l03gko020?Ogn0050?ooo`3cm?@0loCd0>CIeP3c]Id05@3o
ool20?ogn0040?ooo`3omoP0ooOh0?ooo`80ooOh>`3oool000l0oooo00@0ooOh0?ooo`3omoP0oooo
1P3omoP30?ooo`80ooOh2`3oool20?ogn0H0oooo0P3omoP`0?ooo`0;0=[<g`1WD4`0XIF;0;76b`28
TId0ooCd0??dk@3oooL0loO]0?Ook`3gmn`00P3ooo<20?ooo`@0ooOh103oool20?ogn0030?ooo`3o
moP0ooOh0080ooCd00<0oooo0?ogn03omoP00P3om?@60?ooo`030?odm03oool0ooOh0080ooOh0P3o
m?@00`3omn`0oooc0?ooo`020?ooo`80ooog00`0oooc0?Ogn03oiOP0onGh0?O]kP3gool0mo;o0?ob
o`3ol_@0oooo0?ogo`3gool20?ogm`030?Ogl`3omol0ooOh0080oooo00<0mOoh0?7gn03amoP00P3e
ool05P3aool0mOoo0?ogn03omoP0oooo0??fn03om_P0loOh0?ogn03gmoP0loCd0?Ogn03gko00mno]
0?O_i@3omnl0moOh0?ooo`3gmoP0k_OW0=7Db`3I_JhE0?ooo`80ooOh00<0oooo0?ogn03omoP00P3o
ool20?ogn3X0oooo000?0?ooo`80ooOh0P3oool20?ogn080oooo0P3omoP30?ooo`80ooOh2`3oool2
0?ogn3L0oooo00`0hmg`08MeJ`1aH4T0jnc^08>M/P2MWJ80mno`0?Ogk03gmnl0ooog0?Ogn03ooo<2
0?oom`040?ooo`3omoP0ooOh0?ooo`@0ooOh0P3oool30?ogn0070?ooo`3om?@0oooo0?ooo`3om?@0
ooOh0?ooo`020?odm0030?ooo`3oooL0ooog0080ooog00@0ooOh0?ooo`3om?@0ooOh0P3oool40?oo
m`80oooo0P3oooL0303gmnl0moOd0?Ogn03oiOP0ooKh0?Ogn03om_l0oooo0?oon03oool0ooKh0?Og
o`80ooOo00h0oooo0?Oom`3omoL0ooOh0?odo`3emoP0oooo0?Ggn03oool0lOCd0?Ggn03amoP0mOOh
0?odm080ooOh00`0moKh0??fn03oool0moCd0?Ogn03cm?@0oooo0?Ogn03cj>80k_od0?O_g`3gm>d2
0?ooo`030>Gok`3AcKl0fL;001`0oooo0P3omoPj0?ooo`003P3oool00`3om?@0ooOh0?ooo`020?og
n0D0oooo0P3omoP00`3oool0ooOh0?ogn0040?ooo`80ooOh3`3oool20?ogn2`0oooo00l0moOh0?Od
m02OQ8d0J58o0<Nk_@3ah=/0U:Nb0865U`3Smnl0f^oo0?Ogn03gmn`0oooc0?ooo`3oooL00P3oool2
0?ogn0<0oooo103omoP20?ooo`030?ogn03oool0ooOh0080ooCd0`3oool01@3omoP0oooo0?ogm03o
ooL0oooc0080ooog00<0ooOh0?ooo`3omoP00`3oool01P3oooL0moOh0?Ogk`3gmnl0moO/0?ool`80
ooO_00H0moOd0?ooo`3gm?@0moOh0?odm03gool20?ofo`040?obm03om_@0oooh0?Ofn080mooo0P3o
mol0303gm?<0ooOo0?ogn03em?@0oooh0?ooo`3emoP0lNg^0?Gdm03am?@0ooCd0?Gdm080ooCd0P3o
ool0103cool0loOh0??gn03oool20?Ogn0030?O_l03gkml0k_od0080ooO_00@0oooo0?Ogn03N_JP0
llo66`3oool20?ogn3/0oooo000>0?ooo`030?odm03oool0ooOh0080ooCd1@3oool20?ogn0030?oo
o`3omoP0ooOh0080ooOh00<0oooo0?ogn03oool01@3omoP0103oool0ooOh0?ogn03oool20?ogn0D0
oooo0P3omoP/0?ooo`080;FPY019=cT0CD<j0::WY03Smnd0_<G907F6R@2=TZ820=[_o`050?oom`3o
ool0ooog0?ooo`3oooL00P3oool20?ogn080oooo0`3omoP20?ooo`040?ogn03oool0oooo0?ogn080
oooo0`3omoP20?ooo`070?ogn03omo@0oooc0?oom`3oool0ooOh0?odm0030?ogn080oooo01H0ooog
0??dk@3gmnl0ooO_0?odm03gj>T0moCd0??dm03ckNh0mnG`0?O/m03cm?@0moOh0?ofn03ol_@0mn_]
0?Ocm03oooP0moKd0?Ofn03gmoL0loCc0P3omoL01@3gmoL0ooCo0?ogn03emo@0oooh0080mOoo00<0
ooCd0?odn03emo000P3eool20?ooo`030?ocm03ol_@0loKh0080looo0P3oooP02P3oool0moOh0?og
n03cj>80mnoU0>cdm03/kN40mnoW0=J^V`3gfM0K0?ooo`80ooOh>`3oool000l0oooo103omoP70?oo
o`80ooOh00@0oooo0?ogn03omoP0oooo0P3omoP00`3oool0ooOh0?ogn0020?ogn0040?ooo`3omoP0
ooOh0?ooo`80ooOh5@3oool20?ogn1/0oooo00T0moOh04hf>@2eZYd0joCd0=KKg03gool0F6AV08J7
S03SgNP00P3oool20?oom`030?ooo`3oooL0oooo0080oooo0P3om?@20?ooo`030?odm03omoP0oooo
0080oooo00@0ooOh0?ooo`3oool0oooo0`3omoP00`3oool0ooOh0?ooo`020?ooo`030?ogn03om?@0
ooCd00D0ooOh00X0ooCd0?ooo`3oool0ooog0?Ogk`3cm?@0ooCd0?Ogn03gool0mo?d0P3ojnh04P3o
iNh0onkd0?obm03ol_@0ooKh0?ooo`3gmoL0oooo0??dl`3gm?<0loOg0??dl`3gmoL0oooo0?Ogm`3o
moL0ongd0?Gon080oooo01X0lOoo0?7gn03okO00ooCd0?ooo`3amo00mOoo0?ogn03olo@0moO`0??b
n03oool0ooKh0?ooo`3goo@0oood0?Ooo`3omoP0oooo0?Ogn03ckNh0k>oU0>?fn03giMd0gZnF0?OX
hRT0oooo0P3omoP40?ooo`80ooOh103oool20?ogn240oooo000@0?ooo`80ooOh0P3oool40?ogn080
oooo103omoPK0?ooo`80ooOh1`3oool20?ogn1X0oooo00T0moOh0=[<e`0b9R00loC]0=[Ul03[i>40
D7J405MCF@3AgND00P3oooL40?ool`80oooo00P0ooOh0?odm03omoP0ooCd0?ooo`3omoP0oooo0?od
m0<0oooo00@0ooOh0?ooo`3omoP0ooOh0P3oool20?ogn00:0?ooo`3omoP0ooOh0?ogn03oool0ooOh
0?ooo`3om?@0ooOh0?ooo`<0ooOh00L0ooog0?ool`3ooo<0ooog0?oPkP3cm_P0oooo0080ooKh0P3o
ool00`3gm?L0loOc0?Ogm`040?ooo`030?Ogm`3cm?<0loCc00<0ooOg00H0moOg0?ogm`3omoL0ongd
0?7on03aool20?Goo`0:0?Ggn03em?00lOOh0?7on03eooP0mOCd0?ooo`3om_P0loKh0?Oom080ooKd
00D0oooo0?oon03gool0mooh0?Ooo`030?Ogn0050??]i@3ogML0oood0=S1ZP3gj>T0:@3oool20?og
n0@0oooo0P3omoP40?ooo`80ooOh8@3oool00100oooo0P3omoP00`3oool0ooOh0?ooo`030?ogn0@0
oooo0P3omoPK0?ooo`80ooOh8`3oool02@3ckNh0Q75b07moMP3ckND0k>c]07emQ01=Df80h]GF0?Oo
k0020?oom`040?ooo`3oooL0ooog0?oom`80ooOh00<0ooCd0?ogn03om?@00P3omoP0103oool0ooOh
0?ooo`3omoP20?ooo`040?ogn03oool0ooOh0?ogn0D0oooo0`3omoP00`3oool0ooOh0?ooo`040?og
n080oooo00P0oooc0?oom`3ooo<0moOd0??/n03glo@0oooo0?obm0<0ooKh00L0mnk_0?Odl`3cooL0
ooOo0?ooo`3gool0loOg00<0loCc0P3omoL0203gm?<0ooCc0?ogm`3eool0mOCh0?Ggn03omol0lOoo
0P3oool0403amo@0ooOd0?ooo`3eool0ooCd0?ooo`3om_P0loKo0?Ooo`3om_P0ooKd0?Oon03goo@0
mooo0?Oon03gool40?ooo`040??XhP3gk]l0dKb]0?o]kRH0oooo0P3omoP`0?ooo`004@3oool80?og
n0H0oooo0P3omoPl0?ooo`0;0?ogn02/X9D0EU1@0=K:``3[m>d0Sj6/05UTI`38eMl0moO/0?Ogm03o
ooL00P3ooo<30?ooo`<0ooOh00D0oooo0?odm03om?@0oooo0?ogn0030?ooo`80ooOh0P3oool20?oo
m`L0oooo0P3omoP30?ooo`80ooOh00/0ooCd0?ooo`3oool0ooog0?ooo`3ooo<0moOd0?Ogn03ok>h0
oo;d0?ofn0020?obm080ooKh00/0mooo0?Ogo`3gooL0loCc0?ogm`3cmoL0moCc0?odl`3gm?<0oooo
0?Ogm`020?ooo`0;0?ogn03em?@0mOOh0?Ggo`3ekoP0mOCh0?ogo`3oool0lOCh0?odn03eool00P3e
moP0103oool0moKh0?ofn03goo@20?Ofn0030?oom03oooP0oooo00<0mooh00L0loOh0?Ogn03gmoP0
moCd0?ogk`3H[iH0ong^02H0oooo0P3omoP30?ooo`80ooOh:`3oool000l0oooo103omoP20?ooo`@0
ooOh1P3oool20?ogn200oooo0P3omoPI0?ooo`0;0?Ogn02n^L@0HEUD0:2PZ`3NkNl0_ZV[075]J`38
`kd0moO_0?ooo`3gmoP00`3oooL00`3oool0ooOh0?ogn0030?ooo`050?odm03oool0ooOh0?ooo`3o
moP01`3oool20?ool`80ooOh1@3oool00`3om?@0oooo0?ooo`020?ooo`030?ogn03oool0ooO_0080
ooog00H0oooc0?oom`3oiOP0mn3^0?OTiP3ok_020?ooo`030?ofn03gk^l0moOg0080oooo00T0moOg
0?ooo`3gmoL0moCc0??gm`3gmoL0ooOg0?Odl`3gmoL00`3oool05@3em?@0lOoo0?7gn03omoP0mOOh
0?Ggo`3em?P0mOoo0?7dn03om?P0mOoo0?Gdm03emoP0ooOh0?Ooo`3oool0mood0?oon03gooP0mood
0?oon0020?Ooo`090?ooo`3cooP0moOh0?Ogn03cm?@0moOh0?O]kP3Rb:h0f/[400l0oooo0P3omoPJ
0?ooo`80ooOh00@0oooo0?ogn03omoP0oooo103omoP0103oool0ooOh0?ogn03oool20?ogn1d0oooo
000?0?ooo`80ooOh1`3oool40?ogn2D0oooo0P3omoPH0?ooo`0;0?Ogn03^iO00I5MF08n6N`3gknL0
X[W8069cP02/`lD0ooOW0?oom`3gmo@00`3oooL20?ooo`030?ogn03oool0ooOh00<0ooOh00@0ooCd
0?ogn03omoP0ooOh1`3oool20?ool`80ooOh103oool20?ogn0D0oooo00X0ooCd0?oom`3oool0onG_
0?OTm03cm?@0mnO`0??fn03ol_P0oooh0`3oool0103gmoL0oooo0??dl`3cm?<20?Ogm`030?ooo`3g
ool0ooOg0080ooOg0P3oool01@3oooP0mOOd0?Ggm03em?l0lOoh00<0mOOh0P3oool01@3om?@0ooOh
0?Ggn03om?P0mNgd0080ooOh00d0oooo0?Ooo`3cm_@0moKo0?Oom03oooP0mooh0?Oom03gooP0oooh
0?Ooo`3oool0mooo0080loCd00@0lng^0?OUeP3H^J`0mmgG3P3oool20?ogn1d0oooo0P3omoP00`3o
ool0ooOh0?ogn0020?ogn0040?ooo`3omoP0ooOh0?ooo`80ooOh7@3oool001L0oooo00<0ooOh0?oo
o`3omoP00P3omoPn0?ooo`0;0?Ogn038//H0C3`o06UJB@3@e=H0e]cW051IH@2/ZJ@0oooo0?Ogk03g
mnl00`3ooo<00`3oooL0ooOh0?odm0020?ogn0<0oooo00L0ooOh0?ooo`3omoP0ooOh0?oom`3ooo<0
ooog0080oooo00<0ooog0?ool`3oooL00P3oooL30?ooo`80ooOh00<0oooo0?odm03omoP00P3omoP3
0?odm00<0?ogk`3oooL0oooc0?OTm03oool0mnko0??/n03cl_P0ooKo0?ogm03om?l0mngg0P3cj?<0
1@3gkOL0ooCo0?odo`3om?P0ooCd0080mng]0`3om?@20?Gdm0080?Gdn03omol0ooOo0?G_m03em>h0
mOCd0?ogn03om?@20?ogn0070?ooo`3gool0mooo0?G_n03emol0ooOh0?ooo`020?Oon0070?ofn03g
m_@0mooh0?Ooo`3oooP0mooo0?oon0020?ooo`0:0??oo`3gmoP0oooo0?Ogn03cm?@0ooO_0>cEa@3H
^J<0fL[40?O_l5D0oooo000C0?ooo`H0ooOh0`3oool20?ogn080oooo0P3omoPh0?ooo`090??]kP1o
JFh0PhA/0?ooo`3Uk>d0QiFQ06IeN`3gknL0moO/0080oooo0`3oooL00`3oool0ooOh0?odm0020?og
n0050?ooo`3omoP0ooOh0?ogn03oool00P3omoP30?oom`80oooc00P0ooog0?ooo`3ooo<0oooo0?oo
m`3ooo<0ooog0?ooo`D0ooOh00<0oooo0?ogn03oool00P3oool02P3oooL0moOh0?Ogm03gmo@0onG_
0?ooo`3gk_l0mooh0?Ogm03omoP20?Ogm`D0oooo00<0moOd0?Ogk`3oooP00P3ooo@00`3oooP0mNkh
0?o^n0030?ooo`040?Ggn03eool0mOOh0?ooo`80ooOh0`3oool00`3gool0oooo0?Ooo`020?ogn00F
0?ooo`3coo@0lood0?Oon03coo@0oooh0??oo`3oool0ooKd0??fm03cm_P0moKh0??oo`3gmoP0oooo
0??gn03gmoP0ooCd0?Ogn03ogLl0g/Vc0??Ie1P0oooo103omoPi0?ooo`00403oool20?ogn0030?oo
o`3omoP0ooOh0080ooOh00<0oooo0?ogn03omoP00P3oool20?ogn080oooo0P3omoPg0?ooo`0:0?Og
n02l]/40DTU30<S<cP3^moP0[;^n07=/J`2n`lD0moO/0?Ogk`D0ooog103oool0103omoP0oooo0?od
m03omoP50?ooo`030?ool`3oool0oooo0080oooo00H0ooog0?ooo`3ooo<0oooo0?oom`3ooo<30?oo
o`040?ogn03om?@0ooOh0?odm0D0oooo00`0moC]0?O/k`3ofnd0mn3_0?O^o`3geML0ll?60?O8d03o
cm`0lmCK0?oKgP3ocML20?GAe`0=0?GAf`3bh>T0omgU0>cUi`3bh>h0mnG^0?oom03oooP0mNkh0?Gf
o`3amoP0mOOh0?Gdm0030?ogn080mooo0P3oool00`3gool0looo0?Ooo`020??on0<0oooo01H0mooh
0?oon03goo@0mooh0?oon03gool0looo0?Ofn03cm_P0mo;d0??bn03gooP0oooo0?ogn03cmoP0mooo
0?O_l03oool0mno`0>CLb`3g`;80mno`5`3oool40?ogn1T0oooo0P3omoPN0?ooo`00403oool20?og
n0@0oooo103omoP00`3oool0ooOh0?ogn00l0?ooo`0<0?Ogn01gIFT0QgUY0?Gdk03>eMd0Kf]W0:bZ
]P3gmo@0ooog0?ooo`3oooL0oooo103oooL30?ooo`@0ooOh1@3oool00`3ooo<0oooo0?ooo`020?oo
o`040?oom`3oool0ooog0?ool`80ooog00L0oooo0?ogn03omoP0ooOh0?odm03oool0ooOh0080oooo
0P3omoP03@3oool0onC]0?oMi`3om_P0mmCF0??3aP3oool0llgD0?OUl03oool0lno]0?oXl`3okoL0
0P3ei_L02P3ei^l0l^7X0?oEi`3/e>L0l^7X0?OAh@3/b=`0k=CR0?oTkP3oool20?Ggn0040?ocn03o
m_l0ooKh0?ofn080mooo00D0ooKh0?Ofn03oool0loKh0?ofm0020?Ofn0080??om03gmo@0ooOh0?oo
o`3gool0looh0?oon03oool20?Ooo`80looo00H0ooKd0?Ofo`3goo@0oooo0?ofn03clo@30?ogn004
0?O_l03ZkNP0hkRT0??A_2<0oooo0P3omoP60?ooo`80ooOh00<0oooo0?ogn03omoP00P3omoP20?oo
o`80ooOh3@3oool00`3omoP0oooo0?ooo`0>0?ooo`004P3oool20?ogn0050?ooo`3omoP0oooo0?og
n03oool0103omoPl0?ooo`080>kUn01HAC80/K:f0>GWh@1PPY80T9F@0?Odi`3gm>P30?oom`030?oo
o`3oooL0ooog00@0ooog103omoP40?ooo`80ooog00<0ooO/0?ogn03oool00`3oool20?oom`040?oo
l`3oool0oooo0?ooo`<0ooCd103omoP0303oool0ooOh0?ooo`3omoP0om_X0?ooo`3om_P0fMC@0>:l
_@3om_P0llgD0?OUl080mno_0P3oool20?Gfl00@0?ooo`3ei_L0k?Oh0?O_k`3oool0mOK`0?O^l03/
kOL0k=c/0>CDh@3/e>80lN3^0?Ggn03eool0oooh0?ofn080mooo00/0ooKh0?Ooo`3gl_@0mooo0?Oo
n03oool0ooKo0?Oon03gmo@0ooOh0?ooo`020?Ooo`80looo0P3oool0403gool0looo0?Oon03gm_P0
ooKd0?ooo`3om_P0mo?d0?Ogn03gm?@0moOh0?Odm03gmoP0j^3L0=jkY`3SeMlR0?ooo`80ooOh1P3o
ool20?ogn0030?ooo`3omoP0ooOh0080ooOh4@3oool00`3omoP0oooo0?ooo`0>0?ooo`003`3oool2
0?ogn0040?ooo`3omoP0ooOh0?ooo`80ooOh0P3oool00`3omoP0oooo0?ogn00m0?ooo`0;0<jf_@1H
ET00fMCF09RWZ@1JI7H0lnCW0??gk@3gmn`0oooo0?ool`3oooL00`3oool40?oom`80ooOh00<0ooCd
0?ooo`3oool00`3oool01P3oooL0oooo0?ogm03ok_l0mnCd0?Odm0<0ooOh00H0oooo0?ool`3oool0
oooo0?ogn03oool30?ogn0030?ooo`3omoP0oooo0080ooOh00<0onG_0?oDh@3oiNl00P3oool00`3J
onl0f_K]0?>lb`020?ooo`040??Xj03oool0oooo0?ooo`80mOK`00<0oooo0?;Qk03bhN`00P3oool0
2@3em_00oooo0?Gfl03/mol0i?Co0?o_m`3gj>`0k]W]0>_/n0020?ofo`0>0?Ooo`3oool0looo0??f
n03cl_P0moKh0?obi`3ol^l0oooo0?Oom03cooP0mooh0?ogn03gmoP30?Ooo`80oooo00X0mooo0??o
o`3gooP0loKo0?Ofn03oooP0mooh0??oo`3gool0moCd0P3gmoP01@3om?@0mno]0>[D]@3R_KD0onoW
01P0oooo0P3omoPh0?ooo`003`3oool20?ogn0H0oooo0P3omoP00`3oool0ooOh0?ogn00m0?ooo`07
08M]K01]MgH0g^C`05aYM@2/Z;80mngU0?Ogk0030?oom`080?ool`3oooL0ooog0?ooo`3ooo<0ooog
0?ool`3omo@30?ogn080oooo00T0ooog0?ool`3ooo<0oooc0?ogk`3omo@0onC]0?O^o`3gmoP00P3o
moP00`3ok_l0onGh0?ool`020?ooo`L0ooOh00@0oooo0?oMi`3oe>40omgW0P3oool20?oDe`060?oo
o`3om_P0ml[N0?O1eP3ogNL0lnSX0P3oooP30?ooo`030?GVk`3ZkNl0lnSX00<0oooo00T0mOK`0?oo
o`3em_00oooo0>cgo`3gk_00k^kW0?;Vk03gknl00P3om_l01@3gool0looo0??oo`3cooP0moKh0080
mnk/00D0ooKo0?Ofn03gm_l0looh0?ogn0020?Ogn0080?ogn03oool0oooo0?ogn03om?@0ooOh0?Oo
n03oool30?Oon00:0?Ooo`3oool0moCd0?Ogn03oool0mno`0?Ogn03ZkNP0f<Zi0=[:bAH0oooo103o
moPT0?ooo`80ooOh4P3oool001L0oooo103omoPl0?ooo`0:0=[<c`2TThX0Ecli0=kbn019FF80OXN9
0?Ogn03ckND0loC]0?ooo`P0ooog00<0ooO/0?oom`3omoP0103oool01@3ooo<0oooo0?ooo`3omoP0
moOh0080moO_00L0mooo0?odm03oool0onGh0?ogn03oi?@0oooc00@0oooo0`3omoP0103ogNL0omCQ
0?oDh@3oiNl20>?^g`80oooo00/0omCG0?NY[P3c`lH0jk2m0>JN^@3[Z[P0ll[80?OUgP3ol^h0mNCR
0?7Kd@020?7Tf`050?o<cP3bhNP0mno_0?ofl03om^h00P3em^h20?7bkP0=0?oon03oool0mOK`0?Gf
l03Tm?l0mnOX0?;Ef`3bgNl0lo;h0?Obn03gm_P0mooh0??fm0020?O^m`070?ook`3gm^l0ooKh0?Of
n03oool0mooo0?Ogn0050?ogn0030?odm03oool0mooh0080mooh00/0ooKd0??fn03oool0moOh0?og
n03cm?@0loOh0?o_l03om?@0mnG>0>>kX`020=[<_P030?ooo`3gko00mno`0140oooo0P3omoPV0?oo
o`80ooOh4P3oool001<0oooo0P3omoP40?ooo`80ooOh>P3oool02`3gmoP0h]CN0927S02i_/D0SWQj
05U[N`2ZViD0ooOW0?Odk@3gmoP0moOd0080oooo0P3oooL01`3ooo<0ooog0?ool`3oool0ooog0?og
k`3omoP01@3oool20?oom`0<0?ooo`3om?@0loOh0?Odm03omoP0mooo0?odm03omoP0mnO`0?OTm03o
moP0oooc0P3oool0103omoP0ooCd0?ogn03oool20?oUk`80oooo01`0omgW0>?_n03SkoP0omgW0?of
n03^k>D0jlg<0??_i@3gknD0ooK^0>c[iP3Zh>80lN3Q0>[]k@3bkN`0oooo0?GXj03aknl0mNcX0?ob
j@3om^h0oo;^0?ofn03aiNL0mN3Q0?G/k@3em_P0lO;^0`3al^T01`3gk_00i??`0?o^l03ehN`0looh
0?Oom03cl_P00P3cm_l01P3ol^d0ooK_0?ofk`3om^l0mo;o0?Ofm0<0oooo103omoP20?odm080mOoo
00@0oooo0??om03cl_l0mo;d0P3oool20?Odm0050?Ogn03omoP0moOh0?O]kP3gk^D00P3A[Y/00`3o
moP0mno`0?O_l01=0?ooo`00403oool20?ogn0030?ooo`3omoP0ooOh00<0oooo0P3omoP00`3oool0
ooOh0?ogn00h0?ooo`090?Odm02=PXX0T8n40<_2^@3NcLH0>3i>0>cUl03omnl0moOh0080oooo00D0
oooc0?oom`3oool0ooog0?ooo`020?ogm0030?oom`3ooo<0ooog00H0oooo0P3oooL03@3oool0ooCd
0?Odm03gm_P0mnc^0?Ooo`3om?@0ong^0??gn03ckNh0ooOh0?ool`3oool0103omoP20?oUk`<0oooo
0`3ogNL02P3geML0jm7>0>k5d03oeML0k=gO0>[PhP3ah>40j^GU0??dm03oool20?Ogm`030?ooo`3e
knl0lNSX0080lNSX00H0lN3Q0>[Wj03ZkNd0mNo_0?ooo`3oknl20?oXj00=0?o_k`3oool0oooo0?7b
j@3/m_00k>_Y0?OMi`3[j?L0jnoh0?ofn03oooP0oooo0?Ofk@020?ook`070?ofk`3om_l0mooh0??o
n03gm_P0ooKh0?ogn0020?odm0070?ogn03om?@0ooCd0?Goo`3emoP0ooOh0??om0020??fn0090?Oo
o`3oool0ooOh0?Ogn03omoP0moCd0?ooo`3omoP0mnoW0080h[FF00<0k^G`0?ogn03oool0C@3oool0
0100oooo0P3omoP60?ooo`80ooOh00<0oooo0?ogn03omoP0=`3oool02@3gmoP0b;3407iiK03FdLd0
dL[>06IdS@2@Ui80ooCQ0?Ogn0030?oom`030?ooo`3ooo<0ooog0080oooo00@0ooCd0?ogn03omnl0
ooog1`3oool03P3ooo<0oooo0?oUn03ok?P0moCd0?Obm03ojnh0loOh0?Odm03gool0looo0??gn03o
kNh0oooc0`3omoP00`3ogNL0om_X0?oUk`020?ooo`80ooKh0140moO`0>_]hP3[dM00mlS@0??<c@3o
h>40mNCU0?;cm03gh=/0k/;40>^k_P3[fMH0jmcN0?;Dd@3eh=/0onSX0?OXj0020>_Wj0050??]k03g
moL0loCd0??dm03oool0103gmoP05@3oknl0mng]0?Ogn03em_00j_Oo0?oVj@3oool0mnkW0?O_l`3g
knd0ooKo0?oom03gm^l0ooo_0?ooj03^onP0k_K_0?ofk`3goo@0moKh0?ofn0020?ooo`<0ooOh00P0
mOoo0?Ggn03omoP0ooOh0?Oon03oool0ooKd0??cm080ooOh00<0moOh0?Ooo`3omoP00P3gmoP01@3g
kNh0j/RV0>[8YP3giMh0k^Cd04h0oooo000A0?ooo`80ooOh1P3oool20?ogn0030?ooo`3omoP0ooOh
03H0oooo00T0h]c^08f0QP2PYHd0al_E0=78c0002bP0loC_0?ogi@3gmoP00`3oooL00`3oool0ooog
0?ooo`020?ooo`80ooOh00<0ooCd0?ogk03omoP01@3oool20?oom`040?ooo`3gi?@0loKh0?O^l080
ooKh0P3gjnh20?Obm0040??/kP3oko00oooc0?odm080ooOh00<0om_X0?ofn03ol_@00P3ol_@06`3^
knL0jlWF0?O8d03ce=/0mmGN0??Xh@3/iMl0j_Oh0>;VhP3^fMH0k/750>?De`3RfMh0h[ZW0>jbU@3A
]jh0hZZ[0?nZ]03g^/D0e[Zl0=6X[03T[kD0lZjf0??2b`3gj>P0loCd0?Ogn0020??cm080moOh01H0
moOg0?O]k03oknl0mnk`0?OVj@3ok_00onKY0?ooo`3oknl0lno_0??bn03ol^L0ooK_0?Ock03gmoL0
k_oo0?obk`3cm_P0moKd0??om03gooP0oooo0P3omoP0103eool0mOCd0?7dm03oool20?ogn0060?Oo
n03om_@0lo?d0?ooo`3gool0oooo0P3gmoP00`3omoP0oooo0?ogn0020>cEa@040?;A]03oknD0k^C^
0?ogn4`0oooo000>0?ooo`030?odm03omoP0oooo0080ooOh0`3oool20?ogn0070?ooo`3omoP0ooOh
0?ooo`3omoP0oooo0?ogn0070?ooo`80ooOh00<0oooo0?ogn03omoP00P3oool20?ogn2<0oooo00`0
moOh0>_TkP2ISiD0XiR40;Zf/P38c<h0cMcU01dX>03ogNL0mnkg0?Ogn03oool40?oom`080?ooo`3g
moP0moCd0?odm03omoP0ooC]0?ogm03omoP50?ooo`060?ool`3omoP0ooOh0?Odm03cm?@0mo;d0P3o
ool20?Ogm`0b0?ooo`3ok_00lnCV0?ogk`3omo@0ooCd0?oLi@3ofnP0onoW0?Ogl03ci_@0jn3]0>_5
f`3[aM@0mmGN0??Xh@3SfM<0i>3M0>cfn03Rk>h0jl:f0>>WW`3ZZZT0j/2j0??Aa03TflX0iInD0>>E
MP3Ri]h0mnkX0=kghP3^iMH0c[Va0=RbW03Hm=`0jnC>0?Nm_@3c^;d0b=7F0<S_k@3Re=`0hmCU0??/
n03[k>h0moOh0??dm03gmoP0mno_0?Ooo`3oool20?o^l00>0?ooo`3ckn`0lnGd0?ofn03om^l0lncd
0??dm03oonP0oo;o0??bo`3gm_l0loKh0?Ofo`3olo@30?Gdm00@0?7gn03emoP0mOCd0?Ggn03om?@0
mooo0?ooo`3cool0moOh0?ooo`3omoP0ooCd0?ooo`3om?@0oooo0?Ogn080mnoW00L0h/2d0>GUc@3[
joP0jnO`0>kTm03gkNh0mno`04T0oooo000>0?ooo`030?odm03omoP0oooo0080oooo0P3omoP00`3o
ool0ooOh0?ogn0020?ogn0030?ooo`3omoP0ooOh0080ooOh0P3oool20?ogn0<0oooo0P3omoP00`3o
ool0ooOh0?ogn0020?ooo`80ooOh8`3oool02P3gmoP0_JJl08n:R@38`k`0_[Zm0>_Ti@1nS9D0IW5k
0?oUk03oiOP20?ooo`0;0?ool`3oooL0oooc0?oom`3oool0moOh0?Odm03om?@0ooOh0?odj03oool0
0P3omoP20?ooo`80ooOh00P0ooO/0?ogn03omoP0mno`0??gn03gl_@0moO_0??dj080moO]03<0moO_
0?OVj@3gm>d0ooC]0?odm03oi>d0onKO0?OckP3cdMH0k]CL0??dj03ogND0omGG0?OPf`3/bl/0g/S5
0<O5`@3JeLh0iLS10>[Td`3R_Jl0lm7;0>?_m03Hj>d0f>Sd0?O^k03ch=H0k/bf0>kUf`3Ak?P0mooh
0>cgn03JdKd0j/6b0??Vm03Ak>P0g_OY0>k3]P34b;d0a<c30?GAd03geLH0c]7N0:Cdj02ci^80mnGW
0?Ogn03gm?@0onGU0?ogn03oool00P3ok_00103gooL0mnoc0?o/m`3om^l20?Ock00I0?ooo`3ol^l0
moKo0?Ofo`3gl_P0moKo0?ocm03emoP0ooOo0?7do`3emol0oooo0?Goo`3emoP0ooOh0?Ofn03om_P0
mooo0?ogn03oool0ooOh0?odm03gool0moCd0?ooo`030??dm0070?OTgP3ZcZH0moKh0?Ogn03oool0
mo?d0?O_l0190?ooo`004`3oool20?ogn0<0oooo0P3omoP00`3oool0ooOh0?ogn0020?ogn080oooo
0P3omoP_0?ooo`090?O_l02?P8d0_<Fd0<C8`03Ncm40h]gO06UYL02X//T0moOd00<0oooo0P3oooL0
2@3oool0oooc0?ooo`3omoP0ong^0?Ooo`3gm?@0ooCX0?ogn0020?ooo`0U0?ogn03oool0ooOh0?og
n03omn`0onch0?O/n03omoP0moKh0?ofn03cm>P0oooo0?o_n03oj?@0lnGQ0??Ph`3oknD0ooOh0?oL
i@3^eMH0i^3Q0??;g@3ogNL0mnGh0??Km03oeMl0al>f0;g8`03Hg=/0mnoo0>;Li@3SfN40ml>]0=[T
gP3giNP0lZ6I0?NLQ@020=jHQ@0X0?NVT03c_JL0mlb[0?OD/P3ckM@0dNg^0>[dkP3Ih=H0k=790?O^
m03IjoP0f_Ko0?>m`03>c<40d<[10?oUg`3[e<<0fL_>0=[8c`3>hND0b=WN0>kgk`3oknl0onSX0?od
m03oool0onk`0?ooo`3ok_00moog0?OPm`3om_l0ooK_0?O^k03gmnd0ooKX0?ofo`3cl_l0mo;h0?Oo
n080ooOh00<0mOCh0?7]n03oool00P3am?P01P3ekoP0ooOh0?obm03gl_@0mooo0?odm080ooOh00D0
ooCd0?Ogn03gmoP0oooo0?Ogn0020?O_l0060?ogn03bdJX0j^GG0>_Tm03^i?@0k^Gh;`3oool20?og
n0030?ooo`3omoP0ooOh01H0oooo000G0?ooo`80ooOh103oool00`3omoP0oooo0?ogn00M0?ooo`80
ooOh4P3oool02P3^iOP0_[[50;BVYP3>fM00]kJi0>[If`1jRYl0HW=m0=7Lj03gmoP20?ooo`80ooog
00X0oooc0?ooo`3ooo<0ooOh0?O_l03gmoP0loKh0?O^l03gj=`0oooo0`3omoP01@3oooL0oooc0?oo
m`3oknD0mnc^0080ooKh0400k^kW0??Uh@3/fMh0lMCK0?7PhP3biND0k/c?0?OUg`3oi?@0k/;10>JP
Y`3^`lD0olgG0?OAd`3Ij=00a=6i07n8OP0oGfH0VK[=0<61QP33JW@0hkFb0>_Lk@3Uc<d0g/o40>cM
g`3afm`0oooo0>[0a@3IThX0eW=R0<]VD@3;LF<0dIbA0=R`X`3>e=@0bl_50>^ZZ03eb</0hmW<0?ne
Z03oWiL0oi650>^GT@3Rfm00f=c;0=k[hP3ak=d0mmC60=VZ[03g][d0fLcG0<C]m02bk^D0b=cE0?OI
f`3og=`0mmCC0??gk@3gooP0lncW0??gl`3okoL0ooo_0P3gmoL02P3^ool0oo;_0??bo`3ol_@0oooo
0?odm03oool0mOCd0?7]kP3emoP20?oon0060?Ggo`3ekoP0onk`0?ofn03oool0ooCd0P3oool0103o
m?@0moOh0?Odm03om?@30?ogn0070?odm03Zi</0omC60=K9c`3SfN80onSL0?o_i`0^0?ooo`80ooOh
00<0oooo0?ogn03omoP05P3oool000l0oooo0P3omoP60?ooo`80ooOh0P3oool20?ogn0030?ooo`3o
moP0ooOh01d0oooo0P3omoPB0?ooo`090=K6eP2WZ9/0h^SY0;2eZ02TXjL0iNg]02aJJ@38_K`0oooc
0080oooo00d0ooog0?ooo`3oool0oooo0?ool`3oooL0ong^0?Ogn03gool0moKh0?O^l03cj=`0ooOh
00<0oooo02P0ooog0?ool`3oooL0mnSL0?ooo`3om_P0k^k_0?OVi@3okoP0lO;d0?ogk`3ok^L0i<g@
0??Pf`3oko00k/_50>>j]@3ab]@0fM_@0:>m/P2Wd<D0hnc/0>_2]02IDEH0JRhm0650F`3JShd0jkfb
0=6GQ@3FUiL0hX250>JBU`3VYjL0hkJd0?7:e03RQ8H0ml>f0?odk@3oool0ooO/0P3gk_00;P3cdL/0
iHb60?N5Q03cSh<0lij;0<^<Q@3IP7T0hX]m0=6VW`3NkMd0mMCK0>:n[`3og<`0lNcV0=kPg03^i>40
moOh0??_l03eg=h0anod0<GMgP3Rl^h0mnC^0?O;eP3gg=h0mmGG0?O/l03oj?<0ooo_0?ooo`3^koP0
k^ch0?Ook`3oooP0moKh0?ooo`3om?@0mOOo0?Ggm03gmoL0moO_0?oom03oooP0oooo0?7do`3om?@2
0?ooo`070?odm03oool0ooOh0?ooo`3gm?@0moOh0?ooo`030?Ogn0090?ooo`3Nkn40k^3N0>[db`3S
iOP0dMWM0=[<aP3okND0ooOh02L0oooo103omoPL0?ooo`003`3oool20?ogn080oooo0P3omoP60?oo
o`80ooOh103oool20?ogn0<0oooo0P3omoPY0?ooo`0:0:BLZ`2c]Zl0f]gG09>?PP3:aLT0Ni:W05Y/
K03giO@0ooog0?ooo`80ooog00L0oooc0?oom`3oooL0ooOh0?odm03okNh0moKh0080lo;d00<0onOY
0?Ogk03oool00`3oool20?ogn00W0?oom`3gj>80ooKh0>k^k`3gi^L0ono`0?Gfn03ek^L0moOX0?;b
i@3Zcm40mnOU0>:OY03RUjL0k;W30;Ff^@1:S9`0S;[=09fOY03FYjT0cZ2T0=78a02mZJ@0b:2E0?OU
e`3oool0mmC70?>kY`3gb;H0onKA0?o8_@3^[Y`0jiNK0>^?QP3om>d0oooo0?ogn03omn`0oooo0080
mn_Y02T0fMC@0>?_n03/m>D0hnGh0?ofl03RkOP0hn3N0>>^Y`3SSh@0iJ2;0<gUhP3b[ZT0ml>i0=[A
b`3Ik?P0h^GQ0>kTh@3Tcl/0c^Sd0:c_m`3Ai^L0k?oh0??Pi@3oool0k_C]0?oPh`3gj?<0moo_0?oo
o`3^koP0k^ch0?Ook`3oooP0moKh0?ooo`3ekO@0mOOh0?oon03gm?<0ooOg0?Ogm`020?oon0030?Gg
o`3ekO@0oooo0080ooOh00L0moOh0?Ooo`3omoP0ooOh0?ooo`3gmoP0ooOh0080moOh00X0oooo0>Gg
k@3Ufn80lnC40=SAg`3Jc<H0hnkU0=7=i@3NdMh0k^G`9P3oool40?ogn1`0oooo000@0?ooo`80ooOh
00<0oooo0?ogn03omoP0303oool20?ogn0<0oooo0P3omoPY0?ooo`0;08YiQ03AdL@0e]3809nMX@3b
mo@0BFEk0;>[X`3gon`0oooo0?oom`3oool00P3oooL02P3omo@0ooOh0?ogn03om?@0ooOh0??bm03g
m_P0lo;d0?OPf`3oooL20?ooo`@0ooOh01P0oooc0?OXj@3gl_@0loC/0?oXkP3em_P0mNkW0>k_i`3g
kNd0l_;U0>cLgP3RZ;@0fJ2T0<kAb`2]b<T0XnGW0;G5e01@FW<0VI2E0>?Ie@3gd<T0oo;Y0?o]i@3o
h=020?ooo`090?oom`3omo@0ooCd0?ogn03oool0ooCX0?OCa@3gdkT0ooCd0080oooo00T0ooCX0?oo
o`3om_00oooo0??Pd03om=`0mnk`0?ooo`3gk_000`3oool05@3SkoP0ljRS0<Z?T@3RfMh0h^kh0=7P
iP3SiML0g]cO0?O^n02i][<0f_Ch0<Cdm02oloP0amgO0?G^l03ch>D0lnGU0??Kf`3[kn`0lnoo0?oo
k`020>koo`0C0?ofo`3gond0moKh0?ooo`3ekO@0mOOh0?oon03omoL0loOg0?Ogm`3gmo@0oooh0?Gg
o`3ekO@0oooo0?odm03omoP0mooo0?Ogn0030?ogn0030?Ooo`3gmoP0oooo0080oooo00X0ooCd0>[/
h@3cdK<0hmc^0>?Tm03Ab>80hmGO0>cVk`3NdMh0ooOhA@3oool00100oooo0P3omoP20?ooo`@0ooOh
00@0oooo0?ogn03omoP0oooo0P3omoP20?ooo`80ooOh1@3oool20?ogn2P0oooo00/0KEYK0:bk]P3>
c<h0dLgC0;cDh@0mC5/0k>G`0?Ogm03oool0ooog0?ooo`020?oom`090?ogm03omoP0oooo0?o]kP3o
moP0lo;d0?Ofn03gk>h0onoU00<0oooo0P3omoP20?ooo`0H0?ool`3gj>T0mo;d0??Uh@3okoP0lN_U
0>k_i`3^ko00jnKK0??Pj03Z/[d0ainS0;W2``2`a]@0c]W^0?ODhP2o`/d0[Gac0=kLc@3cknD0oo?^
0?ooo`3ojn<0onkX0P3oool20?oom`80ooOh0P3omnl01P3ol^T0oo;L0?odm03oool0ooOh0?ogk080
oooo00D0mn_Y0?O]g03om=`0lnKR0?O^i`020??Vj@0Q0?O^l03oool0oooo0>C?_`3[X:@0hWMg0?=o
M`3SVXd0dMg>0?oDd03Rb<@0bjji0=SPj@3=fMh0_NoU0:cVi`37gMl0i?od0>[PiP3ge=H0moo_0?OX
k`3om_l0ooK_0?ooo`3om_l0moo]0?Ofn03oool0mOOh0?G]m03oool0moOd0080moOg00H0oooh0?Og
k@3emoP0lNgh0?G_n03omoP20?ooo`040?odm03oool0moOh0?Ooo`80moOh0`3oool02P3omoP0k>oU
0?oI_@3ggLH0hnGh0?ogn03Je>D0f<oQ0?;]i@3^i?A50?ooo`00403oool20?ogn080oooo103omoP0
103oool0ooOh0?ogn03oool60?ogn0D0oooo0P3omoPI0?ooo`D0mno`00<0mng^0?odm03omoP01P3o
ool02P3^iOP0HU=50;2k_@3Ti>D0k>CU0:Vb`@1?C5D0mnoU0?ooo`3gmo@20?oom`0;0?ool`3oooL0
oooo0?ooo`3omoP0mno`0?Ogn03gm_P0mo;d0??Ph`3ooo<01`3oool05@3ooo<0mn3S0>k^i`3ghND0
mOKh0?G/h@3VkNh0oooo0?O^k@3I_KT0_K2i0:[1cP36dMh0fNo/0>[DhP3R^/h0/InT0;jXW`3IkoP0
mncX0?obj@030?ofl00E0?ooo`3ok^P0onkX0?oom`3omnl0ooOh0?odj03ok^P0oncV0?o[f`3om>d0
oooo0?ogn03omn`0oooo0?ofl03ci=L0onGG0?oTd03ci]`0mnkU0080mnk`0240oooo0?O^l03oool0
k=W;0??[gP3^iMd0`]7K0<BWZ`2eNG00dJ2D0?GTj03[e=l0`NoU0=KUg@3Ih>P0T<WN07jbaP3Ig>D0
i>GU0?o;e`3[fMh0omgW0?oUk`3om_l0oooX0?ofj03gool0moKd0?ooo`3emoP0mNgd0?Ogm`3oooP0
0P3gmoL20?ooo`090?Ogk@3ekoP0mNoh0?ooo`3omoP0oooo0?odm03omoP0moCd0080mooo00<0moCd
0?ooo`3oool00P3oool02`3om>d0j^3R0?O]b03ch=/0f]GW0>k^o`3gm_P0jnch0?ogn03^i?@0ooOh
04<0oooo000@0?ooo`80ooOh303oool20?ogn0H0oooo0P3omoP20?ooo`@0ooOh4P3oool40?O_l0<0
mng^00@0mno`0>k/n03Vh?P0k^Cd103omoP03P3oool0e/KN08>0J@2X/Zh0j^GW0??/kP1bO9@0Ngan
0?odj03gmoP0moO/0?ool`3oooL0oooc0`3oooL01P3om?@0moCd0?Ooo`3gm_P0oo?d0?O]kP80ooog
0P3oool00`3omoP0ooCd0?ogn0020?oom`0H0>_De`3gmnd0onSd0?7[i@3^knL0mmc^0?OTm03A[/<0
a<7>0=3DiP3JiNL0k?og0?Ggm`3H`/40e]CN0:RTX`3[eMH0jmcK0?OPb`3oool0onkX0?ockP3ol^80
ooog0P3oi]L0203oool0oooc0?odm03om>P0onKN0?oom`3oi]L0ooCX0P3oool0203om>P0oooo0?o[
h`3giM/0lmcU0??=a03gi]H0mnkU0P3gk_00:03oool0mnk`0?Oon03gh=H0f?KL0<_Xo`3IkoP0h^od
0<SEg`2ILfL0cJ2U0=k1e02dTZ<0_:Z/0<KTk@3@iNl0JmGW08Nkc`37gMl0j^3U0>_Wi@3cb=H0mno]
0?o_m`3oonl0oooo0?ofk`3cm_@0oooo0?odm03am?l0moO]0?ooo`3gmoL0oooo0?Ogm`3oool0moOd
0?G_l03ekO@20?odm0070?Ooo`3gmoP0oooo0?Odm03gool0oooo0?odm0020?Ogn00=0?Odm03omoP0
ooCd0?O^i@3Zg=L0_/;40;FX[03Ab=40e/kF0=7=i@3emoP0oooo0>kTm0130?ooo`009P3oool20?og
n080oooo103omoP?0?ooo`80ooOh00<0oooo0?O_l03gko000P3oool40?ogn0030>kUn03Vfo@0k^Cd
0080ooOh0P3^k_l02P3FcND0[:2E09FEQ02a[j/0j]cN0<O<eP13CV00b<;60?ogn03ooo<20?oom`0=
0?ooo`3omn`0ooOd0?oom`3omnl0mno`0?Ogn03oool0lo?d0??^l03gm?@0mnSY0?o_i@020?ooo`80
ooOh02D0ooCd0?ogk03okNh0i/W<0?GIeP3ah>80mNcQ0>K]kP3gk_l0mmg`0:QiW@3^koP0h^C^0=[T
i@3/mnl0l_Cd0<?1_02c]//0c]cC0?G2c03[e=00mlS;0>JFR`3^/Zh0onGN0?ofi`3og<@0omW<0?oM
c`3ok]l0ooog0?ogk03oiLh0ml_60??Dg@3ge<l0onG=0080ooCd00P0onkM0?o[h`3ogLl0mmgO0>_T
k03^eMD0jl:[0??Pd0<0mnk`0200oooo0??UeP3Rc<D0mmBm0=W_n03Jkol0oooo0>?_n032^K`0`X5h
0:]nO`2SR940CdYS07]gT01KP9D0J7b=0;kUgP0m/]00JZVn0=3/j03Tblh0hlG10?OEeP3gk?@0moKQ
0?ofj03cm_@0oooo0?G]m03emoP0moO_0?Ogm`80ooKh00d0oooo0?Ogm`3gmoL0oood0?Gdo`3amol0
mOOo0?Ogn03gool0moCd0?Ogn03cool0mooo00@0moOh0P3omoP02`3em>`0h^kY0=78g02`Zj00OgQY
0:fbY`3AblD0dL_M0>GWk@3[i>h0mno`0480oooo000A0?ooo`80ooOh:@3oool00`3omoP0oooo0?og
n00>0?ooo`80jnCd00X0d<cN09bFM02ZWZ40aL[G0?Ogm01^Pi/0Nh>40?Ogk03cm>d0moO/0P3ooo<0
3@3oooL0ooOh0?ogn03oool0ooOh0?O]kP3oool0mooo0?O]kP3gm?@0lnk`0?Obm03gh=H00P3oool0
E@3omoP0oooo0?ogn03omn`0ong^0>K?d@3RfM00k^GK0?O]j03Sm>T0moOd0?OgkP2ZR9T0`/KK0=oQ
k@3AgO00f^CU0>?gk`2d_/P0Z:V^0?;[m03ac=H0k]G?0>?D_@3eiNP0jkc;0?OIe03om>P0omWR0?O[
m03ggNP0omc<0?ofl03oool0omW50>_AeP3ckN80mm_^0?o^e@3ok]d0ooKU0?o^eP3oi]d0k]G>0??;
f`3ci>d0moOd0?OPj03gi=H0onkO0?O^l03gooP0lood0>_=_@3Zg<d0g[FL0>;]k@3Jkol0f^og0>?g
k03RkND0k=W>0?O_l03/iNd0c/g809Z>VP2RVZL0Sj:f04m]P`29]//0S=WU0=[Ii@3SiN`0h]WK0>kD
d03^h>D0moK]0?ofk`3cl_P0ooKh0?G]m03emoP0loC/0?ooo`3ol_@00P3om_P03@3gool0ooOg0?Og
k`3em?P0lOCh0?Gdn03oool0ooOh0?Ogn03gool0loKh0?Ofn03gool00P3omoP03P3oool0ooOh0?oo
o`3ekNd0j^_R0=W@i@2IV9d0UHjD0;VocP3Si^D0ln_C0>[Ve@3Zi>l0h]WY603oool20?ogn2P0oooo
000A0?ooo`80ooOh1@3oool40?ogn0<0oooo0P3omoP00`3oool0ooOh0?ogn0020?ogn0040?ooo`3o
moP0ooOh0?ooo`@0ooOh3P3oool20?ogn0`0oooo0P3omoP03`3oool0h]CN0>;DgP2/V9/0KW5N0:bX
ZP3Zk>h0hnko03mML032/Zh0mnCX0??/n03gk_l0onGd0?oom`030?ooo`0:0?o_l03oj>T0ono`0??f
n03clo@0moCd0?O]kP3cl_@0moKh0?OPeP80oooo0P3omoP20?oom`1A0?OPh`3Ra/40g]WD0>KLd@3c
j>P0joOY0>kgkP3^iMh0fJne0<>^Z@2l`K80^[^m0;Fba`3Fh>D0aLSF0;O1^@3Zm_P0k=_U0?GWi@3a
inD0lOoX0?OAgP3[c<h0k]gO0?oKm03[iM@0jmcK0>k:a03ok=/0onKA0>k1]03^iNl0i^SF0?oUn03g
i>d0lnCC0?OAd03^_[d0i[:n0>jfa03gdMH0mmGF0??Df`3ge>D0k]GO0?OPe03okMH0moCQ0>_Tf`3S
^J/0l/_G0>BUZ`3Zk=D0f^oc0?Ogk`3gmoP0k=cN0>;LgP3cj=`0oooo0?ogk03;h>h0f?;o0>;cn02I
TYl0^K_10?O8e03@k_00hnG`0=[Eg`3N`/<0omCN0?Ocm`3om^l0loK]0?ofn03omoP0lNgd0?Odk03g
ool0oo;d0080ooKh00H0mooo0?ogm`3gmoL0mOOd0?G_n03oool20?Odm0050?Ogl03oooP0ooKd0??f
m03gool00`3omoP03P3om?@0ooOh0?ogn03gk^D0k_o]0=78_`38`[H0jn_K0??bh@3gm^d0lo?U0>KP
b`3@`/h0k^Gh5`3oool20?ogn2P0oooo000@0?ooo`80ooOh00<0oooo0?ogn03omoP00`3oool40?og
n0<0oooo0P3omoP00`3oool0ooOh0?ogn0020?ogn0040?ooo`3omoP0ooOh0?ooo`@0ooOh703oool0
0`3omoP0hnGh0<Zje00208n6S@0<071[F@1dQX80a/cG0=W_n033fn80>DMK0??/f`3Ji>P0om_d0?oU
n03oiO@0ooog0`3oool01`3okNh0moOh0??fn03gm_P0ln3S0?Ogn03ok>h00P3gm_P00`3gh=H0oooo
0?ooo`020?ooo`0D0?oom`3gmo@0mn3S0>[3a03NfM40k]C=0?Oon03[iMl0lmcO0>[MgP3ahN80mL7?
0?Fla@3R[k80[HZA08j?S@2`]K<0dNCN0??_k`3/i?@20?G_n0080?GXk`3egN40mMWF0>jja`3V^L40
k]7>0?o<f`3^X:d20>Jm`00c0>jY]@3oe=H0k^KG0>_]hP3oiO00lnKo0?OMi`3J/Z`0j[[40?7Kg03a
i>D0lMCE0>cPf`3geMH0mmCK0??EeP3ccM00lloA0>c9c03//[`0jmcU0>:^]P3[a/T0loCd0?Ogn03g
iNL0h/^m0?oci@3gknD0oooo0?odj03Ik?@0mNkW0=Wfk`3>cm40h]cK0<fT^P3^m?L0cN3U0=7Ej038
c<d0j[g50??Tk`3ok?P0loK]0?ofn03oool0lNSY0?Odl`3gool0oo;d0080ooKh00d0oooo0??dl`3o
ool0oood0?7]n03oool0moOh0?ooo`3gooP0mooo0?Ofn03gl_P0moKh00<0oooo0P3om?@03@3oool0
oooc0??Ve`3gkmH0k>GX0>[Ug`3ooo@0moK]0?ooj03cl^D0j^GK0=[<g`3^iOP0@03oool00100oooo
0P3omoP00`3oool0ooOh0?ogn00d0?ooo`040>kUn03Fa]h0]InS08AiH`80N7QS00X0]K^d0=SPj03R
kNd0moOc076W^@1MF6d0h_C]0>?Tk@3gi?@0oooo0`3oooL0303omo@0moCd0?O_l03gmoP0mo;d0?Of
n03ginT0mno`0?O[kP3gmnl0lo?]0?OPeP@0oooo0200ooog0?Odk@3gi^T0j/SA0=k8^@3ofm`0i^3F
0?o[i@3biMh0k>oX0>k]g@3[in80jmWL0>_IeP3g`M00k;:i0=jTZ03TWJ80j[bj0?;9b@3o`lH0mm7@
0??Xg03Zkm`0l^od0?oAg@3odMH0onS/0?o/k@3egNl0mL7C0?o8h@80omg]01D0olSK0?NmbP3U_[d0
g[^d0>jf_@3Zb<T0k>OR0?G/j03oknl0mno_0>[cm03TfM/0j/G@0>[<eP3/cmH0mLgA0?G;d`3[iMh0
onkg0>c5d`3J][800P3gk>h0:@3/e=H0h]C90>_Aa@3omnl0k>kd0>cTh@3cm?@0joCU0=;^k@3@g=/0
f]WK0;NS^@3Rh=`0hoO_0<oUi`2oc=l0d;2l0>_Me`3oj>d0moK]0?Ooo`3om_P0lNS^0?Odk03gool0
ooKh0?obm03om_P0oooo0??dl`3oooP0ooOh0?Ggn03em?P0moCd0?Oon03gm_@0moKh0?obo`3gm_l0
moKd0080oooo0P3omoP03P3om?@0oooo0?oom`3ci]L0j^6n0?Ggm03/i^D0i=cF0>;LeP3gm_P0mo?^
0?ogm03FeND0k^3U@03oool00100oooo0P3omoP00`3oool0ooOh0?ogn00d0?ooo`040>kUn03Fa]h0
]InS08AiH`80N7QS00X0]K^d0=SPj03RkNd0moOc076W^@1MF6d0h_C]0>?Tk@3gi?@0oooo0`3oooL0
303omo@0moCd0?O_l03gmoP0mo;d0?Ofn03ginT0mno`0?O[kP3gmnl0lo?]0?OPeP@0oooo0200ooog
0?Odk@3gi^T0j/SA0=k8^@3ofm`0i^3F0?o[i@3biMh0k>oX0>k]g@3[in80jmWL0>_IeP3g`M00k;:i
0=jTZ03TWJ80j[bj0?;9b@3o`lH0mm7@0??Xg03Zkm`0l^od0?oAg@3odMH0onS/0?o/k@3egNl0mL7C
0?o8h@80omg]01D0olSK0?NmbP3U_[d0g[^d0>jf_@3Zb<T0k>OR0?G/j03oknl0mno_0>[cm03TfM/0
j/G@0>[<eP3/cmH0mLgA0?G;d`3[iMh0onkg0>c5d`3J][800P3gk>h0:@3/e=H0h]C90>_Aa@3omnl0
k>kd0>cTh@3cm?@0joCU0=;^k@3@g=/0f]WK0;NS^@3Rh=`0hoO_0<oUi`2oc=l0d;2l0>_Me`3oj>d0
moK]0?Ooo`3om_P0lNS^0?Odk03gool0ooKh0?obm03om_P0oooo0??dl`3oooP0ooOh0?Ggn03em?P0
moCd0?Oon03gm_@0moKh0?obo`3gm_l0moKd0080oooo0P3omoP03P3om?@0oooo0?oom`3ci]L0j^6n
0?Ggm03/i^D0i=cF0>;LeP3gm_P0mo?^0?ogm03FeND0k^3U@03oool004P0oooo00D0ooOh0=K9g`2I
T7@0MWMQ07f6Q0020;W6b@0;0>;Ph`3gk^h0fNSQ0>Cgm`0fLHH0V8220?Odj03cm>d0loCd0?ooo`3o
ooL00P3oool01P3omo@0moCd0?o^l03gm_P0lo;d0?Obm080mo?d02P0mo;d0??]j03[fmH0mngX0?oo
l`3oooL0oooo0?oom`3oool0onC]0?OgkP3RcM00g[bh0?oPj03Ve</0mNo`0?GUi@3gm>`0lnCR0?O^
o`3ck?P0mnC]0??Th@3ce=/0lloN0>_8e`3[[/D0jl?;0>KXg03cdM<0ol?A0?o8eP3g`/l0lkO40?Nm
a03o`l/0mm7K0>[6bP3Z/;P0mkg:0`3gdM/0503cj>P0j^g]0>[]k@3gdM/0lLK<0?7Uj03aiNd0mMcR
0>cfl03cmoP0loCd0?ooo`3oh>P0l]_F0=kIeP3Vg>40mncd0?O^o`3giOP0iJjf0P3Zg=d01P3Sc<H0
k/_>0>_3a@3ge=H0i>KX0=kDeP80k]g`0180loCd0<kIf`3Sh>T0WJ^c0>k8d@3Uk_P0j_C]0<OMg`2n
^Lh0b;g30?OVkP3giNP0oooh0?Ofm03aj?@0moCX0?Ooo`3oool20?ofn00=0?ooo`3gmoL0moO]0?og
o`3eool0mNoh0?Ogn03cm_@0oooo0?Ofo`3om_P0oooh0?Ofn0020?Oon00A0?odm03gmoP0mno`0?og
n03oool0j^cK0=W2Z03Vfo@0i^3h0>KVo`3@bM00jn_Y0?OckP3JiOl0mno_0=kLj03^iOP0?`3oool0
00l0oooo0P3omoP20?ooo`80ooOh0`3oool20?ogn0030?ooo`3omoP0ooOh02/0oooo00D0ooOh09><
V01QHUH0Z:jl0<OEeP020?O/k0090>_Ui`3^moP0i^g]0>k_k`0UC6L0`Zj]0?O_i`3oooL0moO_0080
ooog0140oooo0?ogk`3om?@0ong^0?Ofn03oool0mooo0?Ool03oool0loo`0>k^k`3gm?@0jmCF0?Od
m03oooL0oooo0?ool`020?Ogk`0@0?oTk@3glo@0jloA0=S1_`3oooP0i/6i0?7QhP3gk^l0mn_d0?OT
kP3cmoP0moO_0?oom`3oool0ooog0?ool`80ooO/0100onG/0?oKj03gfn40lm_L0??Df`3cg><0loCY
0>_]hP3Vj=`0lm7C0?ODeP3cm>T0jngR0??DeP3gg>D0mmCR0P3oeMl0103oool0mnG`0>[Tl03ZkNl2
0>[]k@0<0>cUg`3al^T0lO;Y0>[^j03gkNd0joCW0?oUn03gi>h0joC]0>Kdj03[mn`0k/G;0P3ce=H0
:@3S`lD0lmcU0>kDf`3[b<D0k>GU0>;Id03[fmL0jn3G0?obn034bLP0oncX09f[/`3V`M40iO?h0=K[
n03Ak^l0alcF0;FXa@3Abl80mnSc0?obn03gooP0lNoh0?OVi@3gmoL0oooo0?ofn03oool0ooKh0?oo
o`3cm>P0oooo0?7do`3om?@0ooOh0?O^l03gm_P0moKo0?Ofn03om_P0ooKo0080lood0140moOh0?og
n03gm?@0ooCd0?ooo`3Tm>P0h/:d0=[:`@3omnl0ooCd0=S=gP3bj>40e]GU0?ogn03Ig?@0g^7U0>kP
i@0o0?ooo`003`3oool20?ogn080oooo0P3omoP30?ooo`80ooOh00<0oooo0?ogn03omoP01@3oool2
0?ogn280oooo00L0k^G`0>KKj@3Fa]/0>c0]09ZHU@3AgMl0iNcd0080e^c]00P0e]cN0>Gdm03Vm>d0
Sk;403]6EP3SgMH0mnCX0?OTm0@0ooog02<0ooOh0?odm03gkNh0mooo0??fn03ok_00ln_h0??bm03o
m_P0mnk_0??/k03[i>D0ooCd0?oom`3oool0ooog0?Ogn03oool0mno`0??^l03cfm`0hm7>0>?McP3^
fM<0h/>m0??Ui`3ol_P0lnOU0?o_i@3omo@0oooo0?ogn03om?@0ooOh0?odm0030?ogn0050?odm03o
moP0ooog0?oUk03oe>400P3ocm`20?O?eP80oloL00P0fMCC0>;/f`3cb=00llgD0>;Dd03R_;T0ll?6
0?O3b`<0ol?A02L0mk_80?NmbP3o`m40j/W<0=kTf`3Njm/0g]?<0>?9b@3Fe<H0e^3@0>_]h@3gk>d0
omCR0>k6b`3^gMl0oooo0?OMi`3U^kh0jm6m0>kD``3[`ld0jkK40=6^Z`3A^kH0ll;;0:;4cP36^m40
iOOd0=K/m03AiNL0k=GG0=7_m`2/X:d0b;2d0?Ofi`3cl_@0j_?d0?o]m03cm>`00P3oool20?obm004
0?ooo`3cm>`0oooh0?7]n080ooOh00H0loOh0?oon03gl^d0moK_0?obo`3om_l20?Oom00B0?ooo`3g
moP0oooo0?o_l03omoP0k?O/0:c1b01fKFh0HU9>0:fCV@3RfM/0h^cd0?oon03Nio<0lno]0=kKk@3[
iNd0mno`?P3oool000l0oooo0P3omoP20?ooo`80ooOh3@3oool20?ogn280oooo00L0i]_Y0?ooo`3F
a]80;3<L0>k_l03JiNl0e^C/0080c^g]00T0j_Ch0>[dl03UkN`0IgnF08=iL`3oooL0onGh0?O^m`3g
moP0103oool0803omoP0mng^0?ooo`3gool0mo?d0?ooo`3ok?P0moOh0?ocm03gk>h0ooOh0?Odm03o
ool0ooog0?Ogk`3gmoP0mnCd0?o[kP3gm_P0ln7Q0?o/m03RgM<0k^o`0=k8`03/hN40mnk^0??Tj03o
mnl0oooo0?ogn03om?@0ooOh0P3oool01@3om?@0ooOh0?ogn03om?@0ooOh0080oooo00@0ooCd0?oo
o`3oool0oooo0`3omoP06P3JkOP0f]_]0?oTj03oiN`0f^3h0=[Pm03oi?@0mn_o0??Vm03cjoP0moKh
0?oco`3ci>P0jn3Q0?o;gP3gcND0mm7Q0>cPg@3Zlnd0k?Oo0>Ccl03/jnT0i?;Y0>c^j03[h>80jmcK
0P3Vm>P0603[i>d0omG^0>?VkP3ecM/0i>CU0?OLg@3ci>H0lmcX0;K^l02mb=/0e_Ch0=K:g`3HinL0
mnG`0?OMj03SeNP0W82M0?o_m`3oonP0j^_N0?G]n03gmnd0moOg0?ooo`80on_^00T0moOg0?Ogk`3o
moP0lOCh0?odm03omoP0mooo0?Oon03ol^d00P3oonl01@3ol^l0mood0?Oom03gool0ooCd0080ooOh
00h0ooCd0>cgk02L_/P0ZK2d0:R^Y`2]YZ<0lnSA0>;/m03^m^d0jnC^0>;DgP3eknD0lo;h0??XjCh0
oooo000?0?ooo`80ooOh0P3oool20?ogn0d0oooo0P3omoPR0?ooo`070=k=f`3?dM80ZjVU04a<?03/
m?<0g_Cd0=odm0020>?gn00<0>?dn03BiNl0k_oo06MTMP2FUi@0oooc0?Ogm03oooL0moOh0?oom`3o
iO@0onGh0P3omoP20?Ogn080moKh00T0lnKo0??^o`3cm_P0moKh0?o^o`3oool0moCd0?ooo`3oiOP0
0P3gk_l03P3gmoP0mn_^0?ofn03chN40ooOh0?7[i@3ViMh0k^CN0>;:a@3ciMh0lnC^0?ool`3omoP0
oooo0`3omoP0103om?@0oooo0?ooo`3oool20?ogn080oooo00`0ooOh0?odm03omoP0oooo0?ogn03o
ool0ooOh0?ooo`3omoP0oooo0?ogm03gknL20?O]kP0]0??cm03gk>h0mnk`0?ooo`3gool0loo`0??f
n03gi>D0mng_0?OLm03gcn<0olKK0?o3g03ZfN40lnSX0?7Lk03beND0iNcX0>[^iP3ofmh0k>3N0>cP
h`3gmoP0h^_d0>;Qg`3IfLl0e]C?0=kPhP3FeMl0]LkK0:Bjc@2[^]00]MWR0<C]l03:cnT0a<?M0=7=
hP2SQId0mnoh0?o/k@3cm^D0lNSd0?Ogk@3gmoL0oooo0080on_^00T0moOg0?Ogk@3omol0lOOo0?oo
o`3om?@0mooo0?Oom03ol^l00P3oonl01@3om^l0moKd0?Ofm03gool0ooCd00<0ooOh00d0k>oU0;7K
h@2DUY/0h^GK091nL`2TVXT0g]cX0>KPn03^i?@0jn3^0>_Tm03ck>h0lnSY03h0oooo000R0?ooo`80
ooOh8P3oool01`3Hb=/0[K:[0<S3]P1]KFd0ooOg0<7Uk@3Zk?P00P3Zk?@04P3BkNh0ooCc0=;Ii@0l
DUT0_[g10?Ogk03oool0mnko0?oUn03gmo@0mnkg0?oUn03gm?@0mooo0??gn03gk_l0ooOh0?OPn0@0
lnch00D0moOh0?OVo`3oi?@0oooo0?oUn0020?O^o`0>0?OTm03cio00moK`0??Xh@3om?@0mN_d0>?d
h@3^m?@0g/[90>cMeP3[e=/0oooc0?ooo`3omoP30?odm0040?ogn03oool0oooo0?ooo`80ooCd0P3o
ool30?ogn080ooCd00L0oooo0?ogm03oooL0oooo0?ogm03omnl0mnSY0080ooOh00<0mo;d0?Ofn03g
m_P00`3gm_P09@3gl_@0ooKh0?Ogk`3cm>`0loCc0?O]k@3oooP0mnG`0?;Pm03ajo00mOKd0?GVk@3b
hN`0lnSc0?;Ql`3bhN`0lmWQ0?OIhP3oh><0om_N0>_Db`3[ckl0g/6j0;jk]@2OXJL0WJZ^0:>_^02`
[kP0bmC?0>?If`3NbM@0fJ_80>kgh`3gio<0loKd0?7Xm03cm>P00P3gmnl20?obm00:0?Ogm`3oooP0
moO_0?7]n03om?@0moOh0?ofn03gm_P0oo;_0?ooo`80oooX0P3gl^D0403gool0moOh0?Ooo`3omoP0
oooo0?odj03BkOL0RH^;0?O/k@3JeMH0JeYR09V@U@3gm>d0loCd0?ooo`3gko020??XjCh0oooo000>
0?ooo`030?odm03omoP0oooo03D0oooo00L0g]CY07A/F02c[ZT0]k^m08B^`@1gTid0IX>40080EGj@
00L0DHRT07>V_02Za<h0?daK0??Th@3gmn`0moOh0080onGh0P3gmoP01P3oool0moCd0?O^o`3cm_P0
ln_h0?OPn080mnko0P3oool05@3gmoP0mnCd0?OPn03gk_l0moOh0?ooo`3gmoP0oooo0?O]kP3glo@0
mnk^0??Xh@3om?@0onkh0?7/i`3^i]l0k^gX0?7Dd03[fM/0lngU0?Ogk`030?ooo`@0ooOh00<0oooo
0?odm03om?@00P3oool40?ogn0050?ooo`3omoP0ooog0?ogm03oool00P3oooL0103gkNh0ooOh0?oo
o`3gl_@30?ooo`80moOg00h0oooo0?Ogm`3gmoL0oooo0?Ogm`3gm>d0ooOh0?Gon03emoP0mOoo0?G^
n03ol_l0ooKd0?ooo`80mooo01@0oooo0?O_m`3cj?<0mnSc0??Xk`3[j>l0mnSc0>[Vk03Zmnd0onGX
0?OTj@3gi>h0jn3U0=kPh@3NinD0l^C_0>[_iP3ckND0loKW0?7PkP80moCX00l0loCX0?obm03ol_@0
loCc0?Ogm`3gmnd0lNSd0?ooo`3cool0moKh0?ofm03gm_P0oo;_0?ofj03oonl00P3gl^400`3gm_@0
mo?d0?Ogn0020?Ogn00:0?odj03Im?P0SY>A0=S3aP31][X0j^CX07]eL`2/UiX0lng^0?ooo`<0mno`
?P3oool000h0oooo00<0ooCd0?ogn03oool00P3omoP00`3oool0ooOh0?ogn0020?ogn0030?ooo`3o
moP0ooOh02/0oooo00L0g]CY05]?>@34`LD0JhJL041YL01lPHH0Y9N^0080`Z^b00D0]:NZ07F2TP29
WK80Mfed0?Ogk`020=[_m`0@0?ooo`3gmoP0moOh0?ooo`3omoP0moOh0?O^o`3giOP0onGh0?Ogn03o
ool0onGh0?Odm03gmoP0ooOh0?Ogn080oooo0140moOh0?ooo`3oool0mnCd0?ofn03oool0lo?d0>_T
i@3oko00ooOh0?Gfn03ek>40k_Oh0>?Dc03Zdm<0onkh0??]i@030?oom`80ooOh00<0ooCd0?ogn03o
m?@00P3oool01P3omoP0oooo0?ooo`3omoP0oooo0?ogn080oooo0P3om?@01`3oool0ooog0?oom`3g
moP0mng^0??fn03om_P00`3oool20?Ogm`0@0?ofn03gk^l0moOg0?ooo`3cm?<0oooh0?odn03eool0
ooCd0?Ggn03gk_00loKd0?Ofo`3om_P0moKh0?ofn080looo0180mooo0??oo`3gm_P0loKh0?Ooo`3g
kol0k^Sg0?OXk03oj>P0omgU0??Uj@3gi>h0mn3Y0>c]h`3/knh0lngh0?Ook`3Zfm/20?Odj0030??d
j03om_P0ooKh0080moOg00X0oood0?7Xm03oool0looh0?oom03cm_@0lo;h0?obo`3oool0ooK_0P3g
m^l03P3gooP0oo?d0?odm03gool0oooo0?O]i@3Omnd0X[Fi0??bj03FiMd0c/Jf0=7<_P2XTY40dL?G
0P3gko100?ooo`004@3oool20?ogn0030?ooo`3omoP0ooOh0080ooOh00<0oooo0?ogn03omoP0:P3o
ool0203omoP0f=C^05a?<`3IeMH0;3mC0>?Df`3oiOP0moOh0P3oh>h06@3^mnL0k=G>0<C3_`2e[ZL0
moO_0>;dj03Rm>d0moOd0?Ogk`3gk_l0onGh0?Odm03oool0mnko0?OUn03oiOP0moOh0?ooo`3oiOP0
mng^0?O/n03oi>d0oooc0?Ogk`3gmoP00P3oooL01P3oiOP0oooo0?OTm03oko00loOh0>_Vj080ooCd
00d0oooo0?7[i@3^knL0k_C]0>[8_@3gl_P0lnc^0?OTk@3gmoP0ooog0?ooo`3omoP0oooo0080ooOh
0P3oool00`3omoP0oooo0?ooo`030?ogn080ooCd0`3omoP01@3ooo<0onGh0?oTm03gi>H0moKh0080
oooo00@0moO_0??dk03gmoL0oooo0P3om_P00`3gmoL0loCc0?Ogm`020?ogn00=0?Goo`3em?@0ooKh
0??on03gm_P0oooh0?Obm03gm_P0moKW0?ofk`3om_P0moKh0?Ofo`020?ofo`80oooo01H0moKo0?Ob
o`3om_l0ono/0?O]m03cm>d0moC]0?Ogk@3ckNl0mnkX0?ofk`3Ti=H0mnGQ0?Odj03gmnd0mo?d0?of
n03oool0loC/0?G_l03ekoP0oooo0P3gooP20?Ofo`030?ofo`3oool0ooK_0080moK_00l0moKd0?oo
o`3omoP0mooo0?ooo`3gm?@0goCU08^GW`3Ab;h0_<:i0=[Db`3;`/@0dL[C0<Bf_@3omoP0@@3oool0
04D0oooo00P0k^C^0<RjcP1fLTl0Qj2e07^2S@3oooL0oooo0?Ogn080mnCd00D0mnGX0>kgi@3/k^D0
fN3K0?Ogk0020??dm0090?Ogm03oooL0mnCd0?Ogn03gh?P0mnKo0?Ooo`3oiOP0mnCd00<0onGh00H0
mn3^0?O_l03oiO@0oooc0?oom`3oool20?oom`80onGh0100oooo0?OTm03gm_P0mn3U0?Ogk@3okO@0
oooo0?G[m03eonl0ooO_0?78a03cjnD0mo?d0?oUn03gmn`0oooo0P3omoP01`3om?@0ooOh0?ogn03o
moP0oooo0?ogn03oool00P3oooL0103oool0ooCd0?ogn03omoP20?ooo`060?odm03ooo<0onGh0?O/
n03ok>h0moKh0P3gmnl00`3cm>P0moo]0?Odm`030?ooo`80moOg00D0oooh0?G]l03am?@0mOCd0?og
n0030?Ofn00@0?Obi@3[m^d0jooo0?ooj03glnd0mo?X0?ofh@3gk^`0mo?g0?obo`3om^l0oooX0?of
k`3ol_l0ooKo0?ook`80ooK_01L0mnoo0?OUo`3ol^l0oooo0?oUj03TfmH0ongX0?GMgP3bi>80mo?d
0?ofn03gmoL0moO]0?G]n03emoP0mooh0??om03gooP0ooKh0?oon03oool0ooKo0?ook`020?Obi`0?
0?Oon03gool0moOh0?O^l03gk>h0ooOh0=Wgk01lQH/0moKh0::RU03;b</0moK`0?Ogg03A`/40ooOh
00/0oooo0P3omoPd0?ooo`00A03oool0203omoP0g]W^0<VfZP2[`Kd0Q9RQ0>;LgP3oooL0oooc0`3o
ooL01`3oiN`0ln3W0>?/n03IkNP0f^og0=W]m03cm?@00P3gmoP01P3oool0mn3h0?oUn03ofo@0mnCd
0?Ogk`@0ooog00D0onG/0?oUm03oool0ooog0?ool`030?oom`<0oooo0180mnCd0?ofn03gi^h0loO/
0?o_kP3okNh0onG`0?G[m03ek^L0mNCX0>cDe`3gi=h0mnGX0?Ogk`3ooo<0ooO/0?ogk`3omoP30?od
m080oooo00@0ooCd0?ogk`3oooL0oooo0P3omoP0:`3om?@0oooo0?ooo`3omoP0ooO/0?ogn03gmoP0
onc^0?Ofn03gmnl0oooo0?Ogk`3gonl0loO/0?Ogm`3oool0moOg0??dk03gmnd0oooh0?G_n03akO@0
mOOh0?ooo`3cm_P0ooKh0?obk`3oool0joOh0??dl`3cm?@0mnoh0?O_m03cm?P0moOo0?O^k@3ci^P0
lncg0?Ogn03gmnd0moO/0?o_k03okoL00P3om_l02P3oonP0ooK_0?ofk`3ol^l0mnoo0>[=f`3oooP0
lMCD0>C8a03oool20?Ogm`060?Ggm03eool0lNO^0?Ofo`3gm_P0oo;o0P3om_P00`3om^l0ooo_0?of
o`020??fm00>0?ooo`3gool0oooo0??fn03clo@0lng^0>Kgh@1JIFd0[K_50764RP2TWjL0j^G:0=W:
f`3SeMl<0?ooo`80ooOh=03oool004<0oooo00T0ooOh0?O_l03FdMl0g]bi0;k9g`3gmoP0mnCd0?oo
l`3oool00`3ooo<0203omoP0mnoU0?Ogn03gmnl0hoO/0=W]m03cm?@0moOh0P3gi?@20?oUn080oooo
00<0oooc0?oom`3oool00P3oool01@3ooo<0oooo0?oom`3ooo<0oooo0080ooog01D0oooc0?oom`3o
ooL0ooog0?OTk@3om_P0onk`0>k^k`3cmo<0moC]0?odm03oool0mOKh0?Gck@3ag=h0mnKU0?OUi`3g
iNP0moOh0?oom`3om>d0103oool01@3omoP0oooo0?ogn03om?@0oooo0080ooog00<0oooo0?ogn03o
moP00P3oool06@3om>d0ooO_0?Ogn03ok>h0mo;d0?Ocm03gmo@0oooh0?o_n03oko00moO_0??dk03g
mnd0oooh0?o_n03ej?@0lNSd0?7]m03/mo00loKd0?Ofn03om_l0ooK_0?Ogn03gmoL00P3oool0103o
mnh0ooOh0?oon03oooP20?ogo`0=0?oon03gmoP0onoh0?o_n03gmoP0ono]0?ooj03oonl0ono/0?o_
k@3gloP0mo?]0>[Uf`020?GUl00;0>?Dd`3I`[d0loC/0?Ogk`3ooo@0mOOh0?ooo`3einh0ooKh0??f
m03om^l00P3oonl00`3oool0ooo_0?obo`020?Oom0030?Ooo`3oool0looo0080mooo00P0mno`0=ko
j017CEH0f^gd09JNZ@2PWYl0ZjVQ0=K6e4<0oooo00130?ooo`050?ogn03Rh>h0h]W80=7]k`3gmoP0
0P3oiOP00`3ooo<0oooo0?ool`020?oom`0:0?odk@3gkN40moOh0?Ogk`3oooL0fNgd0=[_m`3oiOP0
moOh0?OTm0@0oooo00<0ooog0?ool`3oool00P3oooL01@3ooo<0ooog0?oom`3oooL0oooo0080ooOh
0`3oooL04`3oool0om_]0?OVo`3om?@0mo;h0?ogn03ckn`0ono`0?ogn03oool0mNkW0?ogk`3eiNP0
lnGU0?o[kP3gko00moO_0?ogk`3omoP00P3oool01P3omoP0ooCd0?ooo`3omoP0ooCd0?oom`80oooo
00@0oooc0?ogm03omoP0oooo0P3omoP01`3ooo<0mnCd0?ofn03gm?@0mnCU0?Odm03okO000P3eiO00
503ej>h0mNgd0?Gdo`3emol0mNSd0?Goo`3oool0mooh0?ofn03gm_l0ooo_0>kok`3^knl0loCd0?oo
n03ooo@0ooOd0?ogo`3omoP0ooCo0P3omol0703oool0ooOo0?ogo`3gool0moOo0?Odo`3ckOl0loCo
0?O]k`3gmnd0mng]0?O]m03^kO@0l^3K0?7Tl03/iMl0l^cd0>?AcP3oooP0oood0?ogo`3om?l0lNoh
0?o^l03gm_@0moKh0?ofk`3oonl20?ooj080ooKo0P3gm_P03P3om_@0looh0?ogn03gmoP0looo0?O_
l03Ako00EEYS0?odm02n^l00dLRn09fTY`3Fa[d0k^Gh@P3oool004@0oooo00@0g]CY0>[Q^@3AkOP0
moOh103oooL03P3ooo<0ooog0?oom`3omo@0lngQ0?ooo`3cm>P0mnCX0=Wck@3Jkol0onG_0?OTm03g
ool0ooOh0P3oooL0103oool0ooog0?ool`3oooL30?ooo`80ooOh0P3oool20?odm080ooOh00/0oooo
0?ool`3gi?@0mooo0?Ocm03cm_l0lo?]0?Ogm`3omoP0ong`0?o_n0020?Gfn0070?7TkP3gkNP0mnk_
0?o^l03gko00moO/0?odm0020?ooo`030?ogn03om?@0ooOh0080ooOh0`3oooL03@3ooo<0ooOd0?od
m03om?@0ooOh0?ooo`3oooL0onG_0??cm03oi>h0mnCW0?O]m03emo000P3ok>h01@3em?@0mOoo0?Gd
m03einh0mNC^0080moKd00X0lo;h0?Ofk`3gonl0moO/0?O]m03gmo@0mooo0?ogn03omol0oooo0P3o
moP0103om?P0ooOd0?ogn03oool20?ogo`80ooOh0P3oool01P3omol0moCh0?Odn03gmol0moOh0??_
k080onk`0140moo_0?;[gP3em?@0ooOd0?ogn03oool0mOCh0>cgl03cm_P0moKh0?obk@3oonl0oooo
0?ook`3oool0ooK_0?obo`020?Ooo`0>0?ofn03cooP0ooOh0?Ooo`3cloP0mnc`0=K]i`18E680moCh
0=75a@2Y][<0]kc60=K6/P3VfnhR0?ooo`80ooOh7P3oool004@0oooo00@0g/gK0>_La03IioP0moOh
0P3ooo<00`3oool0ooog0?oom`020?ogm00;0?o]h@3[i=h0mnk`0?Ogk`3gk_L0mnko0?Ogk`3oooL0
onGh0?oPn03oi?@00P3oooL00`3oool0oooc0?ooo`020?ooo`040?ogn03om?@0ooOh0?ogn080ooCd
01L0ooOh0?odm03om?@0ooCd0?ooo`3oooL0moO_0?OTm03oko00moKh0??[k@3cm?<0moOg0?o_kP3o
koP0mOKh0?Gck@3egMl0mNGX0??dk03om_P0mn_^0?OTj0020?ogn0@0oooo0P3omoP40?ooo`0<0?oo
m`3ooo<0oooc0?oom`3Jkol0fNg_0??dk@3gi>h0mnc]0?Ogk`3emo@0oooo0P3eoo@0203amo@0mNo`
0?ocm03om_P0oooo0?Ofo`3om_l0moo_0P3oool03P3gkO@0oooh0?Oom03oool0oooh0?ogo`3om?P0
oooh0?ogo`3omoP0ooOd0?ooo`3omo@0oood0P3gmoP02@3omoP0ooOo0?ogo`3oooP0moOo0?Odn03o
moP0lnO]0??fk`020?ooo`0A0?G^l03ak_00oooo0?Gdo`3ekOP0mNoh0?7]m03gooP0loKh0?Obk@3o
m_P0ooK_0?ofo`3oonl0oooo0?ofk`3om_l00P3ol_l03`3goo@0looo0?ooo`3omoP0mo?h0?O/l03F
kNL0>dQF0=k]i@3:c<D0OHn<06j3PP1GIfH0ShJ=0?ogn00Q0?ooo`80ooOh7P3oool004<0oooo00L0
mno`0>[=_03Zk]l0mnCd0?ooo`3ooo<0ooO/00<0ooCd0P3giNP03@3[i>D0k^c/0??PhP3gmnl0moOd
0?Ogn03oool0moOh0?OTm03gh?P0oooo0?oUn03oool0103oooL00`3oool0ooCd0?ooo`030?ooo`80
ooK`00T0ooOh0?ooo`3oool0ooOh0?ooo`3ooo<0onGh0?ogn03clo@00P3gm_P0303gmoL0mnKU0?o_
n03ek^L0oooo0?Gck@3ai>h0mnKW0?Ogk`3gk^T0mnCX0?ooo`80ooOh103oool01P3omoP0ooCd0?og
m03ooo<0ooO/0?ogm080moOh00T0onGd0=[fk03Ilnd0mnko0?oVm03gmnd0mng_0?Gon03omo@00P3a
moP04P3eool0mOOh0?;Ig@3ckn`0moo_0?ooo`3conl0oooo0?o_n03oknd0mngh0?Oon03omol0ooCh
0?ogo`3omoP0ooCh0?oon080ooOo00H0ooCo0?odm03gmoP0moOh0?Ogm03gmol30?ooo`0:0?odn03g
ool0moCh0?Odn03^k>40moKo0?ofn03el_@0mNc^0?ogo`80mOOo00d0lNgd0?Gdm03em?@0oooo0?of
n03cm^L0ooo_0?ofo`3oool0ooK_0?ook`3om_l0oooo0080mooo00l0lo;h0??bm03om_P0mooo0?Og
n03ckNh0bnc`049?C03Tm?l0loCg0<WLgP3ggML0TjBS07EVK@3omoP0@@3oool00480oooo00D0mno`
0=[<c`3Ri</0looo0?Odm0020?oom`040?oTj03gk?P0moCd0?odm080jnCN00X0moO]0?oon03[e=H0
ooog0=W]n03JkoL0moOh0?O^o`3gk?P0moCd0P3oiOP20?oom`050?ooo`3oooL0ooO_0?ogn03om?@0
0P3oool40?ofl00@0?ooo`3omoP0ooOh0?ogn03omo@0ooog0?oUn03omoP0mo?d0?ooo`3gl_@0oooo
0??dk03okO00mNGO0?G^i`80lO;d00@0onSd0??dj03oi^T0loCX0P3oool00`3om?@0oooo0?ooo`02
0?ooo`080?ogn03om>d0omgW0?OPkP3gkNh0onO`0??/n03gmoP30?O^o`060??/n03gk?@0moKh0??]
k03omoP0mOOo0P3eool03P3oiNh0lNk^0>[Ig@3oond0mnS]0??/m`3gm^l0ooKW0?oUk`3okn`0loC_
0?odo`3oool0ooOo0`3omoP01@3ooo@0oooh0?oon03omo@0mnoo0080oooo00<0moOo0?oon03oool0
0P3oool04P3omol0ooOh0?ogo`3[kNd0moo_0?Gfn03ak_00mOCd0?o_n03omoP0ooCh0?Ggn03omoP0
mOOh0?ogn03oool0mooo0?Ofm080ooKo0P3oool00`3om_l0mooh0?Obn0020??bo`030?Ofn03cl_@0
moKh0080moOh00T0moCd0<_Tj@12EUL0i?Cg0??do`3Rmnh0fMWX06M/K@2PR8T0@P3oool00480oooo
00/0mmW<0=[PcP3IkoL0ooCd0?ogn03oooL0ooOd0?oMi@3gh>h0onc^0>_Ti@020>k/k`0:0?Ggn03b
m>D0lm_R0?ooo`3AkN`0bnc/0?oUn03gi?@0mooo0?oTk@80oooc00D0ooog0?ooo`3oool0oooo0?od
m0020?ogn0030?ooo`3om_00ooK`0080ooK`1@3oool0303om>d0oooc0?ool`3oiNl0onO`0?Ocm03c
oo00moKh0??dl`3omoP0ong^0?ooo`80lN_U00D0mNcd0>cIgP3ge=L0lmcN0?oom`020?ogn0<0oooo
02<0ooOh0?oMi`3gi>d0mnko0?OPj03gj>80on3U0?OTk@3cm>d0ooog0?ooo`3gmoP0mnCd0?Ocm03c
m_l0mnk_0?O_k`3gkO@0k?Od0?oon03oiO00mNG`0?OUj03ggMh0mng]0??^m03ch>P0mn3U0?OWk03c
m>`0mnoW0>c_m03/mo@0oooh0?odo`020?Ogn0060?ooo`3gmoP0moOo0?oon03cm?@0moOg0P3gmoP0
2`3gmol0moOh0?Ogo`3oool0moOo0??go`3[j>d0hmgG0?7Vj@3ei>H0ooC^0080ooOh00D0ooOo0?o_
l03aool0lOCd0?7gn0020?ooo`090?Ooo`3cooP0mo;h0?ofk`3oonl0oooo0?ofo`3cm_@0lood0080
mooh00h0moKh0?ofn03gm_P0ooOh0?Ogn03gm?@0a>C`05EWN@3;cmL0]/SA0<_8c02JUhT0JFaR0<B`
]T80oooo00110?ooo`070?O_l03gfKd0moOd0?Ogk`3oooL0oooo0?oom`020?odk@030?Ogm03gh><0
ln7Q0080ong`00X0lOCh0>[Xh@3ch>T0mnko0=Wck@3IioL0onGh0?OTm03gmoP0onGd0P3ooo<01@3o
ooL0oooo0?ooo`3oool0ooCd00<0oooo00@0ooK`0?obj@3ol^T0oooo0`3om_020?ooo`80ooOh0180
ooog0?Ogk`3giOP0moOh0??^o`3gjnh0moOg0?Ogm03oj>h0oooo0?G^i`3omnl0oooo0?Gfn03gj>D0
k]CD0?Ogk03om?@30?ooo`070?ogn03omnl0onGd0?OTk@3gmn`0oooo0?oom`020?ool`0G0?oom`3g
mo@0moOh0?oom`3gi>d0mnCd0??/l03oool0mnk]0?Ogm`3ckO<0mOOo0?odm03emoP0ooOh0?O^n03[
h>D0jmcM0?O_k@3Zmnh0j^o^0?odn03omo@00P3/mol01@3ooo@0ooCh0?Ogn03gmoP0oood0080moOh
00P0oooo0??dk@3^ool0k^o]0?O]n03oooP0onoo0?Ogn080moOo00@0mno_0?Ofi`3ai>H0ooCd0P3o
moP01`3oool0ooOo0?odn03em?@0ooCd0?ogn03emoP00`3oool0203gooP0mo;h0?ook`3om^l0ooKo
0?ooo`3gl_@0mo;U0P3ol^L03P3gm_@0mooh0?Ofm03gm_l0mnkh0>?_j02jbMd0MGb40>[Pi@3SiNl0
hmC504]RKP2CRZd0f/cO@P3oool00440oooo00<0lnSY0??Va03oool0103oooL01@3om?@0ooC]0??T
gP3ggMl0moCd0080ooOd00T0lNoh0?7Qh@3[h><0mnko0?OTm03gmoP0onGh0?Ogn03gi?@00`3oool0
0`3ooo<0ooOh0?ogn0020?ogn0@0oooo00@0ooK`0?obj@3om_00oo;Y0P3om_030?ooo`0E0?ogn03o
mnl0moO_0?OPn03cjoP0mooo0?O[m03oooP0moO_0?OUi@3omo00oooo0?Gfn03oool0mOKh0?oXm03[
i=40mnC]0?ogk`3omoP0oooo0080ooOh00<0ooog0?ool`3oool00P3oooL00`3ooo<0ooog0?oom`03
0?ool`0Z0?oom`3gmn`0mnko0?Oon03gk?00oo;h0?oon03cmoL0ooCg0?Ggm03eool0onkh0?O/m03g
m?@0moKh0>kMeP3SiM/0mOCd0??oj@3goo@0k?Oo0>[gn03goo00ooO`0?odm03om?P0ooOh0?ooo`3o
oo@0moOo0?o_m03cm?@0joO_0?Ogo`3oko@0oooo0??dm`3^kNP0lnGQ0>cbi@3ak_00mNg^0P3oool0
203omoP0oooh0?ogn03om?P0mOOh0?ogn03emoP0ooOh0`3oool0203gm_@0moKo0?ooo`3oool0ooKo
0?obn03oool0ooK]0P3ol^L00`3gm_@0mooh0?ofm0020?ofo`0:0>_]hP2Z]/P0NXF40?Ogl03Nfn40
b/>j07MoR02GRYT0/:>d0>?Ml440oooo00110?ooo`030?OPe03gk=80onGh0080onGh00L0onG/0?og
n03omoP0mnGK0>kLgP3gm>d0ooOd0080ong^00X0lOoo0>[Qf`3^k^h0hnC]0=W]m03cm?@0mnko0?OT
m03gk_l0onGh0P3oool0103ooo<0ooOh0?ooo`3omoP30?ooo`P0ooK`0P3oool03P3omoP0ooCd0?og
k`3oooL0mnCd0?o^o`3ok?@0oooo0?Obn03om_P0lng/0?o]m03okoP0oooo0P3em_P01@3okoP0jn7@
0?O_l03oiN`0ooCd00@0ooOh00@0oooo0?oom`3oooL0oooo0P3omoP20?ooo`0M0?ogn03om?@0ooOh
0?oom`3oiNl0mnko0?OTkP3oool0ooKh0?Oon03gkO<0ooOh0?7gm03oiO00mo?h0?Ooo`3omoP0moKo
0>_Ti`3Si=<0jng@0?ogl03emo@0j_O^0?Ggm03/moP0oooh0?ogn03omol00P3oooP05`3gmoP0onoh
0?Ogn03cm?@0mngd0?ooo`3gkO@0mooX0?Ooo`3ojnh0lOCd0?ogn03om?@0ooOg0?ogm03omoP0ooOo
0?ooo`3omoP0mOCd0?ogn03aool0mOCd00<0oooo00P0mo;d0?ofn03gm_P0ooKo0?Ooo`3gl_P0oooo
0?ofn080moKd00<0moKh0?ofo`3om_P00P3om_l03@3cj>T0W;3007:5U`3oool0f]gO0;bh_01oR8H0
Kg9W07A]F`38/[D0i]_d0>kTm03omoP0?P3oool001d0oooo0P3omoPQ0?ooo`040?ogn03ofKd0ooO_
0?oUn080oooo00D0onG/0?odm03omoP0lmW@0??/k0020?o_kP80mNg^00P0ono`0>[Th@3gjo@0h^c_
0=[_o`3ck>l0mnCd0?ooo`80onGh00@0ooog0?ool`3oooL0oooo0P3omoP30?ooo`080?ofl03oool0
ooK`0?obj@3om_00oo;Y0?ooo`3om_020?ooo`80ooOh00`0ooog0?ool`3gmnl0mnch0??^m03gjoP0
ooOh0?Obn03gm>L0moo]0?o]l03omoP30?ooo`090??EeP3goo00lnOW0?O_i`3omoP0oooo0?ogn03o
ool0ooOh00<0oooo0P3om?@0103oool0ooOh0?ogn03oool20?ogn00;0?oom`3gmn`0ln3W0?Ofn03o
ool0oo?d0??gl`3omol0mOoo0?Ggm03omoP00P3gmoP04@3gool0moOh0?Ofo`3[i^d0hmc>0>_Xj03c
h>l0hmcU0?GdkP3gool0ooC`0?ogn03om?l0ooOd0?oon03cm?l0moOo0080ooo_0180mngd0?O_m`3g
onl0mNk`0?7^l03emoP0ooCd0?ogn03gm?<0loO_0?Ogm03oool0ooOh0?ogm03ekO@0ooOh0?7gn03e
moP20?ooo`090?ofn03cooP0loKd0?Obm03gm_l0mooo0?obn03gool0ooKh0080moKh00<0oooh0?Ob
m03gloP00P3gk_P03@3^m>D0Wjj^08jAZ03SmoP0joOh0>kdm03^kNh0k>CU07YkNP25OVX0a;JW0=[E
gP3^i>h0?P3oool00100oooo0P3omoP;0?ooo`80ooOh00<0oooo0?ogn03omoP07P3oool0103okND0
mmVm0?Odm03omoP20?oUn0070?ool`3om?@0mngU0>kIb`3/gMh0lNCV0?GPiP020?7]l0070?7Xj03c
jnd0ooCd0?ooo`3ck>l0moO_0?OTm0020?oUn0030?oom`3oool0ooog0080oooo0P3omoP40?ooo`80
ooK`00@0oo;Y0?ofl03om_00oo;Y103oool20?ogn00<0?oom`3oiNl0moOh0?oPm03cmo@0oo?d0?of
o`3gk_@0moCg0??_k03gknL0ooOh0P3oool02@3ghN80mnk_0?O[kP3gi>d0ooog0?ogn03om?@0oooo
0?ogn0030?ooo`@0ooOh0P3om_002@3oool0ooCd0?ooo`3oooL0mnC]0?O^m03om_P0oo?h0??gl`02
0?ogo`0K0?Gom03eool0moOh0?Ooo`3cmoP0looo0?Ooo`3gmoP0mo?d0?Obi@3gm^D0jn__0>?]k@3b
kO@0i>gh0>[dn03cool0moOd0?ogm03gmoP0loCo0?o_n03gkO@0moKW0?Obi@3ol_@0lNc^0080ooOh
00`0oooo0?Ogm`3oool0loC/0?Ogm03oool0ooOh0?ogm03om?P0lOOh0?Ggn03eool20?ooo`040?ob
m03gl_P0mooh0?Ofm080moKo00<0oo;h0?Oon03gm_l00P3gm_l04P3gool0moKh0?O[l03oool0mno`
0>Gdk02Q/Zd0VIZ_0<WDhP3AfnT0b=gX0?Ooo`3FkNd0[;Rl09NPV`2/Z9d0_[:/0=k=f`80ooOh?03o
ool00100oooo0P3omoP>0?ooo`80ooOh7@3oool01@3omoP0omc30?OTeP3gk_l0onCd0080onGh00L0
oooc0?ogn03[e</0mmGF0>;DeP3[k>D0onoh0080mNcd00L0lMcL0>[bkP3Sm?P0mnko0?ooo`3oiOP0
moOh0080onGh0P3oooL0103ooo<0oooo0?ooo`3om?@60?ooo`050?ofl03oool0oooo0?ofl03ol^T0
103oool03@3omoP0oooo0?ogk03oiOP0moOh0?oUn03ch?00mo;h0?Ofo`3gm_P0moOd0??gl`3gm>d0
0`3omoP0203okNh0loCc0??Uh`3oiNl0ooog0?ogn03om?@0ooOh0`3oool40?ogn0050?ofl03oool0
oooo0?ofl03om?@00P3oooL02`3ckNh0on_`0?oon03oool0lngc0?ooo`3omol0mOod0?Goo`3omoP0
oooo0080moCd00<0lo?h0??fo`3oool00P3gool05`3ol_@0loo_0=kQi`3Zm?P0j_Oh0??om03oool0
moCh0?ooo`3oooP0loCd0?O_m`3/l^D0lOoo0?7gn03emo00ooCo0?oon03gooL0ooOo0?ooo`3cm>`0
moOd0080oooo0P3omoP02P3amoP0mOOh0?Goo`3emoP0mO?h0?oon03oool0ooKh0?Ofn03gooP20??f
n00H0?ooo`3gooP0moKh0?Ofn03gm_l0looh0??^l03om_l0lnC^0?O_i@3:cL@0/;:m08^^a02]a]80
]<GK09nme02ce=h0fN7R0;Bj_@37c<D0XjRM0;FPY@3Sg>D0ooCd?03oool003l0oooo00D0onCF0?OL
``3gmoP0onch0?oUn0020?oUm0070?Ogm03[g</0mnoU0?;De`3Nh=H0h^GN0>[/k`020?;Tj0060>cD
eP3Nmo00h^co0?O^o`3oool0mnCd1@3oool0103ooo<0oooo0?ooo`3om?@30?ooo`@0ooK`0P3ol^T0
0`3om_00oooo0?ofl0020?ooo`80ooOh01<0ooOd0?ogn03ooo<0mnC]0?oUn03ci>h0mnO^0?O[m03c
m_P0jncX0?ooo`3omoP0mng]0?OUi`3okO00mnoW0>kgi@3oh>h0moO_00@0ooog00@0ooO/0?Odj03g
mn`0ooO/0P3omo@03@3omnl0ooK`0?ofl03olnh0oncV0?ogn03ooo<0moOh0?O]kP3gjnd0lng/0??X
j03/i^D00P3akNT0103em>h0ooCd0?ogn03gmoP20?Odm00D0?ocn03oooP0loKh0??fn03gl_@0ooKo
0??fn03^iNP0lnod0>cgo`3Tm?l0mOOd0?Odo`3gmoP0loCh0?Ogk`3conl0mN_^0?7dm03emo020?og
n0040?oon03cmo<0loOc0??dl`80moOg00D0ooOg0?odl`3oknl0mOCd0?ogn0020?Ggn00:0?odm03e
k_P0oo?h0?obn03gl_P0moKo0?Ofn03ol_l0mo;o0?ofm0<0mooo01D0mo;d0?Ofn03gmoP0mo?h0?OU
l03/i^D0fMC40??Xi@3Rk_@0am7Q0=kgn034h>P0a=g`0<O/m03AdmH0_;^m08nDT@1SIE/0HEQF0:ZG
W@3^iO00>`3oool00100oooo0P3omoP00`3oool0ooOh0?ogn00Y0?ooo`0?0?ogn03gdKH0omgW0?o^
o`3gm?@0oooo0?oom`3oiNl0ln3X0??Th@3ck>P0g/S;0?O]h@3cmo00mn3Q0080j^3Y00H0lnCQ0>;g
n03Smol0lnch0?OTm03oiOP20?ooo`80ooog00H0oooo0?ool`3oooL0oooc0?ogk`3omoP20?ooo`80
ooK`00<0oo;Y0?ofl03oool00P3om_00103oool0ooK`0?ooo`3oool20?ogn0040?oom`3oool0onG/
0?O^m`80moOh00d0onGh0?ooo`3cmo@0jncX0?Oom`3cmo<0oooo0?oon03cm>`0moOd0??Uj@3gmoP0
mnC]00<0oooo0180ooog0?oTm03ck?P0lnO`0?OTm03gmn`0ooog0?ogm03om?@0ooC]0?ogm03oooL0
oooc0?O_i`3gkNh0onk`0??Ti@3omoP20?Ggn0060?ooo`3om_l0mo;o0?Ofo`3oool0loKo0P3gm_l0
603gm_P0mo;o0?ofn03ooo@0mo;o0??fk@3gm^d0onG/0>;VkP3/moP0oood0>Cdl03om?@0loCh0?oP
m03gm^L0mnk^0?G^l03aool0mOOd0?ogo`3oool0moOg0?ooo`80ooOo00h0moOg0?ooo`3omoL0ooCc
0?ogm`3emol0mOOd0?Goo`3omoP0mOKo0?G^n03em?@0ooKo0?Ofo`80mooo00<0ooKh0??fn03cm_P0
0`3oool05@3gm_P0looo0??oo`3gko00oooo0=kUi@3UfL@0mnSW0>kokP3IgMh0dMCN0<KIf`2mdM/0
Vm3U0>[bn03amo@0mOOg0=oPh`2YZY/0XiRF0>KKj@0k0?ooo`00403oool20?ogn0030?ooo`3omoP0
ooOh02T0oooo00l0ong^0??D/`3ck?P0moOh0?OTm03omoP0ong^0>kLgP3[m=d0oooh0?G_l03Ze<d0
mooo0??]m`3ce=H00P3ai^L01@3ciND0h_Oh0=[fo`3Ji>d0f^og00<0ooog00P0oooo0?oom`3oooL0
ooog0?ool`3oooL0ooO_0?ogn0<0oooo00L0ooK`0?ooo`3om_00oo;Y0?ofl03ol^T0ooK`00@0oooo
00<0ooCd0?ooo`3ooo<00P3oiOP0203oool0moOh0?oTm03omoP0moOd0?O[k`3gk?@0ooOo0P3gmoL0
1P3oool0moOg0>_De`3oiO@0omgW0?ogk`80oooo0300moOd0??/n03olo@0ooKh0?ogn03gi>d0oooc
0?oom`3gmnl0moOh0?ooo`3gmnl0moOh0?OPkP3gl_P0ooKd0??Xj03eool0mNcd0?ofo`3om_P0moKh
0?Ooo`3gm_l0loKh0?Obm03om_@0oooh0?oom03om_P0ooKd0?oon03ol_l0ooK_0?ooo`3gkNd0g^g^
0?oom03Sk_l0j^Cd0?odkP3cm?@0mnc/0?Oom03ek?@0mOoh0?ogm03omoP20?ooo`040?Ogm`3oool0
ooOo0?Oom`D0oooo00X0mOCh0?Goo`3eooP0mOoo0?G^n03oool0mOKo0?ogn03oool0ooKh0P3gm_P0
0`3gm_@0loKo0?Ooo`020?Ooo`0E0?ofn03oooP0oooh0?o_l03oool0hngU0>_Pd@3oj>`0mnoh0?O]
m03SgMh0f=_Q0=7Af`2J/LD0_m7K0>kVg`3>b/`0SiF208=nL@2e/Kh0jn3Y03/0oooo000n0?ooo`03
0?oXhP3ce;T0loOh0080oo?d00X0k]cF0>KPeP3^gMh0omWV0?;8d@3/dLP0mnGW0??]k`3om_P0mn3D
0P3Zk>`01P3^mnh0oooo0??Vo`3Si>d0hoO_0?Ogk`<0oooo00<0oooc0?ooo`3oooL00P3oooL20?og
n0<0oooo0P3ol^T00`3oool0ooK`0?ofl0040?ooo`80ooOh00H0ooCd0?ooo`3oooL0ooog0?ooo`3g
moP20?OTm0060?ogn03gk?P0moOh0?Obm03oool0oooh0P3gm_@03`3gmnl0ln3R0?O_i`3om>d0ooCd
0?oom`3oool0mnC]0??/n03ok_P0mo;o0?Ogm03gi?@0oooo0?Ogm0020?oom`0D0?Ogm03gi?@0onCd
0??cm03gk^h0mooh0?OXk03aooP0oncd0?Ofo`3gm_P0lo;h0?ofi`3oonD0ooKh0?ofo`3om_P0oooo
0>kfn03^ool20?Ocm`0@0?ooo`3oonl0moO_0?O_n03TkOP0oood0>;/o`3ciO@0moO^0?O]k@3conL0
on_`0?7gn03omo@0ooOo0?ooo`80oooh00<0moOg0?ooo`3gmoL00`3oool20?Oom`040?ooo`3em?@0
mOoh0?Gon080mOoo00D0mNkh0?o^n03ok>h0ooKh0?Ofn0020??fn0030?ofm03cooP0mo;d0080moKh
01D0ooKh0?Oon03gm_P0onc`0?O_l03Umo<0jn340?o_n03okn`0moOg0?O_o`3gkO00hnG^0<CDeP27
^/T0_LK9092?Q026Ng/0aZk40>_Pj@3gko00>`3oool003h0oooo00l0omW90??A`@3clo@0oooo0>kE
e`3SbLD0lLoA0>;9b@3NbL/0j]CR0??Km03gk?P0onS_0??[gP3ekNh00P3Zk>`00`3Ronh0hoOo0??/
n0020?O^o`040?Ogn03oooL0oooo0?ooo`<0ooog00@0oooo0?ogn03om?@0ooOh0`3oool20?ofl0D0
oooo0`3omoP05P3oool0ooOh0?ooo`3oool0oooc0?ooo`3gmoP0onGh0?OPn03gmoP0lnKo0?ocm03g
l_@0oooh0?Ofn03ok_P0mn_h0?Ofn03gooP0ln3Y0?ogk03omoP20?oom`060?oUn03gk>h0ooKo0?Of
o`3gh>h0oooo0P3gmoP20?O^o`0@0?ooo`3gh?P0lo;d0?ocm03ok_00loO_0?o]m03eoo@0mOCd0?Of
n03ol_@0mo;d0?ofk@3oonl0k_oo0>_gm`80lnc/0P3cm?<0403gmoL0loCd0?Ogk03cm>d0mnoh0>c_
n03/mol0mOOd0>cgn03goo00lnod0?O_j03gm_P0oncd0?7gn03omoP20?ooo`80moOd00<0moOg0?oo
o`3gmoL00P3gmoL01P3oool0moog0?Oom`3oool0mOCd0?7oo`80mOoo0`3emoP01@3gjo@0mo;h0?Oo
o`3cm_P0mo;h0080moKh00d0looh0?Obm03gl_@0oooo0?Obm03gknh0ooKo0?O_l03Umo<0jn340?oo
k`3oool0ono/00<0moO_00D0mno_0;cIhP2`/ZX0T7ek0=[<e`0n0?ooo`003P3oool00`3om?@0ooOh
0?ooo`020?ogn2X0oooo0100ooOh0?O=/P3oin80moO^0?ocm03Vcm40lNKL0?ooo`3^dN80moCd0??P
n03ci_l0lnkd0?OXj03ci^T0mOCd0P3Zm>`01@3Rm^h0hoOo0??/n03gk_l0onG_0080oooc0`3oooL2
0?ogn0040?ooo`3omoP0ooCd0?ogn080oooo00D0ooK`0?obj@3Sk>h0hnoh0?ooo`020>?_n0050?oo
o`3omoP0ooOh0?ooo`3om?@00`3oooL0203gmnl0moOh0?ooo`3gmoP0oooo0??Wl03gl_@0looh0P3o
m_@07@3gm_l0oo?d0?Oon03gk?@0onOU0?OUk@3ooo<0ooOh0?ogk`3ooo<0ooog0?OPkP3olo@0onO^
0?OUl03gmoP0moO_0?ool`3gi>d0lnch0?O_l03gjo@0mo;h0?obn03gmo@0mnod0?ogo`3eooP0mOCd
0080moKh00H0oooo0?Ogm`3cm?<0lngg0?Odl`3gmoP20??dm00A0?Ogm03oooP0moOh0?Ogo`3gmoP0
moOd0>Cdo`3oool0j_Ch0?Ool03gkoP0mnoW0??fi`3om_l0mOCd0?Ggm03omol00`3gmoL0103oool0
loCc0?ooo`3gmoL20?Odl`80ooOg0P3omol0103em?@0lOoo0?ogn03amoP20?ogn0090?Ggn03gk_P0
moKo0?ofn03gm_P0ooKd0??om03ooo@0oooo0080mo;o00L0mooh0?Obm03gknh0mnc`0??XhP3oooL0
lm_40080oooX0P3gkO@01P3oknd0moo/0?ogm`3NgMh0cK^O0<jfa3l0oooo000>0?ooo`030?odm03o
moP0oooo0080ooOh:P3oool0403gg=H0ol_10?Ofn03ok?P0moO^0>_6d03ak^40mNGh0?;Pk@3cinl0
lnkh0?Oon03omnh0jnCU0?O/kP3emo@20>[]j0080?O^m03gk_l0moOh0?ooo`3gmn`0ooog0?ool`3o
ooL20?ooo`80ooOh0`3oool0203om?@0oooo0?ooo`3ol^T0ooK`0>?/kP3SkoP0oooo0P3SkoP30?oo
o`80ooOh0P3oooL02@3ooo<0mnCd0?OPn03oi?@0moCd0?oUn03clo@0oooo0?Obo`030?Ofn0040?og
n03oiOP0loC]0?Ogk`80ooog00L0ooCd0?ogn03omoP0oooc0?oUn03gi>d0moO/0080oooc0P3oooL0
4`3gmo@0lnch0??[n03gooP0ooKo0?obn03cmo@0onog0?Ggm03eool0oncd0??bn03om_l0k_oh0>_d
l`3cmoP0loO/0?Odl`3cm?@00`3gmol0703gmo@0oooh0?oon03gm?P0mOOh0?ooo`3/mol0i?Co0?og
kP3cmo@0mnoX0?Obn03omoP0mOOh0?Ggm03omol0loCc0?Ogm`3cm?<0moOg0?Ooo`3gm?<0oooo0?Og
l`3cmoL0moOo0?ogm`3omol20?ogn0050?Gdn03oool0lNo`0?odm03emoP00P3omoP01`3om_P0oooo
0??bm03cooP0mooh0?Ooo`3goo@00P3ol_P01`3gm_l0mooo0??cn03ci>h0mnoU0>Ggo`3VfKT00P3g
kOl0203oko@0mngd0?o_n03gooL0mno_0>_Pe`3A/9H0k^C^?`3oool003d0oooo0100mmC60?oLg03g
k_l0onko0??^j@3cc]H0mNkW0?OTi@3/i^h0mnKh0?O^m03Rmo@0j^o^0??Ph@3gmoP0lNgX0P3ciNd0
1P3ok?@0oooo0??dk@3gmnl0ooog0?Ogm080ooog0P3oool0103omoP0ooCd0?ogn03oool20?ogn080
oooo103om_040?ooo`030?ogn03om?@0ooOh0080ooog0140oooo0?ool`3gfnh0lnkh0?Ooo`3gk?P0
ooKh0??/n03omoP0mo;o0?O[n03olo@0ooOh0?oUn03oool0moO/0?ogn0020?odm0060?ogn03oool0
ooOh0?odk@3omn`0ooog103oool02@3ooo<0oooo0?oUn03gh?P0mo?d0?ofo`3om_@0mooo0?O]k002
0?Ggn00@0?ocn03cm_@0oooh0>kon03[m?<0loOh0??dm03gmoL0loCd0?;dn03em?@0mooh0??dn03g
moP0j^gh0>cdn080j_Oh00X0k?Oo0>?gl03ckOP0mngd0??Uk`3ok_00mOOh0?7oo`3emo@0ooOo0`3g
moL03`3cm?<0ooOg0?Ogm`3om?<0moCg0??gm`3gooL0oooo0?ogo`3om?@0ooCh0?Gdo`3omoP0lOOh
0?Ggn0020?odm0080?ofn03gm_l0mo;h0?Ofn03om_@0ooKh0?Ofm03om_l20?Obn00A0?Ofn03gool0
loOh0??]kP3gknL0iOOg0>K?^@3omoP0moCh0??dn03okol0ooo_0?o_k03oonl0jn3G0<:ZUP3okNh0
?`3oool000l0oooo0P3omoP[0?ooo`0A0?OMe`3ge;h0mmgW0?O^o`3ok?P0jo?U0?OAf`3ok_P0j_O/
0??dn03^k?@0k>ch0?Ooo`3Rmo00om_Q0??_l03ZiND00P3gl_@01P3om?@0oooo0??dk@3gmnl0ooog
0?Ogm080ooog0P3omoP01@3om?@0oooo0?odm03oool0ooCd00D0oooo0P3om_030?ooo`80ooOh0`3o
ooL04P3oiOP0om_X0?oUm03giO00loOd0?ooo`3ck?P0moOh0?o^n03gjoP0oooo0?O/m03ci_l0ln_h
0?O_l03oiOP0mnCX0?ogn080ooCd00L0ooOh0?ooo`3oool0oooo0?ogn03om?@0ooOh00<0oooo0P3o
ooL20?Ogn00:0?Odm03gl_P0oooh0?Ogm`3gm?@0ooCd0?7gn03gool0mo;d0?ooo`80moOg0P3oool2
0?Ogn0030?Ggn03ZmoP0lood0080moOo01H0l_Ch0>c]kP3gm?@0moCd0?O]hP3gj>D0mmgQ0??Vf`3/
k>h0mOOh0?7oo`3omoP0ooCh0?ogo`3oool0moCc0?ogm`3gm?<0loOg0?Ooo`3cool0mooo0P3omoL0
1P3omol0ooOh0?ogo`3emol0mOoh0?7oo`@0ooOh00D0mo;U0?ooi@3ol_l0mo;h0??on0020??om00E
0?ooo`3oooP0oooh0?ofo`3gm_P0mooo0?O_l03gknL0ooog0>_3/`3gooP0ooOh0??gn03oknd0onog
0?ooo`3om_P0ln3S0=k1YP3ceM00moOh03h0oooo000?0?ooo`80ooOh:P3oool04P3oko00llVb0??T
i@3gool0mnG_0?o_i`3[h>D0mmWK0?oVm03ek^L0mOo_0=WPm03^k_P0j_O^0??_k@3[g>D0k>g^0>[d
k080oo;h00D0mo?d0?O^o`3gmoP0ooog0?Ogn0030?oom`80ooCd00<0ooOh0?odm03omoP00P3omoP8
0?ooo`80ooOh01H0ooCd0?oom`3oool0ooog0?ooo`3oiN`0om_d0?ooo`3gi?@0lnch0?ooo`3gk_l0
moOh0??[o`3gm_P0mnkh0?Ogn03ck?P0lnko0?Ooo`3ojo@0mm_Q0`3oool01`3omoP0ooCd0?ogn03o
ool0ooOh0?odm03omoP0103oool03@3ooo<0moOh0??/n03om_P0mnK^0?ogo`3gmoL0moCd0?G]kP3e
ool0mooo0?Obm03oool00P3gmoL00`3oool0moOh0?oon0020?Ogo`80ooOh01`0loCo0??dn03gmo@0
moOh0??dm03cm>d0k_Og0??^l03gk_00oooo0?Goo`3emoP0lOOh0?ogm03om?L0ooCc0?Ogl`3cm?L0
mooo0?Ogo`3omol0mooo0?Ogm`3omoL0looo0?Odl`3omol0ooOd0P3em?@20?7gn0080?odm03omoP0
oo?h0?ofo`3cl^D0moK]0?ofn03ol_P30?Oon00:0?ooo`3oooP0oooh0?ofo`3gm_l0mooh0??Xj@3U
mo<0iOOg0>K8^P80moOd00<0loOh0?oXk`3oonl00P3om_P0103gko00h/Vb0=6k^P3gmoPn0?ooo`00
>`3oool04P3oh=@0mlg40?Ooo`3gk?P0moCX0?oTj03ci>T0lnSL0?ooo`3oi_@0lOoX0=K]n03goo00
j_O^0??Xj03Si^T0lOCd0??dj080on_h00D0mnch0?oUn03cm>d0oooo0?Ogm0020?oom`030?ooo`3o
m?@0ooCd0080oooo0P3omoP0103oool0ooOh0?ogn03omoP20?odm080ooOh00@0ooCd0?ogn03omoP0
ooO_0P3oooL04`3gmn`0moO_0?ool`3gmoP0lnch0?ooo`3ck?P0onGh0?ooo`3om_P0lnko0?Ool03o
jnh0onKY0?O[kP3gk>h0mncd0?Ooo`3ch=`00P3oool20?oom`030?ooo`3om?@0ooOh00<0ooOh103o
ool02P3gmn`0moOh0?oUn03ck?P0mnC^0??fm03cm?<0mng]0?7dm03oool20?Ofn0040?ooo`3^ool0
loCc0?ooo`80moOh02@0loOh0??gm03gmo@0moOd0?Ogk@3gmo@0moOg0?OWl`3ok>`0ooo_0?Ofn03g
lo@0ooOh0?ooo`3eooP0lOOh0?oon03emoP0onSc0?Ooo`3omol0moOo0?Ogm`3cmo<0moOc0??gm`3g
moL0oooo0??gm`3gm?<0oooh0?ogo`3emoP0lOCd0?ogn03eool20?ooo`070?ocn03gm_l0ooKh0?Oo
m03cm_P0lo;d0?ooo`020?ofn0<0oooo00L0ooKh0?Ofo`3gm_P0ln3Y0>Ggl`3UmoL0jlS400<0moOh
00L0onoo0?Ooh@3gl_P0oooo0?ofn03gdKT0dJZP03l0oooo000>0?ooo`030?odm03omoP0oooo0080
ooOh00<0oooo0?ogn03omoP0903oool04`3oko00omc10?oKgP3om_P0oo?d0?oTj03oiN`0mmcV0>_L
g@3omo00onKd0?7oj03Vm?P0i?Ch0>Cdm03cj>P0hnKY0?7]k@3cmnd00P3gk_@01P3gk_l0moOh0?Og
k`3gmoP0moOd0?ool`80oooo00<0ooCd0?ogn03om?@00P3omoP01`3om?@0ooOh0?ogn03omoP0ooC]
0?oom`3oool00P3omoP20?ooo`080?oom`3oool0ooog0?ooo`3cm?@0lnc_0?OTk@3oiOP20?O^o`07
0?Ogn03ck?P0mnch0?Ocm03ok_P0ooKh0?oon0020?ooo`090?o[kP3ojoP0moKh0?oTk@3gmnl0oooo
0?oom`3oool0ooog0080ooOh00<0oooo0?ogn03omoP0103oool03`3gmnl0moOd0?oom`3gm>d0oncd
0??ck@3gm?@0mOOh0?ogn03emoP0loKd0?o/m`3okoL0k_oo0??dl`020?ooo`0A0?oon03gooP0mooo
0?ooo`3gmol0mng/0?Ogk`3gmoL0ooKo0?Oon03gm_@0mo;h0?Ogn03omoP0mOoh0?ogn03em?l00P3e
mol02P3om?L0moOg0?Ooo`3cooP0moO_0??dl`3gmoL0loCc0?Ooo`3gm?<20?ogm`060?ogn03omol0
ooOd0?Ggn03oool0mOOh0P3oool00`3omoP0moKo0?Obn0020??on0050??fn03oool0ooKd0?oon03o
m_P00P3oool04P3oooP0mo;h0?Ofo`3ch>T0iOOc0=Wdo`3[e<X0ono]0?o/k@3ok>`0oooX0?Ofi@3g
m_l0ooKo0?ofm03ci=h0f9^20?o_l3h0oooo000>0?ooo`030?odm03omoP0oooo0080ooOh00<0oooo
0?ogn03omoP0903oool04`3oh=@0onC;0?OTiP3cl_@0moO^0?oTj03oooL0onSR0>KDf`3eiML0lOK]
0?Ggj03Vm?@0j_Oh0?;gn03gj>P0hnKY0?7Xj03cm_@00P3gjo@00`3oiOP0lnch0?OTk@020?Ogn004
0?oom`3oool0oooo0?odm080ooOh00@0ooCd0?ogn03omoP0ooOh0P3om?@0203omo@0ooog0?ooo`3o
ool0ooog0?ool`3gmn`0loC]0P3gmnl20?Ogn080mnCd00T0onGh0?ooo`3ci_l0oooo0?Oon03oloP0
ooKo0?ooo`3om_P00P3oooP01P3ooo@0ooKo0?oon03gjo@0onGh0?Ogm080ooog0P3oool00`3ooo<0
ooog0?ooo`040?ooo`@0ooog00`0oooc0?oTj03ck^h0oooh0??Xj03emoP0ooOh0?Gdm03gm_P0mnc_
0?o_m`3^ool20?Ogm`@0oooo00h0moOh0?O]m03^ko@0k_o]0>kon03oooP0moKh0?Oom03cm_P0ooCd
0?ooo`3eooP0ooOd0?Ggn0<0ooOg0180moOg0??oo`3gooP0moO_0??gm`3omoL0oooo0?ogm`3gm?<0
ooOh0?odm03ooo@0mOoh0?7go`3eool0mOOh0?Gdm03omoP20?ocm0090?ofo`3gl_P0oooo0?ofo`3g
ooP0oooh0?ooo`3om_@0ooKh0080oooh01<0ooKo0?oon03ol_l0ln3Y0>Ggl`3Im?L0jnCM0?obi`3g
onl0mooh0?obn03gm_@0mooo0?obn03oknl0mnG]0=VZU03Ia/T0moOh03d0oooo000R0?ooo`80ooOh
5P3oool04`3oe;T0omcU0>_Uf`3cm>P0jm_G0?o_i@3omoP0mmWF0>_IeP3ajnD0mOo_0?;_k03Smo00
k?Oo0?Ggn03^j>P0hnKY0>[Xh@3gl_P00P3om?@01@3gmoP0mnko0?oUm03gmo@0moO/0080oooo0P3o
moP50?odm080ooog103oool0203gmnl0moCd0?ogk`3gmoP0loCd0?o^n03oh?@0onGh0P3gi?@01`3c
kNh0moCd0?O^o`3ci_l0mooh0?Ogn03gool00P3om_P01`3om_@0oooo0?ofm03om_l0oooh0?Ofl03g
k?P00P3gmoP0103gmo@0moOh0?oom`3ooo<40?oom`80ooOh00d0oooo0?oom`3oooL0ooog0?ool`3o
ool0mnC]0?O^kP3oooP0lng/0?o_l03aool0ooOh0080moKh00D0oooo0>__o`3gkol0loCc0?ooo`02
0?oon00]0?Ogn03gmoL0ooo_0>kok`3[knl0jno]0?ofk`3ol_P0oooh0??fn03om?@0ooOh0?Ggn03o
moP0mOoh0?o]l`3om?<0moOc0?ogo`3gmol0moCg0?Ooo`3gmoL0oooo0?ogm`3oool0k>o_0?Ggn03e
ool0mOCh0?Gdm03amoP0mOOo0?odm03oool0mooo0?Ofn03ok_00ooOh0??oo`3cl_P0loKh0?Ofm03g
m_P0ooKh0080oooo0P3oooP20?ofo`0A0?ofn03ch>80ooog0?ool`3gh><0lo;h0?Oon03cm_P0moKd
0?ofm03gool0mn_U0?O]m03oj>d0f/RS0=VZY`3gmoP0?@3oool00280oooo0P3omoPF0?ooo`0C0?o?
[P3oh>h0i^cF0?ooo`3VclH0ooO_0>kMeP3[e<h0moCd0?7[iP3emol0l^o/0=Wdl03emoP0lOCd0?O]
k@3Ofmd0i>gQ0?obo`020?Ocm0040?O^o`3gmoP0loCd0?Ogn080ooog01D0oooo0?ogn03omoP0ooCd
0?ogn03oool0ooOh0?odm03omo@0moCd0?Ogk`3oool0ooog0?ool`3gmo@0ooO_0?Odk@3gmoP0loCd
0?OWkP3gjo@00P3gk_l00`3gooP0on_`0?o[l0020?o^n00@0?ooo`3gk?@0mn_h0?oom03oooP0oooo
0?oon03om_@0ooOh0?oVm03gi_P0mnko0?ooo`3cm?@0moOd0?Ogk`<0ooog00<0oooc0?oom`3ooo<0
0P3omoP30?ooo`80ooog00l0oooc0?Ogn03gh>h0oood0?Odm`3gm>d0lOCd0?ooo`3gooP0mo;h0?oo
o`3gkol0k_Og0?ogm`3gool00P3oooP0103cm?@0onoh0?o_m`3^onl20?O_k`0Q0?obi@3gooP0lo;o
0?Obn03omoP0oooo0?7gl03am?P0lOOo0?odm`3oool0moCg0?Oom`3gmo<0moOo0?Ogm`3omoL0moCc
0?Ogm`3gm?<0mOOd0?Gdo`3emol0ooCd0?Gdo`3emo@0ooOo0?Ggn03omoP0mooo0?ooo`3cmoP0lnk`
0080ooKh00@0mood0?Ofo`3gm_@0ooKh103oool04`3oooP0oooo0?OTj03^mnD0hoCg0>?do`3OfL/0
jo?_0??fn03oooP0ooKh0?Ofo`3gknh0k]C@0?Ogn03okoP0fLVf0>>RS@3omoP0?@3oool003T0oooo
01@0mmgG0?O<]03^c<l0hlW50?GMgP3^fMh0e[2j0=Jjb@3TfMh0ZKRj08nZY`2X`/@0c^3X0>Gdm03/
mol0mOOh0>cXj03IcLl0j_O]0?o[n080ln_h00H0lnKo0?ooo`3gmoP0moO_0?oom`3ooo<20?ooo`80
ooOh00<0oooo0?ogn03omoP00P3om?@06@3gkND0moO_0?ooo`3oooL0oooc0?oom`3gmoP0oooo0?oU
n03gk_l0mnch0?O^o`3om?@0ooOh0?oVm03ooo@0ooKd0?ogm03ok^h0mnk^0??Vj@3gmo@0ooKh0?oo
m03goo000P3gk^h02P3gi_P0mnko0??/n03cm?@0moOh0??dm03gmo@0moO_0?oom`3ooo<30?oom`03
0?ool`3oool0oooo0080oooo00h0ooog0?ooo`3oool0ooog0?oUn03giO@0moK`0?O/m03gm?@0mOO`
0?Ggn03gm_l0moKd0?Ogm`80joOg01H0ooOg0?Ooo`3oool0oooo0?Ogm`3cm?L0jngc0>_gk03gmn`0
oooo0?ofn03gl_@0moKo0?Ofn03gl_l0oncd0?7gm03emol0mOoo0?ooo`3omoL0ooCc0P3omoL0303o
ool0moCc0?Ooo`3gm?<0mooo0?G_k`3em?P0mOOh0?Gdn03am?@0mOCh0?Gon080lOoo00T0ooOh0?od
m03gloP0moKo0?Ofn03om_P0ooKd0?Oon03om_P00P3oooP40?ooo`0C0?ofn03ol_P0mnc`0>kgi@3S
m?L0hoCo0>jbX`3[]L@0jkg80>_UgP3gmoP0loC^0?O]iP3c`l/0mood0??gn03oiMh0eYF90?O<]@0m
0?ooo`00>03oool05@3omoP0mmBm0?OIa03SbLD0oooo0?GWhP3SeML0l^gU0??^n03AeLd0_<c=0>cg
n03gmoL0amcM0=7Pj03Rjo@0moKh0>;Lg03Fcm40loKd0?o/m0020??/n0030?OTm03cm?@0moO_00<0
ooog103oool00`3omoP0ooCd0?ooo`030?ogn0080?oom`3gmn`0moO/0?Ogk03gm>d0moCd0?ooo`3o
iOP20?O^o`040?Ocm03omoP0ooKo0?ogn080ooKh00T0moKd0?Ooo`3gooP0lood0?Ofn03oool0oo;o
0?Obn03gk?P00`3gk_l02P3ck?P0loCd0?Ogn03cm>d0moO_0?Ogk03oool0moO_0?Ogn03oool30?oo
m`<0oooo0P3oooL03`3ooo<0oooo0?OTm03ci_l0moOd0??/j03om?P0mOO`0?Ggn03cl_P0oooh0?Og
k03^onl0loCc0?Ogm`050?ooo`030??dl`3[moL0moOg0080oooo00T0ooKh0?Obn03om_l0mnkh0?oU
l03aooP0mOCh0?Gdm03omoL00P3oool02@3omoP0ono_0?ogm`3oool0ooCc0?Ogm`3gool0mNo_0?Gd
m0020?Goo`0;0?7gn03em?@0mOOh0?Ggn03eool0oooo0?ogn03om_l0loOh0??fo`3cm_P00P3gool0
0`3om_P0oood0?ooo`020?ooo`80ooKo01@0oood0?ofo`3oool0lnSL0?ooo`3UmoL0b9RA0>?oo`3c
g>L0jlW50??^gP3cm>h0mng^0??=e`3gknD0loOh0?Ogn03R_L<0hj>60?O_l3`0oooo000h0?ooo`0E
0?oTeP3og<<0i/K50?7IeP3ak^40hn3N0>?Ui@3Ne=H0d=CG08NPX`3:cM/0g^C^0>cgn03gmoP0fNGU
0>K]k03Sk^d0b/oF0>CKg@3cjnd0ooCd0080moOh0P3gmo@00`3gmn`0oooo0?ooo`050?ooo`030?og
n03gm?P0moOd00<0oooo00@0ooog0?Ogk`3oool0mno`0P3gmoP03@3gkNh0mnC^0?oVkP3gi^T0mn_d
0?o[n03oool0ooOh0?Ofn03gk_@0mn_`0>cbkP3Sl_@00P3om_l0103oool0mo;h0?Obn03ok?@20?og
n00:0?o^n03gk?@0loC]0??dj03oool0moOd0?ool`3oooL0moOh0?Ogk`@0ooog1@3oool01P3ooo<0
moOh0?ogn03gmoP0on_`0??dk080mOCd00D0ooKo0??fm03^ool0joO/0?Ogn0040?ooo`80oooh00@0
ooOg0??]n03^onl0oooh0P3^ooP02`3gl_P0loKo0?Ogn03ok_P0mOOh0?Gom03emol0ongd0?Ggm`3o
mol0ooCh0080mOOh00@0ooCh0?Gdn03ekNl0ongg0P3ekoL01`3em?P0mOOo0?Ggo`3om?@0ooOh0?Gg
n03omoP00P3oool20?ogn0050?O/m03om_l0moKh0?ooo`3om_P00P3oond20?ook`0G0?ooo`3om_P0
ooKh0?oon03oool0mo?h0>kdh@3UmoL0iOOc0<FMU`3Zm?@0hooh0>k9f`3ggMl0ooKU0?O_l03gk>H0
on3/0?oon03gmol0onkW0=jCN`3cfM@0?03oool003L0oooo01H0ooOh0?oI_@3oiMh0i/S;0?GVi@3g
moP0cnoR0>cgm03Afm`0VJnd0>?Vk`2d_</0mnkh0=KTkP3Ii?00hnkh0>[_l03ZknD0^L7@0=KKg@3[
lnD0lnO`0P3gmoP0103cm>P0moO/0?Ogk03oooL20?ool`030?oom`3oool0oooo0080ooog0P3gooP0
5P3oooL0oooc0?oom`3oool0ooog0?Ogk03ckN40moC]0?ogn03om?@0oncd0?o[l03gl_@0mn_`0>?[
m03Slol0on_h0?Oon03ok_P0lnCU0>[Vh@3ZjnP20??^k@0=0?Ofn03coo@0loKd0?ogn03om_l0ooOh
0?o^n03gk?@0loC]0??dj03oooL0oooo0?Ogk0020?oom`040?ooo`3gmnl0moOd0?ool`80ooog01X0
oooo0?oom`3oooL0oooo0?ogk03giOP0onko0?Odm03ol_@0lngc0?Ggm03em?@0mo;W0?Ook@3^ool0
jngc0?Ogo`3gool0loOh0?Ogn03oool0oooh0?ooo`3gm>`0k_o_0>__k`80k_od00l0k_oh0??bn03g
m_l0mncd0?ooo`3eool0lOOo0?Gom03eool0mOCo0?Goo`3em?P0lOOh0?7oo`3oooP00P3aooP00`3e
moP0oooo0?ogn0030?oon080ooOh00<0mOoo0?ooo`3omoP00P3gk?@20?ogn0040??gn03gool0mo;h
0?oon0@0ooo_0`3oooP20?obo`050?O[n03[mnD0mOOo0>?]k@34ZJd00P3/moP02`3ce>40mnSV0?O[
h@3oool0mooh0?OTk`3oj>`0mng_0?O]o`3AXi00mkZb03`0oooo000f0?ooo`0G0?Ogn03cj>T0mm6b
0?OUj03Ra/40mNk]0>[dm`34eM00_LS;0;c5b@3Vk^l0[;^n0<C2bP3AfNH0jncd0?Ogn03[joP0moOh
0?;]i@2d`lX0e/oA0>_^j@3ck?P00P3oool0103oooL0moOd0?ool`3oooL20?ool`0:0?oom`3oool0
mooh0?Ook`3oool0ooog0?ooo`3oooL0oooc0?oom`@0oooo01H0moO/0??dk@3cm>P0moCQ0?O]f`3c
j=`0lngQ0=W]k@3Ij>P0ln3L0?OPi@3gi^h0mnGW0?odl`3oool0ooOg0?ogm03gkN40mngX0?OWk03c
k>d0mnk`0`3ok?@06P3gk?P0lnch0?ooo`3oooL0oooo0?Ogk`3oool0ooog0?Ogn03gmo@0oooc0?oo
m`3oool0ooog0?ool`3oooL0moO/0?OUk`3gool0mooh0?o[l03ok_P0lng/0?Ggl03ek_00loK]0P3o
onl01P3^koP0loCg0?Ooo`3cmoP0oooo0?Ogm080mooh00@0loC/0>__o`3[kol0k_oh0P3oooP04`3g
l_P0oooo0?Ogn03omoP0oooo0?Goo`3emoP0mOOd0?Gom03am?P0mOoo0?odm03omoP0mOOh0?7oo`3e
ool0ooOh0?Ggm03eooP00P3omoP0203oool0mOOh0?Goo`3emoP0ooOh0?Ogn03om_l0mnkh0P3omoP0
1P3gmoP0ooKh0?Oon03ol_P0ooKd0?oon080ooo_0`3oooP20?obo`0C0?O[n03[mnD0mOOg0>?]i@34
[[80k>o_0>cgn03gcn40moCV0??Vi@3om^D0moKW0?ofn03cl_@0mncU0?o_m03I`[d0hj:=0?ogn00k
0?ooo`00=P3oool05`3gmoP0jm7<0??I_@3[jnD0j/S40?7^h@3Rm_@0Y:ji0;kEeP2nfmd0_[Rl0?oo
o`2P[[d0lo?d0?ofn03gmoP0iNch0=WTm03ZkNh0_L?40=K?d@3cjnh0moCd0080moOh00<0moOd0?Og
k03oooL0103oool0203oooL0moo/0?Oom03oooL0oooo0?ool`3oooL0oooo0P3gmnl01P3oool0mooh
0??om03gonl0oooo0?oom`80mooh0P3oool20?ool`80moO_01@0mnko0>k^kP3coo@0loO_0?Ogm`3o
moP0oood0?oon03emoP0lNo]0>[Xh@3Zh>40mnc_0?obo`3Rm_@0fNOh0?Ogn03gmnl0ooog0?Ogm080
ooog00@0oooo0?oom`3ooo<0oooo0P3oooL0403ooo<0oooo0?Ogn03gi?@0lnch0?oVm03omo@0moOg
0?Odk@3am?@0moKd0?O/m`3okn`0mnoo0??]n03gmnl20?oon080loCh00T0loOo0?Odm03gkN`0i_o_
0?ook`3oool0k_oo0>kfm03gm_l00`3gmoP01`3omoP0mOOh0?7gn03eool0lOoo0?7gn03em?P00P3e
ooP01P3emoP0lOoh0?Goo`3oool0lOOh0?Ggn080lOOh01<0lOoo0?ooo`3om?@0ooOh0?Ogn03om_l0
mo?h0?ooo`3gm?@0moOh0?Ofo`3oooP0moKh0?ofn03ooo@0ooKh0?ook`3^onl0k_oo0080oooh01D0
ooKh0?ooo`3[k>D0ooO_0>kgi`3cj>80a;Fj0?odl`3Ti?@0mnG_0?O_kP3giNL0lnc_0??^h@3gm_P0
mooo0?OKj03gmoP0mm_K0=RMQ03okND0>`3oool003L0oooo01H0mlo00?oPd03[g=/0lMWF0>[^g033
gM/0SjNf0=[UhP21W:@0lnc/0=[Mg`3>fN40]<7>0;Fia03cg=h0g^gh0<kDj@3IkO@0_Kbn0=KEeP3c
l_@0mng^0P3gmoP00`3ooo<0moO_0?Ogk`030?ooo`070?ogn03omnl0oooc0?oom`3oool0ooog0?oo
l`020?oom`060?Ogn03oool0loCX0?Odh@3gmn40mood0P3ooo<30?ooo`0L0?Oon03gonl0ooog0?Og
k`3cm>P0hnCX0>;[i`3gk_@0loo^0?Ogm`3okO<0ooCg0?odo`3eoo@0mOoo0?ooo`3eooP0j^gR0>CL
f`3cjnD0fNkh0??dm03cm>d0ooog0??dm03gmn`0oooo0?ool`80ooog0`3oool0403gmn`0mnCd0?oU
n03gmoP0oooo0?OPj@3gm>l0moOg0?ogm03am?@0moKd0?O/m`3okn`0mnoo0?Odm03ooo@20?Ogn003
0??do`3gm?@0ooOh0080moCd00T0loCd0>_gk03^ool0k_oh0>kbn03gool0loOh0?ooo`3gm?@00P3o
moP03@3emo00mOoh0?7on03aooP0mOOd0?Goo`3emoP0lOod0?oon03oool0mOoo0?odm03em?@00`3e
ool20?ogn0070?ooo`3gool0mo?h0?o^n03om?@0mooo0?ooo`020?ofo`070?Ofn03om_P0ooKh0?of
m03oooP0k_oo0?Ogm`020?Ogm00F0?ofn03om_l0k_OW0>?]i@3gknd0mno`0<_1aP3gkN`0h]c]0=KK
k03RfnP0llSF0??3d@3Uc<d0k^GO0?Ofn03gi>l0moOU0?OTh@3NXY00lmG;0?Ogn0d0oooo0P3omoPI
0?ooo`80ooOh403oool000h0oooo00<0ooCd0?ogn03oool09@3oool05`3omoP0omC00>_Da03/dLd0
onkh0>[Mc@2K`[<0Vjjf0;GEgP2i`//0QZRd06R8W`2?XkH0^Kg60;k6d`3Jjo@0_/;F0>cUl03JkO@0
W;Fn0=KEeP3cjnh0mno`0080moOh00H0oooc0?Ogk`3oool0moO_0?ooo`3oooL20?ogk080moO/00X0
oooc0?oom`3gmnl0loCX0=W]k@3Ij>P0moC]0?Ogn03cm>d0ooOU0`3goo@30?ooo`0K0?Oon03oool0
fNod0=[_m`3oool0fNg_0=[_o`3gh>l0e_K`0>[fkP3gooP0ooOg0?o]l`3okNP0lOOh0?ogn03om?@0
ooOh0?o]kP3Sj=/0f=cF0>;Lg`3ci>D0moO_0?ooo`3cm>P0oooo0080ooog103oool07`3gmnl0mnC]
0?O^o`3oool0ooOh0?OTiP3gm?L0moCc0?o]j03amoP0oo;h0??on03gmoL0loCd0?Ogn03oooP0moCd
0?ogn03gmol0ooOh0??gn03gool0ooOg0??dl`3gmoL0i_oh0?ooo`3ol_@0oooh0?Ooo`3gmoP00P3g
m?@02@3om?@0mOO`0?Ggl03emo00mOoh0?ogn03emo@0mOoh0?ooo`020?Goo`070?ooo`3gk?@0mn_h
0?O/m03gmoP0ooOh0?ooo`020?ogn0050?odm03omoP0ooOh0?Ogn03cool00`3gool01`3om_@0ooKo
0?oon03ooo@0ooKh0?ofo`3[moL00P3[mo@0103^m_P0ooKo0>kgi`3SkNd20?O_l00@0<_1aP3[j>P0
loOh0>_PhP3Fe=H0bm_L0<_=eP3@/<@0f[Ji0>_;``3gm]`0onoo0?Oon03NZi`0jk:T0?Ogn0d0oooo
0P3omoPI0?ooo`80ooOh403oool000h0oooo00<0ooCd0?ogn03oool09@3oool05P3okNh0om6f0>K9
`@3afMH0lNkQ0?OPg@21SiH0_<k;09Nma@3IiO00Nifb0>_[m02CX;T0e/c60=WMeP2lb=H0_/oL0?o^
l03Jh>H0[Kg40<_?d@3ci^T30?Ogn0040?ool`3gmnl0oooo0?Ogn080ooog0P3ooo<02`3gmnl0oooo
0??]kP3cj>80mngU0?odm03Sk_@0k?;`0??[kP3[fmd0k]gF0080moo_00X0moo/0>?_i@3Ij>40lngQ
0?OTj03Se=/0g/o;0>[Ib03RfLl0f<o:0P3Fa/401`3Hg<l0fN7@0>;QeP3bmo@0oooo0?o_k`3ekNd0
0`3emoP02@3oool0ooOh0?ogn03oko00j^KO0?OTi`3omoP0moOh0?Ogk0020?oom`80oooo0P3omoP0
803oool0ooog0?oom`3gmoP0mnko0??/kP3ol_@0ooOo0??om`3ehN80mOKh0?Oom03gm^L0loCd0?oo
o`3omoP0moCd0>[_kP3Rmo@0k?oo0?Ogn03oool0moOd0?Ogk`3cm?<0jo?g0>kbn03ol_l0oooh0?of
n03goo@0loKd0P3gl_@0103cl_@0lnk`0??gn03gm?@20?ooo`80ooOh103oool01@3ck?@0mo;o0?Of
o`3cm?@0ooOh0080oooo00@0ooOh0?ooo`3gmoP0loOh0P3gool20?Ofo`080?Oon03om_P0ooKh0?oo
n03^ool0k_Ko0?ofo`3^ooP20>Kon00E0>kfm03om_l0k_OW0>_]hP3gko00oooo0<_8b`3Vi>D0ong^
0?O[k@3bm?<0mOOg0?o_n03OkO@0h]WR0>k<g`3geMl0mooQ0?OXh@3N]k<0jjZA03/0oooo000f0?oo
o`0F0?oXhP3gb:h0h/K10?oDg`3ec</0mnKO08J8T02neM/0Z<gG09c6e02L[[d0/Kg@0=7Df`2M/;80
SjFZ0=7QhP3Ag=d0i>ch0<OIj@2a][T0`loF0??Vj@<0moOh00<0ooog0?Ogm03oooL00P3gmo@01P3g
mnl0oooo0?ooo`3oooL0moO/0??]i@80lnSR0180mng^0?o/m03gjo00l_?d0;k4aP2TYZX0`[Fb0=S8
a@3A`/D0f/:j0=k8`02n][X0_KF^0<k2_`3Ob<X0fLo:0=W?c`3IcmL20=oIiP0C0=W8d03[fn80jm_R
0=Jmb03Rb]/0j]gW0?;^n03omoP0l_Cd0?;^n03ol_P0ooKh0?ooo`3omoP0mOCd0>cTi@3Rk^h0f^oh
0?Ogk0020?oom`0Z0?ooo`3omoP0oooo0?ooo`3omoP0ooog0?ool`3gmo@0mnko0??/kP3ol_P0moO]
0?Ogm03ekNh0mNk`0??_m03gio@0moOh0?oon03omoP0moCo0>[_m03NmoP0j^oh0?Ogn03gool0moOd
0?Oon03oool0mnkg0??Vl`3gjnP0mnkX0??Wm`3[i?l0jnkg0?Ogm03oooP0k_oo0>kbm03oool0moOh
0P3cm?@00`3ckNh0moCd0?ogn0020?Odm0060?ogn03cm?@0ooKo0?Ocn03gmoP0oooo0P3om?@20?og
n0040?Ogn03cm?@0moOh0?Ooo`80oo?h00P0moKh0?oom03om_l0ooKh0>kfn03^ooP0k_oo0>kon080
oooo01D0ooKh0?ofo`3gko00h^oY0>?ol03^m_P0e]GF0>KVj03oj>T0l_;d0?ooo`3bm?<0oooo0>Ko
o`3Zi>D0k>G`0>k9f`3[i]/0lnS/0>C2a@3VWHD0>`3oool003H0oooo01L0on3@0>_1Z`3Zb<@0mNGh
0?G5aP3cj>40WIRA0;32b`2`bmH0JZ_10=[@f`2S]L/0]MCV0;CDh`3Ai>h0f^C^0=[^k`3^knL0j^3^
09N[/`33cmH0ln_^0?O_l0030?Ogm0060?Ogn03gmo@0moO/0?Ogk`3oooL0moO/0`3oooL05@3gmn`0
loC]0??]i@3^i>H0ln3K0>;Ad03AbL/0`/[<0=7=eP29UZL0L8bM07f:V`2LXK<0_Kc40<_8bP3@fM/0
e^gW0=k]i`3ZkNh0k?O_0?oom`020?ooo`0H0?ogk03VkN40i^gQ0?;dk@3Fe<D0g]_@0>_Ui`3^g?00
lnCd0?Ofm03cooP0loKh0??bm03bhN80j^SQ0?;_k@3Zm^h0hnch0?Ogk`3cm>P0moO_0?ooo`3om?@0
ooOh0P3oool0203omoP0ooog0?Ogm03gmoP0mng^0?O[m03gmnd0moOd0P3em?@03P3ci>d0mngc0??d
m03gmoP0moOo0??do`3Zko@0j_Oh0?O]l03okOP0ooOh0?odm03gm?@0moOh0P3oooP02@3cm?@0joO/
0??]k`3[ko@0joO]0?O^k`3om_P0k_Kd0>kfn0050?ooo`080??dm03gm?@0ooOh0?ogn03gm?@0moOh
0??/m03gk_P20?ooo`0:0?ogn03oool0oooo0?o_l03om?@0ooOh0??dm03gmoP0oooo0?Ogl080ooKh
00H0oo;h0?ofo`3om^d0ooo]0>koo`3^ooP20>?on00;0>?fo`3Sm_00f^oo0>?ol03RknT0k_;h0=KQ
f`3[h>40mng^0?G^l03blo@00P3gmoL02@3cm?<0joOg0?7Vj@3cfnP0jmcA0?o]k03be=00gYQo0?og
n00j0?ooo`00=P3oool05`3oe;T0i/Ri0?7?d@3eiOP0mLG60??]j02YZj<0W:Zh0=[Uk`23[L@0k?Og
0;7Dh@2ag>L0l_Og0?7oo`3Vj>T0i?;o0>kdj03UiO00PXbF0<CAe`3gk_00mnoW0080moOh00D0moOd
0?ooo`3gmnl0moO/0?Ogm0020?Ogn00S0?Ogm03gmoP0moOh0?Ogk`3oool0ooCd0?Ofn03bk>D0j^SY
0>KPi@3Ig=h0Xj2^0<SLi@3oi^80j^CQ0<7AgP34dN<0j^g^0=WUi`3ok]l0f_Og0>?ok`3Rh>T0`loA
0<_?a033clX0_LS80;Bm^@2m`kl0g^O]0?Oon03ZinH0c]7;0=kdh@3^m?<00P3gkO<20??]k00:0>;A
d`3/kND0moOd0??on03ojo00ooOh0?Ogn03gmo@0ooog0?odm0@0ooOh0140ooog0?ool`3oooL0moCd
0?OVkP3ooo@0loC/0?G]kP3ek_00loKW0?ooj03^ool0loC]0?Ogn03cmoP0k?Oo0?Ggn0020?Gdm009
0?oXo`3emoP0l^7d0>c]l03Rm?L0loC/0?Ogm`3^ooP0oooo0080k_od00D0jo?]0?Och@3^m^D0k^C]
0?oTk@020?O[k@0B0?obm03^l_@0iN_`0?Ocn03gmoP0oooo0?Ogn03oool0ooOh0?odm03omoP0oooo
0?ogn03eooP0mOOd0?ogn03gmoP0lng^0P3oool02P3gk_00oo;o0?ofo`3om_P0ooKo0?ofn03^m^L0
i_o_0>koo`3^ooP20?Gon0030>?bo`3Sm_00hoK`0080mno`0140k_;h0<kQf`3^h>40moCd0?O/kP3c
lo@0moOg0??dl`3gmoL0joOg0?G^l03Zc=/0lnGK0??go`3oh=/0f9io0?odm00j0?ooo`00=@3oool0
603omoP0mlf]0>_6a@3e`=00oooo0?:m^@3gmoL0_<:h08ZM[@3@i>H0WlGK0>k^n03Si>l0dNcg0=W]
k03Nm?@0moC^0>?/n03Ui>D0k_og06icQ03:e=h0mng^0?oom`80moOd00<0ooog0?Ogk03oooL00P3o
ool20??dm00]0?ooo`3gooL0moog0??dk@3cm>P0lngU0?O]kP3/iNL0g]WC0=71`@3^iNL0f]gM09VG
W02e^kh0k?Oc0>cgo`3JiN`0dMG@0=S</P3I]Yl0k;J[0;c3]P2/^;H0Z[Nj0;3:eP2Y^L@0UjB^08nZ
^P2J[[X0XZZb0:2^_`2ne=d0dMgO0>[If`3Sb</0iMW@0>G_gP3RgM/0hmCF0>k1`@3N`[X0g/Ji0>;E
b03ZgMl0mnc^0080moOh00@0oooc0?ogn03oool0ooOh103oool06P3gmn`0oooo0?OUl03ok_@0loC/
0?o]kP3ajnh0loK_0?ofj03[moP0moO_0?Ogn03gmo@0lood0?Ggn03okol0oooo0?7LkP3ei^h0j_Cd
0>[gl03/kN`0oooo0>kon03^ool0k_oh0P3^ool01@3[moL0moO/0>kok`3^kn`0ono/0080moOg00X0
ooo_0>kok`3^ond0mo?Q0?O[h@3[jmh0gn3R0>_Ti@3gkNh0oooo0`3omoP04@3eooP0mOOd0?ooo`3g
moP0loCd0?Ogn03cm?@0ooKh0?obo`3oooP0ooKo0?ofn03^ool0oooo0>Kfn03^m_P0i_Kh0080i_Kd
0`3om_l0203Soo00hoK`0>kfn03>g=H0jnKX0?Odm03ei^T0k?oo0P3gmoL20??dl`070?G^l03bh>P0
jmGK0??_j03oi^T0f9io0?odm00j0?ooo`00=@3oool05`3om?@0llRX0>Zj]P3ec=h0lM_d0>[D_`3c
m>d0b/g105aoR`38bmH0]Mc_0<_go`3Nlo@0hnkg0=K]k@3oool0j^kd0>[/n03Fi_@0jnCQ07bAXP31
b=40lnSY00@0moOd00@0moO/0?Ogm03oool0ooOh0P3cool0<@3omoP0mooo0?ogk`3oool0oooc0?oo
m`3cm?@0ooOh0?odm03/iNL0fLRn0>?A_03Ug=/0VZ2]0;6^_03>g>D0hoOo0:>[/`3IcKX0f>3N0>cg
kP2GU9D0fK:I0;bk_@2:RXT0OW]k0<SKg@2bfo<0[=C]0=kWkP3ck>d0f<K@0;G<cP3Sm?@0k>o_0>;^
m`3Icn40g/WK0=WKgP34b=40_Znn0;fR^@36[k@0fLZm0??Ug`3ok>h0lngX0?oom`3omoP00P3oool3
0?ogn00J0?ooo`3gmn`0oooo0?O_l03oi>h0loOc0?ogn03ai>H0loKd0?obk@3cm?@0oood0?Ogo`3/
moP0i?Oo0?o_o`3oooP0mNK^0?ooo`3ooo@0l_C^0>c]k@3^mnl0i_Kd0>kfn03gk_@60??Vj@80lnKK
00<0ln_^0??bm03gl^D00P3om^D02@3gk^40mnkU0>kfk`3[moL0mo?d0>?PhP3[fML0lnSS0?Odm004
0?ogn080oooo0P3gmoP0103oool0oooh0?ofn03^m_l20>kbn0040?ofn03Vm_P0k_Kh0>Kfn080joKd
00/0hoKo0?ofo`3om_l0hoo`0>?fl03^m_P0e]cF0=kVk@3Zm>d0j^c^0>[fn0020?ooo`090>_gm`3g
moL0lNKY0?Ogn03[b=H0mnoX0?O[kP3HWGl0ong^03X0oooo000>0?ooo`030?odm03omoP0oooo0080
ooOh8P3oool0603okND0mlR^0=jf[P3afo@0lNGh0>[1^P3[kN80e]W@03]PK@3;cmH0boCo0=K^n03e
iNl0fNo_0>kgn03oool0k>cd0?ooo`3/m_l0gmcK07bAXP3Hb</0fNS^0?Ogm080moOh00h0moO/0?Og
m03oool0loCd0?Ooo`3cool0loOh0?odm03oool0moO/0?ool`3gmoP0moOd0??dk@80moO_02P0ooOh
0<BYX03[g=L0k^GU0>GTgP2e/:l0Uhb907J@YP3emoL0V9ZJ0:ZSS@3B`[80Pge`0>;^f`2GQ7X0f/bn
06f0S@2?Ti@0oooo0;SKj02fcnT0jmgX0=7Ih`3Ra/40a<:f0??1/P3^a/40jm7C0?;LgP3Fk_00h^c]
0?oDeP3[cLl0g/SO0=;=`03ZiN40mn_^0?odk@3gmnl0ooOh103oool0803omoP0oooo0?ool`3gmoP0
mng^0?o[m03cm?L0ooCd0?7]kP3gm_P0moo]0?OWm03cm?@0moCh0>?gm03TkOl0oooh0>cMl03cl_l0
moKd0?G_l03ZkNh0f^CU0>kbn03giO00lnC`0?OVm03omoP0ooCd0?Gdm03akNd0mNgX0P3/kN401@3o
m>d0ong^0?oXj@3gkNh0lncd0080mo?h00T0mo?`0?Ofm03gl_@0k_Kh0>_cm03gk^d0oooh0?Ogn03c
kNh00P3gkNh01@3gm?@0moOh0??dm03gmoP0oooo0080mooo00P0oooh0>kbn03^m_l0oooo0>kfo`3V
m_l0k_Kh0>Kon080jood00X0ooKo0>?oo`3om_l0oooo0?ofo`3Vk^d0g]WR0>G/k@3bkND0moOh0P3g
m_P02P3oool0k_oo0>K^l03Rk_00loCd0??Kg03gj>P0mo;d0=RHNP3okNhj0?ooo`003P3oool00`3o
m?@0ooOh0?ooo`020?ogn200oooo01X0moOh0??dm03ceL/0jlVf0>;1^@3[e=h0g_?U0=Vf/P3[kMd0
moO`059`N`2?X;D0b=WQ0=kTk03gmoL0h_O^0>_gm03gooP0ooOh0>C[n03UgMl0jn3R05abT03RdM00
h_Ch0?ooo`80moOd03`0ooog0?ool`3gmoP0oooo0?Ogn03gk_l0moKh0??]kP3gmoP0moO/0?oom`3g
mnl0moOd0?Ogn03oool0moO_0?ooo`3I`<@0h]7B0?O]hP3^e<`0hnkQ0>k<_`3Rknh0VZZd0:g8d03@
fMH0R96;0::HS@39eMd0X9Z@0:o2d02T]^40MWUQ0?ooo`3:fm/0[LoO0=Wgk03[moL0jmC:0:^_Z@3e
lnd0j]g;0>?Da@3Ag=/0iNGW0<_Ui`3Afn80`]CW0<C1c03@b[d0k=gO0?O/kP3omnl0moO_0?ogn03o
ool0ooOh0?odm03omoP20?odm00Q0?ogk`3oooL0lng^0?o[kP3gool0mngX0?7]m03ol_@0loK_0?OW
m03cmnh0mooh0>cgo`3ZiO@0k=GW0?O/l`3om?<0mnc/0>cMgP3bknH0jnKU0?Ogm03gkNh0onG`0?oT
kP3omoP0oooo0?;Ul03ZgNL0mOOg0>cdk@3SiM/0lnSR0080mno`00D0moCd0?ogn03gkNh0mng^0?O_
l0020?ogn0050?O[l03ol_P0oooh0>kfm03^m_P00P3gmoP03`3gm?@0mng^0?O]kP3ckNh0moOh0?oo
o`3[m_P0joKd0>kfm03^ooP0k_Ko0>Kfo`3[k_L0mn_g0>kbn0030?ofn00F0>_om03Nl_P0oooo0?of
o`3^m_P0k_C/0<WDh`3bknD0k>g^0>cgn03omoP0lo;d0?Ofn03Rjnh0f>k`0=[gn03ggNL0jmGE0?O_
k`3ol_@0f99d0?odm3X0oooo000c0?ooo`0I0>;DgP2LS8H0[If90?;_g`3S[k@0g]cF0?o^k@3N_[T0
mNk`0?Ogk`2M/:P0NYJb0=7]kP3Sk_L0i^Kc0>;^i`3cm?00j_O^0=kdm03Ji>h0c]?N0>c]j01XPi`0
i>3Q0?ogn0030?Ogn080moOd00<0mnCd0?oUn03oool00P3gi?@20?Ogn0060?Ogk`3ooo<0oooo0?oo
l`3gmoP0ooog0P3cm?@09P3^iNP0hmGG0>;<a@3omo00ml_60=;Pi@2`Z[@0Y;350;Fna@21Vjh0NYb[
0;>j_@3ekND0aZZO0;ZRW02/^K<0OXa/0>cgn03Hh=H0`]7W0<OQi@3NhNd0j/S50;:fZ@3NfNH0iMG8
0=S6]03[in80bnk_0;o;eP3FbmL0lmWN0>CPf`3ck>40ooKh0?odm03cm>P0oooo103omoP30?ooo`0X
0?O]i@3gmo@0lng^0?o[kP3gmoL0moO]0?7Xm03gl_@0mooX0??dn03om>h0k?Oo0>cgn03gk^l0mnkg
0?ooo`3^ooP0c[_>0;:R_@2X//40`[;10=72aP3ci>H0mno`0?ooo`3giO00lm_Y0>kMg`3[fMh0glSA
0=oDc`3AfM/0dMCF0=72a@3Ib</0d]CF0<[Ae03Sh><0lnSY0??]kP80moOh00P0mo?`0?ofn03oooP0
i_;h0>kcm03UiND0loC^0??]kP80lnSY00d0lng^0?Ogl03ooo@0k_Ko0>kfm03^m_P0moOg0>_cm`3^
m_l0mnkg0>kfo`3gloL0ooKo0080oooo01H0i_Kh0>kbn03oool0k_;h0?Ogk`3Zknl0bLgD0?Ggk`3b
moP0j_Oh0?ogn03gk_00onk`0=k_l03Zm?@0mnG_0?oTk@3[j=`0looh0?Obn03HV7X0ong^>P3oool0
0380oooo01/0moOh05i<CP1bFTL0MhB=0=kVh@3>Uid0hncQ0?oom03V`kh0lNKY0?ooo`34dM00JXRS
0:WEeP3clol0h^_c0>?^m`3[m>h0h_Od0>_gn03OkNh0g^C`0<k6b01gUjL0i=_L0?O_l03cm?@0103g
moP00`3gi?@0onGh0?ooo`050?Ogn00/0?oom`3gmoP0moO/0?Ogm03gmoP0oooo0?oom`3cm>d0mnc^
0>cUi`3SeMH0mnkg0=[<a`3Zg=h0k=WN0=7LeP3Ie=L0/k[60;6i``3AdM<0dMcU0>GLe`3>bl00/<6i
0>?^n03NlnL0d]WN0=kfkP3^m_@0c[Zm0<G2]@39`Z/0h]C40>[Mg`3Rm?@0jn3S0>;Vk@3Zg>D0jm_F
0>[XkP3gk^D0mn__0?o/m03cm>P20?oom`80ooOh0P3oool20?ofl00L0?O]i@3gmo@0lng^0?o^l03g
k^l0moO]0?7Xm03cm_@0onc/0??dn03/kO@0mooh0?Ggn03cjoL0mncc0?O^m`3[mo@0_;360>C]j03?
^/P0];K40:>Y]03FdM<0gm7C0=o?d@3Se=<0i^S@0>;Ue`80g^CM00`0g^SY0=7DeP3Oe=H0gn3Q0=7K
g03Ae=H0f]7C0=W=d03NfM/0i^KX0>KVk@3Vjo@20>Kbn0060>kfm03^m_P0i^_g0?Ooo`3[jnl0k_Kd
103oooP02`3ooo@0oooo0>kfm03Vjnl0jnkg0?ogm`3gk_L0k_Ko0?Ogm`3[moL0oooo0080ooKo01H0
k_Kd0>kfn03^l_P0i_Kd0?Odl`3Nm?@0f<oA0?Ogn03ck?@0j^cd0?ogn03/k?@0h^cd0=7dk@3Rk_<0
onG_0?Ogj03gj?@0onoU0?OUk@3AUgX0onSY>P3oool00100oooo0P3omoP0103oool0ooOh0?ogn03o
ool20?ogn1T0oooo01X0ooOh0;FOX`0K0P@0b=7F04MFJ@3[k>40e[2b0>?Ib`3gond0hZjm0>cLgP3g
kNl0k>CV0621V@1lY;<0k^k_0=k]k@3[m>h0oooo0>Kdm03Smnh0e_Cd0>[Pi@3;e=/0L8bM0>CDePH0
moOh1@3oool30?Ogn0030?oom`3gmo@0moO_00<0oooc02T0oooo0??dk@3omoP0mnk`0>cUi`3ZiMh0
mOOh0>?Ec`3ZkND0hmWN0=kTi@3>b;l0^<SA0::W/P38c<D0e^SQ0<_IgP2C_M/0WL;F0;cEh@38gNL0
k_Kh0>Kfn02mb=40h_KY0=k^j@3Hm?@0loCd0>?oo`3/moP0i>Cd0>?<c@3Se=H0ooOh0?Ggm03gm>`0
mnK^0??dk@3oool0ooog0?odm0030?ooo`80ooK`00d0ooCd0?Ogk03gmoP0onc^0?Ofn03gm>P0lNSd
0??om03oi>`0loCh0>c]m03goo@0mOOo0080l^G`02H0lnKc0?Ogn02cbL`0f/cF0?O/m03ae=L0^;Ff
0>?/kP3/m?@0moog0>c]j03Rm?@0g^G]0>?/k03NinP0dMCF0=KLgP3ZmoP0j_C]0>cgk03emn`0hoOo
0=WWj033cM00bLS;0=kDc`3Tg=/0k>g_0?odm`3^k?<0i^Kc0>K[m`3ck?<0loOg0>k^m`3Vl_P0k_Kh
0?oon080mnk]00L0mnk_0?Ogm`3^k_L0moOg0?ooo`3gmoL0ooOg0080k_Ko0`3^ool05P3Vm_P0k_Ko
0>koo`3Vmnl0ooOg0=k]kP3>aM00lo?h0?ofo`3Zk_P0j_oo0>ccn03SloP0/=WQ0??Tn03omoP0joO^
0??]m`3gj?L0mnS/0=6AM03oj>Tj0?ooo`00403oool20?ogn0040?ooo`3omoP0ooOh0?ooo`80ooOh
5`3oool07P3gmoP0jnC^08mmO01;=SH0Ng=b0<;<h@0iGGL0iM780>k;e`3JZjT0gYjR0=ZY]@3gm_@0
moOg0?o_l01RPiD0HY6]0=oPk@3NkN80lood0=kdm03eoo00joOh0>?gn03Th>D0bmCK0726T@3Th>P0
ooOh0??dm080moOh1@3oool01`3gmoP0loOh0?Odm03oooL0moOd0?oom`3ooo<00`3oooL07@3oool0
oooc0?Ogm03cm>d0mno`0?O/kP3giNL0k>KO0?;dkP3SeML0j]cN0<k?f`3:g=l0dMC;092T]03IfMl0
Z[K;0;S5c@3:e=`0_mCK0<kKeP2ja]00c]7C0=KXh@2cbMh0f>C^0=7CeP3AfN40mnkg0080k?Oh00d0
a;K50=W=c03eiO00lNgh0?7]l03gm>`0mnKY0?Ogn03gmnl0ooog0?odm03oool0ooK`0080oo;Y02d0
ooK`0?odm03gmn`0moCd0?o[kP3gool0moC/0?7XkP3cm_@0onG/0??]m03omoP0i?Ch0?oon03ei^h0
mNKd0?O^k`3gk_L0h^CV0;k=e033^L`0iMGM0<BeZ@3ReL/0hlJ]0>^l[P3NZIL0dJZA0<jfV034g=l0
/Kg90;f^_@32]L@0]L7;0;6m_@2j`/@0hmgM0?ooo`3em>d0mnko0=WKi@2mcLl0a<K90<O9a03Ti>80
0P3TkNh01`3TkNd0hoO]0>?dm03ZkNP0mnoQ0>k/j03Vh>`00P3[k_L20>_fk`080?O/l`3gmoL0mooo
0??oo`3[k?<0oooo0>kfo`3^ool20>Kon0090>kfm03^m_l0i_oh0>k]k03/m?@0j^CV0;k1d03^k_@0
lo;h0080jnkd00/0lo;o0??cn02fb>40joo^0??okP3ckO@0loOX0>kQf`3[iMl0gYIf0?OIe00j0?oo
o`00;P3oool07`3gmoP0mno`0927S@1[DT40XjV^0>GPh@3Oi>d0;E^50=W8_@3gmnl0jn_]0>KVj03g
moL0jnCU0?ogm03eh>h0JH^G06jZ_P38g>D0j_O^0??gn03HkNh0lOoo0>kgn03[mo@0j^3R0<_Df`1`
QY40i>3X0?Ogn03gm>d00P3gmo@20?ogn0<0moOh00`0mnk`0>k/kP3gmoP0loC]0?oom`3gmo@0loCX
0?Ogk03oooL0oooc0?ooo`3oooL20?ooo`0L0??dk@3oool0mnk`0??Ti@3/iNL0mOCd0>G=d03NcLT0
l^SK0?Ggo`2a][H0/;K10;k2b@2n`/d0h]cN0<OMl02lfNh0iNcd0>?TkP3Vi_@0aMWV0>_gm03[h>P0
k_oh0??Vl`3oool0f]GW0<k5a080mNoh00X0onoh0?GXkP3ck>D0onc^0?ooo`3cm>d0ooO_0?ogn03o
ool0ooK`0P3ol^T0<03om_00ooCd0?Ogk03gi>H0ooKh0?ooo`3cm?<0lNSY0??bi@3gkO@0moC^0?og
n03Tm?P0oooh0?Ofn03biO@0mNK`0??[k`3gknl0joOd0=[IgP3NloP0c[J^0<Vj[`3[h>T0moK_0?Of
m`3>bld0T7MQ0=Vma@3Bi>h0g^7X0=KUk03NjoP0k_oh0>G_i@2lb/`0]L;40>GTh@3bk_l0f^GU0??g
k@3clol0b=CN0<[;c`3Rk?@0loOh0??dm080hnGd00X0fOCh0=7Un03NiO@0j^g^0?7Xj@3ZkNh0k>gh
0?odm03cool0moOg0P3cm?<0103gloL0ooKo0>koo`3^ool20>kfm00F0?ofo`3^m_P0k_?d0?o]k@3T
ool0hn3Y0<;8d@3gk?00j_;^0>coo`3gool0lo?d0>?TkP2]_MH0g_O^0?o_n03gkoL0loo_0>_Ld@3[
kNT0f9R50?O?`3X0oooo000>0?ooo`030?odm03omoP0oooo0080ooOh00<0oooo0?ogn03omoP00P3o
moP00`3oool0ooOh0?ogn00C0?ooo`0O0?Ogn02oZ:`0Fe1709ZHU@3/i^l0k^_]0>_bm00cEHX0e]C9
0>kMg`3^k^L0oooo0>_[k@3giND0ongd0>[Tl01mV:<0Sk_80=WMg`3Zh>D0j^k]0>_]h`3gmoL0k?Og
0>Ggo`3Ie=40a=_Y07N6T@3Tfn80mooo0??gk`020?oUk`030?o^o`3omoP0loCd0080moOh00X0jn3S
0?Ocm03giNL0mno`0??dm03oool0loCd0?ooo`3gmo@0ooog0P3gooP0?`3ooo<0ooog0?Ogn03gmnl0
oooo0?ogn03giNL0k=gO0>?If`3cin80j^KU0>cQg03[k>D0hn3S0?O]iP3AgMh0b<_>0=kDeP3?e=H0
cMWM0<[Ih@3;hN80dMgW0??Vl`3oool0lnKc0?Ggo`3FaMD0dMCB0?Ofk@3ai>h0mOCh0?Gdm03oiND0
lo?]0?o^n03omoP0loC]0?ogk`3omoP0oooo0?ofl03ol^T0ooK`0?ogn03gknL0ooO_0?O/kP3ol_@0
moKh0?Odl`3aj>T0lo;U0?Ogm`3gmoP0ooCd0>Cdm03oool0lo;o0>[LkP3ei_P0moKd0?O/l`020?Og
n00]0<SDgP3bkN`0_ZNJ0<Rk_@3[i=`0g^K]0:2KS03:[YT0]JZZ0:Ra[@2edN40]Mg/0;7MiP38k>T0
k>gR0=WId`3ek^L0_m7F0<Wgn03[k_00k^kh0>kgm03Jknl0_l_;0=7Lh@3Zh>40j^K]0=kVm03Nh>D0
g]CF0>;IeP3^i^40k^_]0?Ofn03Zm?P0j_oh0?Odm03^k_L0jo?g0>koo`3^m_l0i_Ko0>koo`3om_l0
k_Ko0080i_;d01H0oo;h0?obm03Vi^`0k?Cd0>?gn03NfMh0fMCK0?o^l03Zh>80h^g]0?Ocm03gjnh0
moOh09N_aP3Ri^D0mnoX0?Ofi`3^k>D0k]C=0>_TgP3SSh/0f/:d>P3oool000h0oooo00H0ooCd0?og
n03omoP0oooo0?ogn03oool40?ogn0030?ooo`3omoP0ooOh01<0oooo01d0]J2U05Q1>P1[MW@0hmgW
0?Ooo`3^jnd0moKh06Z5[01QPI@0f[:n0>kMg`3Vi]`0dL>m0=S=a@3Afl/0/kVf07^H[@3@iND0j^k^
0>cgm`3Uh>L0joCV0?Ogm`3/moL0k_Oh0=KDeP34fnT0OGUo0=kTl0020?ooo`<0lnko01@0loCd0?oo
o`3cm?@0loCd0>KKgP3/g=d0f<S;0=Jm`@3ZfM/0k^GX0??dm03oool0ooog0?Ogk`3goo@0ooog0??o
k@3gon`0ooog0?Ogk`80loC]06<0mnoW0?OTi`3Zk>P0h]cM0>[Lg03ZhN80i>S^0?;_kP3om?@0loC^
0=[Uk@3Ai>l0h_Co0>[_kP3Sk_P0h^Kd0=K;e@3Hcm40blK:0;k3a03:bL@0hnGF0?Ofm03ojnh0lNG`
0?odn03gkNd0lnGW0?O[l03ok?@0mno`0?Ogk`3oooL0ooCd0?ofl03oool0ooK`0?obj@3omoP0lngQ
0??^o`3clo@0oooo0?Obm03gmoL0lNGU0??^l03om^L0loC_0?odm03Tm?@0oooo0?Ofo`3gm_@0oooo
0?GVm03/eNL0k^G_0?ooo`3ck_L0a/cF0<kUh`3/`:L0ZXmd09R:N@2cZ9@0Zk2a0;FOU01RKh<0/<S1
0=kVj03FfMh0e^co0<O]k03Uk?P0jnCQ0>_KeP3NfLd0hmBi0?;5/P3HdlD0d]cF0>?/k@2Zcn80S/;K
0:C8f`2bcm`0_N3]0=WUkP3Ig>h0iOC]0>?Mg`3IdM/0h]CF0>_Kg03[h>`0mnkg0>Kbo`3^m_l00P3o
ool00`3^m_l0i_Kh0>Kfn0030>kfn00E0?Ocm`3[k_L0g^g^0>kUi`36g>D0d=WR0=kgm03Zmnd0i>C`
0=[8b@34cm40f^o]09ffaP3RfmH0lo;d0?O_k`3[^kd0on3U0>k/h@3ZTH/0fKfX03X0oooo000@0?oo
o`80ooOh6`3oool05`3SgO00MV5B08Z?S@3[inh0jng/0??dl`3Jh>P0f_Oo0>GUk`1XYkd0OIRM0=V`
^@3acm40a;[50=7Dh@3:^//0X[SB0:WIk@3am_@0h^ko0>_Pm03Vi>H0h_Oh0080mOoo00D0i_Cd0=KK
hP3>cMH0KGR50=[dn0020?Ooo`80oooo01<0ooOh0?Ogn03gmoP0ooog0?Ogk03^iMl0f/?70=kDe@3S
i>D0f/c>0>[Mg`3ok>h0mno`0?oom`3gmnl0oooc0?Ook03coo@0moOo0080ooCd0100moO]0?Oom03g
mnl0mnGW0?ocn03gm_P0loKd0?Odk03oooP0mOoh0?7gm03/ko00loO^0>_^i@3Vk>40jnOQ0P3Re=H0
103^knL0lo;o0?Ofo`3oool20?ofn00:0?Goo`3akO@0mOOh0?ogk`3ck^l0ooKh0?Ocm03ck?P0oooo
0?Ogk080ooOh0P3ol^T20?ofl00D0?ogn03gm>P0onGh0?Ocm03oool0oo;d0??gm`3akNd0moCd0?Ob
m03gmnP0lngh0?;gkP3emol0oooh0>cgn03ZiOP0oooo0?o_kP3/iOL20>_Tk@0G0?O/j03/i>D0fN3Q
0<k/m`3>kND0h]GG09NBT@3Ig>H0CUYd0;K8^@3Hi^P0a<;90>[Xh@3ImoL0mnoW0>kdk@3[fm40`LS5
0?Ggk`3Uk^D0a<g@0=7LgP3ZkND00P3/mnd01`3[knL0lngU0>_IgP3Ik?00b=GO0>?Ui`3Zk?000P3R
fM/00`3ci^P0mnkg0?oon0030>kfm080k_Kh01X0ooKo0?ofn03Vl_P0i_;h0?ofn03gloL0jnkg0=SX
j@3IfN40a=GX0>k^m03oooL0moC]0>[go`37fmh0k?Ko0<CIi@2M][l0h]CA0??oo`3[fmH0hkc50>cP
kP3^k>d0jX>50=VmXcX0oooo000/0?ooo`0O0?Ogn034[[X0KEXl0<_AeP3Zk_P0hnKW0>?dm03Jh>P0
oooo0=[go`2mdnL0A9nm066EZP2LY;@0Xkg@0:g9eP2YdMH0]OC]0=W/m03cl_@0lo?h0>_]o`3oonT0
j_Og0?Ogm`3bmoL0e^g]0<_Kj@3Nb<X0J8ZF0>?TkP020?Ooo`80onko01h0onGh0?Odm03gool0ooog
0?Ogk03oooL0jnCV0=71a@3JgML0hnGW0=[<cP3Ti>D0k>GW0?O_i`3gmn`0oooo0?oom`3omoP0oooo
0?ogn03oool0moOo0?Odn03omoP0loCX0?ogn03om?@0oncd0??Ui@3omoL20?Ggn0050?Ggo`3ekoP0
ooCd0?o[kP3gm_l00P3cm_P00`3gm_l0oooo0?ofn0020?obm0080?ofn03emoP0mNg`0?ogk`3gk^l0
mooo0?ocm03gk?P20?OTm0050?OTj03om?@0ooK`0?ooo`3om_000P3oool0=@3om>d0ooog0??dm03o
m?@0ooKh0?Ofn03gm?<0lNg^0?ogn03cm_@0mo?/0??]m03gonh0lOCo0?oom03/moP0l^7^0?;Qm03b
i_@0mNK`0>;Lk`3Zi?@0hmCF0>;dm03/ko00j^c^0<SEg`2]b]h0k>cE0;jRQ@1gNhL0_Lo60=k/k@38
`/40clgK0=[Wh@3^mnL0g^k^0=K6_P31cM00hn_R0<S2_02c/;`0jn7N0=[go`3Og=h0d/oA0=KPkP3F
h?@0^LcF0;cLi@3Ji>D0j^GX0080j^SS00@0moOd0>?dm03giND0mnkW0P3oooP00`3^m_@0k_Kh0?of
n0020>Kfn080oo;o01H0i_Kh0>kfo`3^k?<0f>SY0<C?g03Fh>h0moOh0??dk@3/mol0h_O]0=SKg03T
m_P0f^cd06fM[P3cfmH0looo0>KDb`3/`]40k>cd0>k/j03RTHD0f[2S>P3oool000h0oooo00<0ooCd
0?ogn03oool06`3oool0603cm?@0U7Qn06iQF@3Ih>h0k??d0>[go`3[ko00e]_Q0?ooo`3Jmol0fOCh
0>kMi`1m/]00Kifi0:2jaP34hNP0dNk^0>GUi@3Fg>l0g^S`0>?_l03^kOP0joO^0?;gm`80moOg00L0
dNg]0=KKhP2lb=L0R9RF0>CKj@3oool0mnko0080oooo0180mnko0??^o`3giOP0oooo0?Ogk`3gmo@0
moOh0?OIi@3@dL/0k^oW0>?Kg03ckNh0hmcN0>cLg`3giO00moO/0?ooo`3om?@20?ogn080oooo00@0
ooOh0?ooo`3gknL0moO_0P3oool02P3gi^h0lo?]0>cUi`3emo@0mNod0?G]m03om?@0oo?d0?o[kP3o
lo@60?ofn00?0?G_n03emol0lNg`0?ogk`3ck^l0oooo0?ocm03omoP0moCd0??cm03gi>P0ooCd0?of
l03oool0ooK`0080oooo0480ooC]0?Ogm03oool0mnO^0?oon03clo@0ooOg0?7_l03oko00looh0??V
j03omo@0moO`0>[gm03/moP0mNKd0?Ggo`3gooP0mnoh0?OXkP3gknh0k=7R0>;Li@3gk^d0jn3U0=KU
k`3/k>h0e]WK0;G3a@3Akn`0a<7<0;?Ig@3Zlo@0jn_O0=7UeP3TgND0jn_h0=[^n03Ab<H0f]CF0;Vk
`@36c=D0k^kh0>k/k@3Ag=l0j^GW0?Goo`3Uk>L0b=CE0<O3eP3UhNd0mooo0?G_l03ekNh0loOh0>;/
m03Zi>D0moOd0??/j03[jo@0mnkd0>kfn03^oo@0k_Kh0?ofn03om_l20>kon080k_Ko01@0ooCc0=7I
f`2d`MH0fMcN0??]h@3gmnl0iOCd0<OIg03Sg=h0i>_h0>koo`1RS9d0jnOQ0?obo`3[a[l0k=7K0>cf
n03ocm`0a9j<0?NeXcX0oooo000>0?ooo`030?odm03omoP0ooOh00D0ooOh5P3oool05`3gmoP0KEYR
08IhM03gool0k?Oo0?ogn03Zm?P0_MCL0=[^n03ol_@0mn_^0=W^m03Aoo@0dOOd08ZY^@3?kO<0lnKY
0=k/m03IiOl0lOoY0>?_l03Sm?@0f?Cd0080oooo00P0mOOg0=k]k@3Ffn80]l?A08>AUP3/i>h0ooOh
0?Ofn080onGh01<0loCd0?oUn03gk_l0loCd0?ool`3gmn`0loCd0?OUl03ZbM<0f^CO0?Ogn03[i>D0
mno`0>[dk@3Re=<0k]gF0?Ogk`3om?@0oooo00<0ooK`00`0onkX0?ogn03omoP0mnoW0?Ogk`3oool0
onkh0?ogn03Zk>d0mOog0?G_kP3ekO@20?ogn00E0?ooo`3omoP0oooo0?ofn03gm_l0mooh0?Ofm03g
ooP0mNG`0?G_n03aj?@0oood0?Ogm`3gk^l0oo?d0?ooo`3ok_P0mnO^0?Ogk03om?@0oooo0080ooK`
02l0oooo0?ogn03gknL0onG_0?oUn03ginh0oooh0??/k03oool0mOoo0?G_l03gko00k^_U0?Ogk@3o
m>h0k?Oo0?O_n03emoP0mNK^0?GQkP3gkoP0moOo0?Odn03cm?P0mNK^0>?MeP3gk_L0f^GU0=KPh@3[
iNL0a=gX0:c3eP2W^<h0Tjk506jZa023]/X0_<?:0>cIg03ak?P0loOh0=KPi@36dM00gn3M0>;gn03N
mo<0fNC]0;GEi`020>?cn00C0=7Mi`3Rk>d0k=c^0?;Vn03gmoP0j_Ch0>[]n03okO00k^G_0?Ooo`3c
k^l0loCg0>_gn03om_l0lnK/0?Ogk@3^l_l0oooo0?ofn0020>kfn00F0>kon03^k_L0k>o_0;cDg@31
`m40i_Oh0>kom`3Nm?P0jood0>cTh@3/iNL0e^Kh0?oon01WP940gnGU0??^m03[_KP0mNOY0>cUl03o
fN40a8ao0?O8[RP0oooo0P3omoP@0?ooo`003P3oool00`3om?@0ooOh0?ogn0050?ogn1H0oooo01D0
mno`05]<A`2YUY40joOd0>_gn03em?P0moOh0=;Dg03ojnd0moOg0>_oo`3^jo@0moCh0=Wdn02e][l0
k>k_0>k/m03Um?P0oooY0?Gol03gmol00P3IkoP02P3gmol0mOoo0?Ggm`3^m?@0_MCS0=S3a01XRid0
mnk`0?ogn03gm?@20?ogn080moOh0180loCd0?Ogn03gmo@0moOh0?ool`3cm>d0mmgW0>cEe`3FfM<0
jnGQ0>kEj03gm?@0mO?h0=k9e03Jc<D0lnKN0??do`3gjnT30?obj@0;0?ooo`3gmol0loOh0?ogi`3g
mnl0oooo0?o/m03/joP0l^k/0?Ggm03emol00P3omoP05@3om?@0ono`0?ooo`3gooP0moKW0?OTi@3g
fnD0ln3Q0>_Pf`3gi>D0mNC^0?Ggm03omoL0loO_0?O^n03gjo@0ooOh0?O/m03gmn`0ooCd0?ooo`04
0?ogn0070?Ogk03oiOP0mnko0?o/kP3gk^l0moOg0?ogm`020?Gdm00i0?O]kP3om_P0i^k_0??]i@3e
moP0lngd0>[_n03/kOl0k>oh0?O]m03om>h0oood0?ooo`3Zind0mnkg0>?MeP3gk^L0mno`0>kMg`3I
iNL0e]CF0=W_m03Oh>40fMCK0<OEg`3Fi>L0f]gO0?GTh@3=fNP0a=7N0;g2c`3Fg=l0c]gM0<7=f`2_
`MH0g^GU0>[cn03>dmh0j^GW0>_fn03gk_00j^Gd0>[]n03ZkoP0mngd0??]n03gm?@0jnKc0?O^m03g
lnD0i_o_0?Ogm`3cm?<0jo?g0>Kbn03oooP0k_Kh0080ooKo01H0i_Kh0?odl`3NkNh0_M7N0=k=c`3V
mo@0k>k_0?Ock@3emoL0k>k_0?GTi@3Nk?l0k_;h05EdQ@3[jnh0k]cF0?>k`@3ek_00k>3^0?OPf`3;
S7T0mlo0:03oool20?ogn100oooo000>0?ooo`030?odm03omoP0oooo0080ooOh6@3oool08@3RdM/0
Dd/n0<6e^P3^mo@0k^o`0?G^n03/m_P0bmWN0?o^k`3Sm?@0lng/0=[^k`3Zl_@0hnC]0>G@d03[jo@0
moOo0>[dj@3/mol0moOo0??do`3Zm?l0moOo0?;go`3bmoL0k?Og0>kgn02me><0`L?:08VHW03Zjo@0
moOh0?Ofn0020??^o`0E0??dm03omoP0moCd0?Ogm03gmnl0moOd0?oom`3gmnl0loC]0>kAgP3IdLP0
jng_0??Pm03ck?@0iNG`0>K/k@3Ablh0h/^m0?OTg03ciMH0oo?^0080ooK`00X0oooo0?Odn03cond0
hnoU0>;]i`3/i>h0k>cd0>c^n03ZiND0k>o`0`3cm>h04@3[h=d0i]WK0>KVj03IfMd0g]_N0=KEg@3;
fmH0dM_Q0=WUi@3Ukmh0lmcU0>c_l03eknl0moO_0?ooo`3gooP0onKd0080moO_03/0moOd0?Odn03o
moP0ooOh0?ogk`3oooL0moO/0?Ogn03omoP0on_^0?Ogm`3cm>`0mooh0?7Ui@3omoP0loCd0?Ooo`3[
m_P0jnCU0?OgkP3NmoP0i>go0>cgo`3/koP0mnoh0?ogm03oooP0oood0?O^k`3/ko00j^OX0??/i`3U
iMH0ooOd0>?Ti@2o`lH0`lS?0<W=f`3Uh>D0dL_G0<_IiP2eeNP0e^C^0<kUj03NiNL0X<WN0:g8e`2`
e>P0f]gW0?ooo`3/ko00f^7Q0?Ofn03ck^l0hoOh0>[Vn03/kol0onoo0?Ogn0020?Ogm0050??gn03c
k_L0lnK/0?Ocm03Vm_l00P3^m_l0103Vm_l0k_oo0>kfo`3^ooP20>kfn00F0>koo`3om?<0dMWK0<C9
eP3Fi>d0f^c]0>c^n03Ui>D0e]_U0=[De@3Oj>P0f^od0?7dn011HGl0oooh0??Id03/`M00k?Kh0>CK
j@3ccM40dHm]0?OIe3X0oooo000A0?ooo`P0ooOh4`3oool02@2XSjL0EEQ70>?DeP3gool0loCd0>[c
n03emoP0bn3Y0>Ggn0020=[Ul00F0<k]k@3Ij>P0lno]0??/j@3Si>P0loC`0=k]j@3[k?L0k^kc0?Og
l`3gmoL0g_Ch0>;gn03cm?<0i?Cc0=odm03Afn80a<gM08RAUP3Ti^d0moCd0?O^o`80lnko01`0loOh
0?Ogn03omoP0moOd0?Ogk`3gmoP0ooog0?ool`3oool0mnGW0>?3a`3RfML0j^CY0?OTl03>iNd0f>Sg
0=3Ij02`^k@0XjN^0:>HX@2LRi00W8bA0926R`2GQWl0Uhb50925R`2?Mgh0Pgn50P1lTId05`1XPi00
MhF@08>;W@2:TJP0T9NX09NG[P2MY;T0WK2e09NZ[`2h_<00d/gL0=KLk@3[m?@0loCd0>;Lk@3>e=H0
fL_>0>kUi`3/kNh0mOCg0?O_k`3gk_@0onkh0080moO_0P3gooP01`3oool0ooog0?Ogk`3gmnl0loC]
0?ogn03ok_000P3om_P02`3gloL0moO_0?7_l03om?@0loCd0?ofo`3gjnl0mnk_0?ogkP3/kO@0j_Co
0080j^Gh01l0mngd0?Odn03cm?P0moOo0?O^k@3gk^l0lnKX0?Ogo`3Sk^P0onk^0??dkP3[k>d0i^_g
0=KTk@34e=/0`/WC0<_?d@2]`//0Uk;90;C1eP3>fn40iOCd0;cTm02ldnD0oooo0?o^k`3^k>`0hnKh
0>CAhP3Rg=h0j^g^0080loCd00<0joOh0>_gk@3cm?<00P3cm?@20??dl`080?O^m`3om_l0k_;o0>kb
n03ol_P0k_Kh0>Kbn03oool20>kfo`0F0?ooo`3SiND0]LWC0;G9e03JkNP0i>CW0?Ofn03Nh>L0iNGR
0>K]k@3oool0hngc0=kWj01=IhD0hmgW0>[Ee@3Tc=L0oooo0>CKj@3[_;d0dI5V0?o]kSX0oooo000>
0?ooo`030?odm03omoP0oooo00X0ooOh4@3oool02@2@NI40OgML0>;TkP3oooP0hoC^0=oUi@3Bg>D0
hmgW0>k_k`020=;TkP0=0>_gn03oool0oooo0?odm03Vj>T0k^o`0?;go`3Ii>L0moKc0?Ofm`3gm_<0
bnSd0=kdm0020>[dm`070=Kdm03Afn80c]CR08VHXP3Rg=d0mnk`0?Ogn0030?ooo`030?o^o`3gi?@0
oooo0080moOh0P3oool02`3ooo<0moO/0?o^n03^dMh0j]CL0>;;e`2neMl0b^7/0?;]i@3cmoP0j^g^
0080j_Cd02@0moo_0>cdm03cm?@0fNCd0=7Tn03Rm>L0joOh0>kXj03gh>P0k^CW0?Ofn03gooP0lood
0>k[m03gjol0ooKh0??fm03[oo00j_Kd0>c/m03/moP0g^ch0>?/n03^i>d0jn3U0=kIf`3[i^P0mng^
0?7gm03giNl0mnc^0?ooo`3gmnl0oooo0?Ogk`3omoP20?Odk@0N0??gn03gmoP0mno`0?o^l03om_P0
oooo0?ofm03clnd0ooOg0?7oo`3omoP0lng^0?obo`3[mnd0moOg0?ogm03gm?l0j^od0?ooo`3emoP0
j_Oh0?GVn03cj?@0ooO`0>_[k03oool0mnk_0??Vj03gm_P0ln__1@3oooP03`3Vi_<0ooOh0?odm03H
hNh0mooo0?Ofn03gjnd0mo?d0??cm03gool0iNKX0=WLgP3Zi>H0moCd0?o_k`020?Ogm`0@0??dl`3g
mn`0i_o_0>koo`3^onl0ooo_0?ooo`3^m_l0moOg0?O[m`3^ooP0k_oo0>kfn03^l_@0ooKd0>kfo`80
k_oo01H0ooOg0=SQhP2gcm`0d]CK0>c/k@3/m_l0j^CU0?Ooo`3@fM/0joOh0>cdl`3Sool0Z/;?06n6
UP3Hg=`0j^3Q0>[Ph`3oool0i=_Y0>Jf[P3HTW@0ooCd>P3oool000h0oooo00<0ooCd0?ogn03oool0
0P3omoP60?ooo`80ooOh4@3oool01@2GQY40RGUX0=WKhP3Smo@0iOOo0080ooCc0P3Zm?<0603^moP0
joOh0>?gn03Vm?@0k_Oh0?ogn03NkNh0mOoo0??dj@3NkNT0moOg0?Ofm`3oooL0dNG_0>cgo`3FkO@0
g_Ch0=kdm03Fi?00^/G@09JT[P3NeMH0moKh0?odm080looo00D0moOh0?oUn03ck?P0moCd0?ogn002
0?Ogn00B0?ooo`3oooL0moOd0?Ogk`3gmn`0moO_0?OMi`3RbM<0dLgD0<kDeP3Ji]l0f^ko0=WPm03I
i_P0a>Cd0=S]m`3gm?@0f^C^0P3Hm?l06`3Ii^D0i^g_0??[o`3cm_P0oo;d0>;Tl03/iOP0mnko0?O^
n03oooP0looh0??gm03omnl0k>ko0?ocn03FfnD0dM?U0>k^k@3gmo00f>GU0>_Ti@3eko00mNg/0>_f
kP3gk?P0oooo0??dj0020?Ogk`0d0?ogn03gm>P0ooOh0?o^o`3gk_l0ooCd0?ofn03ol_@0ooKh0?of
m03gm_@0moOg0?7gm`3oool0mng^0?O[m03[koP0moCc0?Odm03/moP0mOO`0>[cm03Tk?P0mOOh0>cg
m03ZkO@0mooh0>_Tk`3ci^`0mnkg0?Ogl03^iND0k^k]0?Oom03oool0oooh0?O^m`3ci_<0lnk_0??g
n03gmol0g]cd0>?Vn03NiOP0h_Oo0>[cm03Hfn80bmWN0=KXj@3/ko00loOg0?Odl`80moOh00@0joOg
0>kfo`3^m_P0i_Kh0P3om_l20>kfo`030?ooo`3ck?<0loCc0080k_;d00@0ooKo0?oon03Vm_P0k_oo
0P3^m_l05P3Uin`0cmCF0;C2e`3>bmL0hnG_0?Odn03Uk>d0k^ko0=3Mg`3[iNP0k?Cc0>cfn029Y;T0
T:B^0=kQhP3bh>40h^3S0>koo`3Zh>T0gjZX0=RHNP3om?@G0?ooo`80ooOh00<0oooo0?ogn03omoP0
7P3oool000l0oooo0P3omoP40?ooo`80ooOh00<0oooo0?ogn03omoP00P3omoP20?ooo`80ooOh00<0
oooo0?ogn03omoP00`3oool20?ogn0@0oooo00L0UhJA07eiKP3Zfm`0iOOh0>_dm03gool0ooOg0080
k?Cc00`0joCd0>Gdm03eool0oooo0>kgn03Vm?@0h_Oh0?;gm`3NkND0g_C^0??dm`3ooo<20?Ofm`0:
0<_Xk@3oool0k_Oh0>k_l03Tk_@0a=CF08nFY`3>cM00moKh0?odm080looo00P0moOh0?ooo`3cm?@0
moCd0?o^o`3gk_l0moOh0?ooo`80ooog01P0oooc0?ooo`3gm>d0lngU0?OUl03/h>D0g/_C0;36``3R
k>h0g_?o0>;fn03Nknh0hn3R0?OVi@3gmoP0k_;`0?o[hP3Nfm/0cmCD0>cIeP3Ifn40g^S]0?Ofo`3o
ool20>CKm00B0>CPl03Sk_P0moO]0>cUi`3Ti_P0hncd0>__k`3cjnd0oooo0>[]kP37g=H0j^kV0?G]
k`3gmnl0loKd0?ocm03gmoP0loCX0P3oool0:@3oooL0moO_0?ogn03gk?P0lnch0?odm03om_P0oo;d
0?ooo`3om_P0mo;d0?oon03/kN`0mOOo0?odm03Si^T0jnoo0??gk03SmoP0h^CU0>KVk03Sg>D0gmGL
0=oDh@3[h>`0j]CW0>[WkP3okOP0moOh0?O^k@3^iMl0moOd0?Oon03oooP0looh0?Oom03ck^d0jnKX
0??Vi@3ci^P0k_K]0080g^cX01@0k_?X0>;Dg03Ne>40mnOX0??dm`3cm?@0moOg0??/l`3Vm_l0i_o_
0>kfk`3Vl_l0oooo0>kon03oool0k_oh0>kfn03^l_P0i_Ko0?ofo`80loCc00H0i_;d0>kfm03oool0
ooKo0>Kfo`3^l_P20>kgm00F0<kLi@3>fn80^/SK0=KKg03gooP0moC^0?ociP3Fi?<0g^C/0=WLf`3/
moL0oo?d0668X`2icML0j]cX0=W^k03Rh><0j_?d0>[PhP3IY:P0f99d0?ogn1L0oooo0P3omoP00`3o
ool0ooOh0?ogn00N0?ooo`003`3oool20?ogn080oooo103omoP00`3oool0ooOh0?ogn0020?ogn080
oooo0P3omoP00`3oool0ooOh0?ogn0030?ooo`80ooOh103oool01`2SS:80Kg=M0?GPg03Zmol0lnSX
0??dl`3omoL00P3oool00`3gool0k?Og0?Goo`020?Ogm`0C0?ooo`3aool0hnC/0<GLi@3[moP0j_Co
0?oom`3oool0moOc0=kdm03^m?@0k>CU0>CPh@3Jk>d0g]cM08nN[@3Be=L0j^c_0>cUl0020?Ogn007
0?ooo`3gm?@0oooo0?Ogn03gk_l0onGh0?ooo`040?oom`0G0?ooo`3omoP0ooO/0?Ogn03cm>d0mnGW
0;FbaP2g^k`0a<gA0;kEd@3>fMH0b]CF0;k?d@3ShMH0mNg]0=7dl`3AkO@0/mcQ0;ODf`39e=H0e]W?
0=7<d02l_M000P3IfM404P3;b</0`Kg90;k1eP3:c>40fM_Q0<kDeP3AcM00e]7C0=7EeP3=dM<0f]G=
0??Ih@3cfN80mnK^0?OTkP3okNh0onoW0?Ogk`80oooo0240ooog0??dk@3cool0moOh0?oUn03gm_P0
on_^0?ooo`3ol_@0ooKo0??fm03coo@0j^gX0?Ggo`3om?@0hnK^0>__n03gknP0j_Oh0>KIf`3Zi>H0
h]cN0=k[k@3Ijnh0g^3S0=kIf`3Ae=d0i=CW0>c_n03gmol0mnk]0??Vk03gk_@00P3gooP02@3cooP0
mood0?Oon03gooP0mood0??^k@3[mo@0k_Og0?O^k`020?oon00I0>kfn03^l^d0k_K]0?Ogm`3gloL0
oooo0>kbo`3oooP0oo;d0>kon03oool0k_od0?ofn03oooP0k_;h0>Kfn03om_l0moO/0>_gk03Vm_P0
oo;o0>Kfn03Vm_l0oooh0>kbo`020>k/k00F0=SXj@2d`=H0c/c>0>CPi@3SmoP0h_Oh0>;Th`3SiNl0
cmWN0>[dk@3emoL0aMCM05Z<Y03cm_P0g^ch0=W^l`3Rh><0j_?d0>;IhP3^_;T0b99k0=[<aSX0oooo
000C0?ooo`@0ooOh503oool01`3omoP0_JBj061VD@3[fmH0fNoh0>_dm03gmoL00P3omoL0203emoL0
l_oo0>Cdl`3Zm?<0hooo0?O_k`3^moP0mOoo0P3BfnP03`3eool0i?Cg0?ooo`3oool0moOc0>cgm`3N
kNh0i>3Q0>kgn03^mnl0mnCX08jW_@3:dM@0k?CX0>c[n0020?odm0030??oo`3gmoP0moOh0080moOh
0P3oool00`3oooL0oooc0?oom`030?ooo`0J0?oom`3ooo<0ooog0?Ogk`3giNL0h]GF0>;IaP3Re<H0
aM7<0=kIh`3cfn80aM7K0;g=e`3>b<l0hlg90>;Db`3AcM00d]CG0;W8d@3B_KT0jmC80<CDf`2ma]40
fLoA0=;2_`33_K@20<>m]@070<6k^@3;_KP0dLRo0=kEb`3ZdM00mnOU0?OPkP020?Ogn0050?ooo`3o
ooL0moO_0?ooo`3gmnl00P3gmn`09P3oiNl0onko0?ogn03oiOP0ooKh0?O[kP3oooP0oo;h0?ocn03g
k_00mooo0>[gm03am?L0mOoh0?OUl03^gO00k^gU0>[]kP3Ih>40j^3V0?Ogk@3cmo@0k_oo0=ogm`3F
k^l0c^GX0=7Mg`3Re>D0hnG`0?Ogn03ooo@0lnK/0?ooo`3goo@0oooh0?Oom03gmo00ooOh0P3oool0
103cm_P0moKd0?Oon03gooP20?ooo`0;0?oon03^m_P0k_;d0>kbm03^m_@0ooKh0?oom03ol_P0ooKo
0>kfm03^m_P00P3oool02`3om_l0ooKd0>kbn03oonL0moOh0?Ogm`3^m_@0k_Kh0?ofn03^ooP0k_;h
0080k^cc01L0^MWS0;Vea03Fk>d0f^C^0=W_n03Rm?P0j_O^0??/n03RiN<0hnGX0=7LgP2C_//0QZVi
0>cgj@3emol0lnKc0?ODe`3cm?<0hlSF0?GPg@37_Jd0Qg5/0?Ogn00i0?ooo`003`3oool20?ogn004
0?ooo`3omoP0ooOh0?ooo`80ooOh0`3oool20?ogn0l0oooo00T0ooOh0<^jc01_I4T0cKg90=[_kP3N
m?L0k?Og0?ooo`3gmoL00P3ZmoL05`3Zm?<0i?Cc0=[_k`3oool0k_Oh0?ooo`3Ah>`0i^Kd0>[gm`3T
m?<0k?Oc0>cgm`3ooo<0loCg0>?gn03=g=h0b=GG0>G^n03Nh>h0Ujk50=;Kg03SiMh0k>__0080ooOh
00@0moOh0?Ooo`3gmoP0moOh103oool20?oom`040?ooo`3omoP0ooOh0?ooo`80ooOh00<0oooo0?Og
k`3oiNl00P3Ih?l0603cfNL0j]CL0=kThP3NfMH0g]C40=SIbP3:fM/0b]cQ0>;DeP3[dLl0jnOM0<[d
kP34iMH0k]W90??IeP3Ni=`0f=cK0>_Ad@3[dLX0g]CF0>[Ud`3Ri=H0mn3U0?oVm080mooh00D0lnC^
0??dm03gmoP0ooog0?Ogk`020?ooo`030?Ogk`3gmo@0loCd0080lnch0200loCd0?Odm03om?@0mo;h
0?ofn03om_l0ooOh0?o[n03goo@0mooo0?G]m`3oooL0mOoh0??TkP3gk^l0hnKO0<kIf`3Ri>h0mn_h
0>_cm03cm?L0mnog0?O]m`3[h>`0dMGO0=WVi`3JeNL0h]_^0>[]n03^iNl0mnk_0?oom080mooo00D0
loCd0?Ogn03gm?@0moOh0??oo`030?Ooo`060?ofn03om_l0oooh0?ooo`3om_P0oo;d0`3om_P20?oo
n080k_Kh00d0oooo0>kfn03Vl_@0k_Ko0?ofo`3^m_P0moOg0?Ogk`3^l_P0ooKh0>Kfn03[loL0mnkg
0080e^3/00L0/<KD0<[=eP3Fh>P0i^g^0>[go`3Rm?P0iOC^0080k?O`00h0`loG0>cTi@2F^]00X[[;
0>;/j@3ci?L0g^G_0??Kg@3cm?<0iLcF0?OMi@2?`]h0CS<Y0>;LkQH0oooo0P3omoP@0?ooo`030?og
n03oool0oooo00h0oooo000?0?ooo`80ooOh00<0oooo0?ogn03omoP01P3oool20?ogn100oooo00h0
fM7R06eOBP34[kT0mOO`0<7Ui`3Sool0joCd0??]k03Tm?<0lOoo0>cgm`3Tm?<0f^o_0>kgn080oooo
00<0g^cc0?Ogn03JiNl00P3oool0303eooL0j_Co0>[go`3RmoP0g^g^0=KIf`3FiNd0h^GW09nmb`3I
i>40fN3R0>[/m080moKh00D0oo?d0?o^l03gool0ooOh0?Ogn0020?ogn0080?ooo`3ooo<0oooo0?oo
o`3omoP0oooo0?odm03oool20?ogn0030?odm03gkND0lnSL00<0lnSL00<0mmWL0?oLi@3JiO@00`3J
iO@05P3om?@0f^7R0=[=d`3ob=00ol760=[?eP3IhN40mmWL0?oLh@3JiNd0moCX0>?^g@3Jh>l0f^oo
0?Ogk`3cm>P0mnCX0?OTk@3oool0ooog0??dk@3gmn`20?ogn00Y0?ooo`3gmnl0moOh0??dk@3gm?@0
oo?d0?oUn03cko00mnk`0?oon03om_l0oooo0?ofn03oooP0moKh0?Oon03emol0mNgg0?Ggm`3/mo00
j]_R0>;=d`38^[d0a=W;0<kLgP3>fN<0e]cN0>k_k`3om?L0ooCc0>G^n02lb=H0X[K409bea02M[l00
UZW009JR^@2`/[T0h]WK0??Vj03^iNL00P3cm?@02@3cmoP0looo0?Ooo`3oool0oooh0?ofm03^ooP0
k_Kh0?ofm0020>kfn0050?ofo`3^m_@0k_;d0?ofm03^m_@00P3oool03@3[jnd0lnc/0?Ogm`3[k?P0
jnCh0>Kfo`3om_P0k_Kh0?ofo`3om_@0i_;o0>_gm`3om_l00P2ibmh01`2Z`M<0_/_F0=[Mg`3SmoP0
oooo0?7oo`3ooo000P3/mo003`3Ae>80mNCU09fjd02``M<0moOo0??Ti@3Jm?@0mn3R0?Ogm`3Rh><0
fNk_07^U_@1EAS@0Z9NL0?o_i`0E0?ooo`80ooOh403oool00`3omoP0oooo0?ooo`0>0?ooo`003`3o
ool20?ogn0<0oooo103omoP00`3oool0ooOh0?ogn00A0?ooo`0=0>_PkP1XHE00bZj]0>_[m03Bh><0
l_Og0>?gn03^moP0j_Og0?;gm`3oool0i?Og0?Odl`020?Goo`0B0>_gn03FkN`0i^Kd0>k^n03Fi>`0
k?Og0?;fo`3Rk_L0oooo0>Kdm03omoP0i>3Q0>Kom`3cfn80ZLSF0>GQf`3Bh=h0lNg_0P3cl_@01@3o
m_P0oo?d0??gn03gool0moCd0080ooOh0P3oooL0203oool0ooOh0?ogn03om?@0oooo0?ogn03om?@0
ooOh2@3oool20?ofl080oooo103om_000`3ol^T0oooo0?ooo`020?ooo`030>?_n03SkO@0ooOh0080
oooo0P3oooL04@3ooo<0moOd0?ooo`3gmoP0ooog0?ogn03oool0moC]0?oom`3gmo@0loC]0?Ogn03o
k?P0ooKh0?Ooo`3ojnh0oo;d0080oooo0P3om_P07P3om_l0loKd0?Oon03cmoP0moOg0?G]l`3emoL0
l_Od0=W:e03Re=h0c/W;0<kIf`3Ae=l0dMgN0>_dk@3cm?P0g^g/0?ogn03^m_l0e^3X0<_Ph@34hN40
`]WQ0:[0c@2X^<@0b]CG0=WCeP3^m^D0oood0?oon080moOh01`0oooo0?oom03oooP0k_Kh0?ooo`3^
ool0k_;o0?oon03^m_P0i_;o0>Kfo`3gmoL0jo?g0>_cm03Ii>D0hng]0>;dm03NkNd0hoO/0?odl`3[
lo@0k_oh0?oon03ol_P0k_od0?ofo`3oool0loCc0P2gcmL0602`b=<0dMCK0=kdm03oool0mOoo0?oo
o`3Zmol0hoOh0=WMiP3gooP0lnk`0<7=f`2]bMD0f=WN0=WTk@3^i>D0lm_L0??dl`3ce=L0e^3X08Re
b`1lLfh0RhnG0>?AeSP0oooo000?0?ooo`80ooOh0`3oool40?ogn0030?ooo`3omoP0ooOh0100oooo
0280ooOh0>_Wl01jKE`0]j^S0?Gon038fN<0f_Oh0?;gm`3gool0lOOg0??dl`3/moL0k?oo0?7gm`3a
ool0mOoo0>_gn03Um?@0e^3]0?ooo`3Fh>d0k?Og0>?^m`3^k_L0joOh0>kgn03omoP0j^KX0=kgm`3g
i>h0ZL7F0=SQg03UiO00f]cN0P3/k^l01@3glo@0moCd0?O_l03gmoP0moCd0080oooo0P3oooL0103o
ool0ooCd0?odm03om?@;0?ooo`<0ooK`00D0oooo0?ofl03oool0ooK`0?obj@020?ofl0040?ooo`3o
l^T0oo;Y0?ofl0<0oooo00<0ooOh0?odm03omoP00P3omo@20?oom`80moO_0P3oooL03P3omoP0moC]
0?Ogm03oool0moOh0?ogn03oool0ooOh0?ofn03gmnh0oooo0?ofn03oool0ooKh0P3ol_P0103cm_P0
mooh0??gn03gmol20?Oon00I0??om03Ri]h0j^7L0>_Ic`3FbL<0aL_80;W1a02i_LH0e^3Y0=7Mi`3N
kNl0f^Gh0>KVkP3^mo@0oo;h0>k[l03Fi>d0/lcF09Nga@23V;80W9na0;g5dP3Fh>D0iNGW0?Ogn002
0?oon080k^kd0P3^m_l0403oool0jn_g0??/l`3ck?<0mnO/0>_Tk@3gknl0cmGO0=SKh`3Nh>T0bMCK
0>;DeP3SgMl0hoOh0>_Vj03ol_P20>kfn0040>kbn03oool0k_oo0?Odl`80[K[501T0/<[C0<GIiP3e
ool0k_Oh0?7oo`3eool0i?Co0<_QkP3olo@0mncd0>K_k@32dMl0]<gC0;c=f`3/mo@0k^G]0>G;eP3^
dM<0mmCG0;g2bP2gg?00ZZBS09nMTP2eZJ`0hmg`03L0oooo000C0?ooo`80ooOh5P3oool03`3omoP0
mng^07IQH@2SUi40i^cd0=kTkP3IiO00i_Cd0>__k`3omoL0j_Og0>[dl`3Zool0mOOg0?Goo`030?oo
o`0@0=7Pk03gmoP0jncd0=k/l`3oool0lOoo0=Sdm03oool0k>cd0=W^m03Skn`0k>G`0:Rjd03NiN40
k^kh0>?Wj@80mNg]00D0j]gO0?O^l03gmoP0moOh0?Odm0030?ooo`060?ool`3oool0ooOh0?ogn03o
m?@0oooo0P3omoP20?ooo`@0ooK`00@0oooo0?ofl03om_00oo;Y0P3om_001P3ol^T0ooK`0?ofl03o
m_00oooo0?obj@L0ooK`0P3oool20?ogn0050?odm03oool0oooo0?ogn03omo@00P3oool01P3oooL0
oooo0?Ogk03gm?@0onCd0??/n080lnko00<0mnko0?Ocm03om_P00P3om_P01@3oool0oo;h0?ofn03g
ooP0looh00<0mooh00<0lood0?Oon03/moP00P3emol05`3ei^L0k]7K0>?DgP3>bl/0_<W30<SDg`3S
iND0e^gL0=7Xh@3AgNL0i^_`0>kbn03oooP0k^_`0>kcn03Jk?@0/l7>0:f[]P2XZK80ZZnl0<_DeP3F
fn40i^CX0080k^C]00X0i^3/0>_Vl`3[i_<0jnkg0??oo`3RmoP0g^o`0>C/kP3=fn<0d=GG0P3SkNP0
303oool0e^GU0=WTe@3Ii>D0k_Og0?ofn03Vool0i_Kh0?ofn03^ool0joOg0?Ogm`80UK3001T0`LSA
0=k/m03oool0d>G_0>_^m`3oool0moOo0=KIh`3^k?P0jng`0?O]i@2bcnP0e]cK0;[2e@3Vc=/0jn3/
0?Ogn03ck>l0k_?d0:fja03Im>`0a<S@0<k5]P2MXi`0h/oD03L0oooo000C0?ooo`80ooOh603oool0
301eHFP0W8Yo0>K/m03Vm?@0i>Kd0?ogn03Sko00k_Oh0?7oo`3gmoL0mooo0?Ggm`80k?Og0P3oool0
403Nk?<0jncd0?Ogn03Ii>l0j_Og0>kgn03eool0joOd0>?^o`3Ji>P0jnCU0>[^n032dM/0cMCN0>_^
k@3Ik?@20?ogk`070>CTi`3ok>h0mooo0?Ogn03oool0ooCd0?ogn0040?oom`030?ooo`3om?@0oooo
0080ooOh0P3oool50?ofl0050?ooo`3ol^T0oooo0?ofl03oool00`3om_00103oool0ooK`0?ooo`3o
ool50?ofl0030?ooo`3om_00oooo0080oooo00`0ooCd0?ooo`3oool0ooOh0?ogm03omnl0ooO/0?oo
m`3gmn`0ooO_0?ooo`3ck_l20?oUn0030?ofn03cm?@0moOh0080mooo0P3om_P01P3om_l0moKh0?Of
o`3om_l0mooh0?Oom0<0mooh01d0j_Od0>Cdm03bmoP0mOOo0?Ggm`3gkND0lncd0=[Ee`2nb/@0a<7@
0=SDi@3Ffnh0a=7N0;k8eP2mdM/0e^CU0>k[m03oool0ooKh0>kbn03JkO@0g^g_0;G3cP3:aM00bLoA
0<?6eP3AcM`0f>CU0=kWj@020>;Ph`0@0=KDe`3;cm40cLg@0=SDeP3Hh>40hngX0?ogk`3oool0ooO_
0=[Ui`3@gNP0h^GM0?OTn03^l_@0i_oo0?ooo`80k_oh00<0i_oo0??dl`3RmoP00P26[/D01@3>`L/0
mooo0=K]k@3bm_l0d>G_0080g_Cd0180mncY0??/n03[m>h0k^o_0<;Pm03?h>H0`M7M0>[/k@3[e=H0
fLG?0<[1bP35b=40ZLcM0?;dk034b=00e/ff08nGW03[e=@g0?ooo`004`3oool20?ogn1P0oooo00/0
RVed08Z<O`3^ooL0ooog0=[Ui`3/loP0k^g^0>_gn03bmoL0h_oo0?Goo`020?Ogm`0C0>cgm`3oool0
oooo0>cgm`3JiNl0k^kh0>_/m03[k?<0h_Oh0?ooo`3IiNh0g^3]0>cUi`3OiNd0j^GW0=oXh@2fcn<0
mOO/0=WTl0020?O]h@090>CVm03om?@0mooo0?Odm03omoP0ooCd0?ogn03ooo<0oooo0080ooog00<0
oooo0?odm03oool01P3oool20?ofl080oo;Y103om_020?ooo`030?ofl03oool0oo;Y00<0ooK`00D0
oooo0?obj@3om_00oo;Y0?ooo`030?ofl00=0?ooo`3om>d0ooog0?ooo`3oooL0ooOd0?ooo`3gknD0
moOh0?Ogm03omnl0mooo0?Ogn0020?ooo`030?o_l03cmoP0mooo0080mooo0P3om_P02@3om_l0moKd
0?Obm03gl_@0mooh0?oon03gm_P0loKd0?Oon0020?ofo`0Y0??om03oool0mOCg0?Ggn03om>d0mnG`
0>GTi`3>dm/0b/g;0=[If`3Zi>40k>gQ0>?LgP37e=h0c^GU0=KTk@3VjoP0k_Ko0>kgn03Vm?@0dNKW
0=7Li@3IfnT0e]WV0=7Kj@3Fdmh0h^OQ0<;Wi@2mh>D0d=cU0=SPkP3[m?P0oooo0?Ggn03bk?P0mnko
0>cgn03NiND0amgX0>;Vg`3omoL00P3^l_P01`3VooP0k_oh0>kon03gmoL0loCc0?ook`3NkOP00P2@
Y;T06@3Ae=/0f^o_0=[_k`3Zm?<0joOh0=K]m03FkND0h_Ch0>cgl03Zmnh0jno_0=o]l`3Aj?<0[<7E
0<CAhP31fNT0_]GM0<[EhP35h>P0fNcX0>[Xh@3Ae=/0_[JQ09^?U`3^iO00=`3oool001<0oooo0P3o
moPH0?ooo`0=091iQ02?QG@0k_Oh0>Kgk`3^mn`0e^_h0>_]l03cm>d0g_Og0>[dl`3ZmoL0mno_0>_g
n0020?Goo`80oooo00l0i?Cc0>KVm03cm?@0jn_g0>[dm`3FkO@0k>kh0>[Ui@3[moL0iNG]0?;Ui`3N
j=`0_=C^0>cdk03Vjo@00P3cj>801@3Zk>l0mnc^0??^o`3oi?@0oooo00@0ooog0`3oool0103om?@0
oooo0?ooo`3oool20?ogn0050?ooo`3om_00oooo0?ofl03ol^T00P3om_000`3oool0ooK`0?ofl003
0?ooo`050?obj@3om_00ooK`0?ofl03oool0103om_004@3oool0ooK`0?ofl03om_00oooo0?odk@3o
ooL0ooOh0?ogk`3omo@0ooO_0?Ogm03gmoP0oooc0?OTj03ck?P0moOh0080loCd00<0mng^0?Ogn03o
ool00P3oool0203ol_@0ooKh0?ofn03ol_@0ooKd0?Oon03gl_P0oo;o0P3oool0603om_l0moKh0?Of
m03cooP0oooo0?ogm`3emol0lOOg0?Gon03gko00mnkh0>k^k`3>iM/0b]WK0<oIiP3Ni>L0d=gU0=oI
gP3Ag>D0g^GU0=KXj03Fknl0i_oo0>kdm080k?Og0P3gmoP06@3^k_P0g^3d0?;/l03UooP0k^kh0>kg
o`3Vk?P0iOoh0=[go`3bk_L0hnC]0=[Ui`3IiNL0k>GU0>_gm03oool0k_Ko0?ofm03oooP0k_oh0?Og
k`3^ool0moOg0??dm03Ni_P00P2?Y;X06035e=d0e^g/0?Ogm`3ZmoL0mOoo0?Ogo`3gmo00oooo0?;g
o`3Zmo00l_Cc0=[fn03Ul_@0c]?W0>[Tj03Rh>40h^O]0=W/kP3^m_P0k^_^0>_]h@3>aL@0PWU_0;FX
[3P0oooo000]0?ooo`0P0:><XP28Le00i_Od0>Kgk03oool0e^c]0>?/n03cknd0fNg/0>[gm`3RmoP0
hoOh0>kgn03SmoP0mOoo0?ooo`3^moP0fNo_0>?Tk`3oool0k^kh0=W/k03JkoP0oooo0>[VkP3[m>`0
iNG`0?OUl03Aj>40dM_^0>[_j03>i?P20??Xh`070?7gm`3ciNL0loo`0?O/n03gmoP0ooOd0?ogn003
0?oom`@0ooOh0P3oool20?odm0060?ooo`3ol^T0oo;Y0?ofl03oool0ooK`1`3oool20?ofl080oooo
0P3om_000`3oool0ooK`0?ofl0020?ofl0<0oooo103omoP0203oool0ooog0?oom`3gmoP0moO_0?OT
k@3gi?@0moOh0P3omoP00`3cm?@0moOh0?ooo`020?Ooo`030?ofn03ol_@0oooh0080ooKd00@0oooo
0?obo`3ol_l0oooo0P3om_l00`3gm_P0oooh0?Ooo`030?ogm`0H0?G_l`3emoL0ooOh0?O]kP3gi?00
ooKo0>k^k`3JkND0i=cN0<oLiP3Ah>D0dM?K0=oDeP3Og=/0f^KO0>c]k@3^ool0k_Oh0>cgm`3/mo<0
j_C_0>;]k@3cm>d0hnC^0P3Oh>h0303[k?@0jnkd0>k^n03Amol0i?Od0=[^n03JgMl0mNGU0?O_k`3V
ooP0k_oh0>kom080i_oo00H0oooo0??dl`3cm?<0jng/0>?gn03Rm?@208ZT^@0H0<_Df`3ZmoL0k?Og
0?Goo`3aool0lOo`0?Gol03Smnh0joO^0?ooo`3Zm?<0k?Kh0<O/kP2egNP0^^Kd0<kco`3[hND0oooh
0?7cl03Sk>L0joC]07ETF@27OhD0lng^>03oool002`0oooo00l0mno`0:RGY028NF80k^oW0>kgn03o
ooL0joCd0>;If`3gmo@0k^g^0>__l03Nm?@0k_Oh0>Kdm03oool00P3^moP01P3oool0mOOh0<CDg@2e
aM00d]_Q0<[Tk@80ooOh00P0k>cd0>G/k@3^ooL0j]_Y0<WXk@3Nfn80j^oX0<kTo`80mnoV00@0j^g]
0?Ooo`3^i>D0ooOh0P3gm?@0103gm>d0ooog0?oom`3oooL30?ogn0030?ooo`3omoP0oooo0080ooCd
00@0oooo0?obj@3ol^T0ooK`0P3oool00`3om_00oooo0?ooo`020?ooo`80ooK`0P3oool20?ofl0<0
oooo0P3om_060?ooo`030?odm03oooL0oooc0080oooc00X0moO_0?oom`3gk_L0mnko0?Ogn03cm?@0
mooo0?ogn03gmoP0moCd0`3gool20?ooo`050?ofo`3ol_P0ooKh0?ofo`3ol_l00P3om_l20?obo`0^
0?ofo`3coo@0mooh0?Ogk`3omol0onog0?G]m`3amoL0lOOo0?Ggo`3giO00lnO^0?O[n03^m_P0k^k_
0?GVi@3Zj>80cMWS0;g?gP31_M@0_KG90:>ea02H^lP0/LSF0<CDh@3Nin`0hnog0>cgm`3/mol0k?Cc
0>_]k@3Vk?@0e^3^0=KPl03>dnD0e^3Q0=KIf`3NdM<0h^GU0>_gm`3VooP0oooo0>kom03oool0k_oh
0>koo`80moOg00@0loOg0?o]k@3NmoP0dMGO0P2?X[H0603Uk?@0hoOh0?Goo`3eool0k_Oh0>_gkP3^
mnh0moO`0=K]kP3/mol0moOg0>cgm`3/iNP0i>CV0<O[k@3Fk>`0e^gd0=kgm03clo@0j^k]0>_XhP1>
B3@0dLCG0>_TkSP0oooo000/0?ooo`0<0>;Ij@2XXY00WH^@0>kdk@3^ooL0ooog0?Odk@3He=00moO`
0?Ogo`3NkNT0f?Cd1@3^moP0403oool0ooOh0>GUj03[k?P0j_O^0>cgl03gk?00mn_^0??[kP3Nk>l0
k_og0>CKj@3;j?@0jn3Q0>?Vi`3IiNd20>?fn0050>[QhP3bm_P0moOg0?O/kP3gm?@00P3gmoP01P3o
ool0ooog0?oom`3oool0ooOh0?ooo`D0ooOh00D0oooo0?ofl03om_00oooo0?obj@020?ofl0040?oo
o`3om_00ooK`0?ooo`80ooK`0P3oool20?ofl080oooo103om_000`3oool0ooK`0?ofl0020?ooo`0<
0?odm03ooo<0ooO_0?ogk`3oool0moOd0?Ogn03oiO@0onGh0?Ogn03oool0moOh0P3cm?@00`3gm?@0
mooo0?ooo`020?ooo`030?ofn03ol_@0ooKh0080ooKh00<0oooo0?ofo`3ol_l00P3ol_l0=03gm_P0
oooo0?ooo`3omoP0moOg0?o_m`3ekOL0mOog0?ogo`3am?l0oooo0?ogn03giO00mo?h0>kbn03Vlo@0
i^c_0>kdl`3^m>`0fNoW0=k_l03/k>h0h]cN0=7Ph@3JiN40iN3K0=KIh`3IfnT0b]CR0<78eP3>cM/0
g^C^0>;]k@3Ig=d0h]cN0?7QhP3biND0moOg0>_gm`3gmoL0k_oh0?O_n03gknl0oooW0?oon03oool0
loCc0?ooo`3cmoP0k?Oh0>;dm02lcm`20;2faP0?0?ooo`3Vm?@0oooo0?Goo`3[moP0hoO^0=kdm03I
ko@0k?O`0>?_l03gmo00fNC/0>k^n03gmoL0fNo_0080k_Oh00P0k^g^0?ogn03Zjo@0hn7L07^3L`26
P6T0Uhf=0=[<aSL0oooo000U0?ooo`80ooOh00<0oooo0?ogn03omoP00P3oool03P3A`]@0V8m/0<Zk
`@3Ji>P0moOh0?Ogm03om?@0fNGW0>?Ui`3gmol0h^o^0?Goo`3^moP0i_Cd0P3oool01@3^moP0iNGX
0>GTiP3^moP0moOd0080mooh00X0mnk^0>[^kP3bm_@0g^c_0?Ogm03Rh>h0d>gd0=3Uk03RiO00j^7K
0P3Nl_P01@3cj>T0j^c/0?Ooo`3gk>h0moCd0080moOh0P3oooL00`3ooo<0oooo0?ogn0020?ogn003
0?odm03omoP0oooo0080oooo00L0ooOh0?ockP3ol^T0oooo0?obj@3om_00oooo0080ooK`00<0oooo
0?ofl03om_001P3oool20?ofl0050?ooo`3ol^T0ooK`0?ooo`3om_000P3oool01`3om>d0oooo0?og
m03omo@0moOd0?Ogk`3oooL00P3gmoP04@3gi?@0onGh0?ogn03ok>h0mnk`0?Ooo`3gmoP0oooo0?of
n03ol_@0oooo0?ofm03om_l0ooKh0?ofm03ol_l0ooKo0080oooo00@0ooKh0?Ofo`3gm_P0loKd0P3g
mol05P3oool0mOOo0?o_m`3am?L0oooo0?7do`3emol0ooCd0?Ogn03ck?@0mo?h0?obn03^m_@0k_;h
0?O^k`3[kND0j^g]0>C]kP3Zi>H0g^3Y0<_Pi@3Bh>420<_Kg00G0=;Ph@3Oi^P0g^3Q0=KIf`3Rk=h0
jnC/0>Kck`3^ooP0k_oo0??]m`3ckNl0k_oh0?O_o`3gknl0jno_0?O_o`3oonl0moOh0?Ogm`3Rm?@0
mOOh0>KUi`2_`MH00P34aM000`3oool0i_Cd0?ooo`020?Ogl00<0?7oo`3SmoP0fNgh0>;]l03/mo00
g^gY0>_/k03gmoP0iNcc0>kgn03Iknl0e^g]0P3gmo@01`3ck^h0h]cU0;k2c@2j/[80ShF=0:BGRP3o
moP0=P3oool002D0oooo0P3omoP00`3oool0ooOh0?ogn0020?ooo`0<0<BZ/P29RW80hmCE0>cUi`3c
m>P0lngU0>k_i@3cmnl0h^3L0>Cbo`3/k_P0k^o`103^moP01@3oool0hn3R0>?Kg@3^m?@0k_Oh0080
i_Cd00X0k_Oh0>c^n03/loP0e^_h0??]h@3[k?@0i=gX0=o]k03Hi_@0i>7R0P3Vjnd01`3ckNh0mNo_
0>[[k@3gmoP0mno`0?Ooo`3gmoP00P3oooL0103ooo<0oooo0?ogn03om?@30?ogn0<0oooo00<0oo?^
0?o^j03om_000`3om_040?ooo`80ooK`103oool20?ofl0<0oooo00<0oo;Y0?ofl03om_000`3oool0
1@3om>d0ooO_0?ogm03oooL0moO/0080moOh0P3oool01`3gk_L0lnc_0??^o`3cmnh0mnk`0?ooo`3g
moP00P3om_P03`3oool0oo;d0?ofo`3ol_P0ooKd0?ofn03ojoP0oo?h0?ofn03ol_P0oooh0?obn03o
ool0lnk]0?odl`020?ogm`060?odl`3emo<0mOog0?Ggo`3am?l0mOOo0P3omoP20?Ogn0@0ooKo00L0
k_oh0>_gk@3[m>P0fNoW0>;dm03ZkNh0i>SY0080i>gR0P3TkNh05@3biND0jngU0??]m03[i?P0oo;o
0>kon03oool0mnoo0?O_n03^ooP0mnoo0>__o`3gknl0joo/0?o_n03gknl0ong/0=kgn03cm?@0fN3Q
0;O8f`020<_KhP0B0?ooo`3Vm?@0oooo0?Ogl03/mo00oooo0?Goo`3gmo00g^g`0>cgl03Zm?00moOg
0?Ofl`3Uk?L0k?Og0?ooo`3Nm?@0moO`0P3gooP01P3/m>h0bMCF0??gn02XWJ<0O7=^0?ogn3H0oooo
000K0?ooo`80ooOh3`3oool0302XRY00Tib90>[DeP3^ooL0moOh0>_]i@3^m>d0joOd0>?Th@3/l_l0
j_oh0?O^l080ooOh01<0i^g^0>kgn03SmoP0i?Cc0>[gm`3VkNd0joOh0=odm03Vm?@0k_Oh0?ooo`3g
moP0mNkh0>?Ui`3[m>d0h]_Y0=[_k`3AgNL0d=gX0080e]WM00H0moO`0?O_l03Th>40ooOh0??_l03o
moP20?ooo`80ooog00@0oooo0?ogn03om?@0ooOh0P3om?@30?ooo`050?ofl03ol^T0ooK`0?ofl03o
ool00P3ol^T00`3om_00oooo0?ooo`060?ooo`80ooK`0P3oool20?ofl0030?ooo`3om_00ooK`0080
oooo00@0ooOh0?ooo`3gknD0moO_0P3oooL00`3gmnl0oooo0?Ogn0020??dk@040?O^o`3glo@0moOh
0?O^l0<0ooKh00@0oooh0?ofn03om_l0oooo0P3om_l20?ogn0060?obm03om_@0ooKo0?ooo`3ol_l0
loCX1@3omoL00`3em?<0mOOg0?Ggo`020?Ggo`080?Ggm03gmoP0lo?h0??cn03gloP0mno`0?OTl03o
l_l20?ofo`090?O^k`3ck>P0lncX0??/j03ci?@0lngg0??]k03ckND0joOd0080k_Kd00@0ooKh0>kf
o`3^ooP0oooo0P3^ool0303^ooP0lngd0??]m`3^kn`0ooo_0>K_m`3gkOL0moO]0>C^l03[i>D0d=cU
0;g=eP80e^3^00X0oooo0>Kdm03eool0lOoo0?Goo`3aool0j_Oo0>;dkP3booP0j_OY0P3gmol03P3o
ooL0moOg0?oom`3SknL0l_O`0>Kdm03^moP0e^g]0>_dm02nb</0loCd0;Fb/P1WHEh0mmgG=P3oool0
01/0oooo0P3omoP?0?ooo`03085]M02]Yi/0mnCQ0080k_oc01`0joC]0?Ogn03omnl0i>KX0>coo`3Z
m_P0moKh0?Odn03Zk?P0e^3Y0?ooo`3eool0j_Og0>?gm`3gkN`0iOCd0?Odm03omoP0k_Oh0>Kdm03U
moP0mNcd0>cfo`3^mnl0g]CK0?;oo`3Uj>P0c^Kd0P3>fN802`3^k^d0moOh0=kIf`3ok_00mno`0?Og
n03oool0ooog0?ooo`3ooo<0ooog00<0ooOh0P3oool01@3omoP0oooo0?ooo`3om_00oo;Y0080ooK`
00H0oooo0?ofl03om_00oooo0?obj@3om_080?ooo`80ooK`00<0ooK]0?ofi`3oool00P3om_030?oo
o`090?odm03gmn`0moOh0?Ogn03gmn`0ooog0?Ogk`3cm?@0mooo0080moOh00P0mooo0?Ocm03om_P0
oo;d0?ooo`3olo@0on_d0?ofo`80ooKh0P3oool06`3om_P0oo;d0?ofn03om_P0mo;d0?Obn03om_P0
loC/0?odl`3oool0ooOg0?Oon03gmo@0mOOg0?o_k`3oooP0mOOo0?Gdn03eooP0ooOh0?oTkP3ok?@0
lncd0??WkP3gmoP0mno`0?Ocn0020??TkP080?Ocn03om_l0oooh0?ooo`3^m_@0i_Kd0>kbn03om_@2
0>kfn0050>koo`3^m_P0k_Kh0>kon03ooo@00P3^ooP02`3gmo@0moOg0>k_m`3^koL0moOg0?O_k`3/
moP0hnc^0=WQh@34eNH0a=?K0080k>cd01/0oooo0>kgn03RmoP0mOoo0?7oo`3gmol0mOoo0=kdkP3o
ool0g_C^0?ooo`3gmoL0moOo0?Ogm`3Zm?l0l_O`0?Ogl03^moP0f^o_0>?^m`3Nk?<0bloA0?Ogn03J
g>D0EFUY0<JWY`3gmoP0=@3oool002@0oooo0P3omoP60?ooo`0907IKG02l_;@0lnGW0??dk@3[mnl0
moOh0>_dm03gknL0hnCQ0080k?Ko01H0j_;h0>k/m03Zk>h0f^G`0>kgn03Vm?@0iOCd0>?oo`3gmoL0
k^o`0>KXj@3VkNh0k_Oh0?ooo`3^m?@0e]cU0=[Ul03eooP0cMcQ0>cUl03cknl0bmWU0P3RkNh02`3F
h>D0moOd0>CQh@3gl_@0ooCd0??gn03omoP0oooc0?oom`3ooo<0ooog00H0ooOh00L0oooo0?ofl03o
ool0oo;Y0?ofl03oool0oo;Y0080ooK`00@0oo;Y0?ofl03oool0ooK`1`3oool20?ofl0030?ofk@3o
m^L0oooo0080ooK`0P3oool03`3omoP0ooO_0?oom`3oool0moOh0?O^m`3gi>P0moOd0?Ogn03giOP0
mnko0?Odm03gmoP0mn_d0?oon0020?ofn080ooOh00@0oo;h0?ofo`3om_P0oooo0P3om_P01P3oool0
mooo0?Ooo`3gooP0mooo0?Oon080moOg00T0mooo0?ogm`3gmo@0mooh0?Gdl`3omoP0mOOh0?Ggo`3e
ooP00P3omoP02`3om?@0oooo0?O_l03oool0lng^0?ogn03gmoP0moCd0??]kP3gmoP0oooo0080oo;h
00D0ooKo0?oon03ol_@0k_Kh0?ooo`020>kfn0050>kfo`3om_l0oooh0>kom03^ooP00`3^ool02@3o
ool0moOg0?Ogm`3cmoP0g_Cd0>?Mg`3Ag>D0aMCR0>Gck`020>c/m0060?ooo`3SmoP0hoOh0?7oo`3/
mol0mOoo0P3/mo004`3bonh0moOo0>?gn03gmo<0moOg0?oom`3RooL0joCd0>kgn03eool0fNC/0>_/
m034fnP0e]CF0??dm03cmnl0Ph=f09AhOP3gmoP0=@3oool002@0oooo103omoP40?ooo`0@0652>03?
g=H0gmWN0??]i@3^ool0joC]0>kdk@3gool0moC]0>C[k`3/m_l0l_Kd0?;[kP3JkNh0i^g^0?Goo`80
g_Cd00<0j_Og0?ooo`3oool00P3/moL20?ooo`080?ogm`3^knl0iNcd0?O^l03UkNP0hnkd0>;Ui`37
gNL20<kAgP090;k;g`3AfMd0h]7B0?Ocm03giNL0moCd0?O_l03omnl0ooog00@0oooo00<0ooOh0?od
m03omoP00P3oool20?ofl0<0oooo00@0ooK`0?obj@3ol^T0oooo0`3om_030?ooo`@0ooK`0P3oool0
1@3ol^T0oooo0?ofl03oool0ooK`0080oooo00h0ooC]0?ooo`3gmo@0moOh0?ooo`3oiOP0mnCd0?oo
o`3gmoP0lnko0??fn03omoP0oooo0?obo`<0ooKh0P3ol_@02@3oool0ooKh0?ofo`3om_l0oo;d0?oo
o`3oooP0mooh0?ooo`020?Ogn080moOg00<0ooOg0?Ogm`3oool00P3omoL0403ekN`0ooCh0?Ggo`3a
mol0mOoo0?Gon03emo@0mOoh0?ogn03oool0mno`0??dm03gko00ooOh0?Odm03gool20?ooo`0=0?of
o`3oool0ooKo0?obm03oooP0k_od0>kfm03om_P0k_;h0>kfm03om_@0oood0>kon0020?ooo`0;0>ko
o`3oool0i_oo0??dl`3SmoP0e^g^0=[Mg`3@g>D0dMgW0<CCgP3TjoP00P3/k_P06P3^moP0joOh0?Go
o`3eool0j_Co0??do`3RknT0l_O`0=[Ui`3>h>`0fNcd0?ool`3oooL0loCg0>cgm`3HmoP0iOCd0>[g
m`3Vi_@0jncd0;gAf`3/k^l0hmcK0>_gn02STI40RW=^=P3oool002H0oooo0P3omoP40?ooo`0@04Ta
8P3am?@0d/7;0=kTi@3[m>P0jngU0>kdm03[ool0loCd0>;Ti@3cl_@0moKh0?;bm03/ool0ooCd0>;]
k@80l_Og00<0loCc0>cgm`3^moP00P3BkNl02P3Vm?@0k_Oh0?ooo`3VkNh0k>cd0>c^n03[kN40moOd
0?OUl03Rh=`20=oLeP060=kIgP3Jko00a<K80?Gdm03ck>P0ooKo0P3gm?@20?oom`@0oooo103omoP2
0?ofl080oooo0`3om_000`3ol^T0oooo0?obj@090?ofl0030?oom`3om^d0oooo00<0ooK`0P3oool0
1@3omoP0ooOd0?ooo`3gmo@0moOh0080ooog00X0onGh0?O^o`3cm?@0ooCd0?ogn03gool0ooOh0?o[
m03om_P0ooKd0P3gmoL08`3oool0ooKh0?obm03oooP0oooo0?ofm03oool0ooKd0?Ofm03oool0ooOo
0?ogn03gmnl0mooo0?ooo`3gool0ooCc0?ooo`3omoL0lNg/0?Ggo`3emo@0mOCd0?7on03eooP0mOOd
0?Gon03oool0ooCd0?ogn03gm?@0mno`0?o_l03gmoP0mooo0080oooo00<0oooh0?ofn03oool00P3o
m_@0103ol_l0oooh0?ofn03ol_P20?ofm0030?oom03oooP0k_oo0080mnoo00X0oooo0>Koo`3gm?<0
g^g^0>;Ul03bk^`0`nSd0>[Kg03;i_@0ooOh0P3^m?@0203SmoP0j_Og0>[dm`3cm?l0hoOh0=S]kP3g
mol0dMgW0P3^k_L04@3clol0moKg0??cl`3/mol0l_Oo0?oom`3eool0k?Og0??bo`3RjoL0e]WK0?o/
kP3/k?@0e^3L0;2MX`1lLVh0ooOh03D0oooo000/0?ooo`0;03/M5`3bk?@0d/7;0>_Ti@3^mn`0oooo
0>_dk@3oooL0loC]0?;dm03blo@00`3gm_P01`3om?@0jng]0?Ogm`3gmoL0g_Og0>Cgm`3^knl00P3O
m?P20>kgn0080>Kdm03omoP0f^C^0>c^n03Vm>P0ooog0?OUl03ek^D20=7IhP0:0=3Li`3[i=h0a<G<
0>[]j03ck>40ooKo0?odm03cm?@0oooo0?ool`@0oooo00@0ooOh0?odm03oool0ooOh103om_030?ob
j@030?ofl03oool0oo;Y0080oooo0`3om_030?ooo`050?ofl03ol^80ooog0?ooo`3om_00103oool2
0?ogn0<0ooog00D0oooo0?Ogk`3gk_l0mnko0??]kP020?Ogn0030?Ooo`3olo@0onk`0080ooKd0P3g
moL30?ooo`0:0?ofn03om_@0ooKo0?obm03oool0moKh0?Ooo`3cmoL0moC/0?ogm0<0moOg0P3omoL0
1`3om?<0mOOg0?Gdm03eool0mOOh0?Goo`3emoP00`3oool01P3om?@0ooOh0?O]kP3omoP0loOh0?Oo
o`80oooo00/0mooo0?Oon03oooP0ooKh0?obo`3om_P0oooo0?ofn03^ool0k_Ko0>kon0040>koo`80
mnoo00X0i_oo0?Ogm`3bi^L0h^o`0>GVk@3Jknl0amGO0=[Mi`3Ijo@0ooOh0P3FiND0703Zm?<0oooo
0?Ogm`3gmol0f>g^0>c^n033fn80k^kg0?Ofm`3[k?L0jncc0?oom`3clol0k?Og0>[dm`3cm?L0hnC/
0>KVm03gmoP0g^cc0>kUj03^k>h0k>cd0=KPg02g[jh0RGaf0>;Af`3gmoPd0?ooo`00:03oool20?og
n080oooo01006@000=[Lh@3Oi>h0mnoW0>_gm03^moP0joC]0?Ogm03^ooL0moOh0>?Th@3eooP0lo;d
0?Ofn03^kNh0k_Oh0P3oool01@3/moL0ooOg0>cgm`3om?<0ooOg00<0k_Oh00L0oooo0>kgn03/k?@0
e^cX0?OUk@3oooL0mOoo0080k?Og00D0f]WR0<SEgP2m^lX0j^gY0>[Pg0020?ogn0050??gn03gm?@0
moO_0?oom`3oool00P3oooL00`3omoP0ooCd0?ogn0020?ooo`030?ofl03oool0oooo00@0oooo00@0
ooK`0?ooo`3om_00ooK`1P3oool0103om_00oo;Y0?ooo`3om_060?ooo`040?odm03oool0ooog0?Og
n080moOd00<0ooog0?ooo`3cio000P3gk?P01P3gm_P0ooKh0?ofn03om_P0oooo0?ofn080oooo0P3o
m_P20?ooo`030?Ofn03gl_@0ooKh0080oooo00L0loOg0?Odk03omo@0moOg0?ogm`3okoL0ooCg0080
oooo00H0ooOh0?Ggn03omoP0mOoo0?Ggn03eool30?ooo`0D0?ogn03oool0mng^0?ooo`3cmoP0moOh
0?ooo`3gmoP0ooOh0?ooo`3gool0ooKd0?obn03om_P0oooo0?ofn03^m_l0k_oo0>Kon03Vool40>ko
o`0;0>_gm`3cm?<0ooOg0>;Xj@3Ik_P0l^k/0;gXm03cfm`0g_Ch0>[[l03Sko000P3Rm?@04@3cm?<0
oooo0?Ogm`3IkOP0j_O^0=k/l02ld>D0oooo0??bl`3cloL0moOo0?Ofo`3gm_L0k^kg0?Ogm`3gmo<0
gn3X0080k^kh00T0i?Cc0>kgn03oool0fN3Y0=kXh@2l`LD0X8mm0<:^_P3gmoP0=03oool00200oooo
0P3omoP00`3oool0ooOh0?ogn0020?ogn00E0?ooo`3omoP0ooOh0?ooo`3gko004`H50=kgm`3Voo<0
joOd0?ooo`3[m?@0joC]0>_gn03^ooL0loC]0??]i@3Tjnl0moKh0??bm03Ui>H0k_Oh0080oooo00l0
k_Oh0=K]k03/ool0k?Og0?Ooo`3gmoL0k_Oh0?ooo`3^moP0oooo0?ogn03Afm`0k^cd0?G/kP3/h>T0
0P3ok^L0303ok^d0d]CS0;Bja03UiND0hmgO0>cMg`3gmoP0oooo0?ogn03gmoP0oooc0?ooo`80ooog
00<0ooOh0?odm03omoP00P3oool30?ofl0@0oooo0`3om_070?ooo`@0ooK`1P3oool02@3omoP0ooCd
0?ogn03gmn`0moO_0?oom`3gi>P0onGh0??/n0020?Ofn0040?OgkP3ol_P0ooKd0?ooo`80oo;d0P3g
ool20?obm080oooo0P3gool01P3oool0moOg0?Ogm`3cool0mooh0?Ogk`80ooOg00T0ooCg0?Gon03e
m?@0ooOd0?Ggo`3am?@0oooo0?Goo`3omoP01@3oool01P3om?@0moOh0?ogn03cmoP0ooOh0?Ooo`80
loOh00L0mooo0?Oon03ol_l0ooKd0?ofo`3oooP0k_;d0080k_Kh00@0oooo0>kon03om_@0k_Kh0P3^
ool02`3cm?<0oooo0>;gn03SkNh0iNK]0>G_k`36eMl0iNG`0=[Tj03JiO00h_Oh00<0oooo00T0moOg
0=W]k`3Sko00hoOh0=7Mg`3cm?P0lo;c0?Ofm`3gm_<00P3gm_L20?ooo`0=0?Ofo`3oooL0k^kd0?oo
o`3[k?@0l_Og0=kdm03Vm?@0d]_S0>GXh@3:cmH0Uh]o0<B`]00e0?ooo`00803oool20?ogn0030?oo
o`3omoP0ooOh0080ooOh103oool01P3cj>T0?c<b0=kAb`3VkNh0k_Oh0??dk@80lnSL00T0moOh0?Og
k`3cm>d0loCd0>[/k03/m_l0lOOd0>[PhP3Vm?@00P3^moP0203Vm?@0e^g]0>Cgm`3/m?<0moOg0?oo
o`3gmoL0i_Cd0`3oool0103Ne=H0g_Od0?O^n03eool20?o^l00:0?oVj@3Oh>h0]/;50>KPi@3cm>h0
j^3Q0>k/kP3omoP0moOh0?ooo`80ooog0`3oool20?ogn0D0oooo00<0oo;Y0?ofl03om_000P3ol^T2
0?ofl0D0oooo0P3om_00103ol^T0ooK`0?obj@3oool30?ofl0@0oooo00/0mnoW0?Odj03oool0moOh
0?Ogk03oiO@0mnCd0??dm03cmoP0moOh0?ocm0020?obn0<0ooKh0P3gool20?obm0030?ooo`3oooP0
oooh0080moOg00H0moOd0?ogm03oooP0moOd0?ogk`3oooP20?G_l0050?Ggn03omoP0lOCh0?ogo`3a
m?@00P3oool00`3emoP0oooo0?ooo`020?ooo`050?Ogn03gool0ooOh0??dm03oool00`3gool00`3o
m_P0moKh0?oon0020?ofn00E0?ooo`3om_P0k_od0>kon03^m_P0oooo0>kfn03ooo@0k_Kh0?ooo`3g
moL0ooOg0??gn03Nko00h^G`0>[Ui@3BkOP0i=_R0=K^n03/i>D0i_Cd00<0mOoo00L0oooo0>?gn03/
mo00oooo0=7Ti@3[k?@0jn_d0080moKc0180oooo0?Ofm`3oool0oooo0>k^n03[joP0oooo0?Ofo`3g
moP0hnC/0?ooo`3Hm?@0k_Oh0=k/m03Ug=h0dLS?08=oKP3A_Kde0?ooo`00803oool20?ogn0030?oo
o`3omoP0ooOh00<0oooo0P3omoP04P3oool0lnSY05A8?P3Rg=l0k^SL0>kom`3ckND0lngQ0?Odj03c
m?@0oooo0?Ogn03cm?@0lOCc0?;fm03/k>P0i>3Q0>k_l080oooo00D0k_Oh0>Kdm03/m?<0i?Og0>cg
m`020>_dm0080>kgn03^m?@0ooCd0?odm03Ti^d0fNg]0>G/n03/mol20?;^l00<0?O^l03[mo@0/<7;
0>;Li@3[i>80lNSX0??[kP3gko00moCd0?ogn03oool0oooc0P3oool40?ogn0@0oooo00<0oo;Y0?of
l03om_000P3ol^T70?ooo`80ooK`00@0oo;Y0?ofl03ol^T0oooo0`3om_030?ooo`050?ogn03gm>P0
moO_0?oom`3gmn`00P3gmoP20??dm0060??gn03gool0oooo0?ofn03ol_@0ooKh0P3gool20?ooo`80
ooKh00<0oooo0?oon03oooP00P3cm>`03@3gooP0oooh0?Ogn03coo@0ooO_0?oon03eko00mNKW0?og
m`3em?P0mOOo0?Goo`3amoP00P3omo@02@3eool0oooo0?ogn03omoP0moOh0?ooo`3gool0ooCd0??g
n0020?Ogn080mooo0P3gm_P20?Ooo`80oooh01D0oo;h0?ofo`3^m_l0k_oh0>Koo`3Vm_P0ooKh0>ko
o`3gmoL0ooOg0?Ooo`3om?@0i?Cd0=kVk@3[kNd0fOOo0=WDf`3Fjnl0ooCd0>Kdm03eool00P3oool0
403Rko00f^CV0>k^n03JiNL0dNG_0?ooo`3gm_l0ooog0?Ofl`3oooL0lo;c0?Ofo`3^k_P0moKo0?Og
n03gm_l20?Ofm`090??dl`3eool0joOh0>kgn03gmoP0e]WN0<_2`@1lLU/0g/gK03D0oooo000P0?oo
o`80ooOh00@0oooo0?ogn03omoP0oooo103omoP03`3oool0fL[K04]5<`3[k_P0jngQ0>?go`3Zj>40
loC]0?ooo`3Voo<0loC]0?Ogn03gool0hno_0>c^k`020>[cm`080?O/kP3^moP0k_Oh0>kgn03oool0
d^g]0=7_k`3Tm?<30>kgn0070?Ggn03Nj>T0k^o`0>[cn03/g=h0k^kW0>G/n0020?;^l00:0>kgo`3V
joP0_/7F0>;]kP3Oe=H0lNg]0?O^k`3gk_00moOh0?Odm080ooog0P3oool00`3om?@0ooO_0?ogm002
0?ogn0<0oooo0P3om_000`3ol^T0ooK`0?ofl0090?ooo`80oo;Y0P3om_030?ooo`060?ogn03om?@0
ooCd0?ooo`3omn`0oooc0P3oooL0103oool0loCd0?Ooo`3gool20?ogn080ooKh0P3oool20?Ooo`03
0?ooo`3gmoL0moOg00<0moOg00h0loOg0?ogk`3oooP0moOg0??oo`3gm?L0moOc0?ooo`3om?<0ooOg
0?Ggm`3ekoL0ooOh0?7on080ooCd0P3aooP20?ooo`030?odm03omoP0moOh0080moCd00P0mooo0??o
o`3gmoP0moOh0?Ooo`3oool0mooh0?oon080mooo0P3oooP00`3om_P0ooKo0>kon0020?ooo`0?0?oo
n03VooP0k_oo0?Odl`3gmoP0ooCd0>c_l03SmoP0dM3K0=3/m03AiO00iMcK0>Cbo`3omoP0k^g^00<0
dN3Y00D0oooo0=;Kg@34fM/0fNc_0??bm`020??bl`060?Ofo`3ooo<0moKc0?Ofm`3oool0moOh0`3[
joP20?Ogl`090??dl`3aool0oooo0>Kdm03/k?@0fMWF08ZBR024Kfh0jnC^03D0oooo000S0?ooo`80
ooOh00@0oooo0?ogn03omoP0oooo0P3omoP03P3A_M40EDP^0>[]j03bknD0mOO]0>;dn03^ooL0moO_
0>Kol`3[mo@0moOh0>_dm03cmoP0j^g/0P3eooP02@3cjnh0ooOh0?ooo`3^moP0oooo0>Ggn03BkNd0
k?Og0?ooo`020>kgn0070>?gn03[moP0k^o`0>?dm03ak?P0jnOR0>[dm0020>[TkP0<0>k/m03Vk?P0
_/SL0>[dm03Oe=/0k>oX0?G]k03cl_@0ooOh0??_l03omnl0ooog0P3oool01P3omoP0ooOd0?oom`3o
moP0oooo0?ogn080oooo0P3om_00103ol^T0ooK`0?ofl03oool20?ofl0H0oooo0P3ol^T00`3om_00
oo;Y0?ofl0020?ooo`070?odm03oool0oooo0?ogn03oooL0moCd0?Ogm0020?oUn0070?Ogn03omoP0
oooo0?Ogn03ok_P0oooh0?ofn0020?Ogm`030?ooo`3gmoL0moOg0080loCc1@3gmoL03P3oool0loog
0?odm`3gmoL0oooo0?odl`3oool0ooCc0?Goo`3om?P0mOoo0?Gon03amoP0mOOh0P3eool00`3omoP0
ooCd0?ooo`020?Ogn0040?ogn03cm?@0looo0??oo`80oooo00@0oooh0??on03gooP0moKo0P3ol_@2
0?ofo`030?obm03^m_P0k_oo00<0i_oo00l0moOg0?Odl`3gmnl0moCh0>coo`3Sm?@0hnkh0<kDg03R
koP0jnGW0>kgn03Zk^d0j_;h0>cfo`3/loP00P3Ji>h02P3Sko00j_Cg0?Ogl`3gmo<0ooog0>cgo`3/
moL0oooo0?Ofm`3gm_l20?ooo`0?0?Ogn03[k?@0moKo0>?Tk`3oool0moOg0??dl`3aool0ooOg0>K]
k@3Ti_@0/kJ_06eSG@3>]/40moOh03D0oooo000M0?ooo`80ooOh00@0oooo0?ogn03omoP0oooo103o
moP05`3oool0ooOh0?ooo`3omoP0`ZNm06MC<`3NmoL0mo?]0>[^k@3Smol0moOd0>_gn03^ool0i_og
0>Kol`3cm>d0oooo0>[]k@3am?<0mOOg0?;bm03/moP0ooOh0080k_Oh00D0i_Cd0>kgn03Um?@0k?Og
0>Kdm0020>kgn0060>_gn03UmoP0d]cN0?Odk@3Jk_P0iOC/0P3Zi>h02`3Si>h0fNod0;gDg03emoP0
h]cU0>kUi`3ZiMh0ln_]0?ogn03gmoP0moCd0080ooog0P3oool20?ogn0030?odm03omoP0ooOh0080
oooo00<0ooK`0?ooo`3om_000`3om_020?ooo`040?ofl03oool0ooK`0?ofl080oooo0`3om_001@3o
l^T0ooK`0?ooo`3oool0ooOh0080ooCd0100ooOh0?ogm03gm>d0moO_0?OTk@3ck?P0loCd0?oUn03o
k?P0moOh0?Ofo`3gool0ooKd0?Ogm`3gooL0moCg0P3oool05@3gmoL0loCc0?Ogm`3cm?<0moOg0?Oo
o`3cmoL0ooOg0??dm`3gooL0oooo0?ogm`3oool0ooCc0?o_k`3em?@0ooOo0?ogn03amo@0lOoo0?Go
o`020?Gon0070?odm03oool0ooCd0?Odm03omoP0moCd0?Ogn0020?ooo`080?Ooo`3oool0oooh0?Oo
n03cm_l0mooh0?obn03ol_l20?oon00E0?obn03^m_@0k_Kh0>kfo`3oool0moOg0?ogm`3gmoP0j_Ch
0>C_n03Zm?@0jnGW0>[^m03Bj>P0j]_Y0?ool`3Vmo@0j^k]0>[fn03Tl_l0ooOh0080e^S^00<0j_Co
0?Ogo`3gmol00P3gmol05@3eool0k?Oc0?Ofm`3^k^l0moOh0?ooo`3/moP0mOoo0>_/m03[joP0lo?g
0?Ogm`3gm_l0iNcc0?Ogm`3FiNl0a]GL0=kLg`2FVi40RF][0?O_l00f0?ooo`007@3oool20?ogn004
0?ooo`3omoP0ooOh0?ooo`@0ooOh01L0oooo0?ogn03omoP0oooo0;RHZ01_KEL0moOd0=W/k@3Tk>l0
hoC_0?oom`3gmoP0joCd0?Odk@3[mn`0loC]0?Ooo`3^moP0moOh0?Ggm`3ok^l0l_?d0?Ogn0020>kg
n0050>Kdm03omoP0bn7Q0=K]k03^moP00P3Vm?@01P3gmoP0jng^0=KIf`3Uk^`0iNc]0<_]k`80onKY
0100d^gh0=[go`2mfn40joOh0>[dn03ci>D0i>3N0?O^k`3giNL0ooOh0??dm03oooL0oooo0?oom`3o
moP0oooo0`3omoP01@3oool0ooOh0?ogn03oool0oo;Y0080ooK`00<0oooo0?ofl03om_000P3om_00
0`3oool0ooK`0?ofl0020?ofl0050?ooo`3om_00oooo0?obj@3om_000P3oool20?ogn0060?ooo`3o
m?@0oooc0?oom`3gmoP0ooog0P3ck?P02`3oiOP0moO^0?obm03gm_P0moKo0?ofm03oool0moOo0?Od
m`3gool0oooo00<0moOg00P0oooo0??gl`3gm?L0moOg0??gm`3omoL0oooo0?ogn080ono_00P0ooCh
0?Ggm03oool0mOod0?7do`3em?P0mNkd0?o^n080mOOd00D0ooOh0?odm03oool0moOh0?ooo`030?Oo
o`80mooh0P3oool0703oooP0ooKh0?ofn03om_l0oo;h0?O^m`3gk_@0k_;o0>kon03ooo@0k_Ko0>ko
o`3cm?<0loOh0>cgn03oool0mOCd0=[^n03booL0g^kd0=KXj03cfn80k_O_0>?go`3Zl_P0k??h0>?/
n03[kO020=KUl00=0?oom`3gm_<0moKc0?Ogm`3oool0moOg0?Ofm`3Sk_P0mOoo0>k^k`3clo@0l_Oh
0>;/m0020?Ofm`0:0?Ofo`3oooL0lo?c0>_^m`3Zm?<0jncd0<;Af`3Ae=H0OhQk0:23SCL0oooo000Q
0?ooo`@0ooOh103oool0103omoP0k^Cd0<Ze]01RIe`20?Ogn0060>;Pg03Jk>d0k_og0>_dm03gool0
looo0P3cm>d20?Ooo`060??dm03emoL0oooo0?;Ti@3^mo@0mooh0P3Vm?@0303omoP0e^SX0=K]k@3^
moP0oooo0>k_l03gool0moOh0>c^k`3Fk_@0joO/0=kon080j^3Y00`0k_Ch0?ooo`35fn40j_Cd0>?o
n03[j>d0j^3D0?Ggn03ci^P0ooCd0??gn03omnl20?ooo`030?ogk`3omoP0oooo0080ooOh00D0oooo
0?ogn03omoP0oooo0?ofl0020?ooo`040?ofl03oool0oooo0?ooo`D0ooK`00`0oooo0?obj@3oool0
oooo0?obj@3oool0ooK`0?ogn03oool0ooOh0?ooo`3om?@20?oom`070?Ogk03gmoP0mnCd0??cm03o
kNh0lo?d0?Obm0030?ofn0040?ooo`3gool0moOg0?Ooo`80oooo0P3cm?<04P3gmoL0moog0?Oom`3g
moL0oooo0?Ogm`3omoP0ooOg0?ogm03eooP0mOOo0?7go`3amoP0mOoh0?ogm03oooP0mNG^0?o^n080
ooCd02P0ooOh0?O/m03cloP0mooo0?Oon03cooP0oooo0?Ooo`3oooP0ooKh0?ofo`3om_P0ooKo0?oo
n03om_P0oooh0?ofm03gmo@0moOg0>kfn03oooP0k_oh0>_cm`3cm?<0ooOg0?Odm03Tool0k?Oh0>?g
n03Zk_P0mOog0>;^k039dMD0iNG`0>kdk@3Zm_P0mnk`0?ooo`3[m?P0hno`0P3/mol01`3ooo<0moKg
0?Ofl`3clol0lo?c0?ooo`3cl_L00P3/moP0403gm_L0jnc]0>k^k`3UiN`0lo?o0?Ofm`3[joL0loCg
0?oom`3cm?<0moOg0>[dl`3NkNh0blg@07EhK@2hV:8g0?ooo`008@3oool60?ogn080oooo00@0ooOh
0>kUn03>a//0HUE60P3cm>d04P3Nh>40i>KX0>kom`3gm>d0looo0?ogn03gmo@0loC]0?ooo`3gmoP0
k^o`0>CWj03/k^l0l_?d0>k/m03gooP0k_Oh0?ooo`@0k_Oh00P0k^o`0?ogn03cm?@0l^cd0>[cn03N
h>P0moOd0?Ooo`80f>3^00d0moOh0>kgo`32h>P0mnk`0>[gn03^j>l0hn_R0?7]l03ck>D0onk`0?Og
n03gm?@0oooc0080ooog0P3oool0103om?@0ooOh0?odm03omoP30?ooo`80oo;Y1@3om_030?ooo`80
ooK`00@0oo;Y0?ofl03ol^T0oooo0P3om_020?ogn00>0?ooo`3omoP0ooOh0?oom`3ooo<0ooog0?Og
n03oko00moOh0?Ooo`3cool0moKh0?ofn03ol_@20?ooo`030?Ooo`3omoL0oooo0080oooo00/0moOg
0?Ooo`3omoL0moOg0?ogm`3gm?<0oooo0?Ogm`3omoP0ooCd0?o]k`020?7dn00I0?Ggo`3omoP0mOOh
0?G/m03eiO00mOOh0?Goo`3om?@0ooOh0?ooo`3gk?@0mo?h0?Ooo`3gm_P0oo;h0??fo`3cool0ooKh
0?ofm03ol_@0oo;h0?obm03oool0ooKo0?oon0020?ofn0050>kfn03^m_l0k_Ko0?ofo`3ck?<00P3g
moL03`3/m?@0k?Oh0?Ogn03gool0k>kh0?;^k03SiO00/=7R0>kgn03/iNL0k>cd0?Ogo`3[m?P0hno`
0?;go`020?Ogo`070?Ogk@3cm>d0moOo0?Ofm`3gm_<0oooo0??bm`020?Ofm`0@0?Ogn03gm_L0iNG_
0?Ofm`3^k_L0moKo0??cl`3cm?L0moOo0?oom`3gmoL0fNKW0>k]kP3;e=H0SXZ409anQ3L0oooo000P
0?ooo`80ooOh00<0oooo0?ogn03omoP00P3omoP30?ooo`0D0?O]kP3Ab=H0HTPd0?Ogn03[mo@0i>KX
0>C[k`3[m?@0j^gX0>k^l03giNP0loCd0>kom`3cmnl0joC]0?Ogk`3Ae=H0j^_]0?Ggm`3ci^T20>kg
n080i_Cd00<0mooo0?Ogn03omoP00P3omoP01P3gmoP0j_?h0>[cn03/i^P0g_Oc0?OTj080i>kh00`0
loKo0=kWm03>i>`0joKh0?7dm03^j>l0jo;U0>cXkP3/mo@0mnk_0?O^l03gkNh20?oom`80oooo00P0
ooog0?ogk`3omoP0ooOh0?o^j03om_00oooo0?ofl080oooo00<0oo;Y0?ooo`3oool00`3om_000`3o
l^T0ooK`0?ooo`020?ofl0030?obj@3om_00oooo00@0oooo00T0ooOh0?ooo`3omo@0oooo0?oom`3g
moP0ono`0?ooo`3gmoP00P3gm_P30?obm080ooKh0P3gool02P3cm?<0moOg0?Ogm`3cmo<0loCg0??g
m`3gmoL0loOg0?ogm`3gmoL20?Oom`050?ogm`3okNl0mOOh0?Ggn03emol00P3emoP0403ek?@0mNkh
0?ooo`3eool0oncd0?ofo`3omoP0ooCd0??gn03gm_P0mooh0?Obo`3oooP0moKd0?ofo`3om_P30?ob
n00K0?ofm03ol_@0ooKh0?ofo`3oooP0k_Kh0?ooo`3^ool0i_oo0?Ogm`3oool0mno_0>Cgn03gm?@0
k_Oh0?Ogn03Fi_@0hoO/0<gWm03Bi?00mngQ0>C[n03om?@0moOo0>GdkP3oool0mOoo0080moO`01T0
k?Oo0?Gol03cm?l0moOo0??dl03gmnL0moKc0?ooo`3gm_L0jncd0>?Tk`3gmol0i^Kc0?Ofm`3oooL0
moKc0?ool`3gmo<0loCg0=[_k`3emoP0jnc^0=7Ph@2>RX/0W7io03L0oooo000P0?ooo`80ooOh103o
ool20?ogn080oooo00d0lnSY0=71b01KE4D0lnCN0>?TiP3Ti^P0i?;o0?Ggk@3bm?@0iNGX0>k^l03o
ool0moO_0080loO_00H0moC]0=KPhP3/k^l0mOOg0>[Ti@3VkNh20>kgn00<0>Kdm03gmoP0moOh0?od
m03oool0ooCd0?ooo`3/m_l0j_;h0?Ofn03Rm?L0iNG`0P3ZiNL03P3Olol0jncd0<kTk03cm_P0j_Cd
0>_]n03gjn40j^SY0?Ggm`3cmoL0mn_^0?Odm03omoP0oooc103oooL00`3oool0ooOh0?o^j0020?of
l0040?ooo`3om_00oo;Y0?ooo`80oo;Y1@3om_030?ooo`030?obj@3om_00oooo0080oooo00P0ooOh
0?odm03oool0oooo0?ogm03oooL0moO/0?O_l080lnko00<0mooo0?o/n03gmnh00P3oool30?ofn003
0?ooo`3gmnl0oooh0080moOg00<0ooCg0?Odm`3gool00P3cm?<09@3gmnl0oooh0?Oom`3gooL0ooOg
0?Gdo`3emo@0mOoh0?Gdm03em?P0ooOd0?Gdm03emoP0mOoo0?ooo`3ok?@0ooKo0?Ofo`3cl_l0ooKo
0?Obn03om_l0moKh0?Obm03ol_P0ooKh0?oon03om_l0oo;o0?ofn03oooP0ooKh0?ooo`3^m_l0k_Kh
0?oon03Vool00P3VooP03@3gmoL0ooOg0?Ogn03Tm?@0loOh0>?/k@3[h>40h^k/0?;]k@3@gNL0hmcK
0?O_i`3Tl_l00P3omoP00`3SmoP0k_Oh0?Goo`020?ool00J0?Gol03eool0h_Ch0=7]m03SmoP0moO`
0>[do`3Nk>d0g^KU0>k^m`3gmol0loCo0??cl`3oooL0oooo0?Ofm`3gmoL0k?Og0?7oo`3^moP0joOh
0=oPh`2le=`0Og1T0;FLW@3gmoPf0?ooo`008P3oool20?ogn080oooo0P3om?@20?ooo`0=0?O]kP3>
_L<0GV5B0>_dn03Oi>H0k>cX0?ogn03/iNL0ooO_0>_]kP3cmoP0mooo0?ooo`020?Ooo`0<0??gn03^
moP0oooo0>kom`3Fi^d0k^g^0>kgn03oool0i_Cd0?odm03/ool0k?Oh0`3omoP01@3/m_l0lncU0=k]
k03Uknl0joO_0080i=_R00d0hng_0??/m`3;g>l0jn_]0>?cm03SiNP0k^GW0>;LgP3eknl0moOg0?O^
kP3ck_P0ooCd0080ooog00L0oooc0?ooo`3oooL0ooog0?ooo`3om?@0oooo0080ooK`00@0oooo0?ob
j@3om_00ooK`0P3ol^T20?ofl0030?ooo`3ol^T0ooK`0080ooK`00<0oo;Y0?ofl03oool00P3oool4
0?ogn00A0?Ogk`3gm>P0moO_0??gn03ok_l0mnko0?Ooo`3gm?@0oo?d0?ooo`3om_P0oooo0?Ogm`3c
m>`0lngX0?Odm`3gmoL00P3gknd00`3gm>P0ooC/0?ogm`020?oon080mood00l0oooo0?ogo`3omol0
mOOg0?ogk@3eool0ooCd0?7dn03amo@0ooCd0?Ggn03eool0oooo0?odm03oool00P3gm_l00`3cm_l0
looo0?ofn0020?obn080ooKh00L0oo;d0?oon03^l_P0k_oh0?obn03^l_P0k_oo0080k_Ko0180oooo
0>Koo`3[mo@0joC/0?O_k`3om>h0j^CS0>?LgP3Si^d0l^k/0>c_l03=j>h0fMgX0=k/m03[kND0oooo
0=k[o`3gmo@20?ooo`0=0=kdm03aoo00mOoo0?Goo`3SmoP0f?Cd0?Gol03Nm?@0oooo0>;gkP3ooo00
lOo`0?Gol0020?Ogo`0?0?ooo`3gmoL0e^O/0=KWm03cm?l0ooog0=kTk03Ah>`0jnkg0>;gn02e^/H0
HVAK08MUF`3Ic=H0moOh03H0oooo000P0?ooo`@0ooOh0P3oool20?ogn080oooo00/0mng^0=kDh@1R
FTD0k=gX0>_oo`3bkND0l^K^0?G/m03/k>P0k^o`0>kdm0020?Ogn00>0??oo`3gmoP0jng^0?Ogn03Z
k>d0f^kh0>G^k03Zi>D0goCd0?ooo`3Vm?@0ooOh0>[cm03Zm_P20>cgn080ooOh00@0h^CU0>;dm03g
m?@0k^cd0P3ZiO00503Ij>d0j^Cd0=KTn03gk^l0jo?d0>[[kP3ZkO00jn3M0>c_j03eknl0lo?]0?Oc
n03cko00moOh0?ooo`3oooL0oooc0?oom`3ooo<0oooo0P3omoP20?ooo`80ooK`00D0oo;Y0?ofl03o
m_00ooK`0?ooo`030?ofl0H0oooo00@0ooOh0?odm03om?@0ooO_0P3oooL01@3gmoP0moC]0?Ogn03g
moP0loOh0080moOh00@0mooo0??oo`3gl_@0oooo0P3gmoL0103ooo@0ooOh0?ogo`3oool20?ogm003
0?oom03oooP0moOg0080moC_00<0ooOo0?Oom`3oool00P3om?l01`3emol0ooOh0?Gon03emo@0ooOd
0?ooo`3eool00P3emoP0203oool0ooOh0?Ocn03cl_P0oooh0?obo`3oool0mooo0P3om_l02@3ol_l0
oo;h0>kon03^m_P0k_;h0>kfo`3oooP0k_Kh0>koo`020>kfo`0F0>koo`3gmoL0ooOg0?Ooo`3/m?@0
g_oh0>?/l03cjnd0i>kd0?;_i@3JgNP0h^k^0?;PhP3Zm>`0jngU0?G^n03Um_P0moOd0?ooo`3^moP0
oooo0>_dn080k?OY00P0iOC^0?Ogm03^kol0g_C^0=W]n03>i>P0g^KU0>_/m`80moOo00h0loCo0?Og
o`3gmol0d^3]0<[Kj03[k?<0k^kg0>_/m03Si>d0dNG_0?Goo`28TID0MfUM0>;AfcP0oooo000J0?oo
o`80ooOh00@0oooo0?ogn03omoP0oooo0P3omoP20?ooo`@0ooOh0P3oool05`3cj>T0g]CQ05a>@03^
m?@0joC]0?;gm03eiNL0lo?d0>CVj03^ooL0k_C]0?O/kP3[k>h0mooo0?Odm03[kNh0moOh0=kPh@3Z
k>`0oooo0?7Ti@3Ii>H0oooo0080k_Oh00X0j^K^0>cfo`3em_P0k?Oh0?odm03omoP0lo;d0=Sdm`3o
m>d0mncd0P3ZfnT03P37eNP0fOCh0=Kdl03/ko00jnc/0>koo`3Ri>h0jn3X0??gkP3ekNh0j^KX0?og
n03gmoP0moCd0P3oool00`3oooL0oooc0?oom`020?ooo`050?odm03oool0oooo0?ofl03ol^T00P3o
ool20?obj@030?ooo`3om_00oo;Y00L0oooo00<0ooCd0?ooo`3oool00P3oooL01P3ooo<0moOd0??d
k@3oiOP0moKh0??gn080moKh00L0mooo0??fn03gm_P0oooo0??dk03ooo@0oooo00<0oooh00D0moOg
0?Ogm03oooP0oooo0?Ogm`020?O]m`0H0?Ogm`3oool0oooo0?ogo`3oool0lOCh0?7gn03eooP0ooOh
0?ogm03eooP0lOoh0?Ggn03amoP0mOoo0?o^n03gmoP0loKh0?Obn03gool0ooKo0?Ofo`3oool0ooKo
0P3om_P20>kon0<0oooh00<0k_Kh0>koo`3[moL00P3[loL0303oool0moOg0?ogn03Zko00mnc^0?OT
i@3Si^d0f]gW0>?MgP3SooP0k?Og0?OUi`80k_Oh00@0j^_h0?Ooo`3omoP0k_Oh0P3^mnh01`3Rm>h0
l_o^0?;okP3gonh0jngY0>K]n03FkNh00P3gm_L02@3^k_L0jncg0?Ofm`3Vi_<0gn3/0>KVk03cl_<0
lo?d0?ooo`020>_[m0070>k^m`38gNL0mOoo0?ogn01IJ6`0U7Eg0?O_l00h0?ooo`006P3oool20?og
n0030?ooo`3omoP0ooOh0080oooo0P3omoP00`3oool0ooOh0?ogn0040?ogn00?0?O_l03Fa]<0HUY5
0>GUl03[kND0mOC/0?7dl`3bm_@0f^c]0?Ogn03cmnl0jnKY0=oPh`3cm>d0mngU0080moOh00D0j^g]
0?Gon03omnl0mOOg0=;De`020?ooo`0;0>K]kP3/m_l0j^_`0?ooo`3cl_@0j_Kh0>coo`3gm_P0fNkd
0>_]h@3ck?@00P3giNd03P3HcMH0moOg0?OUiP3Ig>H0k>GW0>_cm03Zjnh0h]cW0>_^i@3okNh0i>3Q
0?ogn03gmoP0moCd0P3gmoP00`3ooo<0oooo0?ooo`020?ooo`80ooOh0P3oool00`3om_00oooo0?oo
o`020?ofl0030?ooo`3ol^T0ooK`00D0oooo00@0ooOh0?odm03omoP0oooo0P3oooL02`3gmnl0moOd
0?Ogn03cmoP0onch0??/n03gm?@0moKh0?O^l03gmoP0mo;d0080oooo00d0loC/0?Ogk@3gmo@0oooh
0?Ogm03gmoL0loOc0??gk03oooP0oooo0?Ogm`3gko@0ooOh00@0oooo00`0ooOo0?Ggm03emo@0mOOh
0?ogm03omoP0lOoh0?oon03oool0lOoo0?Goo`3ok?@20?o^n0030?ofo`3gool0mooo00<0ooKo0`3o
ooP06`3ooo@0k_od0>kfn03om_l0k_Ko0>koo`3gmoL0mo?g0??/l`3cm?<0ooCc0>cdm03bm?@0joKh
0>?/k`3gool0g^3N0>[go`3oool0j^C]0?oom`3Nm?P0j^kd0>c/m03omoP0mooh0>_dkP020?Goo`0=
0?7oo`3SmoP0hoOh0=W_k`3Tm?<0k?OW0>Gdn03AiNl0lo;c0??cm`3[k?L0k^kg0?ooo`020?Ogn080
k?Oh00T0loCd0>KVk@3[jo@0e^3/0>_gn03^moP0e^3Y06UVHP2MQXD0>@3oool00240oooo103omoP3
0?ooo`80ooOh02<0oooo0=k=f`1QFSh0k>G`0=[Lh@3[mo<0mOC/0?Ofn03Jk>d0joOd0??dm03SiNP0
i^c^0?Ogk`3^kNP0ooOh0??dm03gmoP0l^gU0?7gm03emoL0e]WK0>__l03eool0i^g^0?Ofn03glo@0
j_;h0?Gon03alo@0j^_]0>[bn03oool0hnGW0=oIgP020??KhP0C0=S=eP3oknl0lnKY0>GUl03JgNP0
g^g/0??bm03Tj?@0jnKQ0?OdkP3Tfm`0oooo0?odm03cmoP0mooo0?Ogn03omo@0ooO/0?oom`030?oo
o`030?ogn03om?@0ooCd0080oncV00@0onkX0?ofl03om_00ooK`1`3oool0303om?@0oooo0?ooo`3o
ool0ooog0?ooo`3gmoP0moO/0?oom`3gm?@0ooCd0??gn080moOh0P3oool00`3gjnh0oooo0?Ogm`02
0?ooo`0@0?Ogm`3oooP0moOd0?Ogm`3goo@0moo]0?oom03oooP0moOg0?Ogm03oool0oooh0?ooo`3o
moP0ooCd0?odn0<0mOOd0P3oool20?Ggn0030?Goo`3oool0ooOh0080ooOh00<0mnk`0?Obm03cl_P0
0P3gm_l0203om_l0ooKh0?oon03om_l0oo;d0?ofn03^m^d0ooo_103^m_l05`3om_l0mncc0?Ogm`3o
moL0i?Cd0??dm03^ool0j^K]0>kUg`3JkoP0l_Oo0?OUi`3Jkn`0i_C]0=W^m03glo@0ooCd0?ogn03g
ooP0joOd0>?gn03oool0k?Oo0080loCg00`0moOg0?oom`3Zm?L0h_Oh0?Ogo`3IkOP0lo?g0>?^k`3Z
m?@0lo?h0?Ofo`3gmoP20?Goo`0:0?ooo`3[joP0moKo0>G/l`3eool0k^o`0<GLj01bIU`0X8^;0?Og
n3P0oooo000P0?ooo`80ooOh00@0oooo0?ogn03omoP0oooo0P3omoP30?ooo`0F0=k=f`1`Ie40i>3R
0>GTj03Smol0lOOd0>[bn03Fi^d0i_oc0>kom`3[m?@0mnkh0>GUl03cmoP0moOh0??gn03gmoP0l_Cd
0?Ggm`3am?<0k>cX0=3TkP80joOh00X0f^CV0?Gon03oool0l_Kd0?7dl`3emoL0mncX0>ccn03Tl_l0
gmcN0P3gk_@0403Sk?@0g^kh0>[^l03ek^d0fM_R0=k]k@3^k^l0g^3^0??/j03ck^h0i=CF0?ooo`3o
moP0moOh0?Odm03oool20?ogn0030?ool`3oool0oooo00<0oooo00@0ooOh0?odm03omoP0ooCd0`3o
ool01@3omoP0ooCd0?odm03om?@0ooOh0080oooo00<0ooC]0?oom`3oool01@3oooL02@3gmnl0ooOh
0?ogn03cmoP0ooOh0?Ooo`3gmoP0ooOh0?O[kP020?Ogm`80loCc00L0oooh0?ogn03omoP0oood0?oo
n03omoP0ooOd0080oooh00X0ooOd0?ogo`3omol0ooOd0?odo`3omo@0ooCh0?Gdn03emol0mOoh0P3o
ool0503omoP0mOOh0?Gon03emo@0mnkh0?Obo`3ol_P0moKh0?ooo`3om_@0ooKo0?Ofn03ol_P0ooKd
0?obn03om_@0oooh0?ofn03oond0k_o_0`3^m_l04`3Vm_l0jo?g0>_^m`3omoP0mNg^0>[]kP3[iNL0
j^3Q0=WLi@3Si>T0j_;^0>[PhP3/moL0i_Od0?ogk`3/m_l0k??h0>k]kP3VkNh00P3Vm?@00`3^moP0
mOoo0>cgo`020??dm`040??dl`3cm?L0oooo0?Ogo`80h_Ch00T0i^Kc0>cgn03Rk>d0mOog0=k/m03e
ool0oooo0?Ogn03cm?@00P3gm_l01`3Zm?<0hoOh0=[TkP3Fk>d0HTi20<BZZ`3gmoP0>03oool00200
oooo103omoP20?ooo`@0ooOh0140oooo0=k=f`21O700c/6i0=oTkP3em>`0mOoh0??bm03Ijo@0h_C_
0>_gm03gmoP0gn3^0>KVm03oool0mooo0>kgn0020?Ogn00@0>[]k03emoL0lOOd0>[[l03VkNh0mOoo
0>__l03Ji>h0ooOh0?Ggm03ZiND0ooO_0>[Ti@3cm_P0l^_d0>?dk`80iOCd0100k?oh0?O/m03bh>T0
mNk]0=WKhP3Ti>D0moKh0=KIhP3[inP0lnk^0>CDeP3oool0ooOh0?ooo`3ckNh0ono`0P3oool20?oo
m`060?ooo`3oooL0ooog0?ooo`3om?@0ooOh0P3oool0103om?@0ooOh0?ogn03omoP30?ooo`060?og
n03om>d0ooCX0?ogn03oooL0oooo0`3oooL02@3gmn`0moOd0?Ogn03gk?P0lnch0?O^o`3ok_l0ooOh
0?Ooo`020?Ofn00@0?Ogm`3gmo@0moO_0?Ogm`3ooo@0ooOd0?oom03om?P0ooOh0?ogm03omol0oooo
0?ogn03ooo@0ooOh0?ogm080oooh00@0ooOo0?ogn03om?P0mOOd103oool02`3eool0mOOd0?G^l03g
ool0mo;o0?Ofn03gm_@0loKd0??fo`3gl_P0mooh0080oo;h00@0ooKd0?obm03^m_P0k_Ko0`3^ool2
0>Koo`050?Ogm`3omoL0moOh0?G_l03SmoP00P3[k^l0203emoP0h^gd0=kUl03Si^L0mnCU0?ooo`3V
mo@0ooO_0P3/k_P01`3Vm?@0oooo0?ooo`3/moL0i?Cc0>[gm`3eool00P3^k_L00`3[k?L0loCo0?Og
o`030?Ogo`0A0??cl`3cl_L0oooo0>[cm03Tm?@0mOoo0>cgn03eool0loCd0?Ofm`3^k_<0j_Og0>K]
kP3Ti>L0i^oW03TJ5@3Re=h0>@3oool00280oooo00<0ooOh0?ooo`3omoP00`3oool20?ogn00?0?oo
o`3^iO00MFMR0=7>_@3Sh>h0jngU0?Gon03gm_P0k?Ko0>[Xh@3ZkNd0mOOg0>?TkP3oool0jncd00<0
moOh0140l_Cd0?Ogn03emoL0mOoh0>C/k`3AeML0i^g^0>kgn03[moP0d>G`0?ooo`3omoP0i>__0??c
m03Zg=d0mNc]0?7gm0020=K_k00A0?G/j03gi>h0k?Oo0>Cdm`3AgNL0dL_F0>?_l03Nk>d0hmgW0>?M
gP3Zg=h0mnk_0?odm03omoP0moCd0?Ocm03oiOP00P3oool01P3ooo<0ooog0?oom`3ooo<0ooog0?og
k`80ooOh00D0ooO_0?ool`3omnl0ooOh0?oom`020?ool`@0ooog00/0moOh0?Ogk03oooL0ooog0?oo
l`3oooL0moOh0?O^o`3ofo@0ooOh0??cm0020??fn00:0??oo`3cm_P0ooKh0?ooo`3gmoL0mno]0?og
m03oooP0ooOh0?odn0<0ooOh00<0ooOd0?ogo`3oool00P3om?P04P3omol0ooOh0?Gdo`3em?P0ooOh
0?oon03em?@0ooC^0?odm03omoP0oooo0?Goo`3oool0ooOh0?o/m03oloP0ooOh0?O^n080moKo00@0
oo;h0??bo`3goo@0ooKh0P3oool01P3om_l0k_Kd0>koo`3Vool0i_Ko0>_cm`80loCc0100ooOg0>?g
n03TiNP0h_?d0>koo`3gi^P0k?Oh0>;TkP3Ae><0a]7S0?OTh@3^ool0i_Cd0>kgn03/m_l0k>cd0P3^
moP01P3oool0mOoo0?;gm`3cm?<0ooog0?Ogo`80k^kg01L0h^cg0>Cdo`3Zm?l0loCo0?Ogo`3^k^l0
k^kh0?oom`3cl_<0moKo0??cn03/moP0moOh0?;gn03[k?@0moKc0=W]n03=kNh0aMgX0=K^m02SX9/0
EC/m0?Ogn00i0?ooo`00803oool20?ogn0040?ooo`3omoP0ooOh0?ooo`80ooOh01@0oooo0?ogn03o
moP0oooo06m?B`3=fM00j^C`0>?Uh@3Hm?l0h_Cg0?Ock@3NfmH0g^7Q0?Ggm`3Ukn`0jn3R0=WKh`3g
moP0jnc^0>?TiP80j^c/00l0mOOg0?ogk`3/kNP0i>OX0>;Wj@3eool0hoOh0>_gn03JiO00ooOh0>Cb
o`3Iin40k_oo0>[]k03aoo@00P3[mo@04`3Jg>40mncd0?ogn03ooo<0i?Cg0>_/k@3Idmh0fNCU0>c^
l03JfM/0f^CV0>[Ti@3ok_00ooOh0?Ogn03gi?@0mnko0?Ogn03oool00P3oooL00`3oool0ooog0?oo
o`020?oom`040?ool`3oooL0oooo0?ool`80ooog0P3gmoP40?oom`050?Ogk03gmoP0ooog0?oom`3o
ool00P3gmoP0103gi?@0mn_h0?Ocm03gmoP20??oo`80moKh00<0oooo0?Ogk`3gknd00P3oool00`3o
moP0ooCo0?ogo`020?ogo`040?odo`3ooo@0ooOh0?ogm080ono`00/0oood0?Gom03omoP0mOOh0?og
n03omol0lNgd0?Goo`3eko00mOCd0?Ggn0020?odm0<0ooOh0P3om?@01P3gool0looo0?ooo`3gm_P0
oood0?ofn080oooo00H0ooKo0>kfm03Vool0k_oo0>_cm`3^k_L20??oo`0E0?Ogn03/moP0j^c^0?Of
n03/k_P0j^GU0>?Ul03Umol0mn_^0>CTk@3^mnl0hnG`0?G^n03/k_P0k>cd0>k_l03SmoP0j_Og0>Cd
l`3bmoL0oooo00D0moOg01H0mOoo0?7oo`3eool0mOoo0>cgo`3Si>l0jnc_0?Ogo`3[jo<0j_?h0?;f
o`3Zm?@0k?Oh0??cn03UiNl0j_Cg0<CUkP3gk_00ho?o0=KDc@1hG4T0/jJ/>P3oool00200oooo0P3o
moP0103oool0ooOh0?ogn03oool20?ogn00B0?ooo`3omoP0ooOh0?ooo`1_Cd/0g^OM0>;Tk`3ci=h0
h_C_0>;dm`3glnd0g]_F0>GXj03emoL0hoOo0=[Lf`3[k>h0k_Oh0P3Ifmh20>CVj0060?ooo`3emoL0
oooo0?Ogn031b</0g^g]0`3^moP01P3Ji>h0j_Kh0>?dk03cm?@0j^g]0?Ock@80moKh0100jngU0>kd
m03omnl0moOh0>?ok`3RkNP0i^Kd0=kPh@3^ool0j]GN0=o[gP3Si^L0j^CU0?OTi@3gi>H0mng^0P3g
ool01P3omoP0moOh0?Ogn03oool0moOh0?Ogk`<0ooog0P3oool01@3ooo<0ooog0?ool`3gmn`0moOd
00<0ooog00<0moO/0?Odk@3omoP00`3gmoP0103oool0mnko0?O^o`3okNh20?Ooo`030?ooo`3gool0
oo;d0080moO_00l0loCX0?odo`3omoP0oooo0?ogm03omoP0ooOo0?G]n03em?P0ooCo0?ogn03oooP0
ooOo0?G_n03amoP00P3em?l20?Goo`0>0?7oo`3emoP0mOoo0?Gdm03emoP0mNg^0?ogn03oool0ooKh
0?o^l03ok_P0oo;h0?o^l03gmoP20?Ooo`0<0?ooo`3gm_l0moKo0?Ofo`3ol_P0ooKd0?obn03^m_@0
jo?g0??dl`3oknl0moCd0P3om?@05P3/moP0j_Oh0=KUi`3ci^P0j^GU0>kUi`3Umol0moOh0?oVj@3F
i>d0k_C]0?7Vm03bk_P0k>kh0?ooo`3Vm?@0lOoo0??dl`3oool0moOg0??dl`3oool20?Ogo`80moOg
0`3oool20?Goo`0A0?ooo`3cm?l0moOo0?Ofm`3JiNl0k?Oh0?Ofm`3clo@0k^kh0>_/l`3Rko00g^GX
0?ofo`3Smol0W9R:08=UH@3^iO00>P3oool001/0oooo0P3omoP60?ooo`80ooOh1`3oool08@1RB4H0
jngR0?;dm`3Rh>T0g^SX0?Ggm`3omnl0j^SQ0?Ogn03ZkN`0oooo0=kXj03gool0i_Cd0=oPh`3[k>h0
fMcM0?Ggm`3Zk>`0lOCc0?Ggm`3/knl0fLoA0?Ggm`3SmoP0k_Oh0>Kdm03^m?@0lnc^0?7Ui@3[knD0
joOd0>[/k0020?Gon00K0>[Vk@3Ri>D0loC]0?oom`3gknD0c^GU0>GTkP3Ig>D0joOg0>CQkP3Vi>40
j_C^0?Gdm03cm?<0ooKh0?O/kP3cmoP0mno`0?o_l03gmoP0moCd0?ogn03gool0moOh0?oom`3ooo<0
ooog0080oooo01<0ooog0?ool`3oooL0ooog0?ooo`3oooL0oooc0?oom`3gmnl0mnch0?OUn03oiOP0
mnCd0?Ogn03omoP0mnc^0?OWl03okNh0moKh0080mo;d00<0oo;d0?ofn03cm>`00P3gmoL01P3om?P0
ooOo0?ogn03omo@0mNg`0?GXm080lOOo0100mNSd0?7Xm03ej?@0onSd0?Ggn03am?l0oooo0?Ggo`3e
ool0oooo0?7oo`3om?@0lOOh0?Gdm03eool0mOOh0P3oool03P3om_P0onk`0?O^m03gm_P0mo;d0?oo
o`3gool0moKh0?ofn03gool0joKh0>_fm03^ooP0i_Ko0P3^m_P0103ck?<0mooo0?Odm03oool20>co
o`0H0>Cgn03RiO00hnk/0>?om`3NkNd0k_?h0??gk`3/iND0i?Cc0=K_k03omnl0mNkh0>[^n03^moP0
i_Cd0>kgn03ZmoL0k^kg0?Ofo`3oool0ooog0?Ogo`3oool0ooog0`3gmol00`3cm?l0moOo0?ooo`02
0?ooo`0?0?Ogo`3cm?l0moOo0>KVl`3gmoP0jnc]0>k^k`3[k?@0h^cc0<gXj@3Zl_P0moKh0<_IgP23
NF40[HnI03/0oooo000K0?ooo`80ooOh0`3oool20?ogn0X0oooo00D0NUmP0<K:^@3gmnl0hmgO0<gD
gP020?ooo`0J0?;dm03gmoP0j^g]0?7dl`3ZkNd0mooo0>_dm03VkNh0ooOh0=kQhP3Zi^P0j^_`0>[_
k@3/knl0moKh0?ogn03JiNP0mOoo0>kdm03om?@0mnc^0?o/kP3/jo00hoC_0?o_i`3Si^L20>c^k`0B
0?O[kP3Zind0lnoW0?ogn03ckND0g_Od0>?PhP3Aj?@0k^k_0=[Ti@3Idmh0hnGU0>C]j@3Si]h0loC/
0?OTi@3omoP0moCd0`3cmoP20?Ogn0030?Odm03omoP0oooo00<0oooo0P3gmoP30?oom`050?ool`3o
ooL0moOd0?Ogm03gi?@00P3oiOP01`3gk?P0ong^0??gn03ckNh0moCd0?odm03gl_@0103oool02`3c
kN`0ooCh0?ogm03okNh0ongh0?G_n03em?P0mOCd0?ooo`3em?@0lOOh0080mOCd00l0lOOh0?Goo`3a
koP0lNgh0?o_n03em?@0lOOh0?7oo`3eool0ooCd0?Goo`3oool0ooOh0?o^l03om_P00P3oool01P3o
moP0moOd0?Obm03cl_P0looo0?Ooo`<0moKh00D0k_oo0>kbn03^m_P0i_Kh0?ofo`020?Ogm`0C0??g
m`3oknl0ooCd0>Cgn03/moP0k>k`0>;go`3bk^`0hoog0=k]k@3[k?00mnk]0>Cdm`3oool0i_Cd0?G^
n03Zi_@0k>kh0>Kdm0020?ooo`080>Cdl`3gm_l0moKo0?ooo`3gmo<0moOg0?Ogo`3gmoL20??do`04
0?;go`3Zm?l0moOo0?Ogo`80loCo00l0jncg0>KVl`3Oh>`0hnC]0>cgn03aool0l_Oh0>?Tk`3Ii^L0
e^G`0>cgn03^m?@0a<G@07McEP3A]LD0>`3oool00200oooo0P3omoP:0?ooo`0:0:>5U02X[Xh0moOd
0>[]k03Nh>H0hnKW0?Ggm`3omnl0jngU0>kgn0<0moOh00P0loOh0?Ogn03gm?@0jng^0>;Lg@3bk^h0
k>gX0?;dm080j^KX00X0j^CU0=k]kP3Sko00k^g^0?O[kP3om_P0f^kh0>_gl`3^ko00ono`0P3SmoL0
4@3blo@0j_;h0=KTh@3gm>d0loO_0>?gk@3ok_00amCN0>?Ul03[k>`0dN3Y0??Vh@3ooo@0j^o^0?G_
kP3gk^l0mnGW0080ooOh00P0mno`0?Ogn03gool0oooo0?Ogn03omoP0ooog0?Ogm080moCd00D0ooog
0?Ogm03gmoP0mnCd0?oTm0020?Odm0<0mooo00T0moOh0?OTm03ok_l0moOh0??gn03gm?@0mng^0??^
l03om_P00`3oool06@3gmoL0mng]0?ogn03omoP0mNSY0?G_n03akoP0lOCd0?Gdm03eool0mNgd0?Gd
n03em?@0ooOh0?odm03okoP0lNoh0?7gn03omoP0lOOh0?ogn03oool0mOoo0?Gdm03eool00P3oool0
103om_P0mooo0?Obn03om_l20?ooo`0P0?Obn03ol_P0oooo0??on03goo@0oooh0>kbm03^m_@0mn_]
0?Ogk`3^ooP0mnkg0?ogm`3cool0moOg0?o_k`3ekNh0l^g^0?O^l03Sk_P0j^_d0>[Ph@3Ri>h0g^3^
0=Wdn03Zk>d0k?Og0>kgn03SiO00k>kh0?Ooo`3oool20>kgn0070?Goo`3Zm?<0oooo0?Ofo`3cl_l0
k^kg0?Ogl`020?ooo`80moOg01H0k?Oo0?Goo`3^k_L0lo?g0?Ofm`3cl_<0k^k_0>[dm03ZmoP0lOoo
0?Goo`3oool0j_Oh0=WPk03=h>T0ooOh0>cfo`3;h>D0a;Zj06mYF03Jb]@0moOh>P3oool002`0oooo
0240_Ifd092HM03cmo@0h^gX0=WIf`3^kND0k_O/0?Ggm`3Rj>40k_Oh0?Ogn03emoL0k>o_0>_dm03g
moP0moCd0??cm03IgMl0l^c]0>[/k03gmoP0g]WK0>c/k@3emoL0f^GX0>k_l03Nm?@0onk`0?O[kP3I
k_P0g_Cg0>_gl`3gmo@00P3cm?@04`3SiNL0k>k_0=7Ph@3cm>d0joog0=[go`3ek>P0i??d0=[Mj03J
e=l0dMcU0=WPh@3gool0moO`0?7]kP3oool0mnc/0?Ofn03omoP00P3gkNh01P3om?@0moCd0?O]kP3o
ool0moOd0?oom`80ooOh00T0moOd0?Ogk`3oooL0mnC]0?O/n03ok_l0mnch0?Ooo`3gko000P3gkNh0
1`3gk?P0ooKh0?odm03om?@0moOh0?Ooo`3gl_P00P3ooo@00`3oooP0moOg0?O_k`020?ooo`0:0?od
m03ekNh0mOoo0?G_n03em?P0lOCd0?Goo`3ekoP0mNG`0?o/m080ooOo00T0mOoo0?G_n03am_P0mOKh
0?G]m03emol0lOOh0?Ggn03em?@00P3om_P01`3gooP0lood0?obn03oond0moKW0?Obn03cm_@00P3g
l_l02`3gooP0ooKd0?ofn03om_P0k_Kd0>kon03gmo@0ooKo0>_cm`3cm?<0looo0080oooo00l0k?Cd
0>[gn03cmoP0k_Kh0>G/m03gk>P0f]gW0>k[m03/m_P0hno_0?OUi`3oool0i_Cd0?7Vm03cool00P3o
ool20>kgn0090>[gm`3gmoL0moKo0?Ofo`3oool0moKo0??bo`3cl_L0moKo0080ooog00<0moOg0??d
m`3Si>`00P3^k^l00`3Zm?@0j_Oh0?Goo`040?ooo`0:0>;^n035g>D0iNO^0>c/m03gk>h0dNcd0::G
T029L6l0mng^0?Ogn3X0oooo000N0?ooo`80ooOh1@3oool20?ogn0D0oooo0240e[g>08=iG@3Zk>D0
f>7F0=WIgP3okND0i_O/0?7gm03ZkN`0oooo0??dm03/knl0oooo0?;dm03bmoL0hnKW0??/kP3[k_00
h^3Q0?;cm03/knl0i>OX0>_/kP3Oh><0jnOY0>?gn03SkNh0k_Cd0>k]kP3om_P0j_?d0>kom`3/knl0
0P3cm>d06@3^k_P0b/cG0>k^l03Hfm`0j^c]0>_dm03[k_P0h^GU0>;Wj03@k?@0d=GM0;k8f`3>c=<0
hmgN0>[]iP3ZkNh0lNo_0>[Qh@3ZfM/0ln_]0?Obm03om_P0ooOh0?Ogn03ckNh00P3oool20?Ogn00:
0??dm03gmoP0moO_0?Ogm03cm?@0mnko0??/n03omoP0moOh0??dm080moOh01L0looo0??gn03cmoP0
loOh0?ofn03oooP0ooKo0?Oon03cmnL0k>o]0?Ggn03em?@0lNCV0?7Vj@3ajnh0mOKh0?G_n03ekO@0
lNk`0?Gfn03aool0mO;d0?GTkP020?G_n0060?7_n03em_P0oooo0?ooo`3aiO00mNgd0P3ek_002P3e
moP0mo;d0?Obm03gooP0loKh0?Ofo`3conl0mooh0?Ook@3om_l20?ofk@050?obk@3om^d0ooK]0>kf
i@3VooP00P3[moL0403[m?<0moOg0?O_k`3gm?@0mNg^0>[Ph`3/h><0k^3R0>KPh@3Rh>40j^CU0?Gg
n03Oi?00lnc^0>;Wj03UgMl20>Kdm0030>kgn03Zi_@0iOOh0080i_Cd00D0hoOh0>[gm`3/mol0ooog
0??bo`020?Ogn0040?ooo`3gm_L0lo;c0?Ofm`80oooo0P3oooL0103[jn`0oooo0>cgn03eool40?oo
o`0;0?Goo`3ZmoP0h^_h0<_Xj03omoP0k?Ko0?;on039e>80NfUC0:R?V03gmoP0>`3oool001h0oooo
0P3omoP50?ooo`80ooOh1@3oool08@3^iOP0U7Uk0;VhW`3Zknl0j^_h0?odm03[m?@0j^g/0?7dl`3c
m?@0oooo0??dm03am?<0j^g/0?;dm03UkNd0ooOh0??gn03bkNd0lOOd0?Gdk03am?<0gn3V0?;gl03R
m>h0loOh0?Ogo`3^kNh0moC^0??cn03blo@0oooo0>kom`020?;dk00P0>_/m03[i^h0bmCF0?Ofn03T
jnl0jnoU0??dk@3gooL0mnkh0>?Ui`3FkNl0h^o/0=WTi@3AgND0jn3M0>GUi@3ckNH0l_oh0?G_kP3o
moL0moCc0>[/k03Zi>D0mo?d0?ogn03gkNh0moCd0?ooo`3omoP0moOh0?Ooo`3oool20?Ogn080oooo
00T0mooo0??oo`3gmoP0ooCd0?ogn03gm?@0mncd0?O[m03glo@00P3ol_@01P3ol_P0looh0?o]j03a
iO00mNc^0?Ggn0<0ooKh00H0mOKh0?Ggn03emoP0mOKh0?ofn03gooP20?Obn0030?Ofm03om_P0oooo
00<0ooKh00<0mOoo0?Gfn03om_P00P3om_P02P3gool0moKh0?Ofn03cm^L0loK_0?Ofo`3oonl0oooo
0?ooj03oool30?Ogn080loCd00`0moCc0??gm`3cmoL0moOg0?Ogn03omoP0k?oo0>;dm03cl_@0hoOo
0>_gl`3oool20?Ggn0090?ooo`3Ifn80k?Oc0>cgm`3Vm?@0oooo0?G^n03ai_@0fNG`00<0k_Oh00D0
lOoo0?Ogm`3gmol0moKg0?ooo`020>k^n0030??bm`3oool0lo;c00@0lo;c00@0moKg0>_[k03gmoP0
lOoo0P3eool30?ooo`0;0>[gn03^k^l0dNG/0=[_k`3omoP0j^_`0?o[kP2SWZ@0Ke=40>;DgP3gmoP0
>`3oool001l0oooo0P3omoP<0?ooo`0>0:RAXP2]ZI00jnSQ0>CVm03oool0looo0>[]k@3emoL0loCd
0?ooo`3gmoP0j^g/0?7dl`3oool20??dm00@0>_dm03cmoP0j^OQ0>[^k@3oool0h^C]0>;_kP3booP0
loO^0?OdkP3^m?@0mnk^0??go`3gm_P0mOOg0?ooo`80j^g]0200oooo0??gn03bk?@0dMCO0?Ggm03I
iNh0g_Oc0>kdm03omnl0lnc]0<SUn03JkoP0k>GW0<kPk@39fNH0fM7K0>?Mg`3ZkNh0j^gd0>CXj@3Z
j>T0mNg^0?G_k`3Zk>l0j^_d0?Ofn03omoP0ooCd0?ogn03Rmo@0h_Oo0?ogn080ooCd00<0moCd0?Og
n03oool00P3omoP20?ooo`030?ogn03ojo00oooh0080oo;d00P0moKh0?O^n03cm?L0mNg]0>cVkP3c
m_l0mo?d0?ogn080oo;d00X0oooo0?ocm03olo@0ooKh0?Ofm03gooP0moKo0?ooo`3gm_l0ooKh0P3o
l_@01P3olo@0ooOh0?ofn03oool0oo;d0?ofn080moKd00T0moKW0?ofk@3gonl0moK_0?Ofo`3oool0
ooo_0?o_k@3gkO@00P3oonl03`3gmoL0oooo0?oon03gooP0oooo0?Ooo`3gmoP0hoOh0>Coo`3emoP0
k^k`0?ooo`3Uk?@0mOog0?ooo`020?Ggn00?0>Ggo`3Jk>L0j^CW0?ooo`3Vm?@0k?Ko0?;/m03oool0
fOCd0?ooo`3^moP0f^oh0?;go`3oool0loCc00<0moKo00<0oooo0??bm`3gm_L00P3gmoP20?ooo`03
0>cgn03Rjn`0i^KX00@0mOoo0P3oool02`3eool0h^cd0>k^l`3AkO@0k_Oh0>k]kP3gm_P0k?oh06EU
EP2DLG<0moOh03`0oooo000@0?ooo`80ooOh3@3oool20?ogn0/0oooo00X0moOh0<:W]P2FThL0i]c;
0>[Ul03gk_P0looo0??dm03^ooL0loC]0P3gool0303ZkNd0mOoh0?ogk@3gmol0jng^0??dm03gmoP0
i>OX0>cfo`3em>`0i>KX0>k]kP80k_Oh00L0oooo0>cgo`3JgNP0moOh0?Ogo`3^k_P0lOCc00@0moOh
02X0i^cd0>?_k`3AbmL0mooo0>[PhP3JgMl0k_Cd0?Ogn03Zk?@0dMWY0=KIiP3Uh>80fNKU0>G^k`3I
dmh0c]CK0=oDeP3[h>40jnKX0=oTi@3Si>H0lnSR0>cVi`3Zk?P0i>K]0>CVj03/k^l0hooh0>?gm03o
moP0moKh0?Obm03Rm_@0h_Ch0?O^l03glo@0ooKh0?ocm03omoP0ooKh0?O^i`3gmnl20?obm00?0??o
o`3gmol0moCg0?7]k@3gk_P0ln_`0>kgn03Sjnh0loKh0?Ofn03gl_@0looh0?Ofm03gl_@0moKo0080
oo;_00<0moK_0??ok`3gool00P3gm_l03@3ok_00mn_^0?Obm03om_l0oood0?obn03gm_@0oo;h0?Of
k@3gool0moo_0?Ooo`3gonl00P3oonP0603gkO@0oooo0?o_n03okoP0moOo0?Ogn03cm?P0moOd0??g
n03om?@0ooOh0>[gn03cm?@0ooOh0=[[m03Uk?@0mnk_0?ooo`3emoP0hnG`0=oPkP3Uh>T0j^3R0?OU
i`80k_Oh00/0j^_h0?Ogl03Umo@0iOOh0>cgm`3ZmoL0moOo0?Gom`3cm?L0k^kc0??bo`020>_[n005
0?Ofo`3oool0oooo0?Ogn03eool00`3/moP00`3bm_L0k^k_0?7oo`050?ooo`0;0>[gn03[jnl0fNg_
0>?gn03^m?@0k^o`0?OVi`2c^[d0@3<^0=W2cP3gmoP0?03oool00100oooo0P3omoPJ0?ooo`0Q0?Og
n03Ib=/0UiR:0<S0[P3/kNd0k>kh0>k/m03Uknl0hoOo0?Ogn03omnl0oooo0>kgn03bkND0mNgQ0?og
m03^kNh0mooo0>__l03ekNd0mncU0>[^k@3Zjnd0k^g^0>_gn03aool0g_Cd0=[_n03/mol0fMCG0=WL
i@3bmo@0k>GW0080lOCc02X0k>o_0?Ogn03cmoP0iNG`0=W]k@31`L`0h]WK0?Gdm03Jk>P0k^oW0?O^
n03ek_00hnoh0>_[m03Iko@0d>G]0=kLg@3Ffm`0e^3R0=kPh`3Ri>H0mno_0>_/k03gk^l0lngU0?od
j03gkND0lnSY0>?LgP3Tfm`0i>3U0>CVm03Zk>l0k?Og0>[fl03ci^80l^c]0?Ofn03cm_P0mnk^0?O[
l03ck^l20?Ogm00C0?O^k`3gm_P0mooo0?ogm`3em?<0k>GU0??/kP3Sg=h0k^3K0?OXh@3[kNP0joC/
0??gk03gk>l0k^C]0>k^j03ckN`0mnSg0?o_m`020?ooo`0@0?Ofk`3oool0ooKh0??on03gonl0mooX
0??oh@3cm^D0lood0??fn03gool0oooo0?ook`3oool0ooo_0?o_k080onSh00<0moO_0?o_m`3gmol0
0P3cm?L0103gmoP0loCd0?ogn03gm?@20>coo`0Q0>[gn03cmoP0k_oo0>c[m03[mo<0oooh0>c_kP3I
g>H0hnCU0?Ogm03oool0i?Cc0>kgn03^k_00mN_d0>c^n03Smo@0iOOo0?ooo`3/moL0mOoo0>[dm`3S
k_<0j_;d0>;fm03oool0lo?d0?Ofm`3gmoP0oooo0?Ofm`3cl_<0hnk_0080k?Oh0P3gmoP00`3oool0
lOoo0?ooo`030?ooo`0;0?Goo`3Rk>d0hnkg0=KUkP3^m?@0k^o`0>k]kP3cm?@0GEIF07mNGP3gmoP0
?@3oool002d0oooo00h0k^Gh0;2SY02]XXd0jngU0?7gm03ch>H0g^o_0?ooo`3Smol0loC]0??oo`3[
moP0l_Cd0?Gdm080ooOh0100i^g^0>kgn03^m?@0j^OX0?Ofn03bm_@0j^ch0>cgl03SmoP0f?Cd0?oo
o`3Nm?@0a=7D0>c^k`3Rg=h0j^OX0P3oool0703emoL0j^g/0?Ggm`3cmoP0h^G`0?ooo`3?eMl0fNCU
0?ogk`3Jk^l0iMgO0?ooo`3bh>T0mNk`0?Ooo`3Smol0d^gh0=W]m03RkNP0loOd0>?Ui`3TiNP0hoOh
0=k/k@3Ag=h0moOh0>GUi`3^k^l20?Ogn0090?ogk`3gkM/0mnoX0?Gdn03aj>P0mNg]0?G_k03em?L0
mOCc0080k?C/00<0mNo_0?Gdm03em?@00P3gmoL03P3ekN`0lNg]0>c]kP3UiNP0jnkW0>;Ui`3Tm?P0
g^cd0>;TkP3Tj>T0g^7Y0>[]i@3gkNd0k^oh0P3gmo00303gmol0onog0?ooo`3ok?P0ln3U0??_f`3o
ond0ono/0?O]n03ckOP0mn3W0?o/j080ono/0P3oonl08@3oool0onoh0?ook`3gkOl0loCh0??dm`3g
moL0oooo0??dm03gkNd0loCd0??gn03gmoP0ooOh0>[gn03em?@0k?Cd0?o^l03cm_P0j^CU0>;]k@3R
i?00h^Ch0>_/m03oooL0mNkW0>[Wj03/m?@0i_Cd0>cbn03Zm?P0mooo0>Kdm0020?ogm`0;0>cgo`3J
iN`0k^k_0?Ofm`3/m_P0hooh0?ooo`3gm_L0lo?d0?Ogn03oool01@3gm_L0103cm?@0oooo0?Goo`3e
ool40?ooo`050>[gn03Si>`0fNK`0?ooo`3^ko000P3Vm?@0102ae=h0ABLR0<J^/P3cm?@m0?ooo`00
;P3oool04P34]LT0WHYb0>K]h@3am?P0lnK^0>Kdm03am?<0mOOg0>[]k@3gool0loOh0??dm03gmoP0
oooo0?oon03[kO@0moOh0>KXj@80mOOg00/0l_oh0>[^m03gk^h0f?Cd0>?gn03Nm?@0mOoo0?ogn037
eML0hnGW0>GWj0020=KIf`0J0>[]k03am?<0j^g]0?ooo`3gmoP0f]gX0>[Ul03^moP0fNCU0>[Wh@3^
ool0iMgM0??KhP3Zh>h0k>kh0?ooo`3^m_l0hnO_0=k]k@3Zm?@0g_Og0>?Pj@3/moP0oooo0>?Pg03I
i>L20>k^k`0a0>_/k@3Sm_l0fNc^0>G^l03UiMh0fNCU0=;VkP3Sk>h0mnoW0?;]gP3bh=h0mNCV0?Gg
n03em?@0k?Oh0>[Ui@3em?<0lOOg0?Gdm03gk_P0iNCW0>k/k03RgND0g^C`0?Ofn03ol_@0lo?d0>_^
m`3gooP0k?Oh0>C]kP3ZkNh0j_Oh0?ogm03gooP0loCh0??dk@3gkNl0lood0?O]n03cm>d0loC_0?Oo
n03omoP0moOh0??do`3cm?@0mngd0?Ogn0020?O]m0050?Ogk`3gmol0moOo0?ogm03gm?@00P3cm?@0
0`3omo00l_Od0?Ggn0020?ogn0070>coo`3bm?@0looo0?ofn03Sk_P0g^ch0>cTh@020>k^n0090?oo
n03cm?P0ooog0>[/i@3gi>D0k_oo0>kgn03TjoP0ooOh0080k_Oh00H0ooOg0>coo`3oiN`0f_og0>k^
k`3oooL20?Ofo`<0oooo00D0moOh0??dm03gmoP0moKg0??bl`020>k^k`030?Ogn03oool0lOoo00@0
oooo00`0k?Oh0=[Uk`3AiNl0hoCd0>K]kP3^moP0oooo0?ogn02DYZ`0FcP`0??Xj@3gmoPm0?ooo`00
;P3oool02@3FcND0UhQ`0=7>_@3Zmol0mnk`0>?Ul03ZkN`0mOOg0?;dm0030?Ogn00C0>;]k@3/moL0
oooh0?Ogm03[kNh0i^SY0?ooo`3am?<0lnk`0>c^kP3Zi_@0k?O`0>;gn03oool0hoOh0?Goo`3emoP0
dMCG0<G9d`020>[/k@040>KWj@3Oh><0l_Cd0>c_k`80loCd01@0mooo0??oo`3gool0moOh0??]i@3[
m>P0ooog0?ogn03/iO00k>kh0>kcn03Ok?@0a^og0=kgo`3oool0hnG`0=kTkP3gmoP0k^G/0?O]i@80
k?Cd02P0dMgO0>?Th@3[inD0e^3X0=KTi`3Njnd0mOOd0>kfn03Ojnh0gn_`0=ofo`3Sjnh0mno`0?OU
l03glo00j^gV0?Ggn03oool0iNCV0=oUi@3^mnl0mNo`0=k/l03clnd0k^k_0>?^n03Nkn`0hnGW0>_V
j03[jo@0lo;o0?Ofm03ZloP0g^c`0>c_m03om?P0ooCd0>[_kP3Zmo@0ooOh0P3om?P01`3oool0ooOo
0?odo`3oool0ooOh0?O_k@3gmnd00P3gmoP01`3cm?P0lngd0?ogm03gm?l0oooh0?Oon03emoP00P3Z
moP07`3gmoP0j_Oh0>[gn03emoP0onk`0?Obm03gool0j^_d0>c/k@3gknL0jn_h0?oon03gmoP0hnoo
0>cgl`3Tm?l0oooo0=kTkP3Zi_@0mNk`0?Oon03^moP0i_Cd0>kgn03ZmoL0mNG_0>c^n03oooL0oooo
0?oom`3cl_l00`3oool01@3cm?@0oooo0?Ogn03gmoP0oooo0080loCd00<0mOoo0?7oo`3eool00`3o
ool0303eool0h^c]0>;/m`3Um>h0joOd0?Oon03[mo@0i_Cd0<KIf`1_M7/0Qg1/0?ogn3h0oooo000^
0?ooo`0O0>kUn02ZUI/0[9Mb0=3If`3/knd0jnKd0>;]k@3eooP0ooO_0?Ogn03^ko00moOh0>;]k@3/
moL0mOOg0?7dl`3Si^L0oooo0>_]kP3/knl0iN3U0=k/n03Zlo00moCh0>k_l03RmoP0lOoo0>K]kP3^
inT0hn3V0?Ogo`020=[Mg`80bloA00D0oooo0>;Ui@3[ko00joOh0??gn0020>[]k@0f0??dm03gmoP0
loOh0?o]kP3gh>T0ln3^0?;^l03emol0ooCd0??Wj03[h>40gnSX0>__k03FfMh0hnoY0=SQhP33cMh0
bM_Y0=STkP3RkNh0g^g^0>?_l03gk>h0dLcK0:o1e`39dM/0f=cL0<W>eP3=c]H0i=cL0=[If`3OfM/0
joC]0>?on03Fi_@0fMCF0=WDe`3Jc<l0cm7K0;g?gP33fNH0e^3U0>;Ci@3Ig>d0k_C/0?7gm03[mnl0
fOog0>_gm`3NkN`0e^CU0=o/k03Uk>`0hnG]0P3Tm>h04P3goo@0l_Od0>[gl03Zmnh0loo`0?Ogn03o
mo@0moOh0?Odn03omo@0moOh0>[]n03Tj>T0g^3S0>CWkP3Zm?P0i>gd0>[]kP80j_Ch00@0mOOh0>cg
o`3Rk?@0k>c^0P3giNL0403gk_00iNk_0>Kdl`3RinP0i=_L0?O^k`3NkO00h_Kd0>[cj03SkoL0f^o_
0=K]k@3FkO@0g^C^0=[Ul03UmoP20>Ggo`070>kgn03oool0g_Cd0?Goo`3cm?<0moKo0??bo`020?Of
m`090?Ofo`3oool0moOh0??dm03gmoP0mOoo0?7oo`3ZmoP0i?Cd0080j_Oh00<0mOoo0?ooo`3oool0
0`3oool0103Rk^l0b=gW0=K]m03gooP20?ooo`050>_dkP3JgMl0OXN506QADP3A^[D0?`3oool002h0
oooo01l0k^Gh0:ZEV`2/Ug80d=WK0>c_k@3[i_@0h^g]0?Gon03omnl0moOh0>k_l03gmoP0h^g]0>cg
m`3emoL0lOCc0>?Vi`3oool0jng^0>c_k`3Uh>D0g^ch0>[cl03gm?P0k^o`0>;gn03aool0i^g^0>kW
j@3Sh>H0moOo0080f]gO0P3;cm401@3oool0h^GU0>__l03[moP0loOh0080j^g]03H0loCd0?Ogn03c
moP0ong^0?OPj@3ch>h0l^k`0?Ggo`3om?@0lnOX0>_Ph@3Oj>P0jno/0=KIgP3SknT0f>7R0<?=gP39
fnT0f>C^0>;]kP3NkNh0hno`0?O/kP3Ac=/0[l7G0<WAf`3Hg=`0bLkF0<g>eP3Tg=`0f]WK0=oIf`3[
m>d0hooh0=KVm03Ie=H0fMCG0=[<c`3?dM/0_LoN0<?IiP3Fh>D0h]?U0=WLk@3^m>`0lOOd0>_gk`3I
ooL0joOg0=k]k03Fi>D0gnc/0>G/k03SiNd20>CdkP0B0?Oom03bmo@0j_O`0>[gkP3coo00moOh0?og
m03gmoP0moCh0?ogm03gmoP0j^gh0>CXj@3Nh><0i>O^0>[dn03TkO@0j^g^0P3Zm?P0103emoP0k?Oo
0>;/m03/k>h20?OUi`0@0?O^l03Uk^l0i_Cc0>;Wj03Tfm`0mnk_0=k]l03Rm_@0j_?X0>?_m`3Jknl0
e^g]0=K]m03Ni>h0f^G`0>Ggn080iOOo00L0k_Oh0?ooo`3Nm?@0mOoo0??dl`3gm_l0lo;o0080moKg
00T0moKo0?ooo`3gmoP0loCd0?Ogn03eool0lOoo0>[gn03Tm?@00P3ZmoP00`3eool0oooo0?ooo`03
0?ooo`040>;^k`38gNL0e^gd0?Oon080oooo00D0joC^0=[Mg`1nQhD0J55B0=6j]@0o0?ooo`00;`3o
ool07@3Jc>D0V81]0=KPf`3RkND0j^C`0>__l03gknL0mOoh0>_gl`3cm>d0oooo0??dm03emoL0oooo
0?Ggm`3am?<0gn3S0>_/kP3gmoP0e]cU0>_UiP3^m?@0ooOh0?Odn03Nm>h0h_Oh0>kdm03/jo00l_oh
00@0l_?d0300j^cU0>GXk@3clo@0iNk`0>kdm03^kNh0g^GU0>G]k@3gmoP0lo?d0??/kP3^moP0iNG`
0??bo`3gm_@0l_Kd0>[fo`3Zm_P0l_Kh0??oo`3Nj>d0j^kd0=KVm03ZiND0k?OX0?;om03Sk_l0g^Kh
0=[Un03^iNL0e^cd0<kgo`3[ooL0mnk_0>c^n03Zi^d0k^k_0=kVk@3IiNL0g^o`0=[Ti@3eoo@0jncd
0>cgm03TkNd0h^GU0>G^n03/k_P20?ogk`80hnkh00X0hnC^0=7IiP3Sh>P0h^3R0=kPj@3Nio@0h^gd
0>c_kP3[ooP0k^kg0P3[i_<01`3/iOL0lOCo0>c^n03/k_P0lOC^0>[dl03Tm?P00P3emoP02P3Tm?P0
j_C^0?Ggm03oooP0moKd0?ooo`3[jnd0jn_d0??bn03cl_@20??[k@0@0??fn03gl_@0ooKh0?ocm03g
m_P0loOg0>;/k`3eooL0lOCd0>kgo`3Nio@0fMcV0?GVj@3ek^D0i>gd0>Kgk`80mNkh00X0lNKd0>?g
n03oool0oooo0>kgn03^m?@0i^g]0>_gn03bmoL0moOg103gm_l20?ooo`040??dm03oool0oooo0?7o
o`X0oooo00`0mOoo0;cIh@3JkoP0hoOh0?;on03oool0moO`0>kgn02LZjl0Kfmc0;FMW`3omoPo0?oo
o`00;`3oool07P3omoP0X81o0;Vh]03[knD0g]_X0??gn03cm?@0mOOg0>_gl`3cm>d0mooo0>_dm03e
moL0mNo_0?7]k03emoL0e]WK0??cm03cm?@0i>g/0>_Vl03Nmnh0hno`0?Oon03Rknh0hoOh0>kgn03J
i>h0mo?]0?ooo`<0ooOh00@0l_C]0>k_n03cm_P0i^c^0P3cm?@01@3cmoP0mooo0??gn03ck>h0lo?d
0080jnc^0P3gm_P20?;cn0090?Goo`3emoP0lng]0>k_k`3OmoL0l_Oc0>_dk@3Smo@0k_O_0080l_od
02H0lnk]0>;^k03Rmo@0g_O/0?ooo`3^ool0mnk_0?;^k03eooL0ooO_0>[Ph@3ck>d0fMCE0<kIh@3U
lnl0i>gX0>?Ul03Nh>h0i>Kd0?ofo`3/knL0iOO]0>kgo`3[m?P0jnc`0?G^l03Zjnh0jn_d0??bn03o
l_@0lnk^0=WLl03IiNh0looo0??gn03gm?@0jnG_0>_[m`80mnkg00<0lo;h0?Ofn03ooo@00P3/moP0
2P3oooP0mood0?Oon03gool0loKh0?Ofn03cm?<0moOg0>_dl`3Vm?<20>_gm`0@0>_/k03Rk?@0g_Cg
0=kdm`3Umo<0lnk_0?;^k03omnl0hnoh0>k^l03gk^h0moO_0=[_k03;j>d0e^oh0>koo`80mNkh00D0
j^Kd0>kgm03[mo@0i_Cd0?ooo`020?Ggm`0:0?ooo`3Tm?<0ooog0?Ofm`3gm_l0oooo0?Ofm`3cl_L0
lo?h0>cgn080mOoo00<0oooo0?Goo`3oool0203oool02`3ZmoP0_]CK0>_gm03[moP0l_O`0>cgl03e
ool0i^g^07YhM`1oK6h0mmgG0400oooo000`0?ooo`0M0<B^^@2RWhd0k^GG0=7=d`3cmoP0loC]0>ko
m`3oool0moOh0>kgn03cmoP0l_Cd0?G]k@3eknl0l^o_0=WUi@3[k?00gnC^0?7]k03SjoP0g^oY0?oo
o`3Sko00moKh0??^kP3gm>h0k^o`0>[[k@3omnl00P3/j>401P3UkNd0l^g]0>kgn03gool0hnc^0>k^
l080k?oh01@0moOh0>_gn03ck_00jn_^0>c^n03Zk?P0l_?h0?Ofn03Zjo@0l_?h0>[oo`3gm?@0fOCg
0>?_k03ZkNd0d>oh0=;gn03^mnl0hoOd0>;Xk@<0hnS]0P3FkOP01`3Sj>d0hn3U0>_Ti@3em>d0lOCd
0>?Ul03Idmh00P3gk^l02P3[h>40e/g?0=kKg03Nh>h0mOog0>?gl`3@kn`0j_Od0=Wdl`3gm?@20??o
o`0F0?;^l03oool0mOoo0?;gn03/ooP0loOo0?Ofn03>fNH0h^g^0>;dm03Tool0k?Cd0??gm03[knd0
lno_0??dl`3[k?<0jnK/0??[m03cm_@0loKh0>kfn080jnk_00H0jn_]0>Kdl`3[moL0looo0?Ooo`3o
ool20?;gn0030?Ooo`3booL0ooO_0080hng]0P3am?@02@3SkoP0iNG`0>[go`3bk?00k?Oc0>Gdn03^
moP0oooo0?G^n0020?7Vm00C0>[^n03gooP0iOOo0>kgn03omoL0j_Cc0>cgm`3eool0g^cc0?Ofm`3c
l_L0oooo0?Ogn03^k^l0lo;g0??cn03/moP0mOoo0?7oo`020?Goo`P0oooo00<0k?Oh0=[Uk`3Nk>d0
0P3gmo001P3bmo00mOoo0=Wgn03IkNh0BClg0;2PYd40oooo000`0?ooo`070=K=i@2YXiP0a/^d0<7=
d03[jo00mnGW0>_gm0020?ooo`80moOh0180j^g]0?ogn03ekNd0k?Cd0>cgm`3Si>h0jnkh0>[Xj03g
m_P0lnc`0>cgl03eoo00iNGh0?Oon03cloP0oooo0>[[k@3/kNP20?O_i`060??dm03^moP0joCd0?oo
o`3[jnh0k^k`0P3Fi^h05@3NiNH0hoOd0>?Vj@3oooP0mOOh0?7do`3emol0j^c]0>;Ti@3/k_@0l_Oh
0?Odm03Im?L0amWX0??/m03@koP0f_Ch0?O]k@3gknl0l_oo0>Coo`020=kUl00;0?Goo`3/iO00h^3Y
0??gn03SloP0fOCo0=o/l03JmoP0d>cd0=kXkP3ZkNh00P3RkO@0203Zi>D0mncX0>k_k`3RkO@0hngd
0=;Xk@3^kNd0l_Oh0P3ZiO00203ei^T0lNKY0?7Vj@3Zk?00h^3`0>cUkP3gk>h0iNG`0P3Vi^h02@3S
i>h0h^g^0>[_m03gm?l0loCd0??_kP3gmo@0moOh0>_gm0020>K/h@050>_/i@3ck^l0j^c]0>[Ti@3a
m?@00P3emoP20?7dm080mOOh0P3am?@06@3emoP0k_Oo0?ofn03Vi_@0k^kh0>K/l03ck?00mNk`0?OU
i`3/moL0oooo0>Kdm03oool0lNKd0?oon03gooP0mooo0>kgn03gknl0j_Cc0>Cgm`3emoL0moOg0?;g
m`3RjoL00P3gm_l0203oool0loCd0?Ogn03gmoP0k?Oh0>[gn03aool0mOoo2@3oool0303/moP0hnk_
0=7Tk`3^moP0jno`0?Ogo`3Zmo00hoOh0=Wgn03?`/h0?BLM0>?DgT40oooo000`0?ooo`070>kUn038
//D0/:2A0;bn[P3bk>h0lnkh0>_dm0020>kom`030?ooo`3cm?@0loCd0080lOCc0P3omoP02@3gm?@0
loOh0>;Ui@3emoL0jn_d0?OdkP3Smnh0g^Cd0?Ogn0020?Ofn0050?;cm03ZkNd0oooo0?ooo`3cm?@0
0P3gm_l06P3clo@0moOh0>_[kP3[jnh0lo;d0>?go`3Ik?00mo?d0>?TkP3gm_@0k>og0>CXl`3emoP0
l_C_0?Gon03gmoP0lng]0?ooo`3Zh>P0k>C^0=Wdn03?koP0mNk`0>cPj@3ZfnT0ln3^0P3gi>D02`3N
ind0f<gF0>CTk@3ek_00mNkW0>cPhP3Rkol0moOo0?;^l03[k^h0gnG^0080hoOo00X0goCo0=W]n03I
mol0j_Oh0>;^n03Zk_P0j_oo0?Ooo`3Zh>h0mncd0P3Zk_@01P3Zk^h0i?Co0?ooo`3NkNd0fNgX0?oo
m`80moOg00T0k^kh0>K^m03Ik?P0f>3Y0>;fn03am?P0j_Oo0=kdm03TkO@00P3am?l00`3ZkO@0i>SY
0>;TkP020=o/n0030>?Ul03/ko00jnc^0080gnc`02@0i^K^0>_/m03[m?P0i_Co0>K/n03^k_P0moOh
0>?TkP3Si?00k?K`0>[/k@3/moL0k_Oh0=kTkP3Rh>h0j^Kd0?;^l03gool0mooh0?ogn03VkNh0l_Og
0>;gm`3oool0moOg0??dm`3gmo<0moKo0??cn03gmoP0moKo0>k^n03cm?@0mOoo0?ooo`3ZmoP30?Go
o`L0oooo00d0mOoo0>[dm03Rjo<0e^gd0>?gn03emoP0f^K`0?Ogo`3=kNh0j_Cd09^CW01VC480ooOh
0440oooo000a0?ooo`0>0>KKkP2dZZ80[JjK0=kDf`3oool0joOh0?Ogk`3^ooL0oooo0??dm03gmoP0
k>o_0?ooo`3eknl20?ogo`080>K]kP3Vj>T0lOCc0??bm03^kNh0g_Cd0?G/h`3^lo@20?Ofn00:0?oo
o`3/knl0j^g]0>[]k@3[kNh0lo;h0?;cm03Zk?P0k>kh0>k^l080moOh0P3^k_007@3[kNh0k^o`0>?T
iP3IfN80dLoL0=7DhP3Ri>h0mOOh0??oo`3oj>P0h]cU0>CPkP3ZiO00i>G`0>[^n03ak_00e^C`0>ko
m`3^mnl0k_O/0?odj03RfND0fMCL0>?^m03Zfn80k?Oo0?;PhP3giO00l^3Y0080j^3Y00D0k>G`0?G^
l03ek_00l^k`0?;oo`020?Ggn00E0?O^n03omoP0ln_h0>[Vm03/iO00ooC]0?odj03^m>d0f_Ch0>?o
n03gmo@0k_Od0>cgo`3FkNl0i?Cg0>cgl`3oooL0onkU0?O/k@3cm?L0hnCW0080fM_Y01T0i^K^0>_[
l03Ok?P0fNC`0=oPkP3Vi^d0jnc]0?O/kP3gmoP0iOOh0>?TkP3RmoP0l_Oo0>[Ti`3Hj>`0dN3X0=kP
i@3ci^80loO_0??cm03gmoP0mNk`0>[/l03giNd0j^CW0080k_Oh0P3ek_P01`3cool0looh0??on03^
moP0k^o`0>KUi@3amoL00P3gmoL0303gm_l0moKg0?oom`3gmoL0hnC_0?Ogn03gm_l0k^kh0?Ogn03Z
m?@0l_Oh0>cgn0<0mOoo1P3oool03@3eool0k?Oh0>GUk`3@iNl0mOoo0>?gn03FkO@0mOoo0<KVl03U
moP0mOOh06eTI02PO7/0@P3oool00340oooo00L0k^Cd0<Rj_@2OUH40_[^f0>?LgP3gmoP0joCd0080
oooo0`3gmoP03@3/knd0oooh0?Gdk@3om?P0k_Oh0?ooo`3Si^L0j^c/0>[Ti@3gk>h0i_Cd0>K]kP3Z
i>D00P3Zj>P0;@3akN`0hnKW0>?Vi`3UiNP0moKh0?Ggo`3Zk?P0h^C^0??/kP3/k?@0h^C`0??cn03g
moP0jng^0?ooo`3[m?@0moOh0??/m03Vi_@0hnkh0?ooo`3/moP0h^cd0>c_k`3Ri_@0j^kh0??Pi@3Z
iND0mnK^0>GTi@3^ooL0g_Og0>?go`3^m>d0lnkh0=[Mi`3Rm>`0k_oo0>GUk@3ch>h0lnKd0>GLgP3O
fMH0jnKU0>con0020>[Tk@0F0?;Pj@3eool0k>GW0>?DeP3Ie=/0jn3Y0?ogn03^m?@0i_Oh0>Kom`3F
iNd0g^CW0>?dk03[kN40iNg]0>?go`3Nm?P0ho?h0>K/kP3FkNd0bnS]0<_Xm080bnS]0140e^g_0>Cd
l`3TkN`0g^G/0=SQj03NfM/0i>CU0>C]k03TkO@0i?Cg0>Cdl`3Ti>D0g^3U0<CUl`3;fN40d]WK0=K]
k@020>kgn00>0=KWj03;h>P0bmWN0<_If`3FkN`0fN3Q0=oLf`3FkNd0a>Cd0>G[l03ejo@0lNK^0=[U
kP3Om?@20>?]k@060>kgn03[moP0joCd0>[om`3cm?L0k^kg0`3gm_l0103gmoL0lo?o0??bl`3gm_L3
0?Ogn0040?;gn03eool0mOoo0?Goo`H0oooo00h0k?Oh0>;/k@3Ii>`0jnkg0>;gn03emoP0moCh0?oo
o`3AiNh0cNoh0>_/n01lM7@0D34b0=6j_D80oooo000a0?ooo`0B0?ogn03Rg>h0Xi6;0=WId034dM<0
mnc^0>_gn03cm?@0moOh0?Ggm`3ZkNd0oooo0??go`3akNP0lNg/0?ogn03om?@0i^SY0P3^ko00203e
moL0k>k_0>GTiP3^k>h0g]_L0>kgn03Vk>h0hnGX0P3[kNh0@03cl_@0oooo0?ooo`3gm_P0jn_^0??/
kP3Zk_P0iNKd0?oon03cl_@0iNGX0>_]kP3gool0k^g^0?OTkP3ci_@0k>kh0?ogn03emoP0g]_Y0>k/
m03SiO00f^kh0??Th@3Zm>`0j_Og0>?_k`3NmoL0joCd0?ogk`3Sknl0joCd0>[]k03Smol0joCd0>kg
k`3[m?@0mooo0>K]i@3ek^D0g^OX0?O^m03ci>D0joCd0>?LgP3[h>h0mnkd0>K_i@3/k_P0e^3Q0=KM
g`3oknL0k_og0?Ggm`3Zi^P0moKh0>[[m03Tl_l0l^_d0>;TkP3[lo@0mn_^0>[/n03ai_@30?G^n004
0>kgn03oool0k_Oh0>kdm080g^cd00@0i_Oh0>Kdm03VmoP0i_Oh0P3Nm?P20>Kdm00<0>_gm03eooP0
ooKh0?ofn03Vm?@0g^C^0?Ggo`3om_P0mNkh0?7Vm03Si>h0k_?d0P3oool01P3ZjoP0mOCh0>[go`3S
mo@0iOOo0?ooo`80moOg00H0k?Og0?Ogm`3eool0i?Cg0?Ofm`3gm_l20?ooo`0;0??bm`3gm_L0moKg
0>cfk03Rm_@0oooo0?Ogn03cm?@0j_Oh0?Goo`3oool00`3eool20?ooo`80k?Oh00h0hnk_0>?^m`3g
mol0oooo0>cgl03gmol0k?Ch0=[_n03gmoP0j_Oo0:Z_[@1WC440dKVl0?Ogn480oooo000b0?ooo`0K
0>_Pj@2`WI/0dM7;0=SId`3RfM/0mooo0??gn03gmnl0hoOo0?Ogn03/knl0mooo0>c]k@3gm_P0k>GW
0?ooo`3^moP0jng^0??dm03gmoP0mOOg0>cgm`3cm_P0j^c]0>?Vi`3Nh>P0f]gW0080jn_^00L0oooo
0?Ofn03emol0j^g_0>c_k`3gm_P0jn_^0080lo?d00h0jnKY0>GTiP3RiND0mOOg0??dm03gool0ooCd
0?OTkP34cmd0dNC]0=7IiP3NooP0l^c^0?OUi`<0oooo00@0g^g_0?7gm03oool0lOOd0P3emoL0603Z
k>`0moKh0?;fm03Uk>d0moO_0>kgn03RkNd0k_Oh0?O/j03Abm<0mnkh0>_]i@3gm>d0k_oo0>_oo`3o
mnl0f^G`0>[Vj03elo@0fOCg0>;dm`3emoL0moKh0?O/kP80ooOh0P3gmoP01`3/m_l0k>cd0?Ooo`3c
ool0j^kh0?;^n03ek_P00P3Rh>h0103SiO00k_Oh0?7Vm03ai_@40?ooo`80mOKd0P3/k_P04`3oool0
ooKh0>c^n03Zk?P0h^3^0>kgn03oool0lNKd0?G^n03gmoP0k?oh0>[/n03/k_P0mNkh0?ooo`3Zk_P0
oooo0>kdm03^ko000P3eool01P3oool0j_Og0?Goo`3/moL0j_Og0>_[m`<0oooo0P3cl_L01P3gm_l0
h_Kh0=[go`3gmoP0j_Cd0?7oo`80oooo00@0mOoo0?ooo`3eool0mOoo0P3oool20=k/k@0=0>?^i`3/
mo00lOoo0>[gl03oool0hno`0=;]m03RgMl0i=CF0;Fh``1mJe40Y8230?ogn0130?ooo`005@3oool2
0?ogn1/0oooo00L0k^C^0<Ff_02`]ZX0f]cC0=KAd`3gk_00joOh0080moO_0P3ZkN`0403gmoP0loCh
0>[/i@3blo@0mNg]0?odm03gm?@0mooo0?Ogn03cm?@0k>o_0?7dl`3emoL0j^o_0;k<eP3Zind20?oo
o`080?Ofn03oool0j^_d0>;Ti`3gmnl0j^g_0>c_k`3cjnh20??gn00X0?Ooo`3ZkNd0hno_0??oo`3o
moP0moOh0?OUl031b=H0_/WK0>GTkP3Ni?00e^ch0>_gk03gmnl0hooh0>;gk@3Nh>40j_?g0?ogk`3a
m?<0oooo0?7dl`3Zk>`0k>k_0>[Vj03Fh>P0k_og0??dm03/knl0l_Og0=kPh@3/knl0f]gO0?Odk@3^
ooL0moOh0?Ooo`3em>`0fNcd0>[[k@80mOKd0P3[jo@01@3cjnh0moKh0?odm03^moP0k^g^0080ooCd
0100ooOh0?ooo`3oool0oooo0>_gn03SmoP0looo0?Oon03ek_00mNc]0?7Pi@3bk_P0i>Kd0>c^n03o
ool0k>kh0P3Tk?P02`3/k_P0j^kh0?7Vm03Zlol0k?Ch0?Ooo`3cool0k>kh0?G^n03gool0looo0080
moOh0140oooh0?G^l03Zk_P0j^kh0>c^n03^moP0i^g^0?OVi`3/moL0oooo0>[gm`3bmoL0moOg0?Go
o`3bmoL0jncg0??cm0020??dm0030>k^n03oooL0lo?d00<0moOh00@0k?Oh0>[gn03eool0lOoo1@3o
ool03`3eool0e^3X0=KPj03Zmo00mOo`0>kgn03Rmo@0iOC^0?;go`3;iNh0f=CF0>_dm01oR900T6aM
0=W<i@140?ooo`005@3oool20?ogn1/0oooo00L0ooOh0=72eP36_K80al_50<O4cP3IdM@0looo0080
loCd00L0j^g]0?Gon03gknL0oooh0>c_k@3bmoL0j^g/0080oooo00T0moCd0>[gm03Uk^h0hnCV0>_]
kP3ZkNP0mnoW0>;_k`3IgMl00P3^k_002@3/koL0hnG_0>_cm03Uk_00k>kh0>[]k`3/knl0mnk`0>_V
j@020=;Dg@0G0>KVj@3ck>h0ooOh0??^n03giO00k^cd0>;Li@3NcM<0ooO/0??Ti@3[k?@0joO/0>ko
m`3Jm>l0h_oh0=SKg03Fi^d0k_og0?Ggm`3am?<0mOOg0>[dl`3/moL00P3Zk>d03@3emoL0loCd0?oo
o`3Ri>D0moKh0>[PhP3Sg=h0f^kh0>_gm03omnl0k^oW0>;]k03bm_@00`3/m_l01`3cm?l0loOh0?oo
o`3gooP0loCo0??dl03gooP00`3^moP30?ooo`0=0>Kdm03^moP0k_Oh0>_gm03Im?P0f]gO0>c^k`3U
m?@0k_Oh0>c^n03TjoP0k??h0?ogn0020?ooo`0:0?Ooo`3SmoP0jno`0?Ogn03gool0oooo0>_gn03S
moP0mooo0?ooo`80k_Oh0P3gooP20>kgn0030?ooo`3Vm?@0oooo0080j_Cc01@0lOoo0?Ogm`3oool0
loCc0>k^m`3[k?<0loCo0>_[k03gmoP0oooo0??dm03gm_L0lo?d0?Goo`3Zm?@0loCd0?Ogn03Zm?@0
lOoo0?Goo`@0oooo0100k?Oh0>;/k@3Ii>l0fNC_0?ooo`3^moP0hoOh0=[_n03IkOP0h_Ch0=[dm03A
fM/0_/_?06M<C03A^K@0moOhA03oool003<0oooo00H0g/gK0=K6_@33e</0h^7U0=76_@3[k_P20??g
n0070??dm03omnl0ooO_0?Ogn03oool0hno_0>cgm`020>k]kP090?ooo`3emo00g^GV0?Ogn03^k_00
h_Ch0=7Qi@3FfM/0mooo0080c]WK00D0a<WC0>GWk@3Uk_00jo?d0?Ofn0020??bm00[0>_[kP3Vi^T0
e]WR0=KIhP3[i^T0k^c^0??gn03[k_P0mnkh0>?Ul03/ooP0e]CF0>Kgm03cm>d0moO_0?Ogn03Smol0
hno_0>;]k@3Zk>d0h_?h0>;dm`3am?<0mOOg0?ooo`3/m>`0l_oh0?Ooo`3ok_00i>3Q0?ogk`3ckND0
g]WK0>CPh@3/i>40j_Kh0=KIh@3gmoP0mOC/0?7gm03/k^l0iN_h0>[/n0020?Odn0070>;_kP3Rmo@0
ooCd0??do`3gmo00loCY0?Ogl0020>_gn0<0k_Oh00h0i_Cd0?ooo`3[moP0g_Cd0>Kdm03eool0f_Oh
0>__l03^m?@0oooo0>kgn03omoP0ooCd0?ogn080oooo00<0k_Oh0?ooo`3^moP00P3[moP0103oool0
k_Oh0>kgn03oool20>kgn0080>Kdm03^moP0i_Cd0>kgn03[m?@0jng]0>kgn03/moL20?ogm`0C0>[d
l`3cm?<0moOg0?oom`3gm_L0moOg0??cl`3[jnl0moOh0?Goo`3Zm?@0oooo0?Ogn03eool0moOh0?;g
n03oool0j_Oh0?ooo`020?Goo`80oooo0P3/moP03P3[jo<0l_Oo0?;go`3^moP0hno`0>?dm03IkOP0
f^oh0>cgo`3:bmH0XYFD091mLP2TP800ooOhA@3oool003<0oooo01X0i]_Y0=k>b02i`K`0dMCF0;jh
Z@3FfMh0mooo0>kgn03gmnl0joOd0?Ogn03oool0jng^0>__l03/m?@0fNGU0>;dn03emo00mOOg0>c_
k`3SiNP0k_Oh0??bm03gm_P0k^k`0<C?d@80`L[;01P0oooo0=WLgP3Si>H0k^k`0?Ogn03oool0moOh
0>k_l03ZkNd0g^3Q0=SKg03Ii>D0loOh0?Ooo`3cool0moOh0>CIiP3Sh>T0fNSQ0>kdk@3cm>d0loCX
0>kol`3SmoL20?Ggm`<0lOCc01@0l_Og0>cgm`3em?@0mNgU0>con03bmoL0iN3U0<_?eP3Uj>40j_Od
0?G/k@3bmo@0hnko0=SPk`3SiNl0g^C/0?;gm`3gk_00k^cd0?ogn080mooh00P0moOo0?Gol03eoo00
i^gh0>_]j@3gmo00mOoo0?7oo`80oooo00<0mOoo0>kgn03oool00P3^moP02@3[moP0k_Oh0?Goo`3S
moP0oooo0>?gn03^moP0g_Cd0>?gn0030>Kdm0060=kdm03SmoP0i_Cd0>_gn03SmoP0i_Cd0`3^moP0
0`3Vm?@0k_Oh0>kgn0030>kgn00=0?ooo`3/moL0hooo0?Ogm`3oool0j_Og0?Ggm`3/ool0oooo0>k^
n03[joP0moKg0?ooo`020?Ofm`0<0>_[k`3gmoP0lOoo0>Cdm03oool0lo?d0?Ofm`3bmoP0moOh0?Go
o`3Zm?@0k?Oh0P3eool00`3oool0k?Oh0>cgn0020>k^m`80k?O`00X0h^o^0>?gn03Ji_00mOoo0=K]
m03[kNd0PhZ=09VGP`2/V9d0f/cGAP3oool003<0oooo01L0k^G`0=[<e`37a;h0dMC@0=K<a03AeMH0
fMgW0>_dm03^ooL0joOd0?Ogk`3^ooL0jng]0?;]k@3NkNd0j_Cd0?;gl03/mo@0k>g]0?ogn03akN`0
fMWK0=KIg@020>c_m`060?oon03UinP0iNOX0<_?eP2n`m40k>kh0P3Ig=h0<P3^ko00h_Ch0?;dkP3I
fmd0a<S;0;k1aP3Be=L0moOd0>_dn03Vm?@0k_Oh0>[Kj@3=b=H0h^3U0=[/k@3[mo@0jnoU0=kdk`3[
m>`0ooO_0?ooo`3/moL0j_Cc0?Ggm03Tm>`0j_Og0>c]k@3TfM/0mnk`0>Cdl`3Ni>`0fNg_0??fn03R
inP0j^k^0=kVn03RiNd0j^k]0?Ogo`3ci_@0h^GX0=k/m03oool0hno`0=[_n03oool0g_Cd0>?gn03^
moP0mOoY0P3aool00`3eool0oooo0?Goo`020?Goo`030?7oo`3RmoP0joOh00<0mOoo00L0g_Cd0>Kd
m03eool0mOoo0>kgn03eool0joOh00<0k_Oh00h0h_Oh0>?gn03Iknl0joCd0?Ogm`3/moL0joOh0=kd
m03ZkN`0joCd0?ooo`3^moP0e^gd0>[go`80mOoo0P3bmoL02@3ZmoL0k?Og0?Goo`3/moL0moOg0?Of
o`3cloP0oooo0>_/m0030>_[k`0C0?Ofm`3Zm?@0mOoo0>[gn03Zm?@0h^c]0?Ofm`3bmoP0mOoo0>cg
n03Zm?@0j_Oh0?ooo`3/moP0i?Cd0=[Uk`3Vi_<0moKg0?;go`020?Ogl0090=7PhP3Vind0g^g`0>G]
l03^moP0VJ2T04H`<@2OPXX0f/cG04L0oooo000G0?ooo`80ooOh6`3oool06@3^i>h0fM7K0;Fj]@2n
^Z`0hncN0=KIg@3SiNP0l_Cd0?Ggm`3[mo@0loC]0>c_k`3bm?@0jng^0=KIf`3Zi>D0j^SX0?;]k@3e
moL0l^o_0??fn02n`LP0dN3]0>?Uk`3/koL00P3oool05P3/koL0j^gg0>?Tj03Ae=H0ooKd0=KUi@3R
hM`0f>GW0??bm03/knl0i>S/0>?Uk`3Si?00iNG^0?ooo`3Vool0mnG`0;Zmb@3[inh0k>cX0?Ggm`3a
mo@20?Gon00P0>[cm`3/k^l0i>c/0>[cm03emo@0k?Od0>cgm`3cm?@0f<oA0?o/kP3Uh>d0k^Gh0>GP
k@3:cM`0f=WK0>[om03Sk_l0lood0>kdm03RkO00h^GV0=k/n03bonh0k_Oh0>?_l03gmol0g_Cd0>_g
kP3ooo00lOoY0?Gol03oool20?Ogo`040?ooo`3gmoL0loCg0?Ogo`80oooo00T0mOoo0?ooo`3oool0
mOoo0>kgn03SmoP0j_Og0>cgm`3oool00P3^moP07P3Um?@0k?Og0?ooo`3[moP0mOo`0??dl`3Jknl0
hoOh0>;dm03SmoP0loCc0>?oo`3Jknl0joCd0>kgn03FkOP0moOo0>[go`3aool0moOg0??dm`3gmoL0
k?Oo0>cgm`3aool0loCg0?Ofl`3[jo<0hnC/0>_/k@80oooo01@0moOh0?ooo`3Zm?@0lOoo0>cgn03Z
moP0mOoo0>[gn03oool0k?Oh0?ooo`3eool0oooo0>[gn03Sk^l0jn_c0>k^m`3oool0l_Oo0=[Vl080
g^g`00P0l_Kg0=7Uk`3omoP0k?oo0:C1c01<CT@0/ifK0??XjDP0oooo000G0?ooo`80ooOh00<0oooo
0?ogn03omoP0603oool06@3omoP0g]7N0>?Lf`2oZYd0_[2S0<O<a@3>dM@0j^g]0?ooo`3/knl0moOh
0??dm03oool0k^g^0>GPhP3elo@0l_Og0?Ggm`3gm?@0hno_0>[Ui`3gk>D0h^GR0>?TiP3[jnh00P3c
l_@06@3gm_P0oooo0?ooo`3UiO00b]CK0<CEeP3:eMH0h^GU0>_/kP34b</0]kg50<[=e`3Be=/0hnC]
0>kom`3gmo@0loCd0;S8b`3Bi>h0mNGW0?7gm03eooP0lOOd0?Ggm`3cl_@0103/k^l05@3oool0mOOg
0>c_k`3>cM`0k^oo0>kdm03NfnD0fM_]0<_Di`3Zmo@0g]_]0>[dl03Nm>h0mOo`0>;dn03cmo@0j^oN
0>_gl03gmo@0joo^0=Sdm0020?Gol00=0?7oo`3oool0mOoo0?Goo`3gmol0oooo0??dm`3oool0moOo
0?Ogm`3cm?L0moOg0?ooo`020?;go`030?Goo`3aool0oooo0080j_Cc01<0mOoo0?ooo`3oool0i?Cc
0=W]k03[moP0k_O^0>;gkP3cm?L0ooog0?Ogm`3bk>`0mNk_0??dl`3oool0hooo0>Cdl`3aool0moOo
0080k?Og01@0moOo0>[dm`3gm_l0lo;c0?Ofo`3Zm?L0mOoo0??do`3oooL0loCg0??do`3gm_<0k^kh
0?ooo`3gmoP0oooo0>[dm03eool0moOh0>[gn080oooo00`0k?Oh0?ooo`3Tm?@0k?Oh0>[gn03^k^l0
k^kg0?ooo`3cm?l0l_Oo0>?_l03eool20?Odn0080=K]m03^moP0iOCd0:bb_P2/Ug/0NeaH0>;IhP3g
kNi80?ooo`006P3oool20?ogn1T0oooo00L0k^G`0>;Ij03^k_00b;^/0;bjY02m/:h0joOh0080mOOg
00<0loCd0?Ogn03cm?@00P3gool02P3Sknl0mooo0?Ggm`3gmoP0moCd0?Ggm`3eknl0l_Og0=k]k03I
iND20>_]kP030>k^l03cl_@0moKh0080oooo00@0moKh0?ooo`3^k_00joCd0P3ekNd04`3gm?@0j^g/
0?7dl`3[mo@0ooO_0??gk`32cmL0jno`0>[cn03Zl_P0j_?g0?ogk`3emoL0k>k_0??cn03cm?l0mo?h
0>[cm03am?<00P3emoL04`3Bfo@0i_O^0>kgn03UiOP0looh0>[om03/i>40e]CQ0>;dn03/mo00h_O^
0>_dn03ZmnD0mood0=K]kP3[m>H0k_Cd0?Gol03SmoP00P3eool0503gmol0k?Oo0?Goo`3oool0loCo
0?oom`3gmoL0moOc0?oom`3oool0moOo0?Ogm`3gmol0oooo0??do`3gmol0lOoo0>Cdm`3gmol0k?Og
0P3aool04P3gmoL0mOoo0>cgm`3Nm?@0f?Cd0>_/m`3clol0moOg0>[bn03Ujo@0oooo0?Ogm`3oool0
j_Cc0?Goo`3aool0i?Cg0?ooo`80j_Cg00d0moKo0?Ofm`3gm_L0jncg0?ooo`3cm?L0oooo0?Ogo`3g
moL0ooog0??bm`3gmoP0mOoo0080k?Oh00<0j_Cd0?Ogn03aool00`3oool02`3Tm?@0oooo0>[cm03R
jn`0k^kg0?ooo`3gmol0k?Oo0=[Vl03eool0f^K`0080fNoh00H0k_Oh0?Ooo`36g>D0VXV@08IeJP2/
X;h20?ogn4P0oooo000f0?ooo`090>?DgP3Rh>d0hmcQ0;Fi[`2KShH0hnC^0?;dm03[mo<0moO_0080
moOh00`0k^o`0?ogn03omoP0i>O]0>c^n03am?<0mOOg0?ogm03akNP0h^KW0<_Lg03Uj>P20?Ogn00C
0>_gn03VkNh0hnCV0>k^kP3/ko@0k>og0??bm03Rm?P0jnk^0=WVj@3Ok>h0l_Od0>cXh@3emoL0k>gX
0>_]i@3Nkn`0b=WS0>k]kP020?ogn00U0>[[k@3[mo<0k_og0?7dl`3Vi_@0mooh0?o^l03[k_P0moKh
0??fn03gool0iNko0??^kP3cmoP0joOd0>k^j@3ViNh0fMWX0<oIf`3Zmnh0i?CY0?Gol03eonT0k_Oh
0=K]kP3cm?l0l_O`0>GdkP3gmol0k?O`0>?gn03oool0moOo0?Ofm`3[k?L0loCo0?Ogo`020>cgm`80
ooog00<0moKg0??bm`3^k_<00P3gmol04`3cm?l0k?Oo0?ooo`3bmol0lo?c0>k^m`3gmoL0oooo0?Go
o`3Zm?L0moOo0=W_k`3[moP0h^cW0?Ogo`3gm_l0k^kc0?Ofm`3cm?<00P3gmoL03P3/moL0moOg0?Go
o`3Tm?L0ooog0?Ogl`3^k_<0lo;g0?Ofm`3oool0k^kg0>_/m`3gmoL0moKo0P3cl_L00`3cl_<0moKg
0>cgn0020>cgn080j_Cd0100j_Oh0?Goo`3oool0oooo0?Goo`3Zm?@0oooo0??bl`3gmol0oooo0?Og
m`3/moL0f^K`0>cgm`3RkNd0h_Ch0P3FkO@01@3UiNP0f^3R0:2HU@1mDT/0_ZZU0080mno`B@3oool0
00h0oooo00<0ooCd0?ogn03oool09@3oool0403omoP0i^3`0?7Xh@3Sg=L0PH=T0>?Ul03Ig>D0k_og
0>;dm`3ZkNd0moOh0>k_l03omoP0k_Oh0=WMn03bk>P20?Ggm`050?ogm03eknl0jngd0>_]kP3cm_P0
0P3Ok>h04`3^moP0ooCh0?Ogo`3Nh>P0`LKC0=WKhP3oool0f^kh0=W[m03oool0j^c]0<OMi`3RiN80
lOCc0?Ock@3Zk^d0ooO_0=WPj@3^m?@00P3omoP01@3gk_00f^kh0>_gl`3am?<0i^Kd0080lood01h0
g^3]0=kVk`3^k_l0j_?d0?Ggm`3Vi_@0mooh0>kol03gk^h0k^CV0>?Tj03Fi><0j_O`0?;on03emnP0
lOoo0?ooj@3Um>h0hoOh0?ooo`3SmoP0f>g^0>?gn03Um>h0mOoY0?Ogl03cloL0oooo0?Ofm`3oool2
0>cgm`060?Ofm`3gm_l0lo;g0?ooo`3gm_L0jncg0P3oool20?Goo`0L0?Ogm`3cloL0oooo0>k^m`3g
moL0oooo0?Ogo`3gmoL0k?Oo0>Gdi@3Iknh0i^K/0>?Tk03gmol0moKc0>_[m`3^k_L0loCg0?Ofm`3R
k?<0lOoo0>[dm`3oooL0oooc0??bl`3oool0moKg0??bl`80moKg00@0jn_/0??cm03oool0oooo0P3/
moP01@3Tm?@0mOoo0>[gn03Zm?@0j_Oh00<0oooo00D0mOoo0>cgn03gmoP0moKo0?Ofl`020?Ogo`06
0>?_k@3Ag=/0lo?^0=k]i@3@g=L0h^OY0P3om?@0103Ii>D0_/C6075IF02/Ui`20?O_l0030??Xj@3o
ool0oooo04L0oooo000>0?ooo`030?odm03omoP0oooo02H0oooo00X0k^Gh0>;AeP3cm?P0Shmf0=WD
``3>dMH0k>o_0?Ggm`3ZkN`0loCd0P3gmoP02P3[kNh0k_Oh0>?Vi`3em>d0ooOd0>k_l03^kOP0k?O]
0=k]k03Ag=h20=oWj@070?ooo`3VkO@0gn3Y0=WLf`3emo00g^GU0<kIf`020=oPj@0A0=WPh`3AgMl0
h^CU0=KQhP3Zm?<0l_?d0>cfo`3gm_P0f^C^0>Kdm03^moP0oooo0?odm03gm_P0k>k_0?Ggm`3Vi_@0
0P3coo@07P3Nh>d0g^cg0?Ofm03Ri>d0k?Og0=WPiP3bmnH0lood0??/n03Vh><0l_O`0?O^n03^iNP0
l_CS0>cdkP3ooo00lOo`0>?gkP3>i>l0k^kg0?Ogo`3cloL0f^GW0?;gj@3aonT0moO`0?Ogo`3gm_L0
oooo0?Ofm`80oooo00T0moKg0?Ofo`3cl_L0oooo0?Ogn03UiNl0jncg0??dm`3cm?<00P3gmoL07@3g
mo<0lo;g0?Ofo`3[joL0i^Kc0>_/l`3gmoL0ooog0=[_n03gmoL0a]WU0??cm03cloL0k^kg0?Ofm`3[
joL0ooog0>k^l`3clo<0loCo0?Ogo`3gm_<0lo;g0?Ofm`3oool0moKg0??bl`3gm_L0oooo0080moOh
103/moP01@3Zm?@0oooo0>[dm03gmoP0j_Oh0080oooo00T0k?Oh0>;/k@3[jo@0lo;g0?Ofl`3oooL0
moKg0>[cm`3IkNh00P3Zk>T00`3[mnT0iNCN0<kIf`020<_Qi@040:c3c@27MF/0Sg]k0?ooo`<0mno`
B@3oool003P0oooo00/0hmCN0=[Df`2SV8/0h^3F0<kIeP3SiO00hno_0?ooo`3[mo<0k_og0?ooo`02
0>k_l0080>_cm03UiO00oooh0>k]kP3oooP0f^KW0>[gk`3bmoL20?G]k@0J0>Kdm03gm_P0oooo0>;c
n03HiNL0fN7Q0?Ogn03am>`0mOOg0>k]l03Sjnh0lo;d0=7Lg03/moL0mOOg0?;fm03/m_l0i^SY0>kg
n03gmo00joOd0>k_l03om?@0j^_`0?Gon03Vi_@20??om00D0>_/n03^jo@0onk`0??/l03Vh?@0iNCS
0>_dm03RknD0loC`0>k_l03Zmol0dMWS0=kPkP3gmol0l_O`0?7oj@3oool0l_Oo0>[cm`3oool20?Of
m`070??cm`3/mol0mOoo0?Goo`3/mol0moOo0??bl`040?Ofm`030?Ofl`3gm_l0oooo0080moOh00@0
lo;c0?oom`3gmo<0ooog0P3gmol01P3[jo<0oooo0?ooo`3oool0moKo0?Ofm`80ooog00d0fNgd0=k/
m03^k_L0jn_c0?ooo`3[jo<0moKo0>k^l`3gmoL0oooo0?Ofl`3gm_L0lo;c00<0oooo0P3gmoP20?oo
o`040?Ogn03cm?@0l_Oh0?Ogn080j_Cd00T0j_Oh0?ooo`3bmoP0k?Oh0?Goo`3oool0k?Oh0>?^k`3g
m_L00P3oooL02P3gm_L0lo;c0>?_l03Ai>P0k?Oo0>_dn03^moP0fNo_0>[gm`3[m?@209^^_00609J?
O02HLfX0hmGO0??Xj@3gmoP0mng^BP3oool000l0oooo0P3omoPW0?ooo`0E0?ogn03Sg>h0V7eo0=[;
_P3@g<d0f]GF0>GTiP3Si^L0k_og0?;dk03cm?@0moOh0>_]k@3FfM/0mo?d0>k]l03oooP0iNg]0>G]
j03em?L0lNg/0080mOCd0340k^g^0=oPh`3[k>h0oooo0>?go`3[mo@0lNSX0?Ooo`3/mnl0g^GQ0<CE
eP2ea]H0d]7G0>[Ui`3cmoP0h^GU0>cfo`3Vj>T0i_Cd0>;gm03RknL0f^o_0>Kdm03Fi>h0g^GV0??[
m03omoP0oooo0?Odn03cm?l0lood0>Kdm03cm?l0lnc^0=KLgP3gooP0i?C]0>__l03Ii_00h^g`0?Gg
kP3Nm>h0j_C`0>_dn03Rm?P0k^kg0??cm`3[k?L0lo?g0080moKg0P3gmol20?;go`030??do`3gm_L0
moKg00@0moKg0`3oool0103gm_L0oooo0??bl`3^k_L20?Ogo`0I0??do`3gm_L0jn_c0??cm03gmoP0
oooo0?Ofo`3cl_L0lo;c0>k^m`3cm?l0lo?g0?ooo`3[jo<0oooo0>KVl`3gmol0lo;c0?Ofo`3cl_L0
moKg0?ooo`3Zlo@0k?Oh0?Ogn0020>cgn0030?Ogn03/moP0j_Oh0080lOoo0`3eool0103oool0mOoo
0?;gn03Uk>d20=SVj00?0>;[k03gm_L0moKg0??bl`3gm_<0j_?o0<[Pk03[k_@0h_Od0=7]m03eooL0
joCd0<_PhP2C_/P0Ojk50080JFeS00H0OVeS0=[;eP3cj>T0oooo0?O]kP3omoQ:0?ooo`003`3oool2
0?ogn2T0oooo0140/jJd0;FQW@3Je<D0d=cN0=WTi`3JgNP0hnKW0?Ogn03/knl0loOh0>?_k`3emoL0
jng^0?Ogo`3^kO00j^g/0>[dl`020?ogn0<0oooo0140ooOh0>Gdm03FhN80jngY0?Ggm03bknl0h^SX
0>[]k03ZmoL0oooo0>_Vn03[onh0onc^0=kTi@3Si>40k?Ko0=kXj@020=kdm00M0>cgm`3Rool0moOg
0>cgm`3Ig=/0lnch0?Ogo`3cmnh0k_O^0??dl03cmoP0k_Oh0??dl03ck?P0oo?]0<_Qc@3gmoL0dNG^
0=kdm03bm>P0fNoh0>Gdn03/mo00fNgh0>;dn03Vi^`0hnC/0?Ogo`3cm?l00P3cl_<01@3oool0loCo
0?Ogo`3gmol0loCo0080moKg103oool00`3gm_L0lo;c0?Ofm`020??bl`090?ooo`3gm_L0lo;c0??c
m`3cm?l0moOo0??do`3[jn`0moOh00<0oooo0P3gm_L20?ooo`80moKg00@0k^kg0>_^k@3Sk^80jn_U
0P3oool02@3clo@0k^k_0>[cm03eool0moOh0?7oo`3eool0k?Oh0>[gn0060?ooo`070>cgn03Nk>d0
h^_/0?Ofm`3gmo00loC`0?Ogo`030?Ofm`0;0>?^i@3gmnd0g_Ch0?Ogo`3oool0hoOh0>;dm037gNL0
a]gU0;GDi@3SiO000P2CJDP0103RdM/0mno`0?O_l03gko1<0?ooo`00>P3oool04`3^iO00/jRe0<R`
VP3Ng=H0jnoW0>;Ti`3Si>H0k>o_0>[]k@3gool0loOh0?Ogn03Zm?@0fNGU0?ogn03SiND0k>o_0?Og
m03/mo@00P3/moL0>P3oool0ooOh0>Gdm03Nj>P0moCd0>cgm`3Nj>P0j^g]0>cUi`3Ji?@0i^3h0>;T
j03Rmo@0k>cd0=[/j03Ik>`0moKh0=kXj@3[moP0hoOh0>cgo`3Rmo<0j_Cc0>[gm`3FkNP0mooh0?oo
o`3cm>T0mOoo0>cgl03gmnT0mOo`0>cgj@3UkO00g^O@0<7AaP3gmoL0fNg_0?G/h`3Ae=L0hnkg0>[g
l03bmo00ooog0?Ogm`3Si>l0k^k_0??do`3cm?L0lo;g0?Ofm`3cl_<0jn_c0>k^m`3gmol0k^kg0?oo
o`3gm_L30?ooo`0:0?Ofm`3oool0lo;c0?ooo`3gm_L0lo;c0?ooo`3gm_L0lo;c0??cm`<0moOo00<0
moKg0>[cm03/moP00P3/moP01@3cl_<0oooo0?Ofm`3gm_L0oooo0080moKg00`0h^_U0?OdkP3ZknP0
hnkW0?ooo`3clo@0mOoo0>[dm03/moP0lOoo0?Goo`3oool20?7oo`@0oooo00@0k?Oh0=k/k@3Ii>`0
jncg0P3cm?l04@3gmo00k^kW0>_[l`3oool0jn_c0??cm`3Zm?00k?O`0>?gn03/mol0joOh0>;_l02n
g>H0a=cU0=[Mg`3Ii?00mOC]0080Pe@o00<0moKo0??/l03gko00C@3oool003/0oooo0180f]CU0:bM
W`2n`K@0hnkW0>;Uh@3SiNh0iNG`0?Ggm`3/knl0oooo0??dm03Ji^L0mooo0>?Ui@3^kNh0moCd0?og
o`3Ih>P20=kPhP0M0?odm03gm?@0loCd0>?go`3bmo@0e^GU0<_Lg03UkNP0k>kU0=KPh@3FfNL0hnGX
0=kdm03Th>D0jnoW0=KWj03gm_P0k^g^0>kgn03aool0moOo0?Ogl`3Zm?<0mOoo0>;gn03[m>h0moO`
0??gkP3RmoP00P3eool04`3aool0lOo`0?7ol039e=00dMCM0>G/i@3[k?<0g^CS0<C<eP3gm_L0k^kc
0?Ogm`3[k?<0k^kc0?ooo`3cloL0k^kg0?Ogm`3gm_<00`3gm_L01@3^k_L0lo?g0?Ofm`3gm_L0lo;c
00<0oooo0P3gm_L0103oool0lo;c0?Ofm`3oool30?Ofm`0;0?ooo`3cm?l0h_Ch0=KXiP3/knP0hnk_
0?Ofm`3oool0k?Oh0>[cm03Sk^l00P3gm_L02P3oool0moOo0>_/k@3gmo00h^CM0=kWg@3eool0jn_U
0?Ogn03ZmoP20?Goo`<0oooo0`3eool0203ZmoP0i?Cd0=k/k@3Rjn`0k^kg0>cgl03eoo00moOo0P3c
m?l01@3clo<0lo;g0?Ofm`3cm?l0h_Ch0080dNgd00T0k?Oo0?Ooo`3Bi>h0aMcX0=[^n03NkO<0fMcS
0>?]k@3@^jD00P2?N7P00`3[k>d0k^G`0?ooo`1=0?ooo`00>`3oool02@3omoP0c[S50:fPW@3Ne;h0
jm_:0>coo`3SiO00e]WQ0>[]k0020?Ogn0070>_]kP3am?<0lNg/0>kgn03^mo@0l^g_0=[Mg`020?Oo
o`050=o/kP3gmoP0looo0>?on03bm>h00P3Vj>T0303^mo@0ooCo0?ogn03Fi>`0mncd0>_gm03Tfm`0
moOh0>[Wh@3/loP0k^o`0>kgn080mOoo0P3cm?L01`3gmoL0j_Cc0>cgm`3cm>T0mooh0=kdkP3oool0
0P3bmol20?Goo`0A0>?Uj03[k_00f>3F0>_[l`3Rko00f>O]0??bm`3oool0k^kc0??cm`3oool0jn_c
0?Ogo`3oool0moKg0?ooo`3gm_L00P3oool0103Zlo@0h^_/0?ooo`3oool20?Ofm`050>cgn03Tm?@0
k?Oh0?ooo`3gm_L00P3oool0403gm_L0lo;c0?ooo`3cl_<0oooo0??dl03Rm>H0onk`0=[Mj03Tj=h0
d=gG0>[cm03oool0k?Oh0>[cm03gm_L20?ooo`0<0?Ogo`3cm?00moK]0>_[l`3oool0jn_U0?ool03O
h>`0e^3X0=SVj03Nk>d0i?Cd0P3ZmoP20=k/k@0K0>;/k@3[jn`0jn_c0>_/i`3cm?00k?O`0?Ogo`3Z
m?00k^kg0??cm`3gmol0ooog0?Ogm`3IkOP0f>g^0>[gkP3[mo@0i_Cd0?ooo`3IiO00hnG`0>kgn03/
moL0h]CF0=k^k@3gi=80/9Z60080`Zje00<0onoW0?ooo`3oool0C@3oool003`0oooo00T0k^G`0:bZ
_P2NXId0_[:U0>kPc`3ZkNL0e]WN0?Ogn03/knl00P3gmoP01P3/kNd0ooOh0>?Ui@3^m?P0mNo_0?Og
o`80e]WK01h0fN7R0?ooo`3emo@0iOoh0?Ogn03omo@0oooh0?ogm03ekNl0j^CU0>Gdm03gk?@0iOC^
0<gDeP3gmoP0mnoW0>CPi@3Nm?@0l_O`0?Ogl03Zmol0moOg0??dm`3cm?<0ooog0>[dm`3/mo00loCY
0?;gl03eool20??do`<0moOg00X0j^oO0=SPg@3gm_L0hnkg0?Goo`3gmoL0moKg0?oom`3cloL0k^kg
0P3gm_L00`3oool0moKg0?ooo`020?Ofm`040??bl`3Rjn`0j_?d0?Ofm`80oooo00D0lo;c0>cgn03T
m?@0k?Oh0?ooo`060?Ofm`040??bl`3oool0moO`0>[]iP80i^c_00@0f^Gg0<OEg`3SiMl0moKg0P3o
ool20?Ofm`<0oooo00D0moOo0?ooo`3[k>d0i^KU0?Ofm`020?Ogo`060>[do`3Rk>d0i^KU0=oPk03V
i^`0k^kg0P3[k?L20?Ogo`0H0?Ogl03eool0moOo0>cgi`3oooL0lo;c0>KVl`3cm?l0moOo0>?_l03Z
mnh0k_Oh0>;]j@3Zm?00k^o`0=[TkP3/k_P0k_Oh0>Gdm03AgNL0e]cR0?;gm039]ZT0^J>A0P3NcM]@
0?ooo`00?@3oool0403^iO00b;:f09FHW@3FbkD0d=WF0=[^n03JgMl0l_Cd0??dm03gmoP0ooOh0>c_
k`3emoL0ooOh0?ogo`3bkNl20>cXh@0E0?;on03FhN40lncU0=;VkP3Ii^T0hnG`0?O]i@3^j>80hn7L
0>[Lb`3Zlnd0iN3^0=kdm034cM00oooo0?Ogn03Th>40g^g^0?;gl03gmo00j_Oo0080moOc00@0ooog
0??dm`3oooL0k?Og0`3eool00`3gmol0oooo0?Ogm`020?Ogo`0>0>cgm`3ZloL0moKg0??bm`3Zm>d0
j_C`0?oom`3cl_L0jn_g0?Ogm`3gm_L0lo;c0?ooo`3cl_<40?Ofm`090?ooo`3Zlo@0hnk_0?Ofm`3o
ool0moKg0>[cm03Tm?@0k?Oh00<0oooo0P3gm_L03@3oool0lo;c0?Ofm`3gm_L0moOo0?Ggj03FhML0
jn3h0?Ggl03UiNP0Z[[40=7LcP3[jo<00`3gm_L01P3oool0moKg0??bl`3gm_L0moOo0??dl0<0moO`
02<0ooo`0?Gol03eonT0ooo`0?ooj@3gmo00moOo0?ooo`3gmol0hoOh0=KXiP3IkNH0k_Oh0>[dl03g
m_<0lo;g0?Ogo`3AgNL0dNG^0=7]m03booP0h^gY0=k]i`3^mo@0a=c^0<GLj03UloP0oooo0=[_n038
gND0fNC^0?ogn03ci<l0/9Z80<F`[@020>kUl500oooo000n0?ooo`0?0?O_l02/ZKd0W8f90;FQQ03?
fLl0d=cO0=WLiP3cm?@0loOh0?Ooo`3omoP0moCd0?Gdm03aj>P0k>o_0080l_oh00<0g^g_0<_Lg03I
iND00P3Ijo@07@3clo@0i^kX0?Oci@3omnL0i^o]0>?Ui`3ZgMl0onKY0=SIf`3cm?@0oooo0>[/k03S
i>P0moO`0>kgn03Smnh0k?OW0?Ogm`3gmol0loCo0?Ogm`3clol0hnkg0?ooo`3eool0moOo0?Ogm`3o
ooL0oooc0080ooog00h0moOo0>_[l`3gm_l0hnkU0?Gol03gmol0lo;c0??bm`3oooL0moKg0??bl`3o
ool0moKg0??bl`80moKg01<0oooo0?Ofm`3Zlo@0oooo0>?^k`3gm_L0moOo0=[Uk`3Nk>d0oooo0>Cd
m03/moP0oooo0?Ofm`3cl_<0moKg0??cm`3[jo<0moKg0080moOo0180fMcS0=[Eg`3Ui^L0gmgB0;o5
eP3Zk>H0][ff0;2ZYP3>bLT0moO`0>c_j03Ni=/0g^KU0??cm`3oool0moKg0>k^m`3cm?020>_/i`80
loC`00L0loCY0?Ogj@3eool0lOoY0?Gol03gmol0hoOh0080e^SV01L0fNgh0?Goo`3AfNH0_/7A0<;<
e`3Rlo@0hno`0=Sdm03emoP0bm_Y0;3?hP3FhND0k?Ko0=[Ul03oool0gmcN0=3Qg03Si>L0l^oW0<jb
V`2CIe@0Y8R:0=[Ei`1B0?ooo`00?`3oool03P3omoP0dL;F0:>7S@2l/:40k_O_0=[Ui`3SiO00joCd
0>k]l03gm?P0moOh0?;]k@3ZkN`0mOCd0`3gmoP08@3VkNh0jnc^0=W[m03RloP0k_Oh0=oWj@3Ag=h0
fN7Q0=7Lg03FhN40k=gO0?oVj@3HfM/0loOh0>_dm03emoL0jn_d0>__kP3oool0k_O^0?Gol03Zmol0
k?Oo0?oom`3ooo<0moKo0??cm`3Zmol0lOoo0??do`3ooo<0ooog0?ooo`020?oom`070?Ogm`3gm^d0
jncU0>KVk03gmol0loCo0??bl`040?Ofm`050??bl`3gm_L0moOh0?Ogn03gm_L00P3oool01`3gm_L0
g^c]0>Cdm03gm_L0k^kg0?ool03[jnD00`3/moP07P3Tm?@0j_Cd0?Ogn03cl_<0moOo0?Ggj03ZkN<0
loC`0??dj03oooP0fMcS0;jj[`3^mn`0_LSN0>?Kb`3Ih?<0iMWF0<oMk@2f_M00e]WR0>k/n03SiNP0
g^CS0=KIgP3Nh=L0iNOM0?Ogl03gm_L0oooo0?Ofm`80oooo01d0moOo0>[dl03Tm>T0j_C`0>_/m`3g
m_L0fNgh0=7XkP3AhNT0e^7Y0=[TkP3/m_@0fMcN0<CIhP3gmol0f>g^0=3Ul03oool0i>_h0>c/m03/
m_l0k>kh0>Kdm03Rh>40f_Oo0>kUi`3=^jD0OVeT0=6j_@1D0?ooo`00@@3oool0303A`/h0NVUX0?Oo
l03^m>d0f]gO0>c^n03^koP0joCh0??oo`3oool0moCd0?Ggm`80i>g/00P0j^g]0>c_k`3Ag=h0fNKY
0>_cm03^moP0i^g^0=KQhP80dMcL0200e^GQ0>CTf`3/h=/0g^3Q0>_dm03NhM`0mOoh0?Ofn03gk>h0
k_Oh0>Kdm03[moP0mOoo0>[go`3clo<0lo;o0?Ofl`3oooL0j_Cg0?ooo`3/mol0moOg0?ool`3oooL0
moKc0?Ofm`3oool0loCW0=oPh@3[k?@0k^kg0??do`80moKg00D0lo;c0?ooo`3[jn`0k^k_0?Ofm`02
0>_[k00R0??bl`3oool0oooo0??bl`3Rjn`0k?Oh0?ooo`3cl_<0loC`0>KVi@3oool0k?Oh0>Cdm03/
moP0mOoo0>[dm03gm_L0lo;c0=kTf`3[mnl0h^gF0?7dj03Tj>80h^G@0<_?e`3Ag=h0g^_U0>__k02o
bmh0mOC^0=K=g03Fb=H0f]c]0>k^o`80ooOh0P3^k_l0903Nh?P0fMgX0>Cdj@3Rk>L0jncW0??dl03g
mol0oooo0?Ogo`3cm?l0j_Co0=7Wm03Ai>D0fOOd0>kgm03^k_P0mo?d0>[/n03Ii?00k?Cd0;cQi@3F
iNh0k>kh0?ogn03/k?@0k?Ko0>CVm03/k_P0k_Oh0=[_k`3Ag>D0k^kh0>cD_02ENg80b;2d0?Ogn5@0
oooo00110?ooo`0<0?ogn022Kh40/:NE0>[fk@3cm>d0hnG_0>CVm03Ri>h0iNk^0?;on03om?@0mOOg
0P3/moL01@3emoL0k>k_0>[Ui`3ekNl0k^oh0080joCd0P3Vm?@02P3^moP0jncd0=oPkP3IiNL0j_Cd
0>_]kP3[j>80lOOd0?ooo`3cjnh20?Ogm00=0>?_l03[moP0mOoo0=kVl`3oool0lo;g0?Ofm`3^k_<0
j_Oo0?7oo`3gmol0moOg0?ool`020?Ofo`080?ooo`3gmoL0lo?g0?Ofm`3[jo<0oooo0?Ogo`3cl_<2
0?Ofm`030>_[k03eool0hnk_00<0oooo00X0moKg0?ooo`3gm_L0oooo0?Ofm`3oool0lo;c0?Ogo`3c
loL0moKg1@3/moP0>@3Tm?@0k?Oh0>?^i`3>g</0i>3X0=KIk`3gm^l0h^ch0>[dm`3Oe>D0fLc;0>GU
j03emnl0_l;C0=Jm/`3JbL/0k^ko0?odm03^i?@0onc^0>_gkP3NiNh0k^3^0?O^n03gm?P0mOCV0?7g
kP3eonT0l_Oo0=k]l03FiNT0f>SY0=kXj@3^kNh0moCh0??dkP3FkNh0e^3S0>_cm03gmol0joCh0>k]
kP3/moP0k?oo0>cfo`3/loP0hmcN0=WPhP3Vm?@0gmcN0=WDeP3SinP0i^c^0>[A_P2IMV<0[9RM0?og
n01E0?ooo`00@P3oool02`3Ic=h0VWn509nOS@3oonP0loOd0>kgk`3am?l0fN_d0=kdn03VkNh0k^g^
0080mNo_02<0k?Og0?Ofn03Zk^l0mNo]0?ogo`3gool0moOW0>G/hP3Ii^T0hn_^0>kgn03Ok>h0mooo
0>G_kP3/ooP0k>o_0?ogk`3amo@0j^k_0??[m03cloP0ooOh0>K]kP3oool0h^kg0>k^m`3gm_l0ooog
0?Ofm`3Zm?l0mOoo0?ooo`3[k?<0moKg0?ooo`020?Ofm`0>0?Ofl`3cloL0jn_c0??bl`3gmol0oooo
0>_[l`3oool0lo;c0?Ofm`3Sk^l0k?Oh0?Ofm`3oool30?Ofm`040?ooo`3gm_L0moKg0?ooo`80moKg
00H0oooo0??bl`3/moP0k?Oh0?ooo`3/moP20>Cdm080k?Oh00h0g^c]0:^kaP3IgNH0hmWL0>_dj03U
k>d0i^gQ0>c/m03;cMD0_l_F0?ogi`3Il_<0dMcN0<Bn`@80Zk3;01P0d/S60=KDb`3=e=H0f]cF0=WL
g03;e>40^<SQ0;g6f`33cm00`lo60=WKg@3cjo@0oo?d0>?]kP3Hj>T0dN7R0=k]k@3^moP0g^g^0>GU
j03gk_00ooOh0?ooo`3gm_P20??bm00;0>;Ti@3Jk^l0moO/0?oom`3Zi>d0k>_^0?ooo`3Fb/H0T6AR
0:>@U@3gm?@0EP3oool00480oooo00P0moOh0>;DgP27M8<0Z;2L0>c^i`3gmoL0hno_0>[[m080oooo
01h0k_Oh0>__l03[ko00k>o_0>[dl`3gool0mNo_0?Ggm03[mo@0i_O]0>_fk@3cl_@0fN_d0?Gon03S
i]/0hn_R0=W[m03NiNH0k>o_0?ogk`3em>`0j_Cc0?Ooo`3cl_@0ooKh0>kUj03^ko00mOo`0>?^i`3^
k_L20?Ofm`0;0?Ogo`3bmol0mOoo0>_/l`3oooL0lo?o0>k^l`3gm_<0moKg0>_/l`3Vi_<00P3gm_L0
203gmol0jn_c0?ooo`3cl_<0moKg0?ooo`3gm_L0oooo0P3gm_L00`3oool0lo;c0?ooo`030?ooo`80
moKg00<0oooo0?Ofm`3gm_L01@3oool01`3gm_L0hnk_0>Cdm03Zlo@0b<?60=3<c03Zk_@00P3ZfoP0
703JgNl0joCX0>?Uo`2e_=H0YJo;0<[5b03NfL/0c]WK0=KWkP3glo@0fN3^0>KXm03Ig?P0h^Co0?Og
o`3cm?@0k^o^0?Ggk@3Zk>40fMcU0=oKiP3Ni>H0oooo0=S]kP3;fmd0[LgG0<?Df`3Th>420>[/k080
e^K]00h0j^c/0?7dl`3ZkN`0hoOo0?O_i@3^mo@0ooog0>Cdm`3cm?@0lo;h09N8L02XRXX0moCd0?Og
n5H0oooo00140?ooo`090=[3c`2SQXX0[:230?OUc`3[m>`0j^ch0??cm03cm?@0joCd0080loOh0140
moOh0?Odm03akN`0l_Og0?O_i`3[knh0joCd0>;dn03Smol0f?Co0=KVi@3oool0k_O`0>kgf`3ok]l0
hnCV0>;Ui@020?Ggm`0A0?Ooo`3em_@0k?oh0?ofn03[kO00joCh0>;dn03Ii>L0moKg0??bl`3oool0
j_Co0?Ogl03RknL0hnkc0??co`3gmo<00P3oooL01`3gmol0jn_g0?ooo`3cl_<0moOo0>_/m`3^k_L0
103gm_L20>cgn0030??bl`3oool0lo;c00@0oooo0P3gm_L20?ooo`80moKg0P3/moP20?ooo`0T0>_[
l`3^k_L0lo;c0??bl`3oool0_/_F0;K2d`3IeMh0l^Gd0?ogn03Ni_@0e]_d0=W8eP3OfM`0iNKh0>?^
n03Hh?@0`lSA0:R`]@2GZkD0XkNj0:Vm`02lb=00dMWQ0=kTi@3Ti^P0l_?d0?Ofn03Si?@0fM_V0=;K
gP3Ih><0ln_^0>c^k`3Ukn`0joOd0`3oool30>kom`0;0>kgk03gkN40jngU0>kgn03Vm>d0hno/0=7L
i@3Oh>h0lmcF07E>>@3SeMl0F03oool004D0oooo00P0f]GW09>8X@1WF5X0PWU[0<K<a@3^k_P0i^KY
0>?/kP80loOh00P0moOh0?Odm03bmoL0g^SX0>;]k@3[ko00loOh0>[gm080oooo02T0fN_U0>kok`3o
mml0iNo]0>GUhP3gk]L0f]gO0>;Ui@3gm_P0loKh0>cbn03eooP0lo;d0>_[m03ck?00moOo0=W]n02n
cmd0b]WV0>cgo`3cm?l0k?O`0?Goo`3Sko00j_Cg0??dl`3gmoL0oooo0?Ogm`3Uk?<0hnkg0?Ofm`3^
k_L0loCo0??cm`3cl_<0moKg0?ooo`3gm_L0hnk_0>cgn0020?Ofm`040??cm`3^k_L0oooo0?ooo`80
moKg00D0lo;c0?ooo`3oool0oooo0?Ofm`020>;[k080moKg02L0lo?g0?Ogo`3oool0moOo0>GWiP3N
imd0j_O`0>GEg`3:b/T0a=7F0=[Mk`3emo00lOCY0>[/kP3Zm>D0oo?U0=k/k`33cMd0]/;;0:o2b`2Y
_L00];fj0<g8b`3FfN40f>3Q0=7DeP3Nfm`0lNSX0?7]k03bmoL0looo0?;gm`3emoL0lOCc0>[dm03T
kN`0j_Cc0>C/k03Th>400P3Tfm`02`3Ji>P0k_Oh0>kgn03Fg=h0]LSA0<C?f`3Rk?@0g]3>0;jVQ@21
GTL0T7il05T0oooo00170?ooo`060?O_l02/Ui`0LF5F0=k_k`3/oo@0lo;h0P3Zk?@02`3FfN<0iNCV
0?Ooo`3cmoP0mooo0??dm03gmoP0k^k`0=W[m03RloP0lo;d0080k_o_02H0k>KW0?odgP3/kM/0moKh
0<k=b`3eooP0moKh0?ooo`3cl_@0moKh0??bm03gm_P0ooCd0?Ogm03[k?P0l_C]0<CAb`3RkML0mOoo
0>;Th`3^iNP0j_CY0>[gl03Zmol0k?Oo0>[dl03ooo00jnkg0>_/m03^k^l0lo?g0?Ogo`3oool0lo;c
0?ooo`3cl_<0lo?g0>_[l`80moKg00D0k^kg0??cm`3gm_L0oooo0??bl`020??cm`80moO`0`3oool0
=P3gmo00k^kW0?Ofm`3gmol0loC`0>[]h`3emnP0j^gX0>C]h`3/mo00jnGh0=7DiP3Ui>h0fMg]0<??
k03JgNl0mOO`0>kMgP3Tk>L0bm_^0;c6d02mb</0_<SC0;6mb`2d_KX0bL?;0;k3d02``lH0^L;50;c2
a@2f_LH0/;g;0=7DhP3ci_@0h^3]0=KIgP3IfM/0k>c]0??oo`3cm_P0onk`0?ogn03gool0j^kh0=[U
l03FkNd0e^g/0=7IhP3oool0mnko0>_VgP2QQW@0VWik0=W2cUX0oooo00190?ooo`0407EHI@3Ja9d0
hnSQ0>;Tk`80j^cd00<0iNK^0>_/kP3[moP00P3gmoP20>_]kP0<0=k/l03Jk_P0moKh0?Ofn03^onl0
f^oh0>CXk03SgMH0g]C:0=78_P36^:/0g^CW0P3oool06P3gm_P0oooo0??bm03gm_P0moCh0?ooo`3c
oo@0k>GW0?Ogi`3?g=/0g^CS0>_PiP3gk_P0lnKd0>_PiP3[i><0hno`0?Ogl03eoo00mOOX0=[Me`3[
k?@0i^Kc0??do`3gmol0k^kg0P3gm_L0303^k_L0mOo`0>?^i`3gm_L0lo;c0?Ogo`3^k_L0moKg0??b
l`3Zm?00j_O`0?;gj@80moO`02<0moOo0??dl03gmo00h^C^0=WLj03oool0moO`0?7gj03Zm>P0h^GD
0?Ogl03/mo00fMgS0=kKiP3^k_l0jnCh0>kUm03?gNl0`lSA0<oId03Si?P0]/;@0<gId03amn<0moOo
0?;gl03oool0l_O`0?Ogl03Zmo00l_o^0?Gol03FkNh0dN7Y0=W]n0020??gkP0C0>_dn03Ui>H0j^kh
0?G^kP3gk>h0k?Ko0>CVm03Ii_@0e/_G0>_Th@3Tm?L0onk`0>?/l03[k_P0jnKN0:b6O02@OW`0h]CN
0?Ogn01J0?ooo`00B@3oool0102/X;h0T7Ed0=7;]@3JgMl20=[Mi`0Q0?ooo`3[ko00loOh0?Ooo`3c
moP0loCd0?ogn03booP0fNc`0=W[m03Jk_P0oooo0>CXk03omo00ln_Q0>[gm03UiN`0a<6d0>?Ui`3R
i>D0lo?d0?Ogn03gm_P0lo;d0?Ofn03gmol0moOd0?ooo`3gooP0k>GW0>GVk@3gmol0jnkh00<0looo
00P0jnkh0>?PiP3SiNP0j_O`0?;okP3IiNP0_/_;0?Ofk@80hoOh04L0moOo0?Ofm`3cl_<0moKg0>cg
l03eoo00jncg0??cm`3Zm?00k?O`0>k^m`3gmoP0f^GO0>[do`3UkML0h^gU0>c_h`3oool0l_CS0?Gg
n03RiOP0l^oR0=7<c`3/mo00mOo`0=WIh@3=e>d0b/[90=KQd03ZkMh0mOCV0?ogn03^k_l0h^Cd0?oo
o`3ooo00hnGh0<W=d03=fM<0iNc_0>KPn03Fe>H0f>3S0>Cdj@3Ah><0d]CN0>_PiP3[h?@0k^O`0?Od
n03gooP0oooo0>GPhP3Nfmd0j^_d0?Ggm03Zi^h0oooo0>CVm03JiNL0i_C]0?O]i@3^k?@0mNk]0>?_
n03cjnh0oooo0=W;_@2OPg00T7il0>?Eg`1L0?ooo`005@3oool20?ogn3<0oooo00<0]JZf08YiN02/
Z9@00P3JdL/08@3Ijo@0hnCV0?Ogn03cm?@0moOh0?ooo`3gool0moOh0>k]kP3emo00moKh0=[^n03/
kM/0k>od0?O/gP3RjnP0ho?d0=KDe`3Vh<`0fMcN0>?Ee`3clo@0oooo0>coo`3/moP0moCh0?Oon03g
mo@0mooh0??om03gmol0jnch0>k^n0020?Ggm`1A0?Ooo`3bmoL0j_Cc0=KIg`3[iNH0jnC^0=;8b`3J
dMH0al>l0=W]n03[m?P0i?CY0>[ck@3gm_L0k?O`0=K]kP3Rm>h0k?OY0>;_j@3/mo00lOoY0?;dj03I
g=L0jnc_0>;/k@3AfLd0k^ko0>?_e`3ZkMh0k?O`0>?MeP3NdLP0k^Gh0?GgkP3Sg=00moCh0>?Uk`3U
eMl0i>KU0<k1b034b=80b]CK0=WDeP3IfNL0e^3h0=kPi@3TkNL0j_C^0>[dh`3bk^h0i]_d0>KPn03[
k_l0iNc]0=SKh@3bm?L0moKh0?ofn03ol_@0ooKh0>cfo`3Zjo@0j^CU0?ooo`3Zjnd0k?Ko0?O/j03F
fm`0e]cK0>K]h@3^moP0k?Oo0=kgm035i?@0fLgC0?OPhP3gm_P0dK^]07i/HP2ORY80h]CN05d0oooo
000E0?ooo`80ooOh=03oool0G`3Jc=L0T8N<0:RHM02XV7@0am7B0=kPk03Ae=h0moOh0?;dm03Tj>P0
j^g]0?Ooo`3gm?@0l_C^0?Ofn03/k^L0iNgX0>cgkP3oooP0ooCd0?ooo`3Zk>d0g]cC0>;Ti`3?e=h0
d=?F0>c[k@3/m_P0k?Oh0?Ogo`3gmo@0mooh0?ogn03oool0lood0??^m03cooP0k>GW0?ooo`3Zm?<0
k?Og0?oon03Ii>`0jnko0>kUj03bknL0bLbn0;G2cP3JgLL0j_OY0?ool03Rk^d0moOo0>?^i`3IkOP0
k>c`0?;/m03gk?@0k^Gh0?;_hP3bm>80jncX0=KId03FfLP0c]3O0>cUdP3Je=80gmWW0>GEg`3Oe=D0
fMcR0;n`]03AeNL0a<oK0;feZ`3Ic<h0fMg_0;Jj_@3?a[80l_C]0>k/kP3;h?P0f]gO0?;]h@3Nk>l0
f>3W0=7Kj03Ih>l0fM_]0<_?j03;e>`0hncg0?7dk03oooP0j^c/0080j_Ko01L0lo;d0>[[k@3/k>P0
mOC/0?Gon03ZloP0dM_L0<[Af`3Ih>P0moCd0?Oom`3^mo@0jnG]0>[/k@3gk_00e]cX0=kgm`3gknl0
ooKh07IIB`2eZZh0moCd0?Ogn01M0?ooo`00C03oool0EP3Jc>L0[8n=0:b?S@2/X840fMVf0<k9a@3U
iNP0j^g]0>[]k03oool0mNo_0?Odm03emo00g^c`0?Ofi`3UknP0k>o_0?ooo`3gk>D0jn_Q0??ck@3c
jn40dN3U0=k[m03^ko00dMcN0=kTi@3Ti^P0j^CU0?O/kP3gooP0ooOh0?Ogo`3ok>h0ooOh0>kTm03U
iOP0j^CU0>[/k03emoL0moOd0>[]k`3RkNP0i?CX0=3Me`3Ii^80gmcF0<C9e03gknL0k?O`0?Ggj03S
iM/0moO`0=WTi`3Ri>P0ooOh0>k^o`3^i>d0jnGh0>KPn03[inL0j^cX0=KIj03[m=/0g/o80>;Lb`3o
m^l0iOO]0=kWk`3Abk`0k^OY0?oVf`3:bL`0i>GC0:R``@2X[[80a=7@0>;/iP3Ie>40b<W@0<[Df`3S
i>H0mOOd0?oon03emnd0lOC/0P3oool20?7dl`040?Ggm`3am?<0oooo0?Ggm`80mOC/01D0lOCc0?Gg
m`3oool0moOh0>_]i@3Iknl0iNkd0?ooo`3giNL0moCX0?Ogk`3^ooL0fNCW0=[go`3[k?00h^O^0<OA
f`3Nh>D0`/>f0796@03omoP0G`3oool004d0oooo0P3JeNL0402ZUj`0ViR=0::PQ`3Ig>L0g^3^0>GU
l03/knl0mOOg0>cgm`3RkN`0g^7R0>kok`3Sl_@0hnGW0>c]h@3cjnL20??/i@130??ck@2ob]<0a<c=
0>[/k@3^k_00hnCV0>_]kP3ZkNd0f=_L0<[=eP3NfMh0loKd0??[m03cm_P0iNCd0?Ogo`3cmoP0jn_d
0>;Ui@3gmo@0loCh0>_]n03gmol0g^S]0<S<g`3[kNd0hncK0:bka`3IhM@0k_Oh0>?^l038dmh0l_?V
0>[dl03Fg>H0on_X0?O_i`3ZinL0mO?]0?OTk@3Th>l0l^cK0=k<f`3A`ll0f]gG0>?Dg`3ZiO@0lngL
0>CLh@3gi=/0k_?X0=7=_@37fM`0bn3G0=[Pb`3Vh>h0Zk_K0<;5b`3[g=40j_C]0?ogn03gm?P0moOh
0?7dk03gm^l0j^cd0?;dm0020>CXj00J0=kXj03NkNd0joCd0??dm03[kNh0i^SY0>K_l03Vool0i_Oh
0=Wgo`3Zmnd0iOCd0=;Pj03[h=`0ooO_0?ooo`3/mol0i?Cg0=7Mi`3ok_00dMgW0=kTi@3ggML0UHYh
06QAD02eX:EP0?ooo`003P3oool00`3om?@0ooOh0?ooo`0n0?ooo`1D0>kUn03>_MH0QgA[08V3H02P
YXH0c/Vb0<[=e03Be><0c]WR0=7Qh@3?dM/0f^kg0>_fk@3cl_@0k>KF0=kEa03NfM80hmgF0=kPg@3R
i^D0moOh0>;Ic`3NeLl0hmgO0>GVkP3Ri>h0hnG`0=SKhP2l`/P0XZZi0:V`_`33b=40b/K90<[8d@3A
e>40l^cd0=WVi`3Zm>d0loCh0>_]n03Si?00jn_^0=WLgP3:a/T0j^CU0>;[m03;b=40c[ZW0>?>_`3S
g>40Z[c;0:Bf^P3omml0bn7F0<Zla@3bi=/0k=gU0>CPn03giOP0k>kW0>[VeP3JgML0onoO0=KWkP3F
fM00j^_U0>?Tg@3@gM/0e]cK0>?LcP3ekND0j]c;0?G/f`3Fi^h0moKh0=WWkP3aonh0k?oh0?Oon03g
m?@0oooh0>c_k@3Zk?@0hnGo0P3gmoP06P3cm?@0joC]0>kdk@3[m?@0loC]0?OXg03Vg=40i^gX0>Ko
o`3^mo@0k?C/0?ooo`3Fm?L0bng_0=KLg@3Nh>40dN3X0=kWj03bk>D0`ngg0<?Li`2o][80EC/a044Q
6@1oIFT0dK_6H@3oool000h0oooo00<0ooCd0?ogn03oool00P3omoPn0?ooo`0=0=[Ei`3>^L<0XZ2S
0:RWV`3Ae;@0h^GA0>?UeP3gk_00j^K^0>c^n03^k_00jnc^0>_[kP020=W[m00E0=kPh@3/onT0h^cd
0>?gn03Ri^D0mo?]0>cUi@3ZkNP0g^3L0=kIeP3gm>d0oooh0?ogl03gknL0j^g/0=kKh@3AcM00c]7D
0<kIf`3FiN40j_C_0080moOo0180jnc^0=[^n03oool0mo?N0>?I^P3[im@0lo;U0>Gfm`3>fN80d<cC
0>?cm03ciND0/kR^0<CAd03>bl/0e/c;0>?PiP3Zm>d20>[Pi`0D0?O]i`3bi=h0g^3R0=[Me`3^mnl0
k_O`0>_fh@3Iinh0k?C`0>_]n03RiNL0mngU0>con03Si>H0i^OY0?Ogn03Vm?P0jngd0>KWkP3Oi>h2
0>_gn00L0>Kdm03[ool0loCd0>_gk`3^ooL0k_O/0?ogk`3Voo<0k_og0>_dk@3cj=`0joCd0=Kgm`3N
i>d0j]_L0>?Wj03cm?@0hnC^0=;Lj03NiNh0k?Kh0>G[m03RinP0f>gW07Z6NP1cI5P0_ZVT0?ogn6<0
oooo000A0?ooo`80ooOh?`3oool0@P3^iOP0f/cG0;b^/P2NUHT0];F]0;Vh]031cLP0h^GU0??bm03c
loP0jncd0?Ogn03Smol0f^kh0=kPh@3omnh0mo?]0>[ck@3/moP0k^CN0>KPeP3^iMl0loCd0?Ooo`3g
m?@0moO_0?O]i@3gmoP0moC^0?oon03gknL0mOOo0=kKg03:a]00_/?A0=;Df`3^k_00k?oh0>G^kP3[
jnh0jnkC0>G]kP3SgMl0mnc;0>kgl03UiN80g^cV0=;LeP3Ik^D0hnG^0=79b03Jc<d0_L;F0>?Kb@3Z
mnH0k>kh0?ofk`3/lnd0j^cQ0?G]i@3Ak?P0mnkG0>G_k@3Rg=h0k^gU0??go`80moOh00T0j_oh0>Gg
m03[kNh0loCd0?Ooo`3[m?@0i^g^0=oWkP3Oi>h00P3Vm?@06P3VkND0g^gX0=kdk03Vm>d0k_C]0?og
k`3^m>d0joO/0?Ogk03gm>d0h_oh0>[gm`3TiND0l_Oh0?;fn03cm_P0k^_d0?ofn03Ih>h0e]WV0=WP
j03Fg>D0g_Oh08YiF027K6P0dK[5I@3oool005<0oooo00/0k^Gh0>KKkP36[/@0/jJW0<RkY@3Fdl<0
b]cU0?;ci`3emoP0oooh0??bm0020?Ofn00B0=kPh@3omoP0ooOh0?Ofk`3gk?@0k^CN0>KPeP3^iMl0
moCd0??gn03gmoP0loCX0?O_i`3^kND0moCd0?ooo`3gkND0moC]0P3om?@0803oool0k>o_0=KIf`3I
g=H0jncR0>_[kP3^onl0h]cF0?O^e`3TkNh0k>g_0>kgk`3[im@0mncN0?o_g`3^j=/0iNGX0=31a@3I
e<T0ooON0>C/m03/k_P0moK_0>_[n03Sk?l0jmcN0=WDd@3:cM00`Kk10>cQeP3:fnh0fMcO0P3oool2
0??gn0060??dk@3RiN40i>SX0>[]k03ekNP0ongQ0P3om>P03P3em>`0mOO]0?Gon03oool0joOd0>Kd
k@3VkN40e^g]0=kgm03^k?@0h^Od0>[/m03/i^h0hoOo0P3gool02`3Jk?@0l_Oh0>?Ul03SiNL0cNgc
0=kdo`3Ae<d0Kg5P06]CD`3Ic>D0moOh06D0oooo001F0?ooo`0?0=[<i`2cY[@0XYN30:>XZP3BfLh0
h^CU0?oon03gm_@0lo;h0?Ofn03UkNd0c]WK0>cVi`3gk>D0mnkW0080ooCd00T0mnkW0?Ofk`3omoP0
oooo0?Ogk`3cm>P0moO_0?ooo`3om?@00P3omoP05P3gm?@0loOh0??gn03gool0hnk`0;GCiP3:eN80
i>7Q0=kPh@3SiNL0hmgO0>?Ui`3/mnh0e^g^0=7EgP3Ui^40iNGX0>c]gP3Ii_@0d=GF0>;PgP3JgOP2
0=kTk`0<0>[/k`3JiNl0i^Kh0?ofn03[kOl0hnCh0=kPk@35b=<0^Kg10??dk@3Ri>h0loCd0P3gmoP0
1@3[mo@0joOc0?Ggm`3eooP0mOOg0080k_C]01X0mngQ0>G]k@3Nm?@0i_CX0=kdk03Skn`0ooOd0>cd
n03omoP0moCd0=kcn03/ool0moKh0??oo`3Jk?@0hncd0>kcn03blo@0amGO0<gLi@39kOL0k>GW0;>^
W01dFE@0Q6U[0=W<gVL0oooo001G0?ooo`090>kUn02l]/D0UhnE0;>bX@37c:/0hnGG0?Ofo`3[m^L0
joK]0080hn_^00T0i>S/0=[_n03JkOP0ooo`0?Ofj03^iMl0jn3M0?ogkP3om?@00P3gk>D0>@3om?@0
ooOd0?odkP3omoP0moC]0>k_i`3cmoP0mo?]0?O/i@3Zlo@0k?og0>[bk@3Sk_00ooO^0>;TeP3IfL/0
g]WN0?odm03omnh0mo?]0<SCf`3IfLl0j^cd0>cTc@3IkNl0g]cK0>?LcP3^in80onoW0>[/o`3gm^l0
j_CX0=kTh@3FfND0gn3d0>KVm03cjo@0i>c/0=[Mj03Uinh0jnc^0=WKgP3Oh><0i^g^0>kgn03[m?@0
iNSQ0>_dm03gmoP0moOd0=Wdn03Uk?@0mnCX0?odm03SkO@0hoCh0?O/m0020>[Pj@0A0>cLiP3gh>80
hn3X0=kXk@3^j>P0f>od0=SXm03[k?00_lSK0=KPkP3Ri>D0V[:a06maH`1WDT`0V8fR0??]kP3gmoP0
I`3oool005T0oooo03H0dL;>09R4W@1oM880Ti9e0<72W`3>fN40g^g/0>[/n03emol0h^C]0>[/i@3U
i^40k>gN0?O^hP3[h=d0f^G_0>cgkP3om>h0j^7F0>[Qi@3^k>D0jnCC0?Ofk@3gm?@0k_O_0?O]i@3o
ool0mnkW0??fk`3cmoP0mnkW0>[cm03UjnD0h_?d0=k[n03@iOl0h^oh0?Odm03ooo00lncU0?ofk`3S
iOL0e]?>0>?UhP3om?@0k>gd0>c]f`3Nk>`0a=CN0;Vmf`34b>T0fM_Y0=WKkP3FfND20=SLg00B0=7L
g03FhN80jn3D0>?ThP3oooP0ln_^0?O/kP3oool0jnO^0>_/m03ck_P0lnCU0?Odk@3^k?@0mNc^0>[^
m03/m_P0g^C`0P3Zh>T04P3@g>D0d^SX0<kQh@3>j>P0i_O_0>Gok`3oool0g_og0>;Mg@37dM/0g^CU
0>kVkP2TWI`0NGAG07]FA02DMGh0f/cG0?Ogn6T0oooo001I0?ooo`0h0?Ogn03gm?@0f/cN0:B<Y`1e
HG<0G4U505]7;P2=PUd0b/^d0?Oci@3IhO00dMcd0=kPhP3;cm40a=C>0=kPe`3/knl0e]g@0;c2]03A
cll0moOh0??/m03ck>D0h^3K0>?[i@3Rl^d0g^KR0>_Vg03cm^l0moOh0?Ooo`3[i=h0jncU0>?fn03/
m_P0i?;d0?ooo`3gmoP0loCd0?Ogn03om^l0oo;X0??/gP3gonh0h^c^0=kVhP3Ie<d0h^GU0??dm03^
knL0k>o_0?7do`3am?P0i>OU0=SKg03Hi>L20=STk`0;0=7fi`3>m^L0fOOh0=KUl034i?@0c^3`0>;c
n03Ak?P0e^C`0=KIhP34b=000P3AfMH0503;cm40_/gA0<CIf`2nh>P0c^3Q0=7Tj03Uk_P0e_Oh0>kf
o`3:fNL0a<S@0:[3e`2g`mL0j^g_0=K5^@2;NF00CR`K0651?02TS9X0f/cW0P3gmoQZ0?ooo`00G`3o
ool03P3^iOP0V8fT05EIJ@1jO6T0SiNF0<[1`@3ok]l0loCd0>_gk@3[m^d0j^3C0=KMe03Fg=H0j_Cd
0P3^iNl03P3gmoP0mOO_0?;dk@3bm>d0mnoW0=k]kP3SiMl0moK_0??gn03cm?@0mooo0?Ogn03Sl^d0
k?;]0`3oool07`3om^l0k?;X0=kbk@3Ii]d0ln3A0>com`3Zh=/0mncU0?ooo`3om^l0mncU0>_gk`3[
m>`0loCc0?oon03cm>P0moOd0?o_k`3gkN`0loCd0>kWk@3[k?@0k^kh0=o^m03UooP0loCd0>_]h@3U
kN40iNgU0>c/m03Ah?P00P3;fo@00`3Ih?@0ln_^0?Ofl0020>;cm00<0=WVk@3Skn`0e]WQ0;k8gP3/
k?@0dM_Y0;2m_02:PW<0Lf9F091eOP3A`ll0moOhKP3oool000h0oooo00<0ooCd0?ogn03oool0D03o
ool0303Jc=l0Y8bW08IhPP1_N7/0T8mn0:>NNP2i/Y@0f<nm0>?La@3om=40e]WG0=k]kP80fNGM0480
bM740<W8]03HfL`0g^g^0>?_l03gm>d0h^GN0=KMe`3Tl^d0k?;]0>[[i@3Hjnh0j_og0?ofk`3Si^L0
h^KW0?Ooo`3om^l0i?K/0?Oom`3bmn`0j_O_0>C^k@3Zh=/0j^KR0>Cbm03Tm_@0i>k]0>c/kP3gm>h0
loCY0>__i@3Fi=/0h^cV0?Oon03[mnd0joC/0?Ogm`3cmo@0i_CX0>K]h@3Vj=`0dNgX0=S/j03ZjnT0
j_;^0>;fkP3Rlo@0a>3`0;SDhP2bcm`0a=_K0=7ViP2`aM/0WJo;0:W1f`31fNh0lnK^0>C_k@3RfL`0
[:R=07mMDP2DLG`0fL7<0?Odm03gmoQ_0?ooo`003P3oool00`3om?@0ooOh0?ooo`1B0?ooo`050>kU
l02l]/@0UXZX08YiW@1gKH800P1_KFH05@1XIWX0T8F;0<B_W@2hZZ80^:nV0<BhZ`31`/@0c/:d0>?L
b`3Je=/0fMCK0?OUg`3ciMH0jmG10=WQg@3Rj>80j^oU0>cfk03ol^P0g]cE0=SUi@020?Ooo`0T0>;c
m03Hi^T0f>KR0=SVhP3Njnh0jncU0>_dm03gmo<0loCc0?Ogm`3/m_P0i?;d0>cfn03om?@0k>c^0>[c
kP3gmo@0oooo0?Oon03coo@0moO`0>?dn03SooP0moC^0>[dkP3Hk>P0g^KS0=SVgP3;h=h0e]WL0>kX
h@3oool0loCc0?Ggn03NfN40hmgW0P3oool01P3Sk_P0fMWK09YnK01XGeT0MV5c0=6ja@80moOhL@3o
ool006L0oooo02@0k^Gh0>KKkP3Vfnh0jn3^0=WAhP3;b>40g^3]0>[Ui@3SgNl0iN3h0<Ric03JgML0
j^gQ0>_^g@38bll0_;Vm0<6i/`3Sg</0mnkW0>?_l03Hj>T0dN7S0>GVg`3Tl^d0oooo0>[fn03Rk>h0
looo0?Ogn03omoP0j_C^0;cIi@34h=H0e^_X0=SVj03Zlo@30>cfn00;0>c^l03gool0loCd0?Ogn03g
ool0looo0?Ooo`3omoP0h_C`0=Wgm03[ooP00P3gooP04P3coo@0moOg0?Ogm`3gmoP0mooo0?O_k`3c
m?<0mNCU0>;go`3Th>h0e/gD0;B^W02dXgT0Z8m`08M]K03RdM/0moCd0?Ogn7<0oooo001/0?ooo`03
0?ogn03^i?@0i]_d0080lnc^0200iM_R0=WAf`3OfM/0jnc`0>?/h@3Ri=l0jnCX0;B^^@2dZi`0dLRi
0?O^i`3gmnd0lngN0>;Pf`3Hh=/0lncU0?OUg`3/k>h0j^k`0=S[kP3?iOl0g_CX0??dk@3cmoP0mooo
0>;cm03Zlo@0i?;]0?oom`3Zlnd0iNCN0>;/kP80ooCd00@0loCd0?Ogn03gooP0oooo0P3cmnh30?Oo
n00?0??dl`3emol0j^ch0>[cn03Zk?@0i=_Y0>;dk`3cdK80/jj609BCJ@27M700RW>G0:BC/P3Ic=H0
moOh07D0oooo000@0?ooo`80ooOhG@3oool07`3gko00jnCd0>_[m03Uh?00fLcN0=kEh@3NfNl0h^Cd
0=WLk@3[io00fL_N0;jja@34^Z/0_[Jd0<Bl_@3IdLP0j^CF0?ogj@3ZkM`0g]Bn0>_Ia@3bm=d0g^GU
0?o/i@3gm?@0mooo0?Ogn03Rlo@0j_?d0>[fk`3Nl^d00P3ZjnD05`3emnl0iN_U0>[fn03oool0ooCd
0??on03gooP0loOh0?Ogn03gooP0hno_0>[Xk03Si>d0j^_d0?Ggo`3Zk?@0i>3D0;VbV@2:PF40LVeY
08=eT@2mXl40f/cW07T0oooo000@0?ooo`80ooOhGP3oool0=@3omoP0mng^0?O_l03^iOP0jn3^0??X
j@3[h>h0k^Cd0?ogn03gko00fM7R0<^meP3;]l/0a;300:RGY`21Lh/0O6Mj09InQ@2YWYd0Xj>R0;2Z
V@2XZYd0/;JO0=78Z03;^jP0bl:d0=kKd@3Rh=H0dN3K0>;[f`3/l]/0g^_X0>[gm03Nh>l0j_Od0?ob
j03ojn40h]W@0=KD`03>cKX0blRd0;BbW@1lOfd0L65605E1;P0j;b80AS/X04Tf:01?=SP0KE=[0:B<
ZP3Jc>D0ooOh07/0oooo000>0?ooo`030?odm03omoP0oooo0080ooOh00<0oooo0?ogn03omoP0H@3o
ool40?ogn0H0oooo01`0k^Gh0>KKkP3Fa^80bkO@0<^``02TSjh0T8JR0::NX`2`Y9/0ZIR@0:ZHR`2m
Yi40];6]0:RTX`2aWH`0U8Z508=oNP21O7<0MGAd07EdKP1oLFd0O6Mj085]O`2@LhD0X8>G0<Z^]P3A
`mH0f]CU0P3^i?@00`3omoP0oooo0?ooo`1n0?ooo`003P3oool00`3om?@0ooOh0?ooo`020?ogn003
0?ooo`3omoP0ooOh0640oooo103omoP<0?ooo`0?0?ogn03^i?@0i]_^0>KKj@3Icn<0`[;50;jZ^P34
/<D0dKgA0=S3d@3A_MH0e/KR0>_Pj@3[h>h0k^Gh08X0oooo002;0?ooo`80moCdT`3oool008/0oooo
0P3omoRC0?ooo`00o`3ooolQ0?ooo`004@3oool20?ogn?l0oooo3P3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00680oooo0T00002l0?ooo`00I03oool00d000000oooo0?ooo`2i0?ooo`00EP3oool3
@00000<0oooo0d0000030?ooo`=000001@3oool014000000oooo0?ooo`3oool2@00000H0oooo00=0
00000?ooo`3oool02@3oool2@00000<0oooo0T0000020?ooo`=000000`3oool2@0000080oooo0d00
000=0?ooo`9000000P3oool2@00000030?oood00001000000080oooo0T0000030?ooo`9000000P3o
ool3@00000060?oood0000100000@000003ooom00000GP3oool005L0oooo00=000000?ooo`3oool0
0`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool02@3oool00d000000
oooo0?ooo`0>0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom000000P3oool01D00
0000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom00000403oool01T000000oooo0?oo
od000000oooo@0000080oooo00=000000?ooo`3oool00P3oool01T000000oooo0?oood000000oooo
@00000@0oooo00A000000?ooo`3ooom00000GP3oool005L0oooo00=000000?ooo`3oool00`3oool0
1D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool2@0000100oooo00=0
00000?ooo`3oool00P3oool014000000oooo0?oood0000020?ooo`05@000003oool0oooo0?oood00
00000P3oool014000000oooo0?oood00000?0?ooo`04@000003oool0oooo0?ooo`=000000P3oool3
@0000080oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`04@000003oool0
oooo@00005h0oooo001G0?ooo`9000000`3oool2@00000@0oooo0d0000090?ooo`03@000003ooom0
00000100oooo00=000000?ooo`3oool00`3oool2@00000<0oooo00=000000?ooo`3oool00P3oool2
@0000080oooo1400000=0?ooo`9000000P3oool01D000000oooo@00004000000oooo00=0000000<0
oooo@000040000000T0000020?ooo`=000000P3oool3@00005l0oooo001G0?ooo`04@000003oool0
oooo@00001<0oooo00=000000?oood000000403oool00d000000oooo@00000080?ooo`03@000003o
ool0oooo01/0oooo00=000000?ooo`3oool01`3oool00d000000oooo0?ooo`070?ooo`03@000003o
ool0oooo05l0oooo001F0?ooo`E000000P3oool00d000000oooo0?ooo`0?0?ooo`900000403oool3
@00000L0oooo0T00000L0?ooo`9000004P3oool2@0000640oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-14.3105, -6.40135, 0.991711, 
  0.991711}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Thus, it is obvious that the field theory makes it possible to draw the \
monochrome as well as color sketch images.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.5.3 Painted image generation",
  FontFamily->"Times New Roman",
  FontSize->10.5]], "Subsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Sometimes, it is required a painted image as if painted by artist. In \
order to generate such an image, this section describes a simple methodology. \
A key idea is to emulate a paint touch imaging by classifying the numerical \
data into a limited number of gropes depending on their magnitudes. Computer \
graphics is able to draw any high-resolution images, but the painted image by \
artist is essentially composed of a limited number of color components. \
Thereby, classification of the numerical data into a limited number of gropes \
depending on their magnitudes makes it possible to emulate a paint touch.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox[
  "At first, we classify the numerical data into 5 gropes depending on their \
magnitudes.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
level=5.;
pSample=Table[Round[level*sample[[i]]]/level,{i,dim[[1]]}];\
\>", "Input",
  CellLabel->"In[56]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Figure 10 shows the monochrome images classified into 5 groups. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[ListDensityPlot[pSample[[i]],
\t\tPlotRange->All,Mesh->False,Frame->False,
\t\tPlotLabel->StringForm[\"``\",color[[i]]],
\t\tDisplayFunction->Identity],{i,dim[[1]]}]],
\tPlotLabel->\"Fig.10. Components of color painted image\",
\tImageSize->{450,150}];
\
\>", "Input",
  CellLabel->"In[58]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
%%ImageSize: 450 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[.5 .325 -125 0 ]
[.5 .325 125 12.5625 ]
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .325 -186 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.10) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Components) show
177.000000 12.812500 moveto
(of) show
195.000000 12.812500 moveto
(color) show
231.000000 12.812500 moveto
(painted) show
279.000000 12.812500 moveto
(image) show
309.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -11 0 ]
[.5 1.0125 11 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Red) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC
FFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCCFFFFCCFFFFCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCCFFCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCFFCCFFFFCCFFFFCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCFFFFFFCCFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF
FFFFCCFFCCFFFFFFFFCCFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFCC
CCCCFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCCFFCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC9999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC666699FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC996666CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFFFFFFCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF9966666699FFCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFCCCCFFCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCC6666663399CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCCFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF6666663366CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCFFCCFFFFCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC66666666CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFFFCCFFCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF99666666CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCFFFFCCCCFFCCCCFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF99666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCFFFFCCCCFFCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC66666699FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCCFFCCCCCCCCCCFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF66666699FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFFFFFFCCCCCCCCCCCCCCCCFFCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC66666666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF99666666CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCC66666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFFFCCFF
FFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF99666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF666666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFCCFFFFCCFFFFFF
CCFFFFCCCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF996699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFF
FFFFCCFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC996699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCFFFFFFFFFF
CCFFCCFFFFFFFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
999966CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99
666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99
6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966
6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCFFFFCCCCFFCCCCCCCCFFFFCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999966
3399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCFFCCCCFFCCFFCCCCCCCCCCFFCCCCCCCCCCCCCCCC
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCFFCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996666
6699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCFFCCCCFFCCCCCCCCCCCCFFCCCCCCCCFFCCCC
99CCCCCC9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99996666
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
CCCCCCCCCCFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC996666
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCFFFFFFFFFFFFFFFFFFCCCC9966CCFF
FFCCCCFFFFFFCCCCFFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCC
CCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CC663366
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCFFFFFFFFCCCCCC99CCCCCCCCCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFFFCCFFCC
CCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999996666CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCFFFFFFCCCCCC993399CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCFFCCCCCC9999CC99996699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCFFFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999663366CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCFFCCCCCC999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCC9999999966669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCFFCCFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9966666699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCC99999999CCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFCCCCCC9999999966666699CCCCCCCCCCCCCCCCCCCC
CCCCCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9966666699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCC999999669999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCFFFFFFCC9999996666333399CCCCCCCCCCCCCCCCCC
CCCCCCCCFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99666666CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCC99999999666699CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCFFCCFFFFCC9999996633003399CCCCCCCCCCCCCCCC
CCCCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966666699FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCC99999999996699CCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFFFCCFFCCCCCCFFCC999966333399CCCCCCCCCCCC
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCC
CCCCCCFFCCCC6699CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99663366CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCC99999999FFCCFFFFCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFCCFFFFFFFFCCCCCCCCCCCCCC99669999CCCCCCCCCC
CCCCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99CCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC66336666CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCFFCCCC9999CCCCCCCCFFCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCFFFFFFFFFFCCCCCCCCCCCCCCCC9999669999CCCCCCCC
CCCCCCCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCC996633333366FFCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCFFFFFFFFFFFFCCCCCCCCFFFFFFFFCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCFFFFFFFFFFFFCC
CCCCFFFFFFFFFFCCCCCCCCCCCCCCCCCC9999669999CCCCCC
CCCCCCCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCC66666633333399FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCFFFFFFFFFFFFCCFFFFCCFFCCCCCCCCCCCCCCFFCCCC
CCCCCCFFFFFFCCCCCCCCFFCCCCCCCCCCCC6666669999CCCC
CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCFFFFFFFFCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC9966333366663333CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCC99666666669999CC
CCCCCCCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFFFFFFFCCCCCCFFCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF993333333333663366CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC66666666669999
CCCCCCCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFCCFFFFFFCCFFFFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC663333336666663399FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFCCCC
FFCCCCCCCCCCCCCCCCCCCCCCCCCCCC999966336666999999
99CCCCCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9966CCCCCCFFFFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC333333336666666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFCCCCCCCCCCCCCCCCCCCCCC999966666666999999
99CCCCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFF996699CCCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCC993333666666333366CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCFFCCCCFFCCCCCCCCCCCCCCCC9999999999CC99
99CCCCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC666699FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC99993333666666333366FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCC
CCCCCCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC66666699FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF6666669999CCCCCC6699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC99999999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC6666CCFFFFFFFFFFCCCCFFFFCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999CC99CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC6699FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC6666CCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC99CCFFFFFFFFFFFFFFCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFCCFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC666699CCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFCCFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC663399CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCFFFFCCCCFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC66666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFCCFFCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC66666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC33666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFCCFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCFFFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC333333666699FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC333333666699FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC3333333366CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCFFCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC996666666699CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9966336666FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9933666699CCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFF
FFFFFFFFFFFFFFFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99663366666666CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9966666633666666CCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC996666663333669999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFFCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC99996666666699CCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFCCCCCC99999999666666666699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCFFFFCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC99666666666699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCCCCCCCFFFFFFFFCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCFFCCCCFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC99666699CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCCCCCCCFFFFCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCCFFFFCCFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCFFCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFF
FFFFCCFFCCFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF
FFCCCCCC9999CCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFCCFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFF
CCCCCC9999999999CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99CCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC
CCFFCC6699999999999999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFFFFFCCFFFFFFCCFFFFCCFFFF
CCFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
CC9999CC99999999999999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFCCFFCCFFFFCCFFCC
FFCCFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC99
9999CCCC99999999999999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFFFCCFFCCCCFFCCFFCCCCFF
FFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC99
66CCCCCC99999999669999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCFFFFFFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFCCFFCC
CCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC66
66CCCCCC99CC9999669999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
FFFFFFFFFFFFFFFFCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCCCFFCCCCFFCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999CCCCCCCCCCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFF9966
CC99666699999999999999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFF
FFFFCCFFFFFFFFFFCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFF9966
CC99336699999966999999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCCCCCCCCCCCC
CCCCCCCCFFFFFFCCCCFFCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFF9999
CC66339966666666666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC99CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFFFCC66
9933336633333366666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCC9999999999999999CC99CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC99999999999999CCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCC99
6633336633333366666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCC99996666999999CCCCCC999999
99999999CCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCC66
6633333333666633666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCCCCCC9999666699CCCCCC99666699
66666666669999CCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFFFCC66
3333333333666666666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCCCC99666699CCCCCC666699CC
6633336699666699CCCC99999999999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFFFFF66
3333333366666666666666CCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCCCCCCCC99669999996699CCCC
6633336699999999CCCCCCCC99999999CCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCFFFFCCFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999999999999999CCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFFFFF99
6633333333336666666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC9999666666669999
9933333366999999CCCCCC99999999CCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99CCFFFFCCCCCCFFFFCC
6633333333333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCFFFFCCCCCC9966666666
6600333366666699CC99CC999999CCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC9999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF6666FFFFCCCCCCCCFFFFCC
6633333333666633666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFFFCCCCCC99996666
663333336666669966999999CCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC9966
666699CCCCCCCCCCCCCCCCCCCC9999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC3366FFFFFFCCCCFFFFFFFF
9933333366333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFFFCCCCCC999966
99666666666666999999CCCCCCCCCCCCFFCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC99
66669999CCCCCCCC9999999999999999999999999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF99663366CCFFFFFFFFFFFFFFFF
9933333366333366666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCCC9999CC
99996699999999999999CCCCCCCCFFFFFFCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC99
99999999CCCCCCCCCC999966666666669999999999999999
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99999999999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9966333366CCFFFFFFFFFFFFFFCC
9933663366333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFCCCCCCCC
CC999999999999CCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CC999999CCCCCCCC99666666666666666666999999999999
9999999999CC999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999996699999999CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCC6633663333CCFFFFFFFFFFFFFFCC
9966666633333333336699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
99CC999999CCCCCC66999966333333669966666699999999
66999999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC999999996699999999CCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC66333333333366CCFFFFFFCCCCCC99
6666666666333333666699CCFFFFFFFFFFFFFFFFFFFFCCCC
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CC99CCCCCC99999966CCCC33003366666666666699999966
666666666666669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99996666666699666699CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC996666333333333366CCCCCCCC999966
6666333333333333666699FFFFFFFFFFFFFFFFFFFFFFFFCC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CC99CCCCCCCCCC9966999933003366666666666699999966
6666666666666699CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99996666666666666699CCCCCCCCCCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC66666666333333333366999999666666
6666663333333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF
FFCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99996633003333666666666699996633
66666699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99996666669966666666CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666666663333333333333399666666
3333666633333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC996666333333666666666666666666
6699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99666666666666666666CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666666663333333333333366666633
3333336633333333666699FFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF
FFCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999966666666666633666666
6699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99666666666666666666CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966336666663333336633333366663333
3333333333333333336699FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999996666996666669999
999999CC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999666666666666666666CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666666666663333663333336666333333
3333333333333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFCCFFCCFFCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999966999999669999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999666666336633336666CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666663366666666666666336633
3333333366333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCC9999CC99CC99CC99CCCCCC99999999999999
99999999999999999999999999CCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CC99CC9999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC999966666666666633333366CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666663333333333333366666666333333
3333333366333333666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999CCCCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCCCCCC9999
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC996666666666663333333399CCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666333333333333663333336666333333
3333333333666633666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCC999999CC99CC9999999999999999
99999999999999999999CCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC996666336633666633333399CCCCCC99CCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666663333333333333333333333333366
3333333333666666666699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF99CC99CC999999CC9999CC99999999
99999999999999999999CCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC9999999999
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999966666633666633333333CCCCCCCCCCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666663333333333333333333333333333
3333333333336666666666CCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC99CCCCCCCCCCCC99
CCCC99CCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC9999999999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
996666663333336633333366CCCCCCCC99CCCCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666333333333333333333336633333333
3333333333336666666666CCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCFFFFCCCCFFCCFFCCFFCCFFCC
CCCCFFCCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC9999999999
99999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
996666333366333333666699CCCCCCCCCCCCCCCC99FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9966663333333333333333663333333333
3333333333333333669999CCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFFFCCFF
FFFFCCFFFFFFCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCC9999999999
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
996666333333333333666699CCCCCC999999CCCC66CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966663333663333333333333333333333
3333333333336666666666CCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCC999999
99999966666699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
666633333333333333666699CCCC99999999CC996699FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966663333333333333333333333663333
333333333333666666666699CCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC99
999999666666666666669999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
66663333333333666666666699CCCC999999CC996699CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666633333333333333333333333333
333333333366666666666699CCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
CC9999999966666666666666669999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99CC999999CCCCCCCCCCCCCCCCCCCC99
66336633333333666633336699CCCCCC99CCCC996699CCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666666663333333333333333333333
3333333333666666666699CCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCC
CCCCCC9999999966666666666666669999CCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCC66
666633333333336633333366999999CCCCCC9966669999FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666666666633333333333333333333
333333336633336666669999CCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
CCCCCCCC99999999999966666666666666999999999999CC
CCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCCCC66
6666333366336633336633666699999999999966669999FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666666663333333333333333333333
333333333366666666669999CCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCC999999999999666666666666999999999999
99999999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCC66
66333333333333333333336666669966666666666699CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC66666666663333333333663333333333
333333333366666666666699CCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCCCCCCC9999999999666666669999999999
999999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCC9966
33333333333333333333333366666666666666666699FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC66666666666666333366666633333366
333333336666666666666699CC99CCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCCCCCC999999996666666699669999
9999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC9966
333333333333336633333333333366666666666666FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC66666666666666663366333366336633
666633336666666666669999CCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999966
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999966
663333336633663333333333333333333366666666CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9966666666666666333366663333333366
33663366336666666666999999CCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999
999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC996666
6633333333336633333333333333663366666666669999CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9999666666666666666633663333336666
66666666666666666666669999CCCCCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC996666
663333333333333333333333333333336633663366666699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9966666666666666666666666633663333
33663333336666666666669999CCCCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99996666
663333333333333333333333333333333366666633666699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666666666666666666666666633333333
3366666666666666666666669999CCCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99996666
663333333333336633333333333333333366333333666699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666336633333333
333366666633336666666699999999CCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999666666
666633333333333366333333333333333333333333666666
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666663333666633
333333333333333333666666999999CCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999666666
663333333333333333663333333333663333333366666666
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666666666333333
33333333333333336666666666669999CCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCFFCCFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999966666666
333333333333663333333333333333333333333366666666
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666666666333333
3333666666663333666666666666999999CCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99996666666633
333333336633333333333333333333333333333366666666
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666666666666666666666666666333333
3333333333666666336666666666669999CCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999666666666633
333333333366333333333333333333333333333333666666
99CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666666666666666666666666633333333
333333333333663366666666666699999999CCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999666666663333
333333663333333333333333333333333333333366336666
99CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666666666666666666666666666333333
663333333333336666666666669999999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999666666333333
333366333333333333333333333333333333333366336666
99CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666666666336633
663333333333336666666666996699999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF
FFCCCCFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999666666333333
336633663333333333333333333333333333333366666666
99CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666666666666666666666666666663366
663333333366333366666666666666999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999966666666333333
666666333333333333333333333333333333333333666666
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
336666333333336633336666666699999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
FFFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99996666666666666666
333333333333333333333333333333333333333333666666
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
663366333333666666333366666666999999CCCCCCCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999996666666666666633
333333333333333333333333333333333333333333666699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
333366663333663366663366666699999999CCCCCCCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
FFCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999666666666666666633
333333333333333333333300333333333333333333666699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
66336666336666336666666666669999999999CCCCCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF
FFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999666666666666333333
3333333333333300333333333333333333333333336666CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666633
663366663366336666666666666666999999CCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFF
CCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999666666666666333333
3333333333333333333333333333333333333333336666CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
666633666666666666666666666666999999CCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCC
CCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999666666663333333333
333333333333333333333333333333333333333366666699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
33663366666666666666666666666699999999CCCCCCCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
FFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999966666666666633333333
3333333333333333333333333333333333333366336666CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
333333666666666666666666666666999999CCCCCCCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999966666666666666333333
3333666633333333333333333333333333333333336699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC996666666666666666666666666666666666
6633336666666666666666666666669999999999CCCCCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFF
CCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999669966666633666666333333
66663333663333333333333333663333333333336699CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
6633336666666666666666666666669999999999CCCCCCCC
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFFCC
FFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999666666666666666633663333
33666633333333333333333333333333333333663399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
663333336666666666666666666666669999999999CCCCCC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFF
FFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999966666666666666663333333366
333333333333333333333333333333333333663366CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666666666666666666666
663333336666666666666666666666669999999999CCCCCC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC
CCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999996699666666666666333333333333
333333663333333333333333003333333333333366CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666666666666666
666633336666666666666666666666669999999999CCCCCC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999999966666666666666666633333333
333333336633330033333333333333333333336666CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC996666666666666666666666666666666666
66666633336666666666666666666666666666999999CCCC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC
FFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999666666666666663333333333333333
333333333333333333000033333333333333666666CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666666666666666
6666663333336666666666666666669966669999999999CC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC999999999966666666666666663333333333333333
333333333333333333333333003333333333666666FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666666666666666666666666666666
6666666666333366666666666666666666666666999999CC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFCCFFCCFFCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99999999999966666666666666333333333333333333
3333333333333333333333003333333366666666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF999966666666666666666666666666666666
6666666633663333666666666666666666666666999999CC
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999999999999966666666666633333333333333333333
3333333333333333330033333333333366666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF999966666666666666666666666666666666
666666663366663333666666666666666666666666999999
CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCFFFFFFFFFFCCCCFFFFFFCCCCFFFFCCFFCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999999999999966666666666633333333333333333333
33333333333333333333333333333366666666CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF999999666666666666666666666666666666
666666666633666666666666666666666666666666999999
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCFFCCFFCCCCFFFFFFFFCCFFCCFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999666666666666333333333333333333333333
33333333333333333333333333333366666699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9999996666666666666666666666666666
666666666666336666666666666666666666666666669999
99CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFFFCCCCFFFFCCFFCCCCCCFFFFCCFFCCFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999666666666666333333333333333333333333
33333333333333333333000033336666666699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9999666666666666666666666666666666
666666666666333366666666666666666666666666996699
9999CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
FFCCFFCCCCFFFFCCFFCCFFFFFFCCCCFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999996666666666666666663333333333333333333333
33333333333333000000000033336666666699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9999996666666666666666666666666666
666666666666663366666666666666666666666666666699
9999CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCFFFFCCFFCCFFFFCCCCCCFFFFCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
999999666666666666666666333333333333333333333333
333333333300000000000000336666666666CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666666666666666666666666666666
666666663333666666336666666666666666666666666666
669999CCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCC
FFCCFFCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999
999999666666666666333333333333333333333333333333
333333330000000000003333336666666699CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99996666666666666666666666666666
666666663333333366663366666666666666666666666666
6666999999CCCCCCCCFFFFFFFFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC9999999999
999966666666666633336633333333333333333333333333
333333330033000000003333666666666699FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99996666666666666666666666666666
666666666666336633666666666666666666666666666666
666699999999CCCCCCCCCCCCCCCCCCCCFFFFFFFFFFCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
996666666666666633333333333333333333333333333333
0033330000000000003333336633666666CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99996666666666666666666666666666
666666666633333366336666336666666666666666666666
66666699999999CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFF
FFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
996666666666663333333333333333333333333333330033
3333330000000000003333666666663399FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC999966666666666666666666666666
666666666666333366663366666666666666666699666666
66666666999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC999999999999
996666666666333333333333333333333333333333333333
33333300000000003333336633663366CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC999966666666666666666666666666
666666666633663366663366666666666666666666996666
666666666699999999999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFCCFFCCFFCCFFFFFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999966
666666666666333333333333333333333333333333333333
33330000000000003333663333663399FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC999966666666666666666666666666
666666666666663333336633666666666666666666666666
66666666666699999999CC9999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCC99CCCCCC99CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999999966
666666666633333333333333333333333333333333333333
33330000000000333366663366336699FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF999966666666666666666666666666
666666666666336633333366333366666666666666666666
6666666666666699999999999999CC99CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CC999999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999669966
666666666666663333333333333333333333333333333333
000000000000333333333333663366CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCC9999666666666666666666666666
666666663333666666333366666666666666666666666666
666666666666666699999999999999999999999999CC99CC
9999999999CCCCCCCCCCCCCCCCCCCC999999999999999999
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999669966666666
666633663366663333333333333333333333330000000000
0000000000003366663333333366CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9999996666666666666666666666
666666666666666633336666666666666666666666666666
666666666666666666666699999999999999999999999999
9999999999999999CCCCCCCCCCCC99999999999999999999
999999999999CC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
99CCCCCCCCCCCCCCCCCC9999999999999999999966666666
663366333333333333333333333333333333330000000000
0000000000336666333333336699FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99996666666666666666666666
666666666633336666666633666666666666666666666666
666666666666666699669999999999999999999999999999
99999999999999999999CCCCCC9999999999999999996699
99999999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999999999999999666666666666
666666333333333333333333333333330033003300000000
00000000003333333333333366CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99996666666666666666666666
666666666666663366663366666666666666666666666666
666666669999666666669999999966999999999999999999
999999999999999999999999999999999999999999999966
996699999999999999999999999999CCCCCCCC9999999999
999999999999999999999999999999669966666666666666
666633333333333333333333333333333333000000000000
00000000333333333333336666CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC996666666666666666666666
666666666666336633666666666666666666666666666666
666666666666669966999999996699999999996666666699
669999999999669999999999999999999999996666669966
996666999999999999999999999999999999999999999999
999999999999999999999999999999996666666666666666
663333333333333333333333333333000000000000000000
00000033336633663333666699FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF999966666666666666666666
666666666666663333666666666666666666666666666666
666666666699999999999999999999996699666666666699
669966996666999999999999999999666666669966666666
996666669999999999999999999999999999999999999999
999999999999999999999999999966666666666666666666
663333333333333333333333333300333300330000000000
00003333336666333333666699FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC9966666666666666666666
666666666666666666336666666666666666999966666666
666666666666666666999999666666666699666666666666
666666666666666666996699669966666666666666666666
666666666666669999999999999999999999999999999999
999966996666669999999999666699666666666666666633
663333333333333333333333333333330000000000000000
003333336633663333666666CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC9999666666666666666666
666666666666666666336666666666666666666666669966
666666666666666699669966669966669966666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666666663333333333
333333333333333333333333333333000033000000000000
3333333333663366666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF9999666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666999966666666666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666666333333333333
333333333333333333333333333333003300003300000033
3333333333336666666699FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99996666666666666666
666666666666666666666666669966666666999966666666
666666666666666666999966996666666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666666663333333333
333333333333333333333333330000330000000000000033
33333333333366666699CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99996666666666666666
666666666666666666666666666666666666666699996666
666666666666666666996666666666669966666666666666
666666666666666666666666666666666666666633666666
663366666666666666336666666666666666666666666666
666666666666666666666666666666666633333333333333
333333333333333333333333333333330000000000003333
333366663333666666CCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCC999966666666666666
666666666666666666666666666666669966666666666666
669966666666666666996666666666666666666666666666
666666666666666666666666666666666666666633666633
333333663366666666333366333366663366666666666666
663366666666336666663366666633666633333333333333
333333333333333333330033333300000000000000333333
336666333366666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966666666666666
666666666666666666666666666666666666666666666666
666666666666666699996666666666666666666666666666
666666666666666666663366666666663366336633666633
333333333333663333663366333333666633666666666666
336666336666666666333366333333333333333333333333
333333333333003333333300333300003300000033333333
6666333366336699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC99666666666666
666666666666666666666666666699666666666666666666
666666666666666699666666666666666666666666666666
666666336666666633663333666666336666663366333333
333333333333336633333333663333336633333333333366
333366333366333366663333333333333333333333333333
333333333333003333333333003333000000003333333333
66333333663399CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999996666666666
666666666666666666666699669966669999666666666666
666666666666666666666666666666666666666666666666
666666666666666633666633663333663366663333333333
333333333333333333333333663333333366336633663333
336633663333336633663333333333333333333333333333
333333333300003300333300000033000033333333333333
333366333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99996666666666
666666666666666666666666666666666666666666666666
669999666666666666336666666666666666666666666666
666633663366663333663333663333336633333333333333
333333333333333333333333333333333333333366333333
333333333333333333333333333333333333333333333333
333333333333333300000033000000333333333333336633
3366336699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC999966666666
666666666666666666666666666666666666666666666666
666666666666666666336666666666666666666666666666
336666663366663333336633333366336633333333333333
333333333333333333333333333333333333333333336633
333333333333333333333333333333333333333333333333
333333333300333300000000333300333333333333663366
6666669999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC9966666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666633336666666666
336633666666666633333333663333333366333333333333
333333333333333333333333333333333333333333336633
333333333333333333333333333333333333333333333333
333333003333333300000000333333333333333366333333
666699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC66666666
666666666666666666666666666666666666666699666666
666666666666666666336666666666666633663366666666
663333663333663333333333333333336633663333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333300000033000000000033333333333333336633336666
666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99666666
666666666666666666666666666666666666666666666666
666699666666666666666666666666666633663366336666
663333336633333333333333336633333333333333333333
333333333333333333333333333333333333333333333366
333333333333333333333333333333333333333333333333
003300333333000000003333333333333333663333666666
6699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99996666
666666666666666666666666666666666666666666666666
666666666666666666333366666666666633663366663366
663366336633336633333333333333333333333333333333
333333333333333333333333333333333333333333333333
663333333333333333333333333333333333333333330033
333333003333000000333333333333333366336633333366
99CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99996666
666666666666666666666666666666666666666666666666
666666666666666666336633336666666633663366336633
333333333333336633333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333300
330000333300000033333333333333336633333333336699
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966
666666666666666666666666666666666666666666666666
666666336666666666336633333333336666336633336633
336666333366333366333366333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333330033330033330000000000
0000000033333333333333333333663366333366669999CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999
996666666666666666666666666666666666666666666666
666666336666666666336633333333333333333333333333
336666333366333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333330000330000000000
0000333333333333333333333333336633336666999999FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999
996666666666666666666666666666666666666666666666
663333336666666666333333333333336633333333333333
333366333333663333333333333333333333333333333333
333333333333333333333333333333333333330033003333
333333333333333333333333003300000000330000000000
3333333333333333333333333333663333666699999999FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99
999966666666666666666666666666666666666666666666
666666336666666666663333333333333333336633333333
333366333333333333333333333333333333333333333333
333333333333333333333333333333336633333300333300
333333333333333333333333000000000000000033333333
33333333333333333333336666663366666666999999CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99
999999666666666666666666666666666666666666666666
666633336666666666333333333333333333333333333333
333333333333333333333333333333333333333333003333
333333000033333333333333333333333366333333333333
333333333333333333333333333333333333333333333333
33333333333333333366333333336666666699999999CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC9999666666666666666666666666666666666666666666
666666333366666666333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333366336633333333
333333333333333333333333333333333333333333333333
333333333333333333333333336666666699999999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF9999996666666666666666666666666666666666666666
666666666666666666333333333333333333333333333333
333333333333333333333333333333333333333333330033
333333000033333333333333333333333366663366663333
333333333333333333333333333333333333333333663366
333333333366666633333366666666669999999999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC999999666666666666666666666666666666666666
666666666666666666333366333333333333333333333333
333333333333333333333333333333333333333333333300
333333333300003333333333333333333333666666336666
663333333333333333333333333333333333333333333333
33336666666633336666666666666666999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCC9999996666666666666666666666666666666666
666666666666666666666633333333333333333333333333
333333333333333333333333333333333333333333333300
333333333333000000333333333333333333336666666633
666666336633663333333333333333333333333333336633
666666663333666666666666666666999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF9999999966666666666666666666666666666666
666666666666666666666666663333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333300003333333366333333336666666666
336633333366333366663333333333333333333366336666
666633336666666666666666666699999999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC99999999996666666666666666666666666666
666666666666666666666633666633333333333333333333
333333333333333333333333333333003333333333333333
333333333333003333000000333333666633663333666666
666666333333663366333333333333333366666666663333
3366666666666666666666666699999999FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC999999996666666666666666666666666666
666666666666666666666666666633333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333330000336666666666333366
666666666666666666666666666666666666663333333366
66666666666666666666666699999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9999999966666666666666666666666666
666666666666666666666666666666333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333366666666663333
333366666666666666666666666666663333336666666666
666666666666666666666666999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99999966666666666666666666666666
666666666666666666666666666666336633333333333333
333333333333333333333333333333333300333333333333
333333333333333300333333333333333333336666666666
666666333333333333333366666666666666666666666666
666666666666666666666699999999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9966666666666666666666666666
666666666699666666666666666666666666666633333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333336666
666633666666666666666666666666666666666666666666
66666666666666669999999999CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF99996666996666666666666666
666666666666996666666666666666666666333366663333
663333333333333333333333333333333333333333333333
333333333333333333333333333333333333336666333333
666666333333333333333333336633333333333333666666
666666666666999999999999CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF99999966666666666666666666
666666669999999999666666666666666633666633666633
666666663333333333333333333333333333333333333333
333333333333333333336633333333333333333333336633
333366666633333333333333333366336666336666666666
6666666666669999999999CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC9999666666666666666666
666666669999999999666666666666666666666666336666
666666666666333333663333663333333333333333333333
333333336633333333333366333333666666333333333333
333333336666666633336666666666666666666666666666
66666666669999999999CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99996666666666666666
666666666699999999666666666666666633663366333333
666666666666336633666633333333333333663333333333
333333336666333333663333663333336666666666666666
333333333333336666666666666666666666666666666666
6666999999999999CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999999666666666666
666666669999999999999999666666666666666633666666
666666666666666666336666333333333333336633663333
336633336666666633666666666666333333666666666666
666666666666666666666666666666666666666666666666
6666999999999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999666666666666
666666666699999999999966666666666666663366666666
336666666666666666663366333333333333333366666666
666666666666666666666666666699666633333366666666
666666666666666666666666666666666666996666666666
66999999996666CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966666666
666666666666999999999999996666666666666666336666
663333666666666666666666663366336633333366666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666669966666666666699
999999666699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99999966
666699666666666666996699999999669966999999999966
666666666666666666666666666666666666666633336666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666699999999999999
666666CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999999
666666666666666666999999669999999999999999999999
999966666666666666666666666666669966666666333366
666666666666666666666666666666666666666666666666
666666666666666666666666666699669999999999996699
6699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
999966666666666666999999999999999999999999999999
999999999999666666666666996666666666666666663366
666666666666666666996666666666666666666666666666
666666666666666666666666996699999999999999996666
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
CC9966996666666666999999999999999999999999999999
999999999999999966666666669999666666666666666666
666666663333666666666699666666666666666666666666
666666666666666699666699999999999999999966666699
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCC99996666666666666699999999999999999999999999
999999999999999999999999666699999999666699996666
666666666666333333336666996666666666666666666666
6666666666666699669999999999999999996666669999FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC999966666666666699669999999999999999999999
999999999999999999999999996699999999996666999966
666666666666666666666666666666666666666666666666
996666669966669999999999999999999966669999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC99999999996666666699999966999966999999
999999999999999999999999999999999999999999999999
669999996666666666666666666666666666666666666666
66669999999999999999999999999966669999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF996666666666666666669999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999666666669999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99996666666666999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999999999999999CC
CCCCCC9999CC9999996666999999CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99999999999999CC99CC
CCCCCC99CC99CC9999999999999966999999999999999999
999999999999999999999999999999999999999999999999
999999999966666666999999CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
FFCCCCCCCCCC9999CC9999999999999999999999999999CC
999999999999999999999999999999999999999999999999
99999966666666669999CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCFFCCCC999999CC99999999999999996699
999999999999999999999999999999999999999999999999
999999999999999999CCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCFFFFCCCC999999999999999999999999
999999999999999999999999999999999999999999996666
6666669999CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC999999CC99999999
999999999999999999999999999999999999996699666699
999999CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC99
CCCCCC99999999999999999999999999CC99CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Green) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99CCCC99999999999999999999999999999999
99999999999999999999999999999999999999999999FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999999999CC9999999999999999CC99999999
999999999999999999999999999999999999999999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999999999999999999999999999999999999
999999999999999999999999999999999999999999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999999999999999999999999999999999
9999999999999999999999999999999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCC99
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999999999999999999999999999999999999999999999
99999999999999999999999999999999999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99CC9999CCCC
CCCCCC999999999999999999999999999999999999999999
99999999999999999999999999999999999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC99CC9999CC999999CC99CC99CCCC
CCCCCC99CC99CC9999999999999999999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC9999CC999999999999999999CC
99CC99CCCCCC99CCCC999999999999999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999
999999999999CC9999CC99CC999999999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
9999CC99CC999999999999CCCCCC99999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
9999CC999999CC99999999999999CCCC9999999999999999
999999999999999999999999999999999999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999
99CCCCCCCC9999999999999999999999CC99999999999999
9999999999999999999999999999999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99
99CCCCCCCCCCCCCC999999999999999999CC999999999999
9999999999999999999999999999999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99CCCCCCCCCCCCCC999999999999999999CCCC999999
9999999999999999999999999999999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC99CCCCCCCC9999999999999999999999CCCC9999
99999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999CCCC99
99999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC999999999999999999999999CCCC
CC999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
CC999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
CCCC9999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC99CC99999999999999999999999999
CC999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999999999999999
99CC99CCCC99999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999999999999999
99CCCC9999CCCC9999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC99CC999999999999999999999999
9999CC9999CCCC9999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC9999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999CC9999999999999999999999
99999999999999CC99999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF996666CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
99999999999999CCCC999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC663399CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
9999999999999999CCCC9999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC66333399CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC99999999CC999999999999
9999999999999999CCCCCC99999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF9933333366CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99CC99999999CC999999999999
999999999999999999CCCCCC999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF996633333366CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC999999999999CC999999999999
9999999999999999999999CCCCCC99FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF6633333333CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC999999999999CC999999999999
999999999999999999999999CCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC6633333399CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
99999999999999999999999999CCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF6666333399CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99CC99999999CC999999999999
99999999999999999999999999CCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333399CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC9999999999CC9999CC999999999999
9999999999999999999999999999CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC66336699CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999999999999999
9999999999999999999999999999CCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC66333399CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC99CC99999999999999999999CC99999999
999999999999999999999999999999CCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF9933333366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999CCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF6633333399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999CC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999CC99CCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCC33333399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999CCCCCCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF66333366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC9999CC99999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999CC99CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC663366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999966999999999999
669999999999999999999999999999999999999999999999
999999999999999999999999999999999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC663399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
996699999999999999999999999999999999999999999999
999999999999999999999999999999999999CC99CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF663366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCFFCCCCCCCCCC999999999999999999999999
999966999999669999999999999999999999999999999999
99999999999999999999999999999999999999CCCCCCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC993399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999996666666666669999996699
669966999999999999669999999999999999999999999999
999999999999999999999999999999999999999999CCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
999933CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999996666666666666666666666996666
666666666666666699999999999999999999999999999999
999999999999999999999999999999999999999999CCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99
666666CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999966666666666666666666666666666666
666666666666666699666699999999999999999999999999
99999999999999999999999999999999999999999999CCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9966
6633CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99999999666666999999669999666666666666666666
666666666666666666999966999999999999999999999999
99999999999999999999999999999999999999999999CCCC
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966
3333CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999966999999CC999966CCCCCCCC99669999996666
666666666666666666666666999999999999999999999999
9999999999999999999999999999999999999999999999CC
FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996633
3366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999
999966669999CCCCCCCCCCCC99CCCCCCCCCC99CCCCCCCC99
666699666666666666666666669999999999999999999999
999999999999999999999999999999999999999999999999
CCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99666633
3399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999966
66666666996699CCCCCCCCCCCCCCCCCCCCCC99CCCCCCCC99
669999996666666666666666666699999999999999999999
9999999999CCCC9999999999999999999999999999999999
CCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99666633
66CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC9999CCCCCCCCCC999999999999996666
6666666666996666999999669999999999CC99CCCCCCCC99
999999996633336666666666669966999999999999999999
99999999999999CCCCCC99999999999999999999999999CC
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99663333
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999CCCCCCCC99999999999966330066CC
9999669999996666CCFFFFFFFFCCCC996666999999666666
999999999966666666666666666699669999999999999999
9999999999CCCCCCCCCCCC99999999999999999999999999
99CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663366
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999999CCCCCC99666666666699CCCC99CCFF
FFCCCCCCCCCC9999FFFFFFFFFFFFCCFFCCCCCCCCCCCCCC99
666699999999666666663366666666666699999999999999
99999999CCCCCCCCCCCCCC99999999999999999999999999
9999CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999333399
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC999999999999CCCC666666330066CCCCFFCCCCFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFFFCCFFCCCCCCFFCCCCCCCC
CC9966666666669966663333666666666699999999999999
999999CCCCCCCCCCCCCCCCCC999999999999999999999999
99CCCCFFFFCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9966663333CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99999999999999666666333366CCCCCCFFCCCCFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFFFFFCCCCCCFFCCCCCCCCCC
CCCC66666666666666333366336666666699999999999999
99999999CCCCCCCCCCCCCC99999999999999999999999999
99CCCCCCFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6666333366CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999999999999966663333336699CCCCCCCCFFFFFFFF
FFFFFFFFFFFFFFCCFFFFFFFFFFFFFFCCCCCCFFFFFFFFCCCC
CCCCCCCC9999666666333333333366666699999999999999
99999999CCCCCCCCCCCCCCCCCC9999999999999999999999
9999CCCCCCFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC6633333366CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99999999996666333333336666CCCCCCFFFFFFCCFFFF
CCFFFFFFFFFFCCCCFFFFFFFFFFFFCCCCCCCCFFCCFFCCFFCC
CCCCCCCCCCCC996633333333330033666666669999999999
99999999CCCCCCCCCCCCCCCC999999999999999999999999
9999CCCCCCCCFFCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCFFFFFFFFFFCC9966333399CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999996699333333333333666699CCCCFFFFCCCCFFFF
CCFFFFFFFFFFCCCCFFFFFFFFFFFFCCCC99CCFFFFFFFFCCCC
CCCCCCCCCCCCCC9966666633000000336666669999999999
99999999CCCCCCCCCCCCCCCCCC9999999999999999999999
9999CCCCCC99CCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9966333366CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999999933333333333333996699CC9999CCCCCCCC
CCCCFFFFFFCCCCCCCCFFFFFFCCCCCCCC9999CCCCFFCCCCCC
CC99CCCCCCCCCCCCCCCCCC99336666000066666666999999
999999CCCCCCCCCCCCCCCCCCCC99CC999999999999999999
999999CCCC99669999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC6633333399CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999999966666633333366996699999999CCCCCCCC
CCCCCCFFFFCC99CCCCCCFFCCCCCC999999CCCCCCCCCCCCCC
9999CCCCCCCCCCCC99CCCCCC999999333333336666999999
99999999CCCCCCCCCCCCCCCCCC9999999999999999999999
999999CCCCCC99CCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966333333CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999666633336666669999999999CCCCCC
9999CCCCCC9999CCCCCCCCCC99999999999999CCCCCCCCCC
9966CCCCCCCCCC9999CCCC99999999666633333366669999
99999999CCCCCCCCCCCCCCCCCCCC99999999999999999999
9999CCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCC993333333333CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
99669999999999CC99999999666666669999999999999999
9966999999999999CCCCCC99666666666699999999999999
666699CCCCCCCC99CCCCCC99999999996633333333669999
99999999CCCCCCCCCCCCCCCCCCCC99999999999999999999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCC9966333333333366CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
996699999999CCCCCCCCCCCCCCCC99999999999999999999
999966999999999999999999669966666666666699999966
996699CCCCCC999999CCCC99999999996633333333336699
99999999CCCCCCCCCCCCCCCCCC99CC999999999999999999
9999CCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC663333333333333399CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCCCCCCCCCCCCCCCC
99669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
9999CCCC9999999999999999999999996666666666666666
66666699CC99996699CCCC99999999996633003333336699
99999999CCCCCCCCCCCCCCCCCCCC99999999999999999999
999999CCCCCCFFFFFFFFCCCCCCFFCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF993333330033333333CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
99996699CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC99CC999999999999999999996666666666
66666699999966669999CC99999999666633000000333366
9999999999CCCCCCCCCCCCCCCCCC99999999999999999999
999999CCCCCCCCFFFFFFCCCCFFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCCCC333300333333333366CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999996699
996666666666666666999999666666663333000033333333
6699999999CCCCCCCCCCCCCCCCCC99999999999999999999
99999999CCCC996699CCCCFFCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCC99333333333333333399CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999
999999996699666666669999666666663333000033333333
3399999999CCCCCCCCCCCCCCCC9999999999999999999999
99999999CCCC996666CCCCCCCCFFCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCC99333333333333333399CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999996666666666666666336633666666
3399999999CCCCCCCCCCCCCCCCCC99999999999999999999
9999999999CC99663366FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC99663333333333333333CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999996699666666
6699999999CCCCCCCCCCCCCCCCCC99999999999999999999
9999999999CC9966663399FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC66333366999999663366CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999999999999999999999669966
9999999999CCCCCCCCCCCCCCCCCC99999999999999999999
9999999999CC996666996699FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC6633CCCCCCCCCCCC9999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999999999999999999999999999
9999999999CCCCCCCCCCCCCCCCCC99999999999999999999
9999999999CCCC9999999999CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC6666CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999999999999999
999999999999CCCCCCCCCCCCCC9999999999999999999999
99999999999999666699CCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC9966CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999999999999999
9999999999CCCC99CCCCCCCCCC9999999999999999999999
9999999999CC99666699CCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999999999999999999999999999
9999999999CCCC99CCCCCCCC99CC99999999999999999999
999999999999CC333366CCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCCCCCCCC999999
999999999999999999999999999999999999999999999999
99999999CCCC9999CCCCCCCCCC9999999999999999999999
9999999999CC9933336699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999CC999999
999999999999999999999999999999999999999999999999
9999999999999999CCCCCC99999999999999999999999999
9999999999999933336699CCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999CC99CC999999999999999999999999
9999999999CC993333669999CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC9999999999CC999999999999
999999999999999999999999999999999999999999999999
999999999999999999CC9999999999999999999999999999
99999999999999333333336699FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC9999CC99CC99999999999999
999999999999999999999999999999999999999999999999
99999999999999CC99999999999999999999999999999999
9999999999CC99333333333399FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999CC9999999999999999
999999999999999999999999999999999999999999999999
999999999999CCCC99999999999999999999999999999999
999999999999993333333333CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCCCC99CC99CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFFFFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99CC9999999999
999999999999999999999999999999999999999999999999
999999CC99CCCC9999999999999999999999999999999999
9999999999CC993333336699CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCCCC99CC99CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
999999999999999999999999999999999999999999999999
99CCCCCCCC99CC9999999999999999999999999999999999
9999999999999933333366FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCC99CC9999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999
999999999999999999999999999999999999999999999999
99CCCCCC99CCCC9999999999999999999999999999999999
9999999999CC66333333669999CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCCCCCCCCCCCCCC9999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCCCFFCCCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC9999999999
999999999999999999999999999999999999999999999999
99CCCCCCCCCCCCCC99999999999999999999999999999999
9999999999CC9933333333333399CCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCCCCCCCCCC99CC99CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
9999999999999999999999999999999999999999999999CC
CCCCCCCCCCCC99CC99999999999999999999999999999999
999999999999663333333333336699CCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCCCCCCCC9999CC99CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCC99999999999999
99999999999999999999999999999999999999999999CCCC
CCCCCCCCCCCCCCCC99999999999999999999999999999999
99999999CCCC99663333333333336699CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFCCFFCCCCCCCCCCCCCCCC99CC999999999999
99999999999999999999999999999999999999999999CCCC
CCCCCCCCCCCCCC9999999999999999999999999999999999
9999999999CC9999666666333333666699CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFCCFFFFCCFFCCFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999CCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999999999999999
99999999CCCC99999966666633333333336699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
9999999999999999999999999999999999999999CCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999999999999999
999999CC999999999999666666333333336699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCCCFFCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
99999999999999999999996699999999999999CCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999999999999999
99999999CCCC999999999999996633666699CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCC99999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999999999999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999999999999999
999999CCCC9999999999999999996666CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCC99999999666666999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
9999999999999999999999999999999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999999999999999
9999CC99CCCC999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCC99999966999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999CCCCCCCCCCCC
CCCCCCCCCCCC99CC9999CC99999999999999999999999999
99999999CCCC9999999999999999CCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
CCCCCCCC9999666666999999999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
9999999999999999999999999999999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999CCCC99999999999999999999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
CCCCCCCC99999999999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999CCCCCCCCCCCC
CCCCCCCCCCCC999999999999999999999999999999999999
99999999CCCC9999999999999999CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
CCCCCCCC999999996699999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
99999999999999999999999999999999CCCCCCCCCCCCCCCC
CCCCCCCCCC9999CC99999999999999999999999999999999
999999CCCCCC9999999999999999CCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
CCCCCCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
9999999999999999999999999999CC9999CCCCCCCCCCCCCC
CCCCCCCCCCCC99CC99999999999999999999999999999999
999999CC99CC999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC
CCCCCCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999CC99CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999999999999999
999999CCCCCC999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC
CCCCCCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
99999999999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99CC9999999999999999999999999999999999
999999CC999999999999999999999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
CCCCCCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
9999999999999999999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCC9999CC999999999999999999999999999999999999
999999CCCCCC99999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
CCCCCCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
99999999999999999999999999CC99CCCCCCCCCCCCCCCCCC
CCCC999999CC99CC99999999999999999999999999999999
999999CCCCCC99999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
CCCCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
99999999999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC99CC999999999999999999999999999999999999
9999CC999999999999999999CC99999999FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9999CC
999999996666669999999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999CCCCCCCCCCCCCCCCCCCCCCCC
CC9999CC99CC999999999999999999999999999999999999
999999CCCCCC666699999999CC99999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC999999
999999666666666666669999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
9999999999999999999999CC9999CCCCCCCC99CCCCCCCCCC
CCCCCC99CCCC999999999999999999999999999999999999
999999CCCC99666666999999CC9999999999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99999999
999999336666666666666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999CC99CCCC9999999999999999
CC9999999999999999999999999999999999999999999999
99999999CCCC666666999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99999999
996666996666666666666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
99999999999999999999999999CC9999CCCC9999999999CC
999999999999999999999999999999999999999999999999
999999999999666666999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99999966
666699996666666666666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99CC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
99999999999999999999999999999999CCCC99CC99999999
9999CC999999999999999999999999999999999999999999
99999999CCCC66666699999999999999999999FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC99999966
336699996666666633666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC99CC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999CC9999999999
999999999999999999999999999999999999999999999999
999999CC999966669999999999999999999999FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9999999933
339999666699666633666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
9999999999999999999999999999999999CC999999999999
999999999999999999999999999999999999999999999999
999999CCCC9966666666666666999999999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9999CC6633
666633336666669966666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC99999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999CC999966666666666633666699999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999999996633
666600336699663366666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
CCCC99CCCCCC999999999999999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999CC9999999999
999999999999999999999999999999999999999999999999
99999999999999666666666666666666999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996699CC6666
663300663333333333666699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999CC9999999999999999999999
99999999999999999999999999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
9999999999999999999999999999999999999999CC99CC99
9999999999CC99CC99999999999999999999999999999999
9999CC9999999966666666666666666699999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC999999CC6633
663300333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999996666666666666699999999999999
9999999999999999999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999CC9999CC9999999999999999999999999999
999999CC99999966666666666666666699999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC996699CC9933
330033333333333333333399CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999CC9966663333666666999999666666
666666669999669999999999999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999999999999999
99CCCC9999CC999999999999999999999999999999999999
9999999999999966666666666666666699999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996699CCCC9933
330000003333333333333399CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC99CC99666633336699CCCC99333366
333333333366666666669999666699999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999999999999999
99CCCCCC9999CC9999999999999999999999999999999999
9999999999999966666666666666666666999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99669999CC9933
000000333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC99CC99996633339999CCCC66339999
330000336633336666666666666666666699CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999CCCCCC99999999999999999999999999999999
9999999999999966666666666666666666999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996666CCCC9933
000033333333333333333399CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC9999CCCC99999933669999336699CC
66000033666666669999996666666666669999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999666699
99999999CC9999CCCCCCCCCCCCCCCCCCCC99999999999999
999999999999999999999999999999999999999999999999
9999999999996666666666666666666666999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9966999999CC66
3333333333333333336666CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC999999CC99999966333333669999
6600003366666666999999666666669999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999966666666
99999999CCCCCCCCCC99CCCC999999CC9999CCCCCC999999
99999999999999CCCCCC9999999999999999999999999999
9999999999996666666666666666666699999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99CCCC66666699999999
3333000033333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC999999CCCC9999996633333366
3300003333333366999999666666999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999996666666633
6666669999CCCC9999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999996666666666666666669999999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF6633CCCC99666699999999
333333333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999CCCCCCCC9966663333
3300333333333366666666666666669999CCCCCCCCCCCCCC
CCCCCCCCFFCCCCCCCCCCCCCC999999999999996699666633
333333669999999999996699996666666666669999999999
999999999999999999999999999999999999999999999999
9999999999996666666666666666999999999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF990033CCCC996666CCCCCCCC
6600333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CCCC999999666666
66333333333333666666666666669999CC99CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999666666
333366999999999999666666666666666666666666666699
999999999999999999999999999999999999999999999999
9999999999996666666666666699999999999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC6633003399CCCCCCCCCCCCCC99
6600333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CC99CCCC669999
6666666666666666669999666666CCCCCC99CCCCCCCCCCCC
CCCCFFFFFFCCCCCCCCCCCCCC999999999999999999996666
6666669999CCCCCCCC666633333333336666666666666666
669999999999999999999999999999999999999999999999
9999999999666666666666666699999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF993333003399CCCCCCCCCC99CC99
6633333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999CCCC99CC99
996666666666666666999966669999CC9999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999996699996666
6666336699CCCCCC99333333333333333333666666666666
666699999999999999999999999999999999999999999999
9999999999666666666666666699999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9933333300339999CCCCCCCC999999
6633333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999CC99
999999999966669999666699999999999999CCCCCCCCCCCC
CCCCFFFFCCCCCCCCCCCCCCCC999999999999996699999966
666666669999CCCC66669933003333336666336666666666
336666666666666666666699999999999999999999999999
9999999999666666336666666699999999996666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF99333333330000336699CCCC99999966
3333333333333333333366CCCCCCCCCCCCCCCCCCCCCC9999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999CCCCCCCCCCCCCCCCCC
CCFFCCFFCCCCCCCCCCCCCCCC999999999999999999999999
666699996666666666999933003333336633336699999966
663333336666666666669999999999999999999999999999
9999999966663366666633336699999999666699CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC66333333330000003366999966666633
3333333333333333333366CCCCCCCCCCCCCCCCCCCCCCCC99
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999999999999999999999CCCCCCCCCCCCCCCCCCCC
CCFFCCCCCCCCCCCCCCCCCCCC999999999999999999999999
996666999999666633999933003366663333336699996666
333333333333666666999999999999999999999999999999
9999999966336633336633336699999999666666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC33333333330000000033666666333333
3333333333333333333366CCCCCCCCCCCCCCCCCCCCCCCC99
999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC
CC99999999999999999999999999CCCCCCCCCCCCCCCCCCCC
FFCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999966999999996666666633000033333333336666663333
333366666666669999999999999999999999999999999999
9999999966666633666633333399999999666699CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333330000000000000066333333
3333333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999CC99CCCCCCCCCCCCCCCCCCCC
CCFFCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999666633330033333333336666333333
336666666666999999999999999999999999999999999999
9999996633333333333333333399999966666699CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333330033333300000033333333
3333333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
99999999CC99CCCCCCCCCCFFCCFFCCCCCCCCCCCCCCCCCCCC
CC99999999999999999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999996666666633333333333333333333
666666669966999999999999999999999999999999999999
9999996633333333333333333399999966666699CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6633333333330033333300000033333333
3333333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CC99999999999999CCCCCCFFCCFFCCCCCCCCCCCCCCCCCCCC
99999999CC99999999999999999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
99999999999999CC99996666666666663333666633336666
996666999999999999999999999999999999999999999999
9999996633333333333333333399999966666699CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633333333333333333333333333333333
3333333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC99
99999999999999999966666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999966666666666666666699
669966669999999999999999999999999999999999999999
9999666633333333333333333399999966666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333333333333333333333333333333
0033333333333333333366CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99CC99999999999999999999999966666666666666
66666666666666666666666666669999CC99CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999999999999999999999996666669966
666699999999999999999999999999999999999999999999
9999663333333333333333333399996666666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333333333333333333333333333333
333300333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999999999999999996666666666666666
6666666666666666666666669999999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999666699
999999999999999999999999999999999999999999999999
9999663333333333333333336699996666666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333333333333333333333333333333
333333003333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99996666669999996666666666666666
66666666666666666666669999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999669999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9966333333333333333333006699996666666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333333333333333333333333333333
333333333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999966996666669999999966666666
66666666666666666666669999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC99CC99999999996666666666
666699999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9966333333333333333333336699666666666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333333333333333333333333330033
333333333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
9999999999999999999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999996666666666
666666999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9933333333333333333333339999996666666699CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633333333333333333333333333330033
33333333333333336633669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC99CCCC99CCCCCCCCCC99CC
CC9999CCCCCC99CC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC99CC999999996666666666
666666666699999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
663333333333333333333366999999666666999966FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633333333333333333333333333330033
33333333333333333366669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC9999996666666666
333333666666999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
663333333333333333333366996666666666669966CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6633333333333333333333333333333300
33333333333333333333669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCC
FFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCCCC9999666666
666666333333666666669999999999999999999999999999
999999999999999999999999999999999999999999999966
66333333333333333333336666996666666666663399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633333333333333333333333333333300
0033330033333333333366999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCCCCC
CCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999966
666666333333333333336666669999999999999999999999
999999999999999999999999999999999999999999999966
33333333333333333333333366999966666666663399CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333300
0033333333333333333366999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCFFCCCCFFFF
CCCCFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
996666666633333333333333336666999999999999999999
999999999999999966666666669999999999999999999966
3333333333333333333333336699999966669966666699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333300
00003333333333333366669999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFCCFFCCCCFFFFCCFFFFCCFFFFCC
FFFFFFCCFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999666666663333333333333333666699999999999999
999999999999666666666666999999999999999999999966
3333330033333333333333333366666699666633336699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333333
000033333333333333666666999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCFFFFFFFFFFCCFF
FFFFFFFFFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999996666666666663333333333333366666666669966
996666666666666666666699999999999999999999999966
3333333333333333333333333366666666666633666699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333333
330000333333333333336666999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFFFCCFFFFFFFFCC
CCFFCCFFFFCCFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99999999996666666666333333333333666666666666
666666666666666666669999999999999999999999999933
3333333333333333333333333333333333333333666699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333333
330000333333333333666666999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCCCFFFFFFFFFFFFFFFFFFCC
FFFFFFCCFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC99CC999999999999666666666666333333336666666666
666666666666666666999999999999999999999999999933
33333333333333333333330000333333333333336699FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333333
330000003333333333336666999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999999999666666663333333366336666
666666666666666699999999999999999999999999999933
333333333333333333333333000000333333333366CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966333333663333333333333333333333
33333333333333333333666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCCCFFCCFFFFFFFFFFCCFFFF
FFCCFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
CC99CC99CCCC999999999999999999996666666666666633
336666666699999999999999999999999999999999996633
333333333333333333333333333333333333333366CCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9966333333663333333333333333333333
33333333333333333333666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFCCFFFFFFFFFF
FFFFFFFFFFCCFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999CCCCCC9999999999999999999999666666666666
666666669999999999999999999999999999999999996633
3333333333333333333333003333333333333333666699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666336633666633333333333333333333
33333333333333333366666666999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFFFCCCCFFFFFFFFFFCCFFFF
FFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999CC9999999999999999999999999999999999
999999999999999999999999999999999999999999663333
333333333333333333333333003333333333333333336699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633336633336633333333333333333333
3333333333333333336633666699999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFFFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFCCFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999999999999999
999999999999999999999999999999999999999999663333
333333333333333333333333333333333333333333666699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996633333333333333333333333333333333
333333333333333333333366666699999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99CC999999999999CC99999999999999999999
999999999999999999999999999999999999996666663333
333333333333333333333333333333333333333333333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996633333366333333333333333333333333
333333333333333333333366666699999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFFFCCCCFFCCFFCCCCFFFFFFFF
FFFFFFFFFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC99CCCC9999CCCC999999CC9999CC999999999999
999999999999999999999999999999999999999966333333
333333333333333333333333333333333333330033336666
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666663333336633333333333333333333
333333333333333333333333666699999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFCCCCCCCCFFFFFFCCFFCCFFFFFF
FFFFFFFFFFFFFFCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99CC999999CC999999999999999999999999
999999999999999999999999999999999999996666333333
333333333333333333333333333333333333000033336633
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633336666663333333333333333333333
333333333333333333333366336666669999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFF
FFCCFFCCFFFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC9999CCCC99CC999999CC9999CC9999999999999999
999999999999999999999999999999999999666633333333
333333333333333300003333333333333333003333333366
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333336666333333333333333333
33333333333333333333333333336666999999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCFFCCCCCCFFCCFFFFCCCCFFCCFFCC
FFFFFFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC999999CC99999999CCCC99999999999999999999
999999999999999999999999999999999966666633333333
333333333333330000333300333333333333003333333366
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333663333333333333333333333
33333333333333333333333333663366666699CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFCCFFFFCCFFFFFF
FFFFFFFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999CC9999999999CC9999999999999999999999
999999999999999999999999999999999966663333333333
333333333333000033330033333333330000333333333366
99CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF333333663333333333663333333333333333
3333333333333333333333336633666666669999CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFCCFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
CCCCCC9999CC99999999999999CC99999999999999999999
999999999999999999999999999999996666663333333333
333333333333000033003333003333330033333333333366
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF333333336633663333663333333333333333
333333333333333333333366666666666666999999CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFCCFFFFFFFF
FFFFFFFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999CCCCCC99CC9999999999999999999999999999999999
999999999999999999999999999999996666333333333333
333333333300333333333300330033333300333333333366
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633336633666633663333333333333333
333333333333333333333333666666666666999999CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFCCFFFFFFFFFFFF
FFFFCCFFCCCCCCFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC
CC99CC9999CC999999999999999999999999999999999999
999999999999999999999999999999666666333333333333
333333330000330033330033000033330033333333333333
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633336633333366663333333333333333
333333333333333333333333663366666666999999CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFFFFFFFFFFF
FFFFFFFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999CC9999999999999999999999999999999999999999
999999999999999999999999999999666666333333333333
333333000000003333330000003300333333333333333366
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666633336633333366336633333333333333
333333333333333333333333336666666666999999CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999CC9999999999999999999999999999999999999999
999999999999999999999999999999666633333333333333
333333333333333333000000003300333333333333333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333366333333336666333333333333
33333333333333333333333333333366666699999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFFFCCFFFFFF
FFFFFFFFCCFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999999999999999999999999999
999999999999999999999999999966663333333333333333
333333333333333300000000000000333333333333333399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF99333333333333333333336666333333333333
33333333333333333333333333336666666699999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFFFFFCCFFCCFFFF
CCFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
99CC99999999999999999999999999999999999999999999
999999999999999999999999996666663333333333333333
333333333333330000000000003333333300333300336699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC663366333333666666336666663333333333
33333333333333333333333333336666666699999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFF
FFFFCCFFFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99999999
99CC99999999999999999999999999999999999999999999
999999999999999999999999669966663333333333333333
3300333333330000003300003333003333333333333366CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCC666666333333666666336666663333333333
3333333333333333333333333366336666669999999999CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFCCFF
CCFFFFCCCCFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99CC99CC99
9999CC999999999999999999999999999999999999999999
999999999999999999999999996666333333333333333333
333333003333000000000033330000333333333333336699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333666633336666666633333333
3333333333333333333333333333666666666699999999CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCFFCCFFFFCC
FFCCFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC999999
999999999999999999999999999999999999999999999999
999999999999999999999999666666333333333333333333
333333333333003300003333000033333333333333336699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC336633333333666666663366336633333333
3333333333333333333333333333666666669999999999CC
CCCCCCCCCCCCCCCCCCCCCCCCFFCCCCFFCCFFFFCCFFFFCCCC
FFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999CC99
999999999999999999999999999999999999999999999999
999999999999999999999999666666663333333333333333
333333333333330000333333003300333333333333336699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC336633333333336666666666666633333333
3333333333333333333333333333336666666699999999CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCFFFFCCFFCCCCFF
FFCCFFCCFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CC99
CCCC99999999999999999999999999999999999999999999
999999999999999999996666666633333333333333333333
3333333333333333333333333300333333333333333366CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666633333333336666666666663333333333
333333333333333333333366336633666666669966999999
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCFFCCFFFF
FFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC99CCCC99CCCCCCCCCCCCCCCCCC99CC999999CC99
999999999999999999999999999999999999999999999999
999999999999996666666666666666333333333333333333
33333333333333333333333333333333330000333366CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC663366333333333366666666663366333333
333333333333333333333333336666666666666666999999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFFFCCFFFFFFCCFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC99CCCCCCCC99CCCC99999999
9999CC999999999999999999999999999999999999999999
999999999999999999666666663333333333333333333333
33333333330000333333333333000033000033333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC663333333333333366666666666666333333
333333333333333333333333336633336666666699669999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCCCCCFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC99CCCCCCCCCC99999999CC99
999999999999999999999999999999999999999999999999
999999999999666666666666333333333333333333333333
33333333000033330000000000000033003333333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666633333333336666663333666666333333
333333333333333333333333336666336666666666669999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCFFCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC999999
999999999999999999999999999999999999999999999999
999999999999996666666666333333333333333333333333
33333333333333000000000000000033003333333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666633333333333333666633666666663333
333333333333333333333333333366336666666666669999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999
999999999999999999999999999999999999999999999999
999999999999996666666633333333333333333333333333
333333333333000000330000000000333333333333CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666633333333333333666666666666333333
333333333333333333333333333333666666666666666699
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC99CCCCCC99CCCCCC99CC99CC99CCCCCC99999999
999999999999999999999999999999999999999999999999
999999999966666666663333333333333333333333333333
333333333333000033000000000000003333333333CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC996633333333336633336666666633336633
333333333333333333333333333333666633666666996699
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999CCCCCCCC99CCCCCC99CCCC999999999999
999999999999999999999999999999999999999999999999
999999996666666666333333333333333333333333333300
333333333333333300000000000000333333333366FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666333333336633336666336666333333
333366333333333333333366333333336633333366669999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
99CCCC999999CCCC99CCCC99CC99CC99CC99CC9999999999
999999999999999999999999999999999999999999999999
996699996666666633333333333333333333333333333333
333333333300333300330000000033333333333399FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666333333336633333366333366333333
333333333333333333333333663333336666333366666666
999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
CC99CC99CC999999CCCC999999CC99999999999999CC9999
999999999999999999999999999999999999999999999999
999999666666666633333333333333333333333333333333
3333333333333333000000000033333333333366CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666663333336633333366663366333333
333333663333333333333333663333333333336633666699
66999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
99CCCCCCCC99CCCCCCCCCC9999CC99999999999999999999
999999999999999999999999999999999999999999999999
996666666666666633333333333333333333333333333333
3333333333333333330000330000333333333399FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666663333336666333366663366663333
333333333333333333333333333333333366663333666666
99999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
CCCC999999999999999999CCCC9999999999999999999999
999999999999999999999999999999999999999999999999
666666666666333333333333333333330033333333333333
33333333333333333300000000333333333366CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666663333333366333366663366663333
336633333333333333333333336633333333666666336666
6666999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CC99
CC9999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999966
996666666666333333333333333333333333333333333333
33333333333300000000000000333333333366CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666666633333366663333666666666633
333333333333333333333333333333333333333366663366
669999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCC99
9999999999CC99999999CC99999999999999999999999999
999999999999999999999999999999999999999999996666
996666666633333333333333333333333300003333333333
33330033000000000000000000333333333399FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666666633333366333333333366666666
333366333333333333333333333366663333666633666666
666699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC999999
99CC9999999999CC99CC99999999CC999999999999999999
999999999999999999999999999999999999999999999966
666666663333333333333333333333330000000000003333
33330000000000000000000033333333333399FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9966666633333333666633336633666666
333333333333333333333333333333336666333333666633
6666666699999999CC99CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999666666666666
666666333333333333333333333333330000000033333333
333300000000000000000000333333333366CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666666663333666633333333666666
333333333333333333333333333333666666333333333366
336666669999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999666666666666
666633333333333333333333333333003300333300000000
003300000000000000000033333333333399FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC66666666663333666666333333666666
663333333333333333333333333333666633663333333366
6666666666666699999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999966996666666666
666633333333333333333333333333333333000000000000
0033000000000000000033333333333333CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99666666663333666666333333336666
333333333333333333333333333333336666666633333333
33663366666666669999999999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999966666666666666
663333333333333333333333333300000000000000000000
0000000000000000000033333333333366FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99666666333333336666663366336666
666633333333333333333366333333333366336666663333
33336633666666666666666699999999999999999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999966666666666666
663333333333333333333333000000003300000033330000
00000000000000000033333333333333CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC666666663333336666333333333366
663333333333333333333333666633333333666666666633
333333666666666666666666669999999999999999999999
CC999999CCCCCCCCCC9999CCCCCC99999999999999669999
999999999999999999999999999999999999999999999999
999999999999999999999999999999669966666666666666
333333333333333333330033330000000000000000333300
00000000000000000033333333333366FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC666666663333336666666633333366
663333333333333333333333336666663333666633666666
663333333366666666666666669999999999999999999999
9999999999999999CC9999CCCCCC99999999666699666699
999999999999999999999999999999999999999999999999
999999999999999999999999999966666666666666666633
333333333333333333003333333300000000000000000000
00000000000000003333333333333366FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC996666666633333366666633333333
663333333333333333333333333333666666336633666666
666666333333666666666666666699999999999999999999
999999999999999999999999CCCC99999999996666666666
666666996699999999999999999999999999999999999999
999999999999999999999999666699996666666666336633
333333333333333333333333333300000000000000000000
000000000000003333333333333333CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCC9966666633333333666633333333
336666333333333333333333333333333333666666663333
336666666666666666666666666699996666669999999966
666699996699999999999999999999666666666666666666
666666666666999999999999999999999999999999996699
999999999999996699669966666666666666666633333333
333333333333333333330000330000000000000000000000
000000000000333333333333336699FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9966666666333333666633333333
336666663333333333333333333333333333666666666666
663366663366666666666666666666666666666666996666
666666996666669999999999999999996666666666666666
666666666666666666999966999999999999999999999966
666666666666996666666699666666666666666633333333
333333333333333333333300000000000000000000000000
0000000000003333333333333366CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC66666666333333666633336633
336666333333333333333333333333663366666666666666
666666666666666666666666666666666666666666666666
666666666666669966999999996666666666666666666666
666666666666666666666666666699999999999999996666
666666666666666666666666666666666666333333333333
333333333333333333330000003333000000000000000000
0000000000003333333333333399FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99666666333333336666336666
333366663333333333333333333333666666666666666666
336666666666666666666666666666666666666666666666
666666666666666666666666996666666666666666666666
666666666666666666666666666666666699669966996666
666666666666666666666666666666666633333333333333
333333333333333300330000000000000000000000000000
00000000003333333333333333CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99996666663333333366333333
333366663333333333333333333366666666666666666666
666666666666666666666666666666666666666666336666
336666666666666666666666666666666666666633666666
663333666666666666666666666666666666666666666666
666666666666666666666666666666663333333333333333
333333333333333300000000000000000000000000000000
00000000333333333333333366FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC996666663333333366333333
663366663333333333333333333366666666666666666666
666633666666666666666666666666666666333366336666
336666663366666666666666666666666666666666666666
663333336666666666666666666666666666666666666666
666666666666666666666666666666333333333333333333
333333333333333333000033000000000000000000000000
00000000333333333333333399FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC996666666633333366663333
333333663333333333333333333333336666666666666666
666633336666666666666666666666666666333333336666
663333666666336633666666666666666666666633333333
336633333333336666666666666666666666666666666666
666666663333336666666666663366333333333333333333
333333333300333333000000000000000000000000000000
000000333333333333333333CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC9966666633333333666633
336666336633333333333366666633666666666666666666
666633336666666666666666666666336666333333336666
333333336666333366333333666633333333663333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333330000003333333300000000000000000000000000
0033333333333333333333CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF9999666666663333666666
333366336666333333333366666666666666666666666666
666666663333666666666666336666336633333333333333
333333336666333333666633663366333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333000000003300330000000000000000000000000000
3333333333333333333399FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC9999666666333333336666
333333663366663333333333666666666666666666666666
666633336666333333996633666633663366333333333333
333333333366336633666633336633333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333000000003300000000000000000000000000000033
33333333333333663366CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99666666663366333366
333333663366666666333333336666666666666666666666
663366666666663366666633663333336666333333333333
333333333366663333336633333366333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333330000000033000000000000000000000000000033
333333333333336633CCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99996666663366333333
663333336633336666666666333366666666666666666666
666666666666666666663333666633336666333333333333
333333333366663333333366333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
330033330000000000000000000000000000000000003333
333333333333333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCC999966666666333333
336633336633333366666666666633336666666666666666
666666666666666666663333663333333333333333333333
333333336633333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333300330000000000000000000000000000000000003333
3333333333336699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCC999966666633336633
336666336666333333666666666666663333666666666633
333333336666663366663333663333333333333333333366
333333336633333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333330000
333333330000000000330000000000000000000000333333
33333333333399CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9966666633333333
333366663366666633333366666666666666333333666666
666666663333333366333333333333333333333333333366
333333333366333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333000000
000000000000000000000000000000000000003333333333
003333333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99666666333366
663333663333333366333366666666666666663333333366
666666666633333333333333333333333333333333333366
333333333366333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
000000000000000000000000000000000033333333333333
3333333366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666333333
663333663333333366663333336666666666666666666666
333333333333336666333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333003333333333333333333333000033333333333333
330000000000000000000000000000003333333333333333
3333336699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC9933333333
666666336633333333336633333333666666666666666666
666666663333666633333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
003333003333333333333333333333330000333333333333
330000000000000000000000000033333333333333333333
33336699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9966663333
336666666666333333333333666666666633666666666666
666666663333333333333333333333333333333333333333
333333333333333333333333333333333333333333330033
333333333333000033333333333333003333333333333333
330033333333333333333333333300000000003333000000
000000000000000000000000000033333333333333333333
333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC66663333
336666336666663333336633336666666633333333666666
666666663333333333333333333333333333333333333333
333333333333333333333333333333333333333333333300
333333330033000000333333333333330033333333333333
330033330000333300333333333300003333000000000000
000000000000000000000000003333333333333333333333
3366FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99666633
333333333366666633666633333333666666666633333333
336666663333333333333333333333333333333333333333
333333333333333333333333333300333300333333333333
003333333333000000003333333333330000000033333333
330000333300333333333333000000000000000000000000
000000000000000000003333333333003333333333333333
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99666666
333333333333666666333366333333666666666666663333
336666663333333333333333333333333333333333333333
333333333333333333333333333333003333333333333333
000033003300000000003333333333330000000000333333
333300333300003333330033000000000000000000000000
000000000000000000333333330000333333333333333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99996666
663333666633333366333333336633333333666666663333
333333333333663333333333333333333333333333333333
333333333333333333333333330033333300333333333333
330000000000000000330000333333333333000000000000
333333000033330000330000330000000000000000000000
0000000000333333333300003333333333333333336666CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966
666633336666333366666633333333333366333333666666
333333333333333333333333333333333333333333333333
333333333333333333333333330033333300333333333333
000000000000333300330000000033333333000000000033
333333330000333333003300000000000000000000000000
0000003333333333330000333333333333333333666666FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966
666666336666663333336633663333333333666666333333
333333333333333333333333333333333333333333333333
333333333333330033333333333333333300000000333300
330000000033000033330000333333333333330000000033
330033333300333333330000000000000000000000000000
0033333333333300003333333333333333333366666666FF
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99
666666663366666633336633666666666666666666666633
333333333333663333333333333333333333333333333333
333333330033330000333300333300333333003300003333
330000000000000033003300003333333333333300000000
333333333333000033330000000000000000000000000033
3333333333333333333333333333333333333366666699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99
996666663333666633333366333366666666666633333366
663333333333333333333333333333333333333333333333
333333330033333333003333000033003333330033003333
333300000000003300333300003333333333333333000000
003333333333333300003333333300000000330033333333
33333333003333333333333333333333333366666699CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
999966666633336666663366663333336666666666333333
333333333333663333333333333333333333333333333333
333333330000333333330033330000333333000033000033
333300000000000000003333003333333333333333330000
000033333333333333333333333333333333333333333333
33333333003333333333333333333333336666666699CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF9999666666336633666633666666663333666666666666
663333333366333333333333333333333333333333333333
333333333300333333330033333333000033330000330000
333333000000000000333333000033333333663366333333
003333330000333333333333333333333333333333333333
333300003333333333333333333333336666666699CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC996666666666336633333366666666666666666666
666666333366333333333333333333333333003333333333
333333333300003333330033330000330033000000000000
003333330000000000000033333333333333336666333366
663333333333333300333300333333333333333333333333
33333333333333333333333333333366666666CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCC6666666666336666663333666633666666663333
333333333366663333333333333333333333333333333333
333333333333003333330000333300333300330000003300
000033330000000000000033333333333333333366663333
336666333333333333333333003333333333333300333333
33333333333333333333333333333366666699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF6666666666666666663333333333666666666666
666633333333663333333333333333330000333333333333
333300333333000033333300333300003300330000003300
000033330000000000000000003333333333333366666666
333333333333333333333333333333333333333333333333
333333333333333333333333333366666699FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC99666666666666663333333333333366666666
666666666633663333333333333333330000330033333333
333333333333330033333300003300000033003300000033
000033333300000000000000000033663333333333336666
666633333333333333333333333333333333333333333333
3333333333333333336633336666666699FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666666333333336666666666
666666666666333333333333333333333300003333333333
003333003300330033333300003333000000333333000000
000000333300000000000000000000336666333333333366
666666666666333333333366663333333333333333333333
33333333333333336633333366666699FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9966666666666666663333333366666666
666666666666663333333333333333333333000033333333
330033333333330000333300003300330000003333000000
000033333333000000000000330000003333666666333333
333333333366666666666666333333333333333333333333
333333333333336633333333666666CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99666666666666666666333333666666
666666666666666633333333333333333333330033333333
333333333333330000333333000000000000003333000000
000000333333330000000000333333330033336633333366
663333333333333333333333333333333333333333336633
333333333333333333333366666666FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9966666666663333666666666666
666666666666666666333333333333333333333333333333
333333333333333300003333333300003300000033330000
003300333333333333330033333333333333333333333333
333333333366336666666666666666663333333333333333
33333333333333336666666699CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF66666666666666336666666666
666666666666666666333333333333333333333333333333
333333333333333333000033333300003333330000333300
003333333333333333333333333333333333333333333333
336633333333333333333333333333333333333333333333
333333333333666666666666CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF99666666666666666633336666
666666666666999999663333333333333333333333333333
333333333333333333330033333333000033333300333333
003333333333333333333333333333333333333333333333
333333663333333333333333333333333333333333333333
3333333366336666666666CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF996666666633666666666666
666666666666999966666633333333333333333333333333
333333333333333333333333333333333333333333333333
330033333333333333333366333333336633333333333333
333333333333333333333333333333333333333333333333
33333366336666666699CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99666666333366666633
336666666666666666666666333333333333333333333333
333333333333333333666633333333003333333333333333
333333003333333333663333333333333366666633663333
333333333333333333333333333333333333333333333366
333366666666666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996666663333333366
666666666666666666996666663333333333333333333333
333333333333333333336633333333330033333333333333
333333333366336633336633666666333333336666666633
333333333333333333333333333333333333666666666633
3366666666666666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999666666333333
336666666666669999996666666666333333333333333333
333333333366663333333366333333333300333333333333
663366333366663366333366333366666633333333333333
333333333333333333333333333333336666666666333333
3366666666336699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC666666663333
333366666666669966999999666666666666666633333333
333333336633663366663333663333333333333333336633
333366666666666666663333666666666666663366336666
333333336666666666666666663333666633333333333366
666666333366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99666666
666666666666666666666666999966666666666666666666
666633333366663366666666336666666633663333336666
336666666666666666666633333333336666666633663333
663333666633333333333333333333333366666666666666
66336699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC996666
666666666666666666666699666666666666666666666666
666666663333666666666666666666666666666633333366
333333333333666666666666666666663333666666666666
666666333333333333333366663366666666666666666666
3366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9999
996666666666666666666666666699996666666666666666
666666666666666666666666666666666666666666663333
333333333333666666666633666666666666666633663333
333333333333333333663366666666666666666666663333
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
996666666666666666666666996666666666666666666666
666666666666666666666666666666666666666666663333
333333333333333333336666666666336633333333333333
333333333333336666666666666666666666666633333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCC99666666666666666666666666669966666666666666
666666666666669966666666666666666666666666666666
336633333333333333333333666633333333333333333333
6633333333663366336666666666666666663333336699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC996666666666666666666666999966666699666666
666666666699666699996666666666666699996666666666
666666333333333333333333336666666666336666336633
666666666666666666666666666666666633336699CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC99996666666666666666666666666666669999
666666666666666666996699996666666666999966666666
666666666666666666666666666666666666666666336666
66666666666666666666666666666633336699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC996666336666666666669999996699
999999999999666666666666996666666666666666669999
666666666666666666666666666666666666666666666666
66666666996699666699663333336699CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99996666666666666699999999
999999999999996666666666996666666699999999996666
666699666666666666666666666666666666666666669999
9999999999999966666666666699CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCC99996666666699999999
CC9999999999999999999999666666666666999999999999
999999996666666699666666666666666666669999999966
666666666666666666666666CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFCCCCCCCC
CCCCCC99CCCC999999999999999999666666666666666699
999999999999666666666666666666666666666666666666
66666666666666666666CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
FFFFCCCCCCCCCCCCCC999999999999666699666666666666
666666996699996666666666666666666666666666666666
666666666666669999CCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCFFCCCC99999999999999996699996666
666666666699999999666666666666666666666666666666
666666669999CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCFFFFCCFFFFFFCCCCCCCC999999999999999966
666666996666666666999966666666666666666666666666
666699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCC99
999999999999999999666699999999999999CCCCCCFFCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.5 1.0125 -14 0 ]
[.5 1.0125 14 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Blue) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999999999999999CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999999999999999FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC99CC99999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999999999FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999999999FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99CC9999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99CC9999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC9999CC999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999
99CC99999999999999999999999999999999999999999999
99999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCC99
999999999999999999999999999999999999999999999999
99999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999999999999999999999999999999999999999999999
99999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999999999999999999999999999999999999999999999
99999999999999999999999999999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
CC9999999999999999999999999999999999999999999999
99999999999999999999999999999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999999999999999
99999999999999999999999999999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF996699CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
9999CC999999999999999999999999999999999999999999
99999999999999999999999999999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF99666699CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999999999999999
999999999999999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC33336699CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999999999999999
999999999999999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF66333366CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF9933333366CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF99333333006699CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CC99CC9999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF333333003399CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999CC99FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC3333333399CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF6633333399CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333399CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC33333399CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF66333366CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC33333366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999999999999999999999999999CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF6633333399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCC33333399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999996699669999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999999999999999FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF66333366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC999999CC99999966666666666666996666
666699999999999999999999999999999999999999999999
99999999999999999999999999999999999999CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF66333399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999996666666666666699666666
666666666699999999999999999999999999999999999999
9999999999999999999999999999999999999999CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC333399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999996666666666666699666666
666666666666669999999999999999999966999999999999
999999999999999999999999999999999999999999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF663366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999996666666666669999666666
666666666666666666999999999999999966999999999999
999999999999999999999999999999999999999999CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC993366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999666666666666666666666666666666
666666666666666666666699999999999999996699999999
99999999999999999999999999999999999999999999CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
99993399CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999CCCCCCCC99CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999966666666666666666666666666666666
666666666666666666666699999999999966999999999999
9999999999999999999999999999999999999999999999FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99
666666CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999CCCC999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999996666666666666666666666666666666666
666666666666666666666666999999999999996699999999
9999999999999999999999999999999999999999999999FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC66
6633CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC999999CC99999999CCCCCCCCCCCCCCCCCCCC99
CC9999999966666666999999666666666666336666666666
666666666666666666666666666699999966996699669999
9999999999999999999999999999999999999999999999CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9966
3333CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999999999999CCCCCCCCCCCCCC9999999999
99999966666666999999999966CCCC999999669999996666
666633666666666666666666666666999999996666999999
999999999999999999999999999999999999999999999999
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996633
3366CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC99999999999999CCCCCCCCCCCCCC999999999999
666666666666CCCCCCCCCCCC99CCCCCCCC9966CCCC999966
336666663366666666666666666666999999666666999999
999999999999999999999999999999999999999999999999
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC663333
3399CCCCCCCCCCCCCCCCCCCCCC9999CCCCCCCCCCCCCCCCCC
CCCCCC9999999999999999CCCCCCCCCC9999999999996666
66333366996699CCCCCCCCCCCCCCCCCC99CC99CCCCCCCC99
669999663333336666666666666666666699999999669999
999999999999999999999999999999999999999999999999
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99663333
3399CCCCCCCCCCCCCCCCCCCCCC9999CCCCCCCCCCCCCCCCCC
CCCC999999999999999999CCCCCCCC999999999999663333
33666666669966666666666699999999999999CCCCCCCC99
669999666633336666666666666666669999996666669999
999999999999999999999999999999999999999999999999
99CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99663333
99CCCCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCC
99999999999999669999CCCCCC99669966666666000066CC
996666999999666699CCFFFFCCCCCC996666996666666666
669999999966666633333366666666666666999966996699
999999999999999999999999999999999999999999999999
9999CCFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333
CCCCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCC
99999999999999999999CC999966666633669999CC66CCCC
CC9999CCCCCC9966CCFFFFFFCCCCCCCCCCCCCCCCCCCC9966
666666999966666666333333333366666666996699669999
999999999999999999999999999999999999999999999999
9999CCCCFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999333366
CCCCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCC
99999999999966669999996666663300339999CCCCCCCCCC
CCCCFFFFFFFFCC99FFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CC6633666666666666333333333366666666999966996699
999999999999999999999999999999999999999999999999
9999CCFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666333399
CCCCCCCCCCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCC
9999999999666699999966333333333399CCCCCCCCCCCCCC
CCFFFFFFFFFFCCCCFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCC
CC9933663333666666333333333333336666999999669966
999999999999999999999999999999999999999999999999
999999FFFFFFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6633333333CC
CCCCCCCCCCCCCCCCCCCCCC999999CCCCCCCCCCCCCCCCCCCC
99999999666666666666333333333366CCCCCCCCCCCCCCCC
CCCCFFFFFFCCCCCCFFFFFFFFCCCCCCCCCCCCFFCCCCCCCCCC
CC9999CC9999333333333333333333336666669999996699
999999999999999999999999999999999999999999999999
999999CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6633333366CC
CCCCCCCCCCCCCCCCCCCC99999999CCCCCCCCCCCCCCCCCCCC
99999999666666663333330000336699CCCCCCCCCCCCCCCC
CCCCCCFFFFCCCCCCCCFFFFFFCCCCCCCC99CCFFCCCCCCCCCC
CC99CCCCCCCC993333330000330033333366666699996699
999999999999999999999999999999999999999999999999
999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9933333399CC
CCCCCCCCCCCCCCCCCCCC999999CCCCCCCCCCCCCCCCCCCCCC
9999996666666633333300003366669999CCCCCCCCCCFFCC
CCCCCCFFFFCCCCCCCCFFFFFFCCCCCC9999CCFFCCCCCCCCCC
CC99CCCCCCCCCC9933666600000000333366336666999966
999999999999999999999999999999999999999999999999
99999999CC99CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966333366CCCC
CCCCCCCCCCCCCCCCCC999999CCCC9999CCCCCCCCCCCCCC99
9966996666666633333333000033666699CC999999CCCC99
99CCCCCCCCCC9999CCFFFFFFCCCC99999999CCCCCCCCCCCC
9999CCCCCCCCCCCC9999CC66336633000033333366669966
999999999999999999999999999999999999999999999999
99999999CC99339999CCCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6633333366CCCC
CCCCCCCCCCCCCCCCCC999999CC999999CCCCCCCCCCCCCC99
996699666666663333333333003366669999669999CCCCCC
9999CCCCCC9999CCCCCCCCCCCC999999999999CCCCCCCCCC
9966CCCCCCCCCC9999999999999999333333333366669999
999999999999999999999999999999999999999999999999
99999999CC9999CCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC993333333399CCCC
CCCCCCCCCCCCCC99999999CCCC999999CCCCCCCCCCCCCC99
66669966666699996666663333336666666666999999CCCC
9999CCCCCC9999CCCCCCCCCC999966669999999999CCCC99
666699CCCCCCCC9999999999999999666633333333666699
669999999999999999999999999999999999999999999999
9999999999CCCCCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC993333333333CCCCCC
CCCCCCCCCCCCCCCC999999CCCC999999CCCCCCCCCCCCCC99
996666996699999999999999666666666666666666999999
996699999966999999CCCC99666666666666999999999999
666699CCCCCC996699999999999999666633003333336666
999999999999999999999999999999999999999999999999
9999999999CCFFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC9966333333000066CCCCCC
CCCCCCCCCCCCCC99999999CC99999999CCCCCCCCCCCCCC99
99666699999999CCCCCCCC99999999999999999999666666
666666666666666666996666666666666666666666666666
666666999999996699999999999999666633000033336666
669999999999999999999999999999999999999999999999
9999999999CCFFFFFFFFCCCCCCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC663333333333003399CCCCCC
CCCCCCCCCCCC9999999999CC999999CCCCCCCCCCCCCCCC99
99666699999999CCCCCCCCCCCCCCCCCCCCCC999999999999
999999999999999999999999996699666666666666666666
666666999999666666999999999999666633000000333366
669999999999999999999999999999999999999999999999
999999999999FFFFFFFFCCCCCCCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF99333300003333333399CCCCCC
CCCCCCCCCCCC99999999CC99999999CCCCCCCCCCCCCCCC99
99666699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC99CCCCCC99999999999999999999996666666666663366
666666669966666666999999669999666633000000003333
669999999999999999999999999999999999999999999999
999999999999CCCCFFFFFFFFCCCCCCCCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC333300003333330066CCCCCCCC
CCCCCCCCCCCC999999CCCC99999999CCCCCCCCCCCCCC9999
99996666999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999966666666
666666666666666666666666663366333333000000333333
336699999999999999999999999999999999996699999999
999999999999666699CCFFCCFFFFCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC333333333333330066CCCCCCCC
CCCCCCCCCCCC999999CCCCCC99CCCCCCCCCCCCCCCCCC9999
999966669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99CCCC999999CC999999999966
666666666666666666666666333333333333000033333333
336666669999999999CC9999999999999999999999669999
999999999999993366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCCC99000033333333003399CCCCCCCC
CCCCCCCCCCCCCC99CCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
99999966669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC99CC99999999999999999999999999
999999999966666666666666666666663333333333333333
336666999999999999999999999999999999996699999999
99999999999999663366CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9966003333333333003399CCCCCCCC
CCCCCCCCCCCC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
99999966669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999999999999999
999999999999999999999966666699666666666666666666
666666999999999999999999999999999999999966666699
9999999999999933333399CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF66333366669966663333CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99
9999999966669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999999999999999999999999999666666666666
666666669999999999999999999999999999999999996699
999999999999996666666699FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF663399CCCCCC99996666CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
999999996666999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999999999999999999999999999999999666666
666666666699999999999999999999999999999999999999
999999999999999999999999CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF6666CCCCCCCCCC999999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99CCCCCCCCCCCCCCCCCCCCCC99
999999999966669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999999999669999999999999999999999669966
996699996699999999999999999999999999999999996699
99999999999999666699CCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC6699CCCCCCCCCCCC99CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999669999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999669999666666666699996666999999999999
669999996699999999999999999999999999999999999999
99999999999999666699CCCCCCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
99999999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999966996666666666666666666666666666999999
666699669999996699999999999999999999999966999999
99999999999999333366CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
9999999999999966999999CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999666666666666666666666666666666666699
669966669999996699999999999999999966996699999999
9999999999999933336699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999669966666666666666666666666666666666666666
666666999999669999999999999999999999996699999999
9999999999999933336699CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
99999999999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
996699666666666666666666666666666666666666666666
666666999999999999999999999999996699999966999999
999999999999993333669999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCC9999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC999999999999996699999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
669966666666666666666666666666666666666666666666
666699999999999999999999999999669999996699999999
99999999999999330033336699FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCC999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC999999999999669999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999996666999966
996666666666666666666666666666666666666666666666
666699999999999999999999999999999999999999999999
99999999999999003333333399FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCCC999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC999999999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CC9999CCCCCCCCCCCCCC9999999999999999999966669999
999999666666666666666666666666666666666666666666
669999999999999999999999999999999999999999999999
999999999999993333333333CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCC9999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC9999999999996699999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999999999999666666
666666666666666666666666666699666666666666666666
999999999999999999999999999999999966999999999999
999999999999993333336699CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCCCC9999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99CC99999999999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99999999999999999999999966
666666666666666666666666666666996666666666666699
999999999999999999999999999999999999999999996699
9999999999999933333366CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCCCCCCCCCCCCC999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC9999999999999999999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
666666666666666666666666666666666666666699999999
999999999999999999999999999999999999999999999999
99999999999966333333669999FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCCCCCC99999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC999999999999999999999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999966666666666666666666666666669966666699999999
999999999999999999999999999999999999999999999999
9999999999996633333333333399FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCCCCCCCCCCCCC99999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99CC9999999999999999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999996699666666666666666666666666669999999999
999999999999999999999999999999999999999999999999
999999999999663333333333336699CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCCCCCCCCC99999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999999999999999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999999999
999999999999996666666666666666666666999999999999
999999999999999999999999999999999999999999999999
99999999999966333333333300336699CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCCCCCCC99996699999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC999999999999999999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999966666666666666666699999999999999
999999999999999999999999999999999999999999999999
9999999999999966663333333333666699CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCCCC99999966669999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999966666666666666669999999999999999
999999999999999999999999999999999999999999999999
99999999999966666666333333333333336699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCCCCCCCCCCC999999996666999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999999999CCCCCCCCCCCCCCCC99
CCCCCCCCCCCCCCCCCCCC9999999999999999999999999999
999999999999669966666666666666999999999999999999
999999999999999999999999999999999999999999999999
99999999999999666666666633333333336699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCC99CCCCCC99999999996699669999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99CC9999999999999999CCCCCCCCCCCCCCCC99
99CCCCCCCCCCCCCCCCCCCC99999999999999999999999999
999999999999996666666666666666999999999999999999
999999999999999999999999999999999999999999999999
9999999999999966666666666666336666CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC9999CC999999999966666666999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC9999999999999999CCCCCCCCCCCC9999
99CCCCCCCCCCCCCCCC99CC99999999999999996699999999
999999669999666666666666666699999999999999999999
999999999999999999999999999999999999999999999999
99999999999966999966666666666666CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC99CC99996666666666666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999CC999999CCCCCCCCCCCC9999
99CCCCCCCCCCCCCCCC999999999999999999999999996666
666666666666666666666666666699999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999669966996699CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC99CC99996666666666666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999999999999999996666996666
666666666666666666666666669999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666666666999999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
CCCCCC99996666666666666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9999999999CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999996666996666
666666666666666666666666669999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666666666669999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
CCCCCC99999966666666666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC99CCCC99CCCC9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999996666666666
666666666666666666666666999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666666699999999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
CCCC9999999966666666666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999CCCC99CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999999666666666666
666666666666666666999999999999999999999999999999
999999999999999999999999999999669999999999999999
999999999999666666669999999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99CC
CCCCCC99999999666666669999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99CC99CCCC99CC9999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999996666666666
666666666666666699999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666666699999999CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99
CCCCCC999999996666666699999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC9999999999CC9999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999996666666666
666666996699999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999966666666669999999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999
CCCCCC999999996666666699999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999996699996666666666
666666999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999669999999999999999FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9999
CCCCCC999966996666666699999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999999966666666
666699669999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999996699CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC9999
CCCCCC999999996666666699999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCCCCCC99CC
CCCC99999999999999999999CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999999966666666
669999999966999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999999999999999999666666CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999999
CCCC99999999996666666666999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CCCCCC999999
CC99CCCC999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999999996666666666
996699669999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999996699999999999966666699FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99996699
9999999966666666666666999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CC999999
99999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999966999966666666
666699669999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666999999996666666699FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99669999
6699996666666666666666999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99999999
9999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999999966666666666666
666699999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666669999999966666699FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99669966
6699663333666633666666999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC99CC99999999999999CC9999CC
99CC999999999999CC99CC99CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999966666666666666
669966999999999999999999999999999999999999999999
999999999999999999999999999999999999669966999999
999999999999666666666699999966666666CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999996666
66663366666633333366669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999CCCC99999999
999999999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999966999966666666666666
669999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666666699999999996666CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999966999966
33336699333333333333669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
99999999999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999996699666666666666
669999999999999999999999999999999999999999999999
999999999999999999999999999999999999999966999999
99999999999966666666669966999999666699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966996633
3366996633663333336666999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
99999999999999999999999999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999966669966666666666666
669966999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
99999999999966666666666666999999666699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966996633
3366666666666633336666999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999999999999999999999CC99CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999996666666666666666
666666999999999999999999999999999999999999999999
999999999999999999999999999999999999999999996699
99999999999966666666666666669999996699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996699996633
66663300336666666666669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99999999999999999999999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999999999666666666666666666
669999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999996666333333333333666666996699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99996699996633
66330033666633336633669999CCCCCCCCCCCCCCCCCCCCCC
CCCC9999999999999999CCCCCCCCCC99CCCC999999999999
9999999999999999999999999999999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999999966666666666666666666
666666999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999996666333333333333666666996699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99666699996633
66330033333333333333669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999669999999999996666996666999999
9966996699999999999999999999999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCC9999999999996666666666666666666666
666666666666669999669999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999996666333333333333336666996699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99666699996633
3333003333333333333366999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999966663366663366666666666666669999
996699666666669999999999999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999666666666666666666
666666666699999999999999999999999999999999999999
999999999999999999999999999999999999996699999999
9999999999996666663333333333336666996699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99666699996633
33000033003333333333339999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999966996633333333336666669966666666
66666666666666666666666666669999999999CCCCCCCCCC
CCCCCCCCCCCCCCCC99999999996666996666666666666666
666666999999999999996666996699669999999999999999
999999999999999999999999999999999999999999999999
9999999999996666663333333333333366669999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99666699996633
33000000003333333333339999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC99999999996633333333669999CC99333366
33333333333333666666666666666666669999CCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999666666666666666666
666666999999999999999999996699999966996666669966
999999999999999999999999999999999999999999999999
9999999999996666663333333333336666669999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9966666699CC9933
00000000333333333333669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99669999996633336699CCCC66336699
330000333333336666666633333333333366999999CCCCCC
CCCCCCCCCCCCCCCC99999999999966666666666666666666
666699999999999999999999999999999999999999999999
996699999999999999999999999999999999999999999999
9999999999996666663333333333336666669999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966666699CC9933
000000333333333333333399CCCCCCCCCCCCCCCCCCCC99CC
CCCCCCCCCCCCCCCCCC666699999999663366669933339999
6600003333333366999966666633666666669999CCCCCCCC
CCCCCCCCCCCCCCCC99999999999999666666666666666666
666699999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
9999999999666666333333333333666666669999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966666699999966
333333333333333333663399CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC99996699CC66996666333333669999
9900003333333366999999663333336666999999CCCCCCCC
CCCCCCCCCCCCCCCCCC999999999966666666666666666666
666699999999999999999999999999999999999999999999
999999999999999999999999999999999999996699999999
9999999999666666336633333366666666999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99999966666699999966
33330000333333333333669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC99996699CCCC9999666633333366
6600003333333366999966663333666699999999CCCCCCCC
CCCCCCCCCCCCCCCC99999999999966666666666666666633
333366999999999999669966666666666666999999999999
999999996699999999999999999999996699999966999999
9999999966666666666666336666666666999999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF3333999966666699999999
330033333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC9999999999CC9999996666333333
3300000033333366666666666666666699999999CCCCCCCC
CCCCCCCCCCCCCCCCCC999999999966666666666666666633
003333666666666666666666666666666666666666669999
999999999966999999999999999999666666999999999999
9999999966666633333366336666666666666699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF990033999999666699999999
660000333333333333336699CCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC9999999999CCCC996699663333
3333333333333333333366666666669999999999CCCCCCCC
CCCCCCCCCCCCCCCCCC999999999966666666666666666633
333333666666996666666666333366666666666666666666
996666669966669999999966996699996666669999999999
9999996666663333336633333366666666996699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF66330033669999999999999999
33003333333333333333669999CCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC99999999CC999999666666
6666333366333366666666666666999999999999CCCCCCCC
CCCCCCCCCCCCCCCC99999999999966666666666666666666
6633339999CCCCCCCC663333003333333366666666333333
666666666666666666666666666666666666669999999999
9999996666663333336633336666666666996666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9933330000669999999999999999
330033333333333333336699CCCCCCCCCCCCCCCCCC9999CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999966999999999999
6666666666333366666666666666999999999999CCCCCCCC
CCCCCCCCCCCCCCCC99999999996666666666666666666666
6633336699CCCCCC99333333003333333333336666333333
336666666666666666666666666666669999999999999999
9999666666663366663366333366666699996666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF993333000000669999999999999999
333333333333003333336699CCCCCCCCCCCCCCCCCC999999
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999999999
996666666666666666666666999999999999999999CCCCCC
CCCCCCCCCCCCCCCC99999999999966666666666666666666
666666336699CCCC66336633003333333366336666663333
336666666666663366666666666666999999999999999999
9999666666663333336666333366999999666666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF99333300330000336699999966666633
3333333333333333333366CCCCCCCCCCCCCCCCCCCC999966
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999
99996666666666999999999999999999999999CCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999666666666666666666
666666666666666666999933003333333333336699996666
333333333333663366666699999999999999999999999999
9966666666663333333333333366999966336666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF66333300330000003366666666663333
333333333333333333336699CCCCCCCCCCCCCCCCCCCC9966
66999999CCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
99999999999999999999999999999999999999CCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999666666666666666666
666666666666666633999933003366333333336666996666
333333333333666666666666666699999999999999999999
9999666666333333333333333366999966336666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC33333333330000000033333333333333
333333333300330033336699CCCCCCCCCCCCCCCCCCCCCC99
6666999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999
999999999999999999999999999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCC99999999999999666666666666666666
666666666666666666336633000033333333336666663333
333366663333666666666666666666999999999999999999
9999666666333333333333333366999966333366CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333330000000000000033333333
333333333333333333336699CCCCCCCCCCCCCCCCCCCCCC99
996699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999
99999999999999999999999999999999999999CC99CCCCCC
CCCCCCCCCCCCCCCC99999999999999666666666666666666
666666669999666666663333330000003333333333333333
336666666666666666666666996666996699999999999999
9999666633333333333333333366999966333366CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333330000000000000033333333
333333333333330033336699CC99CCCCCCCCCCCCCCCCCCCC
99996699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC999999
999999999999999999999999999999999999CC9999CCCCCC
CCCCCCCCCCCCCCCC99999999999999996666666666666666
666666666699999966666666333333333333333333333333
666633666666666666666666669966669966669999999999
9966666633333333333333333399999966336666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6633333333330033000000000033333333
3333333333333333333366999999CCCCCCCCCCCCCCCCCCCC
CC9966999999999999CCCCCCCCCCCCCCCCCCCCCCCC999999
9999999999999999666666666699999999999999CCCCCCCC
CCCCCCCCCCCCCCCC99999999999999999966666666666666
666666996666999999666666666633663333336633336666
663366666666666666666666669999999999999999999999
9966666633333333333333333399996633336666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633333333333333333300003333333333
33333333333300333333669999CCCCCCCCCCCCCCCCCCCCCC
CC9999999999996699CCCCCCCCCCCCCCCCCCCC9999999999
9999999966666666666666666666999999999999CCCCCCCC
CCCCCCCCCCCCCC9999999999999999999966666666666666
666666669966669999996699666666666633666666666666
666666666666666666666666666666999999999999999999
9966663333333333330033333399996633336666FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333333333333333333333333333333
00000033333300333333669999CCCCCCCCCCCCCCCCCCCCCC
CCCC99999999666666666666669966666666666666666633
33333366333333336666666666666699999999CCCCCCCCCC
CCCCCCCCCCCC999999999999999999996666666666666666
666666999966669999999999999966666666666666666666
666666666666666666999966999999999999999999999999
9966663333333333333300003399666633336699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333300330033333333333333333333
3333003333333333333366999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999966666666666666666666666666663333
66666633333366336633666666666699999999CCCCCCCCCC
CCCCCCCCCC99999999999999999999999966666666666666
666666999999996699999999999966666666666666666666
666666669966999999999999999999669999999999999999
6666663333333333333300003399666633336699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333300330033333333333333333333
3300000033333333333366999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999666666666699666666666666666666
666666663333336633666666666699999999CCCCCCCCCCCC
CCCCCCCCCC99999999999999999999999966666666666666
666666666699999999999999666666666666666666666666
666699996699999999999999999999669999999999999999
6666333333333333333300003366666633336699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333330033330033003333333333330033
3333330000333333333333999999CCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99666666666666666666996666666666
6666666666336666666666666666999999999999CCCCCCCC
CCCCCCCCCC99999999999999999999999966666666333366
666666666666999999999999999999996699669999999966
996699999999999999999999999999669999999999999966
6666333333333333330000336666666633336699FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC3333330033003300333333003333330033
333300333333333333336699999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCC999999999999999966999999999966
666666666666666666666699999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCC999999999999999999999966666633333333
333366666666666699999999999999999999999999999999
999999999999999999999999999999669999999999999966
6633333333333333333300336666666633336666CCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC3333333333333333000000333333330033
330033000033333333333366999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCC999999999999CC99999999
99999999999999999999999999CC99CCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999CC9999999999999966666633333333
333333666666666699999999999999999999999999999999
999999999999999999999999999999996699999999999966
663333333333333333333333666666663333666666FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633330033330033333333333333330000
33003333333333333366666699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC99CCCCCC99999999999999999999999999666666333333
333333336666666666999999999999999999999999999999
999999999999999999999999999999999999999999669966
663333333333333333333366666666663333666633FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6633333300330033330000333333330000
0033003333333333333366669999999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC99CCCC9999999999999999999999999999999966666633
333333333333333333336666669999999999999999999999
999999999999999999996666999999999999999999996666
33333333333333333333333366666666333366663399CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6633333333003333003300333333330000
003333003333333333336666999999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC99CC99999999999999999999999999999999666666
663333333333333333333366666699999999999999999999
999999999999669966666666666666999999999999996666
33333333333333333333333366666666333366333399CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF6633333333330033000033333333333300
00003333333333333333336699999999CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999999999999999999999999999999999
666666333333333333333333333366666699999999669999
999966666666666666666666666666999999999999996633
3333333333333333333300333366666666666633336699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333300333333333300
0000333333333333333366669999999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCC99999999999999999999999999999999999999
999966666666333333333333333333333366666666666666
666666666666666666666666669999999999999999666666
3333330033333333333300333333666666666633336699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333330033330033333300
0000003333333333336666666699999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC999999999999999999999999999999999999999999
999999666666666666333333333333333333666666666666
666666666666666666666666669999999999999999666633
3333003333003333333333333333333333333333336699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333003300333333333333
0000003333333333333366666699999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999999999999999999999999999999999999
999999999966666666663333333333333333333333336666
666633666666666666666666999999999999996666666633
3300003333333333333300000033333333333333336699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333300003333333333333333
0000000033333333336666666699999999CCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCC999999999999999999999999999999999999999999
999999999999996666666666333333333333333333333333
666666336666666666666699999999999999669966666633
33003333333333333333000000000000333333333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC33333333333333333333333333333333
330000003333333333336666669999999999CCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999999999999999999999999999999999999
999999999999999999666666666666333333333333333333
333333336666666666669999999999999999669966666633
333333333333333333330000000000003333333333FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333333
33333333333333333333666666999999999999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCC9999999999999999999999999999999999999999
999999999999999999999966666666666666663333333333
333366666666666699999999999999999966666666666633
333333333333333333333300000033333333333366CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9933333333333333333333333333333333
33333333333333333333666666669999999999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99CC9999999999999999999999999999999999999999
999999999999999999999999999966666666666666666666
666666666666999999669999996699999966666666666633
3333333333333333333333000033333333333333336699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666333333333333333333333333333333
33333333333333333333666666669999999999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC9999CC99999999999999999999999999999999999999
999999999999999999999999999999996666666666666666
666666669999999999999999999999996699666666663333
333333333333333333333300003333003333333333333399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6633333333333333333333333333333300
3333333333333333333333666666669999999999CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99CC99999999999999999999CC999999999999999999
999999999999999999999999999999999999666666669966
666699999999999999999999999966669999666666663333
333333333333333333333333333300333333333333333399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996633333333333333333333333333333300
00333333333333333333336666666699999999CCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCC99999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999669966999966666666663333
333333333333333333333333003333333333330033333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF993333333333333333333333333333333333
0033333333333333333333666666666699999999CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC99CC99999999CC99999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999996666666633333333
333333333333333333333300333333333333000033333333
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333333333333333333333333300
3333333333333300333333336666666699999999CCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999666666666666333333
333333333333333333333300003300333333000033333333
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333333333333333333333333333
33333300333333333333333333666666666699999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999666666666633333333
333333333333333300003300333333003300000033333333
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333333333333333333333003300
00333333333333333333333333333366666699999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
9999CC999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999666666666633333333
330033333333330000330000333333330000003333333333
99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF336633333333333333333333333333333333
00003333333333333333333333663366666699999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999966666666663333333300
003333333333000033330033003300330000003333333333
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF333333333333333333333333333333333333
330000003333333333333333663366333366999999CCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CC9999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999666666666666663333333333
330033333333000033003300000000330000003333333333
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF333333333333333333333333333333333333
33000033003333333333333333336666336666999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
CC9999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999666666666666333333333333
333333333300333333000000000000000000333333333333
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333333333333333333333333333
33330033330033333333333333663366333366999999CCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999966666666666666333333333333
333333330000000000330000000000000000333333333333
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF663333333333333333333333333333333333
3333000033333333333333333333666666336666999999CC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999996666666666666666333333333333
333333000000003333330000000000003300333333333333
66FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333333333333333333333
333333003333333333333333333333666666666699999999
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999996666666666336633333333333333
330000003333330000000000000000003300333333333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333333333333333333333
333333333333333333333333333333336666666699999999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999966666666666666663333333333333333
333333333333003300000000000000330000333300333366
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333333333333333333333
333333330033333333333333333333666666666666999999
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999996666666666666666663333333333333333
333333333333000000000000000000000000330000333399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333333333333333333333
333333330033333333333333333333666666666666999999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
669999999999996666666666666666663333333333333333
0000003333000000003300000033000033333300333366CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333333333333333333333
333333333333333333333333333333666666666666669999
99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999966666666666666666666333333333333333333
003333000033000000000033330000333300000033333399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333333333663333333333
333333333333333333333333333333666666666666999999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999966996666666666666633333333333333333333
333333333300003300003333000000330033003333333399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333336633333333336633333333
333333333333333333333333333366666666666666669999
999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99CC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999666666666666666666333333333333333333
333333333333330000333333003300330033333333333399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC336633333333333333333333333333333333
333333333333333333333333333333666666666666669999
9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99CCCC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999999966666666666666666633333333333333333333
3333333333333333333333330000333333333333333366CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC663333333333336633333333333333333333
333333333333333333333333333333666666666666666699
999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC99999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999999666666666666666633663333333333333333333333
33333333333333333333333333333333000000333366CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333663333663333333333
333333333333333333333333333366666666666666666699
99999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
999966666666666666663333663333333333333333333333
33333333330000333333333333000000000033333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC333333333333333333663333663333333333
333333333333333333333333333333336666336666666699
999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999966
996699666666666666663366333333333333333333333333
33333333000033330000000000000033003333333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC663333333333333333663333666633333333
333333333333333333333333333366336666336666666666
99999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC9999CC999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
996699666666666666336633333333333333333333333333
00003333333333000000000000000000003333333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333333333333333336633333333
333333333333333333333333333366336666333366666666
99999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999CC99CC9999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999669999999999
996666666666666633663333333333333333333333333300
00333333333300000000000000000000003333333399FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC663333333333333333336633333333333333
333333333333333333333333333333333366663366666666
9999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC9999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999999
666666666666666633663333333333333333333333333333
333333333333000033000000000000000033333333CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996633333333333333336633333333333333
333333333333333333333333333333333333333366666666
99999999CC9999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99CC999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999999999966
666666666666666666333333333333333333330000333300
333333333333003300000000000000333333333333FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666633333333333333333366333333333333
333333333333333333333333333333336633333333336666
66999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999999966666666
666666666666333333333333333333333333333333333333
333333333300333300000000000000333333333399FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666333333336633333366333366333333
333333333333333333333333333333333333333333336666
6699999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999999996666666666
666666666633666633333333333333330000333300330033
3333333333333333000000000000333333333366FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666333333333333333333333366333333
333333330033333333333333333333333333333333336666
66669999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999966666666666666
666666663366333333333333333333330000000033003333
3333333333333333330000330000333333333399FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF666666333333333333333333333366663333
333333333333333333333333333333333333333333336666
66669999999999CCCC99CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCC9999CC99999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999999966666666666666
666666666633333333333333333333000000003300333333
33333333333333333300000000003333333366CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666663333333333333333333333663333
333333333333333333333333336633333333333333336666
6666669999999999CC9999CCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCC99CCCCCC99999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999999999996666996666666666
666666663333333333333333333333000000003333003333
33333333333300000000000000333333333366CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666666633333333333333333333663333
333333333333333333333333333333333333333333333333
66666699999999999999CCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCC999999999999999999999999
999999999999999999999999999999999999999999999999
999999999999999999999999669999666666666666666666
666633336633333333333333333333000000000000330033
33330033000000000000000000333333333366FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC6666663333333333333333333333666633
333333333333333333333333333333333333333333336633
336666999999999999999999999999CCCCCCCCCCCCCCCCCC
CCCCCCCCCC9999CCCC999999999999999999999999999999
999999999999999999999999999999999999999999999999
669999999999999999999999996699666666666666666666
666633663333333333333333333300000000000000003333
00330000000000000000000000333333333399FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966666633333333333333333333333333
333333333333333333333333333333336666333333333333
6666666666999999999999999999CC99CCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCC99CC99CC999999999999999999999999
999999999999999999999999999999999999999999999999
996699996699669966999966996666666666666666666666
663333333333333333333333330033000000000033333333
333300000000000000000000003333333366CCFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF9966663333333333333333333333336633
333333333333333333333333333333333333333333333333
336666666666669999999999999999999999CCCC99CCCCCC
CCCCCCCCCCCC999999CC9999999999999999999999999999
999999999999999999999999999999999999999999996699
999966669966996666666666666666666666666666666666
663333333333333333333333333300000000003300000000
003300000000000000000033333333333366FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC66663333333333333333333333336633
333333333333333333333333333333333333663333333333
333366666666666699999999999999999999999999CCCC99
999999CCCC99999999999999999999999999999999999999
999999999999999999999999999999999999999966999999
999999666666666666666666666666666666666666666666
666633333333333333333333333300000000000000000000
0033000000000000000000333333333333CCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99666633333333333333333333336633
333333333333333333333333333333333333336633333333
333333333333666666666666669999999999999999999999
9999CCCC999999CC99999999999999999999999999999999
999999999966996699999999999999999999999999669999
666666666666666666666666666666666666666666663333
333333333333333333003333003300000000000000000000
0000000000000000000033333333330066FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF99666666333333333333333333333366
333333333333333333333333333333333333333366333333
333366333366666666666666666666999999999999999999
999999999999999999999999999999999999996666666666
669966666666669966999999996666669999999999996699
666666996666996666666666666666666666666633333333
333333333333333333330033000000003300000033330000
00000000000000000033333333333333CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC666666333333333333333333333366
663333333333333333333333333333333333333333663333
333333666666666666666666666666669999669999999999
999999999999999999999999999999999999666666666666
666666666666666699666666996666666666666699669966
666666666666666666666666666666666666663333333366
333333333333330033330000000000000000000000333300
00000000000000000033333333333333FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCC666666333333333333333333333333
663333333333333333333333333366333333333333333333
333333333333666666666666666666669966666699999999
999999999999999999999999999999996666666666666666
666666666666666666666666666666666666669966666666
666666666666666666666666666666666666333333333333
333333333333333300000033000000000000000000000000
00000000000000003333333333333366FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF996666663333333333663333333333
663333333333333333333333333333666666333333333333
333333333333336666666666666666669966666666666666
996699999999999999999999999999666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666633333333333333
333333333333333333000000330000000000000000000000
00000000000000333333333333333399FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCC6666663333333333333333333333
336633333333333333333333333333333333666633333333
336633336666666666663366666666666666666666666666
666666666666666666999966669966666666666666666666
666666666666666666666666666666666666666666666666
666666666666666666666666666666666666663333333333
333333333333333333000000000000000000000000000000
000000000000333333333333333399FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9966666633333333333333333333
336633333333333333333333333333333333336666666633
333366663366666666666666666666666666666666666666
666666666666666666999999666666666666666666336633
333366336666666666666666666666666666666666666666
666666666666666666666666666666663333333333333333
333333333300333300000000000000000000000000000000
0000000000003333333333333366CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC66663333333333333333333333
336666333333333333333333333333333333663333333333
333333666666666666666666666666666666666666666666
666666666666666666666699666666666666666666666633
663366333366666666666666666666666666666666666666
666666666666666666666666666666333333333333333333
333333333333333300330000003300000000000000000000
0000000000003333333333333399FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99666633333333333333333333
333366333333333333333333333333336633336666336633
333366666666666666666666666666666666666666666666
666633666666336666666666666666666666666666663366
336633663366336666666666666666666666666666666666
666666666666666666666666666633663333333333333333
333333330000333300000000000000000000000000000000
00000000003333333333333333CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC666666333333333333333333
333333333333333333333333333333336666663366666666
663366666666666666666666663366666666666666336666
333366666633666633666666666666666666666633663366
333333333333333333336666336666666666666666666666
666666666666666666663333663333333333333333333333
333300000033330000000000000000000000000000000000
00000000333333333333333366FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF996633333333333333333333
333333663333333333333333333333336666666666336666
666633666666666666666666666666666633333333333366
336666333366336633666666666666663366666633333333
333333333333333333663333666666336666663333336633
663333663333336666333333333366333333333333333333
333333000000330000000000000000000000000000000000
00000000333333333333333399FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF996633333333333333333333
333333663333333333333333333333336666666666666633
663333333333333366666666333366336666333333333366
333333666666336633336633666666666666333333333333
333333333333333333333333333333333366333333333366
333366333333333333663333663333333333333333333333
330033330000000033000000000000000000000000000000
000000333333333333333333CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF9966663333333333333333
333333336633333333333333333333666666666633336666
666633333366666666666633666666333333333333333333
333333333333333333333333666633333333663333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333003333
333333000000000000333300000000000000000000000000
0033333333333333333333CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF9966663333333333333333
333333336666333333333333666633666666666666663366
666666333333333366666633336633333333333333333333
333333333333333333663333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333300
333300000000003300000000000000000000000000000000
3333333333333333333366FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF9999663333333333333333
333333333333333333333333336666666666666666666666
333333333333333333666633333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
003333000000000000000000000000000000000000000033
33333333333333333366CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99666633333333333333
333333333333333333333333333366666666666666666633
333333333333333366663333663333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333330033330033
330033330000000033000000000000000000000000000033
33333333333333333399FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99996633333333333333
333333333333336666663366333333666666336666666666
666666666633663333663333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333330033333300
000033330000000000000000000000000000000000003333
333333333333333366FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966333333333333
333333336633333333666666663333333366666666666633
333333333333333366333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333003333000000000000
330000000000000000000000000000000000000000003333
3333333333336699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC999966333333333333
336633333366333333336666666666333333663366663333
333333333333333366333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333300333333330000000000
003300330000000000330000000000000000000000333333
33333333330099CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966663333333333
333333663333333333333366666666666666333333666666
666666663333333366333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
003300333300003333333333333333330033333300000000
000000000000000000000000000000000000003333333333
003333333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99666633333333
333333663333333333333366666666666666663333333366
666666666633333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333003333333333333333333300333333330033333333
000033333300000033333333333300333300333333333333
000000000000000000000000000000000033333333333333
3333333366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996633333333
333333333333333333333333333366666666666666666666
333333333333333333333333333333333333333333333333
333333333333333333333333003333333333333333333333
333300330033003333333333333300333333330033333333
330000003300000033333300333333000033333333003333
000000000000000000000000000000003333333333333333
33333366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC9933333333
333333333333333333333333333333336666666666666633
333333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
333333330000330033333333333333003333333300333333
003300000033000033333333003300330000333300330033
330000000000000000000000000033333333333333333333
33333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966333333
333366333333333333333333666633333333336666666666
666666663333333333333333333333333333333333333333
333333333333333333333333333333333333333333330033
333300333300000033333333333333000033333333003333
330033330033330000333300003300000000003333000000
000000000000000000000000000033333300333300333333
333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC66663333
333333333366333333333333333366663333333333666666
666666663333333333333333333333333333333333333333
333333333333333333333333333333333333333333333300
333333330033000000333333333300000000333333330033
330033330000333300333333003300003333000000000000
000000000000000000000000000033333333333333333333
3366FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99663333
333333333366663333336633333333336666666633333333
333366663333333333333333333333333333333333333333
333333333333333333333333333300333300333333333333
003333333300000000003300003333330000000000333300
330000333300003300333333000000000000000000000000
000000000000000000003300333333003333333333330033
66CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99666633
333333333333666633333366333333336666666666333333
336666663333333333333333333333333333333333333333
333300333333333333333333333333003333333333333333
000033003300000000003333333333330000000000003333
333300333300003333000033000000000000000000000000
000000000000000000333333330000333333333300333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF99996666
663333333333333366333333333333333333666666333333
333333333333333333333333003333333333333333333333
333333003333333333333333330033333300333333333333
330000000000000000330000333333333333000000000000
333333000033330000330000330000000000000000000000
0000000000333333333300000033333333330033333366CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666
666633333333333333663333333333333333333333333333
333333333333333333333333330033003333333333333333
333333333333333333333333330033333300333333333333
000000000000333300330000000033333333000000000033
333333330000333333003300000000000000000000000000
0000003333333333330000333333333333333333336666FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9966
666633333333333333336633333333333333663333333333
333333333333333333333333330033333333333333333333
333333330033330033333300333333330000000000333300
330000000033000033330000333333333333330000000033
330033333300333333330000000000000000000000000000
0033333333333300003333333333333333333333666666FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99
666666333333336633333333333366333333336666666633
333333333333333333333333330033333333333333333333
333333330033330000003300333300333333003300003333
330000000000000033003300003333333333333300000000
333333333333000033330000000000000000000000000033
3333333333333300333333333333333333333333666699CC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
996666663333333333333366333333666633333333333333
333333333333333333333333333333000033333333333333
333333330033333300003333000033003333330033003333
333300000000003300333300003333333333333333000000
003333333333333300003333333300000000330033333333
33333333003333333333333333333333333333666699CCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
999966663333333333333333333333333366663333333333
333333333333333333333333330033003333333333333333
003300330000333333000033330000333333000033000033
333300000000000000003333003333333333333333330000
000033333333333333333333333333333333333333333333
33330033003333333333333333333333333366666699FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCC66666633333333333333333333663333666666336666
663333333333333333333333330033333300333333333333
330033333300003333330000333333000033330000330000
333333000000000000333333000033333333663366333333
003333330000333333333333333333333333333333333333
333300003333333333330033333333333333666699CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC996666663333333333333333336666666666666633
666633333333333333333333333333333333003333333300
330000333300003333330033330000330033000000000000
003333330000000000000033333333333333336666333366
663333333333333300333300333333333333333333333333
33333333333333333333333333333366336666CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCC6666666666333333333333333333666666333333
333333333333333333333333333333330000333333333300
003300003333003333330000333300333300330000003300
000033330000000000000033333333333333336666666633
333333333333333333333333003333333333333300333333
33333333003333333333333333333333666699FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF6666666666663333333333333333333366666666
666633333333663333333333333333330000330033333333
333300330033000033333300333300003300330000003300
000033330000000000000000003333333333333366666666
333333333333333333333333333333333333333333333333
333333333333333333333333333333666699FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC99666666666666333333333333333333333333
336666663333333333333333333333330000000033333333
000033003333330033333300003300000033003300000033
000033333300000000000000000033333333333333336666
666633333333333333333333333333333333333333333333
3333333333333333333333336666336699FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCC666666666666666633333333333333336666
666633336666333333333333333333333300003333333333
003300000000330033333300003333000000333333000000
000000333300000000000000000000336666333333333333
666666666666663333333333663333333333333333003333
33333333333333333333333333336699FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC9966666666666666333333333366666666
666666666666333333333333333333333333000033333333
000033333300330000333300003300330000003333000000
000033333333000000000000330000003333336633333333
333333333366666666333333333333333333333333333333
333333333333333333333333333333CCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCC99666666333333333333333333333366
666666666666666633333333333333333333330033333333
333300003333000000333333000000000000003333000000
000000333333330000000000333333330033336633333366
663333333333333333333333333333333333333333333333
333333333333333333333333666666FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF9966666666333333333333663366
666666666666666666333333333333333333333333333333
333333333333333300003333333300003300000033330000
003300333333333333330033333333333333333333333333
333333333333333366663333336633333333333333333333
33333333333333336666663366CCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF66666666666633333333666666
666666666666666666333333333333333333333333333333
333333333333333333000033333300003333330000333300
003333333333333333333333333333333333333333333333
336633333333333333333333333333333333333333333333
333333333333333366666666CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC666666336633333333333366
666666666666999999333333333333333333333333333333
333333333333333333330033333333000033333300333333
003333333333333333333333333333333333333333333333
333333333333333333333333333333333333333333333333
3333333366333366663366CCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF996666663333333333333333
666666666666996666333333333333333333333333333333
333333333333333333333333333333333333333333333333
330033333333333333333366333333336633333333333333
333333333333333333333333333333333333333333333333
33333333333333666699CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99666666333333333333
336666666666666666666666333333333333333333333333
333333333333333333666633333333003333333333333333
333333003333333333663333663333333366663366663333
333333333333333333333333333333333333333333333333
333333336666666699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996666333333333333
336666666666666666996666663333333333333333333333
333333333333333333336666333333330033333333333333
333333333366336633336666336666333333336666666633
333333333333333333333333333333333333333366333333
3366336666666633FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333333333
333366666666669999996666666633333333333333333333
333333333333333333333333333333333300333333333333
663333663366663333333366333366663333333333333333
333333333333333333333333333333333333336633333333
3333666633333399FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC666666333333
333366666666999966999999666666663333663333333333
333333336633663333663333663333333333333333336633
333333666666666666663333666666666666666666333333
333333333333333333333366663333333333333333333333
336666333366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC99666666
663366666666666666666666999966666666666666666666
663333333333333366666666336666666633663333336666
333366336666666666666666333333333366663333333333
333333333333333333333333333333333333333366333333
66336699FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC996666
666666663333666666666699666666666666666666666666
666666663333333366666666666666666666666633333366
663333333333666666666633336633663333333366666633
333333333333333333333333333333666633336666336633
3366CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99
996666666666666666666666666699996666666666666666
666666666666663333336666666666666666666666663333
333333333333666666666633333333333366333333333333
333333333333333333333333333366336666666633333333
33CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC
996666666666666666666666996666666666666666666666
666666666666666666666666666666666666666666666633
333333333333333333336666333333333333333333333333
333333333333333333336633666633663366663333333366
CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCC99666666666666336666666666669966666666666666
666666666666666666666666666666666666666666996666
333333333333333333333333666633333333333333333333
3333333333333333333333666666666666663333336699FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCC996666666666666666666666999966666699666666
666666666699666699666666666666666699996666666666
666633333333333333333333336666666633333333333333
336633333333666666666666666666663333336699CCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCC99996666666666666666666666666666669999
666666666666666666996666666666666666999966666666
666666666666666666666666666666333366663366333366
33333366666666666666666666663333336699CCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF996633666633336666669999996699
996699669999666666666666666666666666666666666699
666666666666666666666666666666666666666666666666
66666666666666666666333333336699CCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCC99996666666666666699999999
999999999999996666666666996666666699996699996666
666699666666666666666666666666666666666666666666
6666666666666666666633666699CCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCC999966999999999999
CCCC99999999999966996666666666666666666699666699
666666666666666666666666666666666666666666666666
666666666633333333336666CCFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC
FFFFCC99CCCC99CC99999999999966666666666666666666
999999666666666666666666666666666666666666666666
66666666333333336666CCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCCCCCCCCCFFCC999999999999666666666666666666
666666666666666666666666666666666666666666666666
6666663366666699CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCFFCCFFFFCC99999999999999666666666666
666666666699669966666666666666666666666666666666
6633336699CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCCCCCCCC999999999999999966
666666666666666666996666666666666666666666666666
666699CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCC
999999999999999999666699999999999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{450, 140.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720000S2000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00J@3oool>0<c<c5X0oooo603<c<`>09VIVEX0oooo4`3<c<`C09VIV@030<c<c03oool0oooo
04P0oooo001U0?oooa80c<c<FP3ooolG0<c<c0l0VIVIFP3oool@0<c<c1H0VIVIB`3oool00680oooo
00<0c<c<0?ooo`3oool04P3<c<aJ0?oooa<0c<c<4`2IVIUJ0?ooo`h0c<c<602IVIU;0?ooo`00G@3o
ool20<c<c0<0oooo503<c<aK0?ooo`l0c<c<102IVIT40<c<c0h0VIVIF`3oool>0<c<c1L0VIVIC03o
ool006@0oooo4P3<c<aK0?oooa80c<c<1P2IVIT00`3<c<`0VIVI09VIV@0:09VIVE/0oooo3`3<c<`F
09VIVD`0oooo001Y0?ooo`d0c<c<F`3ooolC0<c<c080VIVI0P3<c<`>09VIVE/0oooo4@3<c<`D09VI
VD`0oooo001Z0?ooo`030<c<c03oool0c<c<00T0c<c<F`3ooolF0<c<c00309VIV@3<c<`0VIVI00<0
VIVI00<0c<c<09VIV@2IVIT01@2IVIT00`3<c<`0oooo0?ooo`1I0?oooa40c<c<502IVIU<0?ooo`00
J`3oool:0<c<c5`0oooo6@3<c<`409VIV@030<c<c02IVIT0VIVI00@0VIVI00<0c<c<0?ooo`3oool0
F@3ooolD0<c<c100VIVI00<0c<c<0?ooo`3oool0BP3oool006`0oooo2P3<c<aK0?ooo`X0c<c<00<0
oooo0<c<c03<c<`02`3<c<`<09VIV@030<c<c03oool0oooo05T0oooo5@3<c<`?09VIV@030<c<c03o
ool0oooo04X0oooo001@0?ooo`030<c<c03oool0oooo01P0oooo00<0c<c<0?ooo`3<c<`01`3<c<aK
0?oooaX0c<c<1`2IVIT0103<c<`0VIVI09VIV@2IVIUK0?ooo`0309VIV@3<c<`0c<c<0180c<c<402I
VIU=0?ooo`00C`3oool00`3<c<`0oooo0?ooo`0K0?ooo`P0c<c<FP3oool00`2IVIT0c<c<0<c<c00H
0<c<c0/0VIVIFP3oool209VIVA@0c<c<402IVIU=0?ooo`00CP3oool00`2IVIT0IVIV0?ooo`0J0?oo
o`030<c<c03oool0oooo00L0c<c<F@3oool00`2IVIT0<c<c0<c<c00J0<c<c00309VIV@3<c<`0VIVI
00@0VIVI0P3<c<`00`2IVIT0oooo0?ooo`1G0?ooo`0309VIV@0c<c<0c<c<01@0c<c<402IVIU=0?oo
o`00CP3oool206IVIQX0oooo0P3<c<`20?ooo`L0c<c<F@3oool203<c<aX0c<c<0P2IVIT00`3<c<`0
VIVI09VIV@0509VIV@030<c<c03oool0oooo05L0oooo0P0c<c<A0<c<c1@0VIVIC@3oool004d0oooo
00<0IVIV0<c<c03oool06P3oool0103<c<`0oooo0?ooo`3oool70<c<c5P0oooo00<0<c<c09VIV@3<
c<`06@3<c<`209VIV@80c<c<1`2IVIT00`3<c<`0oooo0?ooo`1F0?ooo`0303<c<`2IVIT0c<c<0180
c<c<4`2IVIU=0?ooo`00C03oool206IVIQT0oooo00<0c<c<0?ooo`3oool0303<c<aF0?ooo`0303<c
<`1VIVH0c<c<01<0c<c<4`2IVIT00`3<c<`0oooo0?ooo`1D0?ooo`0303<c<`1VIVH0c<c<0180c<c<
5@2IVIU<0?ooo`00B`3oool00`3<c<`0IVIV0?ooo`0E0?ooo`030<c<c03oool0oooo0080oooo3P3<
c<aE0?ooo`030<c<c00c<c<0c<c<0180c<c<5@2IVIT00`3<c<`0oooo0?ooo`1C0?ooo`030<c<c00c
<c<0c<c<0180c<c<5P2IVIU<0?ooo`00B`3oool00`1VIVH0VIVI0?ooo`0H0?ooo`030<c<c03oool0
c<c<00h0c<c<E03oool00`1VIVH0VIVI0<c<c00B0<c<c0H0VIVI00<0IVIV09VIV@2IVIT03P2IVIUD
0?ooo`0303<c<`2IVIT0c<c<0180c<c<0P2IVIT206IVIP0409VIV@1VIVH0IVIV06IVIP@0VIVI00<0
IVIV09VIV@2IVIT0202IVIU;0?ooo`00BP3oool00`3<c<`0VIVI0?ooo`0@0?ooo`030<c<c03oool0
oooo0080oooo0P3<c<`50?ooo`l0c<c<DP3oool00`3<c<`0VIVI0<c<c00B0<c<c0<0VIVI0P1VIVH5
09VIV@0306IVIP2IVIT0VIVI00/0VIVI00<0c<c<0?ooo`3oool0D03oool00`3<c<`0IVIV0<c<c00B
0<c<c00309VIV@1VIVH0IVIV00P0IVIV3@2IVIT00`3<c<`0oooo0?ooo`180?ooo`00B@3oool00`3<
c<`0IVIV0?ooo`0C0?oooaT0c<c<D@3oool00`2IVIT0IVIV0<c<c00A0<c<c080VIVI00<0IVIV09VI
V@1VIVH01`1VIVH>09VIV@80c<c<D03oool00`3<c<`0IVIV0<c<c0090<c<c0<0VIVI103<c<`309VI
V@0306IVIP2IVIT0IVIV00T0IVIV00<0VIVI06IVIP2IVIT02P2IVIU:0?ooo`00B@3oool206IVIQ80
oooo2P3<c<`00`2IVIT0c<c<0<c<c0070<c<c0030?ooo`3<c<`0c<c<00D0c<c<D03oool00`1VIVH0
<c<c0<c<c00>0<c<c080VIVI0P1VIVH00`2IVIT0c<c<0<c<c0040<c<c080VIVI101VIVH609VIV@03
0<c<c02IVIT0VIVI00@0VIVI00<0c<c<0?ooo`3oool0CP3oool203<c<`@0c<c<00<0VIVI0<c<c03<
c<`00`3<c<`309VIV@80c<c<0P2IVIT00`1VIVH0<c<c09VIV@060<c<c080VIVI00<0<c<c06IVIP1V
IVH00P1VIVH=09VIVDT0oooo00180?ooo`030<c<c01VIVH0c<c<00/0oooo00X0c<c<0?ooo`3oool0
oooo0<c<c01VIVH0oooo0<c<c03oool0c<c<0`3oool50<c<c080VIVI1`3<c<`20?ooo`L0c<c<CP3o
ool00`3<c<`0<c<c09VIV@0:0<c<c080VIVI00T0c<c<09VIV@2IVIT0VIVI0000003<c<`0IVIV09VI
V@1VIVH00P3oool0102IVIT0IVIV09VIV@1VIVH209VIV@<0IVIV1P2IVIT20<c<c0H0VIVI00<0c<c<
0?ooo`3oool0C03oool00`3<c<`0<c<c09VIV@040<c<c00409VIV@3<c<`0c<c<0<c<c0<0VIVI00d0
IVIV0<c<c02IVIT0VIVI06IVIP000000c<c<06IVIP2IVIT0IVIV0?ooo`3<c<`0VIVI00<0IVIV0P2I
VIT00`1VIVH0<c<c06IVIP0406IVIPX0VIVIB@3oool004P0oooo00<0VIVI06IVIP3oool02P3oool3
0<c<c080VIVI303oool20<c<c00309VIV@1VIVH0VIVI00H0c<c<0P3oool70<c<c0030?ooo`3<c<`0
oooo04/0oooo00<0IVIV03<c<`3<c<`02P3<c<`209VIV@0306IVIP0c<c<0IVIV0080c<c<0`3oool0
0`3<c<`0oooo0?ooo`050<c<c080IVIV0P0c<c<00`1VIVH0VIVI09VIV@0309VIV@80c<c<1P2IVIT0
0`3<c<`0oooo0<c<c01<0?ooo`0306IVIP0c<c<0c<c<00<0c<c<0P2IVIT30<c<c080VIVI00<0IVIV
09VIV@1VIVH00P0c<c<30<c<c080oooo00<0c<c<0?ooo`3<c<`0103<c<`00`2IVIT0<c<c06IVIP03
03<c<`0306IVIP2IVIT0VIVI00X0VIVI0P3oool00`3<c<`0oooo0?ooo`140?ooo`00B03oool00`1V
IVH0VIVI0?ooo`0:0?ooo`80c<c<0P2IVIT00`3<c<`0oooo0?ooo`0<0?ooo`80VIVI00<0<c<c09VI
V@3<c<`0103<c<`30?ooo`H0c<c<CP3oool00`0c<c<0IVIV0<c<c0090<c<c080VIVI00H0IVIV03<c
<`1VIVH0c<c<0?ooo`3<c<`30?ooo`030<c<c03oool0oooo0080c<c<00D0oooo0<c<c03<c<`0c<c<
06IVIP0303<c<`0306IVIP2IVIT0VIVI0080VIVI0`3<c<`509VIV@030<c<c03oool0oooo04`0oooo
00<0<c<c06IVIP3<c<`00`3<c<`209VIV@<0c<c<0P2IVIT206IVIP80<c<c00<0VIVI0<c<c03<c<`0
0P3<c<`00`3oool0c<c<0?ooo`050<c<c00309VIV@3<c<`0<c<c00<0<c<c00<0IVIV09VIV@1VIVH0
2P2IVIT00`3<c<`0oooo0?ooo`160?ooo`00A`3oool00`3<c<`0<c<c0?ooo`0:0?ooo`<0c<c<0P2I
VIT20<c<c0/0oooo00<0c<c<0?ooo`3oool00`3<c<`00`2IVIT0c<c<0<c<c0020<c<c0<0oooo1P3<
c<`00`2IVIT0c<c<0<c<c01:0?ooo`030<c<c00c<c<0c<c<00T0c<c<0`2IVIT01@1VIVH0<c<c06IV
IP1VIVH0VIVI00<0c<c<00D0oooo0<c<c03oool0c<c<09VIV@030<c<c00409VIV@3<c<`0c<c<0<c<
c080VIVI00<0<c<c06IVIP2IVIT00P2IVIT30<c<c0D0VIVI00@0c<c<09VIV@3<c<`0c<c<B`3oool0
0`0c<c<0c<c<0<c<c0030<c<c080VIVI0`3<c<`209VIV@0406IVIP0c<c<0<c<c03<c<`80IVIV1`3<
c<`209VIV@80c<c<00<0IVIV0<c<c02IVIT00`2IVIT00`0c<c<0IVIV09VIV@0<09VIV@80c<c<A@3o
ool004H0oooo0P1VIVH00`0c<c<0oooo0?ooo`080?ooo`80c<c<203oool0103<c<`0oooo0?ooo`3o
ool60<c<c0030?ooo`3<c<`0c<c<0080c<c<00<0IVIV09VIV@3<c<`00P3<c<`40?ooo`D0c<c<0P3o
ool20<c<c4L0oooo00@0c<c<06IVIP0c<c<0<c<c2P3<c<`309VIV@<0c<c<102IVIT0101VIVH0VIVI
09VIV@2IVIT306IVIP0609VIV@1VIVH0IVIV0<c<c02IVIT0c<c<0P2IVIT203<c<`0306IVIP2IVIT0
VIVI00@0c<c<102IVIT50<c<c4P0oooo00<0IVIV03<c<`000000103<c<`00`2IVIT0c<c<09VIV@03
0<c<c00309VIV@1VIVH0VIVI0080c<c<0`2IVIT<06IVIP0309VIV@1VIVH0VIVI0080VIVI0P0c<c<0
0`1VIVH0VIVI09VIV@0909VIV@80oooo0P3<c<a40?ooo`00A@3oool0102IVIT0<c<c03<c<`1VIVH;
0?ooo`030<c<c03oool0oooo00d0oooo203<c<`206IVIP0309VIV@3<c<`0c<c<00<0oooo1`3<c<`2
0?ooo`030<c<c03oool0oooo04D0oooo00@0VIVI03<c<`0c<c<0<c<c2P3<c<`00`2IVIT0IVIV0<c<
c0090<c<c0D0VIVI0`1VIVH00`2IVIT0IVIV09VIV@0209VIV@0303<c<`000000<c<c0080VIVI0`3<
c<`509VIV@80c<c<00<0oooo0<c<c03<c<`0A`3oool0102IVIT0000003<c<`0c<c<40<c<c0<0VIVI
0`3<c<`00`2IVIT0IVIV09VIV@090<c<c0@0VIVI101VIVH0202IVIT0IVIV09VIV@1VIVH0VIVI03<c
<`000000<c<c2`2IVIT0103<c<`0oooo0?ooo`3<c<a40?ooo`00A03oool01@3<c<`0<c<c06IVIP0c
<c<0c<c<00/0oooo00<0c<c<0?ooo`3oool0403oool50<c<c080VIVI0`3<c<`30?ooo`L0c<c<00<0
IVIV0?ooo`3oool0AP3oool01@3<c<`0<c<c03<c<`0c<c<0VIVI00X0c<c<0P2IVIT@0<c<c0D0VIVI
0`1VIVH0100c<c<0IVIV09VIV@2IVIT30<c<c0L0VIVI00<0<c<c0?ooo`3oool0AP3oool01@3<c<`0
000003<c<`0c<c<0VIVI00X0c<c<0`2IVIT;0<c<c0L0VIVI101VIVH303<c<`0306IVIP2IVIT0VIVI
00@0VIVI00<0IVIV09VIV@2IVIT00P2IVIT00`0c<c<0oooo0?ooo`140?ooo`00A03oool20<c<c0l0
oooo00<0c<c<0?ooo`3oool03`3oool:0<c<c0<0oooo1`3<c<`209VIVDL0oooo403<c<`209VIVA00
c<c<2`2IVIT30<c<c0H0VIVI00<0c<c<09VIV@2IVIT0B03oool00`2IVIT0c<c<09VIV@0;0<c<c080
VIVI00<0IVIV09VIV@3<c<`0203<c<`>09VIV@<0IVIV302IVIU50?ooo`00A03oool00`3<c<`0oooo
0?ooo`0>0?ooo`030<c<c03oool0oooo00d0oooo303<c<`30?ooo`L0c<c<00<0IVIV0<c<c03oool0
AP3oool00`2IVIT0c<c<0<c<c00=0<c<c080VIVI3`3<c<`<09VIV@<0c<c<1`2IVIT00`1VIVH0c<c<
0?ooo`160?ooo`l0c<c<102IVIT90<c<c0T0VIVI0P1VIVH00`2IVIT0IVIV09VIV@0=09VIV@0306IV
IP3<c<`0oooo04@0oooo00130?ooo`030<c<c03oool0oooo01`0oooo0P3<c<`00`3oool0c<c<0<c<
c00;0<c<c080oooo1`3<c<`00`1VIVH0c<c<0?ooo`150?oooa80c<c<0P2IVIT;0<c<c080VIVI00<0
c<c<09VIV@2IVIT02`2IVIT00`3<c<`0VIVI09VIV@0609VIV@0303<c<`3<c<`0oooo04H0oooo3`3<
c<`509VIV@T0c<c<1`2IVIT806IVIP0309VIV@1VIVH0VIVI00<0VIVI00<0IVIV09VIV@2IVIT00P2I
VIT00`0c<c<0c<c<0?ooo`140?ooo`00@`3oool00`3<c<`0oooo0?ooo`0I0?ooo`030<c<c03oool0
oooo0080oooo3@3<c<`30?ooo`L0c<c<00<0<c<c06IVIP3oool0A@3ooolB0<c<c080VIVI2P3<c<`2
09VIV@030<c<c02IVIT0VIVI00`0VIVI00<0c<c<09VIV@2IVIT01P2IVIT00`0c<c<0IVIV0?ooo`15
0?ooo`@0c<c<00<0VIVI0<c<c03<c<`02P3<c<`409VIV@P0c<c<1`2IVIT906IVIPH0VIVI00<0IVIV
09VIV@2IVIT00P2IVIT00`000000IVIV0?ooo`140?ooo`00A`3oool00`3<c<`0oooo0?ooo`0J0?oo
o`/0c<c<0`3oool80<c<c00309VIV@1VIVH0VIVI04H0oooo0`3<c<`209VIV@L0c<c<00<0oooo0<c<
c03<c<`0103<c<`209VIV@X0c<c<3P2IVIT20<c<c0T0VIVI00<0<c<c09VIV@3oool0A@3oool30<c<
c080VIVI3@3<c<`409VIV@L0c<c<1@2IVIT606IVIP0409VIV@1VIVH0IVIV06IVIP`0VIVI00<0<c<c
09VIV@3oool0A03oool004L0oooo0P3<c<`K0?ooo`/0c<c<103oool70<c<c00409VIV@0c<c<0IVIV
0<c<c4@0oooo1@3<c<`00`2IVIT0c<c<0<c<c0040<c<c0030?ooo`3<c<`0c<c<00H0c<c<0P2IVIT:
0<c<c0`0VIVI0`3<c<`909VIV@80<c<c00<0VIVI0?ooo`3oool0@P3oool30<c<c0<0VIVI3@3<c<`4
09VIV@P0c<c<1P2IVIT606IVIPd0VIVI00@0IVIV03<c<`0c<c<0VIVIA03oool006@0oooo2P3<c<`4
0?ooo`T0c<c<00@0IVIV03<c<`1VIVH0c<c<@`3oool>0<c<c0030?ooo`3<c<`0c<c<00@0c<c<0P2I
VIT:0<c<c0/0VIVI103<c<`909VIV@<0<c<c00<0c<c<0?ooo`3oool0@@3oool30<c<c0<0VIVI3@3<
c<`509VIV@P0c<c<1P2IVIT506IVIPd0VIVI00D0IVIV03<c<`0c<c<0<c<c0<c<c0130?ooo`00A@3o
ool20<c<c1/0oooo2`3<c<`60?ooo`X0c<c<0P1VIVI20?ooo`@0c<c<0P2IVIT90<c<c0030?ooo`3<
c<`0c<c<00l0c<c<2`2IVIT50<c<c0L0VIVI00@0c<c<09VIV@2IVIT0IVIV0P0c<c<00`3<c<`0oooo
0?ooo`0o0?ooo`<0c<c<102IVIT>0<c<c0<0VIVI0`3<c<`0102IVIT0c<c<0<c<c03<c<`909VIV@<0
IVIV3`2IVIT206IVIP80<c<c@`3oool004D0oooo0P3<c<`K0?ooo`X0c<c<1`3oool<0<c<c480oooo
0`3<c<`209VIV@P0c<c<00<0oooo0<c<c03<c<`04@3<c<`;09VIV@D0c<c<1`2IVIT00`3<c<`0VIVI
09VIV@0209VIV@030<c<c03oool0oooo0400oooo00H0VIVI0<c<c02IVIT0VIVI06IVIP2IVIT@0<c<
c0<0VIVI0P3<c<`00`2IVIT0c<c<0<c<c0020<c<c0L0VIVI0`1VIVH?09VIV@0506IVIP2IVIT0IVIV
06IVIP3<c<`0@`3oool004@0oooo0P3<c<`L0?ooo`X0c<c<1P3oool00`3<c<`0oooo0<c<c0090<c<
c4<0oooo0P3<c<`206IVIP80VIVI6`3<c<`:09VIV@L0c<c<1P2IVIT00`3<c<`0VIVI09VIV@0209VI
VD<0oooo00<0c<c<09VIV@1VIVH00P1VIVH00`2IVIT0c<c<0<c<c00=0<c<c080VIVI203<c<`409VI
V@L0IVIV3`2IVIT306IVIP0309VIV@3oool0oooo0480oooo00140?ooo`80c<c<703oool:0<c<c0L0
oooo2`3<c<a20?ooo`<0c<c<0`2IVITK0<c<c0X0VIVI1P3<c<`809VIV@030<c<c02IVIT0VIVI0080
VIVI@P3oool01@2IVIT0c<c<09VIV@2IVIT0IVIV0080VIVI3P3<c<`409VIV@L0c<c<102IVIT506IV
IQ40VIVI0P1VIVH209VIVD@0oooo00140?ooo`80c<c<6`3oool90<c<c0T0oooo2`3<c<a20?ooo`<0
c<c<0`2IVITK0<c<c0X0VIVI1`3<c<`709VIV@030<c<c02IVIT0VIVI0080VIVI@P3oool01@2IVIT0
c<c<09VIV@2IVIT0IVIV0080VIVI3P3<c<`309VIV@P0c<c<102IVIT306IVIQL0VIVIA03oool004<0
oooo0`3<c<`L0?ooo`P0c<c<203oool=0<c<c440oooo0P3<c<`409VIVA/0c<c<2P2IVIT60<c<c0h0
VIVI@@3oool0102IVIT0c<c<09VIV@2IVIT206IVIP0309VIV@3<c<`0c<c<00T0c<c<00<0VIVI0<c<
c03<c<`00P2IVIT90<c<c0@0VIVI0`1VIVHC09VIV@0506IVIP2IVIT0VIVI06IVIP2IVIT0@`3oool0
0440oooo00<0c<c<09VIV@2IVIT00P3<c<`L0?ooo`P0c<c<203oool80<c<c00309VIV@3<c<`0c<c<
0080c<c<@03oool00`3<c<`0VIVI09VIV@0306IVIP0309VIV@3<c<`0c<c<01T0c<c<2P2IVIT50<c<
c0T0VIVI00<0c<c<06IVIP1VIVH00`2IVIU00?ooo`030<c<c02IVIT0VIVI00<0IVIV00<0VIVI0<c<
c03<c<`02@3<c<`609VIV@T0c<c<0`2IVIT406IVIQ<0VIVI0P1VIVH209VIV@0306IVIP3oool0oooo
0440oooo00100?ooo`030<c<c02IVIT0c<c<0080VIVI00<0c<c<0?ooo`3oool06@3oool90<c<c005
0?ooo`3<c<`0c<c<0?ooo`3<c<`00P3oool>0<c<c400oooo00@0c<c<09VIV@1VIVH0VIVI0P1VIVH0
0`2IVIT0c<c<0<c<c00=0<c<c080VIVI2P3<c<`;09VIV@030<c<c02IVIT0VIVI00/0VIVI0P1VIVH3
09VIVD00oooo0P2IVIT01@0c<c<0VIVI03<c<`0c<c<0VIVI00d0c<c<1@2IVIT80<c<c0@0VIVI0P1V
IVHD09VIV@80IVIV0P2IVIT00`1VIVH0oooo0?ooo`110?ooo`00?`3oool0103<c<`0VIVI09VIV@1V
IVH209VIV@030<c<c03oool0oooo00`0oooo00<0c<c<0?ooo`3oool00P3<c<`80?oooaX0c<c<0P2I
VIT20<c<c3l0oooo00D0c<c<09VIV@1VIVH0IVIV03<c<`0206IVIP0309VIV@3<c<`0c<c<00h0c<c<
0`2IVIT80<c<c1P0VIVI00<0c<c<06IVIP1VIVH00P1VIVH00`2IVIT0c<c<0?ooo`0m0?ooo`050<c<
c01VIVH0IVIV06IVIP0000000P1VIVH00`2IVIT0c<c<0<c<c00=0<c<c0D0VIVI1@3<c<`309VIV@@0
IVIV502IVIT01P1VIVH0<c<c03<c<`0c<c<0IVIV09VIVD80oooo00100?ooo`0309VIV@1VIVH0VIVI
0080IVIV00<0c<c<0?ooo`3oool01@3oool=0<c<c0L0oooo6P3<c<`209VIV@80c<c<?`3oool01@3<
c<`0IVIV06IVIP0c<c<0IVIV0080<c<c00<0VIVI0<c<c03<c<`01P3<c<`<09VIV@L0c<c<302IVIT2
0<c<c0`0VIVI0`1VIVH209VIVCh0oooo00<0VIVI06IVIP1VIVH0100c<c<00`2IVIT0c<c<0<c<c005
0<c<c0<0VIVI00<0IVIV09VIV@2IVIT01`2IVIT50<c<c0<0VIVI1P1VIVH00`2IVIT0IVIV09VIV@0?
09VIV@0606IVIP0c<c<0<c<c03<c<`1VIVH0VIVI@P3oool003l0oooo0P3<c<`203<c<`80IVIV00<0
c<c<0?ooo`3oool01@3oool20<c<c080VIVI00D0c<c<06IVIP1VIVH0IVIV09VIV@040<c<c0L0oooo
6P3<c<`209VIV@<0c<c<?P3oool309VIV@8000000P0c<c<00`2IVIT0c<c<0<c<c0060<c<c00409VI
V@1VIVH0IVIV0<c<c0<0<c<c0P1VIVH00`2IVIT0IVIV09VIV@070<c<c0h0VIVI0`3<c<`909VIV@@0
IVIV00<0VIVI0?ooo`3oool0?03oool00`2IVIT0IVIV06IVIP0200000080<c<c00<0VIVI0<c<c03<
c<`01@3<c<`01@2IVIT0IVIV03<c<`1VIVH0VIVI00@0<c<c101VIVH00`2IVIT0c<c<0<c<c0030<c<
c080VIVI1@1VIVH509VIV@80IVIV302IVIT206IVIP80<c<c00<0IVIV09VIV@3oool0@@3oool003h0
oooo0P3<c<`00`3oool0<c<c03<c<`0206IVIP030<c<c03oool0oooo00H0oooo0P3<c<`01@2IVIT0
IVIV06IVIP2IVIT0<c<c0080VIVI00<0c<c<09VIV@3<c<`01`3ooolI0<c<c0<0VIVI0`3<c<`n0?oo
o`80VIVI00<0c<c<03<c<`0c<c<00P0c<c<90<c<c00409VIV@3<c<`0VIVI03<c<`80IVIV00H00000
06IVIP1VIVH0VIVI06IVIP2IVIT70<c<c0<0VIVI0P1VIVH00`2IVIT0c<c<0<c<c00409VIV@030<c<
c02IVIT0VIVI0080VIVI00<0c<c<09VIV@2IVIT01@2IVIT406IVIP80VIVI?P3oool206IVIP0309VI
V@0c<c<0<c<c0080<c<c00<0VIVI0<c<c03<c<`01P3<c<`03@1VIVH0c<c<06IVIP0c<c<0IVIV09VI
V@000000<c<c06IVIP2IVIT0<c<c06IVIP2IVIT01@3<c<`209VIV@D0IVIV3`2IVIT01@1VIVH0VIVI
09VIV@2IVIT0IVIV0080<c<c0P1VIVH00`2IVIT0oooo0?ooo`100?ooo`00?@3oool0101VIVH0c<c<
0<c<c03oool203<c<`80IVIV00<0c<c<0?ooo`3oool01`3oool01`3<c<`0oooo0<c<c02IVIT0IVIV
03<c<`1VIVH00P2IVIT20<c<c0L0oooo103<c<`206IVIP@0c<c<0P2IVIT=0<c<c0<0VIVI0`3<c<`m
0?ooo`0403<c<`2IVIT0IVIV09VIV@@0<c<c00<0VIVI0<c<c03<c<`01`3<c<`0102IVIT0c<c<0<c<
c01VIVH303<c<`<0IVIV00<0VIVI0<c<c03<c<`00P3<c<`00`3oool0c<c<0<c<c00409VIV@80<c<c
102IVIT206IVIPd0VIVI101VIVH209VIVCd0oooo00D0<c<c06IVIP1VIVH0VIVI0000000303<c<`03
09VIV@3<c<`0c<c<00H0c<c<102IVIT203<c<`030000000c<c<0IVIV00<0IVIV00<0VIVI0<c<c03<
c<`00`3<c<`209VIV@<0IVIV0P0c<c<706IVIPL0VIVI00<0IVIV09VIV@2IVIT00P2IVIT00`1VIVH0
<c<c03<c<`0206IVIP0309VIV@3oool0oooo0400oooo000l0?ooo`0303<c<`1VIVH0oooo0080oooo
0`0c<c<00`1VIVH0c<c<0?ooo`090?ooo`@0c<c<0P2IVIT30<c<c0P0oooo1@3<c<`00`2IVIT0c<c<
0<c<c00406IVIPD0VIVI203<c<`00`2IVIT0IVIV09VIV@030<c<c3`0oooo0P0c<c<30<c<c0@0<c<c
2`3<c<`409VIV@<0IVIV0P2IVIT80<c<c0@0VIVI0P1VIVH00`2IVIT0c<c<03<c<`0303<c<`<0IVIV
2P2IVIT306IVIP<0VIVI?03oool00`0c<c<0000009VIV@0209VIV@050000000c<c<0<c<c03<c<`2I
VIT00`3<c<`00`2IVIT0c<c<0<c<c0040<c<c0<0VIVI0P1VIVH0100c<c<0IVIV06IVIP1VIVH209VI
V@D0c<c<0P2IVIT406IVIP0503<c<`2IVIT0c<c<03<c<`0000000P0c<c<00`1VIVH0<c<c06IVIP05
06IVIP@0VIVI00L0IVIV03<c<`1VIVH0<c<c06IVIP2IVIT0IVIV0480oooo000k0?ooo`0306IVIP0c
<c<0<c<c0080oooo00H0c<c<06IVIP1VIVH0<c<c06IVIP3<c<`30?ooo`80c<c<203oool60<c<c0P0
oooo1@3<c<`01@2IVIT0c<c<09VIV@3<c<`000000080IVIV0P2IVIT306IVIPL0c<c<00@0VIVI06IV
IP1VIVH0IVIV0`3<c<`k0?ooo`80<c<c00@0000009VIV@3<c<`0VIVI100c<c<40<c<c080VIVI203<
c<`609VIV@P0c<c<1@2IVIT306IVIP0409VIV@000000<c<c03<c<`80VIVI0P0c<c<206IVIPL0VIVI
00<0<c<c06IVIP0c<c<00`2IVITk0?ooo`80<c<c00@0000009VIV@2IVIT0IVIV100c<c<40<c<c080
VIVI1@3<c<`409VIV@80IVIV1@2IVIT50<c<c080VIVI1`1VIVH01P2IVIT0000003<c<`0c<c<0VIVI
06IVIP80<c<c0P1VIVH609VIV@0406IVIP0c<c<0<c<c03<c<`<0IVIV@P3oool003/0oooo0P1VIVH3
03<c<`0606IVIP0c<c<0IVIV03<c<`1VIVH0c<c<103oool20<c<c0L0oooo1P3<c<`80?ooo`P0c<c<
00<0VIVI03<c<`0c<c<00`1VIVH209VIV@P0c<c<00@0VIVI06IVIP1VIVH0IVIV0`3<c<`k0?ooo`80
<c<c0`00000503<c<`D0c<c<0P2IVIT70<c<c0H0VIVI2@3<c<`709VIV@0606IVIP0c<c<0<c<c03<c
<`1VIVH0<c<c0P1VIVH809VIV@0706IVIP0c<c<0<c<c03<c<`2IVIT0IVIV09VIV@0k0?ooo`80<c<c
0`00000503<c<`0309VIV@3<c<`0c<c<0080c<c<0`2IVIT50<c<c0T0VIVI1@3<c<`209VIV@D0IVIV
00D0VIVI06IVIP1VIVH0<c<c0000000303<c<`L0IVIV0`2IVIT0101VIVH0<c<c03<c<`0c<c<306IV
IT80oooo000j0?ooo`030<c<c01VIVH0IVIV0080<c<c00<0IVIV03<c<`0c<c<00P0c<c<00`1VIVH0
c<c<0?ooo`040?ooo`<0c<c<0`3oool00`3<c<`0oooo0<c<c0060<c<c0L0oooo2P3<c<`00`2IVIT0
IVIV09VIV@0209VIV@T0c<c<00@0VIVI06IVIP1VIVH0IVIV0`3<c<`j0?ooo`030<c<c00c<c<0<c<c
00P0<c<c1P3<c<`309VIV@D0c<c<102IVIT00`1VIVH0VIVI09VIV@070<c<c0X0VIVI101VIVH00`2I
VIT0IVIV09VIV@0709VIV@0706IVIP0c<c<0<c<c03<c<`2IVIT0IVIV09VIV@0j0?ooo`050<c<c00c
<c<0<c<c03<c<`000000100c<c<00`000000<c<c09VIV@050<c<c0<0VIVI103<c<`309VIV@@0IVIV
0P2IVIT40<c<c0@0VIVI101VIVH309VIV@80IVIV00<0<c<c06IVIP1VIVH01P1VIVH409VIV@@0<c<c
00<0VIVI03<c<`1VIVH0@P3oool003X0oooo00@0c<c<06IVIP0c<c<0<c<c0P1VIVH403<c<`0306IV
IP3<c<`0oooo00H0oooo0`3<c<`809VIV@80c<c<1`3oool;0<c<c00309VIV@3<c<`0VIVI00X0c<c<
0P1VIVH203<c<`<0c<c<>P3oool00`2IVIT0<c<c03<c<`0803<c<`0309VIV@3<c<`0c<c<00@0c<c<
102IVIT806IVIP80VIVI203<c<`<09VIV@0306IVIP2IVIT0VIVI00P0VIVI100c<c<00`2IVIT0IVIV
09VIV@0j0?ooo`0309VIV@0c<c<0<c<c00P0<c<c00<0VIVI0<c<c03<c<`0103<c<`00`2IVIT0IVIV
06IVIP0606IVIP80<c<c0P1VIVH209VIV@@0c<c<102IVIT406IVIP0409VIV@1VIVH0VIVI09VIV@H0
IVIV1`2IVIT0201VIVH0<c<c03<c<`0c<c<0000009VIV@0c<c<0VIVI@P3oool003X0oooo00<0c<c<
06IVIP0c<c<01P0c<c<206IVIP030<c<c03oool0oooo00H0oooo0P3<c<`01@2IVIT0c<c<0<c<c03<
c<`0VIVI00<0c<c<2@3oool30<c<c0<0VIVI4@3<c<`0202IVIT0IVIV03<c<`0c<c<0IVIV0<c<c02I
VIT0c<c<>P3oool00`2IVIT0<c<c03<c<`0303<c<`030000000c<c<0<c<c0080<c<c00<0VIVI0<c<
c03<c<`01P3<c<`;09VIV@T0c<c<0P2IVIT306IVIQ80VIVI100c<c<00`2IVIT0IVIV09VIV@0j0?oo
o`040<c<c00c<c<0000000000080<c<c00<0000003<c<`0c<c<00P0c<c<209VIV@L0c<c<1@2IVIT5
06IVIP0309VIV@3<c<`0c<c<00@0c<c<102IVIT0101VIVH0<c<c03<c<`0c<c<206IVIPl0VIVI00<0
IVIV03<c<`0c<c<00P0c<c<00`1VIVH0<c<c06IVIP120?ooo`00>P3oool00`3<c<`0IVIV03<c<`07
03<c<`0306IVIP3<c<`0oooo00d0oooo00<0c<c<0?ooo`3oool02`3oool20<c<c0@0VIVI403<c<`0
1`2IVIT0<c<c03<c<`0c<c<0VIVI0<c<c02IVIT00P3<c<`i0?ooo`030<c<c00c<c<0<c<c00<0<c<c
00<0000003<c<`0c<c<00P0c<c<00`2IVIT0c<c<0<c<c00K0<c<c00509VIV@1VIVH0IVIV03<c<`1V
IVH0402IVIT0101VIVH0<c<c03<c<`0c<c<306IVIP0309VIV@3<c<`0oooo03P0oooo00<0c<c<03<c
<`0c<c<00`0c<c<2000000<0<c<c00<0IVIV09VIV@3<c<`05`3<c<`509VIV@0306IVIP0c<c<0<c<c
0080IVIV3`2IVIT0101VIVH0<c<c03<c<`0c<c<206IVIP0303<c<`1VIVH0oooo0440oooo000k0?oo
o`0306IVIP0c<c<0<c<c00D0<c<c0P1VIVH00`2IVIT0c<c<0?ooo`0L0?ooo`80c<c<0P2IVIT306IV
IP0309VIV@3<c<`0c<c<00D0c<c<00<0VIVI0<c<c03<c<`00P3<c<`00`1VIVH0<c<c03<c<`0206IV
IP040<c<c02IVIT0VIVI09VIVCX0oooo2P0c<c<00`2IVIT0c<c<0<c<c0080<c<c0050?ooo`3<c<`0
c<c<0<c<c03oool0403<c<`00`2IVIT0IVIV06IVIP0303<c<`0306IVIP2IVIT0VIVI00@0VIVI0P1V
IVH409VIV@D0<c<c00@0VIVI06IVIP1VIVH0IVIV>P3oool603<c<`060000000c<c<0<c<c03<c<`1V
IVH0VIVI603<c<`709VIV@0306IVIP0c<c<0<c<c0080<c<c00<0IVIV09VIV@2IVIT00P2IVIT506IV
IP80VIVI00<0IVIV03<c<`0c<c<00`0c<c<206IVIP0303<c<`1VIVH0oooo0400oooo000k0?ooo`80
IVIV1P0c<c<206IVIP0309VIV@3<c<`0oooo01h0oooo0P3<c<`209VIV@<0IVIV1P2IVIT50<c<c004
06IVIP0c<c<0<c<c03<c<`@0IVIV00<0VIVI0?ooo`3oool0>03oool603<c<`060000000c<c<0<c<c
03<c<`1VIVH0VIVI2@3<c<`00`3oool0c<c<0?ooo`030<c<c080oooo3`3<c<`00`2IVIT0IVIV06IV
IP0303<c<`H0IVIV1@2IVIT803<c<`0306IVIP3oool0oooo03P0oooo0`0c<c<010000000<c<c03<c
<`00000303<c<`0306IVIP2IVIT0VIVI01H0c<c<2P2IVIT206IVIP@0<c<c1P1VIVH209VIV@80IVIV
100c<c<01@000000<c<c03<c<`0c<c<0IVIV0440oooo000k0?ooo`D0IVIV0`0c<c<206IVIP0309VI
V@3<c<`0oooo01h0oooo103<c<`209VIV@0306IVIP2IVIT0VIVI00<0VIVI1@3<c<`00`2IVIT0<c<c
03<c<`0403<c<`80IVIV>`3oool603<c<`8000000P0c<c<00`1VIVH0VIVI0<c<c0060<c<c0P0oooo
4P3<c<`209VIV@80IVIV00<0<c<c06IVIP1VIVH00`1VIVH609VIV@D0<c<c00@0000003<c<`0c<c<0
c<c<>P3oool603<c<`8000000P0c<c<00`1VIVH0VIVI09VIV@0F0<c<c0/0VIVI0`1VIVH503<c<`80
IVIV102IVIT00`1VIVH0<c<c03<c<`0203<c<`8000000P0c<c=20?ooo`00>P3oool0103<c<`0IVIV
06IVIP1VIVH203<c<`D0IVIV00<0VIVI0<c<c03<c<`0803oool?0<c<c080IVIV1@0c<c<00`1VIVH0
<c<c06IVIP0i0?ooo`030<c<c00c<c<0IVIV00P0<c<c00<0IVIV09VIV@3<c<`01`3<c<`30?ooo`03
0<c<c03oool0oooo0080oooo403<c<`@09VIV@X0<c<c>@3oool00`3<c<`0<c<c03<c<`0803<c<`03
06IVIP2IVIT0VIVI01D0c<c<00<0VIVI0<c<c02IVIT0302IVIT506IVIP@0VIVI0P1VIVH503<c<`03
0000000c<c<0<c<c0080<c<c@@3oool003X0oooo00<0VIVI06IVIP1VIVH00`1VIVH203<c<`0306IV
IP0c<c<0IVIV0080VIVI00<0c<c<0?ooo`3oool07P3oool>0<c<c00309VIV@1VIVH0IVIV0080<c<c
00<0IVIV03<c<`0c<c<00P0c<c<00`1VIVH0c<c<0?ooo`0g0?ooo`0309VIV@0c<c<0<c<c00P0<c<c
00<0IVIV09VIV@2IVIT01P3<c<`0103oool0c<c<0<c<c03<c<`30?ooo`030<c<c03oool0c<c<00l0
c<c<0P2IVIT0103<c<`0VIVI0<c<c03<c<`:09VIV@P0<c<c00<0000003<c<`2IVIT0>03oool00`2I
VIT0<c<c03<c<`0803<c<`80IVIV0P2IVIT=0<c<c0030?ooo`3<c<`0c<c<00D0c<c<00<0VIVI0<c<
c02IVIT0502IVIT206IVIPD0<c<c00H0000003<c<`0c<c<0000003<c<`2IVIU00?ooo`00>P3oool0
0`2IVIT0IVIV06IVIP0306IVIP@0<c<c0P1VIVH00`2IVIT0c<c<0?ooo`0Q0?ooo``0c<c<00D0VIVI
06IVIP0c<c<0<c<c06IVIP0503<c<`0306IVIP2IVIT0oooo03L0oooo00<0IVIV03<c<`1VIVH0200c
<c<206IVIP0309VIV@3<c<`0c<c<00L0c<c<1@3ooolA0<c<c0<0VIVI00<0c<c<09VIV@2IVIT02@2I
VIT00`1VIVH0<c<c03<c<`0203<c<`030000000c<c<0<c<c00<0<c<c00<0VIVI0?ooo`3oool0=P3o
ool00`1VIVH0<c<c03<c<`0503<c<`040000000c<c<0<c<c03<c<`80IVIV00<0VIVI0<c<c03<c<`0
4P3<c<`H09VIV@80IVIV100c<c<200000080<c<c00<0000003<c<`2IVIT0@03oool003X0oooo1P1V
IVH303<c<`<0IVIV0P2IVIT00`3<c<`0oooo0?ooo`0M0?ooo`d0c<c<00D0VIVI06IVIP0c<c<0<c<c
06IVIP0703<c<`0309VIV@3oool0oooo03H0oooo00<0<c<c06IVIP0c<c<02@0c<c<206IVIP0309VI
V@3<c<`0c<c<00<0c<c<0P3oool00`3<c<`0oooo0?ooo`030?ooo`l0c<c<00<0VIVI0<c<c02IVIT0
3@2IVIT00`1VIVH0<c<c03<c<`0203<c<`050000000c<c<0<c<c03<c<`0000000P0c<c<00`1VIVH0
oooo0?ooo`0f0?ooo`L0<c<c0P00000303<c<`0306IVIP0c<c<0VIVI01@0c<c<5`2IVIT206IVIP@0
<c<c00<0000003<c<`0000000P00000203<c<`0306IVIP3oool0oooo03h0oooo000j0?ooo`0309VI
V@1VIVH0IVIV00@0IVIV0`0c<c<206IVIP80VIVI00<0c<c<0?ooo`3oool06`3oool00`3<c<`0oooo
0<c<c00<0<c<c00509VIV@1VIVH0<c<c03<c<`1VIVH01P0c<c<00`1VIVH0VIVI0?ooo`0g0?ooo`03
06IVIP0c<c<0IVIV00T0<c<c0P1VIVH00`2IVIT0c<c<0<c<c0050<c<c0@0oooo0P3<c<`00`3oool0
c<c<0<c<c00=0<c<c0l0VIVI00<0IVIV03<c<`0c<c<01@0c<c<200000080<c<c00<0IVIV0?ooo`3o
ool0=P3oool00`1VIVH0<c<c03<c<`0;03<c<`0309VIV@3<c<`0c<c<0140c<c<5`2IVIT306IVIP@0
<c<c1@00000203<c<`0306IVIP3oool0oooo03h0oooo000j0?ooo`L0IVIV0P0c<c<406IVIP0309VI
V@3<c<`0oooo01d0oooo3@3<c<`0102IVIT0IVIV06IVIP1VIVH803<c<`0306IVIP3oool0oooo03L0
oooo100c<c<00`1VIVH0<c<c03<c<`0603<c<`0306IVIP2IVIT0c<c<00H0c<c<1`3oool?0<c<c0h0
VIVI00<0IVIV03<c<`0c<c<0100c<c<3000000<0<c<c>@3oool=03<c<`80IVIV0P2IVITA0<c<c1H0
VIVI0`1VIVH503<c<`D000000P0c<c=10?ooo`00>P3oool706IVIP0303<c<`1VIVH0<c<c00<0IVIV
00<0VIVI0<c<c03<c<`06P3oool00`3<c<`0oooo0?ooo`0<0<c<c080VIVI0P1VIVH903<c<`0306IV
IP3oool0oooo03H0oooo00<0c<c<06IVIP0c<c<00`1VIVH803<c<`0306IVIP2IVIT0VIVI00H0c<c<
0`3oool00`3<c<`0oooo0?ooo`0=0<c<c00309VIV@3<c<`0VIVI00h0VIVI00<0IVIV03<c<`0c<c<0
0P0c<c<30000000303<c<`000000<c<c0080<c<c>@3oool=03<c<`80IVIV0P2IVIT@0<c<c1H0VIVI
101VIVH303<c<`@0000000D0<c<c0000000c<c<0000003<c<`110?ooo`00>P3oool=06IVIP0309VI
V@3<c<`0c<c<01/0oooo3P3<c<`0102IVIT0IVIV06IVIP1VIVH803<c<`80IVIV>@3oool203<c<`@0
IVIV1P0c<c<206IVIP80VIVI1`3<c<`30?oooa00c<c<402IVIT00`1VIVH0<c<c03<c<`0403<c<`03
0000000c<c<0<c<c00<0<c<c>@3oool503<c<`0306IVIP0c<c<0<c<c00@0<c<c0`1VIVH209VIV@l0
c<c<00<0VIVI0<c<c02IVIT0502IVIT406IVIPH0<c<c00@0000003<c<`0c<c<000000P0c<c=10?oo
o`00>P3oool706IVIP0303<c<`1VIVH0IVIV00<0IVIV0P2IVIT20<c<c1X0oooo3@3<c<`209VIV@<0
IVIV200c<c<00`1VIVH0VIVI0?ooo`0h0?ooo`0306IVIP0c<c<0<c<c0080IVIV1`0c<c<306IVIP80
VIVI1@3<c<`00`3oool0c<c<0?ooo`0>0<c<c00309VIV@3<c<`0VIVI00h0VIVI0P1VIVH603<c<`03
0000000c<c<0<c<c0080000000<0<c<c09VIV@3oool0>03oool<03<c<`@0IVIV0P2IVIT>0<c<c1H0
VIVI0`1VIVH703<c<`030000000c<c<0<c<c0080000000<0<c<c09VIV@3oool0@03oool003X0oooo
1`1VIVH203<c<`@0IVIV0P2IVIT20<c<c1X0oooo00<0c<c<0?ooo`3<c<`02@3<c<`309VIV@80IVIV
0`0c<c<00`1VIVH0<c<c03<c<`0403<c<`030<c<c03oool0oooo03L0oooo00H0IVIV03<c<`0c<c<0
IVIV03<c<`1VIVH603<c<`<0IVIV0P2IVIT70<c<c0030?ooo`3<c<`0c<c<0100c<c<3@2IVIT206IV
IPL0<c<c100000000`0c<c<0VIVI0?ooo`0h0?ooo`0306IVIP0c<c<0<c<c0080<c<c00<0IVIV03<c
<`0c<c<0100c<c<406IVIP80VIVI3P3<c<`E09VIV@<0IVIV1P0c<c<00`000000<c<c03<c<`040000
000303<c<`2IVIT0oooo0400oooo000j0?ooo`0309VIV@1VIVH0IVIV00D0IVIV00<0<c<c06IVIP1V
IVH00`1VIVH209VIV@030<c<c03oool0oooo01L0oooo00<0c<c<0?ooo`3<c<`02@3<c<`209VIV@<0
IVIV2P0c<c<00`1VIVH0oooo0?ooo`0h0?ooo`0409VIV@0c<c<0<c<c03<c<`<0IVIV1P0c<c<306IV
IP0309VIV@3<c<`0c<c<01D0c<c<00<0VIVI0<c<c02IVIT0302IVIT00`1VIVH0<c<c03<c<`0703<c
<`<000000P0c<c<j0?ooo`0309VIV@0c<c<0<c<c00`0<c<c00@0IVIV09VIV@2IVIT0VIVI3@3<c<`E
09VIV@<0IVIV100c<c<010000000<c<c03<c<`0c<c<400000080<c<c@P3oool003X0oooo00<0VIVI
06IVIP1VIVH01`1VIVH00`0c<c<0IVIV06IVIP0206IVIP0309VIV@3<c<`0c<c<01D0oooo00<0c<c<
0?ooo`3<c<`02`3<c<`309VIV@80IVIV2P0c<c<00`1VIVH0c<c<0?ooo`0i0?ooo`80IVIV0P0c<c<0
1@1VIVH0<c<c03<c<`0c<c<0IVIV00D0<c<c0`1VIVH00`2IVIT0c<c<0<c<c00>0<c<c00309VIV@3<
c<`0c<c<0080c<c<3P2IVIT306IVIP/0<c<c00<0000003<c<`2IVIT0>P3oool00`1VIVH0<c<c03<c
<`0<03<c<`80IVIV0P2IVIT<0<c<c1<0VIVI1@1VIVH403<c<`8000001P0c<c<00`000000<c<c09VI
V@120?ooo`00>P3oool00`3<c<`0VIVI06IVIP0606IVIP0303<c<`1VIVH0IVIV00<0IVIV0P2IVIT0
0`3<c<`0oooo0?ooo`0@0?ooo`030<c<c03oool0c<c<00h0c<c<0P2IVIT306IVIPP0<c<c00@00000
03<c<`1VIVH0c<c<>P3oool00`2IVIT0IVIV03<c<`0206IVIP80<c<c00<0IVIV03<c<`0c<c<0100c
<c<306IVIP0309VIV@3<c<`0c<c<00d0c<c<502IVIT206IVIPT0<c<c0`00000203<c<`030<c<c03o
ool0oooo03P0oooo00<0VIVI06IVIP0c<c<0300c<c<206IVIP80VIVI2P3<c<`00`2IVIT0c<c<09VI
V@0B09VIV@D0IVIV100c<c<00`000000<c<c03<c<`0203<c<`<000000P0c<c<00`3<c<`0oooo0?oo
o`100?ooo`00>`3oool@06IVIP<0c<c<303oool30<c<c0030?ooo`3<c<`0c<c<00d0c<c<0`2IVIT2
06IVIPP0<c<c0P0000000`0c<c<0IVIV06IVIP0k0?ooo`030<c<c01VIVH0<c<c0080<c<c0P1VIVH6
03<c<`0306IVIP0c<c<0IVIV0080IVIV00<0VIVI0<c<c03<c<`02`3<c<`C09VIV@<0IVIV1@0c<c<2
00000080<c<c1000000203<c<c`0oooo00<0IVIV03<c<`0c<c<02@0c<c<00`1VIVH0<c<c03<c<`02
06IVIP@0VIVI1`3<c<`?09VIV@80IVIV0`2IVIT406IVIPH0<c<c0P00000203<c<`@000000P0c<c=3
0?ooo`00>`3oool00`2IVIT0IVIV06IVIP0506IVIP80<c<c1P1VIVH209VIV@<0c<c<0P3oool00`3<
c<`0oooo0?ooo`050?oooa<0c<c<0P2IVIT306IVIPH0<c<c1000000203<c<`0306IVIP3oool0oooo
03X0oooo0P1VIVH0100c<c<0IVIV03<c<`1VIVH603<c<`0306IVIP0c<c<0<c<c00<0IVIV0`2IVIT:
0<c<c180VIVI101VIVH603<c<`H000000`0c<c<l0?ooo`0306IVIP0c<c<0<c<c0080<c<c00<0IVIV
03<c<`0c<c<0200c<c<206IVIPD0VIVI00<0c<c<09VIV@2IVIT03`2IVIT00`1VIVH0VIVI09VIV@09
06IVIP@0<c<c2000000303<c<d<0oooo000k0?ooo`0309VIV@1VIVH0IVIV00h0IVIV0`2IVIT60<c<
c080oooo00<0c<c<0?ooo`3<c<`04P3<c<`309VIV@80IVIV200c<c<200000080<c<c00<0IVIV0?oo
o`3oool0>`3oool206IVIP0303<c<`1VIVH0<c<c00P0<c<c0P1VIVH00`0c<c<0IVIV06IVIP0206IV
IP@0VIVI00H0c<c<09VIV@3<c<`0c<c<09VIV@3<c<`209VIV@0306IVIP2IVIT0VIVI00h0VIVI0`1V
IVH503<c<`<0000000<0<c<c0000000000000P00000203<c<cd0oooo00<0IVIV03<c<`0c<c<03@0c
<c<506IVIP0309VIV@1VIVH0VIVI00L0VIVI1`1VIVH0102IVIT0IVIV06IVIP2IVIT806IVIPH0<c<c
100000000`0c<c<000000000000200000080<c<cA03oool003/0oooo00<0c<c<06IVIP1VIVH03`1V
IVH509VIV@030<c<c02IVIT0VIVI00@0c<c<1P2IVIT;0<c<c0<0VIVI1@1VIVH403<c<`@0000000@0
<c<c06IVIP0c<c<0IVIV?@3oool01`3<c<`0IVIV03<c<`0c<c<0IVIV03<c<`1VIVH01P0c<c<00`1V
IVH0<c<c03<c<`0706IVIP0309VIV@1VIVH0VIVI00@0VIVI1P1VIVH909VIV@D0IVIV1P0c<c<70000
00<0<c<c00<0IVIV0?ooo`3oool0>`3oool00`3<c<`0IVIV03<c<`0303<c<`0306IVIP0c<c<0<c<c
00@0<c<c00@0IVIV03<c<`0c<c<0<c<c2`1VIVH209VIVA@0IVIV1@0c<c<8000000@0<c<cA03oool0
03`0oooo00<0VIVI06IVIP1VIVH0101VIVH00`0c<c<0IVIV03<c<`0706IVIPX0VIVI00<0c<c<09VI
V@2IVIT01P2IVIT60<c<c0L0VIVI0`1VIVH503<c<`030000000c<c<00000008000000`0c<c<00`3<
c<`0oooo0?ooo`0l0?ooo`80IVIV00@0<c<c06IVIP1VIVH0IVIV1P0c<c<>06IVIP80VIVI2P1VIVH3
09VIV@P0IVIV1P0c<c<00`000000<c<c00000004000000<0<c<c00<0VIVI0?ooo`3oool0?03oool0
0`1VIVH0<c<c03<c<`0203<c<`0306IVIP0c<c<0<c<c00L0<c<c4@1VIVH00`0c<c<0IVIV03<c<`0=
06IVIPL0<c<c1`00000303<c<`0309VIV@3oool0oooo0480oooo000l0?ooo`0309VIV@1VIVH0IVIV
00D0IVIV00<0<c<c06IVIP1VIVH01@1VIVH409VIV@H0IVIV0`2IVIT506IVIPd0VIVI101VIVH503<c
<`030000000c<c<000000080000000@0<c<c06IVIP0c<c<0IVIV?`3oool00`2IVIT0IVIV03<c<`03
03<c<`0406IVIP0c<c<0<c<c03<c<`/0IVIV0`0c<c<906IVIP0303<c<`1VIVH0IVIV00`0IVIV1P0c
<c<00`000000<c<c00000005000000<0<c<c?`3oool00`2IVIT0<c<c03<c<`0303<c<`0306IVIP0c
<c<0<c<c0080<c<c2P1VIVH303<c<`L0IVIV1P0c<c<00`1VIVH0<c<c06IVIP0403<c<`0406IVIP0c
<c<0<c<c06IVIP@0<c<c00<0000003<c<`0000001`00000303<c<dD0oooo000m0?ooo`0309VIV@1V
IVH0IVIV02d0IVIV2P0c<c<00`000000<c<c03<c<`0206IVIT40oooo00@0VIVI06IVIP0c<c<0IVIV
100c<c<706IVIP0303<c<`1VIVH0IVIV0080IVIV100c<c<00`1VIVH0<c<c06IVIP0H03<c<`800000
00<0<c<c0000000000000`00000403<c<d40oooo00<0IVIV03<c<`0c<c<01`0c<c<206IVIP0703<c
<`1VIVH0<c<c03<c<`1VIVH0<c<c06IVIP0P03<c<`P00000100c<c=60?ooo`00?@3oool00`2IVIT0
IVIV06IVIP0@06IVIP0309VIV@1VIVH0IVIV01T0IVIV2@0c<c<200000080<c<c0`1VIVI10?ooo`03
09VIV@1VIVH0<c<c0080<c<c0`1VIVH00`0c<c<0IVIV06IVIP0606IVIP80<c<c00<0IVIV03<c<`0c
<c<00P0c<c<00`1VIVH0<c<c06IVIP0I03<c<`L00000100c<c=10?ooo`0309VIV@0c<c<0<c<c00H0
<c<c101VIVH303<c<`0306IVIP0c<c<0<c<c01h0<c<c0P0000000`0c<c<0000000000005000000@0
<c<cAP3oool003d0oooo00<0c<c<09VIV@1VIVH01P1VIVH00`2IVIT0IVIV06IVIP0406IVIP0309VI
V@1VIVH0IVIV00L0IVIV00@0<c<c06IVIP0c<c<0IVIV100c<c<00`1VIVH0<c<c06IVIP0303<c<`05
06IVIP0c<c<0<c<c03<c<`1VIVH01`0c<c<01@000000<c<c03<c<`0c<c<000000080<c<c00<0IVIV
03<c<`2IVIT0@P3oool00`3<c<`0IVIV06IVIP0206IVIP<0<c<c0P1VIVH00`0c<c<0IVIV06IVIP02
03<c<`80IVIV800c<c<01@000000<c<c03<c<`000000<c<c00@000000`0c<c<00`2IVIT0oooo0?oo
o`100?ooo`050<c<c01VIVH0<c<c03<c<`1VIVH00`0c<c<206IVIPH0<c<c00<0IVIV03<c<`0c<c<0
6`0c<c<010000000<c<c00000000000203<c<`030000000c<c<0000000<000000`0c<c<00`2IVIT0
oooo0?ooo`150?ooo`00?P3oool00`2IVIT0IVIV06IVIP0C06IVIP0303<c<`1VIVH0<c<c00d0<c<c
00<0IVIV03<c<`0c<c<02`0c<c<00`000000<c<c0000000203<c<`0306IVIP0c<c<0IVIV04@0oooo
00H0VIVI06IVIP0c<c<0<c<c06IVIP0c<c<406IVIP80<c<c0P1VIVH903<c<`0306IVIP0c<c<0<c<c
01L0<c<c1`00000403<c<d@0oooo00D0VIVI06IVIP0c<c<0<c<c06IVIP0203<c<`<0IVIV0P0c<c<2
06IVIQX0<c<c00<0000003<c<`0000000P0c<c<200000080<c<c1`00000403<c<dP0oooo000o0?oo
o`030<c<c01VIVH0IVIV0180IVIV1P0c<c<00`1VIVH0<c<c03<c<`0C03<c<`<000000`0c<c<306IV
ITD0oooo00<0c<c<09VIV@0c<c<00P1VIVH303<c<`H0IVIV4`0c<c<010000000<c<c03<c<`000003
03<c<`030000000c<c<0<c<c0080<c<c0P0000000`0c<c<0000000000004000000D0<c<cAP3oool0
0`2IVIT0<c<c03<c<`0603<c<`@0IVIV4@0c<c<00`000000<c<c0000000203<c<`040000000c<c<0
<c<c03<c<`<0000000D0<c<c000000000000000003<c<`06000000D0<c<cB@3oool003l0oooo00<0
c<c<06IVIP1VIVH0301VIVH0100c<c<0IVIV06IVIP1VIVH403<c<`0306IVIP0c<c<0<c<c01H0<c<c
00<0000003<c<`0000000`0c<c<0101VIVH0<c<c06IVIP3<c<a60?ooo`040<c<c01VIVH0<c<c03<c
<`<0IVIV00<0<c<c06IVIP1VIVH00P0c<c<00`1VIVH0<c<c03<c<`0;03<c<`030000000c<c<0<c<c
00<0<c<c00@0000003<c<`0c<c<0<c<c0P00000503<c<`P000000P0c<c<01@000000<c<c03<c<`0c
<c<0c<c<04L0oooo00L0IVIV03<c<`0c<c<0IVIV03<c<`1VIVH0<c<c0080IVIV0P0c<c<00`1VIVH0
<c<c03<c<`0603<c<`030000000c<c<0<c<c0080<c<c00<0000003<c<`0c<c<00`0c<c<010000000
<c<c03<c<`0c<c<2000000@0<c<c2@00000203<c<`050000000c<c<0<c<c03<c<`3<c<`0B@3oool0
0400oooo00<0VIVI06IVIP1VIVH0201VIVH00`0c<c<0IVIV06IVIP0603<c<`80IVIV5P0c<c<40000
00H0<c<c00<0IVIV09VIV@3oool0A`3oool01@2IVIT0IVIV03<c<`0c<c<0IVIV00@0<c<c00<0IVIV
03<c<`0c<c<0300c<c<00`000000<c<c03<c<`0203<c<`80000000<0<c<c0000000000000P0c<c<0
1@000000<c<c03<c<`000000<c<c00L000000P0c<c<00`000000<c<c03<c<`0203<c<`0306IVIP3o
ool0oooo04H0oooo0P1VIVH=03<c<`030000000c<c<0<c<c00H0<c<c00<0000003<c<`0c<c<00P0c
<c<20000000303<c<`00000000000080<c<c00D0000003<c<`0c<c<0000003<c<`0700000080<c<c
00<0000003<c<`0c<c<00P0c<c<00`1VIVH0oooo0?ooo`180?ooo`00@@3oool00`2IVIT0IVIV06IV
IP0706IVIP0303<c<`1VIVH0IVIV00d0<c<c00@0000003<c<`0c<c<00000100c<c<00`1VIVH0<c<c
03<c<`0<03<c<`0606IVIP0c<c<0IVIV06IVIP2IVIT0c<c<B03oool01@3<c<`0IVIV06IVIP1VIVH0
<c<c00@0IVIV00<0<c<c06IVIP0c<c<0300c<c<20000000303<c<`000000<c<c008000000P0c<c<0
1@000000<c<c03<c<`0c<c<0000000<0<c<c00@0000003<c<`00000000002@0c<c<00`1VIVH0c<c<
0?ooo`180?ooo`80IVIV0P0c<c<00`1VIVH0<c<c06IVIP0803<c<`030000000c<c<0<c<c00D0<c<c
0P0000000`0c<c<0000003<c<`0200000080<c<c00D0000003<c<`0c<c<0<c<c0000000303<c<`04
0000000c<c<00000000000T0<c<c00<0IVIV0<c<c03oool0B@3oool00440oooo0P2IVIT;06IVIQ00
<c<c00<0000003<c<`0c<c<00P0c<c<206IVIP`0<c<c00@0IVIV03<c<`1VIVH0IVIV0P2IVIU:0?oo
o`0309VIV@1VIVH0<c<c0080<c<c00<0IVIV03<c<`1VIVH00P1VIVH00`0c<c<0IVIV03<c<`0703<c
<`050000000c<c<0000003<c<`0000000P0c<c<01P000000<c<c000000000000<c<c00000080<c<c
00@0IVIV03<c<`0c<c<00000200c<c<00`000000<c<c03<c<`0203<c<`80IVIVBP3oool00`3<c<`0
IVIV03<c<`0403<c<`<0IVIV100c<c<00`000000<c<c03<c<`0303<c<`050000000c<c<0000003<c
<`0000000P0c<c<01P000000<c<c000000000000<c<c00000080<c<c00@0IVIV03<c<`0c<c<00000
200c<c<00`000000<c<c03<c<`0303<c<`0306IVIP3oool0oooo04T0oooo00130?ooo`0309VIV@1V
IVH0IVIV00T0IVIV5@0c<c<306IVIP80<c<c00@0IVIV03<c<`0c<c<0<c<c0`1VIVH0100c<c<0IVIV
06IVIP1VIVH209VIVDd0oooo0`1VIVH203<c<`<0IVIV1@0c<c<01`000000<c<c03<c<`0c<c<00000
03<c<`0000000P0c<c<01@000000<c<c000000000000<c<c00@000000P0c<c<206IVIPh0<c<c0P1V
IVI=0?ooo`80IVIV100c<c<206IVIPD0<c<c00L0000003<c<`0c<c<0<c<c0000000c<c<000000080
<c<c00D0000003<c<`000000000003<c<`0400000080<c<c0P1VIVH?03<c<`0306IVIP3oool0oooo
04X0oooo00130?ooo`030<c<c02IVIT0IVIV00X0IVIV4`0c<c<206IVIP80<c<c1@1VIVH00`0c<c<0
IVIV06IVIP0506IVIP0309VIV@3oool0oooo04`0oooo00@0c<c<06IVIP1VIVH0IVIV0P0c<c<406IV
IP@0<c<c00<0000003<c<`0c<c<00P0c<c<010000000<c<c03<c<`0c<c<300000080<c<c0P000000
100c<c<0000003<c<`1VIVH303<c<`80IVIV2P0c<c<00`1VIVH0oooo0?ooo`1<0?ooo`040<c<c01V
IVH0IVIV06IVIP80<c<c101VIVH403<c<`040000000c<c<0000003<c<`8000000`0c<c<300000080
<c<c0P0000000`0c<c<0000003<c<`0403<c<`0306IVIP0c<c<0<c<c00X0<c<cC@3oool004D0oooo
1`1VIVH00`2IVIT0IVIV06IVIP0306IVIQ<0<c<c3@1VIVH209VIVE40oooo0P1VIVH00`0c<c<0IVIV
06IVIP0406IVIP/0<c<c0P0000000`0c<c<000000000000203<c<`030000000c<c<0<c<c00D0<c<c
101VIVH603<c<`80IVIVD@3oool206IVIP<0<c<c101VIVH;03<c<`80000000<0<c<c000000000000
0P0c<c<00`000000<c<c03<c<`0603<c<`0306IVIP0c<c<0<c<c00H0<c<c00<0IVIV03<c<`3oool0
C@3oool004H0oooo00<0VIVI06IVIP1VIVH00`1VIVH209VIV@@0IVIV00@0<c<c06IVIP1VIVH0IVIV
200c<c<0101VIVH0<c<c03<c<`0c<c<206IVIP<0<c<c0P1VIVH00`0c<c<0IVIV06IVIP0506IVIP80
VIVID`3oool806IVIR80<c<c0P1VIVH00`2IVIT0oooo0?ooo`1A0?ooo`0406IVIP0c<c<0<c<c03<c
<`@0IVIV900c<c<00`2IVIT0oooo0?ooo`1=0?ooo`00AP3oool00`3<c<`0VIVI06IVIP0306IVIP<0
VIVI2@1VIVH303<c<`0306IVIP0c<c<0<c<c00@0IVIV0P0c<c<<06IVIP80VIVIE03oool0103<c<`0
IVIV03<c<`0c<c<506IVIPP0<c<c00<0IVIV03<c<`0c<c<01@0c<c<306IVIP80<c<c00<0IVIV03<c
<`0c<c<01P0c<c<506IVIU@0oooo00<0c<c<06IVIP0c<c<00P0c<c<406IVIPP0<c<c00<0IVIV03<c
<`0c<c<01@0c<c<206IVIP<0<c<c00<0IVIV03<c<`0c<c<01P0c<c<00`1VIVH0<c<c06IVIP0206IV
IU00oooo00180?ooo`030<c<c02IVIT0IVIV00<0IVIV1@2IVIT806IVIP0303<c<`1VIVH0IVIV00h0
IVIV0`2IVIT00`1VIVH0c<c<0?ooo`1F0?ooo`030<c<c01VIVH0IVIV00@0IVIV00<0VIVI06IVIP1V
IVH00P1VIVH00`0c<c<0IVIV03<c<`0406IVIP0303<c<`1VIVH0IVIV00<0IVIV0P0c<c<01@1VIVH0
<c<c03<c<`0c<c<0IVIV00@0<c<c0`1VIVH00`0c<c<0VIVI0?ooo`1F0?ooo`030<c<c01VIVH0IVIV
00@0IVIV00<0VIVI06IVIP1VIVH00P1VIVH303<c<`@0IVIV00<0<c<c06IVIP1VIVH00`1VIVH203<c
<`0306IVIP0c<c<0<c<c00L0<c<c00@0IVIV03<c<`0c<c<0VIVID@3oool004X0oooo00@0c<c<09VI
V@1VIVH0IVIV2@2IVIT00`1VIVH0VIVI06IVIP0406IVIP0303<c<`1VIVH0IVIV00T0IVIV0`2IVIT2
06IVIU/0oooo00<0VIVI06IVIP1VIVH03`1VIVH403<c<`80IVIV1P0c<c<506IVIP80<c<cF`3oool0
0`2IVIT0IVIV06IVIP0?06IVIP@0<c<c00<0IVIV03<c<`0c<c<01`0c<c<00`1VIVH0<c<c06IVIP02
03<c<e<0oooo001;0?ooo`0309VIV@1VIVH0IVIV00X0VIVI00@0IVIV09VIV@2IVIT0VIVI2`1VIVH5
09VIV@0306IVIP2IVIT0oooo05`0oooo00<0VIVI06IVIP1VIVH00P1VIVH00`2IVIT0IVIV06IVIP02
06IVIP0309VIV@1VIVH0IVIV0080IVIV00@0VIVI06IVIP1VIVH0IVIV100c<c<306IVIP0303<c<`1V
IVH0IVIV00@0IVIV00<0<c<c09VIV@3oool0G03oool00`2IVIT0IVIV06IVIP0206IVIP0309VIV@1V
IVH0IVIV0080IVIV00<0VIVI06IVIP1VIVH00P1VIVH00`2IVIT0IVIV06IVIP0503<c<`0606IVIP0c
<c<0<c<c03<c<`1VIVH0<c<c101VIVH00`0c<c<0VIVI0?ooo`1C0?ooo`00CP3oool00`2IVIT0IVIV
06IVIP0D09VIV@80c<c<0P2IVIT00`1VIVH0VIVI0<c<c01R0?ooo`0409VIV@1VIVH0IVIV06IVIP@0
VIVI101VIVH209VIV@0306IVIP2IVIT0IVIV00H0IVIV0`2IVIT306IVIP030<c<c03oool0oooo0600
oooo00@0VIVI06IVIP1VIVH0IVIV102IVIT406IVIP80VIVI00<0IVIV09VIV@1VIVH0301VIVH00`3<
c<`0oooo0?ooo`1D0?ooo`00E03oool20<c<c0030?ooo`2IVIT0c<c<0100VIVI00<0c<c<0?ooo`3o
ool0J03oool30<c<c080VIVI3`1VIVH00`2IVIT0c<c<0?ooo`1Y0?ooo`80c<c<00<0oooo09VIV@2I
VIT03`1VIVH00`2IVIT0c<c<0?ooo`1G0?ooo`00F03oool20<c<c0d0VIVIK`3oool00`3<c<`0oooo
0<c<c00309VIV@@0IVIV00<0VIVI06IVIP1VIVH0101VIVIa0?ooo`040<c<c02IVIT0VIVI09VIV@/0
IVIVF`3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0
oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool005L0
oooo0d000000103ooom000000?ooo`3oool2@00000<0oooo0d00001]0?ooo`9000000P3oool3@000
00<0oooo0T0000030?ooo`90000000<0oooo@000040000000P3oool00d000000oooo0?ooo`1X0?oo
o`A000000P3oool3@00000<0oooo0d0000020?ooo`900000F`3oool005P0oooo00I000000?ooo`3o
oom000000?oood0000040?ooo`04@000003oool0oooo@00006`0oooo00=000000?oood0000000`3o
ool01D000000oooo0?ooo`3ooom0000000@0oooo00=000000?ooo`3oool00P3oool014000000oooo
0?oood00001[0?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@0000002
0?ooo`03@000003ooom0000005d0oooo001H0?ooo`=000000P3oool3@0000080oooo00A000000?oo
o`3ooom00000K03oool014000000oooo@000040000020?ooo`04@000003oool0oooo0?ooo`=00000
0P3oool3@0000080oooo00A000000?ooo`3ooom00000J`3oool014000000oooo0?oood0000020?oo
o`05@000003oool0oooo0?oood0000000P3oool00d000000oooo@0000002@00005/0oooo001H0?oo
o`05@000003oool0oooo@000003oool00d0000030?ooo`=00000K03oool00d000000oooo0?ooo`02
0?ooo`A0000000@0oooo@0000400001000000P3oool3@00000030?oood000010000000900000K03o
ool3@00000<0oooo00=000000?ooo`3oool00T000000103ooom00000@000003oool3@00005/0oooo
001H0?ooo`04@000003oool0oooo@00000T0oooo00=000000?ooo`3oool0JP3oool00d000000oooo
0?ooo`200?ooo`04@000003oool0oooo@0000080oooo00=000000?ooo`3oool0I03oool005L0oooo
140000090?ooo`900000K03oool3@00007l0oooo140000020?ooo`900000IP3oool00?l0oooo``3o
ool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3o
ool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3o
ool00?l0oooo``3oool00?l0oooo``3oool00740oooo0T00000a0?ooo`=00000IP3oool3@00003h0
oooo0T00001b0?ooo`00L`3oool00d000000oooo0?ooo`0_0?ooo`03@000003oool0oooo06H0oooo
00=000000?ooo`3oool0?`3oool00d000000oooo0?ooo`1_0?ooo`00I@3oool3@00000<0oooo0d00
00030?ooo`=000001@3oool00d000000oooo0?ooo`05@0000080oooo00=000000?ooo`3oool01@3o
ool00d000000oooo0?ooo`090?ooo`9000000`3oool2@00000070?oood000000oooo@000003ooom0
00000?ooo`03@00000<0oooo0T0000000`3ooom00000@00000020?ooo`03@000003oool0oooo0090
000000<0oooo@000040000000P3oool00d000000oooo0?ooo`02@0000080oooo0T00000D0?ooo`90
00000P3oool3@00000X0oooo0d0000030?ooo`9000000P3oool3@00000<0oooo0T0000020?ooo`=0
00003@3oool3@0000080oooo140000001@3ooom00000@00004000000oooo009000000P3oool00d00
0000oooo0?ooo`02@00000<0oooo0T0000030?ooo`=000003P3oool3@00000070?oood000000oooo
@000003ooom000000?ooo`04@0000080oooo0d0000020?ooo`900000K@3oool006H0oooo00=00000
0?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203o
ool01d000000oooo0?ooo`3ooom000000?oood0000004@3oool00d000000oooo0?ooo`020?ooo`03
@000003oool0oooo0090000000H0oooo@000003ooom000000?oood0000020?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool00d000000oooo@00000040?ooo`06@000003oool0
oooo@000003ooom000000P3oool01D000000oooo0?ooo`3ooom000000180oooo00A000000?ooo`3o
oom000000P3oool00d000000oooo0?ooo`090?ooo`03@000003oool0oooo0080oooo00A000000?oo
o`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom00000
3P3oool01D000000oooo0?oood000000oooo00=000000`3oool01D000000oooo0?ooo`3ooom00000
0080oooo00=000000?oood0000000P3oool00d000000oooo@00000040?ooo`04@000003oool0oooo
@00000l0oooo00U000000?ooo`3ooom000000?oood000000oooo@000003oool00d0000020?ooo`06
@000003oool0oooo@000003ooom00000K`3oool006H0oooo00=000000?ooo`3oool00`3oool01D00
0000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool01d000000oooo0?ooo`3o
oom000000?oood0000004@3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00900000
00H0oooo@000003ooom000000?oood0000020?ooo`03@000003ooom000000080oooo00=000000?oo
od0000000P3oool00d000000oooo@0000002@0000080oooo00I000000?ooo`3ooom000000?oood00
00050?ooo`03@000003oool0oooo0140oooo00A000000?ooo`3ooom000000P3oool00d000000oooo
0?ooo`090?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom000000P3oool01D000000
oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom000003P3oool014000000oooo0?oood00
00030?ooo`05@000003oool0oooo0?oood0000000`3oool01T000000oooo0?oood000000oooo@000
00@0oooo0d0000020?ooo`04@000003oool0oooo@00000l0oooo00Q000000?ooo`3ooom000000?oo
od000000oooo@00000<0oooo00A000000?ooo`3ooom000000P3oool00d000000oooo@0000002@000
06d0oooo001V0?ooo`9000000`3oool2@00000@0oooo0d00000:0?ooo`07@000003oool0oooo0?oo
od000000oooo@000000A0?ooo`03@000003oool0oooo00<0oooo0T0000001P3ooom00000@000003o
oom000000?ooo`A000000`3oool2@00000030?oood0000100000009000000P3oool3@00000030?oo
od00001000000090000000<0oooo@000040000000T0000030?ooo`9000004`3oool2@0000080oooo
0d00000:0?ooo`=000000`3oool2@00000<0oooo00=000000?ooo`3oool00P3oool2@0000080oooo
1400000;0?ooo`A000000`3oool2@0000080oooo0T0000020?ooo`A0000000<0oooo@00004000000
0T0000020?ooo`=000000`3oool3@00000h0oooo0T0000020?ooo`90000000<0oooo@000003oool0
0P3oool2@00000<0oooo0d000000103ooom00000@0000400001]0?ooo`00IP3oool014000000oooo
0?oood00000D0?ooo`07@000003oool0oooo0?oood000000oooo@000000A0?ooo`03@000003ooom0
000002D0oooo00=000000?ooo`3oool07@3oool00d000000oooo0?ooo`0D0?ooo`03@000003oool0
oooo02X0oooo00=000000?ooo`3oool02P3oool00d000000oooo0?ooo`2@0?ooo`00I@3oool5@000
0080oooo00=000000?ooo`3oool03P3oool2@00000@0oooo00=000000?ooo`3oool0403oool3@000
04H0oooo00=000000?ooo`3oool04P3oool2@00002<0oooo00=000000?ooo`3oool04P3oool2@000
00l0oooo00=000000?ooo`3oool0P03oool00?l0oooo``3oool00?l0oooo``3oool00001\
\>"],
  ImageRangeCache->{{{0, 449}, {139.625, 0}} -> {-0.308828, -0.0234427, 
  0.00805715, 0.00805715}, {{38.3125, 154.688}, {136.688, 
  20.3125}} -> {-122.582, -12.7492, 2.59671, 2.59671}, {{166.313, 282.625}, {
  136.688, 20.3125}} -> {-454.88, -12.7492, 2.59671, 2.59671}, {{294.313, 
  410.625}, {136.688, 20.3125}} -> {-787.258, -12.7492, 2.59671, 2.59671}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Combination of the red, green and blue components in Fig. 10 yields a \
painted image as shown in Fig. 11.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Show[convertRGB[pSample],
\tPlotLabel->\"Fig.11. Painted color image\",
\tAspectRatio->dim[[2]]/dim[[3]]];\
\>", "Input",
  CellLabel->"In[59]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[.5 1.0125 -83 0 ]
[.5 1.0125 83 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.11) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Painted) show
159.000000 12.812500 moveto
(color) show
195.000000 12.812500 moveto
(image) show
225.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
768 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99CCCC99FFCC99CC9999FFCC99FFCC99CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FFFFCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99CCCC99FFCC99FFCC99FFCC99CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FFCC99FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FFCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99FFCC99CCCC99
FFCC99CCCC99CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
CCCC99FFCC99FFCC99FFCC99CCCC99FFCC99FFCC99CCCC99FFCC99FF9999CCCC99
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99CCCC99FFCC99FFCC99FFCC99CCCC99FF9999CCCC99CCCC99CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCC99CCCCCCFFCC99FFCC99\
CCCC99FFCC99FFCC99CCCC99FFCC99CCCC99CCCC99CCCC99CCCC99CCCC99CCCC99
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99CCCC99FF9999CCCC99CC9999CCCC99CC9999CC9999CCCC99CCCC99
CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCC
FFCCCCFFCCCCCCCCCCFFCCCCCCCCCCFFCC99FFCC99FFCC99FFCC99CCCC99FF9999FFCC99FF9999\
CC9999CCCC99CC9999CC9999CC9999CCCC99CC9999CCCC99CC9999CCCC99CCCC99
CCCC99CCCC99CCCC99CC9999CCCC99CC9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999\
FFCC99FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99
CC9999CCCC99CC9999CCCC99CCCC99CCCC99CC9999CCCC99CCCC99CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999FFCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
CCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9999CCCC99CC9999CCCC99CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCCCCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999CC9999FF9999CC9999
CC9999CC9999FFCC99FF9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99\
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC\
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999CC9999CC9999
FF9999FF9999FFCC99FF9999FF9999FF9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999FFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999
FF9999FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999
FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999FFCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999\
CC9999FF9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CCCC99FFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999\
FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99
FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999\
FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999\
FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999FF9999\
FF9999FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999\
FF9999FF9999FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CCCC99CC9999CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFCCCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999\
FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CCCC99CCCC99CC9999CC9999CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFCCFFCC9999CCCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999\
FF9999CC9999FF9999FF9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CC9999CC9999CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFCCFFCC9999999966FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CCCC99\
FF9999CC9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999FFCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
CC9999996666996666FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999\
FF9999FF9999FF9999FF9999FF9999FF9999FF9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CC9999CC9999CC9999CC9999\
CC9999CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC\
666633663333999966FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999\
FF9999CC9999CC9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CC9999CC9999CC9999\
CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF996666\
663333663333CC9966FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
CC9999FF9999CC9999CC9999FFCC99FF9999FF9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9999CC9999\
CC9999CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333\
663333663333996666FFCCCCCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99\
FF9999CC9999FF9999CC9999FFCC99CC9999CC9999FF9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9999\
CC9999CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999666633663333663333\
333300996666CCCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999\
CC9999FF9999FF9999FF9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99FFCC99\
CCCC99CC9999FFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF666633663333663333333300\
663333CCCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999\
FF9999CC9999CC9999CC9999FFCC99CC9999FF9999FF9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99\
CCCCCCCCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666633663333663333663333\
CC9999FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999\
FF9999FF9999CC9999FF9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CCCC99CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666666633663333663333CC9999\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99FF9999FFCC99\
CC9999CC9999FF9999CC9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CCCC99CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333663333663333CC9999FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999\
CC9999FFCC99CC9999FF9999FFCC99CC9999CC9999FF9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666633663333666633999999FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999CC9999CC9999FF9999\
CC9999CC9999CC9999CC9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CCCC99CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF666666663333663333999966FFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999FFCC99FF9999FF9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999FFCC99CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CCCC99FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCC99CC663333663333663333666666FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCC99FF9999FF9999FF9999FF9999FF9999FF9999FF9999FF9999FF9999
FF9999FF9999FF9999FF9999CC9999FF9999CC9999FF9999CC9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CCCC99CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF996666663333663333663333CC9999FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FF9999FF9999FF9999FF9999FF9999FF9999FF9999FFCC99FF9999FF9999
FF9999FF9999FF9999CC9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CCCC99CC9999CCCC99FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCC663333663333663333999999FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFF9999FF9999FF9999\
FF9999FF9999FF9999FF9966CC9999FF9966CC9999FF9999FF9999CC9999FF9999
FF9999FF9999FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CCCC99CCCC99FFCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF996666663333663333996666FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FF9999FF9999FFCCCCFF9999FF9999\
FF9999FF9966FF9966FF9966FF9966FF9966FF9966FF9966FF9999FF9966FF9966
FF9966CC9966FF9999FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CCCC99CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCFF666666663333666633FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCC99FF9999FF9999FF9999\
FF9966FF9966FF9966FF9966CC6666FF9966FF9966CC9999FF9966FF9966FF9966
CC6666FF9966FF9966CC9966CC9966FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCC666633663333999999FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFF9999FF9999FF9999\
FF9966FF9966FF9966FF9966FF9966FF9966FF9966FF9999FF9966FF9966FF9966
FF9966CC6666FF9966FF9966FF9966CC9966FF9966CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999FFCC99FFFFCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF996666663333996666FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999\
FF9966FF9966FF9966FF9966FF9966FF9966CC9999FF9999FF9966FF9966FF9966
FF9966FF9966CC6666FF9966FF9966FF9966CC6666FF9966CC9966CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC999999663333999966FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFF9999FF9999FF9966FF9966FF9966FF9966\
FF6666FF6666CC6666CC6666CC6666CC6666FF9966FF9966FF9966FF6666FF9966
CC6666FF9966CC6666FF9966FF9966FF9966FF9966FF9966CC9966CC6666FF9966CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC
999999999999663333CCCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FF9999FF9999FF9966FF9966FF6666CC6666CC6666\
CC6666CC6666CC6666CC6666FF6666FF6666FF6666FF6666FF9966FF6666FF6666
CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666FF9966FF9966CC9966CC9999CC9999\
CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FF9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999
666666666666996666FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FF9999FF9999FF9966CC6666CC6666CC6666CC6666CC6666\
CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666
CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666FF9966CC6666CC6666CC9966CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99FFCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CC996666
666666663333FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCCCCFFCC99FF9999FF9999FF9999FF9966FF6666CC6666CC6666CC9999CC9999CC9999CC6666\
CC9966FF9966CC6666CC6666CC6666CC6633CC6666CC6666CC6666CC6666CC6666
CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC9966CC9966CC6666CC9966\
CC9966CC9999CC9999CC9999CC9966CC9999CC9966CC9999CC9966CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99FFCCCC
FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF999999666666
663333663333FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FF9999
FF9999FF9999FF9999FF9966FF9966CC6666CC9966CC9999CC9999CCCC99FF9999FF9999CC6666\
CCCCCCFFCCCCCCCC99CCCC99CC9999CC6666FF9999FF9999CC9999CC6666CC6666
CC6666CC6666CC6633CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC9966\
CC9966CC9966CC9999CC9999CC9999CC9999CC9966CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99
FFFFCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF999999996666663333
333333996666FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999FF9999FF9999
FF9966FF9966CC6666CC6666FF9966CC9966CCCCCCFFCCCCCCCCCCFFCCCCCCCCCCCCCCCCCC9999\
CCCCCCCCCCCCFFCCCCCCCCCCCCCC99CC9966CCCCCCCCCCCCCCCC99CCCC99CC9966
996633CC6666CC9966CC6666CC6633CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666\
CC9966CC9966CC9999CC9999CC9999CC9966CC9966CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9999FF9999CC9999CC9999CC9999CC9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CCCCCCFFCCFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CC996666666633663333
663333999999FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999FF9999FF9999FF9999FF9966FF6666
CC6666CC6633CC6633CC6666CC9999CC6666FF9999CCCCCCCCCCCCFFCCCCCCCCCCCCCCCCCCCCCC\
CCCCCCCCCCCCCCCCCCFFCC99CCCCCCCC9999CCCCCCCCCCCCFFCCCCCCCCCCCC9999
996666CC9999CC9999CC9966996633996633CC6633CC6666CC6666CC6666CC6666CC6666CC6666\
CC6666CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9966CC9999CC9999
CC9999CC9999CC9999CC9999CC9999FFCC99FFCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CCCC99FFCCFFFFCCFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999996666666633663333
666633CCCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FFCC99FFCCCCFFCCCC\
FFCCCCFFCCCCFF9999FF9999FF9999FF9999FF9999FF9999FF9966CC6633CC6633
CC6633CC6666CC6666CC6666CC6666FF9999CC6666CC6666CC9966FF9966CC9966CC6666CC9999\
CC9999CC9999CC9999CC9999CCCC99CC9999CCCCCCCCCCCCCCCCCCCCCCCCCC9999
CC9966CC9999CC9999CC9966CC6666993333993333CC6666CC6666CC6666CC6666CC6666CC6666\
CC9966CC6666CC9966CC9999CC9999CC9999CC9966CC9966CC9966CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99
CCCC99CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCC9999996666663333663333
CC9999FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9966CC9999FFCC99FFCCCCFFCCCCFFCCCC\
FF9999FF9966FF9999FF9966FF9966CC9966CC6666993300660000CC6666FFCCCC
FF9999CC9966CC6666FF9999FF9999FF9999CC6666CC6666FFCC99FFFFCCFFFFFFFFFFFFFFFFCC\
FFCCCCFFCCCCFF9999FF6666CC6666FF9999CC9966CC9966CC6666CC6666CC6666
CC9966CC9999CC9999CC9999CC9999996666996666996666996633996633CC6633CC6666CC6666\
CC6666CC9966CC6666CC9966CC9966CC9999CC9999CC9966CC9999CC9966CC9999
CC9999CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999FFCC99CCCCCCCCCCFFFFFFCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999CC9999666666333333666633
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FF9999FF9999CC9999CC9999CC9999FFCC99FFCCCCFFCC99FF9999\
CC6666CC6666CC6666996633CC6666CC9999CCCC99CCCCCCCC9966FFCCCCFFFFCC
FFFFCCFFCC99FFCC99FFCCCCFFCCCCFFCCCCFF9999FF9966FFFFCCFFFFFFFFFFFFFFFFFFFFFFCC\
FFFFCCFFCCCCFFFFCCCCCCCCFFCCCCCCCCCCFFCCCCFFCCCCCCCCCCFFCC99CC9966
CC6666CC6666CC9966CC9999CC9999CC9966996666996666996666996633993333CC6633CC6633\
CC6633CC6666CC6666CC6666CC9966CC9999CC9966CC9999CC9966CC9999CC9999
CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999FFCCCCCCCCCCCCCCFFCCCCCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999999999999999663333663333CC9966
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FF9999FF9999CC9999CC9966CC9966FF9999FFCC99FFCC99CC6666CC6666\
CC6666993333330000996633CCCC99FFCC99FFFFCCFFCCCCFFCCCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFCC\
FFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCC
CCCCCCFF9966CC6633CC6666CC6666996666996666CC9966996666996633663333993333CC6633\
CC6633CC6666CC6666CC6666CC9966CC9999CC9999CC9966CC9999CC9966CC9999
CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CCCC99CCCCCCFFFFFFFFFFFFCCCCFFCCCCCCCCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999996666666666333333663333CCCC99
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FF9999CC9999CC9966CC9966CC9999CC9999FF9999CC6666CC6633CC6633\
993333993333996633CCCC99FFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFFFCC
FFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC\
FFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCCCCC99CC6633CC6666CC6633996633996666996666996666663333663333996633993333\
CC6633CC6633CC6633CC6666CC9966CC9999CC9999CC9999CC9966CC9999CC9966
CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CCCC99FFCC99CCCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666666633663333663333996633FFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FF9999FF9999CC9966CC9966CC9966CC9966CC9966CC6666CC6633993333993333\
993333996633CC9966CCCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC\
FFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFFFFFFFCCFFFFCCFFFFCCFFCCCCFFCCCC
FFCCCCCCCC99FFCC99CCCCCCCC9999CC9999996633996633996633993333663333663333663333\
993333CC6633CC6633CC6666CC9966CC9966CC9999CC9999CC9999CC9966CC9999
CC9999CC9999CC9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99FFCCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFF996666663333663333663333996666FFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FF9999CC9999CC9966CC9966CC9966CC6666CC6633993333993333993300663300\
996633996666CCCC99FFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCC
FFCCCCFFFFCCFFFFCCFFFFFFFFFFFFFFFFCCFFCCCCFFCCCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFCC\
FFFFCCFFCCCCFFCCCCFFCC99FFCCCCFFFFFFFFCCCCFFFFCCFFCCCCFFFFCCFFCCCC
FFCCCCFFCC99CCCCCCFFCCCCFFCCCCFFCCCCCC9999996633993333993333663300663300333333\
330000993333CC6633CC6633CC6666CC6666CC9966CC9999CC9999CC9966CC9999
CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CCCCCCFFCCCCCCCCCCFFFFFFFFCCFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999666633663333663333CC9999FFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FF9999CC9966CC9966CC6666CC9966993333993333993333993300663300663333\
996666CC6666FF9999FFCC99FFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFFFFFFFFFCC
FFCCCCFFFFCCFFFFCCFFFFFFFFFFFFFFFFCCFFCCCCFFCCCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFCC\
FFFFCCFFCCCCFFCC99FF9999FFCCCCFFFFFFFFFFCCFFFFCCFFFFCCFFCCCCFFCCCC
FFCCCCFFCC99CCCCCCFFCCCCCCCCCCFFCCCCFFCCCCCC9999996633996666996666663300330000\
000000330000993333CC6633CC6666CC6633CC9966CC9966CC9999CC9999CC9966
CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CCCC99CCCCCCCC9999CCCCCCCCCCCCCCCCCCCCCCFFFFFFFFFFCCFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFCCFFCCCCCC999999666666663333663333996666FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCC\
FFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FF9999CC9966CC9999CC9966CC9966CC9966CC9966993333993333993333993333993300663300\
993333CC9966CC6666FF9999FFCCCCFF9999FF9999FFCC99FFCCCCFFCCCCFFCC99
FFCC99FFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFCC99FFCC99FFCCCCFFFFFFFFFFFFFFFFFFFFCCCC\
FFCCCCFFCC99FFCC99FF9999FF9999FFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCC
FFCC99CC9999FFCCCCFFCCCCFFCCCCCCCCCCFFCCCCCCCCCCCCCC99CCCC99FFCCCCCC9966993333\
996666666633330000330000996633CC6633CC6633CC6666CC9966CC9999CC9966
CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FF9999FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999FFCC99CCCCCCCC9999666633999999CC9999CCCCCCCCCCCCFFCCFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFCCCCFF996666663333333333663333CC9966FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCC\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FF9999CC9966CC9999CC9966CC9966CC9966CC9966CC6633CC6633CC6633993333993333993300\
996633FF9966CC6666FF9999FF9999CC9966FF9999FFCC99FFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCCCCFFFFCCFFFFCCFFCC99FF9999FFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCC99FF9999FF9999FF9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FF9999CC9966FFCCCCCCCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9999CCCC99CCCC99CCCC99CC9999\
CC9999CC9999993333663333993333993333CC6633CC6666CC9966CC9999CC9999
CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCCCCCCCC99999999CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFCCCCCCCC9999666633333333663333663333CCCC99FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
CC9966CC9966CC9999CC9966CC9966CC9966CC9999CC9999FF9966CC6666CC6666993333993333\
CC6633CC6666CC6666CC9966FF9966CC9966FF9999FF9999FFCC99FFCCCCFFCCCC
FF9999FF9999FFCCCCFFCCCCFFCCCCFF9999FF9999FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFF9999\
FF9999FF9966FF9966FF9999FF9999FF9999FFCC99FFCC99FFCCCCFFCCCCFFCC99
CC9966CC6666FFCC99FFCCCCFFCCCCFFCCCCFFCCCCCC9999CC9999CCCC99CCCC99CC9999CC9999\
CC9999CC9999996666996666663333993333993333CC6633CC6666CC9966CC9999
CC9966CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CCCC99CCCC99CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC\
FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
CCCCFFCCCCCC999999663333333333333333333333663333FFCCCCCCCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FF9999CC6666CC9966CC9999CC9966CC9999FF9999FFCC99FF9999FF9999FF9999FF9999CC6666\
CC6666CC6666CC6666FF9966FF9966FF9966FF9966CC9966FF9999FF9999FF9999
FF9999FF6666FF9999FF9999FF9999FF9966FF9999FF9999FFCC99FFCCCCFFCCCCFF9999CC6666\
CC6666CC6666CC6666CC6666FF9966FF9999FF9999FF9999FF9999FF9999CC9999
CC6666CC6666FF9999FFCCCCFFCCCCFFCCCCFFCC99CC9966CCCC99CCCC99CCCC99CC9999CC9999\
CC9999CC9999CC9966996666993333663300993333993333CC6633CC9966CC9966
CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CCCC99CCCC99CCCCCCCCCCFFFFCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC\
CCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCC\
CC9999666666663333663333333333333300333300996666FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
CC9999CC6666CC9966CC9999CC9999FF9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FF9999FF9999FF9999FF9999FF9999FF9999FF9999FF9966FF9966FF9966
FF9966FF9966CC6666FF9966FF9966FF9966FF9966FF9966FF9966CC9999FF9966FF9966CC6666\
FF9966CC6666CC6666CC6666CC6666CC6666CC6666CC9966FF9966CC9966CC6666
CC9966CC6666CC9966FFCC99FFCC99FFCC99CC9999CC9966CC9999CCCC99FFCC99CC9999CC9999\
CC9999CC9999CC9966CC6666663333663300663300993333993333CC6666CC9966
CC9966CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FF9999FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CCCC99CCCC99CCCCCCFFCCFFFFCCFFFFCCFFFFCCFFCCCCCCCCCCCCCCCCCC\
CCCCCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666\
663333333333333333663333663333333300333333CC9999FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99\
FFCC99FF9999FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FF9999CC6666CC9966CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FF9999FF9999FFCC99FFCC99FF9999FF9999FF9999FF9999FF9999FF9999FF9999FF9999CC9999\
FF9966CC9999FF9966CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666
CC6666CC6666CC6666CC9999CCCC99CC9999CC9966CC6666CC9966CCCC99FFCC99CC9999CC9999\
CC9999CC9999CC9966996666663333660000663300663300993333996633CC9966
CC9966CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99FFCC99FFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCCCCCCCC\
FFFFCCCCCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999333333\
333333333300330000333333663333333333663333CCCC99FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FF9999CC9966CC6666CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999FFCC99FF9999FF9999FF9999FF9999\
FF9999FF9999FF9999FF9966FF9966FF9966CC6666CC6666CC6666CC6633CC6666
CC6666CC6666CC6666CC9966CC9999CC9966CC6666CC6666CC9966CC9999CCCC99CC9999CC9966\
CC9999CC9999996666CC6666663333660000660000660000663300993333996633
CC9966CC9999CC9999CC9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99FFCC99CCCCCCFFFFCCFFFFFFFFFFFFCCCCFFFFCCFFFFFFCC\
CCCCCCCCCCCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFCCCCCC663333333333\
330000333300663333663333663333333300996666FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FF9999FF9999CC9966CC9966FF9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9966FF9966CC6666CC9966
FF9966CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC6666CC9966CC9966CC9966CC6666\
CC6633CC6666996633993333663333330000660000663300993333993333993333
996633CC9966CC9999CC9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99CCCC99999966666666CC9999CCCCCCCCCCFFFFFFCCFFCCFF\
CCCCFFCCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFCC99CC333333333333\
333333333333663333663333663333663300999966FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FF9999FF9999CC9966CC9966CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCCCCFFCC99FF9999FF9999FF9999FF9999FF9966
FF9966CC9966FF9966FF9966CC6666CC9966CC6666CC6666CC6666CC6666CC9966CC9966CC6633\
CC6633CC6633996633993333663333660000660000663333993333993333993333
993333CC9966CC9966CC9966CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99\
FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99FFCC99999999666633996666CCCCCCCCCCFFFFCCFFFFCCFF\
FFFFFFFFCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC999999333300333300\
663333663333663333333333333300663333CC9999FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FF9999FF9999CC9999CC9966CC9966FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FF9999FF9999CC9999CC9999CC9999FF9966CC9966CC9966FF9966CC9966CC6666CC6666CC6666\
CC6666CC6666CC6666CC6633996633993333996633993333996633CC6633996633
993333CC9966CC9966CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999666666663333996666FFFFCCFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF999999996666333300333333\
663333663333663333333333333300663333FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FF9999FF9999FF9999CC9966CC9966CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FF9999FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966\
CC9966CC9999CC9966CC9966FF9966CC9966CC6666CC9966CC6666CC6666CC6666
CC6666CC9966CC9966CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999666633666633663333999999FFFFCCFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF666666663333663333996666\
999966CC9999CC9966CC6666663333996633FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99
FF9999FF9999FF9999CC9999CC9966CC9966FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC6666CC9966CC6666
CC9966CC9966CC9966CC9966CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999996666996666999966996666CC9999FFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF666666663333CCCC99FFCCCC\
FFCCCCFFCCCCFFCC99FFCC99CC9966CC9966FFCCCCFFCCCCCCCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FF9999FF9999FF9999CC9966CC9966CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99999999999999999999CC9999999999CCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF666666996666FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FF9999FF9999FF9999CC9999CC9966CC9966FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966
CC9999CC9966CC9999CC9999CC9966FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999666666666666CC9999CCCCCCCCCCCCCCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC99CC996666CCCC99FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99CCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FF9999FF9999FF9999CC9999CC9966FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9966CC9966CC9966CC9966\
CC9966CC9999CC9999CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999
CC9966CC9999CC9999CC9999CC9966FFCC99FFCC99CC9999FFCC99FFCC99FFCC99FFCC99FFCC99\
FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999666666666666999999CCCCCCCCCCCCCCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC9999FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FF9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999
CC9966CC9966CC9999CC9966CC9999FFCC99FFCC99CC9966FFCC99FFCC99FFCC99FFCC99CC9999\
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CCCC99663333333333996666CCCCCCFFCCFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999CC9966FF9999FFCC99FFCC99FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999
CC9966CC9999CC9966CC9966FFCC99FFCC99CC9999CC9966FFCC99FFCC99FFCC99FFCC99FFCC99\
CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999663333663333666666999999CCCCCCFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999CC9999FF9999FFCC99FFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FF9999FF9999CC9999FF9999CC9999FF9999CC9999FFCC99CC9999CC9999CC9999
CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9966FF9999FFCC99FFCC99FFCC99FF9999FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999663333663333666666999999CCCCCCFFCCFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999FF9999FFCC99FF9999FFCC99CC9999\
CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999333333663333666666999999CC9999FFCCFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9966CC9999FFCC99FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999\
CC9999FF9999FF9999FF9999FFCC99CC9999CC9999CC9999CC9999CC9999CC9999
CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9999CC9999CC9999CC9999FF9999FF9999CC9999FFCC99CC9999FF9999CC9999\
CC9999CC9999CC9966CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999333333333300333333663333666666999999\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9966FF9999CC9999FF9999FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999\
FF9999CCCC99CC9999CCCC99FF9999FF9999CC9966CC9966CC9999CC9999CC9966
CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9999CC9999CC9999FF9999FF9999FFCC99FF9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999333300333333333333663333663333999999\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999FF9999FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FF9999FF9999CCCC99FF9999CC9999CC9999CC9999CC9966CC9966CC9999CC9999
CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9999CC9999FF9999FF9999FF9999FFCC99FFCC99FF9999CC9999FF9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999333333333333333333333333663333CCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FF9999FFCC99CC9999FFCC99FFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FF9999FF9999CC9966FF9999CC9999FF9999\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FF9999CCCC99FF9999CCCC99CC9999CC9999CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9999FF9999FF9999FFCC99FF9999FFCC99FFCC99FF9999FF9999CC9999FF9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99999999663333663333663333666666999999CCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FF9999FFCC99CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999FF9999FF9999\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999
CC9999FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999CC9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999
CC9999CC9999CC9999CC9999CC9999CC9999999999663333333333663333666666FFFFCCFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FF9999FFCC99FF9999CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999CC9999FF9999\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999FF9999
FF9999FFCC99FFCC99FFCC99FF9999FFCC99FFCC99FF9999FF9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99996666333333663333663333996666CC9999CC9999\
CCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99FFCC99FF9999CC9999FFCC99FFCCCCCCCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999\
FF9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FF9999CCCC99CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9999CC9966CC9966CC9966CC9999CC9999CC9999FF9999
FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999FF9999FF9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99999966663333333333663333663333663333663333\
CC9999FFCCFFFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FF9999FFCC99CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999\
FF9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999FF9999FF9999FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999996666663333663333663333333333663333663333\
666666CC9999CCCCCCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9999\
CC9999FFCC99CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999\
FF9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999FF9999FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999FF9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99CCCC99CC9966996633663333663333663333333333333300\
663333996666999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FF9999CC9966\
FF9999CC9999CC9999FFCC99CCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999\
FF9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FF9999FFCC99FF9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9999FF9999FF9999FF9999FF9999FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999CC9999CC9999CC9999FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9966CC6666996633996633663333663333\
663333666666996666CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99CC9999CC9966\
CC9966CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCC\
FFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9999CC9999CC9999CC9999FF9999FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99FF9999CC9999FF9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99FFCC99CC9966CC9966CC9966996666996633996633993333\
663333663333663333663333666666999999FFCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99CC9999CC9966\
CC9966CC9999FFCC99FFCC99CCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99\
FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9999CC9999CC9999FF9999FF9999FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999CC9999\
FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9966CC9966CC9966CC6666CC6666996633\
663333663333663333663333666666999999FFCCFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999CC9966CC9999\
CC9966CCCC99FFCC99FFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC6666CC9966\
CC9966CC9966CC9999CC9999FF9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999FF9999CC9999CC9999FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99CCCC99CC9999CC9966CC9966CC9966CC9966CC9966CC9966\
996666663333666666996666CC99CCFFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFCCFFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99FF9999FF9999CC9966CC9966CC9966CC9966\
CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99\
FF9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9966CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9999CC9999CC9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CC9999CC9966CC9999CC9999CC9966CC9966CC9966CC9966\
CC9966996666996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCFFCC99FFCCCCFFCC99FF9999CC9966CC9966CC9966CC6666CC6666CC6666CC9966CC9999\
CC9999FFCC99FFCC99CCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCCCC\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99\
FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999CC9999FF9999FF9999CC9999\
FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CC9999CCCC99CCCC99CC9999CC9999CC9999CC9966CC9999CC9966CC9999\
CC9966CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCCCFFCC99FFCCCCFFCC99FF9999CC9966CC9966CC6666CC9966CC9966CC9966CC9966CC9999\
CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFFFCCCCCCCC\
FFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FF9999\
FF9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9999CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9999CC9999CC9999FF9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999FF9999CCCC99CC9999FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99CCCC99CC9966CC9966CC9966CC9966CC9966CC9966CC9999\
CC9999CCCC99FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FF9999CC9966FF6666CC6666CC6666CC9966CC9966CC9966CC9999\
CC9999FF9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9999CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9999CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99FF9999FF9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FF9999FF9999CC9966CC9966CC9966CC9966CC9966CC9966CC9999\
CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FF9999\
FF9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999\
CC9999CC9999FF9999FF9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99CCCC99CC9966CC9966CC9966CC9966CC9966CC9999CC9999\
CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCC99FF9999FF9999CC9966CC9966CC6666CC9966CC9966CC9966CC9999\
CCCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCCCCFFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99\
FF9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999\
FF9999CC9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FFCC99CC9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9966CC9966CC9966CC9966CC9999CC9999CC9999\
CC9999CCCC99FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99FFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FF9999FF9999FF9999CC9966CC9966CC9966CC9966CC9999CC9999\
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCCCCFFCCCCFFCC99FFCCCCFFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CCCC99FF9999FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CCCC99CC9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CC9999CCCC99CC9966CC9966CC9966CC9966CC9966CC9999CC9999\
CC9999CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCC99
FFCCCCFFCCCCFFCCCCFFCC99FF9999FF9999FF9999CC9966CC9966CC9966CC9966CC9999CC9999\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
FF9999FF9999CCCC99FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9966CC9966CC9966CC9966CC9966CC9999CC9999\
CC9999CC9999CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99FFCC99
FFCCCCFFCCCCFFCCCCFFCC99FF9999FF9999FF9999CC9966CC9966CC9966CC9966CC9999CC9999\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999CC9999\
FF9999CC9999CC9999CC9966CC9999CC9999CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FF9999\
CCCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999CC9999FF9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCC99FFCC99
FFCCCCFFCCCCFFCCCCFFCC99FF9999CC9966CC9999CC9966CC9966CC9966CC9966CC9999CC9999\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966
CC9966CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FF9999FF9999FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9966CC9999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFFCC99FFCC99
FFCCCCFFCCCCFFCCCCFFCC99FF9999CC9999FF9999CC9966CC9966CC9966CC9966CC9999CC9999\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC
FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966
CC9966CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999FF9999\
CCCC99FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99CC9999FF9999CC9999FFCC99FF9999FFCC99CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9966CC9966CC9966FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99FFCC99FFCC99
FFCCCCFFCCCCFFCC99FF9999FF9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CCCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99
FFCCCCFFCC99FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966
CC9999CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FF9999\
CCCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FF9999CCCC99FF9999CC9999FF9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CC9999FF9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CCCC99\
CC9966CC9966CC9966CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99FF9999CC9966FFCC99
FF9999CC9999CC9999CC9999996666996666CC6666CC9966CC9966CC9966CC9966CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999\
FF9999CC9999CC9999CC9999CC9966CC9999CC9999CC9966CC9966CC9966CC9966
CC9966CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99CC9999FF9999CCCC99FF9999CCCC99CC9999CC9999FF9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CCCC99CC6666CC6666CC9966CC9999CC9999CC9999CCCC99\
CC9966CC9966CC9966CC9966FFCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99CC9966FF9999FF9999
CC9966CC9999CC9999996666996666996666996666996666CC6666CC6666CC9966CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999\
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99FF9999\
CC9999FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FF9999FFCC99CCCC99FF9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CCCC99CC9999996666CC6666CC6666CC9966CC9999CC9999CCCC99\
CC9999CC9966CC9966CC9966CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCCCCFF9999CC9966FF9999CC9966
CC9966FF9999CC9966663333996633996666996666996633996666996666996666CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCCCC
FFCC99CCCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCCCCFFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FF9999FFCC99\
FF9999CCCC99FFCC99FF9999FF9999CC9999FF9999FF9999CC9999FF9999FF9999
CCCC99FF9999CC9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99CCCC99CC6666CC6666CC6666CC9966CC9966CC9999CC9999\
CC9999CC9966CC9966CC9966CC9966FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99FF9999FF9999CC9966CC9966
CC9966996666996633CC9966996666996666996633996633996633996666996666CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCCCCCCCCCCFFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999FF9999\
CC9999CC9966CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
FFCC99FF9999FF9999CCCC99FFCC99CC9999FF9999FF9999CC9999FF9999CCCC99
FF9999CC9999FF9999CC9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999FF9999CC9999CC9999CC6666CC6666CC6666CC9966CC9966CC9999CC9999\
CC9999CC9999CC9999CC9966CC9966FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99FFCC99CC9966FF9999CC9999996666
996633996633CC9966CC9999996633996633996633996633996633996633996666CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999CC9999\
CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FF9999\
FF9999CC9999FF9999CCCC99CCCC99FF9999CCCC99FF9999CC9999CC9999FF9999
FF9999FF9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CCCC99CCCC99CC6666CC6666CC6666CC9966CC9966CC9999CC9966\
CC9999CC9999CC9999CC9966CC9966CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99FFCC99CC9966FF9999CC9966996633
663333CC6666CC9999CC9966996633996666996633996633663333996666996666CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999CC9999CC9999CC9999FF9999FFCC99FFCC99\
CCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999CC9999\
CC9999CC9966CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999FF9999CC9999FF9999FFCC99FF9999FF9999CC9999FF9999CC9999
CC9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CC9999CC9999CC6666CC6666CC9966CC9966CC9966CC9966CC9966\
CC9999CC9999CC9999CC9966CC9966CC9999FFFFCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99FF9999CC9966FF9999CC9966663333
663333CC9966CC9966CC6666996666CC9966996666996633663333996666996666CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCC
FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FF9999FF9999CC9999CC9999CC9999CC9999CCCC99\
FFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999FF9999CC9999\
CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
FF9999CC9999FF9999CC9999CCCC99FF9999CC9999CC9999FF9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999
CC9999CC9999CC9999CCCC99CCCC99CC9999CC6666996666996666CC6666CC6666CC6666CC6666\
CC9966CC9999CC9999CC9999CC9966CC9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFCC99CC9966FF9999FFCC99996666663333
CC6666996666663333663300996633996666996666999966996666996666996666CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCCCCCCCFFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999CC9999CC9999CC9999\
CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FF9999CC9999\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CC9999CC9999CC6666996666996633996633996633996633993333\
CC6633CC6666CC9966CC9966CC9999CC9966FFCC99FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCC99FF9999CC9966FF9999FF9999996666663333
CC6666996633330000663333996666999966996633663333996666996633996666CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCC\
FFCCCCCCCCCCFFCC99FFCCCCFFCCCCCCCC99CCCC99CCCC99CCCC99CCCC99CC9999
CCCC99CCCC99CC9999CCCC99FFCC99FFCC99FF9999CC9999CC9999FF9999CC9999CC9999CC9999\
CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966996666996633996633996633996633996633\
CC6633CC6666CC6666CC9966CC9999CC9966FFCC99FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFCCFFCC99CC9966FF6666FF9999FFCC99996666996633
CC6666663333330000996633663333663333663333663333663333666633996666CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CCCC99999966CC9999CC9999CCCC99\
CC9999CC9999CC9999CC9966CC9966CC9999CC9966CC9966CC9999CC9999CC9999
CC9999CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999FFCC99CCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FF9999CC9999\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9966CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CCCC99CC9999
CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CCCC99CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CCCC99CC9999CC9999CC9999CC9966996666996633996633996633996633996633\
CC6633CC6633CC6666CC9966CC9999CC9966FF9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFCCCCFFCC99CC9966CC9966FF9999FFCC99CC6666663333
996633333333330000663333333333333333333333663333663333663333666666CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99CC9999CC9966999966996633996666996666\
996633996666996666996666CC9966999966CC9966CC9966CC9966CC9999CC9999
CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99CC9999CC9999\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9999CCCC99CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CCCC99CC9999CC9999CC9966996666996666996633996633996633996633\
996633CC6633CC6666CC9966CC9999CC9966CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFCCCCFFCC99CC9966FF6666FF9999FFCC99CC9966993333
663333330000333300663333333300333333333333663333663333663333663333CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99CCCC99CC9999CC9966CCCC99CC9966996633996633\
663333663333996633996666996666CC9966CC9999CC9966996666996666996666
996666996666996666996666CC9966CC9966CC6666CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999CC9999\
CC9966CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9999\
CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CCCC99CCCC99CC9999CC9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999999966996666996666996633996633996633996633\
CC6633CC6633CC6633CC9966CC9966CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFCCCCFF9999FF6666CC9966FFCC99FFCC99CC9966663333
663333330000330000330000333300663333663333333333663333663333663333CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99CCCC99CC9999CCCC99CC9966996633\
996633663333663333996666CC9999CCCC99CCCCCC999999663333663333996666
663333663333663333663333663333996633996633CC6666CC6666CC6666CC9966CC9966CC6666\
CC6666CC9966CC9966CC9966CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FF9999CC9999\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9966CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966CC9999CC9966
CC9999CCCC99CCCC99CCCC99CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966996666996666996633996633996633996633\
CC6633CC6633CC6666CC6666CC9966CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFCC99CC9966FF6666CC9966FF9999FFCCCCCC9999663333
330000330000330000333300333333663333663333663333663333663333666666CC9999FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9966CCCC99CC9999CC9999\
996666663333663333999966CC9999CCCCCCCCCCCC666666663333999966CC9999
663333330000330000663333996633663333663333996666CC6666CC6666996666996633996633\
996633996633996633996633CC9966FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9966CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966996666996666996633996633996633996633\
CC6633CC6633CC6666CC6666CC9966CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFCCFFCC99CC9966FF6666CC6666FFCC99FFCCCCFF9999663333
330000330000333300333333663333663333663333663333663333663333663333CC9999CCCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCC9966CC9966CCCC99CCCC99\
CC9999CC9999999966663333996666999966999999663333996633CC9999CCCC99
666666330000330000663333996633996633996633996666CC9999CC9999CC9966CC6666996666\
996633996666996666CC6666CC9966CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FF9999CC9999\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC6666CC9966
CC9966CC9966CC9999CC9999CCCC99CC9999CC9999CCCC99CCCC99FFCC99FFCC99CCCC99FFCC99\
CCCC99CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9966996666996666996633996633996633996633996633\
996633996666CC6666CC6666CC9966CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFCCCCFFCC99CC9966CC6666CC9966FF9999FF9999FFCC99996666
663333333333333333333333333333333333663333663333663333666666666633CCCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9999CC9966CC9999\
CCCCCCCC9966CC9999999966996666663333663333663333666666999999999999
996699330000330000333333666633996633996633996666CC9999CC9999CC9999996666996633\
996633996633CC9966CC9966FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC6666CC6666CC6666
CC9966CC9966CC9999CC9999CCCC99CCCC99CCCC99CCCC99CCCC99CC9999CCCC99CCCC99CC9999\
CC9999CC9999CCCC99CC9999CC9999CCCC99CCCC99CCCC99CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99CCCC99CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9966996666996666996633996666996633996633996633\
CC6666CC6666CC6666CC9966CC9999CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
CCCCCC999999CCCC99FFCC99FF6666CC6666CC6666CC9999FF9999FF9999CC9966
663333333333330000330000333333333333333333333333663333663333996666CCCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9999CC9966\
CC9999FFCCCCFFCCCCCC9999CC9999CC9966996666663333663333663333666666
663366000000330000333333663333663333663333996666CC9999999999CC9966996666996633\
996633CC9966CC9966CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC6666CC6666CC6666996666993333
996633996633CC6666CC9999CC9999CCCC99CCCC99CC9999CC9999CC9966CC9999CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9966CC9966996666996666996666996666996666996633996666\
CC6666CC6666CC9966CC9966CC9999CC9999CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
666633663333FFCC99FFCC99CC9966CC6666CC6666CC9999FF9999FF9999CC9999
663333333300333333333333333333663333663333333333663333663333996666CC9999FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99CC9999\
CC9999CC9999FFCCCCFFCC99CCCC99CCCC99CC9966996666996633663333663333
663333330000333300333300663333663333663333996666666666996666996666996666CC6666\
CC6666CC6666CC9966CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC6666CC9966CC6666996666663333
663300663333993333CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC9966CC9966\
996666996666996666996666996666CC6666CC9966CC9966CC9966CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9966CC9966996666996633996633996633996666996633996666\
CC6666CC9966CC9966CC9966CC9966CC9966CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999\
330000663333FFCC99FFCC99FF9999CC6666CC6666FFCC99FFCC99FFCC99FFCC99
996666330000333300333333663333333333333333333333663333663333996666CCCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCC99CC9999CC9999FFCCCCFFCCCCCC9999CC9966CC9999996666996633666633
996633663333663333663333663333663333663333996633996633996633CC6666CC6666CC6666\
CC6666CC9966CC9999FFCC99CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC6666996633
663333663333996633999966CC9966CC9966CC9999CC9966999966996666996666996666996633\
996633996666996666996666996666996666996666996666996666CC6666CC9966
CC9999CC9966CC9966CC9966CC9999CC9966CC9966CC9999CC9999CC9999CC9999CC9966CC9999\
CC9966CC9999CC9999CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9966CC9966999966996633996633996633996666996633996633996633\
CC9966CC9966CC9966CC9966CC9999CC9966CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF996666663333\
330000663333CC9966FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
996633330000333333333333663333333333333333663333663333663333996666CCCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCC99FFCC99CC9999CC9999FFCCCCCC9999CCCC99CCCC99996666999966CC9966
996666996666666633996633996666996633996633996666996666999966CC9966CC6666CC6666\
CC6666FFCC99FFCC99FFCC99CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666996666
996666996633996633999999CC9999CCCCCCCCCCCCCCCCCCCCCCCC996666996633663333663300\
663333663333663333996633996666996666996666996666996633996633996633
CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9966CC9966CC6666996633996633996633996666996633996633996666\
CC9966CC9966CC9966CC9966CC9999CC9966CC9966FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333333333\
330000663300CC9966FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99CC9999
996633333300663333333333663333333333333333333333663333663333996666CCCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99CC9999CC9966CC9999FFCC99CCCC99CC9999CCCC99CC9999
CC9966996666996666996666996666996633996633CC6666CC6666CC9966CC9966CC6666CC6666\
CC9966CC9999FFCC99CC9999FF9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC9966CC9966CC6666CC6666
CC6666996633993333996666CC9999CCCCCCCCCCCCCCCCCC999999663333663333663333663300\
663333663333663333663333663333996633996666996666996633996633996633
996633996666999966999966999966CC9966999966999966999966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9966CC9966CC9966996666996633996666666666996633996666996633996633\
CC9966CC9966CC9966CC9999CC9999CC9966CC9966FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333333333663300\
330000333300CC9966FF9999FFCC99FFCC99FFCC99FFCC99FF9999FF9999CC9999
996633663333663333663333333333333333333300333333333333663333996666CCCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCC99FFCC99CCCC99CC9999CC9999CC9999CC9999CCCC99CC9999
CC9999CC9966CC9966CC9966CC9966CC6666CC6666CC9966CC9966CC6666CC6666CC9966CC9999\
CC9999CC9999FF9999FF9999FF9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9966CC9966CC9966CC9966CC9966CC6666CC9966CC9966CC9966CC6666
996666CC6666996666996633999966CC9999CCCCCCCCCCCC666666996633999966663333330000\
333333333333663333996633666666663333666666996666996666996633996633
663333996666996666996666996666996666996666996633996666996666CC6666CC9966CC9966\
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9966CC9966999966996666996633996633663333996666996666996633996633\
CC9966CC9999CC9999CC9999CC9966CC6666CC6666CCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333333333333300333333\
330000330000663333CC6666FF9999FFCC99FFCC99CC9966CC9966CC9966996633
663333663333663333663333663333333333333333333333663333663333996666CCCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9999CC9966
CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99CC9999
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC6666996666CC9966CC9966CC6666996666996666996666666666CC9999CC9999333333000000\
333333663333663333666633663333663333666666999999999999999966666666
666633663333663333663333666633666633666666996633996666CC6666CC9966CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9966CC9966999966996666666666663333666633666633996633663333663333996633\
CC9966CC9999CC9999CC9966CC6633CC6666CC9966FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF996666663333663333333300333333\
330000330000330000663333CC6666CC9966CC9966CC6666996666996633663333
663333663333333333333333333333333333333333333333663333663333996666FFCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9966
CC9966CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
FF9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966996666CC6666CC9966CC9966CC9966CC6666996666663333999999999999333333000000\
333333666666666633663333663333663333666666999966999999996666666666
663333663333663333663333663333663333666666996666CC6666CC9966CC9966CC9966CC9966\
CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9966999966996666663333666633663333663333666633663333663333996633\
CC9966CC9999CC9999CC9966CC6633CC6666CC6666CCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC663333663333663333663333333333\
330000330000330000330000663333996633996633996633663333663333663333
663333663333663333333333333333333300333333333300663333663333996666CCCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFF9999
CC9966CC9966CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99CC9999FFCC99
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC6666CC9966CC9966CC9966CC9966CC6666996666996633666666333333000000\
330000333333663333663333663333663333666666996666996666663333333333
663333663333666666996666996633996633996666CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9966999966996666666633666633663333996633666633663333663333663333\
CC9966CC9999CC9999CC9966CC6633CC6633CC9966FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333663333663333663333663333\
330000330000330000330000330000330000330000996633663333663333663333
333333333333663333663333333333333333333333333333663333663333996666CCCC99FFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
CC9999CC9966CC9999CC9999CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999FFCC99\
CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCCCCFFCCCCFFCCCC
FFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CCCC99\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9999CC9999CC9966CC9966CC9966996666666633663333333333\
330000333300663300663333663333663333666633666633663333663333663333
663333996666996666996666996666CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9999\
CC9966CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9966996666663333663333663333663333663333663333663333663333663333\
CC9966CC9999CC9999CC6666CC6633CC6633CC9966FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333663333663333663333663333\
330000333300333300333300330000330000330000663333663333663333333333
333333333333333333663333333333333333333333333300663333663333996666FFCC99FFCCCC\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FF9999CC9999CC9966CC9999CCCC99CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CCCC99FFCC99
FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99\
CCCC99CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9966CC9966996666996666996633\
996633663333663333663333663333663333663333333333663333663333663333
666666996666996633996666999966CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9999CC9966CC9966CC9999CC9966CC9966CC9999CC9999CC9999CC9999CC9999
CC9999CC9966CC9966996666663333663333663333663333663333663333663333663333663333\
CC9999CC9999CC9999CC6666CC6633CC6666CC9966FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666663333333333663333663333663333\
330000333333333300663300330000330000330000663333663333333333333333
333333333333333333333333333333333333333333333333333333663333996666FFCC99FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFF9999CC9966CC9999CC9999CC9999CC9999CC9999FFCC99FFCCCCFFCCCCFFFFCCFFCCCC\
FFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99
CC9999CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966\
CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9966CC9966CC9999CCCC99CC9999CC9966996666996666996666\
996666996633996666663333663333996633666666663333663333996666996666
999966996633996666CC9966999966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9966999966996666663333663333663333663333663333663333663333663333663333\
CC9999CC9999CC9966CC6633CC6633CC6666CC9966FFCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666666663333663333663333663333663333\
333333333333663333333333333300333300663333663333333333333333333333
333333333333333333333333333333333333333300333333663333663333996666CCCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99CC9999CC9999CC9999CC9999CC9999CC9966CC9999FFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCC99CCCC99FFCC99CCCC99CC9999
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC6666CC6666CC6666CC9966\
CC9966CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99CC9999\
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9999CC9966CC9966CC9999CC9999CC9999CC9966CC9999CC9966\
999966996666996666996666666633996666996666996666666666996666999966
996666999966CC6666CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9966996666996633663333663333663333333333663333333300333333663333663333\
CC9999CC9999CC9966CC6633CC6633CC6666CC9966FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333663333663333663333663333663333\
333333663333663333663333663333663333663333663333333333663333333333
330000333300333300333333663333333333333300333333663333663333996666CCCC99FFCC99\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FF9999CCCC99CC9999999966999966CC9966999966CC9966999966CC9966\
999999CC9966CC9966CC9966996666996666996666996666996666996666996633
996633996633996633996666996633996633996633996633996666996666996666996666996666\
CC6666CC9966CC9999CCCC99FF9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99\
CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9966CC9966CC9966999966999966CC6666996666CC6666999966996666
996666CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9966CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999999966996666663333663333663333663333663333663333333333333300333300663333\
CC9999CC9966CC6666CC6633CC6633CC6666CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333663333663333333333333300333333\
333300333333333333333333663333663333663333663333333333333333333333
333333333333330000333333663333333333333333333333663333663333996666CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFF9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966\
CC9966999966999966996666996666996666996666996666996666996633996633
996666996666996666996633996633996633996666996633996666996633996666996666CC9966\
CC9966CC9966CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99\
CCCC99CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CC9966CC9966CC9966999966CC9966CC9966CC9966CC6666996666999966
CC9966CC9966CC9966CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9966999966666666663333663333663333663333663333333333333333333300333300996633\
CC9999CC9966CC6666CC6633CC6633CC6666CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333663333333333333333333300333333\
333300333333663333333333333333333333663333663333333333333333333333
333333333300333300330000333333663333663333333333663333663333996666CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CCCC99CC9999CC9966996666996666996666\
CC9966999999CC9966996666996666996666996666996666996666996666996666
996666996666996666996666996633996633996633996666996633996666CC6666CC9966CC9966\
CC9966CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99\
CCCC99CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC6666CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9966996666663333663333333333663333333333663333663333333333333300330000996633\
CC9966CC9966CC6666996633CC6633CC6666CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333663333663333333300333333333333\
333300333333333300333333333333333333333333333333333333333300663333
333333333333333333333300333300663333663333663333663333663333996633CC9999FFCC99\
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99999966CC9966996666CC9966\
996666996666996666CC9966999966999999CC9966996666996666996666996666
996666996666996666996666996666996633996666996666996666996666CC6666CC9966CC9966\
CC9966FF9999FF9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999\
CCCC99CC9999CC9999CC9999CC9966CC9966996666996666996633996633996666
CC6666CC6666CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9966
CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966
999966996666663333663333663333333333663333663333333333333300333300333333CC6666\
CC9966CC6666CC6666CC6633CC6633CC6666CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CC663333663333663333333300333333333300\
333333333300333333333333333333333300333333333333333333330000333333
333333333333333300333333333333333333663333663333663333663333666666CC9999CCCC99\
CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99CC9999CC9999CC9999\
CC9999CC9999CC9999999999CC9966CC9999CC9999CC9999CC9999CC9999999966
CC9966CC9966999966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9999\
FF9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99\
CCCC99CC9999CC9999CC9999CC9966CC9966996666996633996633996633996633
996633996633CC6666CC9966CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966
999966663333663333663333333333333333333333663333333333333333333300663333CC9966\
CC9966CC9966CC6666996633CC6633CC6666CC9966CCCCCCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666633663333333333333333333333333333\
333333333333333300333300333300333333663333333333333333330000333333
333333333300333333333300333300333333663333663333666633663333666633CC9966CC9999\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCC\
FF9999CCCC99CCCC99FF9999CCCC99FFCC99CCCCCCFFCC99CCCC99FF9999CCCC99
CCCC99CC9999FF9999CCCC99CCCC99CCCC99FF9999CCCC99FF9999FFCC99FFCC99FFCC99FFCC99\
FFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99\
FF9999CCCC99CC9999CC9999CC9966CC9966996666996633996633996633996633
996633996633996633996666CC6666CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9966
996666663333663333333333333333663333333333333333333333663333663333996633CC9966\
CC9966CC9966CC6666CC6633CC6633CC9966CC9966996666FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666663333663333333300333333333333\
333300333333333333333333333333663333333333333333333333330000333300
333333333300333333333333333333333333333333333333663333996666996666CC9966CC9999\
CCCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCCCCCCCFFCCCCFFCCCCCCCCCCFFCCCC
FFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
CCCC99FF9999CCCC99CC9999CC9999CC9966996666996666996633996633996633
993333993333993333996633996666CC6666CC9966CC9966CC9966CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966
996666663333663333333333333333333333333333333333333333663333663333996666CC9966\
CC6666CC6666996666996633996633CC6666CC9966666633CCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666663333663333333333333300663333\
333300333333333333333300333300333333333333333333333333333300330000
333300333333333300333333333333333333663333663333663333663333666666CC9966CC9999\
CCCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC
FFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCCCCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FF9999CCCC99FFCC99CCCC99CC9999CC9966996666996666996633
996633996633996633663333663333663333996633996633996633996633CC9966CC9966CC9966\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966996666
666633663333333333333333333333333333333333333333333333663333663333996633CC6666\
CC9966996666996666996633996633CC6666996666663333999999FFFFCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF996666663333663333333333333333333300\
333333333333333300333333333300333333333333333333663333333300330000
330000333333333333330000333333333333663333663333663333663333666666999966CC9999\
CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999CC9999CC9966CC9966996666
996666996633996633663333663333663333663333663333663333663333996633996666CC6666\
CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966996666
663333663333333333333333333333333333333333663333663333663333663333663333996666\
CC9966CC9966996666996633996633CC6666996633663333999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999966663333663333663333333333333333\
333300333333333300333300333333333333333333333333333333333333330000
330000333300333333333333333333663333663333663333663333663333666633999966CC9999\
CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFFFCC
FFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99CCCC99CC9999CC9999
CC9966996666996666996633996633663333663333663333663333663333663333663333663333\
996633996666CC9966CC9966CC9999CC9999CC9999CC9999CC9966CC9999CC9999
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966996666CC6666996666996666996666\
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966996633
663333333333663333333333333333333333333333663333663333333333333300663333996633\
CC9966CC9966CC9966996666CC6666CC9966996633666633996666CC9999CCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333663333663333663333663333\
333333333333333333333333333300333333333333333333333333333333330000
330000330000333333333333333333663333663333663333663333666633996666CC9966CC9999\
CC9999CC9999CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCC\
FFCCCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCC
FFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99CCCC99FFCC99CCCC99CCCC99
CC9999CC9999CC9966996666996666996666996633663333663333663333663333663333663333\
663333663333996633996633CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC6666996666996666996666996666996666CC9966\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966666666
663333663333333333330000333333333333333333663333333333333333333300663333993333\
996633996666CC6666CC9966CC6666996666663333663333996666999999FFCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333663333663333663333663333\
663333333333333333333300333333333333333300333333333333333333333300
330000330000333300333333663333333333333333663333663333666666996666996666CC9966\
CC9999CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99
CC9999CC9999CC9999CC9966996666996666996666996666996666996633663333663333663333\
663333663333663333663333996633996666996666996666996666999966CC6666
CC9966CC6666996666996666996666996666996666996666996666996666996666CC9966CC9966\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966666633
663333663333333300333333663333333300663333333333333333663333333333663333663333\
996633996633996633996633996633996633663333666633996666999999FFCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999663333663333663333663333663333\
333333333333333300333333333300333333333333333333333333333333333333
333300330000330000333333333333663333663333663333663333663333996666996666CC9966\
CC9999CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCC
FFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
CCCC99CCCC99CC9999CC9999CC9999CC9966999966996666996666996666996633996633663333\
663333663333663333663333663333996633996633996633996633996666996666
996666996666996633996666996666996666996666996666996666996666CC9966CC9966CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966663333
663333333300333300333333333333333333333333333333333333333333333300663300663300\
663333993333663333663333663333663333663333666633996666CC9999FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999663333663333663333663333663333\
333333333300333300333333333333663333333333333333333333333333333333
333300330000330000333300333333663333663333663333663333666666666666996666CC9966\
CC9999CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCC
FFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FF9999CCCC99CC9999CC9999CC9999CC9999CC9966CC9966CC6666996666996666996633\
996633996633663333663333663333663333996633996633996633996633996633
996666996666996666996633996666996666996666996666996666CC9966CC9966CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9966999966663333
333333333300333333333333333333333333333333333333333333333333333300330000660000\
663300663300663300663333663333663333663333666633999999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CC663333663333663333663333663333\
663333663333333333333333663333663333663333333333333333333333663333
333333330000330000330000663333663333663333663333663333663333666666996666CC9966\
999999CC9999CCCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99CCCC99CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9966CC9966CC9966996666\
996666996666996633663333663333663333663333996633663333996633996633
996633996633996633996633996666996666996666996666CC9966CC9966CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9966999966663333
333333333333333333333333333333333333333333663333333333333333333300333300330000\
330000660000663300663333663333663333663333666633FFCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999666633663333663333663333666633\
663333663333663333333333663333333333333333663333333333663333333333
663333663333333333333333663333663333663333663333663333663333996666996666CC9966\
CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCC
FFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FFCC99FF9999FFCC99FF9999CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9966CC9966\
CC9966CC9966CC9966CC6666996666996666996633996633996633996633663333
993333996633996666996666996666CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966999966996666663333
663333333333333333333333663333333333663333333333333333333333333333333300333300\
333300333333333333333333663333663333663333666666CCCCCCFFCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF999999666633663333663333663333666633\
663333663333333333333333663333663333333333333333333333333333663333
333333663333333333663333333333663333663333663333663333663333996666996666999966\
CC9966CC9999CC9999CCCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99CCCC99FF9999FF9999CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9966CC9966CC9966CC9966CC6666996666996666996666996666996666
996666996666996666CC6666CC9966CC9966CC9999CC9999CC9999CC9966CC9999CC9999CC9999\
CC9966CC9999CC9999CC9999CC9966CC9966CC9966CC9966999966666666663333
663333333333333333333333333333333333663333333333333333333333333333330000333300\
333333663333333333663333663333663333663333666633996666999999CCCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666996666663333666633663333666633\
666633663333663333663333333333663333333333333333333333663333663333
663333663333663333663333663333663333663333663333663333666633666666996666996666\
CC9966CC9999CC9999CCCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFFFCCFFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99CCCC99CCCC99FF9999FF9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966996666663333663333
663333333333333333333333333333333333333333333333333333333333333333333300330000\
333333333333333300663333333333663333333333663333663333666633999999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666663333663333666633663333663333\
666633663333663333663333663333663333663333333333663333333333333300
333333663333333333333333333333663333663333663333663333666633663333996666996666\
CC9966CC9966CC9999CC9999CCCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFFFCC\
FFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99CCCC99CCCC99CCCC99CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9999CC9966
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9966CC9966CC9999CC9999CC9966CC9966999966996666663333663333
663333333333333333333333333333333333333333333333333333333333333333333333333333\
333333333300333333333333663333663333663333333333666633666633999999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999666666663333663333663333663333663333\
663333663333663333663333663333663333663333333333333333333333333300
333300663333663333663333663333663333663333663333663333663333663333666666996666\
996666CC9966CC9999CC9999CC9999FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99CCCC99FF9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999\
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966\
CC9999CC9966CC9999CC9999CC9966CC9966CC6666996666996666663333663333
663333333333333333333333333333333333333333663333333333333333333333333333333300\
333333333333333333333333663333333333333300333333663333663333996666
FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999666633663333663333663333666633663333\
663333663333663333663333663333333333663333333333333333333333333333
333300333333663333663333663333333333333333663333663333663333663333996666996666\
996666999966CC9966CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFFFCC\
FFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFFFFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99CCCC99FF9999CCCC99CCCC99CC9999CC9999CCCC99CCCC99CC9999CC9999\
CC9999CCCC99CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9966CC9966CC9966999966996633663333663333663333
663333663333333333333333333333333333333333333333663333333333333333333300333333\
333333333333333333333333333333333300330000333333663333666633666633
CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999966666666666633666633663333663333663333\
666633663333663333663333663333663333333333333333663333663333333300
333333333333333333333333333333333333333333333300333333663333663333663333996666\
996666999966CC9966CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99CCCC99CCCC99FF9999CCCC99CC9999CC9999CC9999CCCC99CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9966CC9966999966996666996666663333663333663333
663333333333333333333333333333333333333333333333333333663333333333333300333300\
333333333300663333333333333333330000330000663333663333666633663333
999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666666666663333663333666633666633666633\
663333663333663333663333663333663333663333663333333333333333333333
333333333333333333333300333333333333333333333333663333663333663333666633663333\
666666996666996666CC9966CC9966FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99CC9999FF9999CCCC99FFCC99FF9999CCCC99FF9999CC9999CC9999CCCC99\
CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9966999966996666996666663333663333663333663333
333333333333333333333333333333333333663333333333330000330000333333333300333333\
333333333333333300333333333300330000333300663333663333663333666633
999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666666666663333663333663333663333663333\
666633666633663333663333663333663333663333663333333300333333333300
333300333333663333663333663333663333333333333333663333663333663333663333663333\
663333996633996666999966CC9966CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFFFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99CCCC99CC9999CC9999CC9999CCCC99CC9999CC9999CC9999CC9999CCCC99\
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9966CC9966996666996666666666663333663333663333333333
333333333300333333333333663333333333333333330000330000333333333300330000333333\
333333333333333333333300333300330000333333663333663333663333666633
999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF666633666666663333663333663333663333666633\
663333663333663333663333663333663333663333663333333333333333333333
333300333300333333333333333333663333663333663333333333663333663333663333663333\
666666663333996666996666CC6666CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCC
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99CC9999FF9999CCCC99FF9999CC9999CC9999CC9999CC9999CCCC99\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9966CC9966999966996666666666663333663333663333663333333300
333300333333333333333333333333663333330000330000333333333333330000333333333300\
333333333300333333330000330000333300333333333333663333663333666633
999966CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF663333663333663333666633663333663333663333\
663333663333666633663333663333663333663333333333333333333333333333
333333333300333300333300333333333333663333333333663333663333663333663333666666\
663333996666996633996633996666CC9999CC9999FFCC99FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCC\
FFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FFCC99FFCC99FFCC99FF9999FF9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966\
CC9966CC9966CC9966996666996666666666663333663333663333333333333333
333333333300333333663333333333333333330000330000333333330000333333333300330000\
333300333300333333330000333300333300333333663333333333663333666633
996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF663333663333663333663333666633663333666633\
663333663333666633663333663333663333663333663333333333333333333333
663333333300333300333333333300333333333333663333663333663333663333666633666633\
996633996666996666996633996666CC9966CC9999CC9999FFCC99FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
CC9999FF9999FFCC99CCCC99CCCC99FF9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966\
CC9966CC9966999966996666996666663333663333663333333333333333333333
333333333333663333333333333333330000333333333333333333333300333300330000333300\
330000333300333300333300330000333333333333663333333333663333666633
996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666666666663333663333666633663333666633\
666633663333666633663333663333663333663333663333333333663333333333
663333333333333300333333333333333300333333663333663333663333663333663333996633\
666666996633996666996633996633CC9966CC9999CC9999FFCC99FFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CC9999FFCC99
FFCC99CC9999CCCC99FF9999FF9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966\
CC9966CC9966996666996666996666663333663333663333333333333333333333
333333663333333333663333330000330000333300330000333300333333330000333300330000\
330000333300333300330000333300333333333333663333663333663333663333
996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF666666666633663333663333666633663333663333\
663333666633666633663333663333663333663333663333663333333333663333
663333333333333300333300333333663333333333333333663333663333663333663333666633\
663333666666996666996666996633CC9966CC9966CC9999FFCC99FFCC99FFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FF9999CC9999CCCC99CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966\
CC9966CC9966996666996666666666663333663333663333333333333333333333
663333663333663333330000330000330000330000333333333333333333330000330000330000\
333300330000333300333333333300333333333333333333663333663333666633
996666FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666633666633663333663333666633663333663333\
663333666633663333666633663333663333663333663333663333663333663333
333333663333663333333300333333333333333333663333333333333333663333663333663333\
666633996633996666996666996666CC9966CC9966CC9999FFCC99FFCC99FFCC99
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99
FF9999FF9999CC9999CCCC99CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966\
CC9966999966996633666666663333663333663333663333663333663333663333
333333333300333300333300333333333333333333333300333300330000330000330000330000\
333300330000333300333333333300333333333333333333663333663333666666
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC663333663333663333663333663333666633663333\
663333663333663333666633666633663333663333663333663333663333663333
663333333333663333333333333333333333663333663333663333333333333333663333663333\
663333663333996633996666996666CC9966CC9966CC9999CC9999FFCC99FFCC99
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
CC9999FF9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966\
999966996666996666663333663333663333663333663333663333663333333333
333333333333333333333333333333333333333300333333330000330000330000330000330000\
330000330000333333333300333300333333333333333300663333663333999966
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CC663333663333663333663333663333663333663333\
663333663333663333666633666633663333663333663333663333663333663333
333333333333663333663333333300333333663333333333663333663333333333663333663333\
663333996633996666996666996666CC9966CC9966CC9966CC9999FFCC99FFCC99
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCC
FFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999
FF9999CCCC99CC9999CC9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966\
996666996666666666663333663333663333663333663333663333663333333333
333333333333333333333333333333333333333300330000330000330000330000000000330000\
333300333300333300333300330000333333333300330000663333666633999999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666633663333666633663333663333663333666633\
666633666633663333666633666633666633663333663333663333663333663333
663333333333663333663333333300663333663333333333663333663333663333663333663333\
663333996633996666996666996666999966CC9966CC9966CC9999FFCC99FFCC99
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCC
FFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999FF9999CC9999FF9999
FF9999CCCC99FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966996666\
999966996666666666663333663333663333663333663333333333333333333333
333300330000333300333333333333333300330000000000330000333333330000330000333300\
333333330000333300333333333333333333333300333333663333666666CCCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCC666633666633666633663333663333663333666633\
666633666633663333666633666633666633663333663333663333663333333333
663333333333663333663333333333663333333333663333663333663333663333663333663333\
666633663333996666996666996666CC9966CC9966CC9966CC9966CC9999FFCC99
FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCC
FFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999CCCC99FF9999CCCC99FF9999
CC9999FF9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966999966999966\
996666996666663333663333663333663333663333663333333333333333333333
333300333333333333330000333300333333330000330000330000330000330000333333333333\
330000330000333333333333333300333300333300333333663333666633CC9999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC663333663333663333663333663333663333666633\
666633663333663333666633666633666666666633663333663333663333663333
663333663333333333663333663333663333663333663333663333663333663333663333663333\
663333666633996666996666996666CC6666CC9966CC9966CC9999CC9999FFCC99
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCC
FFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CCCC99FF9999FF9999CC9999
CC9999CC9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9966CC9966999966999966996666\
996666996633663333663333663333663333333333333333333333333333333333
333333333333333333333333333333333300330000333333330000330000333333333333330000\
330000333300333333333300333333333300333333663333663333666633999999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC663333666633663333663333663333663333666633\
666666666633666633663333666633663333666666663333663333663333663333
333333663333333333663333663333663333663333663333663333663333663333663333663333\
663333666666996666996666996666999966CC9966CC9966CC9966CC9999CCCC99
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCC\
FFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCC
FFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FF9999CCCC99CC9999
FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966999966996666\
996666666666666633663333663333663333663333333333333333333333333333
333333333333333333333333333333333333333333330000330000333333333333333333330000\
333333330000333333333300333333333333663333333333663333666633CC9999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC663333666666663333663333663333663333663333\
666633666633666633666633666633666633666633663333663333663333663333
333333333333333333663333663333663333663333663333663333663333663333663333663333\
663333663333996666996666996666CC6666CC9966CC9966CC9966CC9999FFCC99
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCC
FFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCCCCFFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCC99FF9999CC9999CCCC99FF9999
CCCC99CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966999966996666996666996666\
996666663333663333663333663333663333663333663333333333333333333333
333333333333663333663333333333333333333333333333333333333333333333333333333300\
330000333333333333333333333333333333333333333333663333996666CCCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666666633663333663333663333663333663333\
666666666633666633666633666633666633663333663333663333663333663333
663333333333333333663333663333663333663333663333663333663333663333666633663333\
666633663333996666996666996666996666999966CC6666CC9966CC9966CC9999
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFFFCC
FFFFCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FFCC99FF9999FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999CC9999CC9999CCCC99FF9999
CC9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC6666996666996666996666996633666666\
996633666633663333663333333333663333663333663333333333333333333333
663333663333333333333333663333333333333333333333333333333333333333333333333333\
663333333333333333333300330000330000333333663333996666CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666633663333666633663333663333663333663333\
663333666633666666666633666633666666663333666633663333663333663333
663333333333333333663333663333663333663333663333663333663333663333663333663333\
666633666666996666996666996666996666996666CC6666CC9966CC9966CC9999
CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFFFCCFFFFCCFFCCCCFFFFCCFFFFCCFFFFCCFFCCCCFFFFCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999\
FFCC99FFCC99FFCC99FFCC99FF9999FFCC99CCCC99FF9999CC9999FF9999CC9999
FF9999CC9999CCCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966999966996666996633996633666666\
663333663333663333663333663333663333663333333333663333333333333333
333333663333663333333333333333330000330000333333333333333333333333333333333333\
330000330000333300330000330000333333663333333333999999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666633663333663333663333663333663333663333\
663333666633666666666633666633666666666633666633663333663333663333
663333333333333333333333663333663333663333663333663333663333663333663333663333\
666633663333663333996666996666996633996666999966CC6666CC9966CC9999
CC9999CCCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFCCCCFFCCCCFFFFCCFFFFCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999\
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999CC9999FF9999FF9999CCCC99FF9999
FF9999CC9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966
CC9999CC9966CC9999CC9966CC9966CC9966CC6666996666996666996666996633666666663333\
663333663333663333663333663333663333333333333333333333333333663333
333333333333333333333333330000330000333333333333330000330000330000330000330000\
330000330000333333330000333333663333333333663333CC9999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC666666666633663333663333663333663333663333\
666633666633666666663333663333666666666666666633663333663333663333
663333333333333333333333663333663333663333663333663333663333663333663333663333\
666633666666663333996666996666996633996666996666CC6666CC9966CC9966
CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFFFCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99CC9999FF9999CC9999
CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9966CC9999CC9966CC9966CC9966999966996666996666996633666666996633663333\
663333663333663333663333663333333333333333333333333333333333333333
333300333300333333663333333333333333333333330000330000330000330000330000000000\
330000330000333300330000333333333333333333663333CC9999FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF996666666666663333663333663333663333663333\
663333663333666633666633663333666633666666666633666633663333663333
663333663333333333333333663333663333663333663333663333663333663333663333663333\
663333666666663333996666996666996633996633996666CC6666CC9966CC9966
CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCC99FFCCCCFFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FF9999FF9999FF9999CC9999FF9999FF9999CC9999FF9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999
CC9999CC9966CC9966CC9966CC9966999966999966996666996633996666996633663333663333\
663333663333663333663333663333663333663333333333333333333333333300
333300333333333333333333663333333333330000000000330000333300330000330000330000\
330000330000333300333300333333333333663333663333CCCC99FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666666633663333663333663333663333663333\
663333663333666633666666666633666633666633666633663333663333663333
663333663333663333333333333333663333663333663333663333663333663333663333663333\
663333663333666633666633666666666666996633996666996666CC6666CC9966
CC9999CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FFCC99FFCC99FF9999FFCC99FFCC99FFCC99FF9999\
FFCC99FF9999FFCC99FF9999FFCC99FFCC99FFCC99FF9999CC9999FF9999CC9999
FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9966CC9966CC9966CC9966CC9966996666996666996666996633666666663333663333663333\
663333663333663333333333333333333333333333333333333333333333333333
333333333333333333333333333333333333330000330000333333000000000000330000330000\
330000330000330000333300333333663333663333663333CCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF999999666666663333663333663333663333663333\
666633663333663333666666666633666633666633663333663333666633663333
663333663333663333333333333333333333663333663333663333663333663333663333663333\
663333663333996633666633663333996633996633996666999966996666CC9966
CC9999CC9999FFCC99FFCC99FFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FFCC99FFCC99FFCC99FFCC99FF9999FFCC99\
FFCC99FFCC99FF9999FFCC99FFCC99FF9999FF9999CC9999FF9999CC9999FF9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966
CC9966CC9966CC9966999966996666996666996666996666666666663333663333663333663333\
663333663333663333333333333333333333333300333300333333333333330000
333333333333333333333333333333333333333300333333330000330000330000330000000000\
330000330000333333333333333333663333663333666633FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666666666666633663333663333663333663333\
666633663333663333666633666666663333666633666633663333663333663333
663333663333666633663333663333333333333333663333663333663333663333666633663333\
663333663333663333666666663333663333663333996633996633999966CC9966
CC9966CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99
FF9999FFCC99FFCC99FF9999FF9999FF9999FFCC99FFCC99FF9999FFCC99FFCC99FF9999FFCC99\
FF9999FFCC99CC9999FFCC99FF9999FFCC99CC9999FF9999CC9999FF9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966
CC9966CC6666999966999966996666996666996633996633663333663333663333663333663333\
663333663333333333333333333333333333333333333333333333333333333333
333333333333333333333333333333330000333333333333330000333300330000000000330000\
330000333300333333663333663333663333663333CC9999FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999966996666666666663333663333663333663333\
666666663333663333663333666666663333663333666666663333663333663333
663333663333663333663333333333663333333333333333663333663333663333663333666633\
663333663333663333666633666633663333663333996633996633996666CC6666
CC9966CC9999CC9999FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FFCC99FF9999FFCC99FF9999FFCC99FF9999FF9999FF9999FFCC99FFCC99FF9999FF9999FF9999\
FFCC99CC9999FF9999FF9999FF9999FF9999CC9999CC9999CCCC99CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966
CC9966999966999966996666996666996633996666996666663333663333663333663333663333\
663333333333333333333300333300333333333333333300333333333300333333
333333333333333333333333333333333333333333333333330000000000330000330000330000\
333300333333333333663333663333663333996666FFCCFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666996666666666666633663333663333663333\
666633663333663333663333666633666633663333666666663333663333663333
663333663333663333666633333300663333663333333333333333663333663333663333666633\
663333663333663333663333663333663333666633663333996633996666999966
CC6666CC9966CC9999CC9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FF9999FFCC99FFCC99FFCC99FFCC99CC9999FFCC99FFCC99FFCC99FFCC99FFCC99CC9999CC9999\
FFCC99FF9999FF9999CC9999CC9999FF9999FF9999CC9999FF9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966996666996666996666996633996666996633996633663333663333663333663333663333\
663333333333333333333300333300333300333300333333333300333333333333
333333333333333333333333333333333333333333333333333333330000330000333333330000\
330000333333663333663333663333663333CC9999FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666996666996666666633663333663333663333\
666633666633663333663333666633666633663333666666666666663333663333
663333663333663333663333663333333333663333663333663333663333663333663333663333\
663333663333663333663333666633666633663333663333996633996666996666
CC9966CC9966CC9999FF9999FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999
FFCC99FFCC99FF9999CC9999FF9999CC9999FF9999CC9999CC9999FF9999FF9999FFCC99FFCC99\
CC9999FF9999CC9999FF9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
996666996666996666996666996666996633663333663333663333663333663333663333333333\
333333333333333300330000333300333300333333333300333333333333333333
333333333333333333333333333333333333333333333333333333330000330000330000330000\
333300333333663333663333663333996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999996666996666996666663333663333663333\
663333666633663333663333666633666633663333666633666666663333663333
663333666633663333663333663333663333333333663333663333663333663333663333663333\
666666663333663333663333663333666633666633666633663333996666996666
996666CC6666CC9966CC9999CC9999FFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCCCC\
FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FF9999FFCC99FF9999
FFCC99CC9999FF9999FF9999CC9999CC9999FF9999FF9999CC9999FF9999CC9999CC9999CC9999\
FF9999FF9999CC9999FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9966CC9966CC9999CC9966CC9966CC9966CC9966CC6666
999966996666996666996666996633996633663333663333663333663333663333663333333333\
333333333333333300333300333300333300333333333333333300333333333333
333333333333333333333333333333333333330000330000330000330000000000000000330000\
333333663333663333663333663333996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC99CC996666996666666666666666663333663333\
663333666633666633663333663333666633666633666633666666666633663333
663333663333663333663333663333663333333333333333663333663333663333663333663333\
663333663333663333663333663333663333663333666633996633663333996633
996666999966CC9966CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCCCC\
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FFCC99CC9999
FF9999CC9999FF9999CC9999CC9999FFCC99FF9999CC9999FF9999CC9999FFCC99FF9999FF9999\
CC9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966\
CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666996666
999966996666996633996633666666663333663333663333663333663333663333663333663333\
333333333333333300333300330000330000333300333300333333333300333333
333333333333330000333333330000330000330000000000000000000000000000000000330000\
333333663333663333663333663333999966FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666996666996666666633663333663333\
663333666633663333663333663333663333663333666633666666666666666633
663333663333666633663333663333663333663333333333663333663333663333663333663333\
663333666633666633663333663333666633666633663333666633666666996633
996633996666CC9966CC9999CC9999CC9999FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FF9999FFCC99FF9999FF9999FF9999
FF9999FFCC99FF9999CC9999FF9999FF9999CC9999FFCC99CC9999FFCC99FF9999CC9999CC9999\
CC9999FFCC99FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966999966996666
996666996666996633666666663333663333663333663333663333663333663333663333333333\
333333333300333300330000330000330000330000330000330000333333333333
333300333333330000330000330000000000000000000000000000000000000000000000333300\
663333663333663333663333663333CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF999999666666666666666666663333663333\
663333663333666633666633663333663333666633663333666633666633666633
663333663333663333663333333333333333663333663333663333333333663333663333663333\
663333663333663333666666666666663333663333663333666633666633663333
666666996666996666CC6666CC9966CC9999CC9999CC9999CCCC99CC9999FFCC99FFCC99FFCC99\
FFCC99FFCCCCFFCC99FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCCCCFFCC99FFCCCCFFCC99\
FFCC99FFCC99FFCC99FFCC99FFCC99CC9999FF9999CC9999CC9999CC9999CC9999
FF9999CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999FF9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9966CC9999CC9999CC9966CC9999CC9966CC9999CC9966CC9999CC9999CC9966CC9999\
CC9966CC9966CC9966CC9966CC9966CC6666CC6666996666996666996666996666
996666996633996633663333663333663333663333663333663333333333333333333333333333\
333300333333333300330000330000330000330000333333333333333333333333
333333333333330000330000000000000000000000000000000000000000330000330000333300\
663333663333663333663333996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999996666996666666633666633666633\
663333663333666633666633663333663333663333663333666633666666666633
663333663333663333663333333333333333333333333333663333663333333333663333663333\
663333663333666633666633666633663333663333663333663333663333666633
663333666666996666996666999966CC9966CC9966CC9999CC9999FFCC99FFCC99FFCC99FFCC99\
CCCC99FFCC99FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCC99FFCCCCFFCCCCFFCCCC
FFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99FF9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999
CC9999CC9999CC9966CC9966CC9999CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966999966CC6666996666996666996666996666996666
996666996633663333663333663333663333663333663333333333333333663333333333333333\
333333333300330000333300330000333300333333330000330000330000330000
330000333333330000330000000000330000000000000000000000000000330000333333663333\
663333663333663333663333999966FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666996666666633666633666633\
663333663333666633666633666633663333663333663333666633666666666633
666633663333663333663333663333663333333333663333333333663333663333663333663333\
663333663333666633666633663333666666663333663333663333663333666633
666633666633996666996666996666996666CC6666CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CCCC99CCCC99FFCC99FFCC99FFCC99FFCC99FFCC99CCCCCCFFCCCCFFCC99
FFCC99FFCC99FFCC99FFCCCCFFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999CC9999
CC9999CC9999CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC6666999966996666996666996666996666996666
996666666666663333663333663333663333663333663333333333333333333333333333333333\
333333333300333300333300333300330000330000330000330000330000330000
000000333333330000000000000000000000000000000000000000330000333300333333663333\
333333663333663333663333CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999996666666666666633666633\
663333663333666633666633666633663333663333663333663333666666666633
663333663333663333663333663333333333333333333333663333333333663333663333333333\
663333663333663333666633666633666633666666663333663333663333663333
663333666633663333996633996633996633996666CC6666CC9966CC9966CC9966CC9966CC9966\
CC9999CC9999CC9999CCCC99CCCC99CCCC99CCCC99FFCC99FFCC99FFCC99FFCC99
FFCC99FFCC99CCCCCCFFCCCCFFCC99FFCC99FFCC99FFCCCCFFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99FFCC99CC9999CC9999CC9999CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9966CC9999CC9999CC9999CC9999CC9999\
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999CC9999
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966996666996666996666996666996666996633996633
996633663333663333663333663333663333663333333333333333333300333333333333333300\
333333330000330000330000330000330000330000330000330000000000330000
330000330000330000000000000000000000000000000000000000330000333333663333663333\
663333663333333300996666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC9999996666996666666666663333\
663333663333663333666633666633666633663333666633663333666633666666
666633666633663333663333663333663333333333333333663333663333333333666633663333\
663333663333663333663333666633663333666633996666666633663333663333
663333663333666666663333996633996666996666996666996666996666CC6666CC6666CC9966\
CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CCCC99
CCCC99FFCC99FFCC99CCCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99FFCC99\
FFCC99FFCC99FFCC99CCCC99CC9999CC9999CC9966CC9966CC9966CC9966CC9966
CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9999CC9966CC9999CC9999CC9999CC9999\
CC9966CC9966CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9966CC9999
CC9966CC9966CC9966CC9999CC9966CC9966CC9999CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966999966CC6666996666996666996633996633996633996633
996633663333663333663333663333663333333333333333333333333333333300333333330000\
330000330000330000333333330000330000330000333333333333330000330000
330000330000330000000000000000000000000000000000330000333333333333663333333333\
663333333333663333CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666996666666666666633\
663333663333663333666633666633663333663333663333663333663333666666
666666663333663333663333663333333333663333333333663333663333333333663333666633\
666633663333663333663333663333666633666633666633996666666633663333
663333663333663333666666666666996666996666996666996666996666996666996666CC6666\
CC9966CC9966CC9966CC9999CC9999CC9966CC9999CC9999CC9999CC9999CC9999
CCCC99CC9999CC9999CC9999CCCC99FFCC99CCCC99FFCC99CCCC99FF9999CC9999FFCC99FFCC99\
FFCC99CC9999CC9999CC9999CC9999CC9966CC9966CC9966CC6666CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9966CC9966CC9966CC9999\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9966CC9999CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC6666999966996666996666996633996633996633996633666666
663333663333663333663333663333663333333333333300333333333333330000333300333300\
330000330000330000330000330000330000330000330000333333333333330000
330000330000000000000000000000000000000000000000330000333333663333333333333333\
663333333333996633FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666996666666666666633\
663333663333663333666633666633666633666633663333663333663333666633
666666663333663333663333663333663333663333333333333333333333663333333333663333\
666633666666666633663333663333666633666633663333666633666633666633
666633663333663333663333663333666633996666996666996666996666CC6666996666996666\
CC9966CC9966CC9966CC9999CC9966CC9966CC9966CC9999CC9999CC9999CC9999
CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99CC9999CC9999FFCC99CCCC99\
CCCC99CC9999CC9999CC9966CC9966996666CC6666CC9966CC6666996666CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9999CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC6666996666996666996666996633996633996633996633996633663333
663333663333663333663333663333333333333333333333333300330000333300333333333300\
333300330000330000330000330000330000330000330000330000330000330000
330000330000000000000000000000000000000000330000333333663333663333333333663333\
333333663333996666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF999999996666666666666666\
666633663333663333663333666633666666666633663333663333663333663333
666666663333663333663333663333663333333333663333333333333333333333663333333333\
333333663333666666666666666666663333666633663333666633666633666633
666633666633666633663333663333663333666633996666996666996666996666996666996666\
996666CC9966999966CC9999CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9999CC9966CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CC9999CCCC99\
CCCC99CC9999CC9966CC9966CC9966999966996666CC6666996666996666996666
996666CC6666CC6666CC9966CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666\
CC6666999966999966996666996633996633996633996633663333996633663333
663333663333663333663333663333663333663333333333333333333300333300333300333333\
333300330000330000330000330000330000330000330000330000330000330000
000000000000000000000000000000000000330000333333333333333333333333333333663333\
333333663333CCCC99FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999966996666666666\
666633663333663333663333663333666633666633663333663333663333663333
663333666666666633663333333333333333663333663333663333333333333333663333663333\
663333663333663333663333663333666666666666666633666633663333663333
663333666666666633666633666666666666666666666666996666996666996633996666996666\
996666999966999966996666996666996666999966999966CC9966999966CC6666
996666996666999966999966996666CC9966CC9966CC9966CC9966CC9999CC9999CC9966CC9966\
CC9999CC9966996666996666996666996666996666996666996666996666996666
996666996666996666996666996666CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC9966
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC9966CC6666CC9966CC6666996666\
996666996666996666996666996666666666996633663333663333663333663333
663333663333333333663333333333663333663333333333333333333300330000330000333300\
330000330000330000330000330000330000000000000000000000000000000000
000000000000000000000000000000000000333333663333663333333333333333333333333333\
666633CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999996666996666\
666666666633663333663333663333666633666633663333663333663333663333
663333666666666633666633663333663333663333663333333333333333663333663333663333\
663333663333663333663333663333666633666666666666666666666666666633
666633663333666666666666663333666666666666666666666666666666666666996666996666\
996666996666996666996666996666996666996666996666999966996666996666
996666996666996666999966996666996666996666999966CC9966CC9999CC9999CC9999CC9966\
CC9966999966999966996666996666996666996666996666996633996666996633
996633996633996666996633996666996666CC6666996666CC6666CC9966CC9966CC6666CC9966\
CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666
996666CC6666CC6666CC6666CC6666CC6666CC9966CC6666CC6666CC6666996666999966996666\
996666996666996666996633996633996633996633663333663333663333663333
663333333333663333333333333333333300333333333333333300333300333300330000330000\
330000330000330000330000330000330000000000000000000000000000000000
000000000000000000000000000000330000663333663333333333333333333333333333663333\
996666FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666996666\
666633666633663333663333663333666633666633663333663333666633663333
663333666666666666663333663333333333333333663333663333663333663333333333663333\
663333663333666633663333666633666666666633666633666633666633666633
666633666633666633666666666666666666666666666666996666666666996666996666996666\
996666996666996666996666996666996666996666996666996666996666996666
996666996666996666996666996666996666996666999966996666999966CC9966CC9999CC9966\
996666996666996666996666996666996666996666996666996666666666996633
996666996633996666996633996633996666996666996666996666996666CC6666CC6666CC6666\
CC6666CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC9966CC6666CC6666
996666996666996666996666996666996666996666996666996666996666996666996666996666\
996666996666996633996633996633663333663333663333663333663333663333
663333663333663333333333333333333333333333333333333300333333330000330000330000\
333333333300330000000000330000000000330000000000000000000000000000
000000000000000000000000000000330000333333333333333333333333333333333333663333\
CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999996666\
666666666633663333663333663333663333666633666633663333666633666633
663333663333666666666633663333663333663333333333663333663333333333663333663333\
663333663333666633666666666633666633666666666666666633666666666633
663333666633666666666666996666996666666666666666666666666666996666996666996666\
996666666666996666996666996666996666996666996666996666996666996666
996666996666996633996666996666996666996633996666996666996666996666996666999966\
996666996666996666996666996666996666996666996666996666996633666666
996633666666996633996666996633996666996633996666996666996666996666996666996666\
996666996666CC6666CC6666CC9966CC6666999966996666999966996666996666
996666996666996666996666996666996666996666996666996666996666996666996666996666\
996666996633666666996633663333663333663333663333663333663333663333
663333663333333333333333333300333300333333333333330000333300330000330000330000\
330000330000330000330000330000000000000000000000000000000000000000
000000000000000000000000330000333333333333333333333333333333333333663333663333\
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC99CC999966\
666666666666666633663333663333663333663333666633663333663333663333
663333663333666633666633663333663333333333663333333333663333663333663333663333\
663333666633666633666666666666666666666633666666666666666666666666
666666666633666666666666666666666666666666996666666666996666996666996666996666\
666633996666996666996666996666996666666666666666663333666666996666
663333996633996666996666996666996633666666996666996633996666996666996666996666\
996666996666996666996666996666996666666666663333666666996633666666
996633663333663333996633996633996633996633996633996633996633996666996666996633\
996666996666996666996666996666996666996666996666996666996666996666
996666996666996666996666996666996666996666996666996666996666996633996633996666\
996633996633996633663333663333663333663333663333663333663333663333
663333333333333300333300333300333333333333333300330000330000330000330000330000\
330000330000000000000000000000000000000000000000000000000000000000
000000000000000000330000333333663333333333663333333333333333663333663333996666\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF999999\
996666666633666633663333663333663333663333666633663333663333663333
666633663333666633666666663333663333663333333333333333663333663333663333663333\
663333666633666633666666666666666666666666666666666633666666666666
666666666666663333666666666666996666996666996666996666996666996666996666996666\
996666996666996666666666996633663333663333666633663333666633996666
663333996666666666996633663333666666996633996666996633996666996666996666996666\
996666996666666666666633666666666666996666666633666633666633666633
996633663333663333663333996633996633996633996633996633996666996633996633996666\
996666996666996633996666996666996666996633996633996633996666996633
996666996633996633996666996633996633996633996666996666996633996633996633996633\
996633666666663333663333663333663333663333663333663333663333663333
663333333333333333333300333300333300333333333300333300330000330000333300330000\
330000000000330000330000000000330000000000000000000000000000000000
000000000000330000330000333333663333663333333333333333333333663333663333999999\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC9999\
996666666633666633666633663333663333663333666633666633663333663333
663333663333663333666666663333663333663333663333663333333333663333663333663333\
663333663333663333666666666666996666996666666666666666666666666633
666666666633663333663333666633666633666633666633666666996666996666996666666633\
666633666666666633666666996666663333663333663333663333666633666666
666633663333663333666666666666666666663333666666663333996633666666996633666666\
996666666666666666666666666666666633666633663333663333663333663333
663333666633663333663333663333663333663333996633996633996633996633996633996633\
996633996633996633996633996666996633996633996633996633996633996666
996633996633666666996633663333663333663333996633996633996666996633996633666666\
663333996633663333663333663333663333663333663333663333663333333333
663333333300333333333333333300330000333300333300333333330000330000330000330000\
330000330000330000000000000000000000000000000000000000000000000000
000000330000330000333333663333333333663333333333333333663333663333663333CCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF\
999999996666666666666633663333663333663333663333666633666633663333
663333666633666633663333666666663333663333663333663333333333663333666633666633\
666633663333666666666666666666666666666666666633666633996666666666
666666666666663333663333666633666666666666666666996666666666996666666633666666\
996666666666663333996633666633663333663333663333663333666633666633
663333663333663333663333666633666633663333663333666633663333663333663333666666\
666666663333663333663333663333666666663333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333663333663333663333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333663333663333333333333333333300333333333333
333333333333333333333300330000330000330000333300333300333333333333330000330000\
330000330000000000000000330000000000000000000000000000000000000000
330000333333333333333333333333663333333333663333663333663333663333CCCCCCFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
999999999966666666666633666633666633663333663333666633666633666633
663333663333666633663333666666666666663333663333663333663333663333666633666666\
666666666633666666666666666666666666666666666666666666666633666666
666666666666666666666633663333663333666633666633666666996666996666666633663333\
666666666633663333666633663333663333663333663333663333663333663333
663333663333663333663333666633666633663333663333663333666666666633663333666633\
663333666633663333663333663333663333663333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333663333663333663333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333663333333333333333333333333333333333333300
333333333333333300330000330000330000330000333333330000333300330000330000330000\
330000330000000000330000000000000000330000000000000000000000330000
333333333333333333333333333333333333663333663333663333663333999966FFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF\
CC9999999999996666666633666633663333663333663333663333666633666633
663333663333663333666633663333666633666633663333663333663333663333663333666633\
996666666666666666666666666666996666996666666666666666666666666666
666633666633663333663333666633666633663333663333663333999966996666663333996633\
666633663333666633663333666633663333663333663333663333663333663333
663333663333663333663333663333666633663333666633663333666633666633663333663333\
666633663333663333663333663333663333663333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333663333663333663333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333663333663333333333333333333333333333333333
333300333333333333330000330000330000330000333300330000330000330000330000330000\
000000000000330000000000000000000000000000000000000000000000333333
333333333333333333333333333333333333663333666633663333996666CCCCCCFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
CCCCCC999999996666666666666633666633663333666633663333663333666633
663333663333663333666633663333666633666633666633666633663333663333663333663333\
666633666666666666666666666666666666666666996666996666666666666633
666633663333666633666633666633666633666633663333666666996666666633663333666666\
663333663333663333996633666633663333663333663333663333663333663333
663333663333663333663333663333666633666633663333663333663333666633663333663333\
663333666633663333663333663333663333663333333333663333663333663333
663333333333663333663333663333663333663333663333663333333333663333663333663333\
663333663333663333663333663333663333663333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333333333333333333300333333333333333300333333
333333333300333333333333330000330000330000330000333333330000330000330000330000\
330000330000330000000000000000000000000000000000000000330000333333
333333333333663333663333333333333333663333666633663333CCCC99FFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
CCCCCCCC9999999999996666666633666633663333666633663333663333663333
666633663333663333663333666633663333663333666666666666666666666633666666663333\
663333666633666666996666666666666633666666666666666666666666666666
666666996666666666666666666666666633666666666633666633996666663333663333666633\
666633663333663333666633666633663333663333663333663333663333663333
663333663333663333663333663333666633666633663333663333663333663333666633663333\
663333663333663333663333663333663333663333333333663333663333333333
333333333333333333663333333333663333663333663333663333333333333333663333333333\
333333663333663333333333663333663333663333663333663333663333663333
663333333333663333663333663333663333333333663333663333663333333333663333663333\
663333333333663333663333333333333333333300333333333333333333333300
333300330000333333333333330000330000330000330000330000330000000000330000330000\
330000000000000000000000000000000000000000000000330000333333333333
333333663333663333333333333333663333663333663333999966FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFCCFFCCCCCC999999999999666666666633666633666633663333663333663333
663333666633663333663333666666663333663333663333666633666666666666666666666666\
666633663333663333666633666666666666666666666666666666666666666633
666633666633666633666633666633666633666633666633996666996633663333663333666633\
663333663333663333663333663333663333663333663333663333663333663333
663333663333663333663333666633663333663333663333663333663333333333663333663333\
663333663333663333333333663333333333663333333333663333663333333333
333333333333333333333333333333333333663333333333333333663333333333663333333333\
333333333333663333663333333333663333663333663333663333663333663333
333333663333663333333333663333663333663333663333663333333333333333663333333333\
333333333333333300333333333333333300333300333300333300333300333300
333333333300330000333300330000330000000000330000330000330000330000000000330000\
330000000000000000330000000000000000000000330000330000333333333333
663333663333333333333333663333333333666666999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFCCFFCCCCCCCC9999CC9999996666666633666633663333663333666633663333
663333666666666633663333666633666666663333663333663333666633666666666666666666\
666666996666666633663333663333666666666633666666666666666633663333
663333663333663333663333666633666633666633663333996666666633663333663333666633\
663333663333663333663333663333663333663333663333663333663333666633
663333663333663333333333666633663333663333663333333333663333333333333333663333\
663333663333333333663333663333663333333333663333333333333333333333
333333333333333333333333333333333333333333663333333333333333333333333333663333\
333333333333333333663333333333333333333333333333333333333333663333
333333333333663333333333333333663333333333333333663333663333333333333333333333\
333333333300333333333333333333333333333300333300333300330000330000
333300333333333300333333330000330000000000330000330000333333330000330000000000\
330000330000000000000000000000000000330000330000333333333333333333
663333333333333333333333663333333300999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFCCFFCCCCCC999999996666996666666633663333663333663333663333
663333663333666633666666663333666633666633666633663333663333663333996666666666\
996666666666666666996666996666663333663333663333666666666666666666
666666666666666666666666663333663333663333663333666666663333663333663333663333\
663333663333663333663333663333663333663333663333663333663333666633
663333663333663333663333663333666633663333663333333333663333663333333333663333\
333333333333663333333333663333663333333333333333333333333333333333
333333333333333333333333333333333333333333333333333333333333333333333333663333\
333333333333333333333333663333333333663333333333663333333333333333
333300663333333300663333333333333300333300663333333333663333333333333333333333\
333333333333333333333300333333333333333333333300330000330000330000
330000330000330000330000330000000000000000330000000000330000330000000000000000\
000000330000000000000000330000330000333333333333333333333333333333
330000333333663333333333333333999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFCCCCCCCCCCCC999999996666666666666633663333663333666633
666633663333663333666666663333663333663333663333666633663333663333666666666666\
666666666666666666666666666666666666663333663333663333663333666666
666666996666996666666666666666663333663333663333663333333333663333663333663333\
663333663333663333663333663333663333663333663333663333663333666633
663333663333333333663333333333666633663333333333333333663333333333333333663333\
333333333333333333663333333333333333333333333333333333333333333333
333333333333333333333300333333333333333333333333333333333333333333333333333333\
333333333300333333333333333333333333333300663333333333333333333333
333300333300333333333333333333333300333300333300333333333333333333333333333333\
333333333300333333333333333300333333333333333333333333333333333333
330000330000330000330000330000330000330000330000000000000000000000330000000000\
000000000000330000330000333333333333333333333333333333663333333333
333333663333333333663333996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFCCFFCCCCFFCCCCCC999999996666666633663333663333663333
666633663333663333666633663333663333663333663333666633666633663333663333663333\
666633666666666666666666666666666666666666666666666666666666666666
663333663333663333663333663333663333663333666633666633333333663333663333663333\
663333663333663333663333663333663333663333663333663333663333663333
333333663333663333663333333333663333663333333333333333333333663333333333333300\
333333663333333333663333333333333333333333333333333333333333333333
333333333333333300333333333300333333333300333333333333333333333333333333333333\
333333333300333333333333333333333333333300333333333333663333333333
333333333300333300330000333333333300333300333300333333333333333333333300333333\
333333333333330000330000333333333333333333333333333300333333333333
333300330000330000330000330000000000330000330000000000000000000000000000330000\
330000000000330000333333333333333333333333333333663333333333663333
6633336633336633339966669999CCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFCCCCCCCCCCFFCCCCCC999999663333663333663333663333
666633666633666633663333666633663333663333663333663333663333666633663333663333\
663333663333666633666666666666666666666666666666666666666666666633
666633666633666633666633663333663333666633666633663333663333663333663333663333\
663333663333663333663333333333333333663333663333663333663333663333
333333663333333333663333663333663333663333663333333333333333333333333333663333\
333333333333333333333333663333333333333333333333333333333333333333
333333333333333333333333333300333300333333333300333333333333333333333333333333\
333333333333333300333333333333333333333333333300333333663333333333
330000333333333300330000333300333333333300333300333333333333333333333333333300\
333333333300333333330000330000333333333333333300333333333300333333
333333330000330000000000330000330000330000330000000000000000000000000000330000\
330000333333333333333333333333333333333333663333333333333333333333
663333663333996633CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCC9999666666666633663333663333
663333666633666666666633666633666633663333663333663333663333663333663333666666\
666666666633666633666633663333666633666666996666666666666666666666
666666666666666666666666663333663333663333663333663333333333663333663333663333\
663333663333663333663333333333663333333333663333663333663333663333
663333333333333333663333333333333333663333333333333333333333333333333333333333\
333333333333333333663333333333663333333333333333333333330000333333
333333333333333300333333333333333300330000330000333333333333333333333333333333\
333333333333330000333300333333333333333333333333333300333333333333
333333330000333333333333333300333333333333333300333300333333333333333300333300\
333333330000330000330000330000330000333333333333330000330000330000
330000330000000000000000000000330000000000000000000000000000000000330000330000\
330000333333333333333333333300333333663333333300333333663333663333
663333663333999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCCCCCCCC996666666666663333663333
663333666633666633663333666633666666666633663333663333663333666633663333663333\
666633666666666666666633663333663333663333663333666666666666666666
666666666666996666666666663333663333663333663333663333663333663333663333663333\
663333663333663333663333333333663333333333663333333333663333663333
663333333333333333333333663333333333333333333333333333333333333333333333333333\
663333333333333333333333333333333333333333333333333333333333330000
333333333333333333333333330000333333330000330000330000333333333333333333333333\
333333333300333300330000333300333333333333333333333333333300663333
333333330000333333333333330000330000333333333333330000333333333333333333333300\
333333330000330000333333333333330000330000330000330000330000330000
000000330000000000330000330000330000000000000000000000000000330000330000330000\
333300333333333333333333333333663333333333333333663333663333663333
663333996666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC999999996666666633663333
663333663333663333663333663333666666666666666633663333666633666666663333663333\
663333663333666633666666666666666666666666663333663333663333663333
663333666633666666666666663333663333663333663333663333333333333333663333663333\
663333663333663333663333333333663333333333663333663333333333663333
663333333333663333333333663333333333333333663333333333333333333333333333333333\
333333330000333333333333330000333333333333333333333333333333333333
330000333333333333333333333333333300330000330000330000330000333333333300333300\
333333333333333333330000330000330000330000333300333333333333333300
663333330000330000333333333333330000333300333333333300333333333333333333330000\
330000330000330000330000330000330000330000330000330000000000330000
330000330000330000000000330000330000000000000000000000330000333333333300333333\
333333333333330000333333663333333333663333333333333333333300663333
996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF999999996666666666666633
663333663333663333663333663333663333666666666666666633663333663333666666663333\
663333663333666633666666666666666666666666666666666633663333663333
663333666666666666666666663333663333663333663333663333333333663333333333333333\
663333663333663333663333333333663333333333663333333333663333333333
333333333333333300333333333333333333333333663333333333333333333333333333333333\
333333333333330000333333333333333333333333333333333333333333333333
330000330000333333330000333333330000330000330000330000330000333333333333333333\
333333333333333333330000330000330000330000330000333300333333333333
333333333333330000333333333333330000330000333333333333333300330000333333330000\
330000330000330000330000330000330000330000330000330000330000000000
330000000000000000330000330000000000000000000000330000333333333333333333333333\
330000330000333333663333333333333333333333333300333333663333996666
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999999999996666666666
666666663333663333666633666633663333663333663333666666663333663333663333663333\
666633663333663333663333663333666666666666666666666633663333663333
663333663333663333333333663333663333666633663333663333333333663333333333333300\
333333333333333333663333663333333333663333333333333333663333333333
333333663333663333333300333333663333333333333333663333333333333333663333333333\
330000333333333333333333330000333333333333333333333333333333333333
333333330000330000330000330000330000330000330000330000333333330000330000333333\
333333333333333333333333333333330000330000330000330000330000330000
333333333333333333330000330000333333333333330000330000333333330000330000333333\
000000330000330000000000330000330000000000000000000000000000000000
000000000000000000000000330000333333333333333333333333333333330000330000333300\
333333663333333333663333333333333300663333663333996633996666CCCCCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCC9999999966996666
996666666666663333663333666633666633663333663333666633666666666633663333663333\
663333663333663333663333666633663333663333663333666633666633666633
663333663333663333333333663333663333663333663333663333333333663333333333333333\
333300333333333300333333333333333333333333333333333333333333333333
333333663333663333333333333333663333333333333333333333333333333333333333333333\
330000333333333333333333330000333333333333333333333333333333333333
330000330000330000330000330000330000333333333333330000333333330000330000330000\
330000333333333333333333333333330000330000330000330000330000333333
333333333333333333333333330000330000333333333333333333330000333333330000330000\
330000330000330000000000000000330000000000000000000000000000000000
000000000000330000333333333333333333333333333333333333330000330000333333333333\
333333333333663333333333333333663333663333996633996666996666FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999996666
996666666666666633663333666633666633666633663333663333663333666666663333666633\
663333663333663333663333663333666666666633666633663333663333663333
663333333333333333333333663333663333663333663333663333333333333333333333333333\
333300333333333333663333333333333333333333333333333333333333333333
333333333333663333333333333300333333663333330000333333333333333333333300333333\
333333333333333333333300330000330000330000330000333333333333330000
333333330000330000330000330000333333330000330000333333333333330000330000333333\
333333333333333333333333333333333333000000330000000000330000333333
333333330000333333333333333333330000333333333333333333333333330000330000000000\
330000000000000000000000000000330000000000000000000000000000000000
330000333333333333333333333333333333333333330000330000333333333333333333333333\
333333663333333333333333663333663333996633996666996666996666FFFFFF
FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999
996666996666666666666633663333666633666633666666663333663333666633663333666633\
666633666666666633666633666633666633666666666666666666666666663333
663333663333663333333333663333663333666633663333663333663333333333333333333333\
333300333333333333333333333333333333663333333333333333333333333333
333333333333663333333333330000333333333333330000330000333300333333330000333333\
333333330000333333333333333333330000333333330000330000333333333333
333333330000330000330000330000330000330000330000333333330000333333330000330000\
333333333333333333663333333333333333333333000000330000330000000000
333333333333333333333333333333333333330000330000333333333333330000330000000000\
000000000000000000000000000000000000000000330000330000330000333333
333333333333333333333333333333333333333333333300333333333333333333663333663333\
663333333333663333663333663333663333996633996666996666CC9999FFFFCC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF9999CC
999999996666996666666666663333663333666633666633663333663333663333666666663333\
663333666633666666666666666633666633666633663333663333663333666633
666633663333333333333333663333663333663333663333663333333333333333333333333333\
333333333333333300333300333333333333333333333333333333333333333333
333333333333333333333333330000333333333333333333333300330000333333333333330000\
330000333333330000333333333333333333330000333333000000333333333333
333333333333330000000000000000330000330000333333330000333333333333330000330000\
333333333333333333333333663333333333333333333333330000330000330000
330000333333333333333333333333333333333333333333330000330000333333333333333333\
333333330000330000330000330000333333330000333333333333333333333333
333333333333333333333333330000333333333333333333333333663333333333333333333333\
333333663333663333663333663333996633996666996666999999CCCCCCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF
CC9999999999996666666666666633663333663333666633666633666633663333666633666633\
663333663333663333666633666666666666666633666633663333663333663333
663333663333663333333333333333663333666633663333663333333333333333333333333333\
333300333333333300333333333333333333333333333333333333333333333333
333300333333333300333333330000330000333333333333333333333300330000333333333333\
330000330000333333333333333333330000330000333333330000330000333333
333333333333330000330000330000330000330000330000330000330000333333333333330000\
333333333333333333333333663333333333663333333333333333330000330000
330000330000333333333333333333333333333333333333333333333333333333333333333333\
333333333333333333333333333333333333333333333333333333333333333333
333333333333333300333333330000333333333333333333333333333333333333333333333333\
663333663333663333663333996633996666996666996666CC9999FFCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF9999CC999966996666666666666633663333666633663333666633666633663333666633\
666633666633666666663333663333666666666666666666666633666666666666
666666663333663333663333663333666633663333663333663333333333333333333333333333\
333300333333333333333333333300333333333333333333333333333333333333
333333333300333333333333333333330000333300333333333333333333330000333300333333\
333333333333330000330000333333333333330000330000333333000000330000
333333333333333333000000000000330000330000330000330000333333333333333333330000\
330000333333333333333333663333666666333333666666663333333333333333
330000333333333333333333330000330000333333333333333333333333333333333333333333\
333333333333333333333333333333333333333333333333663333333333663333
333333333333330000330000333333663333663333663333333333333333333300663333663333\
663333663333663333996633996633996666996666999999CCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCC999999996666996666666666666633666633663333666633663333663333\
663333666633666633666666666666666666666666666666666666666666666633
666666666666666633663333663333666633663333663333663333333333333333663333333333\
333333333333333333333333333333330000333333333333333333333333333300
333333333300333300333333333333330000330000333333333333333333330000333333333333\
330000330000333333330000333333330000330000330000330000330000000000
330000333333333333333333330000000000000000330000330000330000330000333333333333\
333333333333333333333333333333663333666666666666333333663333666666
666666333333333333333333333333333333333333333333330000333333333333330000333333\
333333333333333333333333333333333333333333333333333333333333333333
333333333333663333663333663333663333333333333333663333663333663333663333663333\
663333663333666666996633996666996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCCC996666996666996666666666666666663333666633666633666633\
663333663333666633666633663333666666666666666666666633663333663333
663333663333663333663333663333666633666633663333663333663333663333333333333333\
333333333333333333333300333300333333333333333333333333333333333300
333300333333333300333300333333333333330000333333333333333333330000330000333333\
333333330000333333333333330000333333330000330000330000333333000000
330000330000333333333333330000330000000000000000000000330000330000333333333333\
333333333333333333333333333333333333663366666666666666663366333333
663333666633666633333333663333333333663333333333333333333333333333333333330000\
333333333333333333333333333333333333333333330000333333663333333333
663333663333663333663333333300333333663333663333663333663333663333663333663333\
663333663333996633996666996666CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF996666996666996666996666666666666666666633666633666633\
663333663333663333663333663333666633666633666666666666666666666666
666666666666663333663333663333663333666666663333663333663333663333663333663333\
333333333333333333330000330000333333333300333333333333333333333333
333333333333330000333333333300333333330000330000333333333333333333330000333333\
333333330000330000333333330000333333330000330000330000333333330000
330000330000333333333333330000330000330000330000000000000000330000330000330000\
333333663333333333333333333333333333663333666666666666666666666666
333333663333333333333333333333663333333333333333663333663333333333333333333333\
333333333333333333333333333333333333333333663333333333663333663333
663333663333333333333333663333663333663333663333663333663333663333663333663333\
663333996633996666996666999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999996666996666996666996666666666666666666633\
663333663333663333663333663333663333663333666633666633666633666633
666633666666666666666666666633663333666633663333663333663333663333333333663333\
663333333333333333330000330000333300330000333333333333333333333333
333300333300333333333300333333333333333333330000333333333333333333330000330000\
333333330000000000330000333333330000333333330000330000330000333333
330000330000333333333333333333330000000000330000330000000000000000000000330000\
330000333333666633663333333333663333333333333333663333666666666666
666666666666663333333333333333333333663333333333663333333333333333333333333333\
333333333333333333333333663333663333663333663333663333333333333333
333333663333663333663333663333663333663333663333663333666633663333663333666666\
996666996633996666999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC996666996666996666996666666666666666666666\
666666666633663333663333663333663333666633666633666633666666666666
666666666666666633666633666666666666663333663333663333663333663333663333663333\
663333333333333333333333330000330000333333333333333333333333333333
330000333333333300330000333300330000333333330000333333333333333333330000330000\
333333333333330000330000330000333333333333333333330000330000330000
330000330000330000333333333333330000330000330000330000330000330000330000330000\
000000000000333333666666666666663333663333663333333333333333666633
666666666666666666666666666666666666663366663333663333663333663333666633666666\
663333663333663333663333663333663333333333333333333300333333663333
663333663333663333663333663333663333663333663333666633663333663333663333996633\
996633996666999999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999996666996666996666666666666666\
666666666666666633663333663333663333663333666666666666666666666666
666666666666666666666666666666666666666633663333663333663333663333663333663333\
663333663333333333333333333333330000330000333333333333333333333333
333300330000333333333333333333333300333333330000330000333333333333330000330000\
333333330000333333330000330000330000333333333333330000330000330000
330000330000333333333333333333333333330000330000330000330000330000330000333333\
330000330000330000333333663333666633666666666633663333333333333333
333333333333663333663333663333666666666666666666666666666633666633666633663333\
663333663333663333333333333333333333663333663333663333663333663333
663333663333663333663333663333663333663333666633663333663333663333663333996633\
996633996633CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999996666996666666666666633\
666633666633666633666633666633663333663333663333666633666633666666
666666666666666666666666666666666666666666666666663333663333663333663333663333\
663333663333333333663333333333333333330000333333333333333333333333
333333333333333300333300333333333333333300330000330000333333333333333333330000\
330000330000330000330000000000330000333333333333330000330000330000
330000330000330000333333333333333333333333330000000000330000330000330000333333\
333333333333333333330000333333333333666666663333663333663333666666
666666663333663333333333333333333333333333333333333333333333333333663333663333\
663333663333663333663333663333663333663333663333663333666633663333
663333663333663333663333663333663333663333663333663333663333663333996633996666\
996666996666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF999999666666666666\
666666666666666633663333663333666633666633666633666666666633666666
666666666666666666666666666666996666666666666666666666663333663333663333663333\
663333663333663333663333663333663333663333333333333333333333333333
333333333333333333333333333333333333333333333333330000330000333333333333333333\
333333330000330000333333330000330000330000333333333333330000330000
330000333333330000333333333333333333333333333333333333333333330000333333333333\
333333333333333333333333333333333333333333333333333333663333663333
663333663333333333663333663333666633663333666633666666666666666633666633666633\
666666666633666633663333663333663333663333663333663333663333663333
663333663333663333663333663333663333663333663333996666996666996666996633999966\
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF996666996666\
666666666666996666666666666633663333666633666633666666666666666666
666666666666666666666666666666666666996666666666666666663333663333663333663333\
663333663333663333663333663333333333333333663333663333333333333333
663333333333333333333333333333333333333333333333333333330000330000333333333333\
333333330000330000333333333333333333330000330000333333333333330000
330000333333333333333333333333333333333333333333333333333333333333333333333333\
333333333333333333333333333333333333663333663333333333333333333333
663333666666663333333333333333333333333333333333333333333333333333333333333333\
663333333333333333333333333333333333333333333333663333663333663333
663333663333663333663333663333663333996633996633996666996666996666996666CCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999CC996666\
996666666666666633666666666633666633666633663333663333666633666666
666666666666666666666666996666996666999999999999999999666633663333663333663333\
663333663333663333663333333333663333663333333333663333663333333333
663333663333663333663333333333333333333333333333333333333333330000333333333333\
333333333333330000330000333333333333333333330000333333333333333333
330000333333333333333333333333333333333333333333333333333333663333333333333333\
333333333333333333333333333333333333333333333333333333663333333333
333333333333663333666633663333333333333333333333333333333333333333333333333333\
333333663333333333663333663333333333663333663333663333663333663333
663333663333663333663333666666663333996633996666996666996633996666CCCCCCFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC9999\
996666996666666666666633663333666633666633666633666633666633666633
666666666666666666666666996666996666999999999966996666666633666633663333663333\
663333663333663333663333663333663333663333663333333333663333663333
663333663333663333663333663333663333333333333333333333663333333333333333663333\
333333333333333333333333333333333333333333333333333333333333333333
333333330000333333333333663333333333333333333333333333333333333333666666333333\
333333333333663333666666663333333333333333333333333333333333333333
333333333333333333333333663333663333663333663333333333333333663333663333663333\
663333663333663333663333663333663333663333663333663333663333663333
663333663333663333666633663333996633996633996666996666999999CCCCCCFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
CCCCCC999999996666666666666666663333663333666633666633666633663333
663333666666666666666666666666996666996666996666996666666666666666666666663333\
663333663333663333663333333333663333333333663333333333333333333333
663333663333663333663333663333663333333333663333333333666666666666333333333333\
333333333333330000333333333333663333333333333333333333333333333333
333333333333333333330000663333663333333333333333333333666666333333333333663366\
333333333333333333663333666666666666666633663366666666663333663333
333333333333333333333333333333333333333333663333663333663333663333663333663333\
663333663333663333663333663333663333663333663333663333663333666633
663333663333996633996633996666996666996666996666CC9999FFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFCCCCCC999999996666996666666633663333663333663333663333666633
666633666666666666666666996666996666996666996666996666999999996666996666666666\
663333663333663333663333663333663333663333333333663333663333663333
663333663333663333663333663333663333663333663333663333333333666666663366333333\
333333333333333333330000333333333333663333333333663333333333333333
333333663333333333333333663333666666663333666666333333663333666666663366666633\
666666666666333333333333333333663333666666666666666666666666663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333663333663333666633666633666666666633666633663333
663333666666996633996666996666996666996666996633FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFCCCCCC999999999999666666666633666633663333663333663333
663333666633666666666666666666996666996666999999999999999999996666666666666666\
666666666633663333663333663333663333333333663333663333663333663333
333333663333663333663333663333666633666633663333663333663333333333666633333333\
333333333333333333333333330000333333333333663333663333663333663333
666666663333666633663366663333666666666666663333666633663333663333666666663333\
663333996666666666666633333333333333333333663333663333663333663333
663333663333663333663333663333663333663333663333663333663333663333663333663333\
663333663333663333666633666633996633666666666633663333663333663333
663333996633996666996666996633663333666633CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFCCFFCCCCCC996666996666666666666633663333663333
663333663333666666666666666666666666996699999999996666999999999999999999996666\
666666666666666666666633666633666666666633663333333333663333663333
663333333333333333663333666666663333666666663333666633666666663333663333666666\
333333663333333333663333333333333333333333663333663333666666663333
663333663333666633666666666666666666666666666666666666666666663333663333666666\
666666666666666666666666666666666666663366666666663333666633666633
663333663333663333663333666633666633666633666633666633666633666633666666666666\
663333663333666633996633663333663333663333663333663333663333996633
996633996666996666663333663333996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC999999996666996666666666
666666666633996666666666666666666666666666666666666666996666666666996666999999\
999999996666666666996666666666996666996666996666996666996666666666
666666666633663333663333663333666633666633663333666666666666666666666666663333\
666666666666666666666666663333666666663333333333333333666666666666
663333666633666666666633666666666666666666666666666666666666666666663366663333\
663333663333663333666633666666666666666633663333666633663333663333
666633663333663333666633666633663333663333663333663333663333663333663333663333\
663333663333663333663333996633996633996633996666996633996633996633
666666663333666666CC9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFCCCCCC999999996666996666
666666666666666666666666666633666633666666666666666666996666996666999999666666\
996666996666996666996666996666996666996666996666996666996666996666
996666996666666666666666663333663333666633666633666666666666666666666666666666\
666666666666666666996666666666666666666666663333333333333333666666
663366663333663333663333663333663333666666666666666666666666666666666633666633\
666666666633666666663333663333666633666633666666666666666666666633
666633666633666633663333663333663333663333663333663333663333663333666633666633\
663333996633666666996666996633996633996666996666996633666666996633
663333996666CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFCC99CCCC9999
999999996666666666666666666666666666666666666666666666996666996666996666996666\
996666999999999999996666996666996666996666996666996666996666996666
996666996666996666996666996666996666666666666633666633666633666666666666996666\
666666666666666666666666666666666666666666666666666666333333663333
663333663333663333663333663333663333666666666666666666996666666666663333666633\
666633666633666633666633666666666633666633663333666633663333663333
663333663333663333663333663333663333663333663333663333666633663333666633996633\
666633996666996633996666996666996666996666996633996633663333663333
666633CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC
CC9999996666666666996666666666666666666666666666666666996666996666996666999999\
996666996666996666996666996666996666996666996666996666996666996666
996666996666996666996666996666996666996666996666666666666666666666666666666666\
996666996666666666666666666666666666666666666666666666663366663333
663333663333663333663333333333333333663333663333663333663333666666996666666633\
666633666633663333666633663333663333663333663333663333663333663333
663333663333663333663333663333663333663333666633996633666633666666996633996666\
996666996633996666996633996666996666996633663333663333663333996666
CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCCFFCCCCCC999999996666666666666666666666666666666666666633666666996666996666\
996666996666996666999999996666996666996666996666996666996666996666
996666996666996666996666996666996666996666999966996666996666996666996666666666\
666666996666996666996666996666666666666666996666996699666666666666
663333666633663333663333663333663333333333333333333333333333663333663333996666\
666666663333663333663333663333663333663333663333663333663333663333
666633663333663333663333663333666633663333996633663333996633996633996666996666\
996666996666996666996666996666663333663333663333996666999999FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCCC999999996666666666666666666666666666666666666666996666666666\
996666996666999999999999996666996666996666999999996666996666996666
996666996666996666996666996666999999996666996666999999999966996666996666996666\
666666996666996666996666999999999999666666666666996666996666666666
666666666666666633663333663333663333663333663333663333663333663333663333663333\
666666666666666666666666666633663333666633666633663333666633663333
996633666666666633666633996633666633666666996666996666996666996666996666996666\
996666996666996666996633663333663333996666999999CCCCCCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999999999996666996666996666666666666666666666\
666666996666996666996666666666996666996666666666996666999999999999
996666996666996666996666996666996666996666996666996666999999996666999966999966\
996666996666996666996666996666999999999999996666996666996666996666
666666996666996666996666666666666666666666666666666666666666666666666666666666\
666666666666666633666633666666666666666633666666663333666633666666
666633666633996633996666996666996666996666996666996666996666996666996666996666\
996666996633663333663333996666999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF999999666666666633663366\
666666666633666633666666666666666666999999999999999999996666999999
999999999966999999999966999999999999996666996666996666996666996666996666999966\
996666996666996666996666996666996666996666996666996666999966999999
996666996666996666996666996666996666996666996666996666996666996666996666996666\
996666996666996666996666996666996666996666996666996666996666996666
996666996666996666996666999966996666999966996666996666999966666633663333663333\
663333996666999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCCC999999999999\
666666666666666666666666666666996666996666999999999999999999999999
999999999999999999999999999999999999999999996666996666996666996666996666999999\
996666996666996666996666999999999999999966999999999999996666996666
996666996666999999996666996666996666996666996666996666996666996666996666996666\
996666996666996666996666996666996666996666996666996666999966CC9966
CC9966CC9966CC9966999966999966CC9966999966996666996666666666666633996666996666\
999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFF\
CCCCCC9999CC999999996699996666996699996699999999CC9999999999CC9999
CCCCCCCC99CCCC9999999999CC9999999999CC9999999999999966999999999966999966996666\
996666666666996666996666996666999966999966999999999966999966999999
999966999966999966999966996666996666996666996666999966996666996666996666996666\
996666996666996666996666996666996666999966999966999966999966996666
996666996666996666996666996666666633666633666633666633996633996666996666CCCCCC\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFCCFFFFCCFFFFCCFFFFFFFFCCCCCCCCCCCCCCCCFFCCCCCC
FFCCFFCCCCFFCCCCCCCC9999CCCCCCCCCCCC9999999999CCCC9999999999999999999999999999\
999999999966996666996666996666996666996666996666996666996666CC9966
999999999999999999999966999966999966996666996666996666996666996666996666996666\
996666996666996666996666996666996666996666996666996666996666996666
996666996666996666666666666633666633666633666633996666996666CCCCCCFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFF
FFFFFFFFFFFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFCCCCCCCC9999999999999999999999\
CC9999999999996666996666999966996666996666996666996666666666996666
996666996666996666999966996666999966999966996666996666996666996666996666996666\
996666996666996666996666996666996666996666996666996666996666996666
9966669966669966669966339966669966669966669999999999CCCCCCCCFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCFFFFCCFFCCCCFFCCCCCCCCCCCCCCCCFFCCCCCCFFFFFFFFCCFFCCCCCCCC9999999999\
999999999999999999999999999999999966996666999966999966996666996666
996666996666996666996666996666999999999966999999999966996666996666996666996666\
996666996666996666996666996666996666996666996666996666666666666666
666666666633666633996666999999CC99CCCCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFCCFFFFFFFFFFFFFFFFFFFFCCCCCCCCCCCC\
CCCCCCCCCCCCCC9999999999999999999999CC9999999999999999999999996666
996666996666996666999966996666996666996666996666996666999999999966996666996666\
996666996666996666996666996666996666666666996666666666666666996666
996666996666999999CCCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCFFFFCCFFCCCCCCCCCCCCCCCCCC9999CC
CC9999CC9999CC9999999999999999999999999999999999999999996666996666999999999999\
999999999999999999CC9999999999CCCCCCCCCCCCCCCCCCFFFFFFFFCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFCCFFFFCCFFFFCCFFCCCCFFCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCFFCCFFFFFFFF\
FFCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF\
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00J@3oool`0?o<c0T0olbI00<0c<bI0?o<V@3<VIT0
0P3oc9TV0<bIV@030?ooc03oool0oooo0500oooo001Y0?oooc00olc<1`3oc9T0103<c9T0olbI0?o<
V@3oc9T50<bIV@030<c<V@3<VIT0c9VI00H0c9VI00<0c<bI0<bIV@3<VIT05`3<VIT00`3oc9T0oooo
0?ooo`1A0?ooo`00J@3oool00`3ool`0olc<0?o<c00Y0?o<c0h0olbI:@3<VIT00`3oc<`0oooo0?oo
o`1A0?ooo`00J@3ooolZ0?o<c0T0olbI00@0c<bI0?o<V@3<c9T0olbI103<c9TW0<bIV@030<c<V@3o
ool0oooo0580oooo001Y0?ooo`030?ooc03oc<`0olc<02D0olc<0`3oc9T01@3<c9T0olbI0?o<V@3o
c9T0c<bI0080olbI00@0c<bI0?o<V@3oVIT0c<bI;03<VIT00`3<c<`0oooo0?ooo`1B0?ooo`00J@3o
oolU0?o<c0P0olbI00H0c<bI0?o<V@3oc9T0olbI0<c<V@3oVIT20<c<VBd0c9VI00<0olc<0?ooo`3o
ool0DP3oool006T0oooo9P3oc<`00`3<c<`0olbI0<c<c0020?o<V@050<c<V@3oc9T0olbI0<c<V@3o
c9T01`3<c9TZ0<bIV@030<c<V@3oool0oooo05<0oooo001Y0?ooo`030?ooc03oc<`0olc<01d0olc<
00D0c<c<0?o<c03oc<`0olc<0<c<c0080?o<V@050<c<V@3oVIT0c<bI0<bIV@3<c9T00P3<VIT50<c<
VBP0c9VI00<0c<c<0?ooo`3oool0D`3oool006T0oooo703oc<`01`3<c<`0olc<0?o<c03oc<`0c<c<
0?o<c03<c<`0103oc9T01P3<c9T0oiVI0?o<V@3oVIT0c9VI0<c<V@<0c9VI00@0c<bI0<bIV@3<c9T0
c9VI1@3<c9T0103<VIT0c<bI0<bIV@3<c9TS0<bIV@030<c<V@3oool0oooo05@0oooo001Y0?ooob80
olc<1`3oc9T20?nIV@030?o<V@3oVIT0oiVI00L0c9VI00@0c<bI0<bIV@3<c9T0c9VI0`3<c9T00`3<
VIT0c<bI0<c<V@0Q0<bIV@030?o<V@3oool0oooo05@0oooo001Y0?oooah0olc<00<0c<c<0?o<c03o
c<`01@3oc<`00`3oc9T0olc<0?o<V@050?o<V@<0oiVI2`3<VIT01P3<c9T0c9VI0<bIV@3<c9T0c9VI
0<c<VAh0c9VI00<0c<c<0?ooo`3oool0E03oool006T0oooo6`3oc<`20<c<c0d0olc<1P3oc9T01@3o
VIT0c9VI0<bIV@3<VIT0oiVI00<0c9VI00@0olbI0?nIV@3<c9T0oiVI1@3<VIT30<c<VA`0c9VI00<0
olc<0?ooo`3oool0E03oool006T0oooo:@3oc<`00`3oc9T0olc<0?o<V@040?o<V@<0oiVI0`3<VIT2
0?nIV@050?o<V@3oVIT0oiVI0?nIV@3<c9T01`3<VIT20<c<VAX0c9VI00<0ooo<0?ooo`3oool0E03o
ool006T0oooo6P3oc<`00`3<c<`0olc<0?o<c00?0?o<c0H0olbI1@3oVIT40?o<V@<0oiVI203<VIT0
0`3<c9T0c9VI0<bIV@0F0<bIV@030<c<V@3oool0oooo05D0oooo001Y0?ooob/0olc<203oc9T0103o
VIT0olbI0?nIV@3oVIT70?o<V@80oiVI1`3<VIT00`3<c9T0c9VI0<bIV@0E0<bIV@030?o<V@3oool0
oooo05D0oooo001Y0?ooob`0olc<303oc9T00`3oVIT0olbI0?o<V@050?o<V@030?nIV@3<VIT0c9VI
00H0c9VI0P3<c9TD0<bIV@030<c<c03oool0oooo05D0oooo001Y0?ooob`0olc<3P3oc9T00`3oVIT0
olbI0?o<V@020?o<V@<0oiVI0P3<VIT00`3oVIT0c9VI0<bIV@030<bIV@80c<bI4P3<VIT00`3<c9T0
ooo<0?ooo`1F0?ooo`00J@3oool]0?o<c1<0olbI0`3oVIT80<bIV@80c<bI4@3<VIT00`3<c9T0oooo
0?ooo`1F0?ooo`00J03oool00`3ool`0olc<0?o<c00/0?o<c0050?o<V@3oc<`0olbI0?o<V@3oc<`0
3@3oc9T40?nIV@030<bIV@3oVIT0c9VI00D0c9VI0`3<c9T?0<bIV@030?o<c03oool0oooo05H0oooo
001X0?oooc<0olc<1@3oc9T00`3oc<`0olbI0?o<V@060?o<V@@0oiVI2P3<VIT00`3<c9T0c9VI0<bI
V@0=0<bIV@030<c<c03oool0oooo05H0oooo001X0?oooc<0olc<00<0olbI0?o<c03oc<`02`3oc9T5
0?nIV@T0c9VI0P3<c9T>0<bIV@030?o<c03oool0oooo05H0oooo001X0?oooa`0olc<00<0ooo<0?o<
c03oc<`06@3oc<`80?o<V@030?nIV@3oc9T0oiVI00D0oiVI1`3<VIT00`3<c9T0c9VI0<bIV@0=0<bI
V@030<c<c03oool0oooo05H0oooo001W0?ooobL0olc<00<0ooo<0?o<c03oc<`03`3oc<`80?o<V@T0
oiVI1`3<VIT0103<c9T0c9VI0<c<V@3<c9T:0<bIV@030<c<V@3oool0oooo05L0oooo001W0?ooo`03
0<c<V@3oc<`0olc<03@0olc<00<0olbI0?o<c03oc9T01`3oc9T70?nIV@T0c9VI0P3<c9T20<bIV@80
c<bI203<VIT00`3<c9T0oooo0?ooo`1G0?ooo`00I@3oool00`3oc?l0c9VI0<c<V@0f0?o<c0/0olbI
00D0oiVI0?o<V@3oVIT0oiVI0<bIV@030?nIV@030<bIV@3oVIT0c9VI00D0c9VI00<0c<bI0<bIV@3<
VIT00P3<c9T80<bIV@030<c<V@3oool0oooo05L0oooo001T0?ooo`040?o<o`3<VIT0VIUV0?o<VCH0
olc<0`3oc9T00`3oc<`0olbI0?o<V@040?o<V@<0oiVI00H0c<bI0?nIV@3<VIT0oiVI0<bIV@3oVIT=
0<bIV@030<c<V@3<VIT0c9VI00D0c9VI00<0olbI0?ooo`3oool0E`3oool006@0oooo00@0c9VI09UV
IP2IIVH0olbI=P3oc<`;0?o<V@X0oiVI2`3<VIT20<c<V@H0c9VI00<0olc<0?ooo`3oool0E`3oool0
06<0oooo00D0c<c<06IV<`1V<c<0VIUV0?o<V@0f0?o<c0`0olbI0`3oVIT30<bIV@030?nIV@3<VIT0
c9VI00`0c9VI0P3<c9T50<bIV@030<c<c03oool0oooo05L0oooo001R0?ooo`050<c<o`2IIVH0IS<c
06Hc<`3<VFH0=P3oc<`?0?o<V@050<bIV@3oVIT0c9VI0<bIV@3oc9T00P3oVIT<0<bIV@<0c<bI103<
VIT00`3oc<`0oooo0?ooo`1G0?ooo`00HP3oool01`2IVIT0IS<c06Hc<`1V<c<0VFIV0?o<c03<c<`0
=03oc<`=0?o<V@070?nIV@3oc9T0oiVI0<bIV@3oVIT0c9VI0?o<V@020<bIV@030?nIV@3<VIT0c9VI
00X0c9VI0`3<c9T30<bIV@030?o<c03oool0oooo05L0oooo001P0?ooo`070<bIV@1VIS<0IS<c06Hc
<`0c<`00VFIV0<c<V@0^0?o<c080olbI00<0olc<0?o<V@3oc<`0403oc9T20?nIV@060<bIV@3oVIT0
oiVI0?nIV@3<c9T0oiVI403<VIT01@3<c9T0olbI0<c<V@3<VIT0ooo<05T0oooo001P0?ooo`0606IV
<`1V<c<0IS<c03<c001V<c<0c<bI;@3oc<`G0?o<V@030?nIV@3<VIT0oiVI00<0c9VI00@0olbI0<bI
V@3oVIT0oiVI3`3<VIT00`3<c9T0c<c<0<c<V@1J0?ooo`00G`3oool00`3<c<`0IVHc06Hc<`0206Hc
<`030<bIV@3oc<`0olc<02d0olc<5P3oc9T01@3oVIT0c9VI0?nIV@3oVIT0c9VI0080oiVI00<0c9VI
0?nIV@3<VIT0403<VIT00`3<c9T0c<c<0?ooo`1I0?ooo`00G`3oool01@2IIVH0IVHc06Hc<`1V<c<0
c9VI0300olc<5@3oc9T00`3<c9T0oiVI0?o<V@020<bIV@040?nIV@3<VIT0c<bI0?nIVA80c9VI0P3<
c9UJ0?ooo`00GP3oool01@2IVIT0IS<c06Hc<`1V<c<0c9VI0340olc<503oc9T30?nIV@80c9VI00@0
olbI0<bIV@3oVIT0olbI0P3<VIT00`3oVIT0c9VI0<bIV@0?0<bIV@030<c<V@3oool0oooo05P0oooo
001M0?ooo`050<c<c01VIS<0IS<c06IV<`2IVIT0<03oc<`F0?o<V@<0c9VI00<0oiVI0<bIV@3<VIT0
0`3<VIT00`3oVIT0c9VI0<bIV@0A0<bIV@030<c<V@3<c<`0oooo05P0oooo001L0?ooo`050?o<o`1V
IVH0IS<c06Hc<`2IVFH0<03oc<`E0?o<V@040<bIV@3oc9T0oiVI0?nIV@P0c9VI00<0olbI0<bIV@3<
VIT04@3<VIT00`3<c9T0olc<0?ooo`1G0?ooo`00F`3oool01@3<VL`0IS<c06Hc<`1V<c<0IVIV0380
olc<103oc9T=0?nIV@060<bIV@3oVIT0c9VI0?nIV@3<VIT0oiVI7P3<VIT00`3<c9T0c<c<0?ooo`1F
0?ooo`00F`3oool01@2IIVH0IS<c06Hc<`1V<c<0c9VI03<0olc<0P3oc9T70?nIV@030?o<V@3oVIT0
oiVI00<0oiVI00@0c9VI0?nIV@3<VIT0oiVI803<VIT0103<c9T0c9VI0<c<V@3oc<aF0?ooo`00FP3o
ool01@3<c<`0IS<c06Hc<`1V<c<0VIVI0380olc<1P3oVIT0103oVFH0c9VI0?nIIP3<VIT20?nIV@03
0<bIV@3oVIT0oiVI00@0oiVI8`3<VIT20<c<V@030?o<V@3oool0oooo05@0oooo001J0?ooo`0409UV
IP1V<c<0IS<c09UVIS00olc<00@0olbI0?nIV@3oVIT0olc<0`3oVIT70?nIIP050?nIV@3oVFH0oiUV
0?nIIP3<VFH0103oVITS0<bIV@030<c<V@3<VIT0olc<05D0oooo001I0?ooo`050?o<o`1VIVH0IS<c
06IV<`3oc9T0<@3oc<`00`3<c<`0olbI0?nIV@020?nIV@@0oiUV00@0c6IV0?nIIP3oVFH0c9VI0`3o
VFH00`3<IVH0oiUV0?nIIP020<bIIP030?nIV@3<VIT0oiVI0280c9VI0P3<c9T00`3<c<`0oooo0?oo
o`1B0?ooo`00F@3oool0103<c<`0IVHc06Hc<`2IVITd0?o<c0<0oiVI1`3oVFH00`3oVIT0oiUV0?nI
IP020?nIIP060<aVIP3oVFH0oiUV0?nIIP3<VFH0oiUV2P3<VIT00`3<VFH0c9VI0<bIV@0F0<bIV@04
0<c<V@3<VIT0olbI0?ooc5<0oooo001I0?ooo`0309UVIP1V<c<0VFIV0340olc<00<0ooo<0?o<c03o
c<`00`3oc9T00`3oVIT0oiUV0?nIIP040?nIIP030<bIV@3oVIT0oiUV00@0oiUV00L0c6IV0?nIIP3o
VFH0oiUV0<aVIP3oVFH0c9UV00P0c9VI00<0c9UV0<bIV@3<VIT05`3<VIT20<c<V@030<c<c03oool0
oooo0540oooo001G0?ooo`040<c<c02IVIT0IS<c09VIIRh0olc<00<0c<c<0?o<c03oc<`00P3oc<`2
0?nIV@@0oiUV0P3oIVH40<aVIP<0oiUV00D0ofIV0?nIIP3<IVH0oiUV0<aVIP050?nIIP030<bIIP3<
IVH0oiUV00P0c9VI00<0c9UV0<bIV@3<VIT05`3<VIT00`3<c9T0c<c<0?ooo`1A0?ooo`00EP3oool0
1@3<c<`0VIVI09VIV@1V<c<0c<bI01T0olc<0P3oc9T40?o<c0030?o<V@3oc<`0olc<00l0olc<00<0
olbI0?nIV@3oVIT00P3oVFH00`3oIVH0c6IV0<aVIP040<aVIP@0ofIV00<0oiUV0?mVIP3oIVH0203<
IVH20?nIIP030<bIIP3<VIT0c9VI00@0c9VI00<0c9UV0<bIV@3<VIT0303<VIT00`3oVIT0c9VI0<bI
V@0:0<bIV@80c<bIDP3oool005H0oooo00@0VIVI06IVIP1VIVH0VFIV6P3oc<`20?o<V@80olc<0`3o
c9T@0?o<c0040?o<V@3oVIT0oiVI0?nIIQP0c6IV00@0oiUV0<aVIP3<IVH0c9UV1`3<VIT00`3<VFH0
c9VI0<bIV@0H0<bIV@030<c<V@3oc?l0olco0500oooo001E0?ooo`040<bIc02IIVH0IVIV06Hc<a/0
olc<0`3oc9T00`3oc<`0olbI0?o<V@020?o<V@X0olc<00<0olbI0?o<c03oc9T00`3oVIT0103oVFH0
ofIV0<aVIP3<IVH30<bIV@030<aVIP3<VFH0oiUV00<0c6IV00<0c6Hc0<aVIP3<IVH0303<IVH20<bI
IP030<aVIP3<VFH0c9UV00<0c9VI00D0c9UV0<bIV@3<VFH0c9VI0<bIIP090<bIV@030?nIV@3<VIT0
c9VI00`0c9VI00@0c<bI0?o<c03oc<`0olcoC`3oool005@0oooo00<0c<co09VIV@1VIVH00P1V<c<J
0?o<c0P0olbI1`3oc<`40?o<V@@0oiVI0P3oVFH01@3<IVH0c9UV0<bIV@3<VIT0c<bI0080oiVI00<0
c6IV0<c<c03oc<`00P3<c9T01@3<VIT0c6IV0?nIV@3oVIT0c9VI00@0c6IV00<0c6Hc0<aVIP3<IVH0
1`3<IVH30<bIIP@0c9VI0P3<VFH90<bIV@80oiVI3`3<VIT20<c<V@030?ooc03oc?l0oooo04d0oooo
001C0?ooo`060?o<o`2IVIT0VFIV06Hc<`0c<c<0VFIV6P3oc<`70?o<V@L0olc<0`3oc9T30?nIV@80
oiUV0P3<IVH01P3oVFH0c9UV0<c<c03oc<`0c<c<0?o<c080c<c<00L0c9VI0<c<c03<c<`0olc<0<c<
c03<c9T0c9UV0080c<c<0P3<c9T01P3<VFH0VFHc0<aVIP3<VFH0c6IV0<aV<`P0c6IV0P3<VFH30<bI
V@<0c9UV1`3<VIT00`3oVIT0c9VI0<bIV@020<bIV@030?nIV@3<VIT0c9VI00d0c9VI00@0c<c<0?o<
o`3oool0olcoC03oool005<0oooo00<0c9W<09UVIP1VIS<00P1V<c<00`2IVIT0olc<0?o<c0090?o<
c080olbI303oc<`80?o<V@D0olc<0P3oc9T40?nIV@030?nIIP3oIVH0c6IV0080c6Hc00@0c6IV0<bI
V@3<IVH0oiVI0P3<c<`00`3oc<`0c<c<0<c<c0040<c<c0030?o<V@3<c<`0c9VI0080c<c<00@0olc<
0<c<c03<VIT0VFIV0P3<VIT0103<VFH0VFHc09UV<`3<IS<70<aVIP<0c9UV103<VIT00`3<VFH0c9VI
0<bIV@050<bIV@80olbI4P3<VIT01@3<c9T0olco0?o<o`3oool0olco04/0oooo001C0?ooo`0609VI
V@2IIVH0IVHc06Hc<`1VIS<0c<bI2`3oc<`20?o<V@/0olc<1P3oc9T20?nIV@030?o<V@3oc<`0olc<
0080olc<1P3oVIT0103oVFH0c6Hc0<aV<`3<IS<40<aVIP070?nIV@3<IVH0c6IV0<bIIP3oVFH0c9UV
0<aVIP050<bIV@030<c<V@3<VIT0c<c<00<0c<c<00H0c9VI0<bIIP3<VIT0c9VI0<bIIP3<IVH209Tc
<`H0c6IV00<0c9UV0<aVIP3<VFH00`3<VIT30<bIIPT0c9VI0`3oc9T=0<bIV@<0c<bI00<0c<c<0?oo
o`3oool0C03oool00540oooo00@0olco0<c<c03<VIT0VFIV0P1V<c<00`3<VIT0olc<0?o<c0090?o<
c0@0olbI203oc<`50?o<V@050?nIV@3<VIT0c9UV0<bIV@3oc9T00`3oc<`00`3oVIT0oiUV0?nIV@02
0?nIIP090<bIIP3<IVH0VC<006H0003<IVH0olc<0?nIV@3<VFH0c6IV00<0oiVI0P3<IVH01@3oc9T0
ooo<0?ooo`3oool0ooo<0080olc<00@0oiVI0?mVIP3<IVH0oiVI0P3<VFH30<aVIP030<bIIP3<VIT0
c9VI0080c9VI0`2IIVH209UV<`060<aV<`3<IVH0c6IV0<aVIP3<VFH0c6IV0P3<VFH20<bIV@030<bI
IP3<VIT0c9UV00H0c9VI1P3oc9T?0<bIV@030?o<V@3<c<`0c<co0080ooo<BP3oool00540oooo00H0
c<c<09VIV@3<VIT0IVIV03<c<`1VIS<;0?o<c0@0olbI2@3oc<`40?o<V@80oiVI0`3<VIT0103oc9T0
olc<0?o<V@3oVIT30<aVIP0709UV<`3<IVH0c9VI0<c<V@3<c<`0c9UV0?o<c0020?ooc080olbI0`3o
c<`00`3oVIT0oiUV0?ooc0030?ooo`80ooo<00D0olc<0?ooc03<c<`0olc<0<c<c0020?o<c0030<c<
c03oc9T0c9UV0080c6IV00@0c9UV0<bIV@3<VIT0c9UV0`2IIVH00`2IIS<0VC<c0<aV<`020<aV<`<0
c6IV00D0c9UV0<bIV@3<VFH0c9VI0<bIIP060<bIV@L0olbI403<VIT01@3oc<`0c<c<0<c<o`3<c<`0
ooo<04T0oooo001A0?ooo`<0VIVI0P1V<c<00`3<VFH0olc<0?o<c0090?o<c0@0olbI2@3oc<`30?o<
V@80oiVI00@0c9VI0<bIIP3<VFH0oiVI0P3oc9T30<aVIP0609Tc<`0c0000VFHc0<c<V@3oc9T0ooo<
0P3oc<`40?ooc0@0oooo00<0ooo<0?o<V@3oool00`3oool20?ooc0030?o<c03ool`0olc<0080olc<
00<0ooo<0?o<c03oc<`00P3oc<`00`3<c<`0oiUV0<aV<`020<aVIP80VFIV00D0c9UV09UVIP2IIS<0
IS<c09Tc<`020<aV<`<0c6IV00H0c9UV0<bIV@3<VIT0c9UV0<bIV@3<VFH40<bIV@T0olbI3P3<VIT0
1@3<c9T0c<c<0?ooo`3oool0c<co0080c<c<00<0olco0?ooo`3oool0A@3oool00540oooo00H0VIVI
09UVIP1VIVH0<c<c06Hc<`3<c9T:0?o<c0D0olbI2@3oc<`30?o<V@040?nIV@3<VIT0c9UV0<bIIP80
c9VI00@0oiVI0<aVIP3<IS<0c6Hc0P2I<c<01@2IIS<0c<bI0?o<c03oc<`0ooo<0080olc<0`3ool`5
0?ooo`030?ooc03oc<`0oooo00<0oooo0`3ool`30?o<c0030?ooc03oc<`0olc<00@0olc<00D0c<bI
0<aV<`3<IVH0c6Hc09UV<`0309UVIP80IS<c00<0VFHc09Tc<`3<IS<00P3<IS<00`3<IVH0c9UV0<bI
V@020<bIV@030<bIIP3<VIT0c9UV00@0c9VI1`3oc9T?0<bIV@030<c<V@3oc9T0c<co00<0oooo0P3<
c<a70?ooo`00D@3oool01@2IIVH0IVHc06Hc<`1V<c<0VFHc00`0olc<0`3oc9T:0?o<c080olbI0P3o
VIT50<bIIP030<aVIP3<IS<0VC<c0080VC<c00<0VFHc0<bIIP3<c<`00`3oc<`60?ooc0<0oooo0P3o
ol`00`3oc<`0oooo0?ooo`020?ooo`<0ooo<0`3oc<`0103oool0ooo<0?ooc03ool`30?o<c0030<c<
V@3oc9T0c<c<0080c9VI0`2IIS<01@2I<c<0IS<c06Hc<`1V<c<0VC<c0080c6Hc00<0c6IV0<bIIP3<
VFH00`3<VIT00`3<VFH0c9VI0<bIV@020<bIV@030?nIV@3oc9T0olbI00L0olbI3P3<VIT00`3<c9T0
olc<0<c<o`040?ooo`030?o<o`3oool0oooo04@0oooo001@0?ooo`030?o<o`2IIVH0IS<c0080IS<c
00<0VFIV0?o<c03oc<`02@3oc<`40?o<V@X0olc<0P3oc9T00`3oVIT0c9VI0<bIIP020<bIIP090<aV
IP3<IS<0VC<c09Tc<`2I<`00IS<009UV<`2IIVH0c<bI0080olc<0`3ool`0103oc<`0ooo<0?ooc03o
c<`20?ooc080oooo00@0ooo<0?o<c03oc<`0ooo<0`3oool20?ooc080olc<00L0olbI0?o<c03oool0
olc<0?ooc03oc<`0ooo<0080olc<00<0olbI0<c<c03oc<`00P3oc<`0103<VIT0VFHc09Tc<`2I<c<2
06Hc000303<c<`0c0000VC<c0080c6Hc0P3<IVH0103<VFH0c9VI0<bIV@3<VFH50<bIV@P0olbI3`3<
VIT01P3<c9T0c<c<0?o<c03<c<`0oooo0?o<o`80oooo00<0olco0?ooo`3oool0@`3oool004P0oooo
0P3oc?l60?ooo`030<c<c02IVIT0IVHc0080IS<c00<0c9VI0?o<c03oc<`02@3oc<`30?o<V@/0olc<
0P3oc9T01@3oVIT0c9UV0<bIIP3<IVH0c9UV00<0VC<c00P0VC<006Hc001V<c<0VFIV0<aVIP3oVIT0
olbI0?o<c080ooo<0P3oc<`00`3oool0ooo<0?o<c0020?ooc080oooo00@0ooo<0?o<c03oc<`0ooo<
0`3oool20?ooc0050?o<c03oc9T0oiVI0?o<c03oool00`3ool`30?o<c0040?o<V@3<c<`0olc<0<c<
c080olc<00`0c9VI09UV<`2IIVH0VFIV06Hc000c0000000003<0002I<c<0c6Hc0<aVIP3<IS<20<bI
IP80c9VI00<0c9UV0<bIV@3<VIT00P3<VIT90?o<V@h0c9VI0P3<c9T00`3<c<`0c9VI0<c<c0020<c<
c0030<c<o`3oool0olco04@0oooo001=0?ooo`80olco00<0c<c<09VIV@1VIVH00P1V<c<00`2IIVH0
olc<0?o<c0090?o<c0<0olbI0P3oc<`20?o<V@L0olc<00@0olbI0?nIV@3<VFH0c9VI103<VFH409Tc
<`0709Tc001V<`00VC<c0<bIIP3<IVH0oiVI0?o<c0020?nIV@030?o<V@3oc<`0olc<0080olbI00D0
olc<0?ooc03ool`0ooo<0?o<c0020?o<V@040?o<c03oool0oooo0?ooo`80olc<0P3oc9T20?nIV@80
olc<00H0ooo<0?o<c03oc<`0olc<0?o<V@3<VIT30?o<c0030<c<c03oc<`0c<c<0080c<bI00D0olc<
0<bIIP2I<c<0VFIV06IV<`0203<0000709UV<`3<IS<0c6Hc0<aVIP3<VFH0c9VI0<bIIP030<bIV@X0
olbI00<0oiVI0?o<V@3<VIT0303<VIT01P3oc9T0c<c<0<bIV@1VIS<0VIVI0<bIV@80c<c<00<0olco
0?ooo`3oool0@P3oool004l0oooo00H0c<co09UVIP1V<c<0<c<c06Hc<`3<VFH;0?o<c0<0olbI00@0
olc<0?o<V@3oc9T0olbI1`3oc<`0103oc9T0oiVI0<bIIP3<VIT40<bIIP<0c6Hc0P2I<c<0102I<`00
VFHc0?nIIP3<IVH20?nIV@030<bIIP3oVIT0olbI00<0olc<0P3oc9T01@3oc<`0ooo<0?ooc03oc9T0
oiVI00<0olc<00@0ooo<0?o<c03oc<`0olbI0`3oVIT20?o<V@D0olc<00@0oiVI0<bIIP3oc<`0c<c<
0`3oc<`00`3oc9T0c9VI0<c<V@020<c<V@<0c9VI00L0VC<c06Hc<`2I<c<0VC<c0<aV<`3<IVH0c9UV
00H0c9VI2@3oc9T?0<bIV@040<c<V@3<c<`0c<bI09VIV@D0c<c<00<0c<co0?ooo`3oool0@@3oool0
04d0oooo0P3<c<`00`3<VIT0IVHc03<c<`0206Hc<`030<c<V@3oc<`0olc<00L0olc<103oc9T20?o<
c0<0olbI1`3oc<`0103oc9T0c9UV0<bIIP3<VIT30<bIIP80c9VI00<0oiUV0<aVIP3<IVH00P2I<c<0
1P3<IS<0c6IV0<aVIP3<VFH0oiUV0<bIIP80oiVI00<0olbI0?o<c03oc<`00P3oVIT30?o<c080oiVI
1@3oc<`20?nIV@80oiUV0`3oVIT20?o<V@80olc<00@0olbI0<bIIP3<IVH0olbI103oc<`20<bIV@80
c<bI103<VIT209UVIP0806Hc<`2I<c<0VC<c0<aV<`3<IVH0c9UV0<bIV@3<VFH30<bIV@X0olbI3@3<
VIT30<c<V@P0c<c<00<0olco0?ooo`3oool0@03oool004/0oooo00D0c<co0<c<c02IVIT0VIVI06Hc
<`0303<c<`0306Hc<`3oc<`0c<c<00T0olc<0`3oc9T20?o<c0<0olbI1`3oc<`02@3oc9T0oiVI0<aV
IP3<VFH0c9VI0<bIIP3<VIT0oiVI0?o<V@040?nIV@@0c6IV103oVFH00`3<VFH0oiVI0?nIV@020?nI
V@050?mVIP3oVIT0oiVI0?nIV@3oVFH00P3oVIT0103oc9T0olc<0?o<c03oVIT50<aVIP030?nIIP3o
VIT0oiVI00<0oiVI00@0c9VI0<aVIP3<IVH0oiVI0`3oc<`00`3oc9T0c9UV0<c<V@020<c<V@@0c9VI
00@0c9UV09UVIP2I<c<0IS<00P2I<c<00`3<IS<0c9UV0<bIIP040<bIV@X0olbI3@3<VIT30<c<V@03
0<c<c03<c?l0olco00H0c<c<00<0olco0?ooo`3oool0?`3oool004T0oooo00@0olco0<c<c03<VIT0
IVIV0`1V<c<0100c<c<0<c<003<c002IIVH:0?o<c0@0olbI00<0olc<0?o<V@3oc9T00P3oc9T70?o<
c0040?o<V@3<VIT0c6IV0<bIIP80c9VI00<0oiVI0?o<V@3oc<`00`3oc<`30?o<V@L0oiVI1@3oVFH0
0`3<IVH0oiUV0?nIIP040?nIIP050<bIV@3oVFH0oiUV0<aVIP3oVFH01P3<IVH01`3<VFH0oiUV0<bI
IP3<IVH0c9UV0<aVIP3<VFH00`3oc9T01@3<VIT0c9UV0<bIV@3<c9T0olbI00@0c9VI00<0c9UV0<aV
IP1V<c<00P1V<`0209Tc<`030<aVIP3<VFH0c9UV00<0c9VI2@3oc9T00`3oVIT0olbI0<bIV@0;0<bI
V@<0c<bI00<0c<c<0?o<o`3oc?l00P3oc?l40<c<c0030?ooc03oool0oooo03l0oooo00190?ooo`04
0?o<o`3<c<`0c9VI06IVIP<0IS<c00@0<c<c03<c000c<`00VFIV2P3oc<`40?o<V@030?o<c03oc9T0
olbI0080olbI1`3oc<`0103oc9T0c9VI0<aVIP3<VFH20<bIV@030?nIV@3oc9T0olc<00<0olc<0`3o
c9T70?nIV@D0oiUV00<0c6IV0?nIIP3oVFH0103oVFH01@3<VIT0oiUV0?nIIP3<IVH0oiUV00H0c6IV
00L0c9UV0?nIIP3<VFH0c6IV0<bIIP3<IVH0c9UV00<0olbI00D0c9VI0<bIIP3<VIT0c<bI0?o<V@04
0<bIV@030<bIIP3<IVH0IS<c0080IS<00P2I<c<00`3<IVH0c9UV0<bIIP030<bIV@T0olbI00<0oiVI
0?o<V@3<VIT02`3<VIT30<c<V@030<c<c03oc?l0olco0080olco103<c<`00`3ool`0oooo0?ooo`0o
0?ooo`00B@3oool00`3<c<`0VFIV06Hc<`0303<c<`80IS<c00<0<c<003<c<`3<VIT02@3oc<`50?o<
V@040?o<c03oc9T0olbI0?nIV@P0olc<00D0olbI0?nIV@3<IVH0c9UV0<bIV@030?o<V@/0olc<1@3o
c9T30?nIV@80olbI203oVIT0103<VIT0oiUV0<bIV@3oVFH;0<aVIP080<bIV@3<c9T0c9VI0<bIIP3<
IVH0c9UV0<c<V@3oc9T40<bIV@040<bIIP2IIVH0IS<c06H00080IS<000@0VC<c09UV<`3<VFH0c9UV
0`3<VIT:0?o<V@h0c9VI0P3<c9T00`3oc9T0oooo0?ooo`020?ooo`<0c<c<00<0ooo<0<c<o`3oc?l0
@03oool004T0oooo00@0VIVI03<c<`0c<c<0<c<00P0c00001@0c<c<0IS<c03<c<`1V<c<0c<bI00T0
olc<103oc9T00`3oc<`0olbI0?o<V@020?o<V@P0olc<00D0olbI0?nIV@3<VFH0c6IV0<bIV@030?o<
VA80olc<00@0olbI0?o<c03oc<`0olc<0P3oc9T00`3oVIT0olbI0?nIV@060?nIV@<0oiUV0`3<IVH0
0`3<IS<0c6IV0<aVIP020<aVIP030<bIIP3<VIT0c9UV0080c6IV00D0c9UV0<bIV@3<c9T0c9VI0<bI
IP020<bIV@0309UVIP3<IVH0IS<c00<0IP0000@0IS<009Tc<`2IIS<0c9UV0`3<VIT00`3oVIT0olbI
0?o<V@070?o<V@h0c9VI0P3<c9T00`3oc9T0c<c<0?ooc0020?ooo`030<c<o`3oc?l0ooo<0080c<c<
00<0ooo<0?ooo`3oool0?P3oool004H0oooo0P3oc?l01@3<c<`0IS<c03<c<`0c0000<c<000@0IS<c
00<0<c<009UVIP3oc<`02@3oc<`30?o<V@80olc<103oc9T70?o<c080olbI0P3oVIT20<bIIP030?nI
V@3oc9T0olbI01H0olc<00D0c<c<0?o<c03oc<`0olc<0<c<c0020?o<c0D0olbI0`3oVIT20?nIIP03
0<aVIP3<VFH0oiUV00P0c6IV0`3<VFH02@3<IVH0c6Hc0<aVIP2IIS<0VC<c06Hc<`0c0000IP0006Hc
000309Tc<`0509UV<`3<VFH0c9VI0<bIV@3oVIT02@3oc9T50<bIV@030<bIIP3<VIT0c9VI00L0c9VI
0P3<c9T02P2IVFH0IVIV0<bIV@3<c<`0c<co0?ooc03oc?l0c<co0<c<c03oc?m00?ooo`00AP3oool2
0?o<o`030<bIc00c<c<0<c<c0080<c<c101V<c<00`1V<`00VIUV0?o<c0090?o<c0<0olbI0`3oc<`0
0`3oc9T0olc<0?o<c0070?o<c080olbI0P3oVIT20<bIIP030<bIV@3oc9T0olc<01`0olc<00<0olbI
0?o<c03oc<`00`3oc9T00`3oc<`0olbI0?nIV@030?nIV@80oiUV00D0c9UV0?nIIP3oVFH0c6IV0<bI
IP040<aVIP80c9UV0`3<IS<00`2IIS<0VC<c06Hc<`0206H0000306Hc<`2I<c<0VC<c0080VC<c0`3<
VFH00`3<VIT0olbI0?o<V@020?o<V@050?o<c03oc9T0olbI0?o<V@3oVIT01`3<VIT00`3<VFH0c9VI
0<bIV@050<bIV@070<c<V@3oc9T0VIVI06IV<`2IIVH0c<c<0<c<o`020?o<o`030?ooo`3oc?l0olco
0400oooo00160?ooo`80c<c<00<0VIVI03<c000c<`00101V<c<0100c<c<0<c<006Hc<`3<VIT;0?o<
c0030?o<V@3oc<`0olc<00`0olc<0P3oc9T20?nIV@030<bIV@3<VFH0c9UV0080olbI6P3oc<`00`3o
c9T0olc<0?o<V@0;0?o<V@<0oiVI0`3<VIT01@3oVFH0c9UV0<bIIP3oVFH0c9UV00H0c6IV00T0c6Hc
09UV<`2I<c<0VFHc09Tc<`2IIS<0c6Hc09UV<`2I<c<00P3<VFH20<bIV@T0olbI1@3<VIT00`3<VFH0
c9VI0<bIV@080<bIV@060<c<V@3<VIT0IVIV06Hc<`2IIVH0ooo<A@3oool004H0oooo00D0c<co09VI
V@2IIVH0<c<003<c<`0406Hc<`0403<c<`0c<`00IS<c0?o<V@X0olc<00<0olbI0?o<c03oc<`03P3o
c<`0103oc9T0oiVI0?nIV@3oVIT20<bIIP030<bIV@3oc9T0olc<01T0olc<3P3oc9T50?nIV@L0c9VI
0`3<VFH01`3<VIT0c9UV0<bIIP3oVFH0c9UV0<aVIP3<VFH0103<IVH20<bIIP80c9VI2@3oc9T60<bI
V@<0c9UV1`3<VIT01`3<c9T0c9VI06IV<`1VIS<0IS<c09VIV@3ool`0A03oool004H0oooo00L0olco
06IVIP1V<c<0IS<c09UVIP2IVFH0c9VI0080c9UV00<0c6IV06Hc<`2IIS<06P3oc<`00`3oc9T0olc<
0?o<V@030?nIV@030<bIV@3<VFH0c9UV0080olbI6P3oc<`>0?o<V@030?nIV@3<VIT0oiVI00l0c9VI
0`3<VFH00`3<IVH0c9UV0<aVIP040<bIIP030<bIV@3oc9T0olbI00L0olbI203<VIT00`3<VFH0c9VI
0<bIV@050<bIV@070<c<V@3<VIT0VFIV09UVIP2IVFH0VFIV0<bIV@140?ooo`00AP3oool0103<c?l0
IVIV06Hc<`3<c9T30?o<c0<0olbI0P3<VFH20?o<c0030<c<c03oc<`0olc<01H0olc<0`3oc9T30?nI
V@80c9UV00<0c9VI0?o<V@3oc9T06@3oc<`>0?o<V@80oiVI4`3<VIT80<bIIPT0olbI403<VIT20<c<
V@<0VIVI00<0c9VI09VIV@3<c<`0@`3oool004H0oooo00<0c<co06IVIP2IIVH01P3oc<`30?o<VA00
olc<00<0olbI0?o<c03oc<`02@3oc<`20?o<V@<0oiVI00<0c9VI0<bIIP3<VFH00P3oc9TI0?o<c0d0
olbI0P3oVIT80<bIV@030<bIIP3<VIT0c9VI00T0c9VI00D0c9UV0<bIV@3<VFH0c9VI0<bIIP020<bI
V@030<bIIP3oVIT0olbI00H0olbI2@3<VIT00`3<VFH0c9VI0<bIV@070<bIV@80IVIV00@0c9VI0<c<
c03<c<`0c<c<@`3oool004D0oooo00@0olco0<bIc02IIVH0c<bI1`3oc<`00`3oc9T0c<c<0?o<c00L
0?o<c080olbI0`3oVIT0103<VIT0c9UV0?o<V@3oc9TI0?o<c0d0olbI1`3<VIT00`3<VFH0c9VI0<bI
V@050<bIIP80c9VI0P3<VFH60<bIV@050<bIIP3<VIT0c9VI0<bIV@3<VFH00P3oc9T00`3<VIT0olbI
0?o<V@030?o<V@030?nIV@3<VIT0c9VI00h0c9VI00D0c<bI0<bIV@1VIVH0IVIV09VIV@030<c<c4<0
oooo00150?ooo`030<c<o`3<VIT0olc<00/0olc<00<0c<c<0?o<c03oc<`0603oc<`40?o<V@<0oiVI
0P3<VIT20?o<VAP0olc<3P3oc9T00`3oVIT0c9VI0<bIV@020<bIV@030<bIIP3<VIT0c9UV00d0c9UV
0`3<VIT20<bIIP030<bIV@3<VFH0c9VI0080olbI00<0c9UV0?o<V@3oc9T00P3oc9T00`3<VIT0olbI
0<bIV@050<bIV@030<bIIP3<VIT0c9VI00P0c9VI00H0c<bI06Hc<`0c<c<0VFIV0<c<c03oc?m40?oo
o`00A@3oool00`3<c<`0olc<0?o<c00W0?o<c0<0olbI103oVIT0103<VFH0oiVI0?o<V@3oc9TG0?o<
c0D0olbI00<0oiVI0?o<V@3oc9T00`3oc9T00`3oVIT0c9VI0<bIV@060<bIVA40c9UV00<0c9VI0<bI
IP3<VIT00P3<VFH20?o<V@030<bIV@3<VFH0olbI00@0olbI103<VIT00`3<VFH0c9VI0<bIIP0:0<bI
V@070<c<V@3<VIT0IS<c06Hc<`1VIVH0VIVI0<c<c0140?ooo`00A03oool00`3<c?l0c<c<0?o<c00=
0?o<c0030<c<c03oc<`0olc<01P0olc<103oc9T40?nIV@040<bIV@3oVIT0olbI0?o<VAP0olc<00T0
olbI0?nIV@3oVIT0c9VI0?nIV@3<VIT0oiVI0<bIV@3oc9T01P3<VIT00`3<VFH0c9VI0<bIIP0E0<bI
IP<0c9VI00<0c9UV0?nIV@3oc9T00P3oc9T20?nIV@H0c9VI00<0c9UV0<bIV@3<VIT02P3<VIT206Hc
<`0406IVIP2IVIT0c<c<0?o<od<0oooo00140?ooo`030?o<o`3<c<`0olc<02P0olc<1P3oc9T00`3o
VIT0c9VI0<bIV@040?o<VAD0olc<0`3oc9T00`3oVIT0c9VI0?nIV@090<bIV@030<bIIP3<VIT0c9UV
01L0c9UV1@3<VIT0103oVIT0olbI0?nIV@3oc9T40<bIV@050<bIIP3<VIT0c9VI0<bIV@3<VFH02@3<
VIT0203<c9T0c9VI03<c<`1V<c<0IVIV09VIV@3<VIT0olco@`3oool004@0oooo00<0c<c<0?o<c03o
c<`0203oc<`20?o<VAl0olc<103oc9T30?nIV@030<bIIP3<VIT0olbI0080olbI4P3oc<`00`3<c<`0
olc<0?o<c0020?o<V@030?nIV@3<VIT0oiVI0080oiVI00<0olbI0<bIV@3<VIT0103<VIT00`3<VFH0
c9VI0<bIIP0G0<bIIP@0c9VI0P3oVIT0103<VIT0olbI0<bIV@3oVIT30<bIV@050<bIIP3<VIT0c9VI
0<bIV@3<VFH0303<VIT01P0c<c<0<c<003<c<`1V<c<0IVIV09VIVD<0oooo00140?ooo`T0olc<103o
c9TE0?o<c0030?ooc03oc<`0olc<00L0olc<1@3oc9T01@3oVIT0c9UV0?nIV@3<VIT0oiVI0080olbI
5@3oc<`20?o<V@80oiVI00<0c<bI0<bIV@3<c9T00P3oVIT20<bIIP80c9VI00<0c9UV0<bIV@3<VFH0
603<VFH30<bIV@80oiVI00<0olbI0?nIV@3oVIT0503<VIT00`3<c9T0c9VI03<c000203<c<`80IS<c
00<0VIVI0?ooo`3oool0@@3oool004<0oooo00<0c<c<0?o<c03oc<`0103oc<`70?o<V@80olc<00<0
c<c<0?o<c03oc<`03P3oc<`00`3ool`0olc<0?o<c0090?o<c0D0olbI0`3oVIT0103<VIT0oiVI0?o<
V@3oc9T<0?o<c080olbI1`3oc<`30?o<V@80oiVI00<0c<bI0?nIV@3<VIT00P3<VIT20<bIIPD0c9VI
5P3<VFH20<bIV@<0oiVI0P3oc9T00`3oVIT0c9VI0?nIV@0E0<bIV@@0<c<c00<0IS<c0<c<c03oool0
@P3oool00480oooo2@3oc<`01P3oc9T0oiVI0?o<V@3oc9T0c9VI0?o<V@80olc<00<0c<c<0?o<c03o
c<`03@3oc<`30?ooc0`0olc<103oc9T20?nIV@050<bIIP3oVIT0c9VI0?nIV@3oc9T0503oc<`50?o<
V@040?nIV@3<c9T0oiVI0<c<V@80c9VI4@3<VFH00`3<VIT0c9UV0<bIIP070<bIIP050<bIV@3oVIT0
oiVI0?o<V@3oVIT00P3oc9T20?nIV@030<bIV@3oVIT0c9VI00D0c9VI00<0c9UV0<bIV@3<VIT02P3<
VIT00`3<c9T0VIVI06Hc<`0206Hc<`0306IVIP2IVIT0c<c<04<0oooo00120?ooo`T0olc<00H0olbI
0?nIV@3oc9T0olbI0<bIV@3oc9TE0?o<c0030?ooc03oc<`0ooo<00P0olc<00<0olbI0?o<c03oc9T0
0P3oc9T30?nIV@040<bIV@3oVIT0oiVI0?o<VAD0olc<1P3oc9T60<bIVA00c9UV00<0c9VI0<bIIP3<
VFH01@3<VFH20<bIV@@0olbI00D0oiVI0?o<V@3oVIT0c9VI0?nIV@0<0<bIV@030<bIIP3<VIT0c9VI
00H0c9VI00H0VIVI06Hc<`0c<c<0IS<c06IVIP3oola40?ooo`00@P3oool80?o<c0030?o<V@3oVIT0
olbI0080oiVI00<0c9VI0?o<V@3oc<`04P3oc<`30?ooc0/0olc<103oc9T40?nIV@030<bIV@3oVIT0
olbI01H0olc<103oc9T20?nIV@H0c9VI503<VFH30<bIV@80oiVI0`3oc9T00`3oVIT0olbI0?o<V@02
0?nIVAD0c9VI00<0c<bI09UVIP0c<c<00P1V<c<0102IIVH0c9VI0<bIV@3<c?m20?ooo`00@@3oool8
0?o<c0@0olbI0P3oVIT0103<VIT0olbI0?o<c03<c<`?0?o<c0040?ooc03oc<`0olc<0?ooc080olc<
00<0ooo<0?o<c03oc<`01`3oc<`60?o<V@D0oiVI00<0olbI0?o<c03oc<`04`3oc<`50?o<V@030?nI
V@3<c9T0c9VI00H0c9VI3P3<VFH0103<VIT0c9UV0<bIIP3<VFH30<bIV@80oiVI1`3oc9T00`3<VIT0
oiVI0?nIV@0C0<bIV@040<c<V@2IVFH0IS<c03<c<`@0IS<c00<0c9VI0?o<o`3oc?l0@03oool00440
oooo203oc<`20?o<V@040?nIV@3oc9T0c9VI0<bIV@80olbI4P3oc<`00`3ool`0olc<0?ooc0020?oo
c0X0olc<00<0olbI0?o<c03oc9T00`3oc9T50?nIV@80olbI5@3oc<`50?o<V@030?nIV@3<VIT0c9VI
00L0c9VI00<0c9UV0<bIV@3<VFH0303<VFH20<bIV@80oiVI1`3oc9T00`3oVIT0olbI0?nIV@0F0<bI
V@0509UVIP1V<c<0IS<c06Hc<`0c<c<00P1V<c<0101VIVH0c9VI0<c<c03oc?lo0?ooo`00@03oool0
0`3ool`0olc<0?o<c0060?o<c0040?o<V@3<VIT0c9VI0?o<V@80c9VI0P3oc9TD0?o<c0030?ooc03o
c<`0ooo<00`0olc<1@3oc9T40?nIV@80olbI3P3oc<`00`3ool`0olc<0?o<c0040?o<c0@0olbI0`3o
VIT;0<bIV@/0c9UV0`3<VIT00`3oVIT0olbI0?o<V@080?o<V@030?nIV@3<VIT0oiVI0180c9VI0P3<
c9T00`3<VFH0VFHc06Hc<`0206Hc<`0603<c<`0c<`00IS<c09UVIP2IVIT0c<c<?`3oool00400oooo
203oc<`0103oc9T0oiVI0<bIIP3oVIT30<bIV@030?o<V@3<c<`0olc<0180olc<00@0ooo<0?o<c03o
ol`0ooo<2`3oc<`60?o<V@@0oiVI0P3oc9T=0?o<c0030?ooc03oc<`0ooo<00@0olc<103oc9T00`3o
VIT0olbI0?nIV@0=0<bIV@T0c9UV00<0c9VI0?nIV@3oVIT00P3oVIT90?o<V@80oiVI0`3<VIT00`3o
VIT0c9VI0<bIV@0?0<bIV@040<c<V@3<VIT0c9UV0<aVIP80VFHc0`1V<c<0101VIVH0VFIV0<bIV@3<
c<`n0?ooo`00?`3oool80?o<c080olbI00@0c9VI0<bIIP3<VFH0c9VI0P3oc9TB0?o<c0080?ooc03o
c<`0ooo<0?ooc03oc<`0ooo<0?o<c03ool`=0?o<c0P0olbI5@3oc<`20?o<V@80oiVI403<VIT80<bI
IP@0c9VI00<0oiVI0?o<V@3oc9T02@3oc9T0103<c9T0oiVI0<bIV@3oVITA0<bIV@030<c<V@3oc9T0
c9UV0080c9UV00@0VFIV09UV<`2IIS<0VC<c101V<c<00`1VIVH0VIVI0?o<o`0l0?ooo`00?`3oool7
0?o<c0<0olbI00@0c9VI0<bIIP3<VFH0c9VI0`3oc9T00`3<c<`0olc<0?o<c00@0?o<c0030?ooc03o
c<`0ooo<0080ooo<3P3oc<`80?o<V@P0olc<00<0olbI0?o<c03oc<`0203oc<`30?o<V@80oiVI3`3<
VIT00`3<VFH0c9VI0<bIIP060<bIIP<0c9VI0P3oVIT<0?o<V@<0oiVI0P3<VIT00`3oVIT0c9VI0<bI
V@0<0<bIV@040<c<V@3<VIT0c9VI0<bIV@<0c9UV0P3<IVH00`2IIS<0IS<c06Hc<`0206Hc<`0306IV
IP2IVIT0olco03`0oooo000o0?ooo`030?o<c03oc9T0olc<0080olc<103oc9T01@3<VIT0c9UV0<bI
V@3<VFH0c<bI0080olbI0`3oc<`00`3<c<`0olc<0?o<c00=0?o<c0040?ooc03oc<`0olc<0?ooc0h0
olc<00<0olbI0?o<c03oc9T01`3oc9T80?o<c080olbI2P3oc<`20?o<V@030?nIV@3<VIT0c9VI00l0
c9VI103<VFH0103<IVH0c9UV0<bIIP3<VFH20<bIV@80oiVI3@3oc9T01@3<VIT0oiVI0<bIV@3<VIT0
oiVI0100c9VI0P3<c9T00`3<VIT0c9UV0<bIIP040<bIIP0609UVIP1V<c<0IVIV09UVIP3<VL`0olco
?@3oool003h0oooo00@0ooo<0?o<V@3oc9T0olc<0`3oc9T20?nIV@@0c9UV00@0c9VI0<c<V@3oc9T0
olbI4`3oc<`00`3ool`0olc<0?o<c00B0?o<c0P0olbI1P3oc<`30?o<V@P0olc<00D0olbI0?o<c03o
c9T0olbI0?nIV@050<bIV@030<bIIP3<VIT0c9VI00D0c9VI00<0c9UV0<bIV@3<VIT0203<VFH30<bI
V@030?nIV@3oc9T0olbI00`0olbI0`3oVITA0<bIV@80c<bI00@0c9VI0<bIIP3<VIT0c9VI1@3<VFH2
09UVIP030<c<c03oool0oooo03d0oooo000n0?ooo`050?o<c03oc9T0olc<0?o<V@3oVIT00`3<VFH3
0<aVIP030<bIIP3<VIT0c9VI00<0olbI00<0c<c<0?o<c03oc<`09@3oc<`40?o<V@040?o<c03oc9T0
olbI0?o<V@H0olc<0`3oc9T80?o<c0@0olbI0P3oVIT70<bIVA00c9UV0`3<VIT?0?o<V@80c9VI0P3o
VIT00`3<VIT0oiVI0<bIV@0<0<bIV@040<c<V@3<VIT0c<bI0<c<V@<0c9VI00L0c9UV0<bIV@3<VFH0
c9VI0<bIIP3<VIT0c<c<0400oooo000n0?ooo`050?o<c03oc9T0olc<0?o<V@3oVIT00P3<VFH00`3<
IVH0c9UV0<bIIP020<bIIP80c9VI00<0c<bI0?o<V@3oc9T04P3oc<`20?ooc0040<c<c03oc<`0olc<
0<c<c0h0olc<1P3oc9TC0?o<c0D0olbI0P3oVIT50<bIV@80c9UV00<0c9VI0<bIIP3<VFH03@3<VFH3
0<bIV@80oiVI303oc9T01`3oVIT0olbI0?nIV@3oVIT0c<bI0<bIV@3oVIT0403<VIT20<c<V@H0c9UV
0P3<VIT00`3<c9T0olco0?ooo`0o0?ooo`00?@3oool40?o<c0040?o<V@3oVIT0c9UV0?mVIP80c6IV
0`3<VFH20<bIV@030?nIV@3oc9T0olbI0180olc<00<0ooo<0?o<c03oc<`04@3oc<`50?o<VAD0olc<
1@3oc9T60<bIV@80c9UV00<0c9VI0<bIIP3<VFH03@3<VFH40<bIVA00olbI00<0c<bI0?nIV@3oVIT0
403<VIT20<c<V@030<bIV@3<VFH0c9UV00D0c9UV0P3<VIU10?ooo`00?@3oool40?o<c0030?o<V@3o
VIT0oiVI00H0c9UV0P3<VIT30?o<VA@0olc<00<0ooo<0?o<c03oc<`02P3oc<`0103oc9T0olc<0?o<
c03oc9T20?o<c080olbI5`3oc<`40?o<V@80oiVI1@3<VITA0<bIIP<0c9VI0`3oVIT<0?o<V@@0oiVI
4`3<VIT20<c<V@D0c9UV0`3<VIT00`3<c9T0oooo0?ooo`0o0?ooo`00?03oool40?o<c080olbI0P3o
VIT20<bIIP060<aVIP3<VFH0c9UV0<bIIP3<VIT0c<bI0`3oc9TV0?o<c0<0olbI0P3oc<`00`3oc9T0
olc<0?o<c00B0?o<c0D0olbI00<0oiVI0<bIV@3<VIT00P3<VIT?0<bIIP@0c9VI00<0oiVI0<bIV@3o
VIT03@3oc9T20?nIV@030?o<V@3<VIT0oiVI00D0c9VI00<0c9UV0<bIV@3<VIT02P3<VIT30<c<V@@0
c9UV103<VIT00`3<c9T0olc<0?ooo`0o0?ooo`00?03oool00`3oc9T0olc<0?o<c0020?o<c0040?o<
V@3oVIT0oiVI0?nIV@@0c9UV0P3<VIT40?o<VBD0olc<00<0olbI0?o<c03oc9T00P3oc<`0103oc9T0
olc<0?o<V@3oc9TC0?o<c0<0olbI00<0oiVI0<bIV@3<VIT0103<VIT=0<bIIPH0c9VI00<0c<bI0?nI
V@3oVIT03@3oc9T0103oVIT0c<bI0<bIV@3oVITB0<bIV@030<c<V@3<VIT0c<bI00D0c9UV103<VIT0
0`3<c<`0oooo0?ooo`0n0?ooo`00>`3oool20?o<c0050?o<V@3oc<`0olc<0?o<c03oc9T00`3oVIT4
0<bIIP80c9VI0P3oc9TX0?o<c0D0olbI00<0olc<0?o<V@3oc9T04`3oc<`30?o<V@030?nIV@3<VIT0
c9VI00@0c9VI203<VFH00`3<VIT0c9UV0<bIV@070<bIV@80oiVI00<0c<bI0?nIV@3oc9T03P3oc9T0
0`3oVIT0c9VI0<bIV@0A0<bIV@<0c<bI1@3<VFH40<bIV@030<c<V@3oool0oooo03h0oooo000k0?oo
o`030?o<c03oc9T0olbI00<0olc<00@0olbI0?nIV@3oVIT0oiVI103<VFH20<bIV@80olbI9P3oc<`9
0?o<VA@0olc<0P3oc9T00`3oVIT0c9VI0?nIV@020<bIV@030<bIIP3<VIT0c9VI00P0c9UV2@3<VIT0
0`3oVIT0c<bI0?o<V@0>0?o<V@050?nIV@3oc9T0oiVI0<bIV@3oVIT04P3<VIT01@3<c9T0c9VI0<bI
V@3<VIT0c9UV00P0c9VI@03oool003X0oooo0P3oc<`20?o<V@<0olc<00@0olbI0?nIV@3<VFH0c9VI
103<VFH20<bIV@80olbI9@3oc<`:0?o<VA@0olc<0P3oc9T20?nIV@L0c9VI1P3<VFH00`3<VIT0c9UV
0<bIV@080<bIV@030?nIV@3oc9T0olbI00/0olbI0P3oVIT00`3oc9T0c9VI0<bIV@0D0<bIV@<0c<bI
203<VIT00`3<VFH0c9VI0<c<c00o0?ooo`00>P3oool20?o<c080olbI0`3oc<`0103oc9T0oiVI0<bI
V@3oVIT40<bIIP80c9VI0P3oc9TK0?o<c0030?o<V@3oc<`0olc<0080olc<00@0olbI0?o<c03oc<`0
olc<2P3oc9TE0?o<c0<0olbI00<0oiVI0<bIV@3<VIT01@3<VIT50<bIIP@0c9VI00<0c9UV0<bIV@3<
VIT0103<VIT00`3oVIT0c<bI0?nIV@0;0?o<V@060<bIV@3oVIT0c9VI0?o<V@3oVIT0olbI503<VIT3
0<c<V@L0c9VI0`3<VFH00`3oc<`0oooo0?ooo`0m0?ooo`00>P3oool0103oc<`0olbI0?o<V@3oc9T2
0?o<c0030?o<V@3oVIT0oiVI0080c9VI1@3<VFH00`3<c9T0olbI0?o<V@0K0?o<c0040?o<V@3oc<`0
olc<0?o<c0<0olbI00@0olc<0?o<V@3oc<`0olc<1P3oc9TG0?o<c0<0olbI00<0oiVI0<bIV@3<VIT0
103<VIT50<bIIP040<bIV@3<VFH0c9VI0<bIIPP0c9VI00<0oiVI0<c<V@3oc9T03@3oc9T01@3oVIT0
c<bI0?nIV@3<VIT0oiVI0180c9VI00D0c<bI0<bIV@3oVIT0c9VI0<bIIP050<bIV@050<c<V@3<VFH0
c9UV0<bIIP3<VIT0?`3oool003T0oooo00H0olc<0?o<V@3oVIT0c9UV0?o<V@3oVIT30<bIV@80VFIV
00<0c6IV0<bIIP3<VFH00P3<VFH00`3<VIT0olbI0?o<V@0M0?o<c080olbI00<0olc<0?o<V@3oc9T0
203oc9TK0?o<c080olbI0P3oVIT30<bIV@030<bIIP3<VIT0c9VI00H0c9UV00<0c9VI0<bIIP3<VIT0
1`3<VIT=0?o<V@050<bIV@3oVIT0c<bI0?nIV@3<c9T00P3<VIT00`3oVIT0c9VI0<bIV@0A0<bIV@<0
c<bI0P3<IVH01@3<VFH0c9VI0<bIV@3<VIT0c<bI00@0c9UV00<0olbI0?ooo`3oool0?03oool003T0
oooo00<0olc<0?o<V@3<VFH00P3oVIT00`3<VFH0c9VI0<bIV@0509UVIP80c6IV00@0c9UV0<bIV@3o
c9T0olbI7@3oc<`00`3oc9T0olc<0?o<V@0;0?o<VAX0olc<0P3oc9T00`3oVIT0c9VI0<bIV@020<bI
V@T0c9UV2@3<VIT00`3<c9T0oiVI0<bIV@040?o<V@030?nIV@3oc9T0olbI00H0olbI00@0oiVI0?o<
V@3<c9T0oiVI5@3<VIT20<c<V@050<bIV@2IIVH0c6IV0<aVIP3<VFH00P3<VIT00`3<c9T0c9VI0<bI
IP020<bIIP030<bIV@3oool0oooo03`0oooo000h0?ooo`80olc<00<0oiVI0<bIIP3oVIT00P3<VFH0
103oVIT0c9UV06Hc<`2IIS<209UVIP0509UV<`2IIVH0VFIV09UVIP3<VIT00P3oc9TF0?o<c0030?o<
V@3oc<`0olbI00H0olbI00H0olc<0?o<V@3oc9T0olc<0?o<V@3<c<`60?o<V@040?o<c03oc9T0olc<
0?o<VAD0olc<0`3oc9T50<bIV@P0c9UV00<0c9VI0<bIIP3<VIT01`3<VIT01@3oVIT0olbI0?nIV@3<
c9T0olbI0080oiVI00@0c9VI0?nIV@3oVIT0c9VI0P3oVIT01P3<c9T0oiVI0<bIV@3oVIT0c9VI0?nI
V@`0c9VI00<0c9UV0<bIV@3<VFH0203<VIT20<c<V@<0c6IV0P3<VFH30<bIV@@0c9UV00<0olc<0?oo
o`3oool0>`3oool003P0oooo00@0olc<0?o<V@3oVIT0oiVI0`3<VFH00`2IIVH0VFHc0<bIIP0209UV
IP<0VFHc0P2IIVH00`3<VIT0olbI0?o<c00K0?o<c080olbI00<0olc<0<c<c03oc9T0303oc9TH0?o<
c080olbI0P3oVIT0103<VIT0c9UV0<bIV@3<VIT80<bIIP`0c9VI00H0olbI0?nIV@3oVIT0c<bI0?o<
V@3<VIT20?nIV@0:0<bIV@3oVIT0c<bI0?nIV@3<VIT0oiVI0<bIV@3oVIT0c9VI0?nIVAD0c9VI00<0
oiVI0<bIV@3<VIT00`3<IVH20<bIIPD0c9VI0P3<VFH00`3oc<`0oooo0?ooo`0k0?ooo`00>03oool2
0?o<V@040<bIIP3oVIT0c9VI09UVIP80VFHc00<0c9UV0<bIV@2IIS<01@2IIS<00`2IIVH0c9VI0?o<
V@0T0?o<c0D0olbI00<0oiVI0?o<V@3oVIT01@3oc9TC0?o<c0<0olbI00<0oiVI0<bIV@3<VIT00P3<
VIT00`3<VFH0c9VI0<bIIP060<bIIP/0c9VI0P3oVIT01`3<VIT0oiVI0<c<V@3<c9T0oiVI0<c<V@3o
VIT00P3<VIT30?nIV@030<c<V@3oVIT0c9VI00l0c9VI00<0c9UV0<bIV@3<VIT01P3<VIT20<c<V@<0
c6IV0P3<VFH00`3<VIT0c9UV0<bIV@020<bIV@80c9UV00<0c9VI0?ooo`3oool0>`3oool003L0oooo
00d0olc<0?o<V@3oc9T0c9UV0?nIV@3<VFH0VFHc06Hc<`3<IVH0c9VI0<bIIP2IIS<0VFIV0080VFHc
00@0IS<c09UVIP2IIVH0c9VI0P3oc9TS0?o<c0@0olbI00<0oiVI0?o<V@3oVIT00`3<VIT0103oVIT0
olbI0?o<V@3<c<`B0?o<c0<0olbI00<0oiVI0<bIV@3<VIT00P3<VFH00`3<VIT0c9UV0<bIIP060<bI
IP030<bIV@3<VFH0c9VI00/0c9VI00@0oiVI0<bIV@3oVIT0olbI0P3oVIT01`3<VIT0oiVI0<bIV@3<
VIT0oiVI0<bIV@3oVIT0603<VIT00`3<c9T0c9VI0<bIV@020<aVIPD0c9UV0`3<VIT20<bIIP030<bI
V@3ool`0oooo03/0oooo000g0?ooo`060?o<c03oc9T0oiVI0<bIIP3oVIT0c9UV0P1V<c<20<bIIP06
0<aVIP2IIVH0c9UV09UVIP2IIS<0IS<c0P2IIVH00`3<VIT0olbI0?o<V@0R0?o<c0030<c<c03oc<`0
olc<00@0olbI0P3oVIT40<bIV@030<c<V@3oc<`0olbI0140olc<0P3oc9T20?nIV@@0c9VI2`3<VFH:
0<bIV@060?nIV@3<VIT0oiVI0<bIV@3<c9T0oiVI0P3<VIT00`3oVIT0c9VI0<bIV@0F0<bIV@030<bI
IP3<VIT0c9VI00<0c9VI0P3<c9T0103<VIT0c6IV09UVIP2IIVH40<aVIP070<bIIP3<VIT0c9VI0<bI
V@3<VFH0c9VI0?o<c00l0?ooo`00=`3oool0303oc<`0olbI0<bIIP3oVIT0olbI09UVIP1V<c<0c6IV
09UVIP1V<c<0IS<009UV<`80VFIV00H0VIUV09UVIP2IIVH0VFIV0<bIV@3oc9TB0?o<c0030<c<c03o
c9T0olc<00/0olc<00<0c<c<0?o<c03oc<`00`3oc<`00`3<c<`0olbI0?o<V@020?o<V@030?nIV@3<
VIT0c9VI00@0c9VI00<0c<bI0?o<V@3oc<`03P3oc<`40?o<V@040?nIV@3<VIT0c9VI0<bIV@X0c9UV
<`3<VIT01@3<c9T0c9VI0<bIV@3<IVH0VFIV00@0VFHc00<0VC<c0<aV<`3<IVH00P3<VFH00`3<VIT0
c9UV0?o<V@0l0?ooo`00=`3oool00`3oc9T0oiVI0<bIIP020?nIV@0?09UVIP1V<c<0c6IV09UV<`0c
0000IS<c09UVIP2IVFH0VFHc06Hc<`2IIVH0VFHc09UVIP3<VIT0olbI00h0olc<203oc9T40?o<c004
0<c<c03oc9T0olc<0?o<c0D0c<bI00D0c9VI0<c<V@3<c9T0c9VI0<c<V@020?o<V@040?nIV@3<VIT0
c9VI0?nIV@D0c9VI0P3oc9T>0?o<c0@0olbI0`3<VIT=0<bIIPl0c9VI00<0c<bI0<bIV@3<VIT08P3<
VIT00`3<VFH0VFIV09UV<`0409UV<`070<aV<`3<IVH0c6IV0<bIIP3<VIT0c9UV0?o<V@0l0?ooo`00
=P3oool0303ool`0olbI0<bIIP3oIVH0oiVI0?o<V@2IIVH0VFHc0<aVIP1V<c<0<`0009UV<`D0IS<c
00@0IVHc09UVIP3<VIT0olbI4`3oc<`00`3oc9T0c<bI09VIIP020<bIV@040<c<V@3<VIT0c9VI0<bI
V@80c9UV00<0c9VI0<bIIP3<VFH0103<VIT00`3<VFH0c9VI0<bIIP0<0<bIV@030?o<V@3<c<`0olc<
00`0olc<103oc9T00`3oVIT0c9VI0<bIIP0A0<bIIP80c9VI00<0c9UV0<bIV@3<VIT0203<VIT00`3<
c9T0c9VI0<c<V@060<bIV@030<c<V@3<VIT0c<bI01<0c9VI00H0c<bI0<bIV@3<VIT0c9VI0<bIIP2I
IVH509UV<`80c6Hc00D0c6IV0<bIIP3<VIT0c9UV0?nIV@0l0?ooo`00=P3oool0303oc<`0olbI0<bI
IP3<VFH0oiVI0?o<V@3<IVH0IS<c09UV<`0c<c<0<`0006Hc<`<0<c<c0`1V<c<0101VIVH0c9VI0?o<
V@3oc9T?0?o<c0<0olbI00@0c9VI0<bIIP2IVFH0VFHc0P2IIVH01P2IIS<0VFIV09UVIP2IIVH0c9UV
09VIIP<0c9UV0`3<VIT00`3<VFH0c9VI0<bIIP030<bIIPL0c9VI103oc9T>0?o<c0<0olbI103<VIT>
0<bIIQT0c9VI00@0c<bI0<bIV@3<VIT0c<bI2@3<VIT00`3<VFH0c9VI0<bIV@060<bIV@040<c<V@3<
VIT0c9VI0<bIIP80VFIV1@2IIS<01P3<IS<0c6IV0<bIIP3<VIT0c9UV0<bIVC`0oooo000f0?ooo`0=
0?o<c03oc9T0c9UV0?mVIP3oVIT0olbI0<bIIP2I<c<0IS<c03<0000c<`00IS<c03<c000203<c<`@0
IS<c00<0c9VI0?o<V@3oc<`03`3oc<`20?o<V@050<c<V@3<VIT0c9UV0<c<V@3<VFH00P2IIS<206Hc
<`0609UV<`2IIVH0VFIV0<bIIP3<VIT0c9UV1`2IIVH20<bIIP030<aVIP3<VFH0c9UV00D0c9UV00<0
c9VI0?o<V@3oc9T00P3oc9T=0?o<c0<0olbI00D0oiVI0<bIV@3<VFH0c9UV0<bIV@0;0<bIIPL0c9VI
0P3<VFH0103<VIT0c9UV0<bIV@3<VFH90<bIV@80c<bI0P3<VIT00`3<c9T0oiVI0<bIV@0G0<bIV@03
09VIIP2IIVH0VFIV00@0VFHc0`3<IS<20<bIIP80c9VI?03oool003H0oooo00@0olc<0?nIV@3oIVH0
c9UV0P3oc9T00`3<VFH0IS<c06Hc<`0303<0000403<c001V<c<0IS<c03<c<`<0IS<c00<0c9VI0?o<
V@3oc<`04@3oc<`20?o<V@040<c<V@3<VIT0c<bI0<bIIP80VFHc0P1V<c<01@2IIVH0c9VI0<c<V@3<
c<`0VIVI0080IS<c00<0VFIV06Hc<`1V<c<00`1V<c<209UV<`<0c6IV0P3<VFH20<aVIP<0c9UV00<0
c9VI0?o<V@3oc<`03@3oc<`20?o<V@040?nIV@3<VIT0c9VI0<bIV@`0c9UV2P3<VIT01P3<VFH0c9VI
0<bIV@3<VIT0c9UV0<bIV@<0c9UV00<0c9VI0<bIIP3<VIT00`3<c9T20<bIV@030<c<V@3<VIT0c9VI
01H0c9VI00<0c9UV09UVIP2IIVH0102IIS<20<aV<`80c6IV00<0c9UV0<bIV@3<VIT0?03oool003H0
oooo00P0olbI0<bIIP3oIVH0c9UV0?nIV@3oc<`0c9VI06Hc<`<0<`0000<0<c<003<c<`1V<c<0101V
<c<00`1VIVH0c9VI0?o<V@0D0?o<c0030?o<V@3<VFH0c<bI0080c9VI00D0VFIV06Hc<`1V<c<0VIUV
0<bIV@020<c<c00506IVIP1V<c<0VIUV0<bIV@1V<c<00P0c00001@1V<c<0VFHc06Hc<`1V<c<0VFIV
0080c6IV00<0VFIV09UV<`2IIS<0102IIS<0103<VFH0olbI0?o<V@3oc9T;0?o<c0@0olbI0P3<VIT<
0<bIIQL0c9VI00@0c9UV0<bIV@3<VIT0c9VI0`3<c9TG0<bIV@030<bIIP2IIVH0VFIV00@0VFHc0P3<
IS<20<aVIP030<bIIP3<VIT0c9VI03`0oooo000e0?ooo`090?ooc03oc9T0c9UV0?mVIP3<IVH0olbI
0?o<c03oVIT0IS<c0080<`0000<0<c<003<c<`1V<c<01P1V<c<00`3<VIT0c<c<0?o<c0090?o<c003
0?o<V@3oc<`0olc<00P0olc<0P3<VFH20<c<V@80c9VI00X0VIUV06Hc<`2IIVH0VIUV09VIV@1V<c<0
VFHc0<bIV@3<c9T0IVIV0P0c00001@1V<c<0VFHc09UV<`2IIS<0VFIV0080c9VI00@0c9UV0<aVIP2I
IVH0VFHc0P2IIVH0103<IVH0c9UV0<bIV@3oc9T<0?o<c0<0olbI00@0oiVI0<bIV@3<VIT0c9VI1P3<
VFH20<aVIP<0c9UV0P3<VIT00`3<c9T0c9VI0<bIV@020<c<V@80olbI00<0c<bI0?o<V@3<c9T00`3<
c9TU0<bIV@030<bIIP2IIVH0VFIV00H0VFHc00@0VFIV0<aVIP3<IVH0c9UV0P3<VITl0?ooo`00=@3o
ool01@3oc<`0olbI0<bIIP3<IVH0c9UV0080oiVI00<0olbI09UVIP1V<c<01@0c<c<306Hc<`0306IV
IP1VIS<0c<bI01H0olc<00T0olbI0<bIV@3<VFH0c9VI0<c<c03<VFH0c9VI09VIIP2IIVH00`1V<c<0
101VIVH0VIVI09VIV@2IIYT203<0000503<c<`1VIS<0VFHc09UV<`2IIVH00`3<VIT0102IIVH0VFHc
09UV<`2IIS<20<bIIP<0olbI3@3oc<`30?o<V@80c9VI1P3<VFH40<aVIP80c9UV0P3<VIT50<c<V@03
0<bIV@3<c9T0c<bI00<0c9VI00<0c<bI0<bIV@3<VIT00`3<c9T:0<bIV@<0c<bI2@3<VIT00`3<VFH0
c9VI0<bIV@080<bIV@050<bIIP2IIVH0VFIV09UV<`2IIVH00`2IIS<30<aVIP040<bIIP3<VIT0c9VI
0<bIVC`0oooo000c0?ooo`050<c<c02IVIT0c<bI0?o<V@3oIVH00P3<IVH01P3<VIT0oiVI0?nIV@3<
VFH0IS<c03<c<`80<`00100c<c<206Hc<`0309UVIP3<c9T0olbI01H0olc<00@0olbI0<bIV@3<VFH0
c9VI0P3oc<`20<bIV@030<bIIP2IIVH0IS<c0080IS<c00D0IVIV06HcIP000000<`0003<c<`0306Hc
<`0509UVIP3<VIT0VIVI0<bIIP2IIVH00P2IIS<20<bIIP040<bIV@3oc9T0olbI0?o<V@`0olc<103o
c9T20<bIV@D0c9UV0`3<IVH01@2IIVH0VC<c09UV<`2IIS<0c6IV0080c9VI0P3<c9T20<bIV@030<bI
IP3<VIT0c9UV00H0c9UV2P3<VIT00`3<VFH0c9VI0<bIV@090<bIV@050<bIIP3<VIT0c9VI0<bIV@3<
VFH0203<VIT20<bIIPD0VFIV00@0VFHc09UVIP3<IVH0c6IV0P3<VFH30<bIVC`0oooo000c0?ooo`05
06IV<`1V<c<0olbI0?o<V@3<VFH00P3<IVH01P3<VIT0oiVI0?nIV@3<VIT0IS<c03<c00<0<c<c0P1V
<c<01@0c<c<0IS<c06Hc<`2IIVH0c9VI01L0olc<0P3oc9T30<bIV@070?o<c03oc9T0c<bI0<c<V@3<
VFH0VFIV09UV<`0306Hc<`0303<0000c<`00<c<000<0IS<c00<0VFIV06IVIP2IIVH00P2IIVH30<aV
IP030<bIIP3<VIT0olbI0080olbI203oc<`00`3ool`0olc<0?o<c0020?o<c0<0olbI0P3<VIT50<bI
IP090<aVIP3<VFH0c6IV09UVIP1V<c<0IS<006Hc<`2I<c<0c6IV00H0c9UV00<0c6IV0<bIIP3<VFH0
1@2IIVH0103<IVH0c9UV0<bIIP3<VFH70<bIV@030<bIIP3<VIT0c9VI00L0c9VI0`3<VFH;0<bIV@80
c9UV00P0VFIV09UV<`2IIS<0VFHc09UVIP2IIS<0VFIV0<aVIPD0c9UV00<0c9VI0?ooo`3oool0>P3o
ool00380oooo00<0c9VI03<0001V<c<00P3oc9T00`3oVIT0c6IV0<aVIP040?o<V@0509UVIP0c0000
<c<003<c<`1V<c<00`0c<c<206Hc<`0309UVIP3<c9T0olc<01L0olc<0`3oc9T20<bIV@80olc<00L0
c9VI0<bIIP3<VIT0VFIV09UV<`1VIS<0VFHc00H0IS<c0`2IIS<40<aVIP040<bIIP3<VIT0olbI0<bI
V@80olbI3@3oc<`30?o<V@80c9VI1`3<VFH20<aVIP0509UV<`1V<c<0IS<c09UV<`2IVFH00P3<VFH0
0`3<VIT0c9UV09VIIP0309UVIP80VFHc202IIVH00`3<IVH0c9UV0<bIV@030<bIIP030<bIV@3<VFH0
c9UV00@0c9VI00<0c9UV0<bIV@3<VFH00P3<VIT30<bIIPT0c9VI0P3<VFH01@2IVFH0VFHc09UV<`2I
IS<0VFIV00<0VFHc103<VFH00`3<VIT0c9UV0<bIV@0l0?ooo`00<03oool01P3oc?l0VFIV06Hc<`0c
0000IS<c0<bIIPL0olbI00<0oiVI09UV<`0c00000P0c<c<00`1V<c<0<c<c03<c<`0306Hc<`0309UV
IP3<c9T0olbI01T0olc<0P3oc9T20<bIV@070?o<c03<VIT0c<bI0<c<V@2IIVH0VIUV0<bIIP0209UV
IP0306IV<`2IIS<0VFIV0080VFHc0P2IIVH00`2IVFH0c9UV0<aVIP020<aVIP<0olbI00<0c9VI0?o<
V@3oc9T01P3oc<`30?ooc0<0olc<103oc9T20<bIV@P0c9UV00<0c6IV09UVIP2IIVH00P2IIS<00`2I
VIT0c9VI0<c<c0030<c<c00409UVIP2IIS<0IS<c06Hc00<0IS<c00<0VFHc09UVIP2IIVH00P2IIVH3
09UV<`030<aVIP3<VFH0c9UV0100c9UV2@3<VIT20<bIIP050<aVIP2IIS<0VFHc09UV<`2IIVH00P2I
IS<00`2IIVH0c9UV0<bIIP020<bIIP040<bIV@3<VFH0c9UV0?o<c3/0oooo000`0?ooo`0609VIV@1V
<c<0<c<c03<0001V<`00c9UV1@3oc9T0203oVIT0olbI0<bIV@2IIS<0<c<006Hc<`0c<c<0IS<c0`0c
<c<206Hc<`0309UVIP3<c9T0olc<00T0olc<0P3oc9T?0?o<c080olbI00T0c9VI0<bIIP3<VIT0olbI
0<c<V@3<VIT0c<bI0<bIV@3<VFH0102IIVH209UV<`80c6IV0P3<VFH20<aVIP050<bIIP3<VIT0olbI
0<bIV@3oVIT00P3oc9T<0?o<c0@0olbI00<0c9VI0<bIIP3<VFH0103<VFH00`3<IVH0c9UV0<bIIP03
0<aVIP0409UV<`2I<c<0VFIV0<bIV@<0c<c<00D0VIVI06Hc<`1V<c<0IS<c06Hc000506Hc<`0309UV
<`2IIVH0VFIV00@0VFHc00D0VFIV09VIIP2IVFH0VIUV0<bIIP0309VIIPL0c9UV2`3<VIT30<bIIP06
09UVIP2IIS<0VFIV06IVIP2IIS<0VFIV0P2IIS<30<bIIP80c9VI0P3<VFH00`3oc<`0oooo0?ooo`0i
0?ooo`00;`3oool0203<VIT0IS<c03<c<`1V<`00<`0003<c003<VFH0oiVI103oc9T20?nIV@030<bI
V@2IIS<0IS<c0080IS<c0P0c<c<01P0c<`00<c<c03<c<`1V<c<0VFIV0<c<V@X0olc<0`3oc9T?0?o<
c080olbI00<0c<bI0<bIV@3<VIT00P3<VIT00`3<c9T0c9VI0<bIV@040<bIIP80c6IV0P3<VFH20<aV
IP040<bIIP3<VIT0c9VI0<bIV@<0oiVI0`3oc9T50?o<c080ooo<103oc<`40?o<V@80c9VI1@3<VFH0
2`3<IVH0c9UV0<bIIP3<VFH0c6IV09UVIP3<IVH0VFIV09UV<`2IVFH0c9VI0080c<c<00D0IVIV09UV
<`2IVFH0IS<c03<0000203<c<`0506Hc<`2IIS<0IVIV06Hc<`1VIVH00P2IIVH209UV<`0306Hc<`2I
IVH0VFIV00@0VFIV00@0VFHc09UVIP2IIVH0c6IV103<VFH<0<bIV@80c9UV00D0VIUV09UVIP2IIS<0
VFHc06Hc<`0209UVIP80VFHc00D0c9UV0<bIV@3<VIT0c9VI0<bIIP020<aVIP030<c<c03oool0oooo
03T0oooo000^0?ooo`050<bIV@1V<c<0<c<c03<c000c<c<00P0c00000`1V<c<0c6IV0?nIV@020?o<
V@<0c9UV00<0VFHc06Hc<`1V<c<00`1V<c<303<c<`80IS<c00<0VFIV0<c<c03oc<`02@3oc<`01@3o
c9T0c9VI0<bIIP3<VIT0olbI00h0olc<1P3oc9T0103<c9T0c9VI0<bIV@3<VIT50<bIIPP0c9VI103o
c9T60?o<c0030?ooc03oc<`0ooo<00@0olc<103oc9T30<bIV@T0c9UV00D0c6IV09UVIP3<VFH0c9UV
0<aVIP0309UVIP0606IVIP3<VIT0c9VI03<c<`000000<c<c0P1V<c<0101VIS<0IS<c06Hc<`1VIVH2
09VIV@0309VIIP1VIVH0IVHc00<0IS<c0P1VIS<01@1VIVH0VFHc09UVIP3<IVH0c9UV00l0c9VI0P3<
VFH0102IVFH0VFIV06IVIP1V<c<206IV<`0509UV<`1V<c<0IS<c09UV<`3<VFH00P3<VIT01@3<VFH0
c6Hc0<aVIP3<VFH0olc<03/0oooo000]0?ooo`060<c<o`2IIVH0IS<c06Hc<`0c<`00<c<c0`0c0000
1`1V<c<0c6IV0<bIIP3<VFH0c6IV09UVIP2IIS<00`1V<c<603<c<`80IS<c00<0VFIV0?o<V@3oc<`0
2P3oc<`0103oc9T0c9UV0<bIIP3<VIT20?o<V@d0olc<1`3oc9T=0<bIV@030?nIV@3oc9T0olbI00<0
olbI1P3oc<`00`3ool`0olc<0?o<c0040?o<c0@0olbI0`3<VIT:0<bIIP0309UVIP3<IVH0c9UV0080
c9UV00<0c6IV09UVIP1V<c<00P2IVIT01@0c<c<0000003<c<`1VIVH0IVHc00<0IS<c00D0IVIV09VI
IP2IVIT0VFIV06IVIP0606Hc<`0306IVIP2IIVH0c6IV00D0c9UV3@3<VIT01@3<VFH0VIUV09UVIP1V
<c<0IVHc0080IS<c00D0IVHc06Hc<`1V<c<0VFHc0<bIIP020<bIV@050<bIIP3<IS<0c6IV0<aVIP3<
c<`0>`3oool002d0oooo00<0c<c<06Hc<`1V<c<00P1V<c<00`0c<c<0<`0003<0000203<0000406Hc
<`2IIS<0VFHc09UV<`H0IS<c0P0c<c<00`0c<`00<c<c03<c000206Hc<`0309UVIP3<c9T0olc<00/0
olc<00H0oiVI0<bIIP3<VFH0c9VI0<c<V@3oc9T?0?o<c080olbI00<0c9VI0?o<V@3oc9T03@3<VIT4
0?o<V@H0olc<00<0ooo<0?o<c03oc<`01@3oc<`40?o<V@<0c9VI2`3<VFH00`3<IVH0c9UV0<bIIP02
0<bIIP080<aVIP2IIVH0VFHc06IVIP0c<c<0000003<0000c<c<406Hc<`0506IVIP2IIVH0VFIV06Hc
<`0c<c<00P1V<c<01@1VIVH0VFIV09UV<`2IIS<0VFIV00P0c9UV303<VIT00`3<VFH0VIUV09UVIP02
06IV<`0306Hc<`2IIS<0IVHc00<0IS<c00@0c9UV0<bIV@3<VIT0c9UV0P3<IS<00`3<VFH0olc<0?oo
o`0j0?ooo`00;@3oool00`2IVIT0IS<c06Hc<`0306Hc<`L0<`0000@0VFHc06Hc<`1V<c<0IS<c0P0c
<c<206Hc<`@0<c<c0P1V<c<00`2IIVH0c<bI0?o<c00;0?o<c0030?o<V@3<VIT0c9UV00<0c9VI00<0
olbI0?o<c03oc<`0303oc<`40?o<V@`0c9VI00<0olbI0<bIV@3oc9T0103oc9T00`3oc<`0olbI0?o<
c0030?o<c0030?ooc03oc<`0olc<00@0olc<103oc9T00`3<c9T0c9VI0<bIV@0=0<bIIP80c9VI0`3<
VFH01`2IIVH0IVHc06Hc<`0c<c<0<`0003<c001V<`000`1V<c<206IV<`@0IS<c102IIVH00`3<IVH0
c9UV0<bIIP040<bIIP050<bIV@3<VFH0c9UV0<bIV@3<VFH02P3<VIT00`3<VFH0VFIV06Hc<`0806Hc
<`040<bIIP3<VIT0c9VI0<aVIP80c6Hc00<0c9UV0?o<c03oool0>P3oool002d0oooo00<0VIVI06Hc
<`1V<c<00`1V<c<0100c0000<c<003<c000c<`0303<000<0IS<c100c<c<01@1V<c<0<c<c03<c<`0c
<c<0<c<00080IS<c00@0VFIV0?o<V@3oc<`0olbI2`3oc<`01`3oVIT0c9VI0<bIIP3<VIT0c<bI0<bI
V@3oc9T0103oc<`00`3ool`0olc<0?ooc0070?o<c0040?o<V@3<c9T0olbI0?o<V@d0c9VI103oc9T0
0`3oc<`0olbI0?o<V@0;0?o<c0D0olbI00<0c<bI0<bIV@3<VIT03@3<VFH30<bIV@80c9UV0P2IIVH2
09UV<`H0IS<c00X0<c<c06Hc<`1V<c<0IS<c06IVIP2IIVH0VFHc09UVIP2IVFH0c6IV1`3<VFH0103<
VIT0c9UV0<bIIP3<VIT20<bIIPL0c9VI0P3<VFH00`2IIVH0IS<c06Hc<`0706Hc<`<0c9VI00D0c6IV
0<aV<`3<IVH0c9UV0?o<c00k0?ooo`00;@3oool00`2IIVH0IS<c03<c<`0306Hc<`0403<0000c<c<0
<c<006Hc00<0<`000P1V<c<;03<c<`0306Hc<`2IIVH0olbI0080olbI303oc<`00`3oVIT0c9UV0<bI
V@040<bIV@060?o<V@3oc<`0olc<0?ooc03oc<`0ooo<1`3oc<`30?o<V@@0c9VI00@0c<bI0<bIV@3<
VIT0c9VI1@3<VFH20<bIV@D0olbI303oc<`40?o<V@D0c9VI2P3<VFH01`3<VIT0c9UV0<bIIP3<VIT0
c<bI0<bIV@3<VFH0102IIVH01P2IIS<0VFIV06Hc<`1V<c<0VFHc06IVIP80IS<c0P2IIVH01@2IVFH0
VFHc09UVIP3<VFH0VIUV00P0c9UV3@3<VIT00`3<VFH0VIUV09UVIP0906Hc<`80c9VI00H0c9UV0<aV
<`3<IS<0c6IV0<bIIP3oc<`k0?ooo`00;03oool00`3<c<`0IVIV06Hc<`0406Hc<`80<c<c00@0IS<c
03<c<`0c<`00<c<00P1V<c<903<c<`0703<c000c<c<0IS<c06Hc<`2IIVH0c<bI0?o<V@0=0?o<c003
0?o<V@3<VIT0c9VI00<0c9VI00<0c9UV0<bIV@3oc<`0203oc<`01@3<c<`0olbI0<c<V@3oc9T0c<bI
00D0c9VI1@3<VFH30<aVIP80c9UV0P3<VIT40?o<V@/0olc<1@3oc9T50<bIV@/0c9UV00<0c9VI0<bI
IP3<VFH00`3<VIT0103<VFH0c9VI0<bIIP2IVFH309UVIP0906IV<`2IIVH0VFIV09UVIP1VIVH0VFIV
09VIIP2IIVH0VIUV0080c6IV2`3<VFH;0<bIV@030<bIIP2IIVH0VFHc00<0IS<c00@0<c<c06Hc<`0c
<`00<c<c0P1V<c<20<bIV@050<bIIP3<IS<0c6Hc0<aVIP3<VFH0?03oool002`0oooo00<0VIVI06Hc
<`1V<c<0101V<c<00`0c<c<0IS<c06Hc<`0506Hc<`0403<c<`1V<c<0<c<c03<00080<c<000D0<c<c
06Hc<`0c<c<0<c<003<c<`0206Hc<`0309UVIP3<c9T0olbI00h0olc<00@0olbI0?nIV@3<c9T0c9VI
0P2IVFH01P3<VFH0VIUV0<bIIP2IVFH0c9UV09VIV@<0c9UV1P2IIVH409UV<`0309UVIP2IIS<0VFHc
0080VFHc1@2IIVH01P3<IVH0c9UV0<bIV@3<c9T0oiVI0?o<V@/0olc<1P3oc9T0103<c9T0c9VI0<bI
V@3<VIT;0<bIIP80c9VI0P3<VFH70<bIV@<0c9UV0P2IVFH0103<IVH0VFIV0<aVIP2IVFH209UVIP03
0<aVIP3<VFH0c9UV00D0c9UV0P3<VIT00`3<VFH0c9VI0<bIV@0<0<bIV@0309VIIP2IIVH0IS<c00D0
IS<c00L0<c<c03<c000c<`00IS<c0<bIV@3<VFH0c6IV0080c6Hc00<0c6IV0<bIV@3oool0>`3oool0
02`0oooo00P0c9VI06Hc<`1V<c<0IS<c03<c<`0c<`00<c<c03<c00<0<c<c101V<c<503<c<`0303<0
000c<c<0IS<c00<0<c<c0P1V<c<0102IIVH0c9VI0?o<V@3oc9T@0?o<c0030?nIV@3<VIT0c9VI00H0
c9UV0P2IVFH609UVIP80VFHc0`2IIVH309UV<`0409UVIP2IIS<0VFIV09UV<`80VFIV0`3<VFH20<bI
V@80olbI2P3oc<`70?o<V@80c<bI0`3<VIT:0<bIIP@0c9VI00<0c9UV0<bIV@3<VIT0103<VIT30<bI
IP0709VIIP3<VFH0c9UV0<bIIP3<IVH0VFIV09VIIP040<bIIP030<bIV@3<VFH0c9VI00P0c9VI00<0
c9UV0<bIV@3<VIT01`3<VIT00`3<VFH0VIUV06IVIP0506Hc<`80<c<c0P0c<`00102IIS<0c9VI0<bI
IP3<IVH20<aV<`030<aVIP3<VIT0oooo03/0oooo000/0?ooo`030<bIV@1V<c<0IS<c0080<c<c00D0
<c<003<c<`0c<`00<c<c06Hc<`0303<c<`80IS<c100c<c<203<c000503<0000c<c<0IS<c06Hc<`0c
<c<00P1V<c<0102IIVH0c9VI0?o<V@3oc9TA0?o<c0040?o<V@3<c9T0c9VI0<bIIP<0VFIV00<0c9UV
09VIV@3<VFH0302IIVH309UV<`0409UVIP2IIS<0VFIV0<aVIP<0c9UV0P3<VIT20?o<V@/0olc<1`3o
c9T20<c<V@<0c9VI103<VFH00`3<IVH0c9UV0<bIIP050<bIIPL0c9VI3P3<VFH20<bIV@030<bIIP3<
VIT0c9VI00P0c9VI00<0c9UV0<bIV@3<VIT01`3<VIT01`3<VFH0VFIV06Hc<`1V<c<0<c<c06Hc<`0c
<c<00P1V<c<0100c<c<0<c<003<0002IIS<20<bIIP050<aVIP2IIS<0c6Hc0<aVIP3<VIT0?03oool0
02`0oooo00D0c9VI06Hc<`1V<c<0IS<c03<c000203<c<`0303<c000c<c<0<c<000H0<c<c00<0<c<0
06Hc<`0c<c<00P0c<c<203<c00D0IS<c00@0VFHc0<bIV@3oc9T0olbI4`3oc<`01@3oc9T0VIUV0<bI
IP2IIVH0c9UV00<0VFIV00@0c9UV09VIIP2IVIT0c9UV2@2IIVH00`2IIS<0VFIV09UVIP0209UVIP04
0<aVIP3<VFH0c9UV0<bIIP80oiVI103oc9T90?o<c0L0olbI00<0oiVI0<c<V@3<VIT00P3<VIT20<bI
IP80VFIV0P2IIS<00`2IIVH0c6IV0<aVIP040<bIIPX0c9VI00<0c9UV0<bIV@3<VFH0103<VIT00`3<
VFH0c9VI0<bIIP0=0<bIV@030<bIIP3<VIT0c9VI00D0c9VI0P3<VFH00`2IVFH0VFIV06Hc<`0206Hc
<`0403<c<`1V<c<0IS<c03<c<`80<c<000<0<c<c0<aVIP3<VFH00P3<IVH20<aV<`030<aVIP3<VIT0
oooo03/0oooo000/0?ooo`090<bIc01V<c<0IS<c06Hc<`0c<`00<c<c03<c000c<c<0<c<000<0<c<c
00D0<c<003<c<`0c<c<0<c<c03<0000303<c<`0403<c000c<c<0<c<c03<c<`@0IS<c00D0IVIV0<bI
V@3<c9T0c<bI0?o<V@0C0?o<c0030?o<V@3<VIT0c9VI00@0c9VI00<0VIVI0<bIIP3<VIT0103<VIT0
102IVFH0c9UV0<bIIP2IVFH80<bIIP80c9VI00<0oiVI0?o<V@3oc<`03P3oc<`60?o<V@80c<bI0`3<
VIT20<bIIP0309UVIP2IIS<0VFHc00@0VFHc00<0c6IV0<bIIP3<VFH00`3<VFHO0<bIV@030<bIIP3<
VIT0c9VI00D0c9VI0P3<VFH0102IVFH0IS<c06Hc<`1V<c<303<c<`0506Hc<`0c<c<0<c<c03<c001V
<c<00`3<VFH01P3<IVH0VFHc0<aV<`3<IVH0c9UV0<c<c3/0oooo000/0?ooo`030<c<c01VIS<0IS<c
00H0<c<c0`0c<`001@0c<c<0IS<c03<c<`0c<c<0<`000080<c<c00D0<c<003<c<`0c<`00<c<003<c
<`0206Hc<`0506IV<`1V<c<0IVHc0<bIIP3<VIT00P3oc9TE0?o<c0030<c<c03oc<`0oiVI0080c<bI
00L0oiVI0<c<V@3oc9T0c<c<0?o<V@3<c9T0oiVI0080c<bI00<0c9VI0?nIV@3<c9T00P3<c9T00`3o
VIT0c<bI0?nIV@040?o<V@030?o<c03oc9T0olc<00d0olc<103oc9T01P3oc<`0olbI0?o<V@3oc9T0
oiVI0<c<V@80c9VI0P3<VFH00`2IIVH0VFHc09UV<`0509UV<`0309UVIP3<IVH0c9UV0080c9UV803<
VIT00`3<VFH0c9VI0<bIV@040<bIV@80c9UV00<0VFIV06Hc<`1V<c<00P0c<c<0101V<c<0<c<c03<c
<`0c<c<206Hc<`0509UV<`3<VFH0c9UV0<bIIP3<IVH00P3<IS<20<bIIP0309UVIP3oool0oooo03T0
oooo000/0?ooo`050<c<c02IIVH0IS<c06Hc<`0c<`000P0c<c<00`0c<`00<c<c03<c<`0203<c<`08
06Hc<`0c<c<0<c<c03<c<`0c0000<c<003<c<`0c<`0603<c<`0606Hc<`2IIVH0VFIV0<bIIP3<VIT0
c<bI0`3oc9TI0?o<c0030<c<c03oc<`0c<c<0080olc<00D0c<c<0?o<c03oc<`0olc<0<c<c0030?o<
c0040<c<c03oc<`0olc<0<c<c0l0olc<00@0olbI0?o<c03oc<`0olc<203oc9T00`3<c9T0oiVI0<c<
V@020<bIV@030<bIIP2IIVH0VFIV00<0VFHc0`2I<c<00`2IIS<0VFIV0<aVIP030<bIIR@0c9VI00D0
c9UV0<bIV@3<VFH0c9UV09UVIP0206Hc<`H0<c<c0P1V<c<01@2IIVH0c9UV0<aVIP3<IVH0VFIV0080
VFHc00@0c6IV0<bIIP1VIS<0c<co>P3oool002d0oooo00L0VFIV06Hc<`1V<c<0<c<c03<c001V<c<0
<c<00080<c<c0P0c<`0403<c<`0503<c000c0000<c<003<c<`0c<`000`0c<c<406Hc<`0406IVIP3<
VFH0c9VI0<c<V@@0olbI7@3oc<`0103ool`0olc<0?ooc03ool`50?o<c0030<c<c03oc<`0olc<00l0
olc<00<0olbI0?o<c03oc<`02`3oc9T01P3oVIT0c<bI0?o<V@3<c9T0c9VI0<bIIP80VFIV102IIS<3
06Hc<`@0VFHc0`3<VFHE0<bIV@80c9UV2P3<VIT01@3<VFH0VFIV09UVIP1VIS<0IS<c00L0<c<c0P1V
<c<00`2IIS<0c6IV0<bIIP0209UVIP80VFHc00D0c6IV09UVIP1V<c<0VIVI0?ooc00i0?ooo`00;03o
ool0103oc?l0VFIV06Hc<`1V<c<203<c<`0603<c000c<c<0<c<c03<c000c<c<0<c<00`0c<c<0101V
<c<0<c<003<0000c000203<c<`0303<0000c<c<0<c<c00@0IS<c00@0IVIV09VIIP3<VIT0c9VI1@3o
c9TH0?o<c0030?ooc03oc<`0olc<00@0olc<00<0ooo<0?o<c03oc<`05`3oc<`00`3oc9T0olc<0?o<
V@0=0?o<V@80c9VI0P3<VFH209UVIP80VFHc1`1V<c<0102IIS<0VFIV0<aVIP3<VFH@0<bIV@030<bI
IP3<VIT0c9UV00H0c9UV1`3<VIT00`3<VFH0VFIV09UVIP0206Hc<`D0<c<c1@1V<c<0102IIVH0c9UV
0<bIIP2IIVH209UV<`050<aVIP2IIS<0IS<c09VIV@3<c<`0>@3oool002d0oooo00@0VIUV06Hc<`1V
<c<0IS<c0P0c<c<0100c<`00<c<c03<c000c<`0603<c<`80<`0000@0<c<003<c<`0c<c<0<c<c1@1V
<c<01@1VIS<0VIUV0<bIV@3<VIT0c<bI0080olbI603oc<`0103ool`0olc<0?o<c03ool`20?o<c080
ooo<0P3oc<`30?ooc1P0olc<3`3oc9T20<c<V@80c9VI00<0c9UV09UVIP2IIVH00P2IIS<806Hc<`04
09UV<`2IIVH0c9UV0<bIIP@0c9VI00<0c9UV0<bIV@3<VIT00P3<VIT60<bIIP0309UVIP3<IVH0VFIV
0080VFIV0P3<VFH70<bIV@060<bIIP2IIS<0VFHc06Hc<`0c<c<0IS<c100c<c<206Hc<`0403<c<`0c
<`00IS<c09UV<`<0c9UV00P0VFIV0<aVIP3<VFH0VFHc06IV<`2IIVH0c9VI0<c<ocP0oooo000]0?oo
o`0309VIV@1V<c<0IS<c00<0IS<c100c<c<00`0c<`00<c<c03<c<`0303<c<`<0<`000`0c<c<406Hc
<`0306IV<`2IIVH0c9UV00D0c9VI00<0olbI0?o<c03oc<`03`3oc<`00`3ool`0olc<0?ooc0020?o<
c080ooo<00@0olc<0?ooc03ool`0olc<0P3ool`01@3oc<`0ooo<0?ooc03ool`0olc<0080ooo<00<0
olc<0?ooc03oc<`0503oc<`>0?o<V@80c<bI00<0olbI0<c<V@3<c9T00P3<VIT01@3<VFH0VFIV09UV
IP2IIVH0VFHc00P0IS<c0P2IIS<=0<bIIP030<aVIP2IIVH0VFIV00<0VFIV00<0c9UV0<bIV@3<VIT0
1P3<VIT20<bIIP80IVIV0P1V<c<00`0c<c<0<`0003<c<`0203<c<`0<06Hc<`0c<c<0<c<c03<c001V
<c<0VC<c09UV<`2IIVH0c6IV0<bIIP3<IVH0VFIV0P1V<c<00`2IIVH0VIVI0?o<c00h0?ooo`00;@3o
ool00`2IVIT0IS<c06Hc<`0406Hc<`80<c<c00@0<c<003<c<`0c<c<0<c<00`0c<c<01P0c<`00<`00
03<0000c<`00<c<c06Hc<`80<c<c0P1V<c<0101VIVH0VFIV09UVIP3<VFH20<bIV@80c<bI00<0olbI
0?o<c03oc<`04`3oc<`00`3ool`0olc<0?o<c0050?ooc0030?o<c03ool`0ooo<00@0ooo<0`3oc<`0
0`3ool`0olc<0?o<c00@0?o<c1@0olbI00D0c<bI0<bIV@3<VIT0c9VI0<bIIP0509UVIP0309UV<`1V
<c<0IS<c00D0IS<c00<0VFHc09UVIP2IIVH00P2IIVH0102IVFH0c6IV0<bIIP3<IVH909UVIP80c9UV
203<VIT20<bIIP80IVHc0P1V<c<01@0c<`00<c<c06Hc<`0c<`00IS<c0080<c<c00@0IS<c03<c<`1V
<c<0IS<c1P2IIS<01@1V<c<0IVHc09UVIP2IVIT0olco03P0oooo000]0?ooo`0309VIV@1V<c<0IS<c
00<0IS<c0P0c<c<00`0c<`00<c<c03<c000603<c<`0303<c000c0000<`000080<c<c1@1V<c<209UV
IP030<bIIP3<VIT0c9VI0080c<bI00<0olbI0?o<c03oc<`04@3oc<`0103ool`0olc<0?ooc03oc<`2
0?ooc0030?o<c03ool`0ooo<0080ooo<0P3oc<`01@3ool`0olc<0?ooc03ool`0olc<0080ooo<0P3o
c<`00`3ool`0olc<0?o<c00?0?o<c1@0olbI0P3<c9T30<bIV@030<bIIP2IVFH0VFIV0080VFIV0P2I
IS<606Hc<`@0VFHc102IIVH00`2IIS<0VFIV09UVIP0509UVIP80c9UV1`3<VIT40<bIIP<0IS<c0P0c
<`0703<c<`0503<c001V<`00IS<006Hc<`2I<c<01@1V<c<00`1VIS<0VFIV0<bIV@0i0?ooo`00;@3o
ool00`3<VIT0IS<c06Hc<`0306Hc<`0303<c<`0c<`00<c<00080<c<c00<0IS<c03<c<`0c<c<00`0c
<c<01@0c<`00<`0003<0000c<`00<c<c00@0IS<c0P1VIVH0102IIVH0c9UV0<bIV@3<VIT20<c<V@03
0?o<V@3oc<`0olc<0100olc<00<0ooo<0?o<c03oc<`02@3ool`01@3oc<`0ooo<0?ooc03ool`0olc<
00<0ooo<00<0olc<0?ooc03oc<`04@3oc<`F0?o<V@030?nIV@3<c9T0c9VI00<0c9VI0P3<VFH00`3<
IVH0VFIV09UVIP0309UV<`@0IS<c1@2IIS<309UVIP0309UV<`2IIVH0VFIV00<0VFIV0P3<VFH70<bI
V@050<bIIP3<VIT0c9UV0<bIIP2IVFH00P1V<c<00`0c<c<0<c<003<c<`0703<c<`0303<c000c0000
IP0000<0IS<0101V<c<00`1VIS<0VIVI0?ooo`0i0?ooo`00;@3oool00`3<VL`0IS<c06Hc<`0506Hc
<`80<c<c0`1V<c<303<c<`0306Hc<`0c<c<0<`000080<`001P1V<c<01@1VIVH0VFIV0<bIIP2IVIT0
c9VI0080c<bI0P3oc9TA0?o<c0040?ooc03oc<`0ooo<0?o<c0l0ooo<5P3oc<`E0?o<V@@0c<bI103<
VIT30<bIIP<0VFIV00<0VFHc06Hc<`1V<c<00P1V<c<00`2IIS<0IS<c09UV<`0509UV<`@0VFIV0P3<
VFH80<bIV@050<bIIP3<VIT0c9UV0<bIIP2IVFH00P1V<c<703<c<`0306Hc<`0c<c<0<c<c0080<c<0
0P0c00000`1V0000IS<006Hc<`0306Hc<`0306IV<`3oc?l0oooo03T0oooo000]0?ooo`030<bIV@1V
IS<0IS<c0080IS<c00H0IVHc06Hc<`1V<c<0IS<c03<c<`1V<c<203<c<`0406Hc<`0c<c<0IS<c03<c
<`80IS<c0P0c<c<606Hc<`80VFIV00<0c9UV0<bIV@3<VIT00P3<VIT30?o<VA00olc<00D0ooo<0?o<
c03oc<`0ooo<0?o<c0050?ooc0050?o<c03ool`0ooo<0?ooc03oc<`01@3ool`E0?o<c1<0olbI00D0
oiVI0?o<V@3oVIT0olbI0?nIV@020<c<V@D0c9VI1@3<VFH00`3<IVH0VFIV09UVIP0409UV<`0306Hc
<`2I<c<0VFHc00<0VFIV0`3<VFH90<bIV@@0c9UV00<0VIUV09UVIP1V<c<00P1V<c<303<c<`0306Hc
<`0c<c<0IS<c00@0<c<c0`0c<`0303<c<`<0IS<c00<0IVIV0<c<c03oc?l0>@3oool002`0oooo00<0
c<co09VIV@1VIS<00`1V<c<00`1VIS<0IS<c06Hc<`0203<c<`80IS<c100c<c<01P1V<c<0<c<c06Hc
<`0c<c<0IS<c03<c<`D0IS<c0P2IIVH00`2IVFH0c9UV0<bIV@020<bIV@030<c<V@3oc9T0olbI01<0
olc<103ool`00`3oc<`0ooo<0?ooc0080?ooc0030?o<c03ool`0ooo<0080olc<00<0ooo<0?o<c03o
c<`03@3oc<`00`3oc9T0olc<0?o<V@0D0?o<V@030<c<V@3oVIT0oiVI00<0c<bI1`3<VIT40<bIIP03
0<aVIP2IIVH0VFIV00H0VFIV00<0c6IV0<bIIP3<VFH00`3<VIT01@3<VFH0c9VI0<bIV@3<VIT0c9UV
00<0c9VI103<VFH00`2IVFH0IVIV06Hc<`0206Hc<`D0<c<c00<0IS<c03<c<`0c<c<00P0c<c<01@0c
0000<c<003<c<`1V<c<0<c<c00@0IS<c00@0IVHc09UVIP2IVIT0c<c<>03oool002`0oooo00H0c<c<
09UVIP2IIVH0IS<c06IV<`1V<c<206IV<`<0IS<c00<0<c<c06Hc<`0c<c<00P0c<c<;06Hc<`0506IV
<`1VIVH0VFIV09UVIP3<VFH00`3<VIT00`3<c9T0olbI0?o<V@0A0?o<c080ooo<0P3oc<`50?ooc003
0?o<c03ool`0ooo<00P0ooo<00<0olc<0?ooc03oc<`03`3oc<`20?o<V@030?o<c03oc9T0olbI01<0
olbI0P3<c9T20?nIV@030<c<V@3<VIT0c9VI00L0c9VI303<VFH<0<bIV@030<bIIP3<VIT0c9UV0080
c9UV00<0VFIV06Hc<`1V<c<00P1V<c<:03<c<`0903<c000c0000<c<c03<c<`0c<`00IS<c03<c<`1V
<c<0<c<c0080IS<c00<0IVHc09VIV@3oool0=`3oool002`0oooo00D0c<c<09UVIP1V<c<0IS<c06IV
<`0206Hc<`0306IV<`1V<c<0IS<c00@0IS<c00H0<c<c06Hc<`0c<c<0<c<003<c<`1V<c<303<c<`@0
IS<c00@0IVHc06Hc<`2IIVH0VFIV0P3<VFH30<bIV@030<c<V@3oc9T0olbI00l0olc<0P3ool`20?o<
c0`0ooo<00<0olc<0?ooc03ool`00P3ool`B0?o<c0030?o<V@3oc<`0olbI00T0olbI00<0olc<0?o<
V@3oc9T02P3oc9T50<c<V@X0c9VI103<VFH0103<VIT0c9UV0<bIIP3<VFH<0<bIV@80c9UV0P3<VIT2
0<bIIP0309VIIP2IIVH0IS<c00<0IS<c3@0c<c<00`0c<`00<c<c03<c<`0306Hc<`0403<c<`1VIS<0
IVHc09VIVCP0oooo000/0?ooo`030<bIV@1VIVH0IS<c00/0IS<c0`0c<c<203<c00X0IS<c00@0IVIV
09UVIP2IIVH0c9UV103<VIT00`3oc9T0olc<0?o<c00A0?o<c0040?ooc03oc<`0olc<0?o<c0d0ooo<
0`3oc<`00`3ool`0olc<0?o<c00=0?o<c1X0olbI00@0c<bI0?nIV@3<c9T0oiVI1@3<VIT00`3<c9T0
c9VI0<bIV@0D0<bIV@030<bIIP3<VIT0c9UV0080c9VI0P3<VFH00`3<IVH0VFIV09UVIP0406Hc<`H0
<c<c00<0IS<c03<c<`0c<c<00P0c<c<00`0c<`00<c<c03<c<`0203<c<`0406Hc<`0c<c<0<c<003<c
<`80IS<c00<0VFIV0?o<c03oool0=P3oool002`0oooo00<0VIVI06IV<`1V<c<00P1V<c<00`1VIS<0
IS<c06Hc<`0406Hc<`0303<c<`1V<c<0<c<c00<0<c<c00<0<c<003<c<`1V<c<00P1V<c<203<c<`@0
IS<c0`2IIVH00`2IVFH0c9UV0<bIIP020<bIV@80olbI3`3oc<`20?ooc080olc<00<0ooo<0?o<c03o
ol`00P3oc<`90?ooc0030?o<c03ool`0oooo0140olc<00<0olbI0?o<c03oc9T00`3oc9T00`3oc<`0
olbI0?o<V@0A0?o<V@040<c<V@3oVIT0c<bI0<c<V@80c9VI0P3<c9T30<bIV@040<c<V@3<VIT0c9VI
0<c<VAH0c9VI0`3<VFH00`2IVFH0VFHc06Hc<`0506Hc<`H0<c<c00@0IS<c03<c<`0c<c<0<c<01P0c
<c<0100c<`00<`0003<c<`1V<c<206IV<`030<bIV@3oool0oooo03D0oooo000/0?ooo`0409VIIP1V
IVH0IVHc06IV<`<0IS<c00<0IVHc06Hc<`1V<c<00`1V<c<203<c<`80IS<c00<0<c<003<c<`0c<c<0
1@0c<c<00`0c<`00<c<c06Hc<`0206Hc<`80VFIV00<0VIUV0<bIIP3<VFH00P3<VIT20?o<V@h0olc<
00<0ooo<0?o<c03oc<`00P3oc<`30?ooc0030?o<c03ool`0olc<00X0ooo<0`3oc<`00`3ool`0olc<
0?o<c00<0?o<c1/0olbI0P3<c9T00`3oVIT0c<bI0<bIV@020<bIV@030<c<V@3<VIT0c9VI01T0c9VI
0`3<VFH00`2IVFH0VFIV09UVIP0506Hc<`P0<c<c00L0IS<c03<c<`0c<`00<c<003<c<`0c<`00IS<c
0080<c<c0P0c000206Hc<`0306IV<`1V<c<0VIVI03L0oooo000/0?ooo`0409UVIP1VIVH0IS<c06Hc
<`<0IVHc201V<c<603<c<`0303<c000c<c<0<c<c0080<c<c0`1V<c<00`1VIS<0IS<c06IVIP0309UV
IP80c9UV103oc9TD0?o<c0L0ooo<00<0olc<0?ooc03oc<`00`3ool`20?o<c0030?ooc03oc<`0olc<
00`0olc<6`3oc9T01`3<VIT0oiVI0<c<V@3oc9T0oiVI0<c<V@3oVIT00P3<VIT0103<c9T0c9VI0<bI
V@3<c9TG0<bIV@80c9UV00<0VIUV09UVIP2IIVH01@1V<c<603<c<`0606Hc<`0c<c<0<`0003<0000c
<c<0<c<00`0c<c<01@0c<`00<c<c03<c000c0000<c<000<0IS<c00<0IVHc09VIV@3oool0=P3oool0
02`0oooo00<0VFIV06IVIP1V<c<0101V<c<206IV<`H0IS<c00D0<c<003<c<`0c<`00<c<003<c<`04
06Hc<`80<c<c1P1V<c<01P2IIS<0VFIV09UVIP2IVFH0c9UV0<bIV@<0olbI303oc<`01P3ool`0olc<
0?o<c03oc<`0ooo<0?o<c080ooo<0P3oc<`0103ool`0olc<0?ooc03oc<`50?ooc0030?ooo`3oc<`0
ooo<00h0olc<103oc9T00`3oc<`0olbI0?o<V@0F0?o<V@050<c<V@3<VIT0c9VI0<bIV@3<c9T0103<
VIT20<c<VAT0c9VI0P3<VFH209UVIP0406IVIP1V<c<0IS<c06Hc<`<0<c<c00@0<c<003<c<`0c<c<0
IS<c0P0c<c<203<0000303<c<`0c<`00<`0000@0<c<c0P0c<`000`0c0000<c<c06Hc<`0206Hc<`03
06IV<`2IVIT0oooo03H0oooo000/0?ooo`0306IV<`1VIVH0IS<c00<0IS<c00<0IVHc06Hc<`1V<c<0
1P1V<c<303<c<`80<c<00`0c<c<306Hc<`0303<c<`1V<c<0IS<c0080IS<c00<0IVIV06Hc<`2IIVH0
0P2IIVH00`3<IVH0c9VI0?o<V@020?o<V@h0olc<00H0ooo<0?o<c03ool`0olc<0?ooc03oc<`20?oo
c0030?o<c03ool`0ooo<00D0ooo<0P3oc<`00`3ool`0olc<0?o<c00=0?o<c0030?o<V@3oc<`0olbI
01/0olbI00@0c9VI0?nIV@3<c9T0oiVI103<VIT00`3<c9T0c9VI0<bIV@0G0<bIV@80c9UV00<0VIUV
09UVIP1VIVH0101V<c<303<c00@0<c<c00<0IS<c03<0000c00000P0c<c<01P0c0000<c<c03<c000c
<c<0<c<003<c<`80<`0000<0<c<003<c<`0c<c<00P1V<c<00`1VIS<0VIUV0<c<c00f0?ooo`00;03o
ool306Hc<`0306IV<`1V<c<0IS<c00<0IS<c00<0IVHc06Hc<`1V<c<00P1V<c<503<c<`<0<c<00P0c
<c<00`1V<c<0<c<c06Hc<`0306Hc<`0306IVIP1V<c<0VFIV00<0VFHc00@0VFIV0<bIV@3<VIT0olbI
3P3oc<`01P3ool`0olc<0?ooc03oc<`0ooo<0?o<c0d0ooo<4`3oc<`F0?o<V@040?nIV@3oc9T0olbI
0?o<V@80oiVI00<0c<bI0<bIV@3<VIT01@3<VIT00`3<c9T0c9VI0<bIV@0D0<bIV@@0c9UV0P2IIVH0
101VIVH0IS<c06Hc<`1V<c<403<c<`0303<c000c<c<0IS<c0080<c<c0P0c00001@0c<c<0<`0003<c
<`0c<`00<`000080<c<000/0<c<c03<0000c<`00<c<003<c<`1V<c<0<c<c06Hc<`1VIS<0VFIV0<c<
c00f0?ooo`00;03oool406Hc<`0306IV<`1V<c<0IVHc0080IS<c00<0IVHc06Hc<`1V<c<00`1V<c<3
03<c<`0506Hc<`0c<`00<c<003<c<`0c<`000P0c<c<406Hc<`80IVHc00L0VFHc09UVIP2IIVH0VFIV
09UV<`2IIVH0c9UV0080c9VI00<0olbI0?o<c03oc<`03P3oc<`01P3ool`0olc<0?ooc03oc<`0ooo<
0?o<c0P0ooo<00<0olc<0?ooc03ool`0403oc<`00`3oc9T0olc<0?o<V@0F0?o<V@030<bIV@3oVIT0
olbI0080c<bI00<0oiVI0<c<V@3<VIT0703<VIT30<bIIP0309VIIP2IIVH0VFIV00<0IS<c1P0c<c<0
101V<c<0<c<c03<c<`0c000303<c<`80<c<000<0<`0003<c000c00000`0c<`002@0c0000<c<c03<c
<`1V<c<0<c<c06Hc<`1VIS<0VFIV0<c<c00f0?ooo`00;03oool01P2IIVH0IVIV06Hc<`1V<c<0IVHc
06Hc<`80IVHc00<0IS<c06IV<`1V<c<0101V<c<01P0c<c<0IS<c03<c<`1V<c<0<c<c03<c0080<c<c
00<0<c<003<c<`1V<c<0101V<c<00`2IIS<0IVIV09UV<`0209UVIP80VFHc00@0c9UV0<bIV@3<VIT0
olbI403oc<`30?ooc0030?o<c03ool`0ooo<00H0ooo<00<0olc<0?ooc03oc<`00P3oc<`00`3ool`0
olc<0?ooc00<0?o<c1P0olbI00D0c9VI0?o<V@3oc9T0c9VI0<c<V@020?nIV@030<c<V@3oVIT0c9VI
01/0c9VI103<VFH309UVIP<0IS<c1@0c<c<00`1V<c<0<c<c06Hc<`0203<0000603<c000c0000<c<0
03<c<`0c0000<c<00P0c000203<c000403<0000c<`00<c<c03<c<`@0IS<c00<0VFIV0<c<c03oool0
=@3oool002`0oooo00D0IVIV06IV<`1V<c<0IS<c06IV<`0306Hc<`80IVHc1P1V<c<0100c<c<0IS<c
06Hc<`0c<c<203<c000403<c<`1V<c<0<c<c03<c<`@0IS<c00<0IVHc06Hc<`1VIVH00`2IIVH0102I
IS<0c9UV0<bIIP3<VIT20?o<V@l0olc<00@0ooo<0?o<c03ool`0olc<2P3ool`00`3oc<`0ooo<0?oo
c00@0?o<c1X0olbI00D0oiVI0<bIV@3<c9T0c9VI0?nIV@0L0<bIV@D0c9UV0P2IIVH0101VIVH0IS<c
06Hc<`1V<c<403<c<`<0IS<c100c000303<c<`<0<`0000D0<c<003<0000c<`00<c<c03<c000303<c
<`80IS<c00<0IVHc09UVIP3oc?l0=P3oool002/0oooo00<0c<c<06IV<`1VIS<00P1V<c<01`1VIS<0
IS<c06Hc<`1V<c<0IVHc06Hc<`1VIS<01`1V<c<0100c<c<0IS<c06Hc<`0c<`0303<c<`0306Hc<`0c
<c<0<c<c00<0IS<c00<0IVHc09UV<`2IIVH00`2IIVH20<bIIP040<bIV@3oc9T0olbI0?o<VA00olc<
303ool`00`3oc<`0ooo<0?o<c00A0?o<c1L0olbI00L0c<bI0?nIV@3oVIT0c9VI0<c<V@3<VIT0oiVI
01`0c9VI103<VFH00`2IVFH0VFHc06IVIP0806Hc<`0403<c<`0c<`00<c<003<c00<0<c<c0P0c<`04
03<0000503<c000c0000<c<003<c<`0c<`000`0c<c<206Hc<`0306IVIP3<c<`0oooo03H0oooo000[
0?ooo`030<c<c01V<c<0IS<c00<0IS<c00<0IVHc06Hc<`1V<c<00P1V<c<206IV<`L0IS<c00<0<c<c
06Hc<`0c<c<00P0c<c<306Hc<`80<c<c101V<c<209UV<`80VFIV0P3<VFH20<bIV@<0olbI3@3oc<`0
103ool`0olc<0?ooc03oc<`20?ooc0030?o<c03ool`0ooo<00D0ooo<00@0olc<0?ooc03ool`0ooo<
3`3oc<`I0?o<V@040<bIV@3oVIT0oiVI0?nIVA`0c9VI1@3<VFH00`2IVFH0VFIV09UVIP0706Hc<`P0
<c<c00<0<c<003<c<`0c00001P0c00000`0c<c<0<c<003<c000203<c<`0403<c001V<c<0IS<c09VI
ISP0oooo000[0?ooo`030<bIc01V<c<0IS<c00P0IS<c0P1VIS<606Hc<`80<c<c0P1V<c<0100c<`00
<c<c06Hc<`0c<c<206Hc<`0503<c<`1V<c<0IS<c06Hc<`2IIS<0102IIVH30<bIIP030<bIV@3oc9T0
olbI00l0olc<103ool`00`3oc<`0ooo<0?o<c0020?ooc0030?o<c03ool`0ooo<00<0ooo<403oc<`H
0?o<V@040?nIV@3<VIT0oiVI0<c<V@<0c9VI00<0oiVI0<bIV@3<VIT05`3<VIT60<bIIP80VFIV00<0
IVIV06Hc<`1V<c<01@1V<c<803<c<`0303<c000c0000<`000080<`0000<0000003<0000c<`000`0c
<`001`0c0000<c<c03<c000c0000IS<c06IV<`2IVIT0>03oool002/0oooo00@0c<c<06IV<`1V<c<0
IVHc0`1V<c<306IV<`0406Hc<`1VIS<0IVHc06IV<`H0IS<c00@0<c<c06Hc<`1V<c<0<c<00P1V<c<0
0`0c<c<0IS<c06Hc<`0406Hc<`0309UV<`2IIVH0VFIV0080VFIV00@0VIUV0<bIIP3<VFH0c9VI0`3o
c9T>0?o<c0030?ooc03oc<`0ooo<00P0ooo<00@0olc<0?ooc03ool`0olc<0P3ool`>0?o<c1@0olbI
00D0oiVI0?o<V@3oVIT0oiVI0<bIV@020?nIV@030<c<V@3oVIT0c9VI01@0c9VI00<0c9UV0<bIV@3<
VIT0103<VIT50<bIIP0409UVIP2IVFH0VFIV06IVIPD0IS<c100c<c<00`0c<`00<`0003<c000203<c
<`0503<c000c0000000003<0000c<c<00P0c0000100c<`00<c<c03<0000c<`0303<c<`0503<c000c
<c<0IS<c06IVIP3<c<`0>03oool002X0oooo00<0olco0<c<c01VIS<00P1VIS<306Hc<`<0IVHc00@0
IS<c06IV<`1VIS<0IVHc101V<c<00`0c<c<0IS<c03<c<`0206Hc<`0303<c<`1V<c<0<c<c00H0IS<c
00<0IVHc06Hc<`2IIVH00`2IIVH40<bIIP030<bIV@3oc9T0olbI00l0olc<00<0ooo<0?o<c03ool`0
0`3ool`00`3oc<`0ooo<0?o<c0020?ooc080olc<00@0ooo<0?o<c03oc<`0ooo<2`3oc<`E0?o<V@0:
0?nIV@3oc9T0oiVI0<c<V@3oVIT0c<bI0?nIV@3<VIT0oiVI0<c<VAX0c9VI1P3<VFH209VIIP80VFIV
1P1V<c<403<c<`0603<c000c<c<0<c<c03<0000c<`00<c<c1@0c000203<c<`80<`000P0c<c<303<c
000403<c<`1V<c<0IVHc0<bIVCP0oooo000[0?ooo`030<c<c01V<c<0IS<c00@0IS<c0P1VIS<206Hc
<`80IVHc00<0IVIV06IV<`1V<c<01@1V<c<00`0c<c<0IS<c06Hc<`0906Hc<`0306IV<`2IIVH0VFIV
0080VFIV00<0c6IV0<bIIP3<VFH00P3<VIT30?o<V@h0olc<00D0ooo<0?o<c03oc<`0ooo<0?o<c002
0?ooc0030?o<c03ool`0olc<00@0ooo<3@3oc<`H0?o<V@040?nIV@3<c9T0oiVI0?nIV@@0c9VI00<0
oiVI0<bIV@3<VIT05`3<VIT00`3<VFH0c9VI0<bIIP020<bIIP80VIUV0P2IIVH00`2IIS<0IS<c06Hc
<`0206Hc<`/0<c<c00<0<c<003<0000c<c<00P0c000203<c<`80<`0000H0<c<003<c<`0c<`00<c<c
03<c000c<c<206Hc<`0306IV<`2IVIT0oooo03L0oooo000[0?ooo`030<c<c01V<c<0IVHc00@0IS<c
00P0IVHc06IVIP1VIS<0IVHc06Hc<`1VIS<0IS<c06IVIP@0IS<c00<0<c<c06Hc<`0c<c<02`1V<c<0
0`1VIVH0VFIV09UVIP0209UVIP0609VIIP3<VFH0c9UV0<bIIP3<VIT0c<bI0`3oc9T90?o<c0050?oo
c03oc<`0olc<0?ooc03oc<`00P3ool`00`3oc<`0ooo<0?ooc0020?o<c080ooo<00<0olc<0?ooc03o
c<`03@3oc<`0103oc9T0olc<0?o<V@3oc<`E0?o<V@<0oiVI00D0c<bI0<bIV@3oVIT0c9VI0?nIV@0K
0<bIV@D0c9UV00D0VIUV09UVIP2IIVH0IVIV06IV<`0406Hc<``0<c<c0P0c000303<c<`0503<0000c
<c<0<`0003<c<`0c<`000P0c<c<01@1V<c<0<c<c06Hc<`1VIS<0c9VI03P0oooo000[0?ooo`030<c<
c01V<c<0IVIV00D0IS<c1`1VIS<406Hc<`<0<c<c301V<c<409UVIP050<aVIP3<VFH0c9UV0<bIIP3<
VIT00`3oc9T<0?o<c0030?ooc03oc<`0olc<0080ooo<00@0olc<0?ooc03oc<`0olc<0P3ool`00`3o
c<`0ooo<0?o<c0020?ooc0/0olc<00<0olbI0?o<c03oc9T00P3oc<`E0?o<V@050<c<V@3oVIT0c9VI
0<c<V@3oVIT00P3<c9TK0<bIV@@0c9UV00<0VIUV09UVIP2IIVH00P2IIVH706Hc<`H0<c<c0P1V<c<8
03<c<`0303<c000c0000<c<c00H0<c<c00<0IS<c09UVIP3<c<`0>03oool002/0oooo00<0c<c<09UV
IP1VIS<01@1V<c<00`1VIVH0IVHc06IV<`0306IV<`H0IS<c0P0c<c<806Hc<`0406IV<`1V<c<0IVHc
06Hc<`D0VFIV00D0VIUV0<aVIP3<VFH0c9UV0<bIV@030?o<V@h0olc<00D0ooo<0?o<c03oc<`0ooo<
0?o<c0030?ooc140olc<00<0olbI0?o<c03oc9T01`3oc9T0103oVIT0olbI0?o<V@3oVIT90?o<V@03
0?nIV@3oc9T0oiVI0080c9VI00D0c<bI0?nIV@3<VIT0c9VI0?nIV@0H0<bIV@@0c9UV00P0c6IV09UV
IP2IIVH0VFIV09UV<`1VIVH0VFHc06IV<`80IS<c00@0<c<c06Hc<`1V<c<0IS<c100c<c<206Hc<`80
<c<c00<0IS<c03<c<`0c<c<01P0c<c<0101V<c<0<c<c03<c<`0c<`0203<0000403<c<`1V<c<0VFIV
0<c<c3T0oooo000[0?ooo`040<c<c01VIS<0IS<c06IV<`D0IS<c00L0IVHc06IVIP1VIS<0IVHc06IV
IP1V<c<0IVHc00@0IS<c0P0c<c<:06Hc<`0306IV<`1VIVH0VFIV00D0VFIV00<0c6IV0<bIIP3<VFH0
0P3<VIT30?o<V@`0olc<0P3ool`01P3oc<`0ooo<0?ooc03ool`0olc<0?ooc140olc<4`3oc9T00`3o
VIT0olbI0?o<V@020?o<V@0:0?nIV@3oc9T0c<bI0?nIV@3<VIT0oiVI0<bIV@3oVIT0c9VI0<c<VAL0
c9VI1P3<VFH01@2IVFH0VFIV09UV<`2IIS<0IVIV00L0IS<c00<0<c<c06Hc<`0c<c<00`0c<c<206Hc
<`80<c<c0P0c000603<c<`80<`0000L0<c<003<0000c0000<c<c06Hc<`0c<c<0VIVI03X0oooo000[
0?ooo`030<c<c01VIS<0IS<c00H0IS<c00D0IVHc06IVIP1VIS<0IVHc06IVIP0206IV<`@0IS<c0`0c
<c<906Hc<`0406IV<`1V<c<0IS<c06Hc<`80VFIV00D0VFHc09UVIP2IVFH0c6IV0<bIIP020<bIV@03
0<c<V@3oc9T0olc<00h0olc<00@0ooo<0?o<c03oc<`0olc<0P3ool`B0?o<c180olbI00<0oiVI0?o<
V@3oc9T00`3oc9T01@3oVIT0c9VI0?nIV@3oVIT0c<bI0080oiVI00<0c9VI0?nIV@3oVIT04`3<VIT0
103<VFH0c9VI0<bIIP3<VIT30<bIIP060<aVIP2IIVH0VFIV09UVIP2IIS<0IVIV1`1V<c<403<c<`80
IS<c100c<c<203<00080<c<c1`0c00001`0c<c<0<`0003<c<`1V<c<0<c<c06Hc<`3<VIT0>P3oool0
02/0oooo00<0c<c<06IVIP1VIS<01@1V<c<206IV<`0306IVIP1V<c<0IS<c0080IVIV00<0IVHc06Hc
<`1V<c<00P1V<c<303<c<`T0IS<c00@0IVHc06IVIP1V<c<0IS<c0P2IIVH0102IIS<0VFIV09UVIP3<
IVH20<bIIP80c9VI0P3oc9T=0?o<c0050?ooc03oc<`0ooo<0?o<c03ool`04P3oc<`01@3oc9T0olc<
0?o<V@3oc9T0olc<01H0olbI00@0oiVI0?o<V@3<VIT0oiVI0P3<VIT00`3oVIT0c9VI0<bIV@0E0<bI
V@030<bIIP3<VIT0c9UV0080c9UV00H0VIUV09UVIP2IIVH0VFHc06IVIP2IIS<606Hc<`L0<c<c0P0c
<`000`0c<c<0IS<c03<c<`0203<c<`D0<`0000D0000003<0000c0000<c<003<0000303<c<`0306Hc
<`3<VIT0oooo03T0oooo000[0?ooo`030?o<o`2IIVH0IVIV00L0IS<c0P1VIS<00`1V<c<0IVHc06IV
IP0206IV<`@0IS<c0P0c<c<:06Hc<`0306IVIP1V<c<0IS<c0080VFIV0P2IIS<0102IIVH0c6IV0<bI
IP3<VFH20<bIV@80olbI903oc<`30?o<V@030?o<c03oc9T0olc<0180olbI0`3oVIT01@3<VIT0oiVI
0?nIV@3<VIT0oiVI0180c9VI00<0c9UV0<bIV@3<VIT0103<VIT40<bIIP80VIUV00@0VFIV09UV<`2I
IVH0VFHc2@1V<c<303<c<`<0<c<00`0c<c<01P1V<c<0<c<c03<000000000<`0003<c00D0<`000P0c
<`0203<c<`80IS<c00<0c<bI0?ooo`3oool0>03oool002/0oooo00<0c<c<09UVIP1VIS<01`1V<c<0
0`1VIS<0IVIV06IV<`0306IV<`H0IS<c0P0c<c<:06Hc<`<0IVHc0P1VIVH01@2IIS<0VFIV09UVIP3<
IVH0c9UV0080c9VI0`3oc9TT0?o<c0030?o<V@3oc<`0olbI00P0olbI00D0oiVI0?o<V@3oc9T0olbI
0?nIV@030?o<V@050?nIV@3oc9T0oiVI0?o<V@3oVIT00`3oc9T01`3oVIT0c9VI0?nIV@3<VIT0oiVI
0<bIV@3oVIT05@3<VIT50<bIIP<0VFIV00<0VFHc06IVIP1V<c<01@1V<c<?03<c<`80<`0000<0<c<c
0000000000001@0c00000`0c<`00<c<c06Hc<`0206Hc<`030<c<c03oool0oooo03P0oooo000[0?oo
o`030?o<o`2IVIT0IVIV00D0IS<c00@0IVHc06Hc<`1V<c<0IVIV0`1VIS<206Hc<`0306IV<`1V<c<0
IS<c0080IS<c0`0c<c<906Hc<`80VFHc00P0IVHc06Hc<`2IIS<0VFHc09UVIP2IVFH0VFIV0<bIIP80
c9VI0P3oc9T00`3oc<`0olbI0?o<V@0Q0?o<c0030?o<V@3oc<`0olbI00X0olbI0P3oVIT40?o<V@05
0?nIV@3oc9T0olbI0?o<V@3oVIT00P3oc9T20?nIV@040<bIV@3oVIT0c9VI0?nIVAL0c9VI103<VFH0
0`2IVFH0VFIV09UVIP0209UVIP0306IVIP1V<c<0IS<c00D0IS<c0`0c<c<203<c0080<c<c0P0c0006
03<c<`0303<c000c<c<0<`0000<0<`0000<0000003<0000c00000`0c<c<206Hc<`0306IV<`3oool0
oooo03T0oooo000/0?ooo`0309UVIP1VIVH0IVHc00@0IS<c00H0IVHc06Hc<`1V<c<0IVHc06IVIP1V
<c<206IV<`D0IS<c00<0IVHc06Hc<`1V<c<00P0c<c<406Hc<`0306IV<`1V<c<0IS<c00<0IS<c00@0
IVIV06Hc<`1V<c<0IS<c0P2IIS<0102IVFH0c9UV0<bIIP3<VIT20?o<VB@0olc<203oc9T00`3oVIT0
olbI0?o<V@030?nIV@80olbI00l0oiVI0?o<V@3oc9T0oiVI0?o<V@3oVIT0olbI0<bIV@3oc9T0oiVI
0?o<V@3<VIT0oiVI0<bIV@3oVIT05@3<VIT50<bIIP030<aVIP2IVFH0VIUV0080VFIV0P2IIS<706Hc
<`l0<c<c00L0<`0003<c<`0c<c<0<`0003<c000c000000000080<`0000<0<c<003<c<`1V<c<00`1V
<c<00`3<VIT0oooo0?ooo`0i0?ooo`00;03oool00`2IVFH0VFIV06IVIP0406Hc<`0506IVIP1V<c<0
IS<c06Hc<`1VIVH00P1V<c<00`1VIVH0IS<c06Hc<`0506Hc<`0403<c<`1V<c<0<c<c03<c<`@0IS<c
00<0IVHc06Hc<`1V<c<00P1V<c<206IV<`80IS<c0P2IIS<00`2IIVH0c6IV0<bIIP020<bIV@80olbI
8@3oc<`90?o<V@060?nIV@3oc9T0oiVI0?o<V@3oVIT0olbI0`3oVIT20?o<V@<0oiVI00<0olbI0<bI
V@3oVIT00`3oVIT20<bIV@030<c<V@3<VIT0c9VI01<0c9VI1P3<VFH209VIIP80VFIV00<0VFHc09UV
IP2IIVH01P1V<c<203<c<`80<c<00P0c<c<00`0c<`00<c<c03<c000:03<c<`0303<000000000<`00
0080<`0000<0<c<003<c<`0c<c<00`1V<c<00`2IIVH0olco0?ooo`0j0?ooo`00;03oool209UVIP03
06IVIP1VIS<0IS<c0080IS<c00@0IVHc06Hc<`1V<c<0IS<c0P1VIS<00`1V<c<0IVIV06Hc<`0506Hc
<`0406IV<`0c<`00IS<c06Hc<`80<c<c0`1V<c<00`1VIS<0IS<c06Hc<`0506Hc<`0706IV<`1V<c<0
VFHc09UVIP2IVFH0c6IV0<bIIP020<bIV@<0olbI7`3oc<`90?o<V@80oiVI103oc9T00`3<VIT0olbI
0?o<V@030?o<V@80c9VI00<0olbI0?nIV@3oVIT00P3<VIT20?nIV@030<bIV@3oVIT0c9VI0180c9VI
203<VFH309UVIP0409UV<`2IIVH0VFHc09UV<`H0IS<c0P0c<c<403<c000303<c<`0c<`00<c<c00/0
<c<c0P0c0000100c<c<0<`0003<0000c<c<406Hc<`030<bIV@3oool0oooo03X0oooo000/0?ooo`<0
VFIV00@0IVHc06Hc<`1V<c<0IS<c0P1VIS<206Hc<`80IVHc00<0IS<c06IVIP1VIVH01`1V<c<00`0c
<c<0IS<c06Hc<`0:06Hc<`80IVHc0P1V<c<00`2IIS<0VFIV09UVIP020<bIIP030<bIV@3oVIT0olbI
0080olbI0P3oc<`00`3oc9T0olc<0?o<c00G0?o<c080olbI00<0olc<0?o<V@3oc9T01`3oc9T0203o
VIT0olbI0?o<V@3oVIT0c9VI0?nIV@3<VIT0oiVI0P3<VIT20?nIV@80olbI00<0c9VI0?nIV@3<VIT0
0P3oVITG0<bIV@L0c9UV1@2IIVH00`2IIS<0IS<c06Hc<`0406Hc<`<0<c<c00H0<c<003<0000c<`00
<c<003<c<`0c<`0=03<c<`@0<`0000<0<c<003<c<`1V<c<00P1V<c<00`2IIVH0c<c<0?ooo`0k0?oo
o`00;03oool0103<VIT0VFIV09UVIP2IIVH406Hc<`0306IV<`1V<c<0IS<c0080IVHc00<0IS<c06IV
<`1VIVH00`1V<c<00`1VIS<0IS<c06Hc<`0206Hc<`0303<c<`1V<c<0IS<c00@0IS<c00<0IVIV06Hc
<`1V<c<00`1V<c<306IV<`0606Hc<`2IIVH0VFIV09UVIP3<IVH0c9UV0P3<VIT30?o<V@030?o<c03o
c9T0olbI01L0olc<00@0olbI0?o<c03oc<`0olc<1P3oc9T20?nIV@040?o<V@3oVIT0olbI0<bIV@80
oiVI0P3<VIT20?nIV@030<bIV@3oVIT0c9VI0080c9VI0P3oVIT0103<VIT0oiVI0<bIV@3oVITE0<bI
V@80c9UV00<0c9VI0<bIIP3<VFH00P3<VFH00`3<IVH0VIUV09UVIP0209UVIP80VFHc1P1V<c<303<c
<`@0<c<00P0c<c<00`0c<`00<c<c03<c<`0703<c<`@0<`000P0000000`0c0000<c<c06Hc<`0306Hc
<`0309UVIP3<c<`0oooo03/0oooo000/0?ooo`030<bIc02IIVH0VFIV0080IVIV0`1V<c<206IV<`80
IS<c0`1VIS<00`1VIVH0IVHc06Hc<`0606Hc<`80<c<c3@1V<c<01`1VIS<0VFHc06Hc<`2IIS<0VFIV
09VIIP3<VFH00`3<VIT40?o<VAX0olc<203oc9T01`3oVIT0olbI0?o<V@3<VIT0oiVI0<bIV@3oVIT0
0P3<VIT01P3oc9T0oiVI0<bIV@3oVIT0c9VI0?o<V@80oiVI0P3<VIT00`3oVIT0c9VI0<bIV@0B0<bI
V@030<bIIP3<VIT0c9VI00L0c9UV00@0c6IV09UVIP2IVFH0VFIV0P2IIS<00`1VIVH0IS<c06Hc<`06
06Hc<`80<c<c0P0c<`0203<00080<c<000<0<c<c03<c000c<c<00`0c<c<00`0c0000<c<c03<00002
03<000D0000000<0<`0003<c<`1V<c<00`1V<c<00`2IVFH0oooo0?ooo`0k0?ooo`00;03oool01@3<
c<`0VFIV09UVIP2IIVH0IVHc00<0IS<c00<0IVHc06Hc<`1V<c<00`1V<c<0101VIS<0IVIV06IVIP1V
IS<206Hc<`0306IV<`1V<c<0IS<c0080IS<c00<0<c<c06Hc<`1V<c<0101V<c<306IV<`80IS<c0P1V
IS<00`1V<c<0IVHc06IVIP0209UV<`0309UVIP3<VFH0c9VI0080c9VI2@3oc9T>0?o<c080olbI0P3o
c<`:0?o<V@030?nIV@3oc9T0oiVI00<0oiVI00<0olbI0?nIV@3<VIT00P3oVIT01@3<VIT0olbI0<bI
V@3oc9T0oiVI00<0c9VI00@0olbI0?nIV@3<VIT0oiVI1P3<VIT00`3<VFH0c9VI0<bIV@0:0<bIV@03
0<bIIP3<VIT0c9UV00H0c9UV00H0VIUV09UVIP2IIVH0VFIV09UV<`1VIVH806Hc<`80<c<c0P0c<`06
03<000<0<c<c00<0<c<003<c<`0c00000P0c00070000000303<c001V<c<0IS<c00<0IS<c00<0c9VI
0?ooo`3oool0>`3oool002`0oooo00<0olco09VIV@1VIVH00P1VIVH406Hc<`80IVHc0P1V<c<00`1V
IS<0IS<c06IV<`0206IV<`@0IS<c0P0c<c<306Hc<`0303<c<`1V<c<0IS<c00D0IS<c0P1VIVH306Hc
<`80IVHc00H0IS<c06IVIP2IIVH0VFIV0<aVIP3<VFH30<bIV@030<c<V@3<VIT0olbI00<0olbI00<0
olc<0?o<V@3oc<`03`3oc<`0103oc9T0olc<0?o<V@3oc<`60?o<V@030<bIV@3oVIT0c9VI00<0c9VI
00<0oiVI0<bIV@3oVIT02`3<VIT00`3oVIT0c9VI0<bIV@080<bIV@080<bIIP3<VIT0c9VI0<bIIP3<
VIT0c9UV0<bIV@3<VFH20<bIV@030<bIIP3<VIT0c9UV00@0c9UV0P3<IVH509UVIP80VFHc1P1V<c<4
03<c<`0303<c000c<c<0<c<000@0<`001`0c<c<203<000H000000P0c00000`0c<`00IS<c06Hc<`02
06Hc<`0309UVIP3<c<`0oooo03`0oooo000]0?ooo`030<bIV@2IIVH0VFIV00<0IVHc0P1V<c<206IV
<`@0IS<c00<0IVHc06IVIP1VIS<0101V<c<403<c<`80IS<c00<0<c<c06Hc<`1V<c<00P1V<c<406IV
<`D0IS<c00<0IVHc06Hc<`1VIVH00P2IIVH00`2IVFH0c9UV0<bIIP020<bIV@@0olbI00<0c<bI0?o<
V@3oc9T00P3oc9T20?o<c0030?o<V@3oc<`0olc<00L0olc<0`3oc9T00`3oc<`0olbI0?o<V@050?o<
V@030?nIV@3<VIT0c9VI01X0c9VI00@0c9UV0<bIV@3<VIT0c9VI0P3<VFH00`3<VIT0c9UV0<bIV@0:
0<bIIP0309VIIP3<IVH0VFIV00D0VFIV00<0VFHc06Hc<`1V<c<0101V<c<203<c<`0:06Hc<`0c<c<0
<c<c03<c<`0c<`00<`0003<c000c0000<c<003<c<`H0<`0000D0<c<c03<0000c0000000003<00004
0000000303<0000c<c<0IS<c00@0IS<c00<0VIUV0?ooo`3oool0?03oool002d0oooo00<0c<c<09UV
IP2IIVH00`1VIS<206Hc<`<0IVHc0`1V<c<0101VIS<0IVIV06IV<`1VIS<506Hc<`0303<c<`1V<c<0
<c<c00H0IS<c0`1VIS<00`1V<c<0IVIV06Hc<`0306Hc<`<0IVHc102IIVH00`3<IVH0c9UV0<bIV@05
0<bIV@80c<bI1@3oc9T00`3<c<`0olc<0?o<V@030?o<V@80olc<303oc9TK0<bIV@030<bIIP3<VIT0
c9VI00@0c9VI3P3<VFH00`3<IVH0VIUV09UVIP0509UVIP0306IVIP1V<c<0IS<c00@0IS<c1P0c<c<4
03<c00L0<`0000<0000003<c<`0c00001P0000001@0c0000<c<003<c<`1V<c<0<c<c00<0IS<c00<0
c<c<0?ooo`3oool0?03oool002d0oooo00@0c<c<09VIV@2IIVH0IVIV0P1VIS<206Hc<`<0IVHc101V
<c<00`1VIVH0IVHc06Hc<`0406Hc<`<0<c<c00D0IS<c03<c<`1V<c<0IS<c03<c<`0406Hc<`<0IVHc
00<0IVIV06Hc<`1V<c<00`1V<c<00`1VIS<0IS<c09UV<`0209UV<`0309UVIP3<IVH0c9UV00@0c9UV
0`3<VIT40<c<V@H0olbI00<0c<c<0?o<c03oc9T00P3oc9T00`3oc<`0olbI0?o<V@070?o<V@`0c9VI
00<0c9UV0<bIV@3<VFH03@3<VIT00`3<VFH0c9VI0<bIV@0A0<bIIPD0VFIV0`2IIS<606Hc<`80<c<c
00D0<c<003<c<`0c<c<0<c<003<c<`0803<000030000000c0000<`0000<0<`001P0000000`0c0000
<c<c06Hc<`0306Hc<`0303<c002IIVH0oooo03h0oooo000]0?ooo`050?o<o`3<VIT0VFIV09UVIP1V
IVH0101V<c<306IV<`0506Hc<`1VIS<0IS<c06IV<`1VIVH00P1VIS<406Hc<`80<c<c0P1V<c<00`0c
<c<0IVHc06Hc<`0506Hc<`0506IV<`1V<c<0IVHc09UVIP1VIS<0101V<c<00`1VIVH0IS<c09UV<`05
09UVIP80c6IV0`3<VFH70<bIV@<0c<bI0P3oc9T00`3<c9T0olbI0?o<V@0:0?o<V@030<c<V@3<VIT0
c9VI00H0c9UV00<0c9VI0<bIIP3<VFH00`3<VFH00`3<VIT0c9UV0<bIV@030<bIV@<0c9UV1P3<VIT0
0`3<VFH0c9VI0<bIIP020<bIIP040<bIV@3<VFH0c9UV0<bIV@T0c9UV00@0VIUV0<aVIP2IIVH0VFIV
1@2IIS<506Hc<`@0<c<c00<0<c<003<c<`0c00000`0c0000100c<c<0<`0003<0000c000203<c<`H0
<`001@0000002@0c0000<c<c03<c<`1V<c<0<c<c06Hc<`0c<c<0IS<c0<c<c00o0?ooo`00;P3oool0
1@3<c<`0VFIV09UVIP1VIVH0IVHc00<0IS<c0P1VIS<506Hc<`80IVIV101V<c<00`0c<c<0IS<c03<c
<`0206Hc<`0403<c<`1V<c<0IVHc06IV<`D0IS<c0`1VIS<00`2IIVH0IVHc06Hc<`0306Hc<`80IVIV
1`2IIVH0103<IVH0c9UV0<bIIP3<VFH20<bIV@030<bIIP3<VIT0c9VI00<0c9VI00/0c<bI0<bIV@3<
VIT0c9VI0<c<V@3oc9T0c<bI0?o<V@3<c9T0oiVI0<bIV@030?o<V@@0c9VI0`3<VFH00`3<IVH0c9UV
0<bIIP080<bIIP050<bIV@3<VFH0c9UV0<bIIP3<VIT01`3<VFH00`3<VIT0c9UV0<bIV@0@0<bIIP04
0<aVIP2IVFH0VFIV09UVIP@0VFHc00<0IVIV06Hc<`1V<c<0101V<c<01@0c<c<0<c<003<c<`0c<c<0
<`000080<c<0200c000203<c<`@0<`001P0000000`0c0000<c<c06Hc<`0203<c<`0306Hc<`0c<c<0
VFHc0400oooo000^0?ooo`050<c<c02IIVH0VFIV06IVIP1VIS<00`1V<c<406IV<`<0IS<c00<0IVHc
06IVIP1V<c<01@1V<c<303<c<`0506Hc<`0c<c<0IS<c06IV<`1VIVH00P1VIS<206Hc<`80IVHc00<0
IS<c06IV<`1VIS<00P1VIS<406Hc<`0306IV<`2IIVH0VFIV0080VFIV00<0c6IV09UVIP2IIVH00`3<
VFH0103<VIT0c9UV0<bIIP3<VFH<0<bIV@040<c<V@3<VIT0c9VI0?o<V@80c<bI0P3<VIT20<bIIP05
09UVIP3<IVH0c9UV0<aVIP2IIVH0503<VFH00`3<VIT0c9UV0<bIIP0@0<bIIP040<aVIP2IIVH0VFIV
09UVIPD0VFHc1P1V<c<303<c<`0403<c000c0000<c<003<c<`80<c<03@0c00050000000903<0000c
<c<0IS<c06Hc<`0c<c<0IS<c03<c<`1V<c<0VFIV0400oooo000^0?ooo`030?o<o`2IVIT0VFIV0080
IVIV00L0IVHc06Hc<`1V<c<0IS<c06IV<`1VIVH0IVHc00@0IS<c00<0IVIV06Hc<`1V<c<00`1V<c<0
0`0c<c<0IS<c03<c<`0203<c<`0406Hc<`0c<c<0<c<c06Hc<`@0IVIV00<0IS<c06IV<`1V<c<01P1V
IS<306Hc<`0306IV<`2IIVH0VFIV00D0VFIV00<0c9UV09VIIP3<VIT01`3<VFH00`3<VIT0c9UV0<bI
V@090<bIV@80c<bI00L0c9VI0<bIIP3<VFH0c9UV09VIIP2IIVH0c6IV00@0VFIV0P3<IVH00`3<VFH0
c6IV0<bIIP0N0<bIIP80c6IV0P2IVFH00`2IIVH0VFHc09UV<`0209UV<`0306Hc<`2IIS<0IS<c00L0
IS<c0P0c<c<303<c000303<c<`0c<`00<`0000X0<`001P0000000`0c0000<c<c03<c<`0303<c<`04
06Hc<`0c<c<0IS<c0<c<VD00oooo000_0?ooo`050<c<c02IVFH0VFIV06IVIP1VIS<0101V<c<206IV
<`D0IS<c00<0IVIV06IV<`1V<c<00P0c<c<306Hc<`80<c<c201V<c<206IVIP80IVHc0`1V<c<00`1V
IVH0IVHc06IV<`0406IVIP80VFIV00@0VFHc09UVIP2IIVH0VFIV0P2IVFH309UVIP80VIUV00<0c9UV
09VIIP3<IVH00P2IIVH209VIIP0309UVIP3<VFH0c9UV0080c9UV0P3<VIT20<bIIP030<bIV@3<VFH0
VFIV00d0VFIV00<0c6IV0<bIIP3<VFH03P3<VFH00`3<IVH0c9UV0<bIIP060<bIIP050<aVIP3<VFH0
c6IV0<bIIP3<IVH01P2IIVH00`1VIVH0VFHc06Hc<`0506Hc<`0303<c<`1V<c<0<c<c0080IS<c0P0c
<c<0100c<`00<`0003<0000c<`0603<000`0000000<0<c<c06Hc<`1V<c<0100c<c<00`1VIS<0c9VI
0?ooo`100?ooo`00;`3oool01@3<c<`0VIUV09UVIP1VIVH0IVHc00@0IS<c0P1VIS<506Hc<`0306IV
IP1VIS<0IS<c0080<c<c0`1V<c<203<c<`P0IS<c0P1VIVH206IV<`<0IS<c00<0IVIV06IV<`1VIS<0
101VIVH209UVIP0409UV<`2IIVH0VFIV09UVIP80VIUV0`2IIVH209VIIP030<bIIP2IVFH0c6IV0080
VFIV0P2IVFH00`2IIVH0c9UV0<bIIP020<bIIP80c9VI0P3<VFH00`3<VIT0c9UV09UVIP0=09UVIP03
0<aVIP3<VFH0c9UV00h0c9UV00<0c6IV0<bIIP3<VFH01P3<VFH01@3<IVH0c9UV0<aVIP3<VFH0c6IV
00H0VFIV00<0IVIV09UV<`1V<c<01@1V<c<00`0c<c<0IS<c03<c<`0206Hc<`80<c<c00@0<c<003<0
000c0000<c<01P0c000<0000000303<c<`1V<c<0IS<c00@0<c<c00<0IVHc0<bIV@3oool0@03oool0
0300oooo00D0VIVI09UVIP2IIVH0IVIV06IV<`0306Hc<`80IVHc1@1V<c<00`1VIVH0IVHc06IV<`04
06Hc<`80<c<c2@1V<c<00`1VIS<0IVIV06IVIP0206IVIP80IVHc00@0IS<c06IVIP1VIVH0IS<c1P1V
IVH:09UVIP0309VIIP2IIVH0VFIV00<0VFIV00H0VIUV09UVIP2IIVH0VFIV09VIIP3<VFH30<bIV@80
c9UV0P2IVFH509UVIP0309UV<`2IIVH0VFHc0080VFHc00L0VFIV09UV<`2IIVH0VFIV0<aVIP2IIVH0
c6IV0080c9UV00<0c6IV0<bIIP3<VFH02@3<VFH00`3<IVH0VFIV0<aVIP040<aVIP060<bIIP3<IVH0
c6IV0<aVIP2IIVH0VIUV102IIVH409UV<`D0IS<c00D0<c<c06Hc<`0c<c<0<c<c03<c000203<c<`<0
<c<0200c000;0000000303<0001V<c<0IS<c00@0<c<c00<0IS<c09UVIP3oc<`0@@3oool00300oooo
00<0c<c<09UVIP2IIVH00P1VIS<306Hc<`80IVHc0P1V<c<00`1VIS<0IS<c06Hc<`0206IVIP80IS<c
0P0c<c<406Hc<`0403<c<`1V<c<0IS<c06Hc<`80IVHc00<0IS<c06IV<`1VIVH0201VIS<506IVIP03
09UVIP1VIVH0VFIV01@0VFIV00H0VIUV09UVIP2IVFH0c9UV0<bIV@3<VFH909UVIP0506IVIP2IIS<0
VFIV09UV<`2IIVH00P2IIS<509UVIP@0c6IV203<VFH20<aVIPl0VFIV0`2IIS<906Hc<`D0<c<c00<0
<c<003<c<`0c00000P0c00001`0c<c<0<c<003<000000000<`000000000c00002P0000000`0c0000
<c<c03<c<`0403<c<`0306Hc<`3<VIT0oooo0440oooo000`0?ooo`050<c<c02IVIT0VFIV06IVIP1V
IS<0101V<c<206IV<`0306Hc<`1VIS<0IVHc0080IS<c00<0IVIV06IV<`1V<c<00P1V<c<0100c<c<0
IS<c06Hc<`0c<c<406Hc<`80IVHc00<0IVIV06IV<`1VIS<00P1VIVH01@1VIS<0IVIV06IV<`1V<c<0
IVHc0080IVIV0P2IIVH406IVIP@0VFIV00<0IVIV09UVIP2IIVH02@2IIVH01@2IIS<0VFIV09UVIP2I
IVH0VFHc00D0VFIV00<0VIUV09UVIP2IIVH01`2IIVH02@2IIS<0IVIV09UV<`1VIVH0VFHc09UVIP2I
IS<0VFIV09UV<`0809UVIP80c6IV00D0c9UV0<aVIP2IVFH0VFIV09VIIP0@09UVIP0309UV<`1VIVH0
VFHc00T0IS<c0P0c<c<203<c0080<c<c00<0<`0003<c000c00001`0c000;0000000303<0000c<c<0
<c<c00@0<c<c0P1V<c<00`3<c<`0oooo0?ooo`100?ooo`00<03oool00`3oc?l0c9W<09VIIP0206IV
IP0306IV<`1V<c<0IS<c0080IS<c00<0IVHc06Hc<`1V<c<00`1V<c<206IV<`80IS<c00<0<c<c06Hc
<`0c<c<01@1V<c<306IV<`<0IVIV00<0IVHc06IVIP1VIVH00`1VIVH00`1VIS<0IVIV06IVIP0306IV
IP0309UVIP1VIVH0VFIV00<0VFIV00<0IVHc09UVIP2IIVH00`2IIVH206IVIP0506Hc<`1VIVH0VFIV
06Hc<`2IIS<00`2IIVH0102IIS<0IVIV09UVIP2IIS<:09UVIP0606IVIP1V<c<0IVIV09UV<`1VIVH0
VFHc0P1V<c<709UV<`80VFIV00<0VFHc09UVIP2IIVH04`2IIVH209UV<`0409UVIP2IIS<0VFHc09UV
<`T0IS<c00@0<c<c03<c000c<`00<c<00P0c<c<00`0c<`00<`0003<0000503<000d0000000D0<`00
03<c<`1V<c<0<c<c06Hc<`0203<c<`80IS<c00<0VFIV0?ooo`3oool0@@3oool00340oooo00<0olco
09VIV@2IIVH00P1VIS<406Hc<`0806IV<`1V<c<0IS<c06Hc<`1VIS<0IS<c06IV<`1VIVH306Hc<`80
<c<c1@1V<c<306IV<`D0IVIV00<0IVHc06IVIP1VIVH00P1VIVH00`1V<c<0IVIV06IVIP0;09UVIP0A
06IVIP2IIS<0IS<c06Hc<`1VIS<0IS<c06IV<`2IIVH0IS<c09UVIP1VIVH0VFHc06Hc<`1VIVH0VFHc
09UVIP2IIS<01P2IIVH01@1VIVH0IVHc06IVIP1VIVH0VFIV00@0IVHc00@0VFHc06Hc<`1V<c<0IS<c
1@2IIS<00`2IIVH0VFHc09UV<`0309UVIP0409UV<`2IIVH0VFIV09UVIP<0VFHc00<0VFIV09UV<`2I
IVH00P2IIS<0102IIVH0VFHc09UV<`2IIS<209UVIPD0VFHc00<0IVIV06Hc<`1V<c<0201V<c<203<c
<`<0<c<000<0<c<c03<c000c<`000P0c0000100c<`00<`0003<00000000203<000030000000c0000
000000L000000P0c00000`0c<c<0IS<c06Hc<`0303<c<`80IS<c00<0VIVI0?ooo`3oool0@@3oool0
0340oooo00<0olco0<bIV@2IIVH00`1VIS<306Hc<`80IVHc1@1V<c<00`1VIVH0IS<c06Hc<`0306Hc
<`0303<c<`1V<c<0IS<c00D0IS<c0P1VIVH209UVIP<0IVIV00<0IVHc06IVIP1VIS<00P1V<c<406IV
<`0406IVIP2IIVH0VFIV09UVIP80IVHc00@0IVIV06IV<`1VIVH0VFIV101V<c<00`1VIS<0IVIV06IV
<`0206Hc<`<0IVIV00P0IS<c06IVIP1V<c<0VFHc06IVIP2IIS<0IVIV09UVIP@0IVIV0P1VIS<506Hc
<`0306IV<`1V<c<0IS<c00<0IS<c2P2IIS<00`2IIVH0VFHc09UV<`0309UV<`0509UVIP2IIS<0VFHc
06IVIP2IIS<00`1V<c<209UV<`0609UVIP2IIS<0VFHc06IVIP1V<c<0VFHc201V<c<00`0c<c<0IS<c
03<c000203<c<`0503<c000c0000<c<003<c000c<c<01`0c000:00000080<`0000@0<c<c06Hc<`0c
<c<0IS<c0P0c<c<306Hc<`030<c<c03oool0oooo0440oooo000b0?ooo`050<c<o`2IVIT0VFIV06IV
IP1VIS<0101V<c<206IV<`80IS<c0P1VIS<00`1V<c<0IVIV06Hc<`0306Hc<`0303<c<`1V<c<0IVHc
0080IVHc00<0IS<c06IVIP1VIVH0101VIVH206IV<`0409UVIP1VIVH0IVIV06IVIP80IS<c00h0IVHc
06IVIP1VIVH0IVIV09UVIP1VIVH0VFIV06IV<`1VIVH0VFIV06IVIP1V<c<0VFHc06IV<`@0IS<c0P1V
IS<406Hc<`80IVHc0P1V<c<0101VIS<0IS<c06Hc<`1V<c<206IVIP@0IS<c00<0IVIV06Hc<`1V<c<0
;P1V<c<203<c<`0303<c000c<c<0<c<c00<0<c<c00@0<c<003<0000c0000<`000P0c<`0203<c<`@0
<`000P0000000`0c00000000000000050000000303<0000c<c<0<c<c0080<c<c00<0IS<c03<c<`1V
<c<00`1V<c<00`3<c<`0oooo0?ooo`120?ooo`00<`3oool00`2IVIT0VIUV06IVIP0306IV<`80IS<c
0`1VIS<206Hc<`0406IV<`1V<c<0IVIV06IVIPD0IS<c00@0IVHc06IVIP1VIVH0IVHc201VIVH00`1V
IS<0IVIV06IVIP0206IVIP0306IV<`1V<c<0IS<c0080IVHc00T0IVIV09UVIP2IIVH0IVHc06Hc<`1V
IVH0IVHc06Hc<`1VIS<02`1V<c<206IV<`<0IS<c00H0IVIV06IV<`1V<c<0IVHc06Hc<`1VIS<c06Hc
<`D0<c<c00@0<c<003<c<`0c<c<0<c<0100c00000`0c<c<0<`0003<c000503<000050000000c0000
00000000000c00000`00000203<000H0<c<c101V<c<00`2IVFH0oooo0?ooo`130?ooo`00<P3oool0
103oc?l0c9VI09VIV@2IIVH206IV<`@0IS<c0P1VIS<306Hc<`0406IV<`1V<c<0IVHc06IV<`D0IS<c
00<0IVHc09UVIP1VIVH0101VIVH209UVIP@0IVIV0P1VIS<206Hc<`80IVHc0`1V<c<02@2IVFH0VFIV
06Hc<`2IIS<0IVHc06Hc<`1VIS<0IS<c06IV<`0;06Hc<`0406IV<`1V<c<0IVHc06Hc<`80IVHc0P1V
<c<00`1VIS<0IS<c06Hc<`0c06Hc<`D0<c<c00<0<c<003<c<`0c<c<0100c00000`0c<`00<`0003<0
000303<00080000000<0<`000000000000001@00000803<c<`0506Hc<`1VIS<0IS<c09UVIP3<c<`0
A@3oool003<0oooo00@0c<c<09VIV@2IIVH0IVIV0P1VIS<01@1V<c<0IVHc06Hc<`1V<c<0IVHc00<0
IS<c00<0IVHc06Hc<`1VIS<00`1VIS<406Hc<`0306IV<`1VIVH0IVIV00D0IVIV0P2IIVH0101VIVH0
IVHc06IV<`1V<c<506IV<`0606Hc<`1VIVH0VFIV06IV<`1V<c<0IVIV0`1V<c<00`2IIS<0IVHc06Hc
<`0:06Hc<`80IVHc0`1V<c<01@1VIS<0IS<c06Hc<`1V<c<0IVHc00D0IS<c00<0<c<c06Hc<`1V<c<0
0P1V<c<00`0c<c<0IS<c06Hc<`0506Hc<`0303<c<`1V<c<0IS<c01d0IS<c0P0c<c<0100c<`00<c<c
03<c<`0c<`0203<c<`0303<c000c<c<0<c<c00@0<`0000<0<c<c03<0000c00001@0c000600000003
03<0000c<c<0<c<c0080<c<c0P1V<c<203<c<`0406Hc<`1VIS<0IS<c0<c<VDH0oooo000c0?ooo`04
0<c<c03<VIT0VIVI09UVIP80IVHc00<0IS<c06IV<`1V<c<00P1V<c<01@1VIS<0IS<c06Hc<`1V<c<0
IVHc0080IS<c0`1VIVH01@1VIS<0IVIV06Hc<`1V<c<0IVHc0080IVIV00<0VFIV06IVIP1VIS<01P1V
IVH01P2IIVH0IVIV06IVIP1VIVH0IVHc06IVIP80IVHc00<0VFIV06Hc<`1V<c<00P1VIS<206Hc<`80
IVHc2`1V<c<206IV<`@0IS<c00<0IVHc06Hc<`1V<c<01P1V<c<00`0c<c<0IS<c06Hc<`0403<c<`03
06Hc<`0c<c<0IS<c00<0IS<c0P0c<c<00`1V<c<0<c<c03<c<`0206Hc<`0303<c<`1V<c<0IS<c00H0
IS<c00<0<c<c06Hc<`1V<c<00P1V<c<01@0c<c<0IS<c06Hc<`1V<c<0<c<c00<0IS<c00<0<c<c06Hc
<`1V<c<00P0c<c<0100c<`00<c<c03<c<`0c<c<203<c000303<0000c<c<0<c<c00H0<`0000@00000
03<0000c0000<`001`0000000`0c0000<c<c03<c<`0203<c<`80IS<c0P0c<c<306Hc<`0309VIIP3o
ool0oooo04D0oooo000c0?ooo`050?o<o`3<c<`0VIVI09VIV@1VIVH00`1VIS<406Hc<`0406IV<`1V
<c<0IS<c06IVIP<0IS<c00<0IVHc06IVIP1VIVH00P1VIVH01@1VIS<0IS<c06Hc<`1V<c<0IVHc00H0
IVIV2@1VIS<01@2IIVH0VFHc06Hc<`1V<c<0IVHc00l0IS<c00<0IVHc06Hc<`1V<c<00`1V<c<00`0c
<c<0IS<c06Hc<`0306Hc<`0503<c<`1V<c<0<c<c06Hc<`0c<c<00P1V<c<703<c<`0606Hc<`0c<c<0
<c<c06Hc<`0c<c<0IS<c0`0c<c<206Hc<`0303<c<`1V<c<0IS<c00@0IS<c00@0<c<c06Hc<`1V<c<0
<c<c1@1V<c<203<c<`0506Hc<`0c<c<0<c<c03<c<`0c<`000P0c<c<603<c000403<c<`0c<`00<`00
03<c0080<`0000<0000003<0000c00000P0c00000`000000<`0003<000020000000403<000000000
000000000080<`000`0c<c<206Hc<`80<c<c00D0IS<c03<c<`1VIVH0VIVI0<c<c0170?ooo`00<`3o
ool01@3oc?l0c<c<0<bIV@3<VIT0VFIV0080IVHc0P1V<c<0201VIS<0IS<c06Hc<`1VIVH0IVHc06Hc
<`1VIS<0IVIV0`1V<c<00`1VIS<0IVIV06IVIP0206IVIP0309UVIP1VIS<0IVHc0080IS<c00D0IVIV
06IV<`1VIVH0IVIV06IV<`0506Hc<`<0IVHc00<0IS<c09UVIP1VIS<00P1V<c<00`1VIS<0IS<c06Hc
<`0806Hc<`0606IV<`1V<c<0IS<c06Hc<`0c<c<0IVHc0`1V<c<0100c<c<0IS<c03<c<`0c<c<306Hc
<`0603<c<`1V<c<0IS<c06Hc<`0c<c<0IS<c2P0c<c<00`1V<c<0<c<c03<c<`0203<c<`0506Hc<`0c
<c<0<c<c03<c<`1V<c<01P0c<c<0101V<c<0<c<c03<c<`1V<c<203<c<`0306Hc<`0c<c<0<c<c0080
IS<c100c<c<00`0c<`00<c<c03<c<`0203<c<`<0<c<00P0c0000100c<`00<c<c03<c000c<c<203<0
00040000000c0000<`0003<c<`80<`0000<0000003<0000c00001000000203<000@0<c<c00P0IS<c
03<c<`0c<c<0<c<c06Hc<`0c<`00VIVI0<c<c4P0oooo000d0?ooo`030?o<o`3<c<`0VIVI0080VFIV
00<0IVHc06Hc<`1V<c<0101V<c<00`1VIS<0IVIV06Hc<`0306IV<`<0IS<c00<0VFIV06IVIP2IIVH0
0`1VIVH209UVIP<0IS<c1`1VIVH406Hc<`0306IVIP1V<c<0IS<c00`0IS<c00<0IVHc06Hc<`1V<c<0
0`1V<c<0101VIS<0IS<c06Hc<`0c<c<206Hc<`0603<c<`1V<c<0<c<c03<c<`1V<c<0<c<c0P1V<c<A
03<c<`0306Hc<`0c<c<0<c<c0080<c<c00D0IS<c03<c<`1V<c<0<c<c06Hc<`0203<c<`0503<c001V
<c<0<c<006Hc<`0c<c<00P0c<`000`1V<c<0<c<c06Hc<`0603<c<`0503<c000c<c<0<c<c03<c<`0c
<`00200c00020000000403<000000000<`0003<000<0000000<0<`000000000000000P0c000603<c
<`0303<0000c<c<0IS<c0080<c<c00<0VIVI0?ooo`3oool0B03oool003D0oooo0P3<c<`0102IVIT0
VFIV06IVIP1VIS<206Hc<`80IVHc0P1V<c<00`1VIVH0IS<c06Hc<`0206Hc<`0306IV<`1V<c<0IS<c
00T0IVIV101V<c<206IVIP80VFIV0P1VIVH406Hc<`0303<c<`1V<c<0IS<c00/0IS<c00P0IVHc06Hc
<`1V<c<0<c<c06Hc<`0c<c<0IVHc06Hc<`80<c<c00@0IS<c03<c<`0c<c<0IS<c0`0c<c<00`1V<c<0
<c<c03<c<`0803<c<`0303<c000c<c<0<c<c00P0<c<c00<0<c<003<c<`0c<c<00P0c<c<00`0c<`00
IS<c03<c<`0203<c<`80<c<00`0c<c<303<c00H0<c<c00@0<c<003<c<`0c<c<0<c<01P0c<c<803<0
00<0000000@0<`0000000000000000000P0c000503<c<`0906Hc<`0c<c<0<c<c03<c<`1V<c<0<c<c
06Hc<`2IIVH0c<c<04X0oooo000e0?ooo`060?o<o`3<c?l0c<c<09VIV@2IIVH0IVHc0`1V<c<0101V
IS<0IS<c06Hc<`1VIS<406Hc<`80IVHc0`1V<c<00`1VIS<0IVIV06IVIP0906IVIPL0IS<c0P1VIS<0
0`0c<c<0IS<c06Hc<`0<06Hc<`0503<c<`1V<c<0IS<c06Hc<`0c<c<00P1V<c<303<c<`0706Hc<`0c
<c<0<c<003<c<`1V<c<0<c<c06Hc<`0903<c<`0503<c000c<c<0<c<003<c<`0c<`001`0c<c<00`0c
<`00<c<c03<c<`0203<c<`0403<c000c<c<0<c<c06Hc<`80<c<c0P0c<`000`0c0000<c<c03<c0002
03<c00<0<c<c00@0<c<003<c<`0c<c<0<c<c0P0c000403<c<`0403<c000c<c<0<c<c03<c00@0<`00
00<0000003<0000c00001000000203<000030000000c0000<c<c00@0<c<c00<0IS<c03<c<`1V<c<0
101V<c<00`2IIVH0VIW<0?ooo`1:0?ooo`00=P3oool0103<c<`0c<co0<c<c02IVIT406Hc<`<0IVHc
00<0IS<c06IV<`1V<c<0101V<c<00`1VIS<0IS<c06Hc<`0206Hc<`80IVHc1`1VIVH506IV<`80IS<c
0P1VIS<906Hc<`80<c<c1@1V<c<00`0c<c<0IS<c03<c<`0506Hc<`@0<c<c00<0IS<c03<c<`0c<c<0
0P0c<c<00`1V<c<0<c<c03<c<`0803<c<`80<c<000<0<c<c03<c000c<c<01P0c<c<00`0c<`00<c<c
03<c<`0203<c<`0:03<c000c<c<0IS<c03<c<`0c0000<c<c03<c000c0000<c<003<c<`80<c<0100c
<c<0100c<`00<c<c03<c000c<c<203<00080<c<c00<0<c<003<c<`0c<`000P0c<c<203<000030000
000c0000<`000080<`001000000203<000H0<c<c00<0IS<c03<c<`0c<c<00P0c<c<206Hc<`0309UV
<`3<VIT0oooo04/0oooo000g0?ooo`050?o<o`3<c<`0c9VI06IVIP1VIS<00`1V<c<00`1VIS<0IVIV
06IV<`0206IV<`H0IS<c0P1VIVH406IV<`0406Hc<`1VIS<0IVIV09UVIPL0IVIV1@1V<c<00`0c<c<0
IS<c06Hc<`0506Hc<`0303<c<`1V<c<0<c<c00D0IS<c0P0c<c<0101V<c<0<c<c03<c<`1V<c<903<c
<`0306Hc<`0c<c<0IS<c00<0<c<c00D0<`0003<c<`0c<c<0<c<c03<c000203<c<`0303<c000c0000
<`0000L0<c<c00<0<`0003<c000c<c<00`0c<c<01@0c<`00<c<c03<c<`0c<c<0<`000080<c<c00<0
<c<003<c<`0c<c<00P0c<`0203<c<`80<c<000<0<c<c03<0000c00000`0c000203<c<`D0<`000`00
00000`0c0000000000000003000000<0<`000`0c<c<01@0c<`00<c<c06Hc<`0c<`00<c<c00D0IS<c
00<0VIVI0?ooo`3oool0B`3oool003L0oooo00D0olco0<c<c03<c<`0VFIV06IVIP0306Hc<`80IVHc
00@0IS<c06IV<`1VIVH0IVHc0`1V<c<0101VIS<0IS<c06Hc<`1VIS<306IVIP0306IV<`1V<c<0IS<c
0080IS<c1@1VIVH00`2IIVH0IVIV06Hc<`0<06Hc<`0503<c<`1V<c<0<c<c06Hc<`0c<c<00`1V<c<3
03<c<`0306Hc<`0c<c<0<c<c00H0<c<c00<0IS<c03<c<`0c<c<01`0c<c<00`0c0000<c<c03<c<`02
03<c<`0303<0000c<c<0<`000080<`001@0c<c<203<c000303<0000c<`00<c<c00<0<c<c00@0<c<0
06Hc<`0c<c<0<`000P0c<c<203<00080<c<c00H0<`0003<c<`0c<c<0<c<c03<c000c<c<203<00080
<c<c1P0c00000`000000<`000000000303<000@000000`0c00000`0c<`00<c<c03<c<`0203<c<`03
06Hc<`0c<c<0<c<c00D0IS<c00<0VFIV0?ooo`3oool0C03oool003P0oooo0P3<c<`00`2IVIT0VFIV
06IV<`0606Hc<`80IVIV00@0IVHc06Hc<`1VIS<0IVIV101V<c<206IV<`@0IVIV1@1V<c<00`1VIS<0
IVIV06IVIP0506Hc<`80<c<c1P1V<c<00`0c<c<0IS<c03<c<`0206Hc<`0703<c<`1V<c<0IS<c03<c
<`1V<c<0<c<c06Hc<`0203<c<`0306Hc<`0c<c<0<c<c00@0<c<c00@0<`0003<c<`0c<c<0<`001P0c
<c<00`0c0000<c<c03<c<`0203<c<`0303<c000c0000<`000080<`0000<0<c<c03<c000c<`000`0c
<c<403<0000503<c000c<c<0<c<c03<c001V<c<00P0c000203<c<`0403<0000c<`00<c<c03<c00<0
<c<c2P0c00000`000000<`0003<0000203<000030000000c0000<`0000<0000000<0<`0003<c<`0c
<`000`0c<c<01@0c0000<c<c06Hc<`0c<c<0IS<c0080<c<c00D0<c<006Hc<`1V<c<0VFIV0<c<c01>
0?ooo`00>@3oool01@3<c?l0VIVI09UVIP1VIVH0IVHc00H0IS<c0P1VIVH0101VIS<0IS<c06Hc<`1V
IVH306Hc<`80IVHc1@1VIVH0101VIS<0IS<c06Hc<`1V<c<306IVIPD0IS<c00@0<c<c06Hc<`0c<c<0
<c<c101V<c<01P0c<c<0IS<c03<c<`1V<c<0<c<c06Hc<`<0<c<c00<0<c<003<c<`0c<c<00P0c<c<0
0`1V<c<0<c<c03<c<`0503<c<`0303<0000c<c<0<c<c00H0<c<c0P0c00000`0c<c<0<`0003<c<`05
03<000H0<c<c1@0c00000`0c<`00<c<c03<c<`0203<c<`0303<0000c<c<0<c<c0080<`000P0c<c<0
0`0c<`00<`0003<c<`0;03<000040000000c0000000000000080<`000`0000000`0c0000<c<c03<c
<`0203<c<`80<`0000<0<c<c06Hc<`0c<c<00P0c<c<00`0c<`00<c<c06Hc<`0209UVIP030<c<c03o
ool0oooo04d0oooo000j0?ooo`030<bIV@2IVIT0VFIV0080IVIV0P1V<c<206IV<`<0IS<c00<0IVIV
06Hc<`1V<c<00P1V<c<00`1VIS<0IS<c06Hc<`0306Hc<`<0IVIV00<0IVHc06Hc<`1V<c<00`1V<c<0
100c<c<0IS<c06Hc<`1VIS<206Hc<`0403<c<`1V<c<0<c<c03<c00<0<c<c0P1V<c<01@0c<c<0IS<c
03<c<`0c<c<0IS<c0080<c<c0P1V<c<00`0c<`00<c<c06Hc<`0203<c<`0606Hc<`0c<c<0<c<c06Hc
<`0c<c<0<`000`0c<c<00`0c0000<c<c03<c<`0503<c<`P0<`0000<0<c<c03<0000c00001P0c<c<6
03<000<0<c<c0P0c000203<c<`80<`0000D0<c<c03<0000c0000<c<c0000000203<000030000000c
0000<`0000T0000000<0<`0003<c<`0c<c<00`0c<c<203<0000703<c000c<c<0IS<c03<c<`1V<c<0
<c<c03<c000206Hc<`0409UV<`2IIVH0c<c<0<c<c500oooo000j0?ooo`030?o<o`3<VIT0VIUV0080
VFIV00<0IVIV06Hc<`1V<c<00P1VIS<206Hc<`0306IV<`1VIVH0IVHc00L0IS<c00@0IVHc06Hc<`1V
<c<0IS<c0`1VIS<306Hc<`0303<c<`1V<c<0IS<c00<0IS<c00L0<c<c06Hc<`0c<c<0<c<c03<c000c
<c<0<c<000T0<c<c0P1V<c<203<c<`0306Hc<`0c<c<0<c<c00D0<c<c00D0<`0003<c<`0c<c<0<c<c
03<0000603<c<`H0<`000P0c<c<00`0c0000<c<c03<0000303<000@0<c<c1@0c000503<c<`80<`00
0`0c<c<00`0c0000<c<c03<0000403<00080000000<0<`000000000000001@0000000`0c0000<c<c
03<c<`0403<c<`80<`00100c<c<00`1V<c<0<c<c03<c<`0206Hc<`0309UV<`2IIVH0VFIV0580oooo
000k0?ooo`070<c<c02IVIT0VFIV09UVIP1VIVH0IVHc06Hc<`0306IV<`<0IS<c00<0IVIV06Hc<`1V
IS<01P1V<c<00`1VIVH0IVHc06IV<`0406Hc<`<0<c<c1@1V<c<403<c<`0403<c000c<c<0<c<c06Hc
<`T0<c<c00H0IS<c03<c<`0c<`00<c<c06Hc<`0c000303<c<`0303<c000c<c<0<c<c0080<c<c00<0
<c<003<0000c00000P0c000203<c<`0303<0000c<c<0<`0000<0<`0000<0<c<c03<0000c00000P0c
<c<203<000L0<c<c00@0000003<000000000<`000P0c<c<01@0c0000<c<c03<c<`0c<c<0<`0000@0
<c<c0P0c00000`000000<`00000000030000000303<000000000000000<0000000<0<`0003<c<`0c
<c<0100c<c<203<000D0<c<c00<0IS<c03<c<`0c<c<00P1V<c<0102IIS<0VFIV09UVIP2IIVH20?oo
o`030?o<o`3oool0oooo04d0oooo000l0?ooo`070<c<c02IVIT0VFIV09UVIP1VIVH0IVHc06Hc<`02
06IV<`0506IVIP1V<c<0IS<c06IV<`1V<c<00P1VIS<00`1VIVH0IVHc06IV<`0306IV<`@0IVIV101V
<c<0100c<c<0IS<c06Hc<`1VIS<306Hc<`<0<c<c00<0<c<003<c<`0c<c<00`0c<c<00`1V<c<0<c<c
03<c<`0403<c<`0306Hc<`0c<c<0<`000080<c<c0P0c00000`0c<`00<c<c03<0000203<c<`0603<0
000c<c<0<c<c03<c<`0c0000<c<c0P0c000303<c<`L0<`0000<0<c<c03<0000c<c<00P0c000303<c
<`0506Hc<`0c<c<0<c<c03<c<`0000000P0c00000`000000<c<c03<c<`0403<c<`80<`000P0c<c<2
03<000P000000`0c000803<c<`0403<c000c<c<0<c<c03<c<`<0IS<c00<0<c<c06Hc<`1V<c<00P1V
<c<0102IIS<0VFIV09UVIP3<VIT20?ooc500oooo000l0?ooo`030?o<o`2IVL`0VIVI0080VFIV00<0
IVIV06Hc<`1V<c<00P1VIS<306Hc<`0406IVIP1V<c<0IS<c06IV<`<0IVIV0`1VIS<306Hc<`80IVHc
00<0IS<c03<c<`0c<c<01@1V<c<603<c<`80<c<02`0c<c<01P0c0000<c<c03<c<`0c<c<0<c<003<0
0080<c<c0P0c00000`0c<c<0<`0003<c<`0203<c<`0303<0000c<c<0000000@0<c<c00<0<`000000
000000000P0c0000100c<c<0<`0003<c<`0c<c<203<000@0<c<c00@0IS<c03<c<`0c<c<0<c<c100c
000703<c<`80<`00100c<c<403<0000303<c<`0c0000<c<c00L0<c<c00<0<`0003<c<`0c<c<00P0c
<c<00`1V<c<0<c<c03<c<`0203<c<`@0IS<c00D0VFHc09UVIP2IIVH0VIVI0<c<c01B0?ooo`00?@3o
ool01P3oc?l0c9VI09VIV@2IIVH0IVIV06IV<`80IS<c0`1VIS<00`1V<c<0IVHc06IV<`0406Hc<`03
06IV<`1VIVH0IVIV0080IVHc1P1V<c<203<c<`0406Hc<`1VIS<0IS<c06Hc<`@0<c<c00<0<c<003<c
<`0c<`00200c<c<0100c<`00<c<c03<c000c<c<203<000<0<c<c00@0<c<003<0000c<c<0<c<c0P0c
000303<c<`80<`0000<0<c<c03<0000c00000`0c<c<803<00080<c<c00<0<`0003<c<`0c<c<00P0c
<c<00`1V<c<0<c<c06Hc<`0203<c<`@0<`00600c<c<00`0c<`00<c<c03<0000803<c<`@0IS<c00H0
VFHc09UVIP2IIVH0VFIV0<bIV@3oc?mB0?ooo`00?`3oool0202IVL`0VIUV09UVIP1VIVH0IVHc06Hc
<`1VIS<0IS<c0P1VIS<0101V<c<0IVHc06IV<`1VIS<206IVIP80IS<c0`1VIVH0101VIS<0IVIV06IV
IP1VIVH406Hc<`0406IV<`1V<c<0IS<c06Hc<`@0<c<c00D0<c<003<c<`0c<c<0<c<c03<c000703<c
<`0603<c000c<c<0<c<c03<c<`0c0000<c<00`0c<c<00`0c0000<c<003<c<`0203<c<`80<`000P0c
<c<203<0000303<c<`000000<`0000<0<c<c0P00000403<000<0<c<c0P0c000303<c<`0506Hc<`1V
IVH0<c<c06IVIP1V<c<00P0c<c<0100c0000<c<c03<c<`0c<c<203<000l0<c<c00<0IS<c03<c<`1V
<c<00P0c<c<203<0000403<c<`1V<c<0IS<c06Hc<`80<c<c00<0<c<006Hc<`1V<c<00`1V<c<209UV
<`80VFIV00<0VIVI0<c<c03oool0DP3oool00400oooo00D0c<c<09VIV@2IIVH0VFIV06IVIP0206IV
<`0306Hc<`1VIS<0IS<c0080IS<c0`1VIS<706IVIP0406IV<`1VIVH0IVIV06IV<`80IS<c00@0IVHc
06Hc<`1V<c<0IS<c0P0c<c<00`1V<c<0<c<c03<c<`0403<c<`0303<0000c<c<0<c<c0080<c<c00@0
<c<003<c<`0c<`00<c<00P0c<c<203<000<0<c<c00<0<`0003<c<`0c<c<00P0c00000`0c<c<0<`00
03<c<`0503<000030000000c0000<c<c0080<c<c00<0<`00000000000000100c000703<c<`0506Hc
<`1VIVH0IVIV03<c<`1V<c<00P1VIVH703<c<`0403<0000c<c<0<c<c03<000h0<c<c101V<c<203<c
<`L0IS<c00D0IVIV09UV<`2IIVH0VFIV0<c<c01E0?ooo`00@@3oool0103<c<`0VFIV09UVIP2IIVH2
06IVIP0406Hc<`1VIS<0IVHc06IV<`80IS<c0`1VIS<01@1V<c<0IVIV06IVIP1VIVH0IVHc00L0IS<c
0P1VIS<406Hc<`D0<c<c0P0c<`0503<c<`80<c<000<0<c<c03<c000c<`000P0c<c<0100c0000<c<c
03<c<`0c<c<203<00080<c<c00D0<`0003<c<`0c<c<0<`0003<c<`0303<0000403<c<`000000<`00
03<00080<c<c0P0c000300000080<`00200c<c<01P1V<fH0IVIV06IVIP1V<fH0<c<c06Hc<`80IVHc
00@0<c<c06Hc<`0c<c<0IS<c1@0c<c<00`0c0000<c<c03<c<`0503<c<`0403<0000c<c<0IS<c03<c
<`@0IS<c00<0<c<003<c<`1V<c<0201V<c<0102IIS<0VFIV09UVIP3<VIUF0?ooo`00@P3oool409UV
IP80IVIV0`1VIS<606Hc<`80IVHc1P1VIVH406Hc<`0306IVIP1V<c<0IS<c00@0IS<c0`0c<c<203<0
000303<c<`0c<`00<c<c00D0<c<c00@0<`0003<c<`0c<`00<c<c0P0c000303<c<`0303<0000c<c<0
<c<c0080<`0000<0<c<c03<0000c<c<00`0c0000100c<c<0<`0003<0000c000203<c<`@0<`000P00
000303<0000303<c<`1V<c<0<c<c00<0<c<c00<0IS<c06IVIP1VIVH00P1VIVH00`0c<c<0IS<c03<c
<`0203<c<`0306Hc<`0c<c<0<c<c0080IS<c2P0c<c<00`1V<c<0<c<c06Hc<`0306Hc<`80<c<c2P1V
<c<0102IIS<0VFIV09UVIP2IVIUG0?ooo`00@P3oool00`3<c<`0VIVI09UVIP0309UVIP80IVIV00<0
IVHc06Hc<`1V<c<01P1V<c<506IV<`<0IVIV00<0IVHc06Hc<`1VIS<0101V<c<00`0c<c<0IS<c06Hc
<`0203<c<`80<`0000<0<c<003<0000c<c<00`0c<c<203<c000303<c<`0c<`00<c<c0080<c<c00@0
<`0003<c<`0c<c<0<c<c0P0c00001`0c<c<0<`000000000c0000<c<c03<0000c<c<00`0c00000`0c
<c<0<`0003<0000303<c<`0403<000000000<`0003<000<000000P0c00001@0c<c<0IVHc06Hc<`0c
<c<0IS<c0080<c<c00<0IS<c06IVIP1VIVH00P1VIVH01`1V<c<0<c<c03<c<`0c<c<0IS<c03<c<`1V
<c<0200c<c<506Hc<`<0<c<c201V<c<0201VIS<0IS<c06Hc<`1VIVH0VFIV09UV<`2IIVH0VIVIF03o
ool004<0oooo00<0c<c<09UVIP2IIVH00P2IIVH406IVIP0306IV<`1V<c<0IS<c00<0IS<c0`1VIS<4
06IVIP80IVHc0P1VIVH806Hc<`<0<c<c0P0c000503<c<`0803<0000c<c<0<c<003<0000c<`00<`00
03<c<`0c000303<c<`80<`000P0c<c<303<000<0<c<c1P0c000203<c<`P0<`000P0000000`0c<c<0
IVIV06IVIP0306Hc<`80<c<c00<0IVHc06IVIP1VIVH0101VIVH00`1V<fH0IS<c06Hc<`0206Hc<`03
06IV<`1VIVH0IS<c00D0IS<c0P0c<c<00`0c<`00<c<c06Hc<`0806Hc<`0406IV<`1V<c<0IS<c06Hc
<`80VFHc00<0VFIV09VIV@3oool0F03oool004@0oooo00<0c<c<09VIV@2IIVH00P2IIVH406IVIP80
IVHc101V<c<:06IVIP0306IV<`1V<c<0IS<c00H0IS<c0`0c<c<203<000@0<c<c00<0<c<003<0000c
<c<00P0c<c<0100c<`00<c<c03<0000c000203<c<`80<`0000<0<c<c03<0000c<c<00`0c000203<c
<`D0<`00100c<c<603<0000:03<c<`0c0000<`0003<0000c<c<0IS<c06IV<`1VIVH0IVHc06Hc<`@0
<c<c0`1V<c<406IVIP<0IVHc101V<c<303<c<``0IS<c00<0IVHc06Hc<`1V<c<00P1V<c<309UV<`03
0<c<c03oool0oooo05L0oooo00150?ooo`050<c<c02IVIT0VFIV09UVIP1VIVH01`1VIS<306Hc<`80
IVHc2@1VIVH706Hc<`0503<c<`1V<c<0<c<c03<c<`0c00001P0c<c<203<c0080<c<c00<0<c<003<0
000c00000`0c<c<503<000040000000c0000<c<c03<c<`H0<`00100c<c<00`0c0000000003<00002
03<000@0<c<c00@0<`0003<c<`0c<c<0IVIV0`1V<c<206IVIP80IS<c200c<c<;06Hc<`0306IV<`1V
<c<0IS<c00X0IS<c00@0VFHc09UVIP2IIVH0VFIVFP3oool004P0oooo00<0VIVI06IVIP1VIVH00P1V
IVH206IV<`80IS<c0`1VIS<00`1VIVH0IVHc06IVIP0506IVIP0409UVIP1VIVH0IVIV06IVIP/0IS<c
300c<c<203<000@0<c<c0P0c0000100c<c<0<`0003<0000c000203<c<`<0<`0000<0<c<c03<0000c
<c<01P0c<c<00`0c0000<c<c03<c<`0903<c<`@0IS<c00H0<c<c06Hc<`1V<c<0IVHc06Hc<`1VIS<2
06IVIP<0IVHc00<0IVIV06IV<`1VIS<0401V<c<309UVIP0309UV<`2IVFH0c<c<05/0oooo00190?oo
o`80VFIV0P1VIVH209UVIP0306IVIP1VIS<0IS<c0080IVHc2@1VIVH00`2IIVH0IVIV06IVIP0906Hc
<`80<c<c0P1V<c<203<c<`0306Hc<`0c<c<0<c<c00H0<c<c0P0c000303<c<`80<`000`0c<c<203<0
0080<c<c0P0c000B03<c<`80IS<c0`0c<c<00`1V<c<0IVIV06Hc<`0:03<c<`0306Hc<`0c<c<0<c<c
00D0<c<c2@1V<c<209UV<`@0VFIV00<0c<c<0?ooo`3oool0FP3oool004T0oooo00@0VIW<09UVIP2I
IVH0IVIV0P1VIS<0101VIVH0IVHc06IV<`1VIS<206Hc<`0306IV<`1VIVH0IVIV00<0IVIV0P2IIVH3
09VIV@0306IV<`1V<c<0IS<c00D0IS<c00@0<c<c06Hc<`1V<c<0<c<c0P1V<c<00`0c<c<0IS<c06Hc
<`0206Hc<`H0<c<c00<0<`0003<c<`0c<c<00P0c<c<203<000<0<c<c00D0<`0003<c<`0c<c<0<c<c
03<0000903<c<`0306Hc<`0c<c<0<c<c00T0<c<c00L0IS<c03<c<`0c<c<0<c<c06Hc<`1VIS<0IS<c
00T0<c<c00D0IS<c03<c<`1V<c<0IS<c03<c<`0906Hc<`0306IVIP1V<c<0VFHc0080VFIV00<0VFHc
09UVIP3<c<`0G@3oool004X0oooo00<0c9VI09UVIP2IIVH00P1VIVH00`1VIS<0IS<c06IV<`0506IV
<`@0IVIV0P2IIVH00`2IVIT0VIUV09UVIP0206IV<`X0IS<c00<0<c<c06Hc<`1V<c<01P1V<c<303<c
<`0406Hc<`0c<c<0<c<c06Hc<``0<c<c00@0<`0003<c<`0c<c<0IS<c1P0c<c<01`1VIVH0<c<c03<c
<`0c<c<0IS<c06IVIP1V<c<02P0c<c<406Hc<`80<c<c4@1V<c<0101VIS<0IS<c09UV<`2IIS<209UV
IP0309VIV@3<c<`0oooo05d0oooo001;0?ooo`040<c<c02IVIT0VFIV09UVIP80IVIV0P1V<c<306IV
<`80IS<c101VIVH409UVIP<0IVIV1@1V<c<0100c<c<0IS<c03<c<`1V<c<303<c<`H0IS<c00<0<c<c
06Hc<`0c<c<00P1VIVH403<c<`0403<0000c<c<0<c<c06Hc<`P0<c<c00<0<`0006Hc<`1V<c<00`0c
<c<0101VIVH0<c<c03<c<`1V<fH303<c<`0606Hc<`1VIVH0IVIV06IV<`1V<fH0IVIV0P1V<c<703<c
<a00IS<c00<0IVHc06Hc<`1V<c<00P2IIS<409UVIP030<bIV@3oool0oooo05h0oooo001<0?ooo`03
0<c<c02IVIT0VIVI0080VFIV00<0IVHc06Hc<`1V<c<00P1V<c<206IV<`<0IVIV1@2IIVH0102IVIT0
VFIV09UVIP1VIVH706Hc<`0303<c<`1V<c<0IS<c00X0IS<c00<0<c<c06IVIP1V<fH0100c<c<01P0c
0000<c<c03<c<`1V<c<0<c<c06Hc<`<0<c<c00`0IS<c03<c<`0c<c<0IS<c06IVIP1V<c<0IVIV03<c
<`1V<c<0IVIV06HcIP1VIS<206IVIP<0<c<c00<0IS<c06IVIP1VIVH00P1VIVHC06Hc<`80IVHc00<0
IVIV06IV<`1VIS<00P1V<c<00`1VIVH0VFHc09UVIP0309UVIP0309UV<`3oool0oooo05l0oooo001=
0?ooo`80c<c<0P2IVIT00`1VIVH0IVHc06IV<`0406Hc<`0406IV<`1VIVH0IVIV06IVIP80VFIV0`2I
VIT01@2IIVH0IVIV06IVIP1VIVH0IVHc00@0IS<c00<0<c<c06Hc<`1V<c<00P1V<c<00`0c<c<0IS<c
06Hc<`0206Hc<`80IVHc0`1V<c<00`0c<c<0IVHc03<c<`0403<c<`0303<0000c<c<0<c<c00@0IS<c
00D0IVIV06Hc<`1VIS<0IS=V06Hc<`0206IVIP0506Hc<`1VIS<0IS<c06Hc<`1VIVH00P1V<c<00`2I
IVH0IVIV06IV<`0303<c<a@0IS<c0P1VIS<00`2IIS<0IVIV06IV<`0406Hc<`0709UV<`2IIVH0VFIV
09UV<`1V<c<0IVHc0<bIV@1Q0?ooo`00C`3oool01P3oc?l0c<c<09UVIP2IIVH0IVIV06IV<`@0IS<c
101VIVH00`2IIYT0VIVI09UVIP0309VIV@0409UVIP1VIVH0IVIV06IVIP80IVHc00@0IVIV06IV<`1V
<c<0<c<c0`1V<c<203<c<`0706Hc<`1VIVH0IS<c06IVIP1V<c<0IVHc06IVIP0206Hc<`0506IVIP0c
<c<0IS<c03<c<`1V<c<00`0c<c<206Hc<`0506IVIP1V<c<0IS<c06Hc<`1VIS<01`1VIVH206Hc<`L0
IVIV00<0IS=V06IVIP1V<c<00P1VIS<406Hc<`L0IVHc0P1VIVH206Hc<`0306IV<`2IIS<0IS<c00D0
IS<c0P2IIS<209UVIP80IS<c00<0VFIV0<c<c03oool0H@3oool00540oooo0P3<c<`00`2IVIT0VFIV
09UVIP0206IVIP0306IV<`2IIVH0IVIV00D0IVIV00<0VFIV06IVIP2IIVH00P2IVIT0102IIVH0IVIV
09UVIP1VIVH509UVIP80IVIV00@0IVHc06Hc<`1V<c<0IS<c0P1VIS<00`1V<c<0IVIV06IVIP0206IV
IP0306Hc<`1VIVH0IVIV0080IVIV00<0IS<c06IVIP1V<c<00P0c<c<206IVIP0406Hc<`1VIS<0IVIV
06IV<`L0IVIV00<0IS=V06Hc<`1V<c<00P1V<c<01P1VIS<0IVIV06IVIP1VIS<0IS<c06IV<`80IS<c
00<0IVHc06Hc<`1V<c<00P1VIS<<06Hc<`<0VFHc00P0VFIV09UV<`2IIS<0VFHc06IVIP1V<c<0IVIV
0<bIVFD0oooo001B0?ooo`030?o<o`3<c<`0VIVI0080VFIV101VIVH206IV<`<0IVIV0P2IIVH00`2I
VIT0IVIV09UVIP0<09UVIP80IVIV0P1V<c<206IV<`P0IVIV00D0VFIV06IVIP1VIVH0IVIV06Hc<`02
03<c<`0306IVIP1V<fH0IS<c00@0IS<c1@1VIVH206IV<`0306IVIP1VIS<0IVIV0080IS<c0P1VIS<3
06IVIP@0IVHc201V<c<206IV<`0406Hc<`2IIS<0IVIV09UVIP80VFHc0P2IIVH01P2IIS<0IVIV09UV
<`1V<c<0VFIV0<c<c6H0oooo001C0?ooo`80olco00@0c9W<0<bIV@2IVIT0VFIV1`1VIVH509UVIP80
VIVI3P2IIVH0101VIVH0IVHc06IV<`1VIS<206IVIP0309UVIP1VIVH0IVIV00L0IVIV00<0<c<c06Hc
<`1V<c<01@1V<c<306IVIP0309UVIP1VIVH0IS<c00D0IVHc00D0IVIV06IV<`1VIS<0IS<c06IV<`0;
06Hc<`0706IV<`1V<c<0IVHc09UV<`1VIS<0VFIV09UV<`0409UVIP80VFHc0P1V<c<00`1VIS<0c<c<
0?ooo`1V0?ooo`00EP3oool01@3<c<`0c9VI09UVIP1VIVH0VFIV00D0IVIV0`2IIVH00`2IVIT0VFIV
09UVIP0A09UVIPD0IVIV0P2IIVH706IVIP0306HcIP1V<c<0IS<c00<0IS<c0P0c<c<406Hc<`0306IV
IP2IIVH0IVHc0080IVHc00<0IS<c06IV<`1V<c<03@1V<c<01@1VIS<0VFHc06IV<`1VIVH0VFHc0080
VFIV00<0VFHc09UVIP2IIS<00P2IIVH01P2IIS<0IS<c06Hc<`1V<c<0VFIV0<c<c6P0oooo001G0?oo
o`040?o<o`3<c<`0VIVI09UVIPD0IVIV00<0IVHc06IVIP2IIVH0102IIVH00`2IVIT0VFIV09UVIP0<
09UVIP0309VIIP2IIVH0VFIV0080VFIV0P1VIVH409UVIP80IVIV00H0VFIV09UVV@1VIVH0IVIV06Hc
<`1VIS<406Hc<`@0<c<c0P1V<c<00`2IIVH0IVIV06Hc<`0906Hc<`0306IV<`1V<c<0IS<c0080IS<c
00@0IVHc06Hc<`2IIS<0IS<c0P2IIS<709UVIP<0IS<c00<0VFIV09VIV@3oool0J@3oool005T0oooo
00<0c<c<09VIV@2IIVH01P1VIVH0102IIVH0IVIV09UVIP2IIVH209VIV@<0VFIV00<0VIVI09UVIP2I
IVH01P2IIVH01@2IVIT0VFIV09UVIP2IVIT0VIUV00<0VFIV00@0IVIV09UVIP2IIVH0VFIV0P2IVIT2
06IVIP80VFIV0`1VIVH00`1VIS<0IS<c06Hc<`0806Hc<`@0IVIV00T0IVHc06Hc<`1VIS<0IVHc06Hc
<`1VIS<0IS<c09UV<`1VIVH00P1VIS<00`2IIS<0IVHc06IVIP0909UVIP0609UV<`1V<c<0IS<c09UV
IP2IVIT0c<c<J`3oool005/0oooo00<0c<c<09VIV@2IVIT00`2IIVH406IVIP<0VFIV00D0IVIV09UV
IP2IIVH0IVIV09UVIP0209VIV@T0VFIV00@0VIVI09UVIP2IVFH0VIUV1@2IIVH209VIV@@0VFIV00@0
IVIV09UVIP2IIVH0VFIV2`1VIVH206IV<`80IVIV00D0IVHc06IVIP1V<c<0IVHc06IVIP0206IV<`03
09UV<`2IIVH0VFIV00T0VFIV00H0VFHc06Hc<`1V<c<0VFIV09VIV@3<c<a]0?ooo`00G`3oool01P3o
c?l0VIVI06IVIP1VIS<0IS=V06IVIP80IVHc0`1VIVH309VIV@0609UVIP2IVIT0VIVI09VIIP2IVIT0
VIUV0P2IVIT609UVIP0309VIIP2IIVH0VFIV00L0VFIV00<0VIUV09VIV@2IIVH06`2IIVH00`2IVFH0
VFIV09VIIP0209UVIP0309VIIP1VIS<0IS<c0080IS<c00<0VFIV09VIV@3<c<`0L03oool00640oooo
00<0c<c<09VIV@2IVIT01@1VIVH209UVIP/0VIVI1@2IIVH00`2IVIT0VFIV09UVIP0209UVIP80VIVI
00<0VIUV09VIV@2IVIT0102IIVH00`2IVIT0VFIV09UVIP0A09UVIP0309VIIP3<VFH0c9UV0080c9UV
0P2IVFH01P3<VFH0VIUV09UVIP2IIVH0IVIV06IV<`80VFIV00<0VIVI0<c<c03oool0L@3oool006<0
oooo00H0olco0<c<c02IVL`0VIVI09UVV@2IIVH209UVV@0>09VIV@3<VIT0VIVI0<bIV@3<c<`0c9W<
0<bIV@2IVIT0c9VI09VIV@3<VIT0VIVI09VIIP2IVIT209VIIP80VFIV00@0IVIV09UVIP2IIVH0VFIV
0P2IVFH0102IVIT0VIUV09VIIP2IVIT409VIIP@0VFIV00<0VIUV09UVIP2IIVH0202IIVH409VIIPH0
VFIV101VIS<0102IIS<0VFIV09UVIP3<c<ad0?ooo`00I`3oool30?o<o`090?ooo`3<c<`0c<c<0<c<
o`3<c<`0olco0<c<o`3<c<`0c9VI0080c<c<00<0VIVI09VIc03<VIT01@2IVIT00`2IVFH0VFIV09UV
IP0609UVIP040<bIIP2IVIT0VIVI09VIV@<0VIUV5@2IIVH00`1VIVH0IVHc06IV<`0206IV<`80VFIV
00<0c<c<0?ooo`3oool0M03oool006d0oooo0P3oc?l20?ooo`D0c<c<00<0olco0<c<c03<VIT00`2I
VIT01@3<VIT0VIVI09UVIP2IIVH0VIUV00@0VFIV00<0IVIV09UVIP2IIVH00P2IIVH0102IVFH0VFIV
09VIIP2IVFHD09UVIP0709UV<`2IIVH0VFIV09UVIP2IVIT0VIW<0<c<c01g0?ooo`00L03oool20?o<
o`090<c<o`3<c<`0c<c<0<c<o`3<c<`0oooo0?o<o`3<c<`0c9VI00H0VIVI00@0VIUV09UVIP2IVFH0
VIUV1`2IIVH0102IVIT0VIUV09VIV@2IVFH=09UVIP<0IVIV0P1VIS<0102IIVH0VIVI0<bIc03<c<aj
0?ooo`00L`3oool0103oc?l0oooo0?ooo`3oc?l30?ooo`@0c<c<00D0c9VI09VIV@2IVIT0VIVI0<bI
V@0309VIV@@0VFIV00<0VIUV09UVIP2IIVH00`2IIVH00`2IVIT0VIUV09UVIP0709UVIP0406IVIP2I
IVH0IVIV06IVIP<0VFIV00<0VIVI0<c<c03oool0O03oool00840oooo0P3oc?l30<c<c00409VIc03<
VIT0c9VI0<bIV@H0VIVI0P2IIVH509VIV@030<bIV@2IVIT0c<c<0080c<c<00<0oooo0?o<o`3oool0
P@3oool008P0oooo0`3oc?l00`3<c?l0c<c<0<c<c0040<c<c0030?o<o`3oool0olco08/0oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo001:0?ooo`900000Q`3oool2@00004/0oooo001<0?ooo`03@000
003oool0oooo08H0oooo00=000000?ooo`3oool0B03oool003h0oooo0d0000030?ooo`=000000`3o
ool3@00000D0oooo00=000000?ooo`3oool02T0000050?ooo`03@000003oool0oooo00L0oooo0d00
00030?ooo`A0000000D0oooo@0000400001000000?ooo`02@0000080oooo00=000000?ooo`3oool0
0T0000030?ooo`9000000`3oool3@00000h0oooo0d0000030?ooo`9000000P3oool3@00000<0oooo
0T0000020?ooo`=000003@3oool3@00000070?oood000000oooo@000003ooom000000?ooo`04@000
0080oooo0d0000020?ooo`900000AP3oool003l0oooo00=000000?ooo`3oool00`3oool01D000000
oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool00d000000oooo0?ooo`020?oo
o`03@000003oool0oooo0100oooo00=000000?ooo`3oool00P3oool3@00000<0oooo00E000000?oo
o`3oool0oooo@00000020?ooo`03@000003ooom000000080oooo00=000000?oood000000103oool0
14000000oooo0?oood00000>0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom00000
0P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom000003`3oool02D00
0000oooo0?oood000000oooo@000003ooom000000?ooo`03@0000080oooo00I000000?ooo`3ooom0
00000?oood0000180?ooo`00?`3oool00d000000oooo0?ooo`030?ooo`05@000003oool0oooo0?oo
od0000000P3oool00d000000oooo0?ooo`080?ooo`03@000003oool0oooo0080oooo00=000000?oo
o`3oool0403oool3@00000@0oooo00E000000?ooo`3oool0oooo@00000030?ooo`06@000003oool0
oooo@000003ooom00000103oool3@0000080oooo00A000000?ooo`3ooom000003P3oool00d000000
oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo00E000000?ooo`3oool0oooo@0000002
0?ooo`04@000003oool0oooo@00000l0oooo00Q000000?ooo`3ooom000000?oood000000oooo@000
00<0oooo00A000000?ooo`3ooom000000P3oool00d000000oooo@0000002@00004H0oooo000o0?oo
o`9000000`3oool2@00000@0oooo0d00000:0?ooo`03@000003oool0oooo0080oooo00=000000?oo
o`3oool0403oool014000000oooo0?oood0000020?ooo`9000000P3oool2@0000080oooo14000000
0`3ooom00000@0000002@0000080oooo0d0000030?ooo`=000003P3oool3@00000<0oooo0T000003
0?ooo`03@000003oool0oooo0080oooo0T0000020?ooo`A00000303oool2@0000080oooo0T000000
0`3ooom000000?ooo`020?ooo`9000000`3oool3@00000040?oood0000100000@00004H0oooo000o
0?ooo`04@000003oool0oooo@00001@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?oo
o`0@0?ooo`04@000003oool0oooo@0000100oooo00=000000?ooo`3oool02P3oool00d000000oooo
0?ooo`0G0?ooo`03@000003oool0oooo07<0oooo000n0?ooo`E000000P3oool00d000000oooo0?oo
o`0>0?ooo`9000000`3oool2@0000140oooo140000080?ooo`03@000003oool0oooo0180oooo0T00
000H0?ooo`9000006@3oool00d000000oooo0?ooo`1I0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-14.3105, -6.40135, 0.991711, 
  0.991711}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.6 High-resolution image generation",
  FontFamily->"Times New Roman"]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In this section, we generate the high-resolution color images by means of \
the image governing equation, i.e. a Poisson type partial differential \
equation. \nAt first, we read in a low-resolution color image. Second, we \
derive the source densities of the red, green and blue components composing \
the low-resolution color image. Third, we solve each of the partial \
differential equations having the red, green and blue component source \
density inputs, independently. Setting the high-resolution conditions \
generates the high-resolution red, green and blue component images. Finally, \
composition of the generated high-resolution color components gives a \
high-resolution color image. We generate two high-resolution images from the \
one low-resolution image. Recoverability is checked up by the correlation \
coefficients between the generated and original color image data.\n \tBefore \
to continue the computation, we remove the needless memories by a following \
command and check up the used memories.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Remove[\"vectMagG\",\"innerProG\",\"monoMG\",\"monoIG\",\"colorSketchData\",
\t\"normalizedCSD\",\"level\",\"pSample\"];
Unprotect[In,Out];Clear[In,Out];Protect[In,Out];
Print[\"Memory: \",Round[N[MemoryInUse[]/1000]],\"K Bytes used\"];\
\>", "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    InterpretationBox[
      \("Memory: "\[InvisibleSpace]4578\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ "Memory: ", 4578, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "More memories than the previous session were used. This means that the \
response speed of ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " front-end processor becomes slow.\n\tIn order to obtain the \
low-resolution source densities, we have to read in a low-resolution color \
image data \[OpenCurlyDoubleQuote]AF038-64.bmp\[CloseCurlyDoubleQuote] whose \
image is shown in Fig. 12.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
sampleL=rgbBMP[\"AF038-64.bmp\"];
dim=Dimensions[sampleL];
Show[convertRGB[sampleL],PlotLabel->StringForm[
\t\"Fig.12.Original`1` by `2`pixles image\",dim[[2]],dim[[3]]],
\tAspectRatio->dim[[2]]/dim[[3]]];\
\>", "Input",
  CellLabel->"In[63]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -107 0 ]
[.5 1.0125 107 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -168 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.12) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Original) show
153.000000 12.812500 moveto
(64) show
171.000000 12.812500 moveto
(by) show
189.000000 12.812500 moveto
(64) show
201.000000 12.812500 moveto
(pixles) show
243.000000 12.812500 moveto
(image) show
273.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFCEB5
F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADE7B59C\
E7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEA58CD6A584D6A58CD6A584D6A58C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BD
F7D6C6F7D6BDF7DECEF7D6C6F7DECEF7DECEF7D6BDEFCEB5EFCEB5EFC6ADE7BDA5DEB59CDEAD94\
DEAD94D6A58CDEAD94DEAD94DEAD94DEA58CDEA58CD6A58CD6A58CD6A584D6C6BD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFCEB5
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6EFCEB5D6C6B5E7BDA5E7AD9CDEAD94DEB59CDEB59C\
DEB59CDEAD94D6A58CD6A58CD6A58CD6A58CD6A584D6A58CD6A58CD6A58CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5F7BDB5E7B59CE7AD94E7AD9C\
E7AD9CDE9C8CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94D6A58CD6A58CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6EFCEB5EFBDADEFBDA5EFBDA5\
E7AD9CEFBDA5DE9C8CDE9C8CDEB5A5D6A58CDEA58CDEA58CD6A58CDEB59CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BD
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6BDEFC6ADEFBDAD\
EFBDA5E7B59CE7AD9CDEAD94DEA58CDEB5A5D6A58CD6A58CD6A58CEFD6CEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DEB5A5F7D6BD
F7D6C6F7D6BDF7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7CEB5F7C6AD\
EFBDA5EFBDA5E7AD9CE7AD94DEA58CD6A58CD6A58CDEA58CD6A58CEFE7E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEF\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C7363EFCEB5F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6BDF7DECEF7D6C6F7D6C6F7D6BDF7D6BDEFBDAD\
EFBDA5EFB5A5E7B594DEA58CDEAD94DEA58CD6A58CDEB59CDEAD94F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6CE5A3129F7D6C6F7D6BD
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BDF7BDB5EFBDA5E7B59CEFBDA5\
EFBDA5E7BDA5DEAD94E7AD94DEAD94D6A584D6A58CD6A58CD6A58CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF634231EFCEB5F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6EFCEB5EFBDADEFBDA5E7B59CE7B59C\
E7B59CE7B594DEAD94DEA58CDEA58CDEA58CDEA58CD6A58CDEAD94EFD6CEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7634231F7DECEF7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6EF948CEF948CE7847BE7847BE7847B\
E7AD94DEA58CDEA58CDE9C84D6A584DEA58CDEA58CD6A584DE9C84D6A58CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6C6EFD6CEF7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7CEB5F7CEB5F7CEB5F7D6C6F7D6C6F7BDB5F7BDB5EF948CE78473DE6B5AE7847BDE7B6B\
E7847BD68C7BD69C84D6A584D69C84DEA58CDEA58CDEA58CDE9C84DEAD94DEAD94
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75A4239EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDEFC6ADEFBDA5F7D6BDF7D6C6F7C6ADEF948CE78473DE9C8CC66B52DEB59CE7AD9CD66352\
D66352DE7B6BD68C7BD6A58CD69C73D6A584DEA58CDEA58CDEA58CDEA58CDEAD94
F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7B59C9CC69C84F7D6BDF7D6C6EFC6ADF7DECEF7D6C6
F7C6ADE7B594DE9C84F7BDB5E7847B842918E7AD9CE79484EFB5A5F7E7DEE77B6BCE8C73BD8463\
C69484A5634AD66352CE947BD69C73DE9C84DEAD94E7B594DEA58CDEAD94DEA58C
DEAD94F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7634A42EFCEB5F7D6C6F7D6BDEFBDA5F7D6C6F7D6C6
F7C6ADDE9473D68C738C2921D6C6BDF7E7DEF7E7DEF7EFEFF7E7E7F7E7DEEFCEB5F7E7DEEFD6CE\
C6ADA5945A4A734229C66B52D6A584DE9C84E7B59CE7B59CE7B594DEA58CDEA58C
DEAD94DED6E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7DED6E7523129EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6
E7A58CC68C63BD5A42842918E79484EFBDA5EFB5A5F7E7DEF7D6BDF7D6BDE7AD9CEFD6CEE7AD94\
F7D6C6D6A58CBD9C8C734231C66B52D69C84E7B594EFC6ADE7B59CDEAD94DE9C84
DEA58CD6C6B5CEBDB5DED6E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F78C7363523129C69484F7D6BDF7D6BDF7C6ADF7C6ADF7D6BDF7D6BD
E7A58CE7B59CEFCEB5F7D6BDF7BDB5EFB5A5E7AD9CE7AD9CEF948CDE9C8CDE7B6BDE6B5AD67363\
DEB59CD68C73CE8C84AD7B6B732110D68C7BE7B594EFC6ADE7B594DEA58CD6A58C
DEAD94DEB59CF7EFEFD6C6D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7DECED6312118422921F7D6C6F7D6BDF7CEB5F7BDB5EFCEB5F7D6BDF7BDB5
E7AD94CE8C6BF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6BDEFBDA5EFBDA5E7B594E7AD94\
DE9C84E7847BD67363BD5A429C3929A54231DEA58CEFBDA5E7B594DEA58CD69C84
DEA58CDEAD94734A39F7EFEFEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7DED6E7F7D6BDEFBDA5EFCEB5F7D6BDF7CEB5F7D6BDF7BDB5F7D6BDF7D6BD
E7B59CDE9C84EFC6ADF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7BDB5EFBDA5EFBDA5E7B59CE7AD94\
D6A584D69C84D6A584D69C84D69C84CE8C84D69C73E7B59CE7B594DEA58CD6A584
DEA58CDEAD947B635AD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7D6BDF7D6C6F7DECEEFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7DECEF7D6C6
EFC6ADE7AD94DE9C84EFCEB5F7DECEF7DECEF7D6C6F7DECEF7D6BDEFBDA5E7A58CE7B594D6A584\
C69C84CE9473CE8C73CE9473CE8C73CE9473DEAD94E7B59CE7AD94D69C84D69C84
D6A584D6A58C523931E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
EFE7E7F7D6BDEFC6ADE7B594D6C6C6F7CEB5F7D6C6F7DECEF7DECEF7DECEF7DECE
F7BDB5EFBDA5E7A58CEFBDA5F7D6C6F7DECEF7BDB5EFCEB5F7D6BDE7B59CE7AD94D68C73D6A58C\
CE8C73CE9473CE947BD69C73CE9473CE8C6BE7AD94E7AD94DEA58CD69C84D69C84
D6A58CDEAD94312121CEBDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7D6BDF7D6C6E7B59CDEAD94EFCEB5F7BDB5F7D6C6F7DECEF7DECEF7DECEF7DECE
F7D6BDF7C6ADE7B594E7A58CF7D6C6F7DECEF7D6C6F7D6C6F7D6C6EFBDADE7B59CDEA58CDEA58C\
CE8C73CE8C73CE947BD69C84DE9C84E7AD94E7B59CDEA58CDEA58CDEA58CD69C84
D6A584D6A58C422921634A42F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7D6BDEFCEB5CE8C6BEFCEB5F7BDB5F7D6BDF7D6C6F7DECEF7E7DEF7DECEF7DECE
F7D6C6F7D6BDE7B59CE7B594EFCEB5F7D6C6F7D6BDF7DECEF7D6C6EFC6ADDEA58CDEA58CD6A58C\
D69C84D69C73CE8C73D69C84E7AD9CEFBDA5E7B59CDEB59CDEAD94D6A58CD6A58C
D6A58CDEB59CC68C63844A39634A42F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6\
E7A58CD67363D69C84D6C6B5F7D6BDF7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECE
F7D6C6EFCEB5EFC6ADEFCEB5F7D6BDF7D6BDEFBDADF7D6BDF7BDB5E7B594DE9C84D69C84CE947B\
D69C73BD846BCE8C73DEAD94E7B59CEFBDA5E7B59CDEAD94DEA58CDEA58CD6A584
DE9C84DEB59CD69C84D69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDB5\
E79484D67B6BD6A58CEFCEB5F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6
F7D6BDEFCEB5F7C6ADEFCEB5F7D6C6F7DECEF7D6C6F7D6C6F7C6ADE7B59CD69C84CE947BC68C73\
C68C73CE947BDEAD94E7B59CE7BDA5EFBDA5E7B59CDEAD94DEA58CDE9C8CDE9C8C
D69C84DEB5A5CE8C6BD69C84FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7CEB5\
E7A58CCE8C6BDEAD94F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6EFCEB5F7D6BD
F7BDB5EFC6ADEFBDA5EFC6ADF7D6C6F7D6BDF7D6C6F7D6C6F7BDB5E7A58CD69C84CE947BCE947B\
C69C84D6A584DEAD94E7B59CEFBDA5E7B59CE7AD94DEAD94DE9C84DE9C84D69C84
D6A584DEB5A5DE9C84D6A58CD6C6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7B594CE8C73\
9C6B52B57B63E7BDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7CEB5EFCEB5EFBDAD
E7BDA5EFBDADEFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6EFCEB5E7AD94D69C84CE947BCE947B\
D69C84D6A58CE7AD9CE7B59CE7B59CE7BDA5E7B59CDEAD94DEAD94D6A58CD69C84
D69C8CDEB5A5CE7352DEB59CD68C73F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DE9473734229\
8C5A4A734A42E7BDA5F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
EFBDADE7AD9CDEAD94EFC6ADEFCEB5F7D6C6F7D6C6F7D6BDEFBDADDEA58CCE8C84CE9473C68C73\
D69C84DEAD94DEA58CDEAD94E7AD9CDEA58CDEAD94D6A58CD6A58CD6A58CD69C84
D69C8CD6A58CC68C63CE9473D68C7BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7AD9CB5735A\
734A39734A42E7BDA5F7D6BDEFCEB5F7D6C6F7D6BDDEB59CDEB59CC6947BC6947B
C69484CE8C84DEA58CDEA58CE7BDA5F7D6C6F7D6C6F7D6C6EFBDADDEA58CCE9473CE8C6BC6947B\
CE947BC69C84C69C84D6A58CDEB59CD6A58CDEAD94DEAD94D6A58CD6A58CD69C84
D69C8CD6A58CA5634AA55239CE8463F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFC6ADE7AD9C421810\
422921523931EFC6ADEFCEB5F7CEB5F7D6BDF7D6BDEFC6ADC69C84AD846B7B635A
634A42845239B57B63AD5A42AD5A42EFC6ADF7D6C6F7D6C6EFC6ADDEA58CCE9473C69C73BD846B\
D6A58CDEAD94DEAD94DEA58CD69C8CC69C84DEAD94DEAD94D6A58CC69C84C69C84
D6A58CD6A58CAD6B52AD5A42CE735AF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7C6ADDE9C84734A42\
4229215A3129EFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6C6DEAD94EFBDAD846352
5231296339297B635AB5735ADEA58CEFCEB5F7DECEF7E7DEEFCEB5DEA58CBD846BBD84637B2918\
C68C73C68C63B5846B9C6B52C6947BC69C84D6A584D6A58CD6A58CC6947BC69C84
D69C8CC6947B945A4AAD6B52D68C7BFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7522118E7A58CE7B59C8C5A4A\
423139422921EFCEB5EFCEB5F7D6BDEFCEB5EFCEB5F7D6C6EFCEB5E7B59CD6A58C
D6A58CBD8463BD8463D6A584E7AD94EFC6ADF7DECEF7DECEEFC6ADDEA58CCE8C6BBD846BAD6B52\
A5847B7B635A211010845242846B5A6342319C7363A57352CE8C6BC69C84C69C84
D69C84AD846B734A39845242DEA58CFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75A31295231294A1008845242422931\
392921523129EFCEB5EFCEB5F7D6C6DE9C8CDEAD94F7D6C6F7DECEF7D6C6EFBDAD
DEA58CDEAD94DEA58CE7B594EFBDA5EFC6ADF7DECEF7DECEEFBDADDEB59CCE9473C69C73CE8C6B\
D6A58CC68C7331212163392973524A5A42399C6B52BD846BD6A584CE947BC69C84
D6A584734A42634231734231CE735AF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75A31296342315A3129523931291818\
5231295A3129EFC6ADF7CEB5EFCEB5F7D6C6DEB59CBD846BC6947BB58C739C7363
8C5A4A94634AA56B52AD6B52DEB59CEFCEB5F7D6C6F7D6BDEFBDA5DEB59CCE947BCE8C6BC69C73\
D6A584D6A58CD6A58CC6947BAD735AAD735ACE947BD69C73C69C84D6A584D6A58C
C69C84634231523129734231BD5A42F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7633929422118392921422921422921\
392921634A42DEB59CF7CEB5F7D6BDF7D6C6F7D6C6EFCEB5D69C8CAD8C84D69C8C
C68C73C6947BBD846BDEA58CEFCEB5F7D6C6F7D6C6F7BDB5EFC6ADDEB59CCE8C849C5A429C5A42\
C69C73D6A584D6A584DEA58CD6A584C69C84D6A584C69C84D69C8CC69C84D6A584
AD846B392921392921C68C73AD5A42F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7734A394A2118422921392921211010\
422921634A42C69C84EFC6ADF7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7D6BDEFCEB5F7DECEEFCEB5EFCEB5EFC6ADE7BDA5E7BDA5D6A58C945A52\
734A39634231B57B63D6A58CD6A584D6A584C69C84CE947BB58C73D69C8CD69C84
734A39422921524239AD6B52A552396B524AF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7634A42523931422921422921312118\
422921634A42C6947BEFC6ADF7D6BDF7D6C6F7DECEF7DECEF7E7DEF7E7DEF7E7DE
F7DECEF7E7DEF7DECEF7DECEF7D6BDF7D6BDF7D6BDEFC6ADEFBDA5EFC6ADEFC6ADEFBDADDEB5A5\
D69C8C9C7363734A396342318C5A4A846B5A9C6B529C6B52D69C8CD69C84CE947B
5231294229214A31315221187B3121735A52F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F773524A73524A392921422921422921\
4A3131634A42AD846BDEB59CF7D6BDF7D6BDF7D6C6F7DECEF7DECEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6BDF7D6BDEFC6ADEFC6ADEFBDA5EFC6ADEFBDADE7BDA5\
DEB59CD6A58CC69C84B58C73A5735AA5735AC68C73C69C84CE8C84C69C84B58C73
523129422921392921312118523129735A52F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7734A396342315239314229214A2118\
523129634231846352D6A58CEFCEB5F7D6BDF7D6C6F7DECEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7DECEF7DECEF7D6BDF7D6C6F7CEB5EFBDA5EFC6ADEFC6ADEFBDA5EFBDA5E7B59C\
E7AD94DEAD94D6A58CDEAD94D6A58CD6A58CD69C84D69C8CD69C84CE947B94634A
523129422921523129392921422921634231C6ADADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76342316B524A523931523129312118\
422921422921734A39A57352EFC6ADF7D6BDF7D6C6F7DECEF7E7DEF7E7DEF7DECE
F7E7DEF7DECEF7DECEF7DECEF7D6BDF7D6BDEFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7B59C\
DEAD94DEAD94DEB59CD6A58CDEA58CD6A58CC69C84C69C84C69C84AD846B5A4239
3121184A3131312121312118211010523129A5847BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7734A39634A42634A42523931523129\
4229215239316B524A846352DEAD94F7CEB5F7D6C6F7D6C6F7DECEF7E7DEF7E7DE
F7E7DEF7DECEF7DECEF7DECEF7D6C6EFCEB5EFC6ADEFBDA5EFBDA5EFBDA5E7BDA5E7B59CE7B59C\
DEAD94DEAD94DEAD94DEAD94D6A58CD6A58CC69C84D69C84C6947B8C6352523129
523931291818312121211010312121422921947B73F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F76B524A6B524A6B524A634A42523129\
312118523129734A399C6B52CE8C6BEFC6ADF7D6BDF7D6C6F7D6C6F7DECEF7E7DE
F7E7DEF7E7DEF7DECEF7DECEF7D6C6F7D6BDEFC6ADE7BDA5E7B59CEFB5A5E7B59CE7AD94E7AD9C\
DEAD94DEAD94DEA58CD6A58CD6A58CCE947BD69C84C68C739C7363734A39523129
312118312121291818312118312121523129F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFEFE7E7634A42634A426B524A634A42422921\
5239315239315A42399C6B52C68C73E7BDA5F7D6BDF7D6C6F7DECEF7DECEF7E7DE
F7E7DEF7E7DEF7DECEF7DECEEFCEB5F7CEB5EFBDA5EFBDA5EFBDA5E7B59CE7B59CE7AD94DEB59C\
DEAD94D69C8CD6A58CD6A58CD6A58CD69C84C69C84B5846BA5735A634231523129
392921392921392921312118392921523129FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F75A4239734A39634A426B524A634A42\
5239315A42396342318C7363A5735ADEA58CEFCEB5F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7D6C6EFCEB5EFC6ADEFCEB5EFBDA5E7B594E7B59CE7B594E7B59CE7B59CDEAD94\
DEAD94DEA58CD6A58CD69C84D69C84C69C84B58C73A5735A734A42523129392921
312118312121291818181010291818734A42F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F773524A6342316B524A6B524A5A4239\
523129634231634A427B6352845242C68C73EFCEB5F7D6BDF7D6BDF7D6C6F7D6BD
F7D6BDF7D6BDF7D6C6F7D6BDEFC6ADEFBDA5E7AD94E7AD94E7AD9CE7B59CE7B59CE7A58CDEAD94\
DEA58CDEA58CD6A58CD69C84CE947BB58C73A5735A734A42634231422921392921
422921312121291818291818523129FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C736B634A42634A4273524A634231\
5A4239523931634A425A42396B524AA5735AD6A584EFCEB5EFCEB5F7D6BDF7D6BD
F7D6BDEFCEB5EFCEB5F7D6BDEFBDA5E7AD94E7B594DEA58CDEAD94DEAD94E7AD94DEA58CDEA58C\
DE9C8CD6A58CD6A584CE947BC6947BAD846B845242634231422921312118312121
422921312121211010291818523129F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C73636B524A6B524A634A42634A42\
4A31315239315A42396B524A634231734A39AD846BD6A58CE7B59CEFC6ADEFC6AD
EFCEB5EFCEB5EFC6ADEFC6ADE7BDA5DEA58CDEA58CDEA58CDE9C84DEA58CDEA58CDEA58CD69C84\
D69C84CE947BC6947BB58C73A5735A9C6B52634231422921392921312118291818
291818181010181010523129633929F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEBDC673524A6B524A634A42735A52\
6342315231296B524A5A42396B524A5239317B6352846352B57B63DEAD94D6A58C
DEB5A5DEB5A5DEB59CE7BDA5D6A58CB5846BBD846BCE8C6BD69C84D69C84D68C73D69C84D69C73\
CE947BC68C73BD846BAD846B8C5A4A734231523129422921312118291818291818
211010181010291818422921EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7846B5A5A4239634A42634A42\
5242394A3131634231634A42735A526B524A634A42735A528C63529C6B5294736B
8C7363A5735AB58C73B58C739C73639C6B5294634AA57352B5735ABD8463CE8C6BBD846BAD735A\
B5735AB57B639C73638C5A4A7342315A3129422921312118291818211010181010
181010181010392921523129F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9CA5634A426B524A63524A\
634A423929215A4239735A52735A527B635A7B635A846B5A846B5A7B635273524A
734A39734A428452428C635273524A73524A8452428452398452429C6B529C6B5294634A9C6B52\
8C5A428C6352845242734A39523129523931312118312118291818211010181010
181010422921312121AD8C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE773524A634A42634A42\
634A42634A426B524A735A527B635A6B524A6B524A734A42845242734A39634A42
523931634A42523129634A42634A425A42395231295239315231295A3129634231634231634231\
5A31295A3129523129523129392921312118291818291818291818181010181010
422931422921634A42F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5A5634A42634A42\
6B524A634A427B635A5A4239735A525A42396B524A8463526B524A634A42634A42
5A423973524A4A3131524239523129523129422921392921422921523129523129422921422921\
422921523129422921422921312118312118291818291818181010181010291818
523931523129F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6734A426B524A\
6B524A634A42524239735A527B635A63524A5A4239734A395239315A42395A4239
4231395242394A3131523129422931392921392921312118392921392921392921312118291818\
312118422921312118291818312118312121291818181010291818392921523931
523129F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B73634A42\
6B524A634A426B524A63524A6B524A5A42395239315239314229215A42394A3131
4A3131422921422931312121291818312121312121291818312121291818312121291818312121\
392921312121291818181010181010181010181010312121312118291818422118
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B73\
5A4239634A4263524A63524A735A52634A4A523129523931392921422921392921
422921291818291818312121312121291818312121291818312121291818523129181010312121\
392921312121181010181010211010312121312121312121523129634231A5735A
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
94736B63524A5A4239735A52735A52735A525242395A4239422931312121422921
3121213929213929213121212918182918182918182918182918183929213121215A52635A5252\
4229312918183121213929213929213121215A42395239315231298C5A4AF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFF94736B735A525A423963524A7B635A735A52634231523931392921312121
2918183121183121212918182918183121212918183121212918182918185A525252394A7B635A\
7B635A634A4A735A525A42393929215239315239316B524A845242F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F78C63527B635A6B524A7B635A7B635A7B635A523931523931634A42
524239422921392921312121312121291818291818392931312121392921312121524239634A42\
3121213929213929213121214229215239316342319C6B52DECED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F78C73635A42396B524A8C736B8C7B737B635A5239314A3131
523129634A425242393121212918184231394231395242394231396B524A3929317B635A634A4A\
634A42634A425A4239634A427B6352634A42A5735AF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7D6C6CE7B635A6B524A735A527B737B8C736B8C736B
8C7B73634A4A5A52527B6B7B8C7B73634A4A5A4A5A634A4A7B6B7B6B524A634A42735A5273524A\
734A42734A396B524A846352A5735A734A39F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C737B7B635A6B636B9C8C8C948484
8C7B738C7B73948484947B738C736B735A527B635A634A4A5A4239634A42735A526B524A845242\
8C5A4A8C63529C7363845242A58484F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE78C7B8CAD9494
C6B5C6B59C9CA5847B947B73947B73A58484A5847B947B73A5847B8C7363947B73A5847B8C7363\
8C736373524ACEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7E7DEEFF7EFEFD6C6D69C8C9C9C8C9C947B73947B73947B73947B738C736B846352846B5A\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[63]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`003P3ooomM0?Ogm`@0klje103ge[d40?OFaP@0mmk>
103ge/H@0?ONcP@0mmK6103ge[d40>o>]@@0klJ]203W]I`D0=j]U0@0gZF<103FYH@40=JUS0@0eZF4
1@3FYH`D0?Ogm`@0mno_:03gmoL@0?ooo`003P3ooomM0?Ogm`@0klje103ge[d40?OFaP@0mmk>103g
e/H@0?ONcP@0mmK6103ge[d40>o>]@@0klJ]203W]I`D0=j]U0@0gZF<103FYH@40=JUS0@0eZF41@3F
YH`D0?Ogm`@0mno_:03gmoL@0?ooo`003P3ooomM0?Ogm`@0klje103ge[d40?OFaP@0mmk>103ge/H@
0?ONcP@0mmK6103ge[d40>o>]@@0klJ]203W]I`D0=j]U0@0gZF<103FYH@40=JUS0@0eZF41@3FYH`D
0?Ogm`@0mno_:03gmoL@0?ooo`003P3ooomM0?Ogm`@0klje103ge[d40?OFaP@0mmk>103ge/H@0?ON
cP@0mmK6103ge[d40>o>]@@0klJ]203W]I`D0=j]U0@0gZF<103FYH@40=JUS0@0eZF41@3FYH`D0?Og
m`@0mno_:03gmoL@0?ooo`003P3oool40?Ogm`@0mno_203gmoL40?O_kbP0moOg1@3gknlL0?Ogm`@0
mmJm103ge/H40?OF_@@0mmk>103ge/H80?ONcP@0mmJm203_c[D40>o6[@@0ikfU103N]I`80=j]U0@0
eZF<303N[I@80=jUS0P0eZF<103FYH@50=K6_D00moOg403oool000h0oooo103gmoL40?O_k`P0moOg
103gknlX0?Ogm`D0mno_703gmoL40?OF_@@0mmK6103ge[d40?ONcP@0mmK6203gg/h40?OF_@P0klje
103_aZd40>NmY@@0g[FL203N[I@40=JUS0`0gZfD203NYH`80=JUS0@0eZF41@3Fa[e00?Ogma00oooo
000>0?ooo`@0moOg103gknl80?Ogm`@0mno_:03gmoL50?O_ka`0moOg103ge[d40?OFaP@0mmJm103g
g/h40?OFaPP0mmk>103ge[d80>o>]@@0klJ]103W_JD40=jeW0P0gZfD103FYH`<0=j]U0P0gZF<203F
YH`40=JUQ0D0e/Jm@03gmoL@0?ooo`003P3oool40?Ogm`@0mno_203gmoL40?O_kbP0moOg1@3gknlL
0?Ogm`@0mmJm103ge/H40?OF_@@0mmk>103ge/H80?ONcP@0mmJm203_c[D40>o6[@@0ikfU103N]I`8
0=j]U0@0eZF<303N[I@80=jUS0P0eZF<103FYH@50=K6_D00moOg403oool000h0oooo203gmoL40?O_
ka00moOg103gknl40?Ogm`@0mno_=@3gmoL40>o>]@@0mmJm203ge/H40?ONcPP0mmK6103_c[D40=K6
]@@0ikfU103W[I`40=j]U0`0g[FL103N[I@@0=JUS0@0eZF4303FYH`M0?Ogm`@0mno_903gmoL@0?oo
o`003P3oool80?Ogm`@0mno_403gmoL40?O_k`@0moOg103gknle0?Ogm`@0klje103ge[d80?OFaP@0
mmk>203ge/H40>o>]@@0e/Je103W_JD40>N]W0@0gZfD303N]I`40=j]U100eZF<103FYH@<0=JUS1d0
moOg103gknlT0?Ogma00oooo000>0?ooo`P0moOg103gknl@0?Ogm`@0mno_103gmoL40?O_kcD0moOg
103_c[D40?OF_@P0mmK6103gg/h80?OFaP@0klje103Fa[D40>NmY@@0ijfL103N[I@<0=jeW0@0gZfD
403FYH`40=JUQ0`0eZF<7@3gmoL40?O_kb@0moOg403oool000h0oooo203gmoL40?O_ka00moOg103g
knl40?Ogm`@0mno_=@3gmoL40>o>]@@0mmJm203ge/H40?ONcPP0mmK6103_c[D40=K6]@@0ikfU103W
[I`40=j]U0`0g[FL103N[I@@0=JUS0@0eZF4303FYH`M0?Ogm`@0mno_903gmoL@0?ooo`003P3oool8
0?Ogm`@0mno_D@3gmoL40?O>]A@0mmK6103ge[d80?OFaP@0klje103g_KD40>NeW0@0ijfD203W[I`4
0=jLS1@0eZF<103N[I@80=JUS4D0moOg403oool000h0oooo203gmoL40?O_ke40moOg103gc[DD0?OF
aP@0mmJm203ge/H40>o>]@@0mkfe103W]I`40>N]U0P0ijfL103NW8`D0=JUS0@0gZfD203FYHa50?Og
ma00oooo000>0?ooo`P0moOg103gknmA0?Ogm`@0mlje503ge/H40?OF_@P0mmK6103_c[D40?Nm]@@0
ikFL103W[I@80>N]W0@0gYb<503FYH`40=j]U0P0eZF<A@3gmoL@0?ooo`003P3oool80?Ogm`@0mno_
D@3gmoL40?O>]A@0mmK6103ge[d80?OFaP@0klje103g_KD40>NeW0@0ijfD203W[I`40=jLS1@0eZF<
103N[I@80=JUS4D0moOg403oool000h0ooooG@3gmoL<0?OF_A00mmK6203gg/h40?OFaP@0klje103_
_Jd80>nmY@@0ijfL103__JD80=jLS0@0g[FU103FYH`80=jUS0@0eZF<103N]Ia50?Ogma00oooo000>
0?oooed0moOg303ge[d@0?OFaPP0mmk>103ge/H40>o>]@@0kkf]203__JD40>N]W0@0kkfU203NW8`4
0=jeY@@0eZF<203NYH`40=JUS0@0g[FLA@3gmoL@0?ooo`003P3ooomM0?Ogm``0mmJm403ge/H80?ON
cP@0mmK6103_c[D40>nm[@P0kkfU103W[I`40>nmY@P0gYb<103N]JD40=JUS0P0gZF<103FYH`40=je
W4D0moOg403oool000h0ooooG@3gmoL<0?OF_A00mmK6203gg/h40?OFaP@0klje103__Jd80>nmY@@0
ijfL103__JD80=jLS0@0g[FU103FYH`80=jUS0@0eZF<103N]Ia50?Ogma00oooo000>0?oooed0moOg
203ge[d40?OFaP@0mmJm203ge/H40?ONcPP0mmK6103gg/h40?OFaP@0mmJm103_aZd40>nm[@@0kkfU
103W]I`40>N]W0@0gZfD103NYH`40=jeY@`0eZF<103_e/hQ0?Ogm`@0mno_803gmoL@0?ooo`003P3o
oomM0?Ogm`P0mmJm103ge/H40?OF_@P0mmK6103gg/h80?OFaP@0mmk>103ge/H40?OF_@@0klJ]103_
_Jd40>nmY@@0ikFL103W[I`40=j]U0@0gZF<103N]JD<0=JUS0@0kmK>8@3gmoL40?O_kb00moOg403o
ool000h0ooooG@3gmoL80?OF_@@0mmK6103ge[d80?OFaP@0mmk>203ge/H40?ONcP@0mmK6103ge[d4
0>o6[@@0kkf]103__JD40>NeW0@0ijfL103N[I@40=jUS0@0g[FU303FYH`40>oFcR40moOg103gknlP
0?Ogma00oooo000>0?oooed0moOg203ge[d40?OFaP@0mmJm203ge/H40?ONcPP0mmK6103gg/h40?OF
aP@0mmJm103_aZd40>nm[@@0kkfU103W]I`40>N]W0@0gZfD103NYH`40=jeY@`0eZF<103_e/hQ0?Og
m`@0mno_803gmoL@0?ooo`003P3ooomI0?Ogm`@0g[FU103ge[d40?OFaPP0mmJm103ge/H40?ONcP@0
mmK6303gg/h80?OFaP@0mlje103gaZd80>nmY@@0ijfL103W[I@40=jUS0P0eZF<103NYH`40=JUS0@0
knOW<@3gmoL80?O_k``0moOg403oool000h0ooooF@3gmoL40=jeY@@0mmJm103ge/H80?OF_@@0mmK6
103gg/h40?OFaP`0mmk>203ge/H40?O>]@@0mlJ]203__JD40>N]W0@0ijfD103NYH`80=JUS0@0gZF<
103FYH`40>oWic40moOg203gknl<0?Ogma00oooo000>0?oooeT0moOg103N]JD40?OF_@@0mmK6203g
e[d40?OFaP@0mmk>103ge/H<0?ONcPP0mmK6103gc[D40?O6[@P0kkfU103W[I`40>N]U0@0gZF<203F
YH`40=jUS0@0eZF<103_inLa0?Ogm`P0mno_303gmoL@0?ooo`003P3ooomI0?Ogm`@0g[FU103ge[d4
0?OFaPP0mmJm103ge/H40?ONcP@0mmK6303gg/h80?OFaP@0mlje103gaZd80>nmY@@0ijfL103W[I@4
0=jUS0P0eZF<103NYH`40=JUS0@0knOW<@3gmoL80?O_k``0moOg403oool000h0ooooE@3gmoL408ac
H`@0klje103ge[d@0?OFaP@0mmk>103ge/H40?OF_@@0mmk>203ge/H80?OF_@@0kkf]103__JD40>ne
Y@@0ikFD103NYH`40=j]U0@0gZF<103FYH`40=jeW0@0gZfDB@3gmoL@0?ooo`003P3ooomE0?Ogm`@0
S7=S103_c[D40?OF_A00mmK6103gg/h40?OFaP@0mmJm103gg/h80?OFaPP0mmJm103__Jd40>nmY@@0
kkFU103W]I@40=jUS0@0gZfD103NYH`40=JUS0@0g[FL103N[IA90?Ogma00oooo000>0?oooeD0moOg
102<Lf<40>o>]@@0mmJm403ge/H40?ONcP@0mmK6103ge[d40?ONcPP0mmK6203ge[d40>nm[@@0kkfU
103_]JD40>NeU0@0gZF<103N[I@40=jUS0@0eZF<103N]I`40=j]U4T0moOg403oool000h0ooooE@3g
moL408acH`@0klje103ge[d@0?OFaP@0mmk>103ge/H40?OF_@@0mmk>203ge/H80?OF_@@0kkf]103_
_JD40>neY@@0ikFD103NYH`40=j]U0@0gZF<103FYH`40=jeW0@0gZfDB@3gmoL@0?ooo`003P3oool8
0?Ogm`@0mno_A@3gmoL40=K6cP@0FS4Y103ge/H40?OF_@@0mmk>103ge/H40?ONcPP0mmK6203gg/h4
0?OFaP@0mmJm103g_KD40>nmY@@0ikFL203__JD40>NmY@@0gZfD103W[I@40=j]U0@0eZF4303FYHa9
0?Ogma00oooo000>0?ooo`P0moOg103gknm50?Ogm`@0e/K>101J<BT40?OFaP@0mmJm103gg/h40?OF
aP@0mmk>203ge/H80?ONcP@0mmK6103ge[d40?Nm]@@0kkfU103W]I`80>nmY@@0ikfU103N[I@40>N]
U0@0gZfD103FYH@<0=JUS4T0moOg403oool000h0oooo203gmoL40?O_kdD0moOg103Fa/h405Xa:@@0
mmK6103ge[d40?ONcP@0mmK6103gg/h80?OFaPP0mmk>103ge/H40?OF_@@0mkfe103__JD40>NeW0P0
kkfU103W_JD40=j]U0@0ijfD103N[I@40=JUQ0`0eZF<B@3gmoL@0?ooo`003P3oool80?Ogm`@0mno_
A@3gmoL40=K6cP@0FS4Y103ge/H40?OF_@@0mmk>103ge/H40?ONcPP0mmK6203gg/h40?OFaP@0mmJm
103g_KD40>nmY@@0ikFL203__JD40>NmY@@0gZfD103W[I@40=j]U0@0eZF4303FYHa90?Ogma00oooo
000>0?ooo``0moOg103gknlm0?Ogm`@0oooo101S@S440>o>]@@0mmJm703ge/H40?ONcP@0mmK6103_
c[D40>nm[@@0kkfU303W]I`40>NeU0@0gZfD403NYH`40=JUS0@0gZfD103_e/i50?Ogma00oooo000>
0?ooo``0moOg103gknlm0?Ogm`@0oooo101S@S440>o>]@@0mmJm703ge/H40?ONcP@0mmK6103_c[D4
0>nm[@@0kkfU303W]I`40>NeU0@0gZfD403NYH`40=JUS0@0gZfD103_e/i50?Ogma00oooo000>0?oo
o``0moOg103gknlm0?Ogm`@0oooo101S@S440>o>]@@0mmJm703ge/H40?ONcP@0mmK6103_c[D40>nm
[@@0kkfU303W]I`40>NeU0@0gZfD403NYH`40=JUS0@0gZfD103_e/i50?Ogma00oooo000>0?ooo``0
moOg103gknlm0?Ogm`@0oooo101S@S440>o>]@@0mmJm703ge/H40?ONcP@0mmK6103_c[D40>nm[@@0
kkfU303W]I`40>NeU0@0gZfD403NYH`40=JUS0@0gZfD103_e/i50?Ogma00oooo000>0?ooo`P0moOg
103gknm10?Ogm`@0Hd8a103gg/h40?OFaP@0mmJm303ge/H40?OF_@P0mmK6103gg/h80?OFaPP0kiB<
303WQ7/40>N]U0P0gZF<103NW8@40=JUQ0P0gZF<103FYH@40=jLQ0@0eZF<<@3gmoL40?O_ka00moOg
403oool000h0oooo203gmoL40?O_kd40moOg101S@S440?ONcP@0mmK6103ge[d<0?OFaP@0mmJm203g
e/H40?ONcPP0mmK6203_U8`<0>N4N`@0ijfD203NYH`40=jLQ0@0eZF4203NYH`40=JUQ0@0gYb4103F
YH`a0?Ogm`@0mno_403gmoL@0?ooo`003P3oool80?Ogm`@0mno_@@3gmoL406=2<@@0mmk>103ge/H4
0?OF_@`0mmK6103ge[d80?OFaP@0mmk>203ge/H80>nDS0`0ihAk103W[I@80=jUS0@0gYb4103FYH@8
0=jUS0@0eZF4103NW8@40=JUS340moOg103gknl@0?Ogma00oooo000>0?ooo`P0moOg103gknm10?Og
m`@0Hd8a103gg/h40?OFaP@0mmJm303ge/H40?OF_@P0mmK6103gg/h80?OFaPP0kiB<303WQ7/40>N]
U0P0gZF<103NW8@40=JUQ0P0gZF<103FYH@40=jLQ0@0eZF<<@3gmoL40?O_ka00moOg403oool000h0
ooooB@3gmoL40=K6aP@0kmK>203ge/H40?OF_@P0mmK6303gc[D80?OFaPP0mkfe103_U8`40>N4L`@0
gV]J103WQ7/40=ikJ`@0ihAk103FS7/40=JLQ0@0eZF4103FW8@<0=jUS0@0gYb42@3N[IA00?Ogma00
oooo000>0?ooodT0moOg103Fa/H40>oFcPP0mmK6103ge[d80?OFaP`0mlje203ge/H80?Nm]@@0kiB<
103WQ7<40=i[FP@0ihAk103NNf/40>N4N`@0eXak103FW8@40=JUQ0@0eYb4303NYH`40=jLQ0T0gZfD
@03gmoL@0?ooo`003P3ooom90?Ogm`@0e/K6103_e/h80?OFaP@0mmJm203ge/H<0?O>]@P0mmK6203g
_KD40>nDS0@0ihAc103NJeX40>N4N`@0gW][103WQ7/40=J<N`@0eYb4103FYH@40=JLQ0`0gZF<103N
W8@90=j]U400moOg403oool000h0ooooB@3gmoL40=K6aP@0kmK>203ge/H40?OF_@P0mmK6303gc[D8
0?OFaPP0mkfe103_U8`40>N4L`@0gV]J103WQ7/40=ikJ`@0ihAk103FS7/40=JLQ0@0eZF4103FW8@<
0=jUS0@0gYb42@3N[IA00?Ogma00oooo000>0?ooodT0moOg101J@ST40>o>]@`0mmJm103ge/H40?OF
_@@0klJ]103__JD40?OF_@@0mmK6103gaZd40>nDS0@0ihAc103NW8`40<I[DP@0g[FL103W[I`80=IS
DP@0gW][103FS7/40=JUS0@0eYac103FYH@@0=jUS0D0gZfD103gimhl0?Ogma00oooo000>0?ooodT0
moOg101J@ST40>o>]@`0mmJm103ge/H40?OF_@@0klJ]103__JD40?OF_@@0mmK6103gaZd40>nDS0@0
ihAc103NW8`40<I[DP@0g[FL103W[I`80=ISDP@0gW][103FS7/40=JUS0@0eYac103FYH@@0=jUS0D0
gZfD103gimhl0?Ogma00oooo000>0?ooodT0moOg101J@ST40>o>]@`0mmJm103ge/H40?OF_@@0klJ]
103__JD40?OF_@@0mmK6103gaZd40>nDS0@0ihAc103NW8`40<I[DP@0g[FL103W[I`80=ISDP@0gW][
103FS7/40=JUS0@0eYac103FYH@@0=jUS0D0gZfD103gimhl0?Ogma00oooo000>0?ooodT0moOg101J
@ST40>o>]@`0mmJm103ge/H40?OF_@@0klJ]103__JD40?OF_@@0mmK6103gaZd40>nDS0@0ihAc103N
W8`40<I[DP@0g[FL103W[I`80=ISDP@0gW][103FS7/40=JUS0@0eYac103FYH@@0=jUS0D0gZfD103g
imhl0?Ogma00oooo000>0?oooa00moOg103gknla0?Ogm`@0]IbL1036W8@40?OF_@@0mmK6103_aZd4
0?ONcP@0mmK6103gaZd40>NeU0@0gYb4103g_KD40>N4N`@0Q2TH103W[I`40>NDQ0@0kkFU103gimh4
0>MkJ`@0cXac102mQ6<40<JDQ0@0YF=:103FHe840<jDN`@0eYac103NW8@40=j]U0@0ikFD103NYH`4
0=j]U0D0gZF<103N[I@40?OWgSP0moOg403oool000h0oooo403gmoL40?O_kc40moOg102eW9`40<JL
Q0@0mmJm103ge/H40>o6[@@0mmk>103ge/H40?O6[@@0ikFD103NW8@40?Nm]@@0ihAk1024:AP40>N]
W0@0iiB4103_]JD40?OWgP@0ig][103>S7<40;f4H`@0aYB4102UHdX40=ISDP@0cYAk103FW7<40=jL
Q0@0gZfD103W]I@40=jUS0@0gZfD1@3NYH`40=j]U0@0mnON>03gmoL@0?ooo`003P3oool@0?Ogm`@0
mno_<@3gmoL40;FLW0@0aYb4103ge[d40?OFaP@0klJ]103gg/h40?OFaP@0mlJ]103W]I@40=jLQ0@0
mkfe103WQ7/408@Y60@0ijfL103WU8@40>neY@@0mnON103WNf/40<j<L`@0_HAS1036U8@40:ESBP@0
eV=B103>U7/40=JLL`@0gYb4103N[I@40>NeU0@0gZF<103N[I@50=jUS0@0gZfD103gimhh0?Ogma00
oooo000>0?oooa00moOg103gknla0?Ogm`@0]IbL1036W8@40?OF_@@0mmK6103_aZd40?ONcP@0mmK6
103gaZd40>NeU0@0gYb4103g_KD40>N4N`@0Q2TH103W[I`40>NDQ0@0kkFU103gimh40>MkJ`@0cXac
102mQ6<40<JDQ0@0YF=:103FHe840<jDN`@0eYac103NW8@40=j]U0@0ikFD103NYH`40=j]U0D0gZF<
103N[I@40?OWgSP0moOg403oool000h0oooo203gmoL40?O_kcT0moOg101SBT840>o>]@@0mmK6103g
e[d40>nmY@P0mmK6103gaZd40=jDL`@0eXac102<:B440=K6_@P0mnON103gknl40?OWi`@0mnON103_
c[D40?OWgP@0kmK>1036[JD409AJBP@0Ld8Y1036Je840=JUQ0@0gYb4203W]I`40>NeU0T0gZF<103N
[I@40=kFi`@0knOW=03gmoL@0?ooo`003P3oool80?Ogm`@0mno_>@3gmoL406=:@P@0klje103ge/H4
0?OF_@@0kkfU203ge/H40?O6[@@0gYAc103FS7<408`Y8@@0e/Jm203gimh40?O_k`@0mnOW103gimh4
0>o>]@@0mnON103_e/h40<J]Y@@0U5Y:101c@RT40<I[DP@0eZF4103NW8@80>NeW0@0ikFD2@3NYH`4
0=j]U0@0g]KW103_inLd0?Ogma00oooo000>0?ooo`P0moOg103gknli0?Ogm`@0HdY2103_c[D40?OF
aP@0mmJm103__JD80?OFaP@0mlJ]103NU7<40=J<L`@0S2TQ103Fa[d80?OWgP@0mno_103ginL40?OW
gP@0klje103gimh40>oFcP@0aZfU102DFTX407=2:@@0aV]B103FYH@40=jLQ0P0ikFL103W]I@90=jU
S0@0gZfD103Ne^L40>oWic@0moOg403oool000h0oooo203gmoL40?O_kcT0moOg101SBT840>o>]@@0
mmK6103ge[d40>nmY@P0mmK6103gaZd40=jDL`@0eXac102<:B440=K6_@P0mnON103gknl40?OWi`@0
mnON103_c[D40?OWgP@0kmK>1036[JD409AJBP@0Ld8Y1036Je840=JUQ0@0gYb4203W]I`40>NeU0T0
gZF<103N[I@40=kFi`@0knOW=03gmoL@0?ooo`003P3ooom10?Ogm`@0g]KW101B<BT40>o>]@`0mmJm
203ge/H40>NUS0@0aXaS102mFT8408@Y60@0iiB4103__JD40>neY@@0mnON203ge[d40>N]W0@0kmK>
103W[I@40?OFaP@0eZF<102mW8`407=2<@@0aV]B103FW8@40>NeU0@0klJ]103W]I`40=j]U0D0gYb4
103NYH`40=K6]@@0c[fe103Ne^L`0?Ogma00oooo000>0?oood40moOg103Ne^L4058a:@@0klje303g
e[d80?OFaP@0ijF<1036S6<40;eJ@P@0Q2TH103WU8@40>nmY@@0kkFU103gimh80?OF_@@0ijfL103_
e/h40>N]U0@0mmK6103FYH`40;fLS0@0Ld8a1036Je840=JLQ0@0ikFD103_aZd40>NeW0@0gZfD1@3N
W8@40=jUS0@0e/Je103>_KD40=kFic00moOg403oool000h0oooo@@3gmoL40=kFi`@0DS4Y103_c[D<
0?OF_@P0mmK6103WYH`40<J<H`@0_EY21024:AP40>NDQ0@0kkfU103_]JD40?OWgPP0mmJm103W[I`4
0>oFcP@0ijfD103ge/H40=JUS0@0_Ib<101c@S440<I[DP@0eYb4103W]I@40>o6[@@0ikFL103N[I@5
0=jLQ0@0gZF<103Fa[D40<jm]@@0g]KW<03gmoL@0?ooo`003P3ooom10?Ogm`@0g]KW101B<BT40>o>
]@`0mmJm203ge/H40>NUS0@0aXaS102mFT8408@Y60@0iiB4103__JD40>neY@@0mnON203ge[d40>N]
W0@0kmK>103W[I@40?OFaP@0eZF<102mW8`407=2<@@0aV]B103FW8@40>NeU0@0klJ]103W]I`40=j]
U0D0gYb4103NYH`40=K6]@@0c[fe103Ne^L`0?Ogma00oooo000>0?oood40moOg103Ne^L4058a:@@0
klje303ge[d80?OFaP@0ijF<1036S6<40;eJ@P@0Q2TH103WU8@40>nmY@@0kkFU103gimh80?OF_@@0
ijfL103_e/h40>N]U0@0mmK6103FYH`40;fLS0@0Ld8a1036Je840=JLQ0@0ikFD103_aZd40>NeW0@0
gZfD1@3NW8@40=jUS0@0e/Je103>_KD40=kFic00moOg403oool000h0oooo?03gmoL508acH`@0DS4Y
1036U8@80?OF_@P0mlJ]203ge[d40>NUS0@0ikFL103_c[D40?OF_@@0mkfe103_]JD80>N]W0@0kiB<
103NW8`40=ikJ`@0gV]J103FLf<40=jeW0@0eXac103>S8@40:ekJ`@0Lb4@103FS7/40>NeU0@0klJ]
103W]I@40=jUS0D0eZF<103N[I@40=jeW0@0mno_103Fa]H`0?Ogma00oooo000>0?oooc`0moOg1@2<
Lf<4058a:@@0aYB4203ge[d80?O6[@P0mmJm103WYH`40>NeW0@0klje103ge[d40?Nm]@@0kkFU203W
[I`40>nDS0@0gYb<103NNf/40=i[FP@0eW=S103N]I`40=J<L`@0cXb4102]Nf/407<Q40@0eXak103W
]I@40>o6[@@0ikFD103NYH`50=JUS0@0gZfD103N]I`40?O_k`@0e/KF<03gmoL@0?ooo`003P3oooll
0?Ogm`D0S7=S101B<BT40<JDQ0P0mmJm203gaZd80?OF_@@0ijF<103W]I`40>o>]@@0mmJm103g_KD4
0>neY@P0ijfL103_U8`40=jLS0@0gW][103NJeX40=IcH`@0g[FL103FS7<40<j<Q0@0[G][101c8A04
0=J<N`@0ikFD103_aZd40>NeU0@0gZF<1@3FYH`40=j]U0@0g[FL103gknl40=K6eS00moOg403oool0
00h0oooo?03gmoL508acH`@0DS4Y1036U8@80?OF_@P0mlJ]203ge[d40>NUS0@0ikFL103_c[D40?OF
_@@0mkfe103_]JD80>N]W0@0kiB<103NW8`40=ikJ`@0gV]J103FLf<40=jeW0@0eXac103>S8@40:ek
J`@0Lb4@103FS7/40>NeU0@0klJ]103W]I@40=jUS0D0eZF<103N[I@40=jeW0@0mno_103Fa]H`0?Og
ma00oooo000>0?oooa@0moOg103gknlP0?Ogm`@0g/kF1@0a8AP4048Y8@@0mmK6103ge[d40?O>]@@0
mkfe103_c[D40?OF_@@0mkfe103W[I@40<j<J`@0mmK6103gg/h80?OFaP@0mmk>103ge/H40?OF_@P0
kkfU103W]I@40>N]U0@0gYb4103WQ7/40=IcH`@0_EY2102L>BT40:E2<@@0gZF<103__JD40>NeU0@0
gZF<1@3FW8@40=jUS0@0gZfD101cBST40?O_k`@0knOW;03gmoL@0?ooo`003P3ooolD0?Ogm`@0mno_
803gmoL40=k>ePD0<B4H1012:B440?OFaP@0mmJm103gc[D40?Nm]@@0klje103ge[d40?Nm]@@0ijfD
103>S6/40?OFaP@0mmk>203ge/H40?ONcP@0mmK6103ge[d80>nmY@@0ikFD103W[I@40=jLQ0@0ihAk
103FLf<40;eJ@P@0W3TY102U@S440=jUS0@0kkfU103W]I@40=jUS0D0eYb4103NYH`40=j]U0@0LdXi
103gknl40>oWib`0moOg403oool000h0oooo503gmoL40?O_kb00moOg103Nc]H5034Q60@0@RTQ103g
e/H40?OF_@@0mlje103g_KD40>o>]@@0mmJm103g_KD40>N]U0@0cXa[103ge/H40?ONcPP0mmK6103g
g/h40?OFaP@0mmJm203__JD40>NeU0@0ijfD103NW8@40>N4N`@0eW=S102mFT8409`i:@@0YD8a103N
YH`40>nmY@@0ikFD103NYH`50=JLQ0@0gZF<103N[I@407=:>@@0mno_103_inL/0?Ogma00oooo000>
0?oooa@0moOg103gknlP0?Ogm`@0g/kF1@0a8AP4048Y8@@0mmK6103ge[d40?O>]@@0mkfe103_c[D4
0?OF_@@0mkfe103W[I@40<j<J`@0mmK6103gg/h80?OFaP@0mmk>103ge/H40?OF_@P0kkfU103W]I@4
0>N]U0@0gYb4103WQ7/40=IcH`@0_EY2102L>BT40:E2<@@0gZF<103__JD40>NeU0@0gZF<1@3FW8@4
0=jUS0@0gZfD101cBST40?O_k`@0knOW;03gmoL@0?ooo`003P3ooolh0?Ogm`@0g]KW1@3ge[d40>nm
Y@@0klje103ge[d40?O>]@@0mmJm103g_KD80?OF_@@0ikFL103NW8@40>o6[@@0mmK6103gg/h80?OF
aP@0mmk>103g_KD80>nmY@@0ikFL103W[I@40=JUQ0@0eYb4103FYH@80=JLQ0@0cXb4103FW7<40>Ne
W0@0ikFD103NYH`50=JUQ0@0gZF<103N[I@407]SFP@0e/Jm<03gmoL@0?ooo`003P3ooolh0?Ogm`@0
g]KW1@3ge[d40>nmY@@0klje103ge[d40?O>]@@0mmJm103g_KD80?OF_@@0ikFL103NW8@40>o6[@@0
mmK6103gg/h80?OFaP@0mmk>103g_KD80>nmY@@0ikFL103W[I@40=JUQ0@0eYb4103FYH@80=JLQ0@0
cXb4103FW7<40>NeW0@0ikFD103NYH`50=JUQ0@0gZF<103N[I@407]SFP@0e/Jm<03gmoL@0?ooo`00
3P3ooolh0?Ogm`@0g]KW1@3ge[d40>nmY@@0klje103ge[d40?O>]@@0mmJm103g_KD80?OF_@@0ikFL
103NW8@40>o6[@@0mmK6103gg/h80?OFaP@0mmk>103g_KD80>nmY@@0ikFL103W[I@40=JUQ0@0eYb4
103FYH@80=JLQ0@0cXb4103FW7<40>NeW0@0ikFD103NYH`50=JUQ0@0gZF<103N[I@407]SFP@0e/Jm
<03gmoL@0?ooo`003P3ooolh0?Ogm`@0g]KW1@3ge[d40>nmY@@0klje103ge[d40?O>]@@0mmJm103g
_KD80?OF_@@0ikFL103NW8@40>o6[@@0mmK6103gg/h80?OFaP@0mmk>103g_KD80>nmY@@0ikFL103W
[I@40=JUQ0@0eYb4103FYH@80=JLQ0@0cXb4103FW7<40>NeW0@0ikFD103NYH`50=JUQ0@0gZF<103N
[I@407]SFP@0e/Jm<03gmoL@0?ooo`003P3ooolh0?Ogm`@0mmJm1@3ge/H40?ONcPP0klje103ge[d8
0?OFaP@0mmk>103ge/H40>o6[@@0ijfD103NW8@40>o>]@P0mmk>103ge/H40?ONcP@0mmJm103__JD4
0>NUS0@0ikFD103FYH@40<JLQ0@0cYAc103>S7<40<jDL`@0cXac103>U7<40=j]U0@0ikFL103W[I@9
0=JLQ0@0eZF4103FYH`4058i<@@0imk_<03gmoL@0?ooo`003P3ooolh0?Ogm`@0mmJm1@3ge/H40?ON
cPP0klje103ge[d80?OFaP@0mmk>103ge/H40>o6[@@0ijfD103NW8@40>o>]@P0mmk>103ge/H40?ON
cP@0mmJm103__JD40>NUS0@0ikFD103FYH@40<JLQ0@0cYAc103>S7<40<jDL`@0cXac103>U7<40=j]
U0@0ikFL103W[I@90=JLQ0@0eZF4103FYH`4058i<@@0imk_<03gmoL@0?ooo`003P3ooolh0?Ogm`@0
mmJm1@3ge/H40?ONcPP0klje103ge[d80?OFaP@0mmk>103ge/H40>o6[@@0ijfD103NW8@40>o>]@P0
mmk>103ge/H40?ONcP@0mmJm103__JD40>NUS0@0ikFD103FYH@40<JLQ0@0cYAc103>S7<40<jDL`@0
cXac103>U7<40=j]U0@0ikFL103W[I@90=JLQ0@0eZF4103FYH`4058i<@@0imk_<03gmoL@0?ooo`00
3P3ooolh0?Ogm`@0mmJm1@3ge/H40?ONcPP0klje103ge[d80?OFaP@0mmk>103ge/H40>o6[@@0ijfD
103NW8@40>o>]@P0mmk>103ge/H40?ONcP@0mmJm103__JD40>NUS0@0ikFD103FYH@40<JLQ0@0cYAc
103>S7<40<jDL`@0cXac103>U7<40=j]U0@0ikFL103W[I@90=JLQ0@0eZF4103FYH`4058i<@@0imk_
<03gmoL@0?ooo`003P3ooold0?Ogm`@0knOW103ge[d50>o6[@@0ikFD103Fa/H40?O>]@@0mmK6403g
g/h40?Nm]@@0kkfU103WYH`40>nmY@@0mmK6103gg/h40?Nm]@@0klje103ge[d40>NeW0@0ijfD103F
S7<40=JUS0@0cXac103>U7<40<jDN`@0eYac103>U7<40<j<J`P0ijfD103NYH`90=JLQ0@0eZF<103N
[I@4034Q8@@0c[fe<03gmoL@0?ooo`003P3ooold0?Ogm`@0knOW103ge[d50>o6[@@0ikFD103Fa/H4
0?O>]@@0mmK6403gg/h40?Nm]@@0kkfU103WYH`40>nmY@@0mmK6103gg/h40?Nm]@@0klje103ge[d4
0>NeW0@0ijfD103FS7<40=JUS0@0cXac103>U7<40<jDN`@0eYac103>U7<40<j<J`P0ijfD103NYH`9
0=JLQ0@0eZF<103N[I@4034Q8@@0c[fe<03gmoL@0?ooo`003P3ooold0?Ogm`@0knOW103ge[d50>o6
[@@0ikFD103Fa/H40?O>]@@0mmK6403gg/h40?Nm]@@0kkfU103WYH`40>nmY@@0mmK6103gg/h40?Nm
]@@0klje103ge[d40>NeW0@0ijfD103FS7<40=JUS0@0cXac103>U7<40<jDN`@0eYac103>U7<40<j<
J`P0ijfD103NYH`90=JLQ0@0eZF<103N[I@4034Q8@@0c[fe<03gmoL@0?ooo`003P3ooold0?Ogm`@0
knOW103ge[d50>o6[@@0ikFD103Fa/H40?O>]@@0mmK6403gg/h40?Nm]@@0kkfU103WYH`40>nmY@@0
mmK6103gg/h40?Nm]@@0klje103ge[d40>NeW0@0ijfD103FS7<40=JUS0@0cXac103>U7<40<jDN`@0
eYac103>U7<40<j<J`P0ijfD103NYH`90=JLQ0@0eZF<103N[I@4034Q8@@0c[fe<03gmoL@0?ooo`00
3P3ooold0?Ogm`@0mmJm103ge/H50>NeW0@0gZfD103_c[D40?Nm]@@0mmK6403gg/h40?OF_@@0mlJ]
103W]I@40>NUS0@0mmK6103gg/h<0?OFaP@0kkf]103W]I`80=jUS0P0cXac103>U7/40=JLQ0@0gYb4
103W[I@40>NeW0`0gZF<1@3FW8@40=JUQ0@0eZF<1012:B4406=:@P@0mno_;03gmoL@0?ooo`003P3o
oold0?Ogm`@0mmJm103ge/H50>NeW0@0gZfD103_c[D40?Nm]@@0mmK6403gg/h40?OF_@@0mlJ]103W
]I@40>NUS0@0mmK6103gg/h<0?OFaP@0kkf]103W]I`80=jUS0P0cXac103>U7/40=JLQ0@0gYb4103W
[I@40>NeW0`0gZF<1@3FW8@40=JUQ0@0eZF<1012:B4406=:@P@0mno_;03gmoL@0?ooo`003P3ooold
0?Ogm`@0mmJm103ge/H50>NeW0@0gZfD103_c[D40?Nm]@@0mmK6403gg/h40?OF_@@0mlJ]103W]I@4
0>NUS0@0mmK6103gg/h<0?OFaP@0kkf]103W]I`80=jUS0P0cXac103>U7/40=JLQ0@0gYb4103W[I@4
0>NeW0`0gZF<1@3FW8@40=JUQ0@0eZF<1012:B4406=:@P@0mno_;03gmoL@0?ooo`003P3ooold0?Og
m`@0mmJm103ge/H50>NeW0@0gZfD103_c[D40?Nm]@@0mmK6403gg/h40?OF_@@0mlJ]103W]I@40>NU
S0@0mmK6103gg/h<0?OFaP@0kkf]103W]I`80=jUS0P0cXac103>U7/40=JLQ0@0gYb4103W[I@40>Ne
W0`0gZF<1@3FW8@40=JUQ0@0eZF<1012:B4406=:@P@0mno_;03gmoL@0?ooo`003P3ooold0?Ogm`@0
mmJm103_c[D50<j<J`@0klje103g_KD40?OF_@@0mmK6103gg/h40?OWgPP0mmk>103ge/H40?OF_@@0
ikFL103W]I@40>o>]@@0mmK6103ge[d40?ONcP@0mmK6103_aZd80=jUS0@0eZF<103FW8@40=JLL`@0
cXac103FW8@40>N]W0@0kkfU103W]I`40=jeW0@0gZfD3@3FYH`40=jeW0@0aXaS1024BST406=:@R`0
moOg403oool000h0oooo=03gmoL40?OF_@@0klje1@3>S6/40>o>]@@0mkfe103ge[d40?OFaP@0mmk>
103gimh80?ONcP@0mmK6103ge[d40>NeW0@0ikFD103_c[D40?OFaP@0mmJm103gg/h40?OFaP@0klJ]
203NYH`40=JUS0@0eYb4103FW7<40<j<L`@0eYb4103W[I`40>nmY@@0ikFL103N]I`40=j]U0d0eZF<
103N]I`40<J<H`@0Q4Xi101SBT8/0?Ogma00oooo000>0?oooc@0moOg103ge[d40>o>]@D0cXa[103_
c[D40?Nm]@@0mmJm103ge/H40?ONcP@0mnON203gg/h40?OFaP@0mmJm103W]I`40>NeU0@0klje103g
e/H40?OF_@@0mmk>103ge/H40>o6[@P0gZF<103FYH`40=JLQ0@0eYac103>S7<40=JLQ0@0ijfL103_
_JD40>NeW0@0g[FL103N[I@=0=JUS0@0g[FL1036S6<408A:>@@0HdY2;03gmoL@0?ooo`003P3ooold
0?Ogm`@0mmJm103_c[D50<j<J`@0klje103g_KD40?OF_@@0mmK6103gg/h40?OWgPP0mmk>103ge/H4
0?OF_@@0ikFL103W]I@40>o>]@@0mmK6103ge[d40?ONcP@0mmK6103_aZd80=jUS0@0eZF<103FW8@4
0=JLL`@0cXac103FW8@40>N]W0@0kkfU103W]I`40=jeW0@0gZfD3@3FYH`40=jeW0@0aXaS1024BST4
06=:@R`0moOg403oool000h0oooo<03gmoL40?OFaP@0ijF<103FLf<50=JLQ0@0e/Je203ge[d40?OF
aQ00mmk>103ge/H40>o>]@@0klJ]103_c[D80?OF_@@0kkf]103ge[d40?Nm]@@0ikFD103NW8@40=JL
Q0@0cYAk103FW7<40;f4J`@0cXac103N[I@40>NeW0@0kkfU103W]I`40=j]U0P0gZF<1@3FYH@40=jL
Q0@0g[FL203FW8@`0?Ogma00oooo000>0?oooc00moOg103ge/H40>NUS0@0eW=S1@3FW8@40=K6]@P0
mmJm103ge/H@0?ONcP@0mmK6103_c[D40>o6[@@0klje203ge[d40>nm[@@0mmJm103g_KD40>NeU0@0
gYb4103FW8@40<jDN`@0eYac102mQ6/40<j<L`@0gZfD103W]I`40>nmY@@0ikFL103N[I@80=jUS0D0
eZF4103NW8@40=jeW0P0eYb4<03gmoL@0?ooo`003P3oool`0?Ogm`@0mmK6103WYH`40=IcH`D0eYb4
103Fa[D80?OF_@@0mmK6403gg/h40?OFaP@0klje103_aZd40>o>]@P0mmJm103__Jd40?OF_@@0mkfe
103W]I@40=jLQ0@0eYb4103>U7/40=JLL`@0_HA[103>S7<40=j]U0@0ikFL103__JD40>NeW0@0gZfD
203NYH`50=JUQ0@0gYb4103N]I`80=JLQ300moOg403oool000h0oooo<03gmoL40?OFaP@0ijF<103F
Lf<50=JLQ0@0e/Je203ge[d40?OFaQ00mmk>103ge/H40>o>]@@0klJ]103_c[D80?OF_@@0kkf]103g
e[d40?Nm]@@0ikFD103NW8@40=JLQ0@0cYAk103FW7<40;f4J`@0cXac103N[I@40>NeW0@0kkfU103W
]I`40=j]U0P0gZF<1@3FYH@40=jLQ0@0g[FL203FW8@`0?Ogma00oooo000>0?oooc00moOg103g_KD4
0>NDQ0@0eW][1@3FYH`40>o>]@@0mmK6103gg/h40?OFaP`0mmk>103ge/H40?OF_@@0klje103gaZd4
0>o>]@@0mmK6103gg/h80?OFaP@0mlJ]103W]I`40=JLQ0@0cYAk2036S7<40<jDN`@0gZfD103W]I`4
0>NmY@@0kkfU103W]I`40=j]U0@0gZF<2@3NW8`40=JLQ0@0g[FU103>S6/40=JLQ0@0oooo;03gmoL@
0?ooo`003P3oool`0?Ogm`@0mkfe103WU8@40=IkJ`D0eZF<103_c[D40?OFaP@0mmk>103ge/H<0?ON
cP@0mmK6103ge[d40>o>]@@0mlJ]103_c[D40?OFaP@0mmk>203ge/H40?O6[@@0ikFL103FW8@40<jD
N`P0aXac103>U7/40=j]U0@0ikFL103W_JD40>nmY@@0ikFL103N[I@40=jUS0T0gYb<103FW8@40=je
Y@@0cXa[103FW8@40?ooob`0moOg403oool000h0oooo<03gmoL40?Nm]@@0iiB4103FNf/50=JUS0@0
klje103ge/H40?ONcP@0mmK6303gg/h40?OFaP@0mmJm103_c[D40?O6[@@0klje103ge/H40?ONcPP0
mmK6103gaZd40>NeW0@0eYb4103>U7/80<J<L`@0cYAk103N[I@40>NeW0@0ikfU103__JD40>NeW0@0
gZfD103NYH`90=jLS0@0eYb4103N]JD40<j<J`@0eYb4103oool/0?Ogma00oooo000>0?oooc00moOg
103g_KD40>NDQ0@0eW][1@3FYH`40>o>]@@0mmK6103gg/h40?OFaP`0mmk>103ge/H40?OF_@@0klje
103gaZd40>o>]@@0mmK6103gg/h80?OFaP@0mlJ]103W]I`40=JLQ0@0cYAk2036S7<40<jDN`@0gZfD
103W]I`40>NmY@@0kkfU103W]I`40=j]U0@0gZF<2@3NW8`40=JLQ0@0g[FU103>S6/40=JLQ0@0oooo
;03gmoL@0?ooo`003P3oool/0?Ogm`@0mmk>103gc[D40>NUS0@0cXa[1@3N[I@40?OF_@@0mmK6203g
g/h80?OFaP@0klje103ge[d40?Nm]@@0klJ]103__JD40>o6[@@0mmK6103ge[d80?OFaP@0mkfe103W
YH`40=JLQ0P0cYAk1036W8@40=JUQ0@0gZfD103W]I`40>nmY@@0ikFL103W[I@40=j]U0P0gYb41@3F
W8@40=JUQ0@0g[FU103NW8@40=JUS0@0e/K6;03gmoL@0?ooo`003P3oool/0?Ogm`@0mmk>103gc[D4
0>NUS0@0cXa[1@3N[I@40?OF_@@0mmK6203gg/h80?OFaP@0klje103ge[d40?Nm]@@0klJ]103__JD4
0>o6[@@0mmK6103ge[d80?OFaP@0mkfe103WYH`40=JLQ0P0cYAk1036W8@40=JUQ0@0gZfD103W]I`4
0>nmY@@0ikFL103W[I@40=j]U0P0gYb41@3FW8@40=JUQ0@0g[FU103NW8@40=JUS0@0e/K6;03gmoL@
0?ooo`003P3oool/0?Ogm`@0mmk>103gc[D40>NUS0@0cXa[1@3N[I@40?OF_@@0mmK6203gg/h80?OF
aP@0klje103ge[d40?Nm]@@0klJ]103__JD40>o6[@@0mmK6103ge[d80?OFaP@0mkfe103WYH`40=JL
Q0P0cYAk1036W8@40=JUQ0@0gZfD103W]I`40>nmY@@0ikFL103W[I@40=j]U0P0gYb41@3FW8@40=JU
Q0@0g[FU103NW8@40=JUS0@0e/K6;03gmoL@0?ooo`003P3oool/0?Ogm`@0mmk>103gc[D40>NUS0@0
cXa[1@3N[I@40?OF_@@0mmK6203gg/h80?OFaP@0klje103ge[d40?Nm]@@0klJ]103__JD40>o6[@@0
mmK6103ge[d80?OFaP@0mkfe103WYH`40=JLQ0P0cYAk1036W8@40=JUQ0@0gZfD103W]I`40>nmY@@0
ikFL103W[I@40=j]U0P0gYb41@3FW8@40=JUQ0@0g[FU103NW8@40=JUS0@0e/K6;03gmoL@0?ooo`00
3P3oool/0?Ogm`@0ikFD103>S7<409a[DP@0]G]S1@3W_JD40?OF_@`0mmK6103ge[d40?O>]@@0klje
103__Jd40>NmY@@0kkf]203_c[D40?OF_@`0mmK6103_c[D40>N]U0@0eYb4203>U7/40=JLQ0@0eZF<
103W[I`80>NeW0@0ikfU103W]I`80=j]U0@0eZF<1@3FW8@40=JLS0@0g[FU103>Le840=jeW0@0eXac
;03gmoL@0?ooo`003P3oool/0?Ogm`@0ikFD103>S7<409a[DP@0]G]S1@3W_JD40?OF_@`0mmK6103g
e[d40?O>]@@0klje103__Jd40>NmY@@0kkf]203_c[D40?OF_@`0mmK6103_c[D40>N]U0@0eYb4203>
U7/40=JLQ0@0eZF<103W[I`80>NeW0@0ikfU103W]I`80=j]U0@0eZF<1@3FW8@40=JLS0@0g[FU103>
Le840=jeW0@0eXac;03gmoL@0?ooo`003P3oool/0?Ogm`@0ikFD103>S7<409a[DP@0]G]S1@3W_JD4
0?OF_@`0mmK6103ge[d40?O>]@@0klje103__Jd40>NmY@@0kkf]203_c[D40?OF_@`0mmK6103_c[D4
0>N]U0@0eYb4203>U7/40=JLQ0@0eZF<103W[I`80>NeW0@0ikfU103W]I`80=j]U0@0eZF<1@3FW8@4
0=JLS0@0g[FU103>Le840=jeW0@0eXac;03gmoL@0?ooo`003P3oool/0?Ogm`@0ikFD103>S7<409a[
DP@0]G]S1@3W_JD40?OF_@`0mmK6103ge[d40?O>]@@0klje103__Jd40>NmY@@0kkf]203_c[D40?OF
_@`0mmK6103_c[D40>N]U0@0eYb4203>U7/40=JLQ0@0eZF<103W[I`80>NeW0@0ikfU103W]I`80=j]
U0@0eZF<1@3FW8@40=JLS0@0g[FU103>Le840=jeW0@0eXac;03gmoL@0?ooo`003P3oool/0?Ogm`@0
gYAc101c@RT408aJBP@0LdY21@3W_JD80?OFaPP0mmJm403ge/H40>nm[@@0ijfL103N[I@40>o6[@@0
klje203ge/H40?OF_@@0kkf]103NYH`40<j<Q0@0cYAc1036S7<40=JLQ0@0gZfD103NYH`40=j]U0@0
ijfL103NYH`40=j]U0`0eZF<1@3FW8@40=JLS0@0eZF<1036S6<40<jDL`@0eXak;03gmoL@0?ooo`00
3P3oool/0?Ogm`@0gYAc101c@RT408aJBP@0LdY21@3W_JD80?OFaPP0mmJm403ge/H40>nm[@@0ijfL
103N[I@40>o6[@@0klje203ge/H40?OF_@@0kkf]103NYH`40<j<Q0@0cYAc1036S7<40=JLQ0@0gZfD
103NYH`40=j]U0@0ijfL103NYH`40=j]U0`0eZF<1@3FW8@40=JLS0@0eZF<1036S6<40<jDL`@0eXak
;03gmoL@0?ooo`003P3oool/0?Ogm`@0gYAc101c@RT408aJBP@0LdY21@3W_JD80?OFaPP0mmJm403g
e/H40>nm[@@0ijfL103N[I@40>o6[@@0klje203ge/H40?OF_@@0kkf]103NYH`40<j<Q0@0cYAc1036
S7<40=JLQ0@0gZfD103NYH`40=j]U0@0ijfL103NYH`40=j]U0`0eZF<1@3FW8@40=JLS0@0eZF<1036
S6<40<jDL`@0eXak;03gmoL@0?ooo`003P3oool/0?Ogm`@0gYAc101c@RT408aJBP@0LdY21@3W_JD8
0?OFaPP0mmJm403ge/H40>nm[@@0ijfL103N[I@40>o6[@@0klje203ge/H40?OF_@@0kkf]103NYH`4
0<j<Q0@0cYAc1036S7<40=JLQ0@0gZfD103NYH`40=j]U0@0ijfL103NYH`40=j]U0`0eZF<1@3FW8@4
0=JLS0@0eZF<1036S6<40<jDL`@0eXak;03gmoL@0?ooo`003P3ooolX0?Ogm`@0mnON103W[I`40;Ec
FP@0LdXi101cBT850>NmY@@0mmJm103_c[D40?OFaP@0mmJm203N]I`80<JDN`@0aYB4103>S8@80=jU
S0@0ikfU303ge/H40>nm[@@0gZF<103>U7<40<j<J`@0aYAk103>U7/80<JLQ0@0eZF<103N]I`40=JU
S0P0gZfD203FYH`50=JLQ0@0eYb<103FYH`40:ESBP@0YE8i103>Q6</0?Ogma00oooo000>0?ooobP0
moOg103gimh40>N]W0@0]G=J101cBST407=:@PD0ikfU103ge[d40>o>]@@0mmK6103ge[d80=jeW0P0
aYAk1036U8@40<j<Q0P0gZF<103W_JD<0?OFaP@0kkf]103NYH`40<jDL`@0cXa[1036U7/40<jDN`P0
aYb4103FYH`40=jeW0@0eZF<203N[I@80=JUS0D0eYb4103FW8`40=JUS0@0YF=:102UDST40<j4Hb`0
moOg403oool000h0oooo:03gmoL40?OWgP@0ijfL102eLeX407=:>@@0LdY21@3W_JD40?OF_@@0klje
103ge/H40?OF_@P0g[FL2036U7/40<JDQ0@0cXb4203NYH`40>NmY@`0mmK6103__Jd40=jUS0@0cYAc
103>S6/40<JDN`@0cYAk2036W8@40=JUS0@0g[FL103FYH`80=j]U0P0eZF<1@3FW8@40=JLS0@0eZF<
102UHdX40:EB>@@0cXAS;03gmoL@0?ooo`003P3ooolX0?Ogm`@0mnON103W[I`40;EcFP@0LdXi101c
BT850>NmY@@0mmJm103_c[D40?OFaP@0mmJm203N]I`80<JDN`@0aYB4103>S8@80=jUS0@0ikfU303g
e/H40>nm[@@0gZF<103>U7<40<j<J`@0aYAk103>U7/80<JLQ0@0eZF<103N]I`40=JUS0P0gZfD203F
YH`50=JLQ0@0eYb<103FYH`40:ESBP@0YE8i103>Q6</0?Ogma00oooo000>0?ooobP0moOg103_aZd4
0>N]W0@0@QP@1012:B44058i<@D0klJ]103_c[D40?O>]@P0mmJm103_aZd40<JLQ0@0[HA[101kHeX4
06=:@P@0Q58i102eNf<80:eJ@P@0klJ]203ge/H40>o6[@@0gZF<103>U7<40<JLL`@0_HA[103FYH`8
0=j]U0@0gZF<103FW8`40<JLQ0P0gZfD103FYH`90<JLQ0P0eZF<102]Je840:eJ@P@0cW=J;03gmoL@
0?ooo`003P3ooolX0?Ogm`@0klJ]103W[I`4048H40@0@RTQ101B>C450>o6[@@0klje103gc[D80?OF
_@@0klJ]1036W8@40:f4J`@0Nf=J101SBT8408AB>@@0]G]S202]FT840>o6[@P0mmK6103_aZd40=jU
S0@0cYAc1036W7<40;f4J`@0eZF<203N[I@40=jUS0@0eYb<1036W8@80=j]U0@0eZF<2@36W8@80=JU
S0@0[F]B102]FT840<icFR`0moOg403oool000h0oooo:03gmoL40>o6[@@0ijfL10126104048Y8@@0
DSTa1@3_aZd40>o>]@@0mlje203ge[d40>o6[@@0aYb4102]Q6/407]SFP@0HdY21024DST40;EkH`P0
[EY2103_aZd80?OFaP@0klJ]103NYH`40<jDL`@0aYac102mQ6/40=JUS0P0gZfD103NYH`40=JLS0@0
aYb4203N[I@40=JUS0T0aYb4203FYH`40:e[DP@0[EY2103>LeX/0?Ogma00oooo000>0?ooobP0moOg
103_aZd40>N]W0@0@QP@1012:B44058i<@D0klJ]103_c[D40?O>]@P0mmJm103_aZd40<JLQ0@0[HA[
101kHeX406=:@P@0Q58i102eNf<80:eJ@P@0klJ]203ge/H40>o6[@@0gZF<103>U7<40<JLL`@0_HA[
103FYH`80=j]U0@0gZF<103FW8`40<JLQ0P0gZfD103FYH`90<JLQ0P0eZF<102]Je840:eJ@P@0cW=J
;03gmoL@0?ooo`003P3ooolT0?Ogm`@0oooo103gaZd40=jLQ0@0LdY21012:B4405Xa:@D0klje103g
e[d40>o>]@P0mmJm103ge/H40=j]U0@0kkf]1024He84058a:@@0HcTY101kHeX40;EcFP@0gZF<103_
c[D40?ONcP@0mnON103_c[D40=jUS0@0_HA[102mQ6<407/Y60@0aXac1036S6<40;F4J`@0W6]B1036
U7/40<JLQ0@0eZF4203FYH`40<JDN`D0aYb4103FW8`40<JDN`@0U5Y:102]Je840=J<N`@0oooo:03g
moL@0?ooo`003P3ooolT0?Ogm`@0oooo103gaZd40=jLQ0@0LdY21012:B4405Xa:@D0klje103ge[d4
0>o>]@P0mmJm103ge/H40=j]U0@0kkf]1024He84058a:@@0HcTY101kHeX40;EcFP@0gZF<103_c[D4
0?ONcP@0mnON103_c[D40=jUS0@0_HA[102mQ6<407/Y60@0aXac1036S6<40;F4J`@0W6]B1036U7/4
0<JLQ0@0eZF4203FYH`40<JDN`D0aYb4103FW8`40<JDN`@0U5Y:102]Je840=J<N`@0oooo:03gmoL@
0?ooo`003P3ooolT0?Ogm`@0oooo103gaZd40=jLQ0@0LdY21012:B4405Xa:@D0klje103ge[d40>o>
]@P0mmJm103ge/H40=j]U0@0kkf]1024He84058a:@@0HcTY101kHeX40;EcFP@0gZF<103_c[D40?ON
cP@0mnON103_c[D40=jUS0@0_HA[102mQ6<407/Y60@0aXac1036S6<40;F4J`@0W6]B1036U7/40<JL
Q0@0eZF4203FYH`40<JDN`D0aYb4103FW8`40<JDN`@0U5Y:102]Je840=J<N`@0oooo:03gmoL@0?oo
o`003P3ooolT0?Ogm`@0oooo103gaZd40=jLQ0@0LdY21012:B4405Xa:@D0klje103ge[d40>o>]@P0
mmJm103ge/H40=j]U0@0kkf]1024He84058a:@@0HcTY101kHeX40;EcFP@0gZF<103_c[D40?ONcP@0
mnON103_c[D40=jUS0@0_HA[102mQ6<407/Y60@0aXac1036S6<40;F4J`@0W6]B1036U7/40<JLQ0@0
eZF4203FYH`40<JDN`D0aYb4103FW8`40<JDN`@0U5Y:102]Je840=J<N`@0oooo:03gmoL@0?ooo`00
3P3oool40?O_k`@0moOg103gknlH0?Ogm`@0DR4H103WYH`40>NeW0@0S5Y:1012<CT4048Y8@T0klje
103ge[d80>o>]@@0mmK6103_c[D40>NeW0P0eZF<202mQ6<40=JUQ0@0ijfD103_aZd80?ONcP@0klJ]
103NYH`40<j<J`@0_HA[102]Je840:F4N`@0Nf=J100Q410408AB@P@0Q6]J101S@S4409acH`@0YG=B
103>S6/90<JLQ0@0eYb4102]Q6/407=:>@@0Q592103NYH`40?ooobP0moOg403oool000h0oooo103g
knl40?Ogm`@0mno_603gmoL4058Q60@0ijF<103W]I`408aJBP@0@S4i1012:B490>o>]@@0mmJm203_
c[D40?OFaP@0klje103W]I`80=JUS0P0_HAS103FYH@40>N]U0@0klJ]203gg/h40>o6[@@0gZF<103>
S6/40;f4J`@0[F]B102UQ7/407]SFP@08A0@1024DT8408A[FP@0Hd8a102LLf<40:EcDP@0cXa[2@36
W8@40=JLQ0@0[HA[101cBST408AB@P@0gZF<103ooolX0?Ogma00oooo000>0?ooo`@0mno_103gmoL4
0?O_kaP0moOg101B8AP40>NUS0@0ikFL102<FTX4048a>@@0@RTQ2@3_c[D40?OF_@P0klje103ge/H4
0>o>]@@0ikFL203FYH`80;f4H`@0eZF4103W[I@40>o6[@P0mmk>103_aZd40=jUS0@0cXa[102mQ6/4
0:e[DP@0YHAk101kHeX4024@40@0Q5921024JeX406=2<@@0W7=S102ULe840<j<J`T0aYb4103FW8@4
0:f4J`@0LdXi1024DT840=jUS0@0oooo:03gmoL@0?ooo`003P3oool40?O_k`@0moOg103gknlH0?Og
m`@0DR4H103WYH`40>NeW0@0S5Y:1012<CT4048Y8@T0klje103ge[d80>o>]@@0mmK6103_c[D40>Ne
W0P0eZF<202mQ6<40=JUQ0@0ijfD103_aZd80?ONcP@0klJ]103NYH`40<j<J`@0_HA[102]Je840:F4
N`@0Nf=J100Q410408AB@P@0Q6]J101S@S4409acH`@0YG=B103>S6/90<JLQ0@0eYb4102]Q6/407=:
>@@0Q592103NYH`40?ooobP0moOg403oool000h0oooo103gknlL0?Ogm`@0FS4Y101B<BT404X@20@0
Q5921012:C4403TY8@@0DS4Y2@3_c[D40?OFaP@0gYb<103N[I@40?OFaP@0mmk>103ge/H40>nm[@@0
gZF<103N[I@40=jUS0@0ikFD103__JD40>o6[@P0mmk>103__Jd40=jeW0@0cYAc1036W7<40<j<J`@0
eZF<1036S7<4034Q8@@0HcTY101cDTX405Y2>@@0W6]B102mQ6/40=JUQ0@0cYAk1@36W8@40=JUQ0@0
LdY2101S@S4407=2<@@0cW=J;03gmoL@0?ooo`003P3oool40?O_ka`0moOg101J<BT4058a:@@0BQ08
1024DT84048Y<@@0>BTQ101B<BT90>o>]@@0mmK6103NW8`40=j]U0@0mmK6103gg/h40?OFaP@0kkf]
103NYH`40=j]U0@0gZF<103W]I@40>nmY@@0klJ]203gg/h40>nm[@@0g[FL103>U7<40<JLL`@0cXa[
103FYH`40<J<L`@0<B4Q101S>BT407=BBP@0FT8i102LJe840;f4J`@0eZF4103>U7/50<JLQ0@0eZF4
101cBT8406=2<@@0Ld8a103>LeX/0?Ogma00oooo000>0?ooo`@0mno_703gmoL405Xa:@@0DS4Y101:
40P408AB@P@0@RTa100i:B44058a:@T0klje103ge/H40=jLS0@0gZfD103ge/H40?ONcP@0mmK6103_
_Jd40=jUS0@0gZfD103NYH`40>NeU0@0kkfU103_aZd80?ONcP@0kkf]103N]I`40<jDL`@0aYac103>
S6/40=JUS0@0aXac100a8B4406<i:@@0Le9:101J@ST409a[DP@0_HA[103FYH@40<jDN`D0aYb4103F
YH@407=:@P@0Hd8a101c@S440<icFR`0moOg403oool000h0oooo103gknlL0?Ogm`@0FS4Y101B<BT4
04X@20@0Q5921012:C4403TY8@@0DS4Y2@3_c[D40?OFaP@0gYb<103N[I@40?OFaP@0mmk>103ge/H4
0>nm[@@0gZF<103N[I@40=jUS0@0ikFD103__JD40>o6[@P0mmk>103__Jd40=jeW0@0cYAc1036W7<4
0<j<J`@0eZF<1036S7<4034Q8@@0HcTY101cDTX405Y2>@@0W6]B102mQ6/40=JUQ0@0cYAk1@36W8@4
0=JUQ0@0LdY2101S@S4407=2<@@0cW=J;03gmoL@0?ooo`003P3ooolP0?Ogm`@0FS4Y101S@S4405Xa
:@@0DSTa100Y61P4058a:@@0FS4Y1@3_aZd40?O>]@@0klje103ge/H40=jeW0@0_HA[1036U7/40;F<
L`@0W7=S102<FTX409ASBP@0YF]B102]Je840=jeW0@0klje103ge/H40?OF_@@0kkfU103N]I`40<jD
N`@0cXa[1036W7<40=JUQ0P0eZF<1036U7/80:ecFP@0cYAk103FW7<40<JLQ0@0eZF41@3FYH`40<JL
Q0@0Hd8a101B<BT407=2<@@0_EY2;03gmoL@0?ooo`003P3ooolP0?Ogm`@0FS4Y101S@S4405Xa:@@0
DSTa100Y61P4058a:@@0FS4Y1@3_aZd40?O>]@@0klje103ge/H40=jeW0@0_HA[1036U7/40;F<L`@0
W7=S102<FTX409ASBP@0YF]B102]Je840=jeW0@0klje103ge/H40?OF_@@0kkfU103N]I`40<jDN`@0
cXa[1036W7<40=JUQ0P0eZF<1036U7/80:ecFP@0cYAk103FW7<40<JLQ0@0eZF41@3FYH`40<JLQ0@0
Hd8a101B<BT407=2<@@0_EY2;03gmoL@0?ooo`003P3ooolP0?Ogm`@0FS4Y101S@S4405Xa:@@0DSTa
100Y61P4058a:@@0FS4Y1@3_aZd40?O>]@@0klje103ge/H40=jeW0@0_HA[1036U7/40;F<L`@0W7=S
102<FTX409ASBP@0YF]B102]Je840=jeW0@0klje103ge/H40?OF_@@0kkfU103N]I`40<jDN`@0cXa[
1036W7<40=JUQ0P0eZF<1036U7/80:ecFP@0cYAk103FW7<40<JLQ0@0eZF41@3FYH`40<JLQ0@0Hd8a
101B<BT407=2<@@0_EY2;03gmoL@0?ooo`003P3ooolP0?Ogm`@0FS4Y101S@S4405Xa:@@0DSTa100Y
61P4058a:@@0FS4Y1@3_aZd40?O>]@@0klje103ge/H40=jeW0@0_HA[1036U7/40;F<L`@0W7=S102<
FTX409ASBP@0YF]B102]Je840=jeW0@0klje103ge/H40?OF_@@0kkfU103N]I`40<jDN`@0cXa[1036
W7<40=JUQ0P0eZF<1036U7/80:ecFP@0cYAk103FW7<40<JLQ0@0eZF41@3FYH`40<JLQ0@0Hd8a101B
<BT407=2<@@0_EY2;03gmoL@0?ooo`003P3ooolP0?Ogm`@0HcTY10128AP403TY8@P0@RTQ100i:B44
06=:@PD0g[FL103gc[D40?OF_@P0mmK6103_c[D40=JLS0@0[Hb4103FW8`40<J<L`@0aYAk102mQ6/4
0=jUS0@0klje203ge/H40?Nm]@@0klJ]103N]I`40<j<Q0P0W5Y21036W7<80=JUQ0@0gZF<103FYH@4
0<JLQ0@0eZF41036W8@40=JLS0@0aYb41@3FYH@40:f4J`P0>BTQ1036S7<40:eJ@R`0moOg403oool0
00h0oooo803gmoL406<i:@@0@R4H100i:B48048Y8@@0>BTQ101SBT850=jeW0@0mlje103ge[d80?OF
aP@0klje103FW8`40:f<Q0@0eYb<1036S7<40<JDN`@0_HA[103NYH`40>o>]@P0mmK6103g_KD40>o6
[@@0g[FL103>S8@809aJ@P@0aYac203FYH@40=jUS0@0eZF41036W8@40=JUQ0@0aYb4103FW8`40<JL
Q0D0eZF4102]Q6/803TY8@@0aXac102]FT8/0?Ogma00oooo000>0?ooob00moOg101S>BT4048Q60@0
>BTQ2012:B4403TY8@@0HdY21@3N]I`40?O>]@@0mmJm203ge/H40>o>]@@0eYb<102]S8@40=JLS0@0
aXac1036U7/40;f4J`@0gZF<103_c[D80?OFaP@0mkfe103_aZd40=jeW0@0cXb4202LFT840<JLL`P0
eZF4103NYH`40=JUQ0@0aYb4103FYH@40<JLQ0@0eYb<1036W8@50=JUQ0@0[HA[200i:B440<J<L`@0
[EY2;03gmoL@0?ooo`003P3ooolP0?Ogm`@0HcTY10128AP403TY8@P0@RTQ100i:B4406=:@PD0g[FL
103gc[D40?OF_@P0mmK6103_c[D40=JLS0@0[Hb4103FW8`40<J<L`@0aYAk102mQ6/40=jUS0@0klje
203ge/H40?Nm]@@0klJ]103N]I`40<j<Q0P0W5Y21036W7<80=JUQ0@0gZF<103FYH@40<JLQ0@0eZF4
1036W8@40=JLS0@0aYb41@3FYH@40:f4J`P0>BTQ1036S7<40:eJ@R`0moOg403oool000h0oooo203g
moL40?O_ka@0moOg101cBST404XQ60@0@RTQ100i:B44024@40@0@RTQ101SBT850<JLQ0@0klJ]103g
e[d40?OFaR00mmk>103ge[d40>o>]@@0mmk>203_c[D40>o6[@P0ikfU103FYH`409AJDP@0LdXi101S
@S440;EkH`@0eZF<203FYH@40<JLQ0@0cYAk102eS7<40=JLS0D0eYb4101cBST4048Y8@@0DT8i102]
Je840:EB>@@0Je9::03gmoL@0?ooo`003P3oool80?Ogm`@0mno_503gmoL407=:>@@0BR4H1012:B44
03TY8@@08A0@1012:B4406=:@PD0aYb4103_aZd40?OF_@@0mmK6803gg/h40?OF_@@0klje103gg/h8
0>o>]@@0klJ]203W_JD40=JUS0@0U5YB101cBST406=2<@@0]G]S103FYH`80=JUQ0@0aYb4103>U7/4
0;F<L`@0eYb<1@3FW8@407=:>@@0@RTQ101B@ST40:e[DP@0YE8i101[DTXX0?Ogma00oooo000>0?oo
o`P0moOg103gknlD0?Ogm`@0LdXi101:8AP4048Y8@@0>BTQ100Q4104048Y8@@0HdY21@36W8@40>o6
[@@0mmJm103ge/HP0?ONcP@0mmJm103_c[D40?ONcPP0klje103_aZd80>NmY@@0eZF<102DFU8407=:
>@@0Hd8a102eNf<40=JUS0P0eZF41036W8@40<jDN`@0]Hac103FW8`50=JLQ0@0LdXi1012:B440592
>@@0[F]B102UDST406]BBRP0moOg403oool000h0oooo203gmoL40?O_ka@0moOg101cBST404XQ60@0
@RTQ100i:B44024@40@0@RTQ101SBT850<JLQ0@0klJ]103ge[d40?OFaR00mmk>103ge[d40>o>]@@0
mmk>203_c[D40>o6[@P0ikfU103FYH`409AJDP@0LdXi101S@S440;EkH`@0eZF<203FYH@40<JLQ0@0
cYAk102eS7<40=JLS0D0eYb4101cBST4048Y8@@0DT8i102]Je840:EB>@@0Je9::03gmoL@0?ooo`00
3P3ooolP0?Ogm`@0HdY2101B>C48048Y8@@0<B4H1012:B4406=:@PD0aYAk103_aZd40?OF_@@0mmK6
203gg/h<0?OWgP@0mmk>103gimh80?ONcP`0mmJm103_aZd40>nmY@P0klJ]103__Jd40=jeY@@0eYb<
102LLf<407=:>@@0Hd8a102<FTX408A[FPP0W6]B103FW8`40=JLQ0D0cYAk101B<BT4048Y8@@0BS4a
101B8AP407/a8@@0LeYB:03gmoL@0?ooo`003P3ooolP0?Ogm`@0HdY2101B>C48048Y8@@0<B4H1012
:B4406=:@PD0aYAk103_aZd40?OF_@@0mmK6203gg/h<0?OWgP@0mmk>103gimh80?ONcP`0mmJm103_
aZd40>nmY@P0klJ]103__Jd40=jeY@@0eYb<102LLf<407=:>@@0Hd8a102<FTX408A[FPP0W6]B103F
W8`40=JLQ0D0cYAk101B<BT4048Y8@@0BS4a101B8AP407/a8@@0LeYB:03gmoL@0?ooo`003P3ooolP
0?Ogm`@0HdY2101B>C48048Y8@@0<B4H1012:B4406=:@PD0aYAk103_aZd40?OF_@@0mmK6203gg/h<
0?OWgP@0mmk>103gimh80?ONcP`0mmJm103_aZd40>nmY@P0klJ]103__Jd40=jeY@@0eYb<102LLf<4
07=:>@@0Hd8a102<FTX408A[FPP0W6]B103FW8`40=JLQ0D0cYAk101B<BT4048Y8@@0BS4a101B8AP4
07/a8@@0LeYB:03gmoL@0?ooo`003P3ooolP0?Ogm`@0HdY2101B>C48048Y8@@0<B4H1012:B4406=:
@PD0aYAk103_aZd40?OF_@@0mmK6203gg/h<0?OWgP@0mmk>103gimh80?ONcP`0mmJm103_aZd40>nm
Y@P0klJ]103__Jd40=jeY@@0eYb<102LLf<407=:>@@0Hd8a102<FTX408A[FPP0W6]B103FW8`40=JL
Q0D0cYAk101B<BT4048Y8@@0BS4a101B8AP407/a8@@0LeYB:03gmoL@0?ooo`003P3ooolP0?Ogm`P0
Le9:100i:B48048Y8@@0BS4a101SBT850:f4J`@0g[FL203ge[d40?OFaPP0mmk>403gimh<0?ONcPP0
mmJm203_aZd40>nmY@@0klJ]103__Jd40>NmY@@0g[FL103FYH`40<JLQ0@0]Hac202ULeX40<J<L`@0
aYb4103>S8@40<JLQ0D0]Hac101B<BT4048Y8@@0>BTQ100a8AP4058a:@@0LeYB:03gmoL@0?ooo`00
3P3ooolP0?Ogm`P0Le9:100i:B48048Y8@@0BS4a101SBT850:f4J`@0g[FL203ge[d40?OFaPP0mmk>
403gimh<0?ONcPP0mmJm203_aZd40>nmY@@0klJ]103__Jd40>NmY@@0g[FL103FYH`40<JLQ0@0]Hac
202ULeX40<J<L`@0aYb4103>S8@40<JLQ0D0]Hac101B<BT4048Y8@@0>BTQ100a8AP4058a:@@0LeYB
:03gmoL@0?ooo`003P3ooolP0?Ogm`P0Le9:100i:B48048Y8@@0BS4a101SBT850:f4J`@0g[FL203g
e[d40?OFaPP0mmk>403gimh<0?ONcPP0mmJm203_aZd40>nmY@@0klJ]103__Jd40>NmY@@0g[FL103F
YH`40<JLQ0@0]Hac202ULeX40<J<L`@0aYb4103>S8@40<JLQ0D0]Hac101B<BT4048Y8@@0>BTQ100a
8AP4058a:@@0LeYB:03gmoL@0?ooo`003P3ooolP0?Ogm`P0Le9:100i:B48048Y8@@0BS4a101SBT85
0:f4J`@0g[FL203ge[d40?OFaPP0mmk>403gimh<0?ONcPP0mmJm203_aZd40>nmY@@0klJ]103__Jd4
0>NmY@@0g[FL103FYH`40<JLQ0@0]Hac202ULeX40<J<L`@0aYb4103>S8@40<JLQ0D0]Hac101B<BT4
048Y8@@0>BTQ100a8AP4058a:@@0LeYB:03gmoL@0?ooo`003P3ooolP0?Ogm`@0LdXi101S@S44058i
<@@0@RTQ101:8AP4058a:@@0Hd8a1@24He840=JUS0@0klje103ge[d40?OFaP@0mmk>103gimh40?ON
cP`0mnON203gg/h40?OF_@@0mmK6103gc[D40>nmY@P0klJ]203__JD40>NeW0@0ijfD103N[I@40=JU
S0@0gZfD203FYH`40=JLQ0@0eYb<103FW8@40<jDN`D0U6=:101B<BT4048Y8@@0DS4Y100i:B44048Y
8@@0Hd8a1036[JdT0?Ogma00oooo000>0?ooob00moOg101cBST406=2<@@0DSTa1012:B4404XQ60@0
DS4Y101S@S4508ASDP@0eZF<103_c[D40?OF_@@0mmK6103gg/h40?OWgP@0mmk>303gimh80?ONcP@0
mmJm103ge/H40?O>]@@0kkfU203_aZd80>nmY@@0ikFL103W[I@40=j]U0@0eZF<103N[I@80=JUS0@0
eYb4103FW8`40=JLQ0@0cYAk1@2DHdX4058a:@@0@RTQ101B<BT403TY8@@0@RTQ101S@S440<J][B@0
moOg403oool000h0oooo803gmoL407=:>@@0Hd8a101B>C44048Y8@@0BR4H101B<BT406=2<@D0Q6=B
103FYH`40>o>]@@0mmJm103ge/H40?ONcP@0mnON103gg/h<0?OWgPP0mmk>103ge[d40?OFaP@0mlje
103__JD80>o6[@P0kkfU103W]I`40>N]U0@0gZfD103FYH`40=j]U0P0eZF<103FW8@40=JLS0@0eYb4
103>U7/509ASBP@0DS4Y1012:B44058a:@@0>BTQ1012:B4406=2<@@0aZf]903gmoL@0?ooo`003P3o
oolP0?Ogm`@0LdXi101S@S44058i<@@0@RTQ101:8AP4058a:@@0Hd8a1@24He840=JUS0@0klje103g
e[d40?OFaP@0mmk>103gimh40?ONcP`0mnON203gg/h40?OF_@@0mmK6103gc[D40>nmY@P0klJ]203_
_JD40>NeW0@0ijfD103N[I@40=JUS0@0gZfD203FYH`40=JLQ0@0eYb<103FW8@40<jDN`D0U6=:101B
<BT4048Y8@@0DS4Y100i:B44048Y8@@0Hd8a1036[JdT0?Ogma00oooo000>0?ooob00moOg101S@S44
06]BBP@0DSTa101B<BT4034Q60P0@RTQ1@1cBST40:EcDP@0klJ]103ge[d40?OFaP@0mmk>203gimh4
0?ONcP@0mnON303gg/h80?OF_@P0klJ]403__JD40>NeW0P0gZfD103N]I`40=JUS0@0gZF<103FYH`<
0<JLQ0@0[HA[1@1J@ST4034Q60@0BS4a100a8B44034Q60@08A0@101B<BT40:F4Nb@0moOg403oool0
00h0oooo803gmoL406=2<@@0Je9:101B>C44058a:@@0<B4H2012:B4507=:>@@0YG=B103_aZd40?OF
_@@0mmK6103gg/h80?OWgP@0mmk>103gimh<0?ONcPP0mmJm203_aZd@0>nmY@@0ikFL203N[I@40=je
W0@0eZF<103NYH`40=JUS0`0aYb4102]Q6/505Y2>@@0<B4H101:<C44034Q8@@0<B4H100Q4104058a
:@@0YHAk903gmoL@0?ooo`003P3ooolP0?Ogm`@0Hd8a101[DTX4058i<@@0DS4Y100a8AP8048Y8@D0
LdXi102ULe840>o6[@@0mmJm103ge/H40?ONcPP0mnON103gg/h40?OWgP`0mmk>203ge[d80>o6[A00
kkfU103W]I`80=j]U0@0g[FL103FYH`40=jUS0@0eZF<3036W8@40:f4J`D0FT8i100a8AP404Xa<@@0
<B4Q100a8AP4024@40@0DS4Y102UQ7/T0?Ogma00oooo000>0?ooob00moOg101S@S4406]BBP@0DSTa
101B<BT4034Q60P0@RTQ1@1cBST40:EcDP@0klJ]103ge[d40?OFaP@0mmk>203gimh40?ONcP@0mnON
303gg/h80?OF_@P0klJ]403__JD40>NeW0P0gZfD103N]I`40=JUS0@0gZF<103FYH`<0<JLQ0@0[HA[
1@1J@ST4034Q60@0BS4a100a8B44034Q60@08A0@101B<BT40:F4Nb@0moOg403oool000h0oooo803g
moL407=:>@P0HdY2101B>C44058a:@@0@RTQ101B>C4506]BBP@0Q6=B103N[I@40?O>]@P0mmK6103g
g/h<0?OWgP`0mmk>103ge/H40>o>]@@0klJ]303__JD40>NmY@P0ikFL403N[I@80=JUS0@0aYb4103F
W8@40<JDN`@0S6=B1@1B<BT4058i<@@0:APH100a8B44024@40@0<B4Q1012:B4409AkLb@0moOg403o
ool000h0oooo803gmoL407=:>@P0HdY2101B>C44058a:@@0@RTQ101B>C4506]BBP@0Q6=B103N[I@4
0?O>]@P0mmK6103gg/h<0?OWgP`0mmk>103ge/H40>o>]@@0klJ]303__JD40>NmY@P0ikFL403N[I@8
0=JUS0@0aYb4103FW8@40<JDN`@0S6=B1@1B<BT4058i<@@0:APH100a8B44024@40@0<B4Q1012:B44
09AkLb@0moOg403oool000h0oooo803gmoL407=:>@P0HdY2101B>C44058a:@@0@RTQ101B>C4506]B
BP@0Q6=B103N[I@40?O>]@P0mmK6103gg/h<0?OWgP`0mmk>103ge/H40>o>]@@0klJ]303__JD40>Nm
Y@P0ikFL403N[I@80=JUS0@0aYb4103FW8@40<JDN`@0S6=B1@1B<BT4058i<@@0:APH100a8B44024@
40@0<B4Q1012:B4409AkLb@0moOg403oool000h0oooo803gmoL407=:>@P0HdY2101B>C44058a:@@0
@RTQ101B>C4506]BBP@0Q6=B103N[I@40?O>]@P0mmK6103gg/h<0?OWgP`0mmk>103ge/H40>o>]@@0
klJ]303__JD40>NmY@P0ikFL403N[I@80=JUS0@0aYb4103FW8@40<JDN`@0S6=B1@1B<BT4058i<@@0
:APH100a8B44024@40@0<B4Q1012:B4409AkLb@0moOg403oool000h0oooo803gmoL<06]BBP@0HdY2
101B<BT4034Q60@0DS4Y1@1cBST409a[DP@0cXa[103_aZd40?OF_@P0mmK6103gg/h<0?OWgPP0mmk>
103ge/H40?OF_@@0klJ]103W_JD40>NeW0@0kkFU103W]I`40>N]U0@0ijfL203N[I@40=jUS0P0eZF<
103>U7/40=JLQ0@0aXac102LLf<407=:>@D0DS4Y100a8AP4034Q8@@0:APH100a8AP4034Q8@@0DS4Y
:03gmoL@0?ooo`003P3ooolP0?Ogm``0Je9:101SBT84058a:@@0<B4H101B<BT507=:>@@0W6]B103>
S6/40>o6[@@0mmJm203ge/H40?ONcP`0mnON203gg/h40?OFaP@0mmJm103_aZd40>NmY@@0ikFL103_
]JD40>NeW0@0ijfD103W[I`80=j]U0@0gZF<203FYH`40<jDN`@0eYb41036S7<409acH`@0LdXi1@1B
<BT4034Q60@0<B4Q100Y61P4034Q60@0<B4Q101B<BTX0?Ogma00oooo000>0?ooob00moOg301[DTX4
06=:@P@0DS4Y100a8AP4058a:@D0LdXi102LJe840<j<J`@0klJ]103ge[d80?OFaP@0mmk>303gimh8
0?ONcP@0mmK6103ge[d40>o6[@@0ikfU103W]I`40>neY@@0ikFL103W[I@40>N]W0P0gZfD103NYH`8
0=JUS0@0cYAk103FW8@40<J<L`@0W7=S101cBST5058a:@@0<B4H100a8B4402TH60@0<B4H100a8B44
058a:BP0moOg403oool000h0oooo803gmoL<06]BBP@0HdY2101B<BT4034Q60@0DS4Y1@1cBST409a[
DP@0cXa[103_aZd40?OF_@P0mmK6103gg/h<0?OWgPP0mmk>103ge/H40?OF_@@0klJ]103W_JD40>Ne
W0@0kkFU103W]I`40>N]U0@0ijfL203N[I@40=jUS0P0eZF<103>U7/40=JLQ0@0aXac102LLf<407=:
>@D0DS4Y100a8AP4034Q8@@0:APH100a8AP4034Q8@@0DS4Y:03gmoL@0?ooo`003P3ooolH0?Ogm`@0
mno_103_inL806=:@P@0Je9:101SBT84048Y8@P0DSTa1@1J@ST409a[DP@0aXac103W_JD40?OF_@@0
mmK6203gg/h<0?OWgPP0mmk>103_c[D40?O>]@`0kkfU203W]I`40>N]U0@0g[FL103N[I@40=JLS0`0
eZF<103FW8@40<JLQ0@0]HA[102ULeX406=2<@D0DS4Y300i:B44034Q60@0>BTQ101B<BT40?ooob@0
moOg403oool000h0oooo603gmoL40?O_k`@0knOW201SBT8406]BBP@0HdY21012:B48058i<@D0FT8i
102LJe840<J<L`@0ikfU103ge[d40?OFaPP0mmk>303gimh80?ONcP@0klje103gc[D<0>nmY@P0ikFL
103W[I@40=jeW0@0gZfD103FW8`<0=JUS0@0eYb41036W8@40;F4J`@0YG=J101S@S45058a:@`0>BTQ
100a8AP403TY8@@0DS4Y103ooolT0?Ogma00oooo000>0?oooaP0moOg103gknl40>oWi`P0HdY2101[
DTX406=:@P@0@RTQ201B>C4505Y2>@@0W6]B1036S7<40>NmY@@0mmJm103ge/H80?ONcP`0mnON203g
g/h40>o>]@@0mlje303__JD80>NeW0@0ijfD103N]I`40=j]U0@0eYb<303FYH`40=JLQ0@0aYb4102e
Q6/40:EcFP@0Hd8a1@1B<BT<03TY8@@0<B4H100i:B44058a:@@0oooo903gmoL@0?ooo`003P3ooolH
0?Ogm`@0mno_103_inL806=:@P@0Je9:101SBT84048Y8@P0DSTa1@1J@ST409a[DP@0aXac103W_JD4
0?OF_@@0mmK6203gg/h<0?OWgPP0mmk>103_c[D40?O>]@`0kkfU203W]I`40>N]U0@0g[FL103N[I@4
0=JLS0`0eZF<103FW8@40<JLQ0@0]HA[102ULeX406=2<@D0DS4Y300i:B44034Q60@0>BTQ101B<BT4
0?ooob@0moOg403oool000h0oooo803gmoL405Y2>@@0LdXi101SBT8406]BBP@0HdY2101B>C4405Y2
>@D0Hd8a102<Lf<40:EcFP@0gZF<103_c[D80?OFaQ00mmk>103ge/H40>o>]@@0klJ]103_c[D40>nm
Y@@0ikFD103W]I`40>NeU0P0ikFL203N[I@40=jUS0@0eZF<203FW8@40<JLQ0@0]Hac102ULeX407=:
@P@0DS4Y1@0i:B44034Q60@0<B4Q100Y61P401P@40@0:APH101cBT8X0?Ogma00oooo000>0?ooob00
moOg101J@ST407=:>@@0HdY2101[DTX406=:@P@0DSTa101J@ST506=2<@@0S7=S102ULeX40=jUS0@0
klje203ge/H@0?ONcP@0mmK6103_c[D40>o6[@@0klje103__JD40>NeU0@0ikFL103W]I@80>NeW0P0
gZfD103NYH`40=JUS0P0eYb41036W8@40;F<L`@0YG=J101cBT84058a:@D0>BTQ100a8AP4034Q8@@0
:APH100H410402TH60@0LdY2:03gmoL@0?ooo`003P3ooolP0?Ogm`@0FT8i101cBST406=:@P@0Je9:
101SBT84058i<@@0FT8i1@1S@S4408acH`@0YG=J103NYH`40>o>]@P0mmK6403gg/h40?OFaP@0klje
103_aZd40>o>]@@0kkfU103W]I@40>NeW0@0ikFD203W]I`80=j]U0@0gZF<103FYH`80=JLQ0@0aYb4
102eS7<40:EcFP@0LdY2101B<BT503TY8@@0<B4H100a8B4402TH60@0610@100Y61P407=:@RP0moOg
403oool000h0oooo803gmoL405Y2>@@0LdXi101SBT8406]BBP@0HdY2101B>C4405Y2>@D0Hd8a102<
Lf<40:EcFP@0gZF<103_c[D80?OFaQ00mmk>103ge/H40>o>]@@0klJ]103_c[D40>nmY@@0ikFD103W
]I`40>NeU0P0ikFL203N[I@40=jUS0@0eZF<203FW8@40<JLQ0@0]Hac102ULeX407=:@P@0DS4Y1@0i
:B44034Q60@0<B4Q100Y61P401P@40@0:APH101cBT8X0?Ogma00oooo000>0?ooob00moOg101cDTX4
06=2<@P0Je9:101J@ST4058a:@@0Hd8a1@1SBT8407]SDP@0Q5921036S7<40>o>]@P0mmJm103ge/H<
0?OF_@@0mmK6103ge[d40>o6[@@0kkfU203W[I@40>N]W0P0ikFL103WYH`40=j]U0P0gZF<103FYH`4
0=JLQ0@0cYAk102eS7<40:EcFP@0LdY2101S@S44048Y8@D0>BTQ1012:B44034Q8@P0:APH101B<BT4
0?ooobP0moOg403oool000h0oooo803gmoL407=BBP@0Hd8a201[DTX405Y2>@@0DS4Y101S@S4506=:
@P@0Nf=B1024DT840<J<L`@0klje203ge[d40?OFaP`0mmJm103ge/H40?OF_@@0klJ]103__JD80>N]
U0@0ijfL203W]I`40>NUS0@0gZfD203NYH`40=JUS0@0eYb4103>U7/40;F<L`@0YG=J101cBT8406=2
<@@0@RTQ1@0i:B44048Y8@@0<B4Q200Y61P4058a:@@0oooo:03gmoL@0?ooo`003P3ooolP0?Ogm`@0
Le9:101S@S4806]BBP@0FT8i101B<BT406=2<@D0HdY2101kHe8408AB@P@0aXac103_c[D80?OF_@@0
mmK6303ge[d40?OFaP@0mmJm103_aZd40>nmY@P0ijfD103W[I`80>NeW0@0ijF<103N[I@80=jUS0@0
eZF<103FW8@40<jDN`@0]Hac102ULeX407=:@P@0Hd8a1012:B4503TY8@@0@RTQ100a8B4802TH60@0
DS4Y103ooolX0?Ogma00oooo000>0?ooob00moOg101cDTX406=2<@P0Je9:101J@ST4058a:@@0Hd8a
1@1SBT8407]SDP@0Q5921036S7<40>o>]@P0mmJm103ge/H<0?OF_@@0mmK6103ge[d40>o6[@@0kkfU
203W[I@40>N]W0P0ikFL103WYH`40=j]U0P0gZF<103FYH`40=JLQ0@0cYAk102eS7<40:EcFP@0LdY2
101S@S44048Y8@D0>BTQ1012:B44034Q8@P0:APH101B<BT40?ooobP0moOg403oool000h0oooo803g
moL408acJ`P0HdY2101cDTX406=2<@@0FT8i101B>C4506=:@P@0FT8i101[DTX40:EcFP@0eZF4203_
c[D<0?OF_@P0klje103ge[d40>nmY@@0ijfD103W]I@40=jUS0P0gZfD103W[I@80=jUS0@0gYb<103F
YH`40=JUQ0@0cYAk1036U7/40:f4J`@0Q592101S@S44048Y8@@0<B4H1@0a8B44048Y8@@0<B4Q100Q
410402TH60@0DS4Y;03gmoL@0?ooo`003P3ooolP0?Ogm`@0S7=[201SBT8407=BBP@0Hd8a101J@ST4
058i<@D0HdY2101J@ST406]BBP@0YG=J103FYH@80>o>]@`0mmJm203_c[D40?OF_@@0kkfU103W[I@4
0>NeU0@0gZF<203N[I@40>N]U0P0gZF<103NW8`40=JUS0@0eZF4103>U7/40<JDN`@0[HA[1024DT84
06=2<@@0@RTQ100a8AP5034Q8@@0@RTQ100a8B44024@40@0:APH101B<BT/0?Ogma00oooo000>0?oo
ob00moOg102<Lf/806=:@P@0Le9:101S@S4405Y2>@@0DSTa1@1SBT8405Y2>@@0Je9:102ULeX40=JU
Q0P0klje303ge[d80>o>]@@0mmJm103__JD40>N]U0@0ikFD103NYH`80=j]U0@0ijfD203NYH`40=jL
S0@0eZF<103FYH@40<jDN`@0aYAk102]Q6/408AB@P@0Hd8a1012:B44034Q60D0<B4Q1012:B44034Q
8@@08A0@100Y61P4058a:B`0moOg403oool000h0oooo803gmoL408acJ`P0HdY2101cDTX406=2<@@0
FT8i101B>C4506=:@P@0FT8i101[DTX40:EcFP@0eZF4203_c[D<0?OF_@P0klje103ge[d40>nmY@@0
ijfD103W]I@40=jUS0P0gZfD103W[I@80=jUS0@0gYb<103FYH`40=JUQ0@0cYAk1036U7/40:f4J`@0
Q592101S@S44048Y8@@0<B4H1@0a8B44048Y8@@0<B4Q100Q410402TH60@0DS4Y;03gmoL@0?ooo`00
3P3ooolP0?Ogm`@0S7=S201[DTX806=:@P@0BS4a101B>C4505Y2>@@0Je9:101S@S4407=:>@@0[HA[
103FYH`40>NeW0P0klJ]203_c[D80>o6[@@0ikfU303NYH`40=jLQ0`0gZF<203FW8@40<jDN`@0aYAk
102eS7<40:EcFP@0W6]B101S@S44048Y8@@0>BTQ100a8AP902TH60P0610@101B<BT406<i:B`0moOg
403oool000h0oooo803gmoL408acH`P0Je9:201SBT8404Xa<@@0DSTa1@1J@ST406]BBP@0Hd8a101c
BST40:f4J`@0eZF<103W]I`80>o6[@P0klje203_aZd40>NmY@`0gZF<103NW8@<0=jUS0P0eYb4103>
U7/40<JDN`@0]Hac102ULeX409a[DP@0Hd8a1012:B4403TY8@@0<B4H2@0Y61P801P@40@0DS4Y101S
>BT/0?Ogma00oooo000>0?ooob00moOg102<Lf<806]BBPP0HdY2101:<C44058i<@D0FT8i101[DTX4
06=2<@@0LdXi102]Q6/40=JUS0@0ikFL203_aZd80>o>]@P0klJ]103W_JD<0=jUS0@0gYb4303NYH`8
0=JLQ0@0cYAk1036U7/40;F<L`@0YG=J102LJe8406=2<@@0@RTQ100i:B44034Q60T0:APH200H4104
058a:@@0HcTY;03gmoL@0?ooo`003P3ooolP0?Ogm`@0S7=S201[DTX806=:@P@0BS4a101B>C4505Y2
>@@0Je9:101S@S4407=:>@@0[HA[103FYH`40>NeW0P0klJ]203_c[D80>o6[@@0ikfU303NYH`40=jL
Q0`0gZF<203FW8@40<jDN`@0aYAk102eS7<40:EcFP@0W6]B101S@S44048Y8@@0>BTQ100a8AP902TH
60P0610@101B<BT406<i:B`0moOg403oool000h0oooo803gmoL40<jmaP@0Le9:101[DTX406=:@P@0
LeYB101S@S44058a:@D0Je9:101J@ST406]BBP@0DSTa101kHe8408ASDP@0]G]S103N[I@40=JUS0P0
g[FU103N]I`40>NmY@@0eZF<102eQ6/40;f4J`@0cXa[203FW8@40=J<L`@0eYb4103FW7<40<jDN`@0
aXac102mQ6/40:f4J`@0S5Y:101c@S44058a:@@0@RTQ100a8AP902TH60@08A0@100H410402TH60@0
@RTQ103_inL/0?Ogma00oooo000>0?ooob00moOg103>_LH407=BBP@0Je9:101SBT8407=JDP@0Hd8a
101B<BT506]BBP@0FT8i101[DTX4058i<@@0Nf=B1024He840;EkH`@0gZfD103FYH`80=jeY@@0g[FL
103W_JD40=JUS0@0]HA[102mQ6/40<j<J`P0eYb4103FS7<40=JLQ0@0eYac103>U7/40<J<L`@0_HA[
102]Q6/408aJBP@0Ld8a101B<BT4048Y8@@0<B4H2@0Y61P4024@40@0610@100Y61P4048Y8@@0knOW
;03gmoL@0?ooo`003P3ooolP0?Ogm`@0c[g6101cDTX406]BBP@0HdY2101cFU8406=2<@@0DS4Y1@1[
DTX405Y2>@@0Je9:101B>C4407]SDP@0Q6=B102eNf<40=j]U0@0eZF<203N]JD40=jeW0@0ikfU103F
YH`40;F4J`@0_HA[103>S6/80=JLQ0@0eXac103FW8@40=JLL`@0cYAk1036S7<40;f4J`@0[HA[102<
FTX407=2<@@0DS4Y1012:B44034Q60T0:APH100Q410401P@40@0:APH1012:B440>oWib`0moOg403o
ool000h0oooo803gmoL40<jmaP@0Le9:101[DTX406=:@P@0LeYB101S@S44058a:@D0Je9:101J@ST4
06]BBP@0DSTa101kHe8408ASDP@0]G]S103N[I@40=JUS0P0g[FU103N]I`40>NmY@@0eZF<102eQ6/4
0;f4J`@0cXa[203FW8@40=J<L`@0eYb4103FW7<40<jDN`@0aXac102mQ6/40:f4J`@0S5Y:101c@S44
058a:@@0@RTQ100a8AP902TH60@08A0@100H410402TH60@0@RTQ103_inL/0?Ogma00oooo000>0?oo
ob00moOg103>_LH407=BBP@0Je9:101SBT8407=JDP@0Hd8a101B<BT506]BBP@0FT8i101[DTX4058i
<@@0Nf=B1024He840;EkH`@0gZfD103FYH`80=jeY@@0g[FL103W_JD40=JUS0@0]HA[102mQ6/40<j<
J`P0eYb4103FS7<40=JLQ0@0eYac103>U7/40<J<L`@0_HA[102]Q6/408aJBP@0Ld8a101B<BT4048Y
8@@0<B4H2@0Y61P4024@40@0610@100Y61P4048Y8@@0knOW;03gmoL@0?ooo`003P3ooolT0?Ogm`@0
Q6]J101J@ST806=:@P@0DT8i101:<C4506=2<@@0HdY2101cFU8406]BBP@0HdY2101cFU8408aSDP@0
W6]B102DLf/408acH`@0YG=J202eS7<409acH`@0W6]B102DHdX40:EcDP@0]G=J102mQ6<40<j<J`@0
_HA[102]LeX40;EcFP@0]G]S102LLf<408aJBP@0Ld8a101J<BT4048Y8@@0<B4H100Y61P4024@40d0
610@100i:B44058a:C00moOg403oool000h0oooo903gmoL408A[FP@0FT8i201SBT840592>@@0BS4a
1@1S@S4406=:@P@0LeYB101[DTX406=:@P@0LeYB102<He8409a[DP@0U7=[102<Lf<40:EcFPP0]Hac
102LLf<409a[DP@0U6=:102ULe840;EcFP@0_HAS103>S6/40;f4J`@0[G=J102eLeX40;EkH`@0W7=S
102<FTX407=2<@@0FS4Y1012:B44034Q60@0:APH100Q410=01P@40@0>BTQ101B<BT`0?Ogma00oooo
000>0?ooob@0moOg1024JeX405Y2>@P0HdY2101B@ST404Xa<@D0Hd8a101SBT8407=JDP@0Je9:101S
BT8407=JDP@0S6=B102LJe8409AcJ`@0S7=S102ULeX80;F<L`@0W7=S102LJe8409ASBP@0YG=B102e
LeX40;f4H`@0cXa[102mQ6/40:ecFP@0]G=J102eNf<409acH`@0S5Y:101c@S4405Xa:@@0@RTQ100a
8AP402TH60@08A0@3@0H410403TY8@@0DS4Y<03gmoL@0?ooo`003P3ooolT0?Ogm`@0Q6]J101J@ST8
06=:@P@0DT8i101:<C4506=2<@@0HdY2101cFU8406]BBP@0HdY2101cFU8408aSDP@0W6]B102DLf/4
08acH`@0YG=J202eS7<409acH`@0W6]B102DHdX40:EcDP@0]G=J102mQ6<40<j<J`@0_HA[102]LeX4
0;EcFP@0]G]S102LLf<408aJBP@0Ld8a101J<BT4048Y8@@0<B4H100Y61P4024@40d0610@100i:B44
058a:C00moOg403oool000h0oooo903gmoL40:fLY@@0HdY2101[DTX406=BBP@0HdY2100i:B4505Y2
>@P0LeYB201kHeX808A[FP@0Nf=B101cDTX407=:>@@0LdY21024DT8408aSDPP0Le9:1024DT8408AB
>@@0Q592202LJe8409ASBP@0W6]B102<FT8408aSDP@0Q592101cBST4058a:@@0DSTa200a8AP402TH
60@08A0@2@0H4104048Y8@@0<B4Q102]S8@`0?Ogma00oooo000>0?ooob@0moOg102]W:D406=:@P@0
Je9:101SDTX406=:@P@0>BTQ1@1J@ST807=JDPP0Nf=J2024JeX407]SDP@0Le9:101cBST407=:@P@0
Q592102<He8807=BBP@0Q5921024DST408AB@PP0W6]B102DHdX409a[DP@0S5Y2102<He8408AB@P@0
LdXi101B<BT4058i<@P0<B4H100Y61P4024@40T0610@1012:B44034Q8@@0[Hb4<03gmoL@0?ooo`00
3P3ooolT0?Ogm`@0[IbU101SBT8406]BBP@0He9:101SBT8403TY8@D0FT8i201cFU8807]SFPP0Q6]J
101kHe8407=BBP@0LdXi101cBT8408AB@P@0S6=B201cDTX408AB@P@0Q58i1024DT8809a[DP@0U6=:
102LJe8408aJ@P@0S6=B1024DT8407=:>@@0DS4Y101B>C48034Q60@0:APH100Q410901P@40@0@RTQ
100a8B440:f<Q300moOg403oool000h0oooo903gmoL40:fLY@@0HdY2101[DTX406=BBP@0HdY2100i
:B4505Y2>@P0LeYB201kHeX808A[FP@0Nf=B101cDTX407=:>@@0LdY21024DT8408aSDPP0Le9:1024
DT8408AB>@@0Q592202LJe8409ASBP@0W6]B102<FT8408aSDP@0Q592101cBST4058a:@@0DSTa200a
8AP402TH60@08A0@2@0H4104048Y8@@0<B4Q102]S8@`0?Ogma00oooo000>0?ooob@0moOg103Wg^L4
07=BBQ00HdY21@1[DTX407=JDP@0Nf=J201[DTX407=:@P@0Q592101cBST406=:@P@0DSTa101SBT84
058a:@P0HdY2101J@ST4058a:@@0DSTa101B<BT405Xa:@`0Hd8a201J<BT8058a:@@0>BTQ100a8AP<
02TH60T0610@1012:C44048Y8@@0HdY2=03gmoL@0?ooo`003P3ooolT0?Ogm`@0imkW101cDTX@06=:
@PD0Je9:101cFU8407]SFPP0Je9:101cBT8408AB@P@0LdXi101SBT84058i<@@0HdY2101B<BT806=:
@P@0FT8i101B<BT4058i<@@0DS4Y101J<BT<06=2<@P0FS4Y201B<BT403TY8@@0<B4H300Y61P901P@
40@0@RTa1012:B4406=:@S@0moOg403oool000h0oooo903gmoL40>ONi`@0Le9:401SBT8506]BBP@0
LeYB101kHeX806]BBP@0LdY21024DT8407=:>@@0HdY2101B>C4406=:@P@0DS4Y201SBT8405Y2>@@0
DS4Y101B>C44058a:@@0FS4Y301S@S4805Xa:@P0DS4Y100i:B44034Q60`0:APH2@0H4104048Y<@@0
@RTQ101SBT8d0?Ogma00oooo000>0?ooob@0moOg103Wg^L407=BBQ00HdY21@1[DTX407=JDP@0Nf=J
201[DTX407=:@P@0Q592101cBST406=:@P@0DSTa101SBT84058a:@P0HdY2101J@ST4058a:@@0DSTa
101B<BT405Xa:@`0Hd8a201J<BT8058a:@@0>BTQ100a8AP<02TH60T0610@1012:C44048Y8@@0HdY2
=03gmoL@0?ooo`003P3ooolX0?Ogm`@0]JFU201SBT8406]BBP@0HdY21@1kHeX405Y2>@@0LeYB101J
@ST406]BBP@0Q6=B101[DTX806=:@P@0FT8i101cDTX404Xa<@@0DT8i201B<BT4048Y8@@0>BTQ1012
:B48058a:@`0@RTQ101B<BT8048Y8@P0<B4H200Y61P801P@40D0:APH101B>C44058a:CP0moOg403o
ool000h0oooo:03gmoL40;FUY@P0HdY2101[DTX406=:@PD0Nf=J101J@ST407=JDP@0FT8i101[DTX4
08ASDP@0Je9:201SBT8405Y2>@@0Le9:101:<C440592>@P0DS4Y1012:B4403TY8@@0@RTQ201B<BT<
048Y8@@0DS4Y2012:B48034Q60P0:APH200H410502TH60@0DSTa101B<BTh0?Ogma00oooo000>0?oo
obP0moOg102eYJD806=:@P@0Je9:101SBT8507]SFP@0FT8i101cFU8405Y2>@@0Je9:1024He8406]B
BPP0HdY2101J@ST407=BBP@0BS4a101B@ST8058a:@@0@RTQ100i:B44048Y8@P0DS4Y3012:B44058a
:@P0@RTQ200a8AP802TH60P0610@1@0Y61P4058i<@@0DS4Y>03gmoL@0?ooo`003P3ooolX0?Ogm`@0
]JFU201SBT8406]BBP@0HdY21@1kHeX405Y2>@@0LeYB101J@ST406]BBP@0Q6=B101[DTX806=:@P@0
FT8i101cDTX404Xa<@@0DT8i201B<BT4048Y8@@0>BTQ1012:B48058a:@`0@RTQ101B<BT8048Y8@P0
<B4H200Y61P801P@40D0:APH101B>C44058a:CP0moOg403oool000h0oooo:03gmoL40=k>eP@0LdY2
201[DTX406=:@PD0DT8i101cFU8407]SFP@0He9:101J@ST407=:>@@0DSTa201J@ST4048a>@@0DT8i
101:<C44058a:@@0@RTa200i:B44034Q60`0>BTQ100a8AP402TH60@0<B4H1012:B44034Q60@0:APH
100a8AP4034Q8@@0:APH100H410402TH60@0>BTQ1@1B>C44058a:C`0moOg403oool000h0oooo:03g
moL40=k>eP@0LdY2201[DTX406=:@PD0DT8i101cFU8407]SFP@0He9:101J@ST407=:>@@0DSTa201J
@ST4048a>@@0DT8i101:<C44058a:@@0@RTa200i:B44034Q60`0>BTQ100a8AP402TH60@0<B4H1012
:B44034Q60@0:APH100a8AP4034Q8@@0:APH100H410402TH60@0>BTQ1@1B>C44058a:C`0moOg403o
ool000h0oooo:03gmoL40=k>eP@0LdY2201[DTX406=:@PD0DT8i101cFU8407]SFP@0He9:101J@ST4
07=:>@@0DSTa201J@ST4048a>@@0DT8i101:<C44058a:@@0@RTa200i:B44034Q60`0>BTQ100a8AP4
02TH60@0<B4H1012:B44034Q60@0:APH100a8AP4034Q8@@0:APH100H410402TH60@0>BTQ1@1B>C44
058a:C`0moOg403oool000h0oooo:03gmoL40=k>eP@0LdY2201[DTX406=:@PD0DT8i101cFU8407]S
FP@0He9:101J@ST407=:>@@0DSTa201J@ST4048a>@@0DT8i101:<C44058a:@@0@RTa200i:B44034Q
60`0>BTQ100a8AP402TH60@0<B4H1012:B44034Q60@0:APH100a8AP4034Q8@@0:APH100H410402TH
60@0>BTQ1@1B>C44058a:C`0moOg403oool000h0oooo;03gmoL409AkL`@0HdY2101[DTX406=:@PD0
Je9:101SDTX406]BBP@0FT8i201B>C44048Y8@@0FT8i201:<C44048Y8@@0@RTa100a8B4402TH60P0
<B4Q100Y61P4034Q8@@0:APH100a8B4402TH60@0<B4Q100i:B44034Q8@@0:APH400H4104034Q8@@0
<B4H100Y61P5048Q60@0knOW?03gmoL@0?ooo`003P3oool/0?Ogm`@0U7]c101SBT8406]BBP@0HdY2
1@1[DTX406=BBP@0Je9:101J@ST8058i<@@0@RTQ101J@ST804Xa<@@0@RTQ1012:C44034Q8@@0:APH
200a8B4402TH60@0<B4Q100Y61P4034Q8@@0:APH100a8B4403TY8@@0<B4Q100Y61P@01P@40@0<B4Q
100a8AP402TH60D0@R4H103_inLl0?Ogma00oooo000>0?ooob`0moOg102DNg<406=:@P@0Je9:101S
BT8506]BBP@0He9:101[DTX405Y2>@P0DSTa1012:B4405Y2>@P0BS4a1012:B44048Y<@@0<B4Q100Y
61P8034Q8@@0:APH100a8B4402TH60@0<B4Q100Y61P4034Q8@@0>BTQ100a8B4402TH6100610@100a
8B44034Q60@0:APH1@128AP40>oWic`0moOg403oool000h0oooo;03gmoL409AkL`@0HdY2101[DTX4
06=:@PD0Je9:101SDTX406]BBP@0FT8i201B>C44048Y8@@0FT8i201:<C44048Y8@@0@RTa100a8B44
02TH60P0<B4Q100Y61P4034Q8@@0:APH100a8B4402TH60@0<B4Q100i:B44034Q8@@0:APH400H4104
034Q8@@0<B4H100Y61P5048Q60@0knOW?03gmoL@0?ooo`003P3oool`0?Ogm`@0U7]c101J@ST406=:
@PT0He9:101cFU8406=:BP@0DS4Y101B>C4403TY8@@0@RTQ100i:B44048Y8@P0:APH200a8B4402TH
60@0<B4Q100Y61P4034Q8@@0:APH101B<BT401P@40@0<B4Q100i:B44034Q8@P0610@100Q410<034Q
8@@0DS4Y101S@S450:EcFT00moOg403oool000h0oooo<03gmoL409AkL`@0FT8i101SBT8906=BBP@0
LeYB101SBTX4058a:@@0DSTa100i:B44048Y8@@0>BTQ1012:B4802TH60P0<B4Q100Y61P4034Q8@@0
:APH100a8B4402TH60@0DS4Y100H4104034Q8@@0>BTQ100a8B4801P@40@08A0@300a8B44058a:@@0
Hd8a1@2ULeY00?Ogma00oooo000>0?oooc00moOg102DNg<405Y2>@@0HdY22@1SDTX407=JDP@0HdY:
101B<BT4058i<@@0>BTQ1012:B4403TY8@@0@RTQ200Y61P8034Q8@@0:APH100a8B4402TH60@0<B4Q
100Y61P4058a:@@0610@100a8B4403TY8@@0<B4Q200H4104024@40`0<B4Q101B<BT406=2<@D0YG=J
@03gmoL@0?ooo`003P3oool`0?Ogm`@0U7]c101J@ST406=:@PT0He9:101cFU8406=:BP@0DS4Y101B
>C4403TY8@@0@RTQ100i:B44048Y8@P0:APH200a8B4402TH60@0<B4Q100Y61P4034Q8@@0:APH101B
<BT401P@40@0<B4Q100i:B44034Q8@P0610@100Q410<034Q8@@0DS4Y101S@S450:EcFT00moOg403o
ool000h0oooo=03gmoL409AcJ`@0He9:1@1J@ST<07=JDP@0DT8i101J@ST4048Y<@@0<B4Q1012:B44
034Q8@P0>BTQ100a8B4D02TH60@0>BTQ100a8B4405YBH`@0FU9B1012:C4402TH60@0<B4Q200i:B44
034Q8@@0FT8i101B>C44058a:@@0S5Y:A@3gmoL@0?ooo`003P3ooold0?Ogm`@0U7=[101SDTX505Y2
>@`0LeYB101B@ST405Y2>@@0@RTa100a8B44048Y8@@0<B4Q200i:B44034Q8A@0:APH100i:B44034Q
8@@0FU9S101JDU84048Y<@@0:APH100a8B4803TY8@@0<B4Q101J@ST4058i<@@0DS4Y102<FTY50?Og
ma00oooo000>0?oooc@0moOg102DLf/406=BBPD0FT8i301cFU840592>@@0FT8i1012:C44034Q8@@0
@RTQ100a8B4803TY8@@0<B4Q500Y61P403TY8@@0<B4Q101JDV<405YBDP@0@RTa100Y61P4034Q8@P0
>BTQ100a8B4405Y2>@@0DSTa101B<BT408aJBTD0moOg403oool000h0oooo=03gmoL409AcJ`@0He9:
1@1J@ST<07=JDP@0DT8i101J@ST4048Y<@@0<B4Q1012:B44034Q8@P0>BTQ100a8B4D02TH60@0>BTQ
100a8B4405YBH`@0FU9B1012:C4402TH60@0<B4Q200i:B44034Q8@@0FT8i101B>C44058a:@@0S5Y:
A@3gmoL@0?ooo`003P3ooold0?Ogm`@0oooo102DLf/507=JDP@0FT8i101SDTX407]SFP@0LeYB101S
@S44058i<@@0>BTQ100a8B4402TH60@0<B4H100a8B4802TH60@0<B4Q100Y61P4034Q8@P0:APH101J
DU84058iBPP0Nf=J101SBTX407=JDP@0FT8i100i:B48058i<@@0Je9:1024DT840?O_kdD0moOg403o
ool000h0oooo=03gmoL40?ooo`@0U7=[1@1cFU8405Y2>@@0He9:101kHeX407=JDP@0Hd8a101B>C44
03TY8@@0<B4Q100Y61P4034Q60@0<B4Q200Y61P4034Q8@@0:APH100a8B4802TH60@0FU9B101B>DX8
07]SFP@0HdY:101cFU8405Y2>@@0>BTQ201B>C4406]BBP@0Q592103gknm50?Ogma00oooo000>0?oo
oc@0moOg103oool409AcJ`D0LeYB101J@ST406=BBP@0Nf=J101cFU8406=2<@@0DSTa100i:B44034Q
8@@0:APH100a8AP4034Q8@P0:APH100a8B4402TH60@0<B4Q200Y61P405YBDP@0DSU:201kHeX406=:
BP@0LeYB101J@ST403TY8@P0DSTa101[DTX408AB@P@0mno_A@3gmoL@0?ooo`003P3ooold0?Ogm`@0
oooo102DLf/507=JDP@0FT8i101SDTX407]SFP@0LeYB101S@S44058i<@@0>BTQ100a8B4402TH60@0
<B4H100a8B4802TH60@0<B4Q100Y61P4034Q8@P0:APH101JDU84058iBPP0Nf=J101SBTX407=JDP@0
FT8i100i:B48058i<@@0Je9:1024DT840?O_kdD0moOg403oool000h0oooo?03gmoL508aSDP@0Nf=J
101[DTX<07]SFPP0DSTa101SBT840592>@@0@RTQ100i:B48034Q8@P0:APH100i:C44034Q8@@0>BTQ
100a8B440592>@@0HdY2100a8B4803TY8@@0<B4Q1012:B44058i<@@0Hd8a102LJe840=k>eTT0moOg
403oool000h0oooo?03gmoL508aSDP@0Nf=J101[DTX<07]SFPP0DSTa101SBT840592>@@0@RTQ100i
:B48034Q8@P0:APH100i:C44034Q8@@0>BTQ100a8B440592>@@0HdY2100a8B4803TY8@@0<B4Q1012
:B44058i<@@0Hd8a102LJe840=k>eTT0moOg403oool000h0oooo?03gmoL508aSDP@0Nf=J101[DTX<
07]SFPP0DSTa101SBT840592>@@0@RTQ100i:B48034Q8@P0:APH100i:C44034Q8@@0>BTQ100a8B44
0592>@@0HdY2100a8B4803TY8@@0<B4Q1012:B44058i<@@0Hd8a102LJe840=k>eTT0moOg403oool0
00h0oooo?03gmoL508aSDP@0Nf=J101[DTX<07]SFPP0DSTa101SBT840592>@@0@RTQ100i:B48034Q
8@P0:APH100i:C44034Q8@@0>BTQ100a8B440592>@@0HdY2100a8B4803TY8@@0<B4Q1012:B44058i
<@@0Hd8a102LJe840=k>eTT0moOg403oool000h0oooo@@3gmoL408acH`@0FT8i101[DTX408acJ`@0
S7]c101kHeX4058i<@@0BS4a101B<BT406=:@P@0DT8i100a8B4402TH60P0@S4i101B@ST4048a>@@0
Je9:100i:C4407]SFP@0HdY:201SBT8405Y2>@@0HdY2101kHe8406=:@P@0YG=J103gknm=0?Ogma00
oooo000>0?oood40moOg102<Lf<405Y2>@@0Je9:102<Lf/408akL`@0Nf=J101B>C4404Xa<@@0DS4Y
101SBT840592>@@0<B4Q100Y61P8048a>@@0DT8i1012<CT406]BBP@0>BTa101kHeX406=:BPP0HdY2
101J@ST406=:@P@0Nf=B101SBT840:EcFP@0mno_C@3gmoL@0?ooo`003P3ooom10?Ogm`@0S7=S101J
@ST406]BBP@0S7=[102<Ng<407]SFP@0DSTa101:<C44058a:@@0HdY2101B@ST4034Q8@@0:APH2012
<CT40592>@@0@S4i101[DTX403TY<@@0Nf=J101SBTX806=:@P@0FT8i101SBT8407]SDP@0HdY2102U
LeX40?O_kdd0moOg403oool000h0oooo@@3gmoL408acH`@0FT8i101[DTX408acJ`@0S7]c101kHeX4
058i<@@0BS4a101B<BT406=:@P@0DT8i100a8B4402TH60P0@S4i101B@ST4048a>@@0Je9:100i:C44
07]SFP@0HdY:201SBT8405Y2>@@0HdY2101kHe8406=:@P@0YG=J103gknm=0?Ogma00oooo000>0?oo
odD0moOg103Fa/h407]SFP@0Je9:101cFU8407]cN`P0S7=[102<Ng<406=:BP@0FU9B101kJg/408ak
L`@0HdY:101JBUX406=:BP@0Nf]k101[DTX406=:@P@0LeYB101cDTX407=:@P@0LdXi101[DTX408AS
DP@0YG=J101cBSUE0?Ogma00oooo000>0?ooodD0moOg103Fa/h407]SFP@0Je9:101cFU8407]cN`P0
S7=[102<Ng<406=:BP@0FU9B101kJg/408akL`@0HdY:101JBUX406=:BP@0Nf]k101[DTX406=:@P@0
LeYB101cDTX407=:@P@0LdXi101[DTX408ASDP@0YG=J101cBSUE0?Ogma00oooo000>0?ooodD0moOg
103Fa/h407]SFP@0Je9:101cFU8407]cN`P0S7=[102<Ng<406=:BP@0FU9B101kJg/408akL`@0HdY:
101JBUX406=:BP@0Nf]k101[DTX406=:@P@0LeYB101cDTX407=:@P@0LdXi101[DTX408ASDP@0YG=J
101cBSUE0?Ogma00oooo000>0?ooodD0moOg103Fa/h407]SFP@0Je9:101cFU8407]cN`P0S7=[102<
Ng<406=:BP@0FU9B101kJg/408akL`@0HdY:101JBUX406=:BP@0Nf]k101[DTX406=:@P@0LeYB101c
DTX407=:@P@0LdXi101[DTX408ASDP@0YG=J101cBSUE0?Ogma00oooo000>0?ooodd0moOg102<Lg/4
07]SFP@0Jf=[102LS8`409B4Q0P0S7]c102DQ8@409AkL`@0S7=[101cFU8407]SFP@0HdY:101J@ST4
06=:@P@0LeYB101[DTX408AB@P@0S5Y:102<He8409acH`@0Q592102UQ8AI0?Ogma00oooo000>0?oo
odd0moOg102<Lg/407]SFP@0Jf=[102LS8`409B4Q0P0S7]c102DQ8@409AkL`@0S7=[101cFU8407]S
FP@0HdY:101J@ST406=:@P@0LeYB101[DTX408AB@P@0S5Y:102<He8409acH`@0Q592102UQ8AI0?Og
ma00oooo000>0?ooodd0moOg102<Lg/407]SFP@0Jf=[102LS8`409B4Q0P0S7]c102DQ8@409AkL`@0
S7=[101cFU8407]SFP@0HdY:101J@ST406=:@P@0LeYB101[DTX408AB@P@0S5Y:102<He8409acH`@0
Q592102UQ8AI0?Ogma00oooo000>0?ooodd0moOg102<Lg/407]SFP@0Jf=[102LS8`409B4Q0P0S7]c
102DQ8@409AkL`@0S7=[101cFU8407]SFP@0HdY:101J@ST406=:@P@0LeYB101[DTX408AB@P@0S5Y:
102<He8409acH`@0Q592102UQ8AI0?Ogma00oooo000>0?ooo`@0mno_D@3gmoL40>ONi`@0S7^<102]
U9@40<JeaP@0]IbL102UQ7/809AkL`@0YHB4102UQ7/409AkL`@0YHAk102<Lf<409AkL`@0YHAk202<
Lf<407=BBP@0c[FmH@3gmoL@0?ooo`003P3oool40?O_ke40moOg103Wg^L408akS0@0[IBD1036]LH4
0;FLW0@0YHAk202DNg<40:F4Q0@0YHAk102DNg<40:F4N`@0S7=S102DNg<40:F4N`P0S7=S101cDTX4
0<je_F40moOg403oool000h0oooo103gknmA0?Ogm`@0imkW102<Nh`40:fDU0@0a[G6102eW9`40:F4
N`P0U7]c102UQ8@40:F4N`@0U7]c102UQ7/408acH`@0U7]c102UQ7/808acH`@0Le9:103>]KeQ0?Og
ma00oooo000>0?ooo`@0mno_D@3gmoL40>ONi`@0S7^<102]U9@40<JeaP@0]IbL102UQ7/809AkL`@0
YHB4102UQ7/409AkL`@0YHAk102<Lf<409AkL`@0YHAk202<Lf<407=BBP@0c[FmH@3gmoL@0?ooo`00
3P3ooomU0?Ogm`@0imk_103gknl40=K6ePP0W8bL402DNg<408acJ`@0Q6=B1024JeX40?O_kfT0moOg
403oool000h0ooooI@3gmoL40>ONk`@0mno_103Fa]H809b<W100U7]c102<Lf/408ASDP@0Q6]J103g
knmY0?Ogma00oooo000>0?ooofD0moOg103Wg^l40?O_k`@0e/KF202LS9`@09AkL`@0S7=[1024He84
08A[FP@0mno_J@3gmoL@0?ooo`003P3ooomU0?Ogm`@0imk_103gknl40=K6ePP0W8bL402DNg<408ac
J`@0Q6=B1024JeX40?O_kfT0moOg403oool000h0ooooO@3gmoL40?O_kh40moOg403oool000h0oooo
O@3gmoL40?O_kh40moOg403oool000h0ooooO@3gmoL40?O_kh40moOg403oool000h0ooooO@3gmoL4
0?O_kh40moOg403oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00380oooo0T00000]0?ooo`900000
=@3oool2@00001H0oooo0d00000h0?ooo`900000<`3oool003@0oooo00=000000?ooo`3oool0;03o
ool00d000000oooo0?ooo`0c0?ooo`03@000003oool0oooo01D0oooo00=000000?ooo`3oool0>@3o
ool00d000000oooo0?ooo`0`0?ooo`009P3oool3@00000<0oooo0d0000030?ooo`=000001@3oool0
0d000000oooo0?ooo`05@00000040?oood0000100000@00000H0oooo00=000000?ooo`3oool00`3o
ool2@0000080oooo0d0000020?ooo`=000000`3oool3@00000050?oood0000100000@000003oool0
0T0000020?ooo`03@000003ooom0000000=0000000@0oooo@0000400001000002P3oool2@00000@0
oooo0d0000080?ooo`A000000`3oool00d000000oooo0?ooo`090?ooo`900000103oool3@00000<0
oooo0d0000020?ooo`=000000P3oool01D000000oooo0?oood000000oooo00=000000`3oool2@000
0080oooo0T00000?0?ooo`=0000000L0oooo@000003ooom000000?oood000000oooo00A000000P3o
ool3@0000080oooo0T00000^0?ooo`009`3oool00d000000oooo0?ooo`030?ooo`05@000003oool0
oooo0?oood0000000P3oool00d000000oooo0?ooo`080?ooo`05@000003oool0oooo0?oood000000
3@3oool014000000oooo0?oood0000020?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo00E000000?ooo`3ooom000000?oo
o`03@00000<0oooo00=000000?ooo`3oool02@3oool00d000000oooo@00000040?ooo`03@000003o
ool0oooo00P0oooo00Q000000?ooo`3ooom000000?oood000000oooo@00000X0oooo00=000000?oo
od000000103oool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo@0000080oooo00=00000
0?ooo`3oool00P3oool2@00000<0oooo00E000000?ooo`3oool0oooo@00000060?ooo`03@000003o
ool0oooo00d0oooo00U000000?ooo`3ooom000000?oood000000oooo@000003oool00d0000020?oo
o`06@000003oool0oooo@000003ooom00000<03oool002L0oooo00=000000?ooo`3oool00`3oool0
1D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool00d000000oooo0?oo
o`020?ooo`03@000003oool0oooo00X0oooo00A000000?ooo`3ooom000000P3oool00d000000oooo
0?ooo`020?ooo`05@000003oool0oooo0?oood0000000P3oool014000000oooo0?oood0000030?oo
o`04@000003oool0oooo@00000<0oooo00E000000?ooo`3oool0oooo@000000;0?ooo`03@000003o
oom000000080oooo140000090?ooo`08@000003oool0oooo@000003ooom000000?oood00000:0?oo
o`03@000003ooom000000080oooo140000030?ooo`04@000003oool0oooo@0000080oooo00=00000
0?ooo`3oool00P3oool2@00000<0oooo00A000000?ooo`3oool0oooo0d0000030?ooo`03@000003o
ool0oooo00h0oooo00Q000000?ooo`3ooom000000?oood000000oooo@00000<0oooo00A000000?oo
o`3ooom000000P3oool00d000000oooo@0000002@00002h0oooo000W0?ooo`9000000`3oool2@000
00@0oooo0d00000:0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool02P3oool01D00
0000oooo0?oood000000oooo00A0000000<0oooo@00004000000103oool3@00000030?oood000010
00000080oooo140000030?ooo`9000000`3oool00d000000oooo0?ooo`090?ooo`9000000`3oool0
0d000000oooo@000000:0?ooo`=0000000@0oooo@00004000000oooo0T0000090?ooo`9000000`3o
ool00d000000oooo@00000030?ooo`A000000P3oool2@00000<0oooo00A000000?ooo`3ooom00000
0P3oool014000000oooo0?ooo`3oool3@00000<0oooo0T00000>0?ooo`9000000P3oool2@0000003
0?oood000000oooo0080oooo0T0000030?ooo`=0000000@0oooo@000040000100000;P3oool002L0
oooo00A000000?ooo`3ooom00000503oool01d000000oooo0?ooo`3ooom000000?oood0000002`3o
ool014000000oooo0?oood00000P0?ooo`03@000003oool0oooo00T0oooo00=000000?ooo`3oool0
0`3oool2@00000X0oooo00=000000?ooo`3oool03`3oool00d000000oooo0?ooo`030?ooo`900000
503oool00d000000oooo0?ooo`1L0?ooo`009P3oool5@0000080oooo00=000000?ooo`3oool03P3o
ool2@00000@0oooo00=000000?ooo`3oool02`3oool2@00000P0oooo00=000000?ooo`3oool01`3o
ool00d000000oooo0?ooo`0;0?ooo`900000303oool2@00000@0oooo00=000000?ooo`3oool01`3o
ool2@0000180oooo0T0000040?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool01P3o
ool2@00001X0oooo00=000000?ooo`3oool0@@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-3.57762, -1.60033, 0.247927, 
  0.247927}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10],
  StyleBox[
  "We compute the source densities regarding the red, green and blue \
components as the scalar potentials. This is carried out by means of the \
function \[OpenCurlyDoubleQuote]laplace2D\[CloseCurlyDoubleQuote].",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["source=-Table[laplace2D[sampleL[[i]]],{i,dim[[1]]}];", "Input",
  CellLabel->"In[66]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "We solve the Poison's type partial differential equations to generate the \
128 by 128 and 256 by 256 resolution images. It must be noted that a large \
CPU time is required for generating a higher-resolution image. Further, \
because of the numerical errors, the solutions are essentially containing a \
little bit of errors. Normalize the solutions reduces the effects of \
numerical errors.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["\n\t",
    TextAlignment->Left,
    TextJustification->1],
  StyleBox[
  "The first 128 by 128 resolution image data are computed by a following \
simple command.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
sampleH1=Table[imageNormalize[poissonSOR2D[source[[i]],
\t{128,128}]],{i,dim[[1]]}];\
\>", "Input",
  CellLabel->"In[67]:="],

Cell[TextData[{
  "\t",
  StyleBox[
  "Higher-resolution image generation requires longer CPU time, because \
higher resolution image generation is reduced into solving a larger linear \
system of equations. must be noted that a high-resolution color image \
generation by differential equations essentially requires a relatively large \
CPU time. A ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " command \[OpenCurlyDoubleQuote]Timing\[CloseCurlyDoubleQuote] used bellow \
gives a required CPU time in second.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
sampleH2=Table[imageNormalize[poissonSOR2D[source[[i]],
\t{256,256}]],{i,dim[[1]]}];//Timing\
\>", "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \({1072.03000000000048`\ Second, Null}\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The normalized solutions are converted into the RGB color image data, and \
an original 128 by 128 resolution image data \
\[OpenCurlyDoubleQuote]AF-038-128.bmp\[CloseCurlyDoubleQuote] is read in a \
list \[OpenCurlyDoubleQuote]sampleH1C\[CloseCurlyDoubleQuote].",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
sample1G=Show[convertRGB[sampleH1],PlotLabel->\"Generated 128\[Times]128\",
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity];
sample1CG=Show[convertRGB[sampleH1C=rgbBMP[\"AF038-128.bmp\"]],
\tPlotLabel->\"Original\",AspectRatio->dim[[2]]/dim[[3]],
\tDisplayFunction->Identity];
sample2G=Show[convertRGB[sampleH2],PlotLabel->\"Generated 256\[Times]256\",
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity];
sample2CG=Show[convertRGB[sample],PlotLabel->\"Original\",
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity];\
\>", "Input",
  CellLabel->"In[69]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Figure 13 shows the obtained high-resolution images arranging with their \
original ones. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[{{sample1G,sample1CG},{sample2G,sample2CG}}],
\tPlotLabel->\"Fig.13. Original and generated images\",
\tImageSize->{450,450}];\
\>", "Input",
  CellLabel->"In[73]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 450 450 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[.5 1.0125 -113 0 ]
[.5 1.0125 113 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.13) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Original) show
165.000000 12.812500 moveto
(and) show
189.000000 12.812500 moveto
(generated) show
249.000000 12.812500 moveto
(images) show
285.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[.5 1.0125 -53 0 ]
[.5 1.0125 53 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Generated) show
123.000000 12.812500 moveto
(256) show
141.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(256) show
165.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math1Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
768 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
D1D1C9D9D7D0DAD8D1DAD8D0D9D7CFD8D6CED7D6CED7D6CFD7D7CFD7D7CFD7D7D0D8D7D0D8D7CF\
D8D7CFD8D6CFD8D6CED8D6CED8D6CED8D6CFD8D7CFD8D7CFD8D7CFD8D7D0D8D7D0
D8D7D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0\
D8D8D0D8D8D0D8D8D0D8D8D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7CFD8D7CFD8D6CFD8D6CF\
D8D6CFD8D6CFD8D7CFD8D7CFD8D7D0D8D7D0D8D7D0D8D8D0D8D8D0D8D8D0D8D8D0
D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D1D8D8D1D8D8D1D8D8D1D8D8D1D8D8D1D8D9D2\
D8D9D2D8DAD3D8DAD4D8DAD4D8DAD3D8D8D0D8D5CCD7D3C8D7D1C5D7D0C4D8D1C5
D8D1C6D8D2C7D8D2C8D8D3C8D8D3C8D8D3C9D8D3C9D8D4CAD8D5CBD8D5CBD8D5CBD8D4CAD8D3CA\
D8D3C9D8D3C9D8D3CAD8D4CBD8D5CBD8D5CCD8D6CCD8D6CCD8D5CCD8D5CBD8D5CB
D9D5CBD9D5CAD9D4CAD9D4CAD9D4C9D9D4C9D9D4C9D9D4C9D9D4C9D8D4C9D8D4C9D8D4C9D8D4C9\
D8D4C8D8D4C8D8D3C8D7D2C7D6D2C7D6D1C6D6D1C6D5D0C5D5CFC5D5CEC4D4CDC3
D4CDC2D4CCC2D4CBC1D4CCC2D4CCC2D4CCC2D4CCC2D4CCC2D3CBC1D2CBC1D2CBC1D2CCC1D3CCC2\
D4CDC3D4CDC3D4CEC4D5CEC4D5CEC4D5CEC4D5CEC4D5CEC4D5CEC4D5CEC4D5CEC4
D5CEC4D5CEC3D5CDC3D5CDC3D5CCC3D5CCC3D5CCC2D5CCC2D4CCC1D3CCC1D3CCC1D2CCC1D2CCC1\
D2CCC1D2CBC1D2CBC0D2CBBFD2CBBED1CABDD0C9BCD0C8BCCFC8BCCFC9BFD1CDC4
D3D2CAD6D7D0D8DBD5DADDD8DADED8DADDD7D9DBD5D9DAD3D9DAD3D8D9D2D8D9D2D8D9D2D8D9D1\
D8D9D1D8D9D1D8D9D1D8D9D1D8D9D1D8D8D1D8D8D1D8D8D0D8D7D0D8D7D0D8D7D0
D8D7D0D8D8D0D8D8D1D8D9D1D8D9D1D8D8D1D8D8D1D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0D8D8D0\
D8D8D0D8D8D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D7D7CFD7D7CFD7D7CFD7D7CFD7D7CFD8D7D0D9D8D0DAD9D2\
DADAD2D9D8D1D1D1CA
D9D7D0E5E2DAE9E4DCE8E3DBE7E2DAE5E1D9E4E1D9E4E2DAE4E3DBE5E4DCE5E4DCE5E4DCE5E4DB\
E5E3DBE5E2DAE5E1D9E5E1D9E5E1D9E5E2DAE5E3DBE5E3DBE5E4DCE5E4DCE5E4DC
E5E4DCE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DD\
E5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E3DBE5E2DAE5E2DA\
E5E1DAE5E2DAE5E3DBE5E3DCE5E4DCE5E4DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DD
E5E5DDE5E5DDE5E5DDE5E5DDE5E5DEE5E5DEE5E5DEE5E5DEE5E6DEE5E6DEE5E6DFE5E6DFE5E7E0\
E6E7E1E6E8E3E6E9E4E6E9E4E6E8E2E6E5DDE6E2D8E6DED2E6DBCDE6DACCE6DACC
E6DBCEE6DCD0E6DCD0E6DCD0E6DDD0E6DDD0E6DED1E6DFD3E6E0D4E6E1D5E6E0D5E6DFD4E6DED3\
E6DDD2E6DDD2E6DED3E6DFD4E6E1D6E6E2D7E6E2D7E6E2D7E6E2D6E6E1D6E7E1D5
E7E0D4E7E0D3E8DFD2E8DFD1E8DFD0E8DED0E8DED0E7DED0E6DED1E6DED1E6DED1E6DFD1E6DED1\
E6DED0E5DED0E5DDCFE4DCCEE3DACEE1D9CDE1D8CCE0D7CBDFD6C9DFD4C8DED3C7
DED2C6DED1C5DED0C5DED0C5DFD1C5DFD1C6DED1C6DDD1C5DCD0C5DCD0C4DBD0C4DCD1C5DDD2C6\
DED4C8E0D5C9E0D6CAE1D6CAE1D6CAE1D7CAE1D7CAE1D7CAE1D7CAE1D6CAE1D6CA
E1D5C9E1D4C9E2D4C8E2D3C8E2D3C8E2D2C8E1D2C8E1D2C7E0D2C7DED2C6DDD2C6DDD2C6DDD2C6\
DDD2C6DDD1C5DDD1C4DCD0C2DCD0C0DBCFBED9CEBED8CDBED7CEC0D7D0C5DAD6CD
DEDDD6E2E5DFE6EBE6E8EEEAE9EFEAE9EEE8E8ECE6E7EAE4E7E9E2E6E8E1E6E8E1E6E7E0E6E7E0\
E6E7DFE6E7DFE6E7DFE6E7DFE6E7DFE6E6DFE6E6DEE6E6DEE6E5DDE5E5DDE5E5DD
E5E5DEE5E6DEE5E7DFE5E7DFE5E7DFE5E6DEE5E6DEE5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E5DD\
E5E5DDE5E5DDE5E5DDE5E5DDE5E5DDE5E4DDE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE4E4DCE4E3DBE4E3DBE5E4DCE7E6DDE8E7DF\
E9E8DFE5E4DCD9D8D1
DAD8D1E9E4DCEDE7DFEDE6DEEBE5DDE9E4DCE8E4DCE8E6DDE8E7DFE9E8E0E9E8E0E9E8E0E9E7DF\
E9E6DEE9E5DDE9E4DCE9E4DCE9E4DCE9E5DDE9E6DEE9E7DFE9E8E0E9E8E0E9E9E0
E9E9E1E9E9E1E9E9E1E9EAE1E9EAE2E9EAE2E9EAE1E9E9E1E9E9E1E9E9E1E9E9E1E9EAE2E9EAE2\
E9EAE2E9EAE2E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1
E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E8E0E9E7DFE9E6DEE9E5DDE9E4DD\
E9E4DDE9E5DDE9E6DEE9E7DFE9E8E0E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E2
EAE9E2EAE9E2EAE9E2EAEAE2EAEAE2EAEAE2EAEAE3EAEAE3EAEAE3EAEBE4EAEBE4EAEBE5EAECE6\
EAEDE7EAEEE9EAEFEAEBEFEAEBEDE8EBEAE2EBE6DBEBE2D5EBDFD0EBDDCEEBDDCE
EBDDD0EBDED2EBDFD2EBDFD2EADFD1EAE0D1EAE1D2EAE3D4EAE4D7EAE4D8EAE4D8EAE2D7EAE1D6\
EAE0D5EAE0D5EAE1D6EAE3D7EAE5D9EAE6DAEAE6DBEAE6DBEBE6DAEBE5D9EBE5D7
ECE4D5ECE3D3ECE2D2ECE1D0ECE0D0ECE0CFEBE0CFEBE0D0EAE0D0E9E0D1E9E1D1E9E0D1E9E0D1\
E9E0D0E9DFCFE8DDCFE7DCCEE5DBCDE4D9CCE2D8CBE1D6C9E0D5C8E0D3C6DFD2C5
DFD1C4DFD0C3E0D0C3E0D0C4E0D0C4E0D0C4E0D0C4DFD0C4DECFC3DDCFC3DDCFC3DED1C4DFD2C6\
E1D4C8E3D6C9E4D7CAE4D8CBE4D8CBE4D8CBE4D8CBE5D8CCE5D8CBE5D8CBE5D7CA
E5D6C9E5D5C8E5D4C8E6D3C8E6D3C8E6D3C8E5D3C8E4D3C8E3D3C7E1D3C7E0D3C6DFD3C6DFD2C6\
DFD2C5DFD1C4DFD1C2DED0C0DECFBEDDCFBDDBCEBDD9CEBFD8D0C3D9D4CADCDBD3
E1E3DDE6ECE7EBF2EEEEF5F2EFF6F2EEF5F0EDF2EDECF0EBECEFE9EBEEE7EBEDE7EBEDE6EBECE6\
EBECE5EAECE5EAECE5EAECE4EAECE4EAEBE4EAEBE4EAEBE3EAEBE3EAEAE3EAEAE3
EAEBE3EAEBE4EAECE4EAECE4EAEBE4EAEBE3EAEAE3EAEAE2EAEAE2EAE9E2EAE9E1EAE9E1EAE9E1\
EAE9E1EAE9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E8E8DFE8E7DFE8E7DFEAE8E0EBEAE2EDECE4\
EDECE4E9E8DFDADAD2
DAD8D0E8E3DBEDE6DEEDE5DDEBE4DCE9E3DBE8E3DBE8E4DCE8E6DEE8E7DFE8E8DFE8E7DFE8E7DE\
E8E5DDE9E4DCE9E3DBE9E2DAE9E3DBE9E4DCE9E5DDE9E6DEE9E7DFE9E8E0E9E8E0
E9E8E0E9E8E0E9E9E0E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1\
E9E9E1E9E9E1E9E9E1E9E9E1E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E7DFE9E6DEE9E4DDE9E3DC\
E9E3DCE9E4DCE9E5DDE9E6DFE9E8E0E9E8E1E9E9E1E9E9E1E9E9E1E9E9E1E9E9E2
E9E9E2E9E9E2E9E9E2E9EAE2E9EAE3E9EAE3E9EAE3E9EAE3E9EBE4E9EBE4E9EBE5E9ECE6EAECE7\
EAEDE8EAEFEAEAF0ECEAEFEBEAEEE8EBEAE2EBE6DBEBE2D4EBDECEEBDCCCEBDBCC
EBDCCEEBDDD0EADDD0EADED0EADECFEADFCFEAE0D0EAE2D3EAE3D5EAE3D7EAE3D7EAE2D6EAE0D5\
EADFD4EADFD4EAE1D5EAE2D7EAE4D8EAE5DAEAE6DAEAE6DAEBE5D9EBE4D7EBE3D5
EBE2D3EBE1D0EBE0CEEBDECCEADDCBE9DDCBE9DDCBE8DDCBE7DDCCE7DDCDE7DDCDE7DDCDE7DCCC\
E7DBCCE7DACBE6D9CAE4D8C9E3D6C8E1D5C7DFD3C6DED2C5DDD1C4DCCFC2DCCEC1
DCCDC0DCCDC0DDCCC0DDCDC0DECDC1DECEC1DDCEC1DCCDC1DBCCC0DACCC0DBCCC0DCCEC1DDD0C3\
DFD2C5E1D4C7E2D5C8E3D6C9E3D6C9E3D6C9E3D6C9E3D6C9E3D6C9E3D6C9E4D5C8
E4D3C7E4D2C6E4D1C5E4D1C4E4D0C5E4D0C5E4D0C5E3D0C5E1D1C5E0D1C4DFD0C4DED0C4DDD0C3\
DDCFC2DDCEC1DDCDBEDDCCBCDCCCBADBCCBAD9CDBCD8CFC0D7D2C7D8D8CFDCDFD9
E1E7E3E6EFEBEBF4F2EEF7F5EFF8F4EFF6F2EEF4EFEDF2EDECF0EBEBEFE9EBEEE8EBEEE7EBEDE7\
EAEDE6EAEDE6EAECE5EAECE5EAECE5EAECE5EAECE4EAECE4EAEBE4EAEBE4EAEBE4
EAEBE4E9EBE4E9ECE4E9EBE4E9EBE3E9EBE3E9EAE2E9EAE2E9EAE2E9E9E2E9E9E1E9E9E1E9E9E1\
E9E9E1E9E9E1E9E9E1E9E9E1E9E9E1E9E8E1E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E8E8E0E8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE9E8E0EBEAE2EDECE4\
EDECE4E8E7DFDAD9D2
D9D7CFE7E2DAEBE5DDEBE4DCE9E2DAE7E0D8E6E0D8E5E1D9E5E3DBE6E4DCE6E5DDE6E5DDE6E4DC\
E6E3DBE6E2DAE6E1D9E6E0D8E6E0D9E6E1DAE6E3DBE6E4DCE6E5DDE6E6DEE6E6DE
E6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DE\
E6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DEE6E6DE
E6E6DEE7E6DEE7E6DEE7E6DEE7E6DEE7E6DEE7E6DEE7E6DEE7E6DEE7E5DDE7E3DCE7E2DBE7E1DA\
E7E1DAE7E2DAE7E3DCE7E4DDE7E6DEE7E6DFE7E7DFE7E7E0E7E7E0E7E7E0E7E7E0
E7E7E0E7E7E0E7E8E1E7E8E1E7E8E1E7E8E1E7E8E2E7E9E2E7E9E3E7E9E3E7EAE4E7EAE5E7EBE6\
E7ECE8E8EDEAE8EEEBE8EEEAE8ECE7E8E8E1E8E4D9E8DFD1E8DBCBE8D9C8E8D8C9
E8D9CAE8DACCE8DACDE8DBCDE8DBCCE8DCCCE8DDCDE8DFD0E8E0D2E7E0D4E7E0D4E7DFD4E8DED3\
E8DED2E8DED3E8DFD3E8E0D5E8E1D6E8E2D7E8E3D7E8E3D7E8E2D6E9E1D4E9E0D2
E9DFCFE8DDCCE7DCC9E6DAC7E4D9C6E3D8C6E2D8C5E2D8C6E2D8C6E2D8C7E3D8C7E3D7C6E3D6C6\
E3D5C5E2D3C4E1D2C3E0D1C3DED0C2DCCFC1DBCEC0D9CDC0D8CCBFD7CBBED7CABD
D8CABDD8C9BDD9C9BDD9CABDDACABEDACBBEDACBBED9CABED8CABDD7C9BDD7CABDD8CBBEDACCC0\
DCCEC1DDD0C3DED1C4DFD2C5DFD2C5DFD2C5DFD2C6E0D3C6E0D2C5E0D2C5E0D1C4
E0D0C3E0CEC2E1CDC1E1CDC0E1CDC0E1CDC0E0CDC1DFCDC1DECDC1DDCDC1DBCDC1DBCCC0DACCC0\
DACBBEDACABCDAC9BAD9C8B7D9C8B6D8C9B7D7CBBBD6D0C2D7D5CBD8DCD5DCE3DF
E1EAE8E6F1EFEAF5F3ECF7F5EDF7F4EDF6F2ECF3EFEBF1EDEAF0EBEAEEE9E9EEE8E9EDE7E9ECE6\
E8ECE5E8EBE5E8EBE4E8EBE4E8EBE4E8EBE4E8EAE3E8EAE3E8EAE3E7EAE3E7EAE2
E7EAE2E7E9E2E7E9E2E7E9E1E7E9E1E7E8E1E7E8E1E7E8E0E7E8E0E7E8E0E7E7E0E7E7E0E7E7DF\
E7E7DFE7E7DFE7E7DFE7E7DFE7E6DFE7E6DFE7E6DEE7E6DEE7E6DEE6E6DEE6E6DE
E6E6DEE6E6DEE6E6DEE6E6DEE6E5DDE6E5DDE6E5DDE6E5DDE5E5DDE6E5DDE7E6DEE9E8E0EBEAE2\
EBEAE2E7E6DDD9D8D0
D8D6CEE5E1D9E9E4DCE9E3DBE7E0D9E5DFD7E3DED6E3DFD7E3E0D8E3E1D9E3E2DAE3E2DAE4E2DA\
E4E1D9E4E0D8E4DFD7E4DED7E4DFD7E4E0D8E4E1D9E4E2DAE4E3DBE4E3DBE4E4DC
E4E3DCE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E4DCE4E3DCE4E3DBE4E3DBE4E3DB\
E4E3DBE4E3DBE4E3DCE4E4DCE4E4DCE4E4DCE4E4DCE4E4DCE4E4DCE4E4DCE4E4DC
E4E4DCE4E4DCE4E4DCE4E4DCE4E4DCE4E4DCE4E4DCE4E4DCE4E3DCE4E3DBE4E1DAE4E0D9E4E0D8\
E4E0D8E4E0D9E4E1DAE4E2DBE4E4DCE4E4DDE4E5DDE4E5DEE4E5DEE4E5DEE4E5DE
E4E5DEE4E5DFE4E6DFE4E6DFE4E6DFE4E6E0E5E6E0E5E7E1E5E7E1E5E8E2E5E8E3E5E9E4E5E9E5\
E5EBE7E5ECE9E6EDEAE6ECE9E6EAE5E5E6DFE5E1D6E5DCCEE5D8C7E5D5C4E5D5C4
E6D5C6E6D7C8E6D7C9E6D8C9E6D9C9E6D9CAE5DACBE5DBCDE5DDCFE5DDD1E5DDD2E5DDD2E5DCD1\
E5DCD1E5DCD1E5DDD1E5DED2E6DED3E6DFD4E6DFD4E6DFD4E6DFD3E6DED1E6DDCE
E5DBCBE4D9C7E3D7C5E0D6C3DED4C2DCD3C1DBD3C1DBD3C1DCD2C1DDD2C1DED1C1DFD0C0DFCFBF\
DECDBEDECCBEDCCABDDBCABCD9C9BBD8C8BBD6C8BBD5C8BBD4C8BBD4C8BAD4C7BA
D4C7BAD5C7BAD5C7BBD6C8BBD6C8BCD7C9BCD6C9BCD6C8BCD5C8BBD5C7BBD5C7BBD6C8BBD7C9BC\
D8CABED9CCBFDACCC0DBCDC0DBCEC1DBCEC1DBCEC1DBCEC1DCCEC1DCCEC1DCCDC0
DCCCBFDCCBBEDCCABDDDC9BCDDC9BCDDC9BCDCC9BCDBCABCDAC9BDD9C9BDD8C9BDD7C9BDD7C8BC\
D7C7BBD6C6B8D6C5B6D6C4B3D5C4B3D5C6B5D5CBBCD6D1C5D7D9D1DAE1DCDDE8E5
E1EEEDE5F3F2E9F6F5EAF7F5EBF6F4EBF4F2EAF2EFE9F0ECE8EFEAE8EDE9E7ECE7E7ECE6E7EBE5\
E6EAE5E6EAE4E6EAE3E6E9E3E6E9E3E6E9E2E5E9E2E5E9E2E5E9E2E5E8E1E5E8E1
E5E7E0E5E7E0E5E6DFE5E6DFE5E6DEE5E6DEE5E6DEE5E6DEE5E6DEE5E6DEE5E5DEE4E5DEE4E5DD\
E4E5DDE4E5DDE4E5DDE4E4DDE4E4DDE4E4DDE4E4DCE4E4DCE4E4DCE4E4DCE4E4DC
E4E4DCE4E4DCE4E3DCE4E3DBE4E3DBE3E3DBE3E3DBE3E3DBE3E2DAE3E3DBE5E4DCE7E6DEE9E8E0\
EAE8E0E5E4DCD8D7D0
D7D6CEE4E2DAE8E5DDE8E3DBE6E1D9E3DED6E2DDD5E1DDD5E1DDD5E2DED6E2DFD7E2E0D8E2E0D8\
E2E0D8E2DFD7E2DED7E2DED6E2DED6E2DFD7E2E0D8E2E1D9E2E1DAE2E2DAE2E2DA
E2E2DAE2E1D9E2E1D9E2E0D8E2E0D8E2E0D8E2E1D9E2E1D9E2E2DAE2E2DAE2E1D9E2E1D9E2E0D8\
E2E0D8E2E1D9E2E1D9E2E2DAE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE3E2DBE3E2DBE3E1DAE3E1D9E3E0D9E3DFD8\
E3DFD8E3E0D9E3E1D9E3E1DAE3E2DBE3E3DCE3E3DCE3E3DDE3E4DDE3E4DDE3E4DD
E3E4DDE3E4DEE3E4DEE3E5DEE3E5DFE3E5DFE3E5DFE3E6E0E3E6E0E3E7E1E3E7E2E3E8E3E3E9E4\
E4EAE6E4EBE8E4EBE9E4EBE8E4E9E4E3E4DDE3DFD4E2D9CBE2D5C4E2D2C0E3D2C0
E3D3C2E4D4C4E4D5C6E4D6C7E4D7C8E4D7C8E4D8C9E4D9CBE4DACDE4DACEE4DBCFE4DBD0E4DBD0\
E4DBD0E4DBD0E4DBD0E4DCD0E4DCD1E4DCD1E5DCD1E5DCD1E5DCD0E5DBCEE4DACB
E3D8C7E1D6C4DFD4C2DBD3C0D8D1C0D6D0BFD5CFBFD6CFBED7CEBDD9CDBDDACCBCDBCABBDCC8BA\
DBC6B9DAC5B8D9C4B7D7C3B6D6C3B6D4C3B6D3C4B6D2C4B7D2C5B7D1C5B8D1C6B8
D2C6B9D3C6B9D3C6B9D4C7BAD4C8BBD4C8BBD5C8BBD4C7BBD4C7BAD4C6B9D4C6B9D4C6B9D5C6BA\
D5C7BAD6C8BBD6C8BCD7C9BCD7C9BDD7CABDD8CABDD8CABDD8CABDD8CABDD8C9BC
D8C8BCD9C8BBD9C7BAD9C7B9D9C7B9D9C7B8D9C7B8D8C7B8D7C7B9D6C6B9D6C6BAD5C6BAD5C5B9\
D4C4B7D4C3B5D3C1B2D3C0B0D3C1B1D4C4B5D5CBBDD7D3C9DADDD7DDE6E3E0EEEC
E4F3F3E6F6F6E8F7F6E9F7F5E9F5F4E9F4F1E8F2EFE8F0ECE7EEEAE6EDE9E6ECE7E6EBE6E5EAE5\
E5EAE4E5E9E4E5E9E3E4E9E2E4E8E2E4E8E2E4E8E2E4E8E1E4E8E1E4E7E1E4E7E0
E4E6DFE3E5DEE3E4DDE3E3DCE3E3DCE3E4DDE3E4DDE3E4DDE3E5DDE3E4DDE3E4DDE3E4DDE3E4DC\
E3E4DCE3E3DCE3E3DCE3E3DCE3E3DBE3E3DBE3E3DBE3E3DBE2E2DBE2E2DBE2E2DB
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1D9E2E1D9E1E1D9E2E1DAE3E3DBE6E5DDE8E7DF\
E8E7DFE4E3DBD7D7CF
D7D6CFE4E3DBE8E6DEE8E5DDE5E2DAE3DFD7E1DCD5E1DCD4E1DCD4E1DCD5E1DDD6E1DED7E1DFD7\
E1DFD8E1DFD7E1DFD7E1DFD7E1DFD7E1DFD7E2E0D8E2E0D9E2E1D9E2E1D9E2E1DA
E2E1D9E2E0D9E2DFD8E2DFD7E2DED7E2DED7E2DFD8E2E0D8E2E1D9E2E1D9E2E0D8E2DFD8E2DFD7\
E2DFD7E2DFD8E2E0D8E2E1D9E2E2DAE2E2DAE2E2DBE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E1DAE2E1DAE2E0D9E2E0D9\
E2E0D9E2E0D9E2E1DAE2E2DBE2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DD
E2E4DDE2E4DDE2E4DEE2E4DEE2E5DFE2E5DFE2E5DFE2E6E0E2E6E1E3E6E1E3E7E2E3E8E3E3E8E4\
E3E9E6E3EBE8E3EBE9E3EBE8E3E8E3E2E3DCE1DDD2E1D7C8E0D2C1E1D0BDE1D0BD
E2D1BFE3D3C1E4D4C4E4D5C6E4D6C7E4D6C8E3D6C9E3D7CAE3D8CBE3D8CDE3D9CEE3DACFE3DBCF\
E3DBD0E3DBD0E3DBCFE4DACFE4DACFE4DACFE4DACFE4DACEE4DACDE4D9CBE3D8C9
E2D6C6DFD4C3DCD3C1D8D1C0D5D0BFD2CEBFD1CDBED2CCBDD4CBBBD7CABAD9C8B9DAC6B8DAC4B6\
DAC2B5D9C0B4D7BFB3D6BFB3D4BFB2D3C0B2D2C1B3D1C2B4D1C3B5D1C4B6D1C5B7
D2C5B8D2C6B9D3C6B9D3C7BAD4C7BBD4C8BBD4C8BBD4C7BAD4C6BAD4C5B9D4C5B8D4C4B8D3C4B7\
D3C4B8D3C5B8D4C5B8D4C6B9D4C6B9D4C6B9D5C7BAD5C7BAD5C7BAD5C7BAD5C6B9
D6C6B9D6C5B8D6C5B8D6C5B7D6C5B6D6C5B5D6C5B5D6C5B5D5C5B6D5C4B7D4C4B7D4C4B7D3C3B6\
D3C2B5D2C0B2D2BFB0D1BEAED2BFAFD3C3B4D5CBBFD9D6CDDDE2DCE1ECEAE4F3F3
E7F7F8E8F9F9E9F8F8E9F7F6E9F5F4E8F3F1E8F2EFE7F0EDE7EFEBE6EDE9E6ECE8E5EBE7E5EBE6\
E5EAE5E4E9E4E4E9E3E4E9E3E4E8E2E4E8E2E4E8E2E3E8E1E3E7E1E3E7E0E3E6DF
E3E5DEE3E3DDE3E2DCE3E2DBE3E2DBE3E3DCE3E4DCE3E4DDE2E4DDE2E4DDE2E4DDE2E4DCE2E3DC\
E2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DA
E2E2DAE2E1DAE2E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E1D9E3E2DAE5E5DDE8E7DF\
E8E7DFE4E3DBD7D7CF
D7D7CFE4E4DCE8E8E0E8E7DEE5E3DBE3E0D8E1DDD5E1DBD4E1DBD3E1DCD4E1DDD5E1DED6E1DFD7\
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E1E1D9E1E1D9E2E1DAE2E1D9
E2E1D9E2E0D8E2DFD7E2DED7E2DED6E2DED6E2DFD7E2E0D8E2E0D9E2E0D9E2E0D8E2DFD7E2DED7\
E2DED7E2DFD7E2E0D8E2E1D9E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E1DAE2E1DAE2E1DA\
E2E1DAE2E1DBE2E2DBE2E2DBE2E2DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD
E2E4DEE2E4DEE2E4DEE2E5DFE2E5DFE2E5E0E2E6E0E2E6E1E2E6E1E3E7E2E3E7E3E3E8E4E3E9E5\
E3EAE7E3EBE8E3EBE9E3EBE8E3E8E3E2E2DBE1DCD1E0D6C7E0D1BFE0CEBBE1CEBB
E2D0BDE3D2C0E3D3C3E4D4C5E4D5C7E4D5C8E3D6C9E3D6CAE3D6CBE3D7CBE3D8CCE3D9CEE3DACF\
E3DBCFE3DBCFE4DACFE4DACEE4D9CDE4D9CDE4D9CDE4D8CCE4D8CBE4D8CAE3D7C7
E1D5C5DFD4C3DCD2C1D8D1C1D4D0C0D1CEC0D0CDBFD1CCBDD3CBBBD6C9BAD8C7B8DAC4B7DAC1B5\
DABFB4D9BDB3D7BDB2D5BCB1D4BDB0D2BEB0D2BFB1D1C0B2D1C2B4D2C3B5D2C4B6
D2C5B7D3C5B8D3C6B9D4C7BAD4C7BBD5C7BBD5C7BBD5C6BAD5C5B9D5C4B8D4C3B7D4C3B6D3C2B6\
D2C2B5D2C2B5D2C3B5D2C3B6D2C3B6D2C4B6D3C4B7D3C4B7D3C4B7D3C4B7D3C4B7
D4C4B7D4C4B6D4C3B6D4C3B5D4C3B4D4C3B3D4C3B3D4C3B3D4C3B4D4C3B5D4C3B5D3C2B5D3C2B4\
D2C0B2D2BFB0D1BDADD0BCACD1BDAED3C2B4D6CCC0DBD8D0E0E5E1E5F1EFE8F8F8
EAFBFCEAFBFCEAFAFAEAF8F7E9F6F4E8F4F2E8F2F0E7F1EEE7EFECE6EEEAE6EDE9E5ECE8E5EBE7\
E5EBE6E5EAE5E4EAE4E4E9E4E4E9E3E4E9E3E4E8E2E4E8E2E3E8E1E3E7E1E3E6E0
E3E5DEE3E3DDE3E2DCE3E2DBE3E2DBE3E3DCE3E4DDE3E4DDE3E4DDE2E4DDE2E4DDE2E4DDE2E4DC\
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DA
E2E2DAE2E2DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E3E3DBE6E5DDE8E7DF\
E8E8DFE4E4DCD7D7CF
D7D8D0E5E5DDE9E9E1E8E8E0E6E4DCE3E0D8E2DDD5E1DBD4E1DBD3E1DBD3E1DCD5E1DED6E1DFD7\
E1E0D8E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1DAE2E1DA
E2E1D9E2E0D8E2DFD8E2DED7E2DED6E2DED7E2DFD7E2E0D8E2E0D9E2E0D9E2E0D8E2DFD7E2DED7\
E2DED7E2DFD8E2E0D8E2E1D9E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DE
E2E4DEE2E4DEE2E5DFE2E5DFE2E5E0E2E6E0E2E6E1E2E6E1E3E7E2E3E7E2E3E8E3E3E8E4E3E9E6\
E3EAE7E3EBE9E3ECEAE3EBE8E3E8E3E2E2DBE1DBD0E0D5C6E0D0BEE0CDBAE1CDB9
E2CFBCE3D1BFE3D3C2E4D4C5E4D5C7E4D5C8E4D5C9E3D5C9E3D6CAE3D6CAE3D7CBE3D8CDE3DACE\
E4DACFE4DACFE4DACEE4D9CDE4D8CCE4D8CCE4D8CBE4D8CAE4D7CAE4D7C8E3D6C7
E2D5C5DFD4C4DCD3C3D9D2C3D6D1C3D3D0C2D2CFC1D3CDBFD5CCBDD7CABBD9C7B9DBC4B8DBC1B7\
DBBFB6DABDB4D8BCB2D6BCB1D5BCB0D3BDAFD2BEAFD2BFB0D3C0B2D3C2B4D3C2B5
D4C3B7D4C4B8D5C5B9D5C6BAD6C6BBD6C6BBD6C6BBD6C5BAD6C3B8D5C2B7D5C1B5D3C0B4D2C0B4\
D1C0B3D0C0B3D0C1B3D0C1B3D1C1B4D1C2B4D1C2B4D1C2B4D2C2B4D2C2B4D2C2B5
D2C2B5D2C2B5D2C2B4D2C2B3D2C2B2D3C2B1D3C2B1D3C2B2D3C3B2D4C3B3D4C2B4D4C2B4D3C1B3\
D2BFB1D1BDAED0BBABCFBAAAD0BCACD2C1B3D7CCC0DCD9D1E2E7E3E7F3F2EAFBFB
ECFDFFECFDFEEBFBFBEAF8F8E9F6F5E8F4F2E8F3F0E7F1EFE7F0EDE6EFEBE6EEEAE6EDE9E5ECE8\
E5EBE7E5EBE6E5EAE5E4EAE4E4E9E4E4E9E3E4E9E3E4E8E2E4E8E2E3E7E1E3E6E0
E3E5DFE3E4DDE3E3DCE3E2DCE3E3DCE3E3DCE3E4DDE3E4DEE3E5DEE3E5DEE2E4DDE2E4DDE2E4DD\
E2E4DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DA
E2E2DAE2E2DAE2E2DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E3E3DBE6E5DDE8E7DF\
E9E8E0E5E4DCD7D7CF
D7D8D0E5E5DDE9EAE1E8E8E0E6E5DDE3E1D9E2DED6E1DBD4E1DBD3E1DBD3E1DCD5E1DED6E1DFD7\
E1E0D8E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E1DAE2E1DA
E2E1D9E2E0D9E2E0D8E2DFD8E2DFD7E2DFD7E2E0D8E2E0D9E2E1D9E2E1D9E2E0D9E2E0D8E2DFD8\
E2DFD8E2E0D8E2E0D9E2E1DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E3DDE2E4DDE2E4DEE2E4DEE2E4DE
E2E4DEE2E5DFE2E5DFE2E5E0E2E6E0E2E6E1E2E6E1E2E7E2E3E7E2E3E7E3E3E8E4E3E9E5E3E9E6\
E3EAE8E3ECE9E3ECEAE3EBE8E3E8E3E2E2DAE1DBCFE1D4C5E1CFBDE1CDB9E1CDB9
E2CEBBE3D1BFE3D2C2E4D3C5E4D4C7E4D4C8E4D4C8E4D5C9E4D5C9E4D6CAE4D6CBE4D7CCE4D8CD\
E4D9CDE4D9CDE4D9CDE4D8CCE4D7CBE4D7CBE4D7CAE4D7C9E4D7C8E4D7C7E4D6C7
E2D6C6E1D5C6DED4C6DCD4C6D9D3C6D7D2C6D6D1C4D7D0C2D8CEBFD9CCBDDBC9BBDCC6BADDC3B9\
DDC1B8DDBFB7DBBDB5D8BDB2D6BDB0D5BDAFD4BEAFD4BEAFD4BFB0D5C0B2D5C1B4
D6C2B5D6C2B7D7C3B8D7C4BAD7C5BAD8C5BAD8C4BAD7C2B9D7C0B7D6BFB5D5BDB3D3BDB2D2BDB2\
D1BEB1D0BFB1CFBFB1CFC0B2D0C0B2D0C0B2D0C0B2D0C0B2D1C0B3D1C0B3D1C0B3
D1C1B3D1C1B3D1C1B3D1C1B2D1C1B1D2C1B0D2C1B0D3C1B1D3C2B2D4C2B3D4C2B3D4C1B3D3C0B1\
D2BEAFD1BCACCFB9AACFB8A8D0BAABD2C0B2D7CBC0DDD9D1E3E8E3E8F4F3EBFBFC
ECFEFFECFEFFEBFBFCEAF9F8E9F6F5E9F5F3E8F3F1E8F2EFE7F1EEE7F0ECE6EFEBE6EEEAE6EDE8\
E5ECE8E5EBE7E5EBE6E5EAE5E4EAE4E4E9E4E4E9E3E4E9E3E4E8E2E4E8E2E4E7E1
E3E6DFE3E5DEE3E4DDE3E3DDE3E4DDE3E4DDE3E4DEE3E5DEE3E5DEE3E5DEE3E5DEE2E4DDE2E4DD\
E2E4DDE2E4DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DB
E2E2DAE2E2DAE2E2DAE2E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E2E1DAE3E3DBE6E5DDE8E7DF\
E9E8E0E5E4DCD7D7CF
D8D8D0E5E5DDE9EAE2E8E9E1E6E5DDE3E1D9E2DED6E1DCD4E1DBD3E1DBD4E1DDD5E1DED6E1DFD8\
E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E1DAE2E1DA
E2E1D9E2E1D9E2E0D9E2E0D8E2E0D8E2E0D9E2E0D9E2E1D9E2E1DAE2E1DAE2E1D9E2E1D9E2E0D9\
E2E0D9E2E1D9E2E1DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DDE2E3DDE2E3DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E5DF
E2E5DFE2E5DFE2E5E0E2E6E0E2E6E1E2E6E1E2E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E9E5E3EAE6\
E3EBE8E3ECE9E3ECEAE3EBE8E3E8E3E3E2DAE2DBCFE2D4C5E2CFBDE2CCB9E2CDB9
E3CEBCE3D0BFE3D2C3E4D3C5E4D4C6E4D4C7E4D4C8E4D4C8E4D5C9E4D5C9E4D6CAE4D6CAE4D7CB\
E4D8CCE4D8CCE4D8CCE4D7CBE4D7CBE4D7CAE4D7C9E5D7C8E5D7C7E4D7C7E4D7C7
E3D7C7E2D6C8E1D6C9DFD6CADED6CADDD5C9DCD4C8DBD3C5DBD1C3DCCFC0DDCDBFDFCABEE0C7BD\
E0C4BCDFC1BADDC0B8DBBFB5D9BEB2D7BEB0D6BEAFD6BEAFD6BEB0D7BFB1D7BFB2
D8C0B4D8C1B6D9C2B8D9C2B9D9C3BAD9C3BAD9C2B9D9C0B7D8BEB5D7BCB3D5BBB2D3BAB1D2BBB0\
D1BCB0D0BDB0CFBEB0CFBEB0CFBEB1D0BFB1D0BFB1D0BFB1D0BFB2D0BFB2D1C0B2
D1C0B2D1C0B2D1C0B1D1BFB1D1BFB0D1BFB0D2C0B0D3C0B0D4C1B1D5C2B2D5C1B2D4C1B2D3BFB0\
D2BDAED0BBABCFB8A8CEB7A7CFB9A9D2C0B1D7CBBFDDD9D0E3E7E3E8F4F2EBFBFC
ECFEFFECFEFFEBFBFCEAF9F8E9F7F6E9F5F3E8F3F1E8F2F0E7F1EEE7F0EDE6EFEBE6EEEAE6EDE9\
E6EDE8E5ECE7E5EBE7E5EBE6E5EAE5E4EAE4E4E9E4E4E9E3E4E9E3E4E8E2E4E7E1
E4E6E0E3E6DFE3E5DFE3E5DEE3E5DEE3E5DEE3E5DEE3E5DEE3E5DEE3E5DEE3E5DEE3E4DDE2E4DD\
E2E4DDE2E4DDE2E4DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DB
E2E2DBE2E2DAE2E2DAE2E2DAE2E1DAE1E1DAE1E1DAE1E1D9E1E1D9E2E2DAE4E3DBE6E5DDE8E8DF\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE1E8E9E1E6E5DDE4E2DAE2DED7E1DCD5E1DCD4E1DCD4E1DDD5E1DED7E1E0D8\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1DAE2E1DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DA\
E2E1DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DDE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E5DFE2E5DF
E2E5DFE2E5E0E2E6E0E2E6E0E2E6E1E2E6E1E3E7E2E3E7E3E3E8E3E3E8E4E3E8E5E3E9E5E3EAE7\
E3EBE8E3ECEAE3ECEAE3EBE8E3E8E3E3E2DAE3DBCFE3D4C5E3CFBDE3CDB9E3CDB9
E3CEBCE3D0BFE4D2C2E4D3C4E4D3C5E4D4C6E4D4C7E4D4C7E4D4C8E4D5C8E4D5C9E4D6CAE4D6CA\
E4D6CAE4D7CBE4D7CBE4D7CBE4D7CAE4D7C9E4D7C8E5D7C7E5D7C7E5D7C7E5D8C8
E4D8C9E4D8CBE3D8CCE3D9CDE2D9CDE1D8CDE0D8CBE0D7C9DFD5C6DFD3C4E0D0C2E1CDC2E2CAC1\
E2C7C0E1C5BEDFC3BBDDC2B8DBC1B4D9C0B2D8BFB0D8BFAFD9BEB0D9BFB1DABFB2
DAC0B4DAC0B6DBC1B7DBC1B8DBC2B9DBC1B9DBC0B8DABEB7D9BCB5D8BBB3D6B9B1D4B9B0D3BAAF\
D1BAAFD0BBAFD0BCAFCFBCAFD0BDAFD0BDB0D0BEB1D1BEB1D1BFB2D1BFB2D1BFB2
D1BFB1D0BFB1D0BFB0D1BEAFD1BEAFD1BEAFD2BEAFD3BFB0D4C0B1D5C1B1D6C1B1D5C0B0D4BEAF\
D2BCACD0B9A9CFB7A7CEB7A6CFB9A8D2BFB0D6CABEDCD8D0E2E7E2E8F3F1EBFAFB
ECFDFEECFDFEEBFBFBEAF9F8E9F7F6E9F5F4E8F4F2E8F3F0E7F1EFE7F0EDE7EFECE6EFEBE6EEEA\
E6EDE9E5ECE8E5ECE7E5EBE6E5EBE6E5EAE5E4EAE4E4E9E4E4E9E3E4E8E3E4E8E2
E4E7E1E4E7E1E3E6E0E3E6E0E3E6DFE3E6DFE3E6DFE3E6DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DD\
E3E4DDE2E4DDE2E4DDE2E4DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E1DAE1E1DAE1E1D9E1E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E8E9E0E6E5DDE4E2DAE2DFD7E1DDD6E1DDD5E1DDD5E1DED6E1DFD7E1E0D8\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE2E1DAE2E1DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DB
E2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DD\
E2E3DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E5DFE2E5DFE2E5DF
E2E5E0E2E6E0E2E6E0E2E6E1E2E6E1E2E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E9E5E3E9E6E3EAE7\
E3EBE8E3ECEAE3ECEAE3EBE8E3E8E3E3E2DAE3DCD0E3D5C5E3D0BDE3CDB9E3CDB9
E3CEBCE4D0BFE4D1C1E4D2C3E4D3C4E4D3C4E4D3C5E4D4C6E4D4C7E4D4C8E4D5C8E4D5C9E4D5C9\
E4D5C9E4D6CAE4D6CAE4D6CAE4D6CAE4D6C9E5D7C8E5D7C7E5D7C7E5D8C8E5D8C9
E5D9CBE5DACDE5DBCFE5DBD0E5DBD0E5DBD0E4DBCEE3D9CCE2D8CAE2D6C8E2D3C6E2D1C5E3CEC4\
E3CBC2E2C9C0E1C6BDDFC4BADDC3B7DBC1B4DBC0B2DBC0B1DBC0B1DBC0B2DCC0B3
DCC1B4DCC1B6DDC1B7DDC1B8DCC1B8DCC0B8DCBFB8DBBEB7DBBDB5DABCB4D8BBB2D6BAB1D4BAAF\
D3B9AED1B9AED0B9ADD0B9ADD1BAAED1BBAFD1BDB1D1BEB2D1BFB3D1C0B4D1C0B3
D1BFB2D0BFB0D0BEAFD0BDAED1BDAED2BDAED3BDAED4BEAFD5BFAFD6BFB0D6BFAFD5BEAED3BDAD\
D2BBAAD0B9A8CEB7A6CEB7A5CFB9A8D2C0B0D7CBBEDCD8CFE2E6E1E7F2F0EAFAFA
ECFDFEECFDFDEBFBFBEAF9F8E9F7F6E9F5F4E8F4F2E8F3F1E7F2EFE7F1EEE7F0EDE6EFEBE6EEEA\
E6EDE9E6EDE8E5ECE8E5ECE7E5EBE6E5EBE5E5EAE5E4EAE4E4E9E4E4E9E3E4E8E3
E4E8E2E4E8E2E4E7E1E3E7E1E3E7E0E3E6E0E3E6E0E3E6DFE3E6DFE3E5DFE3E5DEE3E5DEE3E5DE\
E3E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE1E1DAE1E1DAE2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E8E0E6E6DDE4E2DAE2E0D8E1DFD7E1DED6E1DED6E1DFD7E1E0D8E1E0D9\
E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E1DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E3DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E5DFE2E5DFE2E5DFE2E5E0
E2E5E0E2E6E0E2E6E1E2E6E1E2E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E8E4E3E9E5E3E9E6E3EAE7\
E3EBE8E3ECEAE3ECEAE3EBE8E3E8E3E3E3DBE4DCD0E4D6C6E4D1BEE4CEBAE4CEB9
E4CEBBE4D0BDE4D1BFE4D2C1E4D3C2E4D3C2E4D3C3E4D3C5E4D4C6E4D4C7E4D4C8E4D5C8E4D5C9\
E4D5C9E4D5C9E4D5C9E4D6CAE4D6C9E4D6C9E5D6C8E5D7C8E5D7C8E5D8C9E5D9CB
E5DACDE6DBCFE6DCD1E6DDD2E6DDD2E6DDD2E6DDD1E5DCCFE4DACDE4D8CBE3D6C9E3D4C7E3D1C6\
E3CFC4E2CCC2E1C9BFDFC7BCDEC5B9DDC3B7DDC2B5DDC2B4DDC2B3DEC2B4DEC2B4
DEC3B6DEC3B7DEC3B8DEC2B8DDC1B8DDC0B8DDBFB7DDBFB7DCBFB6DCBEB5DBBEB4D9BCB2D6BAB0\
D4B9AED3B7ADD2B6ACD1B6ACD2B7ADD2B9AFD2BBB1D3BEB3D3C0B5D2C1B6D2C1B5
D1C0B3D0BEB1D0BDAED0BCADD1BBACD2BBACD3BCADD5BCADD6BDADD6BDADD6BDADD5BCACD3BBAB\
D1B9A9D0B8A7CEB7A5CEB7A5D0BAA9D3C1B1D7CCBFDDD9D0E3E6E1E7F2F0EAF9F9
EBFCFDEBFCFDEBFAFBEAF8F8E9F7F6E9F5F4E8F4F2E8F3F1E8F2EFE7F1EEE7F0EDE7EFECE6EFEB\
E6EEEAE6EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3
E4E8E3E4E8E2E4E8E2E4E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6DFE3E6DFE3E5DFE3E5DEE3E5DE\
E3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DB
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E8E0E6E6DEE4E3DBE2E1D9E1E0D8E1DFD8E1DFD8E1E0D8E1E0D8E1E1D9\
E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E1DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E5DFE2E5DFE2E5DFE2E5E0E2E5E0
E2E6E0E2E6E1E2E6E1E2E7E1E3E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E9E5E3E9E5E3EAE6E3EAE7\
E3EBE9E3ECEAE3ECEAE3EBE9E3E8E4E4E3DBE4DDD1E4D7C7E4D2BFE4CFBAE4CEB9
E4CFBAE4D0BCE4D1BDE4D2BFE4D2C0E4D3C1E4D3C2E4D3C3E4D4C5E4D4C6E4D4C7E4D4C8E4D4C8\
E4D5C8E4D5C9E4D5C9E4D6C9E4D6C9E5D6C9E5D6C9E5D7C9E5D7C9E5D8CBE5DACC
E6DBCEE6DDD0E6DED2E6DED3E7DFD3E7DFD3E7DED2E6DDD1E6DCCFE5DACEE5D8CCE4D6CAE3D4C8\
E3D2C5E2CFC3E1CDC1E0CABEDFC8BCDFC6BADFC5B8DFC4B7DFC4B6DFC5B6E0C5B7
E0C5B8E0C5B8DFC5B9DFC3B9DEC2B8DEC1B8DDC0B7DEC1B8DEC2B8DEC2B7DDC1B6DBBFB4D9BCB1\
D6B9AFD4B6ACD3B4ABD3B4ABD3B5ACD3B7AED4BAB1D4BEB4D4C1B7D3C2B8D2C2B7
D1C1B4D1BFB1D0BDAED1BBACD2BBABD3BAABD4BBABD5BBABD6BBABD6BBABD5BBAAD4BAAAD2B9A8\
D1B8A7CFB7A6CFB7A5CFB8A6D1BCABD4C3B3D9CEC1DEDBD1E3E7E2E7F2F0EAF9F8
EBFCFCEBFCFCEBFAFAEAF8F8E9F7F6E9F5F4E8F4F2E8F3F1E8F2F0E7F1EEE7F0EDE7F0ECE6EFEB\
E6EEEAE6EDE9E6EDE9E5ECE8E5ECE7E5EBE6E5EBE6E5EAE5E4EAE4E4E9E4E4E9E3
E4E9E3E4E8E2E4E8E2E4E8E2E3E7E1E3E7E1E3E7E0E3E6E0E3E6DFE3E6DFE3E5DFE3E5DEE3E5DE\
E3E5DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DB
E2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E3DBE2E1D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DFE2E5DFE2E5DFE2E5E0E2E5E0E2E6E0
E2E6E1E2E6E1E2E6E1E2E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E8E4E3E9E5E3E9E5E3EAE6E3EAE7\
E3EBE9E3ECEAE3EDEBE4ECE9E4E9E4E4E4DCE4DED2E4D8C8E4D3BFE4D0BAE4CFB8
E4CFB9E4D0BAE4D1BCE4D1BDE4D2BEE4D2BFE4D3C1E4D3C2E4D3C4E4D4C5E4D4C6E4D4C7E4D4C7\
E4D5C8E4D5C8E4D5C9E4D5C9E5D6C9E5D6C9E5D6CAE5D7CAE5D8CBE5D9CCE5DACE
E6DCCFE6DDD1E6DED2E6DFD3E7DFD4E7DFD4E7DFD3E7DED2E6DDD1E6DCD0E5DACEE5D9CCE4D7C9\
E3D5C7E2D2C5E1D0C3E1CDC1E1CBBFE0C9BDE0C8BBE0C7BAE0C7B9E1C8B9E1C8B9
E1C8B9E1C7BAE0C6BAE0C5B9DFC3B8DEC2B8DEC2B8DFC3B8DFC4B9E0C5B9DFC4B8DDC1B6DBBDB3\
D8B9AFD6B5ADD5B3ABD4B3ABD4B4ABD4B6AED5BAB1D5BDB4D5C1B7D4C3B8D3C2B8
D2C1B5D1BFB2D1BDAFD1BBACD2BAABD3BAAAD4BAAAD5B9AAD5B9A9D5B9A9D4B8A8D3B8A7D1B7A6\
D0B6A5CFB6A5CFB7A6D0BAA8D2BFAED6C6B7DAD1C4DFDDD4E4E9E3E8F2F0EAF9F8
EBFBFCEBFBFCEAFAFAEAF8F7E9F6F5E9F5F4E8F4F2E8F3F1E8F2F0E7F1EFE7F1EEE7F0EDE6EFEC\
E6EEEBE6EEEAE6EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EAE5E4EAE5E4EAE4E4E9E4
E4E9E3E4E8E3E4E8E2E4E8E2E4E7E1E3E7E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DE\
E3E5DEE3E5DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DE\
E2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0
E2E6E1E2E6E1E2E7E2E3E7E2E3E7E2E3E8E3E3E8E3E3E8E4E3E9E4E3E9E5E3E9E6E3EAE6E3EAE7\
E3EBE9E3ECEAE4EDEBE4ECEAE4EAE5E4E5DDE4DFD3E4D9C8E4D4C0E4D0BAE4CFB8
E4CFB8E4D0B9E4D1BBE4D1BCE4D2BEE4D2BFE4D2C0E4D3C1E4D3C3E4D3C4E4D4C5E4D4C6E4D4C7\
E4D4C7E4D5C8E4D5C8E4D5C9E5D6C9E5D6CAE5D7CAE5D8CBE5D9CCE5DACDE5DBCE
E6DCD0E6DDD1E6DDD2E6DED2E6DED3E6DED3E7DED3E7DED3E7DED2E7DDD1E6DCD0E5DBCEE4D9CB\
E3D7C9E3D5C7E2D3C5E2D1C3E2CEC2E2CDC0E2CCBEE2CBBDE1CABCE1CABBE2CABB
E2CABBE2C9BBE1C8BBE0C6BAE0C4B9DFC3B8DFC3B8DFC5B9E0C6B9E0C7B9E0C6B9DEC3B6DCBEB3\
DABAB0D8B6AED6B4ACD5B4ABD5B4ACD5B7ADD5BAB0D5BDB3D5C0B6D5C2B7D4C2B7
D3C1B5D2BFB3D1BEB0D1BCAED2BBACD3BAAAD3B9A9D4B8A8D4B8A7D3B7A6D3B6A6D1B6A5D0B5A4\
CFB5A4CFB6A5D0B8A7D1BCABD4C2B2D8CABCDCD5C9E1E0D8E5EAE6E8F3F1EAF8F8
EBFBFBEBFBFBEAF9F9EAF8F7E9F6F5E9F5F4E8F4F2E8F3F1E8F2F0E7F2EFE7F1EEE7F0EDE6EFEC\
E6EFEBE6EEEAE6EDE9E6EDE8E5ECE8E5ECE7E5EBE6E5EBE6E5EAE5E4EAE5E4E9E4
E4E9E4E4E9E3E4E8E2E4E7E2E4E7E1E4E6E0E3E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DF\
E3E5DEE3E5DEE3E5DEE3E4DDE3E4DDE2E4DDE2E4DDE2E4DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DCE2E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DE\
E2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E1
E2E6E1E2E7E1E2E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E8E4E3E9E5E3E9E5E3E9E6E3EAE7E3EBE8\
E3EBE9E3ECEAE4EDEBE4ECEAE4EAE5E4E5DDE4DFD3E4D9C8E4D3BFE4D0BAE4CFB8
E4CFB7E4D0B9E4D0BBE4D1BCE4D1BEE4D2BFE4D2C0E4D2C1E4D3C2E4D3C3E4D3C3E4D4C5E4D4C6\
E4D4C7E4D4C7E4D5C8E5D5C8E5D6C9E5D6CAE5D7CBE5D8CCE5D9CDE5DACEE5DBCF
E6DBCFE6DCD0E6DCD0E6DDD1E6DDD1E6DDD2E7DED2E7DED3E7DED3E7DED3E6DDD2E6DCD0E5DBCE\
E4DACCE4D8CAE4D6C8E4D4C6E4D2C5E4D1C3E3CFC1E3CEBFE2CDBEE2CCBDE2CBBC
E2CBBCE2CABCE2C9BCE1C7BBE1C6BAE0C5B9E0C5B9E0C6B9E0C7B9E0C7B9DFC6B8DEC3B6DCBFB4\
DBBBB1D9B8AFD8B6ADD6B6ADD6B6ACD5B8ADD5BAAFD5BCB1D5BEB3D5C0B4D4C0B5
D4C0B5D3C0B4D2BFB2D2BDB0D2BBADD2BAAAD2B8A8D2B7A7D2B6A6D1B6A5D1B5A4D0B4A3CFB4A2\
CEB4A3CFB6A5D0B9A9D3BFAFD7C6B8DBCFC3DFD9CFE3E3DDE6ECE9E9F4F2EAF8F8
EBFAFBEBFAFAEAF9F9EAF7F7E9F6F5E9F5F4E8F4F2E8F3F1E8F2F0E7F2EFE7F1EEE7F0EDE7EFEC\
E6EFEBE6EEEAE6EDE9E6EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EAE5E4EAE5E4EAE4
E4E9E4E4E9E3E4E8E2E4E7E2E4E6E0E4E5DFE3E4DEE3E4DEE3E4DEE3E5DEE3E5DFE3E5DFE3E5DF\
E3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DDE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DE\
E2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E1E2E6E1
E2E6E1E2E7E2E3E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E8E4E3E9E5E3E9E6E3EAE6E3EAE7E3EBE8\
E3EBE9E3ECEAE3ECEAE3EBE8E3E8E3E3E3DBE3DED1E3D8C7E3D3BFE3D0B9E4CFB7
E4CFB7E4D0B9E4D0BBE4D1BDE4D1BEE4D2C0E4D2C0E4D2C0E4D3C1E4D3C1E4D3C2E4D3C3E4D4C5\
E4D4C6E4D4C7E4D5C8E5D5C8E5D6C9E5D7CAE5D8CCE5D9CDE5DACEE5DBCFE5DBCF
E6DBCFE6DBCFE6DBCFE6DBCFE6DBD0E6DCD1E6DDD1E7DED2E7DED3E7DFD4E7DFD3E6DED2E6DDD0\
E5DBCEE5DACCE5D9CBE5D8C9E5D6C7E5D5C5E4D3C3E4D1C1E3CFBFE2CEBEE2CDBE
E2CBBEE2CABDE2C9BDE2C8BCE2C8BBE1C7BAE1C7B9E0C7B9E0C7B8DFC7B7DFC5B7DEC3B5DDC0B4\
DBBDB2DABAB1D9B9AFD7B8AED6B8ADD6B9ADD5BAADD5BBAED5BCAFD5BDB0D4BEB2
D4BFB3D3C0B4D3BFB3D2BEB1D1BCAED1BAABD0B7A8D0B6A5D0B5A4CFB4A3CFB4A2CEB3A1CEB3A1\
CEB3A2CFB6A5D1BBABD4C1B3D9CABEDDD3C9E1DDD6E4E6E2E7EFECE9F5F4EAF8F8
EAFAFAEAFAFAEAF8F8E9F7F6E9F6F5E9F5F3E8F4F2E8F3F1E8F2F0E7F2EFE7F1EEE7F0EDE7EFEC\
E6EFEBE6EEEAE6EEEAE6EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6E5EAE5E4EAE5
E4E9E4E4E9E3E4E8E3E4E7E1E4E6E0E4E5DFE4E4DEE3E3DDE3E4DDE3E4DEE3E5DEE3E5DFE3E5DF\
E3E5DFE3E5DEE3E5DEE3E5DEE3E4DDE3E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DDE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DE\
E2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1
E2E7E1E2E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E8E4E3E9E5E3E9E5E3EAE6E4EAE7E4EBE8E4EBE8\
E4EBE9E3EBE8E3EAE7E2E8E4E2E4DFE2E0D7E2DACDE2D5C4E3D2BDE3CFB9E4CFB7
E4CFB8E4D0B9E4D0BBE4D1BDE4D1BFE4D1C0E4D2C0E4D2C0E4D2BFE4D3C0E4D3C0E4D3C2E4D4C4\
E4D4C6E4D4C7E5D5C8E5D5C9E5D6C9E5D7CBE5D8CCE5DACDE5DBCEE5DBCFE5DBCF
E6DBCFE6DACEE6DACEE6DACEE6DBCFE6DBD0E6DCD1E7DED2E7DFD3E7DFD4E7DFD4E7DFD3E7DED2\
E6DCD0E7DBCFE7DBCDE7DACCE7D9CAE6D8C8E5D6C5E4D4C3E3D1C1E3CFBFE3CEBF
E3CCBEE3CBBEE3CABEE3C9BDE3C9BCE2C9BBE2C8B9E1C8B8E0C7B7DFC6B6DEC4B6DEC2B5DDC0B4\
DCBEB3DBBCB2DABBB1D8BBAFD7BBAED6BAADD5BAACD5BAABD5BAABD5BAACD4BCAE
D4BDB1D3BFB3D3BFB3D2BEB1D1BCAED0B9AACFB7A7CFB5A4CEB4A3CEB3A2CEB3A1CDB2A0CDB29F\
CDB3A1CEB6A5D1BCADD5C4B7DACDC3DFD8D0E3E1DCE6EAE6E8F1EFE9F5F5EAF8F8
EAF9F9EAF9F9EAF8F8E9F7F6E9F6F5E9F5F3E8F4F2E8F3F1E8F2F0E7F2EFE7F1EEE7F0EDE7F0EC\
E6EFEBE6EEEBE6EEEAE6EDE9E5EDE8E5ECE8E5ECE7E5EBE6E5EBE6E5EAE5E4EAE5
E4EAE4E4E9E4E4E8E3E4E7E2E4E6E0E4E4DFE4E3DDE3E3DDE3E3DDE3E4DEE3E5DFE3E5DFE3E6DF\
E3E6DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DCE2E2DAE2E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DE\
E2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E5E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1
E2E7E2E3E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E8E4E3E9E5E3E9E5E3EAE6E4EBE8E5ECE9E5ECE9\
E4EBE8E3E9E6E1E5E2E0E1DCDFDDD6DFD9CEE0D5C7E1D2C0E2D0BBE3CFB9E4CFB8
E4CFB9E4D0BAE4D0BCE4D1BEE4D1BFE4D1BFE4D2BFE4D2BFE4D2BEE4D2BEE4D3BFE4D3C1E4D3C3\
E4D4C5E4D4C7E5D5C8E5D6C9E5D7CAE5D8CBE5D9CCE5DACDE5DBCEE5DBCFE5DBCF
E6DBCEE6DACEE6DACEE6DACEE6DBCFE6DBD0E6DCD1E7DED2E7DFD4E7E0D4E7E0D5E7DFD4E7DED3\
E7DDD2E7DCD0E8DCCFE8DCCEE8DBCCE7DACAE6D8C7E5D6C5E4D3C2E4D1C0E4CFBF
E4CDBFE4CCBEE4CBBEE4CABDE3CABCE3C9BBE2C9B9E1C8B8E0C7B7DFC6B6DEC4B5DEC2B4DDC0B4\
DDBEB3DCBDB2DBBCB1D9BCB0D8BCAED7BBACD6BAAAD5B9A9D5B8A8D4B8A9D4B9AB
D3BBAED3BDB0D2BDB1D1BCAFCFBBACCEB8A9CEB6A5CEB4A3CEB3A2CEB2A0CDB19FCDB19ECCB19E\
CDB2A0CEB6A5D2BDAED6C6BADBD1C8E0DBD5E4E5E1E6ECEAE8F2F1E9F6F6EAF8F8
EAF9F9EAF9F8EAF8F7E9F7F6E9F6F4E8F5F3E8F4F2E8F3F1E8F2F0E7F2EFE7F1EEE7F0EDE7F0EC\
E6EFECE6EEEBE6EEEAE6EDE9E6EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EAE6E5EAE5
E4EAE5E4E9E4E4E8E3E4E7E2E4E6E0E4E5DFE4E4DEE4E3DDE3E4DEE3E4DEE3E5DFE3E6DFE3E6DF\
E3E6DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DDE3E4DDE2E3DCE2E2DCE2E2DBE2E1DA
E2E1DAE2E1DAE2E1D9E2E1D9E2E1DAE2E1DAE2E1DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE1E1DAE1E1DAE1E1DAE2E1DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DD
E2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DF\
E2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E2
E2E7E2E3E7E2E3E7E3E3E8E3E3E8E3E3E8E4E3E8E4E3E9E5E3E9E5E3EAE7E4EBE8E5ECE9E5ECE9\
E4EAE7E1E5E1DFDFDADCD9D2DBD3CADBD0C4DDCEBFDFCEBBE2CEB9E3CEB8E4CFB9
E4CFBAE4D0BBE4D0BDE4D0BEE4D1BEE4D1BEE4D1BEE4D2BEE4D2BDE4D2BEE4D3BFE4D3C0E4D3C3\
E4D4C5E5D5C7E5D6C8E5D7CAE5D7CBE5D8CBE5D9CCE5DACDE5DACDE5DACEE5DACE
E6DBCEE6DBCEE6DBCFE6DBCFE6DBCFE6DCD0E6DDD1E7DED3E7DFD4E7E0D5E7E0D5E7DFD4E7DED3\
E8DDD2E8DDD1E8DCD0E8DCCFE8DCCEE8DBCCE7D9C9E6D7C6E6D5C3E5D2C1E5D0C0
E5CEBFE5CDBEE5CCBEE5CBBDE4CABBE3CABAE3C9B9E2C9B8E1C8B7E0C6B6DFC5B5DEC3B5DEC1B4\
DDBFB3DCBDB2DBBCB1DABCAFD9BCADD8BBABD7BAA9D6B8A7D5B7A6D4B7A6D3B7A8
D2B9AAD1BAACD0BBADCFBAACCEB9AACDB7A7CDB5A4CDB3A2CEB2A1CEB2A0CEB19ECDB09DCDB09D\
CDB29FCEB6A5D2BEAFD6C8BDDBD3CCE0DEDAE4E7E5E7EFEEE9F4F3E9F7F7EAF8F8
EAF9F8EAF8F8E9F7F6E9F6F5E9F5F4E8F4F3E8F4F2E8F3F1E8F2F0E7F2EFE7F1EEE7F0EDE7F0EC\
E6EFECE6EEEBE6EEEAE6EDE9E6EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6E5EAE5
E4EAE5E4E9E4E4E9E3E4E8E2E4E7E1E4E5E0E4E5DFE4E4DEE3E4DEE3E5DFE3E5DFE3E6DFE3E6DF\
E3E6DFE3E6DFE3E5DFE3E5DEE3E5DEE3E4DDE3E4DDE2E3DCE2E2DBE2E1DAE2E0D9
E2E0D8E2DFD8E2DFD8E2DFD8E2E0D9E2E1D9E2E1DAE2E1DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DD
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DF\
E2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E7E1E2E7E2
E3E7E2E3E7E2E3E7E3E3E8E3E3E8E4E3E8E4E3E9E4E3E9E5E3E9E5E3EAE6E3EAE7E3EBE7E3E9E6\
E1E6E2DEDFDADBD7D0D8CFC6D7C9BED8C7B8DBC8B6DECAB6E1CCB7E3CEB8E4CFBA
E4CFBBE4D0BDE4D0BDE4D0BEE4D1BEE4D1BDE4D1BDE4D1BDE4D2BDE4D2BDE4D2BEE4D3C0E4D3C2\
E4D4C5E5D5C7E5D6C9E5D7CAE5D8CBE5D9CCE5D9CCE5D9CCE5D9CCE5D9CCE5DACD
E6DACEE6DBCEE6DCCFE6DCD0E6DDD0E6DDD1E6DED2E6DFD3E7E0D4E7E0D4E7E0D4E7DFD4E7DED3\
E8DDD2E8DCD1E8DCD0E8DCD0E8DCCFE8DBCDE8DACAE7D8C7E7D6C5E7D4C2E7D2C1
E7D0BFE6CEBEE6CDBDE5CCBCE5CBBBE4CABAE3C9B8E2C8B8E1C8B7E1C7B6E0C5B5DFC3B5DEC1B4\
DDBFB3DCBDB1DBBCB0DBBCAEDABBACD9BAAAD8B9A8D6B8A6D5B6A5D4B5A5D3B6A5
D1B6A7D0B7A8CFB8A9CEB7A8CDB6A6CDB5A5CDB4A3CDB3A1CEB2A0CFB19FCFB09ECEAF9DCDAF9D\
CDB19FCFB6A6D2BFB1D6C9BFDBD5CFE0E1DDE4EAE9E7F0F0E9F5F5E9F7F7EAF8F8
EAF8F8EAF8F7E9F7F6E9F6F5E9F5F4E8F4F3E8F4F2E8F3F1E8F2F0E7F2EFE7F1EEE7F0EDE7F0EC\
E6EFECE6EFEBE6EEEAE6EDEAE6EDE9E5ECE8E5ECE8E5ECE7E5EBE6E5EBE6E5EAE5
E4EAE5E4E9E4E4E9E3E4E8E3E4E7E2E4E6E1E4E6E0E4E5E0E4E5DFE3E5DFE3E6E0E3E6E0E3E6E0\
E3E6DFE3E6DFE3E5DFE3E5DFE3E5DEE3E4DEE3E3DDE3E2DCE2E1DAE2E0D9E2DFD8
E2DED7E2DED7E2DED7E2DED7E2DFD8E2E0D9E2E1D9E2E1DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DD
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DF\
E2E5DFE2E5DFE2E5E0E2E5E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E2E2E7E2
E3E7E2E3E7E3E3E8E3E3E8E3E3E8E4E3E9E4E3E9E5E3E9E5E2E9E5E1E8E4E0E8E4DFE6E2DDE3DE\
DADDD8D7D5CFD4CDC4D3C5B9D3C0B2D5C0AFD9C3AFDDC7B2E1CBB5E3CEB8E4CFBB
E4D0BDE4D0BEE4D0BEE4D0BEE4D0BDE4D1BDE4D1BCE4D1BCE4D2BCE4D2BDE4D2BFE4D2C0E4D3C3\
E4D4C5E5D5C7E5D7C9E5D8CBE5D9CCE5D9CCE5D9CCE5D8CBE5D8CBE5D8CBE5D9CC
E6DACDE6DBCEE6DCCFE6DDD0E6DED1E6DED2E6DFD2E6DFD3E7E0D4E7E0D4E7DFD4E7DED3E7DDD2\
E8DDD1E8DCD1E8DCD0E8DCD0E8DCCFE8DCCDE8DBCBE8D9C8E8D7C6E8D5C3E8D3C1
E8D1C0E7CFBEE7CDBDE6CCBBE5CABAE4C9B9E3C8B8E2C8B7E2C7B7E2C7B6E1C5B6E0C3B5DFC1B3\
DDBEB2DCBDB0DBBBAEDBBBACDABAAAD9B9A9D8B8A7D7B7A5D5B6A4D3B5A4D2B5A4
D1B5A4CFB5A4CEB5A4CDB5A4CCB4A3CCB3A2CDB3A1CDB2A1CEB2A0CFB29FD0B19ECFB09DCEB09D\
CEB29FCFB7A6D2C0B2D7CBC1DCD8D1E0E3E0E4ECEBE7F2F3E9F6F6E9F7F8EAF8F8
EAF8F7E9F7F7E9F6F5E9F6F4E8F5F3E8F4F2E8F3F1E8F3F1E7F2F0E7F1EFE7F1EEE7F0EDE7F0EC\
E6EFECE6EFEBE6EEEAE6EDEAE6EDE9E5EDE8E5ECE8E5ECE7E5EBE6E5EBE6E5EAE5
E5EAE5E4EAE4E4E9E4E4E8E3E4E8E2E4E7E2E4E7E1E4E6E1E4E6E0E3E6E0E3E6E0E3E6E0E3E6E0\
E3E6DFE3E6DFE3E5DFE3E5DFE3E5DEE3E4DEE3E3DDE3E2DBE2E1DAE2E0D9E2DED7
E2DED7E2DDD6E2DDD6E2DED7E2DFD7E2E0D8E2E1D9E2E1DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DF\
E2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E7E1E2E7E2E3E7E2
E3E7E2E3E7E3E3E8E3E3E8E3E3E9E4E3E9E5E4EAE6E3EAE6E2E9E5DFE6E2DBE2DED7DDD8D3D6D1\
CFCFC8CDC8BFCCC1B6CDBCAED0BAAAD4BCA9D9C1ACDDC6B0E1CBB5E3CEB8E4CFBB
E4D0BDE4D0BEE4D0BFE4D0BEE4D0BEE4D1BDE4D1BDE4D1BDE4D1BDE4D2BEE4D2BFE4D2C1E4D3C3\
E4D4C5E5D5C7E5D7C9E5D9CBE5DACCE5DACCE5D9CCE5D8CBE5D7CAE5D7CAE5D8CA
E6D9CBE6DBCCE6DCCEE6DDCFE6DED0E6DFD2E6DFD2E6DFD3E7DFD3E7DFD3E7DED2E7DDD2E7DDD1\
E7DCD0E8DCD0E8DCD0E8DCCFE8DCCEE8DCCDE9DBCBE9DAC9E9D8C7E9D6C4E8D4C2
E8D1C0E7CFBEE6CDBCE5CBBBE4C9B9E3C8B8E3C8B7E3C7B7E2C7B7E2C6B6E1C5B5E0C3B4DFC1B2\
DDBEB0DCBCAEDBBBACDABAAAD9B9A8D9B8A7D7B7A5D6B6A4D5B5A4D3B4A3D2B4A3
D0B3A2CFB3A2CEB3A1CDB2A1CCB2A1CCB2A0CCB2A0CDB2A0CFB3A0D0B3A0D0B29FD0B19ECFB19E\
CFB3A0D0B8A7D3C1B3D8CDC3DDDAD4E1E6E3E5EEEEE7F4F4E9F7F7E9F8F8EAF8F8
E9F7F7E9F7F6E9F6F5E9F5F4E8F5F3E8F4F2E8F3F1E8F3F0E7F2F0E7F1EFE7F1EEE7F0EDE7F0EC\
E6EFECE6EFEBE6EEEAE6EEEAE6EDE9E5EDE8E5ECE8E5ECE7E5EBE7E5EBE6E5EAE6
E5EAE5E4EAE4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E4E7E1E3E7E0E3E6E0E3E6E0\
E3E6E0E3E6DFE3E6DFE3E5DFE3E5DEE3E4DEE3E4DDE3E2DCE3E1DAE2E0D9E2DFD8
E2DED7E2DED7E2DED7E2DED7E2DFD8E2E0D9E2E1D9E2E1DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DF\
E2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E3E7E2
E3E7E2E3E7E3E3E8E3E3E8E4E3E9E4E4EAE6E4EBE7E4EAE7E1E8E4DCE3DED5DAD5CCD0CAC4C5BE\
BFBDB4BFB7ACC2B4A6C8B5A4CEB7A5D5BCA7DAC1ABDFC7B0E2CBB5E3CEB8E4CFBB
E4CFBDE4CFBEE4D0BFE4D0BFE4D0BEE4D0BEE4D1BEE4D1BEE4D1BEE4D1BFE4D2C0E4D2C1E4D3C3\
E5D4C5E5D5C7E5D7C9E5D9CBE5DACCE5DACCE5D9CCE5D8CAE5D7C9E5D6C9E5D7C8
E6D8C9E6DACAE6DBCCE6DDCEE6DECFE6DED1E6DFD2E6DFD2E7DED2E7DDD2E7DDD1E7DCD0E7DCD0\
E7DBCFE7DBCFE8DBCEE8DBCEE8DCCDE8DCCCE9DBCBE9DBC9E9D9C7E9D7C5E8D4C3
E7D1C0E7CEBEE6CBBCE5CABAE4C8B8E3C7B7E3C7B7E3C6B6E3C5B6E2C5B6E2C3B5E0C2B3DFC0B1\
DDBEAEDCBCACDABBAAD9B9A8D8B8A6D7B7A5D6B6A4D5B5A4D4B5A3D3B5A3D2B4A2
D1B3A1D0B2A0CEB1A0CDB19FCCB19FCCB19FCCB19FCDB2A0CFB3A1D0B4A1D1B4A0D0B39FD0B39F\
D0B4A1D1B9A8D5C3B5D9CFC5DEDCD6E2E8E5E6F0F0E8F5F6E9F8F8E9F8F8E9F8F7
E9F7F6E9F6F5E9F6F5E9F5F4E8F4F3E8F4F2E8F3F1E8F2F0E7F2EFE7F1EFE7F1EEE7F0EDE7F0EC\
E6EFECE6EFEBE6EEEAE6EEEAE6EDE9E5EDE8E5ECE8E5ECE7E5EBE7E5EBE6E5EAE6
E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E6E0E3E6E0\
E3E6E0E3E6DFE3E6DFE3E5DFE3E5DEE3E5DEE3E4DDE3E3DCE3E2DBE2E1DAE2E0D9
E2DFD8E2DFD8E2DFD8E2DFD8E2E0D8E2E0D9E2E1DAE2E2DAE2E2DAE3E3DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD
E2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DF\
E2E5E0E2E5E0E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E7E1E2E7E2E2E7E2E3E7E2
E3E7E3E3E8E3E3E8E3E3E8E4E3E9E5E4EAE6E5EBE7E4EBE7E0E7E3D8DEDACCD0CBBFC0BAB4B1A9\
AEA79DAFA497B7A798C2AE9CCDB6A2D6BEA8DCC4ADE0C9B1E2CCB5E4CEB8E4CFBB
E4CFBDE4CFBFE4D0BFE4D0C0E4D0BFE4D0BFE4D1BFE4D1BFE4D1C0E4D1C0E4D2C1E4D2C2E4D2C3\
E5D4C5E5D5C7E5D7C9E5D8CBE5D9CCE5D9CCE5D9CBE5D8CAE5D7C9E5D6C8E5D6C7
E6D7C7E6D9C8E6DAC9E6DCCCE6DDCEE6DED0E6DED1E6DED1E7DDD1E7DCD0E7DBCFE7DACFE7DACE\
E7DACEE7DACDE8DACDE8DACCE8DACBE8DBCAE8DBC9E8DAC8E8D9C6E8D7C5E7D3C2
E6D0C0E5CDBDE4CABBE3C8B9E3C7B7E3C6B6E2C6B6E2C5B6E2C4B6E2C3B5E1C2B4E0C1B2DFC0AF\
DDBEACDBBDAADABAA7D8B8A5D7B6A4D6B5A3D5B5A3D4B5A3D3B5A3D3B5A3D2B4A2
D1B3A1D0B2A0CFB19ECEB09ECDB09DCCB09DCCB19ECDB2A0CEB4A1CFB5A2D0B5A2D0B4A0D0B4A0\
D1B6A2D2BBA9D6C4B6DAD1C7DFDED8E3EAE7E7F2F2E8F7F7E9F8F9E9F8F8E9F8F7
E9F7F6E9F6F5E9F5F4E8F5F3E8F4F2E8F3F2E8F3F1E8F2F0E7F2EFE7F1EFE7F1EEE7F0EDE7F0EC\
E6EFECE6EFEBE6EEEAE6EEEAE6EDE9E5EDE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E9E3E4E8E3E4E8E2E4E8E2E4E7E1E3E7E1E3E7E0E3E6E0\
E3E6E0E3E6DFE3E6DFE3E5DFE3E5DEE3E5DEE3E4DDE3E3DDE3E2DCE3E2DBE2E1DA
E2E0DAE2E0D9E2E0D9E2E0D9E2E1D9E2E1DAE2E1DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E2DAE2E1D9E2E1D9E2E1D9E2E1DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD
E2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DF\
E2E5E0E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E3E7E2E3E7E2
E3E7E3E3E8E3E3E8E3E3E8E4E3E9E5E4EAE6E5EBE8E4EAE6DEE4E1D4D7D4C3C4C0B1AFA9A29D94\
9B9186A09284AC9B8ABCA895CCB6A1D8C0AADFC7B0E2CBB4E3CDB6E4CEB9E4CFBB
E4CFBDE4D0BFE4D0C0E4D0C0E4D0C0E4D0C0E4D1C1E4D1C1E4D1C1E4D2C2E4D2C2E4D2C3E4D3C4\
E5D3C5E5D5C7E5D6C8E5D8CAE5D9CBE5D9CCE5D8CBE5D8CAE5D7C9E5D6C8E5D6C7
E6D7C6E6D8C6E6D9C8E6DBCAE6DCCDE6DDCFE6DDD0E6DCD0E7DCCFE7DACEE7D9CDE7D9CDE7D8CC\
E7D8CCE7D8CBE7D8CAE7D8C9E7D8C7E7D8C6E7D8C6E7D8C5E7D7C4E7D5C3E6D2C1
E5CEBEE4CBBCE3C8BAE2C7B8E2C6B7E2C6B6E2C5B5E2C4B5E2C3B5E1C2B4E1C1B3DFC0B1DEBFAE\
DCBEABDABCA8D9BAA5D7B8A3D6B6A2D5B4A2D4B4A2D3B5A3D3B5A3D2B5A3D2B4A2
D1B3A0D0B29FCFB09DCEAF9CCDAF9CCCAF9CCCB09DCCB29FCDB4A1CFB5A2D0B6A2D0B5A1D0B4A0\
D1B6A3D3BBAAD6C5B7DBD2C8E0E0DAE4ECE9E7F4F3E9F8F8EAF9F9EAF8F8E9F7F7
E9F6F6E9F6F5E8F5F4E8F4F3E8F4F2E8F3F1E8F3F1E7F2F0E7F2EFE7F1EEE7F1EEE7F0EDE6EFEC\
E6EFECE6EEEBE6EEEAE6EEEAE6EDE9E5EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E9E3E4E8E3E4E8E2E4E8E2E4E7E1E3E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E4DEE3E4DDE3E3DDE3E3DCE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E8E0E6E6DEE4E3DBE2E1DAE2E0D9E2E0D9E2E0D9E2E1D9E2E1D9E2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD
E2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0\
E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E2E2E7E2E3E7E2E3E7E2
E3E8E3E3E8E3E3E8E4E3E8E4E3E9E5E4E9E6E4EAE7E2E7E5DBDFDDCED0CDB9B8B4A49E99928981\
8B7D73918173A28F7FB8A390CCB6A1DAC3ACE1CAB3E4CEB6E4CEB7E4CFB9E4D0BB
E4D0BEE4D0BFE4D0C1E4D0C1E4D1C1E4D1C2E4D1C2E4D2C2E4D2C3E4D2C3E4D3C4E4D3C4E4D3C4\
E5D3C5E5D4C6E5D6C8E5D7C9E5D8CAE5D8CBE5D8CBE5D8CAE5D7C9E5D7C8E5D7C7
E6D7C6E6D8C7E6D9C8E6DACAE6DBCCE6DCCDE6DCCEE6DBCEE7DACDE7D9CCE7D8CBE7D6CAE7D5CA\
E7D5C9E7D4C8E7D4C6E7D4C5E6D4C3E6D4C2E6D4C1E5D4C0E5D3C0E4D1BFE4CEBD
E3CBBCE2C9BAE2C6B8E2C5B7E2C5B6E2C5B5E2C5B5E1C4B4E1C3B4E0C2B4DFC1B2DEC0B0DCBFAD\
DABDA9D9BCA6D8B9A4D6B7A2D5B5A1D5B4A1D4B4A2D3B5A2D3B5A3D2B5A3D2B5A1
D1B3A0D0B19ECFB09CCEAF9BCDAE9BCCAF9BCBB09CCCB19ECDB3A0CEB4A1CEB5A1CFB4A0CFB39F\
D0B5A2D2BBA9D6C5B6DBD2C8E0E1DAE5EDEAE8F5F4EAF9F9EAF9FAEAF8F8E9F7F7
E9F6F5E9F5F4E8F5F3E8F4F3E8F4F2E8F3F1E8F3F0E7F2F0E7F1EFE7F1EEE7F0EEE7F0EDE6EFEC\
E6EFECE6EEEBE6EEEAE6EEEAE6EDE9E5EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E4EAE5E4EAE4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E1E4E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE3E4DDE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E0E6E6DEE4E3DBE2E1D9E2E0D8E2DFD8E2DFD8E2E0D8E2E1D9E2E1DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD
E2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0\
E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E2E7E2E3E7E2E3E7E3
E3E8E3E3E8E3E3E9E4E3E9E4E3E9E5E3E8E5E2E7E5DFE3E1D6D8D7C7C6C5B0ABA9988F8B857871\
7E6D648774679B8677B49F8DCCB5A1DBC4AEE3CCB5E6CFB8E5D0B8E5D0BAE4D0BC
E4D1BEE4D1C0E4D1C2E4D1C2E4D1C2E4D1C2E4D1C3E4D2C3E4D3C4E4D3C5E4D3C5E4D3C5E4D3C5\
E5D3C5E5D4C6E5D5C7E5D6C8E5D7C9E5D7CAE5D8CAE5D8CAE5D8CAE5D8C9E5D8C9
E6D8C8E6D9C8E6D9C9E6DACAE6DACBE6DACCE6DACCE6DACCE7D9CBE7D8C9E7D6C8E7D4C7E7D2C7\
E7D1C6E7D0C4E6CFC2E6CFC0E5CFBEE4CFBDE3CFBBE3CFBBE2CEBAE2CCB9E1CAB9
E1C8B8E1C6B7E1C5B6E1C5B5E1C4B4E1C4B4E1C4B4E1C4B4E0C3B4DFC2B3DEC1B1DCBFAFDABEAC\
D9BCA8D7BAA5D6B8A3D6B6A2D6B5A1D5B4A1D4B4A2D4B5A2D3B5A3D2B5A2D1B4A0
D0B39ECFB19CCEAF9ACDAE99CCAE99CBAE9ACBAF9BCBB09DCCB29ECCB29FCDB39FCDB29DCDB19D\
CEB3A0D1B9A7D5C4B5DBD2C7E0E1DAE5EDEAE8F5F4EAF9F9EAF9F9EAF8F8E9F7F6
E9F6F5E8F5F4E8F4F3E8F4F2E8F3F2E8F3F1E7F2F0E7F2EFE7F1EFE7F1EEE7F0EDE7F0EDE6EFEC\
E6EFEBE6EEEBE6EEEAE6EDEAE6EDE9E5EDE9E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E4EAE5E4EAE4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DDE3E4DDE3E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E6DEE4E3DBE2E0D8E2DFD7E2DED7E2DED7E2DFD8E2E0D9E2E1D9\
E2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DE
E2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0\
E2E6E0E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E2E7E2E3E7E2E3E8E3
E3E8E3E3E9E4E4E9E5E4E9E5E3E9E5E2E7E4DFE3E1DADCDBCFCFCFBEBBBAA69F9D8E827F7C6C66\
76635B816C61988274B49D8CCDB6A3DDC6B1E5CEB7E7D0B9E6D0B9E5D0BAE4D1BC
E4D2BFE4D2C1E4D2C2E4D2C3E4D1C2E4D1C2E4D2C3E4D2C4E4D3C5E4D4C6E4D4C6E4D4C6E4D3C5\
E5D3C5E5D3C5E5D4C5E5D4C6E5D5C7E5D6C8E5D7C9E5D8CAE5D9CAE5D9CBE5D9CA
E6DACAE6DACAE6DACAE6DACBE6D9CBE6D9CBE6D9CBE6D9CAE6D8C8E7D7C7E7D5C6E7D2C5E7CFC4\
E7CDC2E6CBC0E6CABEE4CABCE3CAB9E2CAB7E1C9B6E0C9B5DFC8B4DFC7B4DFC6B4
DFC5B4E0C4B4E0C4B4E1C4B3E1C4B3E1C4B3E1C4B3E0C4B3DFC3B3DDC2B2DCC1B0DABFAED8BDAA\
D7BBA7D6B9A4D5B7A3D6B6A1D6B5A1D6B4A1D5B4A2D4B5A2D3B5A2D2B5A1D0B49F
CFB29DCEB09ACDAF98CCAE98CBAD98CBAD99CAAE9ACAAF9BCBB09CCBB09CCBB09CCBAF9ACCAF9A\
CDB19DD0B7A5D4C2B4DAD1C6E0E0D9E5ECE9E8F4F3EAF8F8EAF9F9E9F8F7E9F6F6
E9F5F4E8F5F3E8F4F3E8F4F2E8F3F1E8F3F1E7F2F0E7F2EFE7F1EFE7F1EEE7F0EDE7F0EDE6EFEC\
E6EFEBE6EEEBE6EEEAE6EDEAE6EDE9E5EDE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E5EAE5E4EAE4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E0\
E3E6E0E3E6E0E3E6DFE3E6DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D8E2DED6E2DED6E2DED6E2DFD7E2E0D8E2E1D9\
E2E1DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DE
E2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0\
E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E2E7E2E2E7E2E3E7E2E3E8E3
E3E8E4E4EAE5E5EBE6E5EBE6E4E9E5E0E5E2DBDEDCD2D3D2C5C2C2B3ADAD9D9291877875786661\
766158836C619B8376B69F8FCFB7A5DEC7B3E5CFB9E7D1BAE6D0BAE5D0BBE4D1BD
E4D2BFE4D3C2E4D2C3E4D2C3E4D1C2E4D1C2E4D2C3E4D3C4E4D4C5E4D5C6E4D5C6E4D4C6E4D4C5\
E5D3C5E5D3C4E5D3C4E5D3C5E5D4C6E5D5C7E5D6C8E5D8CAE5D9CBE5DACBE5DACC
E6DBCCE6DBCCE6DACCE6DACBE6D9CBE6D8CAE6D8C9E6D8C8E6D7C6E6D6C5E6D4C3E6D0C2E6CDC1\
E6C9BFE5C7BDE5C6BAE3C6B8E2C6B5E0C5B3DFC5B1DDC4B0DDC3AFDCC2AFDDC2AF
DEC2B0DFC3B1DFC3B1E0C3B1E0C3B1E0C3B1E0C3B1DFC3B1DEC3B1DCC2B0DAC1AFD8BFACD6BCA9\
D5BAA6D4B8A4D4B6A2D5B5A1D6B4A1D6B4A1D6B4A1D5B4A2D3B4A1D2B4A0D0B39E
CEB19BCDB099CCAE97CBAD96CBAD97CAAD98CAAD99CAAD9ACAAE9ACAAE9ACAAD99CAAC98CAAC98\
CCAF9BCEB6A3D3C1B2D9CFC4DFDED6E4EAE6E8F3F1E9F7F6EAF8F7E9F7F6E9F6F5
E8F5F4E8F4F3E8F4F2E8F3F2E8F3F1E7F2F0E7F2F0E7F1EFE7F1EEE7F0EEE7F0EDE6F0EDE6EFEC\
E6EFEBE6EEEBE6EEEAE6EDEAE6EDE9E5EDE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6DFE3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E2E4DDE2E4DDE2E4DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E6DEE4E3DBE2E0D8E2DED7E2DED6E2DED6E2DED6E2DFD7E2E0D8\
E2E0D9E2E1D9E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DE
E2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E5E0E2E6E0\
E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E2E7E2E2E7E2E2E7E2E3E8E3
E4E9E4E5EAE6E6ECE8E7EDE9E5EAE6DFE3E0D5D7D5C8C6C5B7B2B1A59C9A93858384736E7C6861\
7F685E8E766AA48C7DBDA594D2BAA8DFC8B4E6CFBAE7D1BBE6D0BBE5D0BCE4D1BD
E4D2C0E4D2C2E4D2C2E4D2C2E4D1C2E4D1C2E4D1C3E4D2C4E4D4C5E4D4C6E4D5C6E4D4C6E4D3C5\
E5D3C4E5D2C4E5D2C4E5D2C4E5D3C5E5D4C6E5D5C7E5D7C9E5D8CAE5DACBE5DACC
E5DBCDE6DBCDE6DBCDE6DACCE6D9CBE6D8C9E6D7C8E5D7C6E5D6C4E5D5C3E5D2C1E5CFBFE5CBBE\
E5C7BCE4C4BAE3C3B7E2C3B5E1C3B2DFC2B0DDC1AEDCC0ACDBBFABDABFABDBBFAC
DCC0ADDDC1AEDEC2AFDFC2AFDFC2AFDFC2AFDFC2AFDEC2AFDCC2AFDBC1AED9C0ACD7BEAAD5BBA8\
D4B9A5D3B6A3D3B5A1D4B4A1D5B4A0D6B3A0D5B3A0D4B3A0D3B3A0D1B29ED0B19C
CEB09ACDAF98CCAE96CCAD96CBAC96CBAC97CBAC98CAAC98CAAC98CAAC98C9AB97C9AA96C9AB96\
CBAE9ACEB4A2D3BFB0D8CDC1DEDBD3E3E7E2E7EFEDE9F4F3E9F6F5E9F6F5E9F5F4
E8F5F3E8F4F3E8F4F2E8F3F1E8F3F1E7F2F0E7F2EFE7F1EFE7F1EEE7F0EEE7F0EDE6EFECE6EFEC\
E6EFEBE6EEEBE6EEEAE6EDE9E6EDE9E5EDE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E6DEE4E3DBE2E0D9E2DFD7E2DED7E2DED6E2DED6E2DED7E2DFD7\
E2DFD8E2E0D9E2E1D9E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DE
E2E4DEE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0\
E2E6E0E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E2E7E2E2E7E2E2E7E2E3E8E3
E4E9E4E5EBE6E7EEE9E8EEEAE5EBE7DDE1DDCECFCBBBB8B5A7A09D968A868A7A7585726A877167\
90786B9F8778B29A89C6AE9BD6BEABE0C9B5E5CEBAE6D0BBE5D0BBE4D0BCE4D0BE
E4D1BFE4D1C1E4D2C2E4D1C2E4D1C1E4D1C1E4D1C2E4D2C3E4D3C4E4D4C5E4D4C5E4D3C5E4D3C4\
E5D2C4E5D2C3E5D2C3E5D2C4E5D3C4E5D3C5E5D5C6E5D6C8E5D7C9E5D9CBE5DACC
E5DBCDE6DBCEE6DBCDE6DACCE6D8CBE6D7C9E5D6C7E5D6C5E4D5C3E4D3C1E4D1BFE3CDBDE3C9BB\
E3C5B9E3C2B7E2C1B5E1C1B2E0C1B0DEC0AEDDBFABDBBEAADABDA9D9BCA8DABDA9
DBBEAADCBFABDDC0ACDDC0ADDDC0ADDDC0ADDDC0ADDCC0ACDBC0ACDAC0ABD8BFA9D6BDA7D4BAA6\
D3B8A4D2B5A2D3B4A1D3B3A0D4B29FD5B29FD4B29FD4B19ED3B19ED1B09DD0B09B
CFAF99CEAE97CDAD96CCAC96CCAC96CCAC97CCAB97CBAB97CAAB97CAAA96C9AA96C9AA95C9AA96\
CBAD99CEB4A1D3BDADD8CABDDED6CEE2E2DDE6EBE7E8F0EEE8F3F2E8F4F3E8F5F3
E8F5F3E8F4F3E8F4F2E8F3F1E7F2F0E7F2F0E7F2EFE7F1EFE7F1EEE7F0EDE7F0EDE6EFECE6EFEC\
E6EEEBE6EEEBE6EEEAE6EDE9E6EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E8E0E6E6DEE4E3DBE2E1D9E2E0D8E2DFD7E2DED7E2DED6E2DED6E2DED6\
E2DFD7E2DFD8E2E1D9E2E1DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DB
E2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DE
E2E4DEE2E4DEE2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E5E0E2E6E0E2E6E0\
E2E6E0E2E6E1E2E6E1E2E6E1E2E6E1E2E7E1E3E7E2E3E7E2E3E7E2E2E7E2E3E8E3
E3E9E4E5EAE6E7EDE8E7EDE8E2E8E3D7DAD6C4C4BFAEA9A4988F898A7C7486746A8A766A957F71\
A48D7CB49C89C3AB97D0B8A4DBC3AEE1CAB5E5CEB9E5CFBBE5CFBCE4CFBCE4CFBE
E4D0BFE4D0C0E4D0C1E4D0C1E4D0C1E4D0C1E4D1C1E4D1C2E4D2C3E4D2C3E4D3C4E4D3C4E4D2C3\
E5D2C3E5D2C3E5D2C3E5D2C3E5D2C4E5D3C5E5D4C6E5D5C7E5D6C8E5D8CAE5D9CB
E5DACCE6DBCDE6DBCDE6DACCE6D8CAE6D6C8E5D5C6E4D4C3E3D3C1E3D1BEE2CEBCE2CABAE2C6B8\
E2C3B6E1C0B4E1BFB2E0BEB0DFBEAEDEBEABDCBCA9DBBBA8D9BAA6D9BAA6D9BAA6
D9BBA7DABCA8DBBDA9DBBDAADCBDAADCBEAADBBEAADBBEA9DABEA8D9BEA7D8BDA6D6BBA5D4B9A3\
D3B6A2D2B4A0D2B29FD2B19ED3B09DD3B09DD3AF9CD3AF9CD2AF9BD1AF9BD0AE9A
CFAD98CEAD97CEAC96CEAC96CEAB96CDAB96CDAB96CCAB96CBAA96CAAA95C9A995C9A994CAAA95\
CCAD99CEB3A0D3BBAAD7C6B8DCD1C7E1DCD5E4E5E0E6ECE9E7F0EEE8F3F1E8F4F3
E8F4F3E8F4F3E8F4F2E8F3F1E7F2F0E7F2EFE7F1EFE7F1EEE7F0EEE7F0EDE6F0EDE6EFECE6EFEB\
E6EEEBE6EEEAE6EEEAE6EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E5EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E7E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E5DCE9E9E1E9E8E0E6E6DEE4E3DCE2E1DAE2E0D9E2E0D8E2DFD7E2DED6E2DDD6E2DDD6\
E2DED6E2DFD8E2E0D9E2E1DAE2E2DBE2E2DBE2E3DBE2E3DBE2E2DBE2E3DBE2E3DB
E2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DE
E2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0\
E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E3E7E2E3E7E2E3E8E3E3E8E3E3E8E3
E3E8E3E3E8E3E3E8E4E1E6E1DBDED9CECFC9B9B6B0A29B948F837A847469877467947F70A6907E\
B9A18EC7AF9AD2BAA4DAC2ABDFC7B1E2CBB5E4CDB8E4CEBAE4CEBCE4CEBDE4CEBE
E4CFBEE4CFBFE4CFC0E4CFC0E4D0C0E4D0C0E4D0C1E4D0C1E4D1C1E4D1C2E4D2C2E4D2C2E4D2C3\
E5D1C3E5D1C3E5D2C3E5D2C3E5D2C4E5D3C4E5D3C5E5D4C6E5D5C7E5D7C9E5D8CA
E5DACCE6DACCE6DACDE6D9CCE6D8CAE5D6C8E5D4C4E4D1C1E2CFBEE1CCBAE1C9B8E0C5B5E0C1B3\
E0BEB2E0BCB0E0BBAEDFBBACDFBAAADDB9A8DCB8A6DAB7A5D9B6A3D8B5A3D8B5A3
D9B6A3D9B7A4DAB8A5DAB9A6DABAA7DABBA7DABBA7DABCA6D9BCA5D8BBA4D7BAA3D5B9A2D4B7A1\
D2B5A0D1B39FD1B19ED1AF9CD1AE9BD2AD9AD2AD99D1AD99D1AD99D0AD98D0AD98
CFAC97CFAC97CFAB96CFAB96CFAB96CFAB96CEAA96CDAA96CBAA95CAA994C9A994C9A994CAAA95\
CCAD98CFB19ED2B8A7D6C1B2DACBBFDED5CCE1DED8E4E6E2E6ECEAE7F1EFE8F4F2
E8F5F3E8F4F3E8F4F2E8F3F1E7F2F0E7F2EFE7F1EFE7F1EEE7F0EEE7F0EDE6EFECE6EFECE6EFEB\
E6EEEBE6EEEAE6EDEAE6EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E4EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E4DEE3E4DDE3E4DDE3E4DD
E3E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DFE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E8E0E6E6DEE4E3DCE2E1DAE2E0D9E2E0D8E2DFD7E2DED6E2DDD6E2DDD6\
E2DED7E2DFD8E2E0D9E2E1DAE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DD\
E2E3DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DE
E2E4DEE2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0\
E2E6E0E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E3E7E2E3E8E3E3E8E3E4E9E4E3E8E4
E2E7E2DFE4DFDBE0DBD5D8D3CBCCC6BDBCB5ABA69E9A90868D7F7489786A927E6EA38D7BB7A08C\
CAB29DD6BEA7DDC5AEE0C9B1E2CAB3E3CBB5E4CCB8E4CDBAE4CDBCE4CEBDE4CEBD
E4CEBEE4CEBEE4CFBFE4CFBFE4CFC0E4CFC0E4D0C0E4D0C0E4D0C0E4D0C0E4D1C0E4D1C1E4D1C2\
E5D1C2E5D1C3E5D1C3E5D2C3E5D2C4E5D3C4E5D3C5E5D4C6E5D5C7E5D6C8E5D8C9
E5D9CBE6DACBE6DACCE6D9CBE6D7C9E5D5C7E4D2C3E3CEBEE2CABAE0C5B5E0C1B2DFBEAFDFBAAD\
DFB8ACDFB6ABDFB5A9DEB4A7DEB3A5DDB2A3DBB1A1DAB0A0D9AF9FD8AE9ED8AE9E
D8AF9ED8B09FD9B1A0D9B3A2D9B5A3D9B7A4D9B8A4D8B9A3D8B9A2D7B9A1D6B8A0D5B69FD3B59E\
D2B39ED1B19DD1AF9CD0AD9AD0AC99D0AB97D0AB97D0AB96CFAB96CFAB96CFAB96
CFAB96CFAB96D0AB96D0AB96D0AA96CFAA96CFAA95CDAA95CCA994CAA993CAA993CAA992CBA993\
CDAB96CFAE9AD2B4A1D5BAAAD8C3B5DBCCC2DED6CEE1E0DAE4E9E5E6EFEDE8F3F2
E8F5F3E8F5F3E8F4F2E7F3F1E7F2F0E7F1EFE7F1EEE7F0EEE7F0EDE6F0EDE6EFECE6EFECE6EFEB\
E6EEEBE6EEEAE6EDEAE6EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E4EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E4DDE3E3DDE3E3DCE3E3DC
E3E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E0E6E6DEE4E3DBE2E1D9E2E0D8E2DFD7E2DED7E2DED6E2DED6E2DED7\
E2DFD7E2E0D8E2E1D9E2E2DAE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DE
E2E4DEE2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E5E0E2E6E0E2E6E0E2E6E0\
E2E6E1E2E6E1E2E6E1E2E6E1E2E7E1E2E7E2E3E7E2E3E8E3E4E9E4E5EAE5E4E9E5
E1E6E1DBDFDAD1D4CEC5C5BFB7B5ADAAA49B9E958B968A7E938476978676A4907EB49F8CC6AF9B\
D5BEA8DEC7B0E3CBB3E4CCB4E4CCB4E3CCB6E3CCB7E4CDBAE4CDBBE4CDBDE4CDBD
E4CEBEE4CEBEE4CEBEE4CEBFE4CFBFE4CFBFE4CFBFE4D0BFE4D0BEE4D0BEE4D0BFE4D0C0E4D1C1\
E4D1C1E5D1C2E5D1C3E5D2C3E5D2C4E5D3C4E5D3C5E5D4C6E5D5C7E5D6C8E5D7C9
E5D8CAE6D9CAE6D9CBE6D8CAE6D7C9E5D4C6E4CFC1E3C9BBE1C3B5E0BDAFDFB8ABDFB4A8DEB1A6\
DEAFA5DEAEA4DEACA2DDABA0DCAA9EDBA99CDAA79AD9A699D8A598D8A598D8A597
D8A598D8A699D8A99AD8AC9CD8B09ED8B3A0D8B5A1D7B6A0D7B69FD6B59ED5B49DD3B39CD2B29C\
D1B09BD1AF9BD0AD99D0AB98D0A996D0A895CFA894CEA994CEA994CEAA94CEAA94
CEAB95CFAA95D0AA96D0AA96D0AA96D0AA95CFAA95CDA994CCA993CAA992CAA891CAA891CBA891\
CDA993CFAB96D0AE9BD2B3A2D4BAABD7C3B6DACEC4DEDAD2E2E5E0E5EDEAE7F3F1
E8F5F3E8F5F3E8F4F2E7F2F0E7F2EFE7F1EFE7F1EEE7F0EEE7F0EDE6F0EDE6EFECE6EFECE6EEEB\
E6EEEAE6EEEAE6EDEAE6EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6
E5EAE5E4EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E4DEE3E4DDE3E3DCE3E2DBE3E2DB
E3E2DBE2E2DBE2E2DBE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E6DEE4E3DBE2E0D9E2DFD7E2DED7E2DED6E2DED6E2DED7E2DFD7\
E2E0D8E2E0D9E2E1DAE2E2DAE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DBE2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DE
E2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0\
E2E6E1E2E6E1E2E6E1E2E7E1E2E7E1E3E7E2E3E7E2E3E8E3E4E9E5E5EBE6E5EAE5
E0E5E0D6DAD4C7C7C1B5B2ABA49E95988E8494887B96887A9F8E7FAB9888B8A493C6B19ED3BCA8\
DDC5B0E2CBB4E5CDB5E5CDB5E4CDB5E4CCB6E3CCB7E3CCB9E4CDBBE4CDBCE4CDBD
E4CDBEE4CDBEE4CEBEE4CEBEE4CEBFE4CFBEE4CFBEE4CFBDE4CFBDE4CFBCE4D0BDE4D0BEE4D0BF\
E4D0C1E5D1C1E5D1C2E5D1C3E5D2C3E5D3C4E5D4C5E5D5C7E5D6C8E5D7C8E5D7C9
E5D7C9E6D7C9E6D7C9E6D7C9E6D5C7E5D2C4E4CCBFE3C4B8E1BCB0E0B4A8DFADA3DEA9A0DEA79E\
DEA69DDEA49CDDA39ADCA198DB9F95DA9D94D99C92D89B91D89B91D89A90D79A90
D79B91D89D92D8A094D8A497D8A99AD8AE9CD7B19ED6B39ED5B39DD4B29BD3B09AD2AF9AD1AF99\
D0AD99D0AC98D0AA97D0A995CFA794CFA693CEA792CDA791CDA891CCA992CDAA93
CEAA94CFAA95D0AA95D0AA95D0A995D0A995CFA994CEA993CCA992CAA890CAA88FCAA78FCBA68F\
CDA690CEA792CFA995D0AC99D1B2A0D3BAABD6C6B9DBD3C9E0E0D9E4EAE6E7F1EE
E8F4F2E8F4F2E8F3F1E7F2F0E7F1EFE7F1EEE7F1EEE7F0EDE6F0EDE6EFECE6EFECE6EFEBE6EEEB\
E6EEEAE6EEEAE6EDE9E5EDE9E5ECE8E5ECE8E5ECE8E5EBE7E5EBE7E5EBE6E5EAE6
E5EAE5E4EAE5E4EAE4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E4DEE3E3DDE3E2DBE3E1DAE3E1DA
E3E1DAE2E1DBE2E2DBE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D8E2DED7E2DED6E2DED6E2DED7E2DFD8E2E0D8\
E2E1D9E2E1DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DE
E2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0\
E2E6E1E2E6E1E2E6E1E2E7E1E3E7E2E3E7E2E3E7E2E3E8E3E5E9E5E6EBE6E4E9E5
DFE2DED2D4CFBFBDB7A9A49C978D848D80749081739C8B7CAD9B8BBFAC9BCCB8A6D6C0AEDDC6B3\
E1C9B5E4CCB6E5CDB6E5CDB5E4CCB5E4CCB6E3CCB7E3CCB9E4CDBBE4CDBCE4CDBD
E4CDBDE4CDBEE4CEBEE4CEBEE4CEBEE4CEBDE4CEBCE4CEBBE4CFBBE4CFBAE4CFBBE4CFBCE4CFBE\
E4D0BFE5D0C0E5D0C1E5D1C2E5D2C3E5D3C4E5D4C6E5D5C7E5D6C8E5D6C8E5D6C8
E5D6C8E6D5C7E6D5C7E6D5C7E6D3C6E5CFC2E4C8BCE3BFB4E1B5ABE0ABA2DFA49CDEA099DE9E97\
DE9C95DD9B94DC9891DA968FD9938CD8928AD89189D79189D79189D79189D7918A
D7928AD7948BD7978ED89D91D8A395D7A898D7AC9AD5AE9AD4AE9AD2AD98D1AC97D0AB97CFAB96\
CFAA96CFAA96CFA895CFA793CFA692CEA590CDA590CCA68FCBA790CBA890CCA991
CDA992CEA994CFA994D0A995D0A995D0A994CFA994CEA992CCA891CBA88FCAA78ECBA68DCCA58D\
CDA48DCEA38ECEA48FCEA692CEAB98CFB3A1D3BEAFD8CCC0DDD9D1E2E5DFE5ECE9
E7F0EEE7F2F0E7F2F0E7F2EFE7F1EFE7F1EEE7F0EEE7F0EDE6F0EDE6EFECE6EFECE6EEEBE6EEEB\
E6EEEAE6EDEAE6EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE7E5EBE6E5EAE6
E5EAE5E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E4DEE3E3DCE3E1DBE3E0DAE3E0D9
E3E0DAE2E1DAE2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E5DDD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D8E2DED7E2DED6E2DED6E2DFD7E2E0D8E2E1D9\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DE
E2E5DEE2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0\
E2E6E1E2E6E1E2E6E1E3E7E1E3E7E2E3E7E2E3E7E2E3E8E3E4E9E4E4E9E5E3E6E2
DCDFDACFCFCABCB8B1A69E9696897F8F7F73968476A69484BBA897CEBAA9DAC5B4E0CAB9E3CCBA\
E3CCB9E4CCB7E4CCB6E4CCB5E4CCB5E4CCB5E3CCB7E3CCB9E4CDBBE4CDBCE4CDBD
E4CDBDE4CDBDE4CDBDE4CDBDE4CDBCE4CDBBE4CDBAE4CDB9E4CEB8E4CEB8E4CEB9E4CEBAE4CEBB\
E4CFBDE5CFBEE5CFC0E5D0C1E5D1C2E5D3C4E5D4C6E5D5C7E5D6C8E5D5C7E5D4C7
E5D3C6E6D2C5E6D2C5E6D1C5E6D0C3E5CCC0E4C4BAE3BAB1E2AFA7E0A59EDF9D97DE9893DE9690\
DD948EDC928CDA8F89D98C85D78983D68781D68781D68782D68883D78984D78A84
D68A85D68C86D79088D7968CD79C90D7A293D6A696D5A896D3A896D1A795CFA794CEA794CEA794\
CEA794CEA793CEA792CEA691CDA590CDA48FCCA48ECBA58ECAA68ECAA78FCBA890
CCA892CEA893CFA994D0A994D0A994D0A894CFA893CEA892CCA890CBA78FCBA68DCBA58CCCA38C\
CDA28BCDA18BCDA18CCCA28ECCA792CDAE9AD0B8A6D5C4B6DAD1C6DFDCD4E2E5DF
E5EBE7E6EEEBE6F0EDE7F1EEE7F1EFE7F1EEE7F0EEE6F0EDE6EFECE6EFECE6EFEBE6EEEBE6EEEA\
E6EEEAE6EDEAE5EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6E5EAE6
E5EAE5E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E7E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E4DEE3E3DCE3E2DBE3E0DAE3E0D9
E3E0DAE2E1DAE2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E5DDD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E6DEE4E3DBE2E0D9E2DFD7E2DFD7E2DFD7E2E0D8E2E0D9E2E1DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DE
E2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E0\
E2E6E1E2E6E1E2E7E1E3E7E2E3E7E2E3E7E2E3E7E2E3E7E2E2E7E2E2E5E1DFE1DD
D8D9D4CDCBC5BCB6B0ACA2999F91879B8A7EA49183B4A091C7B2A2D8C3B2E1CBBAE5CFBDE6CEBD\
E5CDBAE4CCB8E4CBB6E3CBB5E3CCB5E3CCB5E3CCB7E3CCB9E3CDBBE4CDBCE4CDBD
E4CDBDE4CDBDE4CDBCE4CCBBE4CCBAE4CCB9E4CCB8E4CCB7E4CCB6E4CCB6E4CDB6E4CDB7E4CDB8\
E4CDBAE5CEBCE5CFBEE5D0C0E5D1C2E5D3C3E5D4C5E5D5C6E5D5C7E5D4C6E5D2C5
E5D0C3E6CEC2E6CDC1E6CCC1E6CBC0E5C7BDE4C0B7E3B6AEE2ABA4E0A09ADF9893DE938EDD918B\
DC8F88DA8C85D98881D7847DD5817AD57F79D5807AD5817CD6837ED68580D68580
D68681D58881D58B83D68F86D6958AD69A8ED69E90D4A091D1A191CFA191CDA190CCA290CCA391\
CCA491CCA591CCA590CCA58FCCA48ECBA48ECAA48DCAA48DC9A58DC9A68ECAA68F
CCA791CDA792CFA893D0A894D0A894D0A893CFA893CEA892CDA890CCA78FCCA68DCCA48CCDA28B\
CDA08ACD9F8ACD9F8ACCA18CCCA58FCDAA96CFB39FD2BDACD7C7B9DBD2C7DFDBD3
E2E3DDE4E9E5E6EEEAE6F0EDE7F1EFE7F1EFE7F1EEE6F0EDE6EFECE6EFECE6EFEBE6EEEBE6EEEA\
E6EEEAE6EDE9E5EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6E5EAE6
E4EAE5E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E4DEE3E3DDE3E2DBE3E1DAE3E1DA
E3E1DAE2E1DBE2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E5DDD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E6DEE4E3DBE2E1D9E2E0D8E2E0D8E2E0D8E2E0D9E2E1D9E2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DE
E2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E0\
E2E6E1E2E6E1E3E7E1E3E7E2E3E8E2E3E8E3E3E8E3E2E6E2E0E4DFDDE0DBD8D9D5
D2D0CCC9C4BFBEB6AFB4A8A0AE9F95AE9C90B6A294C3AE9ED1BBABDDC7B6E4CDBCE6CFBEE6CEBD\
E5CDBAE4CCB8E3CBB6E3CBB5E3CBB4E3CCB5E3CCB7E3CCB9E3CCBAE4CDBCE4CDBD
E4CDBDE4CDBCE4CCBBE4CCB9E4CBB8E4CAB6E4CAB5E4CAB4E4CAB3E4CBB3E4CBB4E4CBB4E4CBB6\
E4CCB7E4CDB9E5CEBCE5CFBEE5D1C1E5D2C3E5D4C5E5D4C5E5D3C5E5D1C4E6CEC2
E6CBBFE6C8BEE6C7BDE6C6BCE6C4BBE5C1B8E4BAB2E3B1AAE1A7A1DF9D98DE9590DC908ADB8D86\
DA8A83D8877FD6837AD47F76D37C74D37B74D37D76D47F79D5827DD5837ED5847E
D4847ED4847ED4867ED58981D58E84D69288D5958AD3988CD0998CCE9A8CCC9B8CCA9D8DCA9F8D\
CAA18ECAA38FCAA48FCAA48ECAA58DCAA48DC9A48CC9A48CC8A48CC9A48DCAA58E
CBA690CDA691CEA792CFA893CFA893CFA893CFA892CEA791CEA790CDA68FCDA58ECDA48CCDA28B\
CEA08ACE9F89CD9F8ACDA18BCCA48ECDA993CEAF9AD0B5A2D4BEACD7C7B8DBD1C5
DFDAD1E2E3DDE5EBE6E6EFECE7F1EFE7F1EFE7F1EEE6F0EDE6EFECE6EFECE6EEEBE6EEEBE6EEEA\
E6EDEAE5EDE9E5EDE9E5ECE8E5ECE8E5ECE8E5EBE7E5EBE7E5EBE6E5EBE6E5EAE5
E4EAE5E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E4E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E4DEE3E4DDE3E3DCE3E2DBE3E2DB
E3E2DBE2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E5DDD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E0E6E6DEE4E4DCE2E2DAE2E1D9E2E1D9E2E1D9E2E1DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DE
E2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1\
E2E6E1E2E6E1E3E7E1E3E7E2E3E8E3E4E9E3E3E8E3E1E5E1DDE0DCD7D9D4CFCFCB
C8C4C0C1BBB6BCB3ACBAADA5BBACA1C0AEA1C7B3A5D0BAAAD9C2B1E0C8B6E4CCBAE6CDBBE5CDBB\
E5CCB9E4CCB7E3CBB5E3CBB4E3CBB4E3CCB5E3CCB6E3CCB8E3CCBAE4CDBCE4CDBC
E4CDBCE4CDBBE4CCBAE4CBB7E4CAB5E4C9B3E4C8B1E4C8B1E4C8B0E4C8B1E4C9B1E4C9B2E4CAB3\
E4CBB5E4CCB8E5CEBBE5CFBEE5D1C1E5D3C3E6D3C4E6D3C4E6D2C3E6CFC1E6CABE
E6C6BBE5C1B8E5BFB6E5BDB5E5BBB4E4B9B1E3B3ACE1ACA5E0A39DDE9B95DC948DDA8E87D88A82\
D6877DD48379D38075D17D72D17B71D17C73D27E76D4817AD5847ED5857FD4847E
D3837CD2827AD2827AD3837BD4867DD48980D48C83D28F85D09186CD9387CB9588C99889C99B8A\
C99E8CC9A08DC9A28DC9A48DC9A58DC8A58CC8A48CC8A48BC8A38BC8A38CC9A38D
CBA48ECCA690CEA791CEA792CFA792CFA792CFA792CEA791CEA790CEA690CEA58ECEA38DCEA18B\
CEA08ACE9F8ACEA08ACDA28CCDA58FCDA892CEAB96CFAF9AD1B5A1D4BCABD8C7B8
DCD2C7E0DED6E4E7E2E6EEEAE7F1EEE7F1EFE7F1EEE6F0EDE6EFECE6EFEBE6EEEBE6EEEAE6EEEA\
E6EDEAE5EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE7E5EBE6E5EAE6E5EAE5
E4EAE5E4EAE5E4E9E4E4E9E4E4E9E4E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E4DEE3E4DDE3E3DCE3E3DC
E3E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E5DCE9E9E1E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DEE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1\
E2E6E1E2E6E1E3E7E1E3E8E2E4E9E3E5EAE4E4E9E4E0E5E0D9DCD8CFD0CCC3C2BE
BAB5B0B4ACA7B5AAA3BBACA3C3B2A7CCB9ACD4BFAFDAC4B2DFC7B5E2C9B6E3CBB7E4CCB8E4CCB8\
E4CCB7E4CBB6E3CBB5E3CBB4E3CBB4E3CBB5E3CCB6E3CCB8E4CCBAE4CDBBE4CDBC
E4CDBCE3CCBAE3CBB8E3CAB5E3C8B3E3C7B0E3C6AEE3C5AEE3C5AEE3C6AEE3C6AFE4C7B0E4C9B1\
E4CAB4E4CCB7E5CEBAE5D0BEE5D2C1E6D3C2E6D3C3E7D3C3E7D0C1E7CBBDE6C6B9
E5BFB5E5BAB1E4B6AEE3B3ACE3B1AAE2AFA8E1ABA4DFA69FDDA099DB9992D8928AD68C83D3877C\
D18377CF8073CE7E71CE7E71CE7F73D08276D1857BD3887FD48A82D58982D4877F
D2837BD18077D07D75D17D74D17E76D28078D2837BD1867DCF897FCD8C81CB9083C99385C89787\
C89A89C89E8BC8A18CC8A38DC7A58DC7A58CC7A58BC7A38AC7A28AC8A28AC9A28B
CAA38CCBA58ECDA68FCEA790CEA791CEA791CFA791CFA691CEA690CEA590CEA58FCEA38DCEA28C\
CEA08BCEA08BCEA18BCEA38DCEA58FCEA791CEA992CEAB94CFAE99D2B5A1D5BFAE
DACCBEDFD9CFE3E4DEE6ECE8E7F0EDE7F1EEE7F1EEE6F0EDE6EFECE6EFEBE6EEEBE6EEEAE6EDEA\
E5EDE9E5EDE9E5ECE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6E5EAE6E5EAE5
E4EAE5E4EAE5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E3E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1\
E2E6E1E2E6E1E3E7E1E3E8E3E5E9E4E5EBE5E4E9E4DFE4DFD5D8D4C6C6C2B5B3AF
A8A39EA39A94A89B93B4A49AC3B1A4D2BDADDBC5B3E0C9B5E2CAB6E3CAB5E3CAB5E4CBB6E4CBB6\
E4CBB6E4CBB5E3CBB4E3CBB3E3CBB3E3CBB4E3CCB6E3CCB8E4CCBAE4CDBBE4CDBB
E4CDBAE3CCB9E3CBB6E2C9B3E2C7B0E1C5AEE1C3ACE1C2ABE1C2AAE2C3ABE2C4ACE3C6AEE3C8B0\
E4CAB3E4CDB7E5CFBAE5D0BEE5D2C0E6D2C1E6D2C1E7D0C0E7CDBDE7C7B8E6C0B3
E4B8ADE3B1A8E2ABA4E1A8A1E0A69FDFA49DDEA29ADCA097DA9C93D7978ED49187D18A7FCE8478\
CB8072CA7E6FCA7F70CB8273CC8778CF8C7ED19083D39287D49288D48F86D38A81
D1837ACF7D74CE796FCE766DCE766DCF7870CF7B72CF7E76CE8279CD867CCB8A7FCA8E81C99284\
C89787C79B89C79E8BC7A28CC7A48DC7A58CC7A48BC7A389C7A288C7A187C8A188
C9A389CAA48BCBA68DCCA68FCDA790CEA790CEA690CFA690CFA690CFA590CFA48FCEA38ECEA28D\
CEA18CCEA18CCEA28CCEA38DCEA58ECEA68FCDA790CDA890CEAB94D0B19BD4BBA8
D9C8B8DED5CAE3E1D9E6E9E4E7EEEAE7F0EDE7F0EDE6F0EDE6EFECE6EEEBE6EEEBE6EEEAE6EDEA\
E5EDE9E5EDE9E5ECE8E5ECE8E5ECE8E5EBE7E5EBE7E5EBE6E5EBE6E5EAE6E4EAE5
E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1\
E2E6E1E2E6E1E3E7E1E3E8E3E5E9E4E6EBE5E4E9E4DEE2DDD0D3CEBDBDB8A8A49F
98918B9287809A8C82AB9A8DBFAC9CD2BCAADDC6B2E3CBB5E4CCB5E4CBB4E4CAB4E3CAB4E3CBB4\
E3CBB4E3CBB3E3CBB3E3CBB3E3CBB3E3CBB5E3CCB6E3CCB8E4CCBAE4CDBAE4CDBA
E4CDB9E3CCB7E2CAB4E2C8B1E1C5AEE0C3ABDFC0A9DFBFA7DFBFA7E0BFA8E1C1AAE2C4ACE3C7AF\
E4CAB3E4CDB7E5CEBAE5CFBDE5CFBEE5CFBDE5CDBCE5CBB9E5C6B5E4C0B0E3B8AA
E2AFA4E1A79EDFA19ADE9D96DD9B93DC9A91DB9A90D99990D7988ED4968BD09186CD8A7EC98375\
C67F6FC57E6EC68271C88877CB907FCE9686D19A8CD39C8ED49A8ED39489D18D82
CF8379CD7B70CB746ACB7167CB7066CB7168CC746BCC786FCC7C72CC8176CB857ACA8A7DC98E80\
C89283C79786C79B89C69F8BC6A28CC7A48CC7A48AC7A388C7A185C7A084C8A185
C8A286C9A489CAA58BCBA68DCCA68FCDA68FCEA690CFA690CFA590CFA590CFA48FCFA48ECEA38D\
CEA28DCEA28CCEA38DCEA38DCEA48ECEA58ECDA58ECDA68ECEA991D0AE98D3B8A4
D8C4B4DED1C4E2DDD3E5E6DFE7EBE6E7EEEAE7EFEBE6EFEBE6EFEBE6EEEBE6EEEAE6EEEAE6EDE9\
E5EDE9E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE7E5EBE6E5EBE6E5EAE6E4EAE5
E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DE
E3E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DAE2E2DBE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1\
E2E6E1E3E6E1E3E7E1E3E7E2E4E8E3E5E9E4E2E6E2DBDED9CBCCC7B5B3AE9D9892
8B827B85796F8F7F73A39081BBA693D0B9A4DDC5AEE4CBB3E5CCB4E4CBB3E4CAB2E3CAB2E3CAB2\
E3CAB2E3CAB2E3CBB2E3CBB3E3CBB4E3CCB5E3CCB7E3CCB9E4CCB9E4CCB9E4CCB9
E3CCB7E3CBB4E2C9B1E1C6AEDFC3ABDEC0A8DDBDA5DDBBA3DDBAA3DEBBA4DFBEA6E1C1AAE3C5AF\
E4C9B3E5CBB6E5CCB9E4CBB9E3C9B8E2C7B6E0C3B2DFBFADDEBAA8DEB4A3DDAC9E
DDA599DC9E95DC9991DC958DDB938ADA9288D89388D69489D4968AD2968ACE9386CA8D7FC68778\
C48272C38271C48775C78F7DCB9885CE9E8DD0A291D2A293D29F91D1988BCF8E81
CC8377C9796DC77266C66E62C66D61C76E63C87166C8746AC9786DC97C71C98075C98478C8887B\
C78D7FC79283C79786C69C89C6A08BC6A28BC6A389C6A286C6A183C7A081C7A082
C8A184C8A386C9A489CAA58CCCA68ECDA68FCEA690CFA690CFA690CFA690CFA58FCFA58FCFA48E\
CEA38DCEA38DCEA38DCEA38DCEA48DCEA48DCDA48DCDA58ECEA890CFAD97D3B5A1
D7C0AFDCCCBEE1D8CCE4E0D7E6E7DFE6EAE5E6ECE8E6EDE9E6EEEAE6EEEAE6EEEAE6EDEAE5EDE9\
E5EDE9E5ECE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE7E5EBE6E5EAE6E5EAE5E4EAE5
E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DD
E3E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DBE2E2DBE2E2DAE2E2DA\
E2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE2E2DBE2E2DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1E3E6E1\
E3E7E1E3E7E1E3E7E2E3E7E2E3E7E2E2E5E1DEE1DCD5D6D1C5C4BFAFAAA4988F88
877B728272678D7A6BA18C7ABAA38ED0B7A0DDC4ABE4CAB1E5CCB3E4CBB2E3CAB1E3C9B0E2C9B0\
E2C9B0E2C9B0E2CAB1E3CBB3E3CCB5E3CCB6E3CCB8E4CCB9E4CCB9E4CCB9E4CBB7
E3CAB4E3C9B1E1C6AEE0C4AADEC0A7DCBDA3DBB9A0DAB79EDAB59EDBB69FDDB9A3E0BEA8E2C3AD\
E4C7B2E5C8B5E5C7B6E3C4B4E0BFAFDCB9A9D8B2A1D4AC9AD2A695D1A191D39D8F
D59A8ED7978CD9938AD99087D98E84D88D82D68F83D59285D39589D1988BCE978ACB9485C78F80\
C58C7CC58C7BC6907EC99583CC9C8ACEA18FD0A392D0A392D09F8FCE9888CB8E7F
C78374C5796BC37264C26E61C26D60C26F62C37165C37368C3766AC4796DC47C6FC57E72C68275\
C68679C78B7DC79182C79786C69C88C6A089C6A187C6A184C6A081C69F7FC79F7F
C7A081C8A285C9A388CAA48BCBA58DCDA68FCEA690CFA790CFA790D0A790D0A790CFA68FCFA58E\
CFA48ECEA48DCEA48DCEA48DCEA48DCDA48DCDA48DCDA58DCEA790CFAB95D2B29E
D6BCA9DAC6B6DED0C2E2D9CEE4E0D7E5E5DEE6E9E3E6EBE6E6EDE8E6EDE9E6EEEAE6EDEAE6EDE9\
E5EDE9E5ECE8E5ECE8E5ECE8E5EBE7E5EBE7E5EBE6E5EBE6E5EAE6E4EAE5E4EAE5
E4EAE5E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DBE2E2DBE2E2DAE2E2DA\
E2E1DAE2E1D9E2E0D9E2E0D9E2E0D9E2E1D9E2E1DAE2E2DBE2E2DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E2E6E1E3E7E1\
E3E7E2E3E7E2E3E7E2E2E6E1E0E4DFDDDFDBD7D8D3CDCBC7BEB9B4AAA29B988B82
8B7B6F887567937E6CA78F7BBDA58ED1B89FDDC4ABE3CAB1E5CBB3E4CAB2E3C9B1E2C7AFE1C7AE\
E1C7AEE1C8AFE2C9B1E2CBB4E3CCB6E3CDB8E3CDBAE4CDBAE4CCB9E4CBB8E4CAB5
E3C8B2E2C6AEE1C3AADFC0A6DCBDA2DAB99FD8B59BD7B198D7AF98D8B099DAB39EDEB9A4E1BEAB\
E4C2B0E5C3B2E5C0B1E2B9ABDCB1A3D5A698CC9C8DC59383C18D7DC18B7BC58C7E
CB8F82D19286D59287D89186D88E83D78D81D68E81D59285D4978AD29C8ED19F91CE9F91CC9D8F\
CB9C8CCA9A8BCB9A8ACC9B8ACE9D8BCF9E8DCF9E8DCE9E8DCC9B8AC99584C68D7C
C28472BF7C6ABD7665BD7363BD7364BD7466BD7568BD7669BC7669BC7669BC7669BF786AC17A6D\
C47E71C68476C78A7BC69181C59884C59C86C49F85C59F82C59F7FC69E7DC79E7E
C89F80C9A083CAA287CBA38ACCA58DCDA68FCEA790CFA891D0A991D0A991D1A990D0A890D0A78F\
CFA58ECEA48ECEA48ECEA48ECDA48ECDA48ECDA48DCDA58ECEA68FCFA993D1AF99
D4B6A2D7BEACDBC7B7DED0C2E1D8CCE3DFD5E5E5DDE6E9E2E6EBE6E6EDE8E6EDE9E6EDE9E5EDE9\
E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE7E5EBE6E5EBE6E5EAE6E4EAE5E4EAE5
E4E9E5E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E4DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DAE2E2DBE2E2DAE2E2DA\
E2E1D9E2E0D9E2DFD8E2DFD8E2DFD8E2E0D9E2E1DAE2E2DAE2E2DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E3E6E1E3E7E1\
E3E7E2E4E8E2E3E7E2E1E5E0DDE0DBD7D8D4CFCDC9C3BEBAB6ADA7A79A939B8A7F
948072957F6DA08874B19881C4AA92D4BAA1DEC4ABE3CAB1E4CBB3E3C9B2E2C7B0E1C5AEE0C4AC\
E0C4ACE0C6ADE1C8B1E2CBB4E3CDB8E3CEBAE3CEBBE4CDBBE4CCB9E4CAB7E4C8B4
E3C6AFE2C3ABE0C0A7DEBDA2DBB99ED8B599D6B095D4AC92D3A991D4A992D7AC98DBB29FDFB7A6\
E2BBACE3BAADE2B6A9DFADA1D7A296CD9488C1877AB77D6FB07768B17869B87F71
C2887BCC9185D39589D7968AD89387D79285D69285D69689D59C8ED5A295D5A89BD4AC9FD3AEA1\
D2AEA0D2AB9DD2A698D2A192D19C8DD19989CF9887CC9786C99684C59380C18D7A
BE8773BB816DB97D6AB97B6AB97C6BB97C6DB87C6EB67A6CB37769B27465B27163B57162BA7264\
BF7568C37B6DC48273C48A7AC4927FC39882C39C82C49D80C59E7EC69D7CC79E7D
C99E7FCA9F83CBA187CBA28ACCA48DCDA690CEA891D0AA92D1AB93D2AC92D2AB92D2AA90D1A88F\
D0A68ECFA58ECEA58ECEA58ECDA58ECDA58ECDA58ECDA58ECDA68ECEA790D0AA94
D1AF9AD4B6A2D7BEABDAC6B6DED0C2E1D8CDE4E0D6E5E5DEE6E9E3E6EBE6E6EDE8E6EDE9E5EDE9\
E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE7E5EBE6E5EAE6E4EAE5E4EAE5E4EAE5
E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1E3E7E1\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E4DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D7D0E5E5DDE9E9E1E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DA\
E2E1D9E2E0D8E2DFD7E2DED7E2DFD7E2DFD8E2E1D9E2E2DAE2E2DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E3E6E1E3E7E2\
E4E8E2E4E9E3E3E8E2E0E4DED9DCD7D0CFCBC4C0BCB8B0ABADA09AA4938A9F8A7E
9F8777A58B77B0957FBEA38BCCB198D8BEA5E0C6ADE3CAB2E4CAB4E3C8B2E1C6AFE0C3ACDFC2AA\
DEC2A9DFC4ACE0C7B0E1CAB5E2CDB9E3CFBCE3CFBDE4CEBCE4CCBAE4C9B6E4C7B2
E3C4ADE2C1A8E0BDA3DDB99EDAB498D7B093D4AB8FD1A68BD0A28AD0A18BD2A390D5A896D9AC9D\
DCAFA2DEAEA3DDAAA0D9A198D2968CC6887EB87A6FAC6E63A5695DA66D60AF796C
BC887BC99588D39D90D79F92D99D91D89B8ED89B8ED89E91D8A497D9AB9FD9B3A7DABBAEDABFB3\
DAC0B4D9BCB0D8B3A6D7A89AD59D8FD39788D09484CC9483C89582C49481C0917D
BC8D78B98A75B88773B78774B78776B68677B38476AF7F71AB786AA77263A76C5DAA695AB0695A\
B76B5EBC7163BF796AC08271C18B78C1937CC2987EC39B7EC59C7DC69D7CC89D7D
C99E80CB9E83CCA087CDA28BCDA48ECEA791CFA993D0AC94D2AD94D3AE94D3AD93D3AC91D2AA90\
D0A88FCFA68ECEA58ECEA58ECEA68FCDA68FCDA68ECDA58ECDA58DCEA58ECEA790
CFAA93D1AE99D3B5A1D6BEACDAC8B8DED2C5E1DBD1E4E2DAE5E6E1E5EAE5E5EBE7E5ECE9E5EDE9\
E5EDE9E5ECE8E5ECE8E5ECE7E5EBE7E5EBE6E5EBE6E5EAE6E4EAE5E4EAE5E4EAE5
E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E1\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E0E6E6DEE4E4DCE2E2DAE2E1D9E2E1D9E2E1D9E2E1DAE2E1DAE2E1DA\
E2E0D9E2E0D8E2DFD7E2DED7E2DFD7E2DFD8E2E1D9E2E2DAE2E2DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E3E6E1E3E7E2\
E4E9E3E5E9E4E3E8E2DFE2DDD5D7D2C8C7C3B9B4B0ABA29DA2938D9F8C82A18A7C
A98E7DB39782BEA28ACAAE95D4B9A0DCC2A9E1C7B0E4CAB3E4CAB4E3C8B2E1C4AEDFC1AADEBFA7\
DEBFA7DEC1AADFC5AFE1C9B5E2CDBAE3CFBDE3CFBDE4CEBCE4CCBAE4C9B6E4C6B1
E3C2ACE2BEA6E0BAA0DCB599D9B093D5AA8DD2A589CFA085CD9C83CC9983CC9986CD9A8ACF9C8F\
D19E94D39E95D39C94D19790CB9088C1857CB5796FA96F65A36C61A57166AF7F73
BC9083CA9F92D4A99CD9AB9FDAAA9EDAA89CDAA79CDAAA9FDBAFA4DCB6ACDEBFB4DFC7BDE0CDC3\
E0CEC4DFC9BEDEBEB2DBB0A3D9A395D59A8BD29787CE9887CA9A88C69B88C29A86
BE9984BC9682BA9581B89482B79383B49082B08B7EAA8376A3796C9E70619C67589E6253A36051\
AA6253B06758B56F60B97968BC8370BE8C76C1937AC3987BC59B7CC69D7DC89D7F
CA9E81CC9E84CD9F87CEA18BCEA48FCFA792D0AB94D1AD95D3AF96D4B095D4AF94D4AE93D3AC91\
D1A990D0A78FCFA68ECEA68ECEA68FCEA68FCDA58ECDA48DCDA48CCDA38CCDA48C
CDA58ECEA992D0AF99D3B7A4D7C1B2DBCCC0DED6CDE1DED8E3E3DFE4E7E3E4E9E6E5EBE7E5ECE8\
E5ECE8E5ECE8E5ECE7E5ECE7E5EBE7E5EBE6E5EBE6E5EAE6E4EAE5E4EAE5E4E9E5
E4E9E4E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E6DEE4E3DBE2E1D9E2E0D8E2E0D8E2E0D8E2E1D9E2E1D9E2E1D9\
E2E1D9E2E0D9E2DFD8E2DFD8E2DFD8E2E0D9E2E1DAE2E2DAE2E2DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E2E6E0E3E7E1E4E8E2\
E5E9E4E5EAE4E4E8E3DDE1DCD2D3CEC0BFBAAEA8A49F948F96877F988479A1897A
AE9480BDA08AC9AC94D3B79EDABFA7DFC5ADE2C9B2E4CAB4E3C9B4E2C7B1E1C3ADDFC0A8DDBDA5\
DDBDA5DEBFA8DFC3ADE0C8B4E2CCB9E3CEBCE3CEBDE4CDBCE4CBB9E4C9B6E4C6B1
E3C2ABE2BDA4DFB79DDBB195D7AB8ED4A587D09F82CD9A7FCA967DC8917BC58D7BC38A7BC2887D\
C2887FC38A83C68D87C79089C59089C08C84B7857DB07F76AC7E74AE8479B79085
C29F93CEADA1D7B6AADBB9AEDDB9AFDDB7AEDDB7AEDDB8B0DEBCB4DFC2BAE1CAC1E2D1C9E3D7CE\
E4D7CEE3D2C8E1C7BBDEB9ACDBAC9ED8A495D5A292D2A392CEA695CBA897C8A997
C5A895C2A694BFA492BDA292B99F91B59A8DAE9286A6877B9E7B6E976E60936455925D4D95594A\
9A594AA15E4EA86555AF6F5EB67A67BB856FBF8E75C29579C59A7CC79D7EC89E80
CA9E82CC9E85CE9F88CFA18BD0A48FD0A893D1AC95D3AF97D4B097D5B197D5B096D5AF94D4AD92\
D3AB91D1A98FD0A88FCFA78ECEA68ECEA68ECDA58DCDA38CCDA38BCDA28ACDA28A
CDA38BCDA68ECEAB95D0B3A1D3BDAFD7C7BEDAD1CCDDD9D6DFDFDDE1E4E2E2E7E4E3E9E5E4EAE6\
E5EBE7E5ECE7E5ECE7E5ECE7E5EBE7E5EBE6E5EAE6E4EAE5E4EAE5E4EAE5E4E9E4
E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6DFE3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E6DEE4E3DBE2E0D9E2DFD7E2DFD7E2DFD7E2E0D8E2E0D9E2E1D9\
E2E1D9E2E1D9E2E0D9E2E0D9E2E0D9E2E1D9E2E1DAE2E2DBE2E2DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E2E6E0E3E6E1E3E7E1E4E8E3\
E5EAE4E6EBE5E4E8E3DCE0DBCECFCAB9B7B3A39D989287818A7B73907C709E8776
B19783C3A790D1B49CDABEA5DFC4ACE2C7B0E3C9B3E4CAB4E3C9B3E2C7B0E0C3ABDFBFA7DDBCA4\
DDBBA3DEBDA7DFC1ACE0C6B2E2CAB8E3CDBBE3CEBDE4CDBCE4CBB9E4C8B5E4C5B0
E3C1AAE1BBA3DEB49ADAAD91D6A588D19E81CE997CCB9479C78F76C38973BD816EB7786AB27267\
B07069B2756FB67F79BC8A84C0938CC09890BE9990BB988FBA998FBD9E93C4A79C
CCB2A7D4BDB1DAC4B9DEC7BDDFC7BFE0C7BFE0C7C0E0C8C1E1CAC4E2CEC8E3D3CDE4D9D1E5DCD4\
E5DCD3E4D7CCE2CDC1E0C2B3DDB8A8DBB2A1D9B0A0D7B2A2D5B6A6D3B8A9D0B9AA
CEB8A9CBB6A7C7B3A4C3AFA2BEAA9EB7A398AF998EA68C819C7D71946F628D6355895A4B895546\
8C54449157479A5E4DA46755AE725EB67D67BD886FC19175C4987BC69C7FC89E81
CA9E83CC9E85CE9F88CFA18BD0A58FD2A993D3AD96D4B098D5B199D6B298D6B197D6B096D5AF94\
D4AD92D3AB91D1AA8FD0A88ECFA68ECEA58DCDA38CCDA28BCDA18ACDA189CCA188
CCA289CCA48CCDA993CFB09FD1BAADD3C4BDD6CDCAD9D5D5DBDBDBDDDFDFE0E3E1E1E5E2E3E7E3\
E4E9E5E4EAE6E5EBE6E5EBE7E5EBE7E5EBE6E4EAE6E4EAE5E4EAE5E4EAE5E4E9E4
E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E2E3E7E1E3E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D8E2DED7E2DED6E2DED7E2DFD8E2E0D9E2E1D9\
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE2E2DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E3E6E0E3E7E1E4E8E2E5E9E4\
E6EBE6E7ECE7E4E8E4DBDEDACACBC7B2B0AC99938E867B757F70678774679A8372
B19883C7AC95D6BAA2DEC3ABE2C7B0E3C9B3E4CAB4E4CAB4E3C9B2E2C7AFE1C3AADFBFA6DEBCA3\
DDBBA3DEBDA6DFC0ABE1C5B2E2C9B7E3CCBBE3CDBCE4CCBBE4CAB9E4C8B5E4C4B0
E2BFA9E0B9A0DCB197D8A88CD3A082CF987BCB9375C88E72C4886EBE7F69B57361AB6758A25D52\
9E5A52A1615BA8716BB2847EBB978FC2A49BC6ACA2C9B0A6CBB3A9CDB7ACD2BDB2
D6C3B8DBCABFDECEC4E0D2C9E1D3CCE2D4CEE2D4CFE2D5D0E3D6D1E4D8D2E5DAD4E5DDD6E6DED6\
E6DDD3E4D9CDE3D1C3E0C9B9DEC2B1DDBEADDCBFAEDBC1B2DBC5B7DAC8BAD8C8BB
D6C6BAD3C3B7CFBFB3CABAAFC4B4A9BCABA1B3A096A991879E82779573678C6659855C4E815647\
8154438555448E5A4899614EA56A57B0755FB88068BD8A71C19378C5997DC79C81
CA9D83CC9E85CE9E88CFA18BD1A58FD3AA94D4AE97D5B199D6B29AD6B39AD6B299D6B298D6B196\
D5AF94D4AE92D2AB90D1A98FCFA68DCEA48CCDA28BCDA18ACDA089CDA088CCA087
CCA188CCA38CCDA893CDAF9ECEB7ACD0C1BBD1C9C9D4D0D2D6D6D7D9DADADBDDDCDEE0DDE0E3DF\
E1E5E1E2E8E4E3E9E5E4EAE6E4EAE6E4EAE6E4EAE6E4EAE5E4EAE5E4E9E5E4E9E4
E4E9E4E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1E3E7E1E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E3E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D8E2DED7E2DED6E2DED7E2DFD7E2E0D9E2E1DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E2E6E0E3E6E1E3E7E2E4E8E3E6EAE5\
E7ECE7E8ECE8E4E8E5DADCDAC6C7C5ACA9A6908A867B716B75665D7F6C5F957F6E
B09883C8AE97D8BDA5E1C6AEE4C9B2E4CAB3E4CAB4E3CAB3E3C9B1E2C7AEE1C4AAE0C0A7DFBDA4\
DEBCA4DFBEA7E0C1ACE1C5B1E2C9B6E3CBBAE3CCBBE4CCBAE4CAB8E3C7B4E3C2AE
E1BDA6DEB69DDAAD92D5A487CF9A7DCB9274C78C6FC4876BBF7F66B7755FAC6754A05749954B40\
90484093514B9D655FAB7F77B9988FC5ABA1CEB9AED4C1B5D8C5B9DAC8BCDCCBBF
DECEC2E0D1C6E1D4CAE2D8CFE3DBD4E4DDD7E4DED9E4DED9E5DED8E5DED8E5DED7E6DFD6E6DED4\
E5DCD1E4D8CAE2D2C3E0CCBBDFC8B6DEC7B4DEC8B8DECCBDDFD0C3DFD2C6DED2C7
DCCFC4DACBC0D6C7BBD1C1B6CABBB0C2B2A8B9A79DAF998FA58A7F9B7B6F916E60886455815D4E\
7E5A497F5948865A498F5E4C9B6451A66C58AF7761B7826ABD8C72C2947AC6997E
C99B82CB9C84CD9E87CFA18BD1A68FD3AB93D5AF97D6B29AD7B39BD7B49CD7B49BD7B39AD7B298\
D6B196D5AF94D3AD91D1AA8FD0A78ECEA48CCDA28ACDA089CD9F88CD9F87CD9F86
CDA087CCA38BCCA792CCAE9DCCB5AACCBEB8CDC5C5CFCBCDD1D0D1D3D3D3D6D6D4D8D9D6DBDDD9\
DDE0DDDFE3E1E1E6E3E2E8E5E3E9E5E4E9E6E4EAE5E4EAE5E4EAE5E4E9E4E4E9E4
E4E9E4E4E9E3E4E8E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E1E3E7E1E3E7E1E3E6E1E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DDD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D9E2DFD7E2DED7E2DFD7E2DFD8E2E0D9E2E1DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E6E0E2E6E0E3E7E1E4E8E2E5E9E3E6EAE5\
E7EBE8E7EBE8E2E6E4D7D9D8C2C2C1A6A2A189817F7368636D5E55796659927C6A
AF9782C9AF98DABFA7E2C7AFE5CAB3E4CAB3E4CAB3E3CAB2E3C9B0E2C7AEE1C5ABE0C2A8E0C0A6\
DFBFA7E0C0A9E0C2ADE1C6B2E2C9B6E3CBB9E4CCBBE4CBBAE3C9B7E3C5B2E1C0AB
DFB9A3DCB198D7A88DD19F82CB9677C68E6EC28768BE8063B9775DB16B55A55B49984B3D8C3F34\
873D348B473F985D55A87870BA948AC8AB9FD3BBAEDAC5B8DECBBDE1CEC0E1CEC1
E2CFC2E2D0C5E2D3C9E3D8CFE4DCD5E5E0DAE5E2DCE5E2DCE5E1D9E6E0D7E6DED4E6DED2E6DCCF\
E5DACBE4D6C6E2D0BFE0CBB9DEC8B6DDC8B6DECBBBDFD0C2E0D4C8E1D6CBE0D4CA
DFD1C6DDCCC1DAC8BCD6C4B8D0BFB4CAB8ADC2AFA4B9A397AF9588A587799B7B6C917162896B5A\
84665582625184604F895E4D905F4E996451A36C58AD7761B6826ABE8B73C39279
C7967EC99982CB9D86CEA18AD1A68ED3AB93D5AF97D7B39AD8B59CD8B69DD9B69DD8B59CD8B49A\
D7B398D6B095D4AE93D2AB91D0A78ECEA48CCDA28ACDA088CD9E87CD9D86CD9D85
CD9E86CCA189CCA590CBAC9ACBB3A7CABBB3CAC2BECBC7C5CCCAC8CDCCCAD0CECBD2D1CED5D5D2\
D8D9D8DBDDDDDDE1E1DFE4E3E1E7E5E3E8E5E4E9E5E4EAE5E4EAE5E4EAE4E4E9E4
E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E2E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E6DEE4E3DBE2E1D9E2E0D8E2DFD8E2E0D8E2E0D9E2E1D9E2E2DA\
E2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E5E0E2E6E0E3E6E0E3E7E1E4E8E2E4E8E3\
E5E8E5E3E6E5DDE0E0D1D1D3BCBABC9F9A9B837A796E615D695950776356907A68
AF9681C9B098DAC0A7E3C8AFE5CBB2E5CAB2E4CAB2E3CAB1E3C9AFE2C8AEE2C6ABE1C4AAE1C3A9\
E1C2A9E1C3ACE1C4AFE2C7B3E3C9B7E3CBB9E4CBBAE3CBB9E3C8B6E2C3B0E0BCA8
DDB59ED9AC93D3A388CD9B7DC79273C28B6BBE8364BA7B5EB57157AD654EA15543944637893C2F\
853A308A453B985A50AA746ABC8F84CBA699D6B7A8DDC2B2E1C8B8E2CABAE2CABA
E2CABBE2CABDE2CEC2E2D3CAE3D9D1E4DED7E5E1D9E5E1D8E5DFD5E6DDD1E6DBCDE6DACAE5D8C8\
E5D5C4E3D1BFE1CBB9DEC6B4DDC3B1DCC3B3DDC7B8DECCBFDFD1C5E0D2C8E0D0C5
DECCC0DDC7BADBC3B5D8C1B4D5C0B2D1BDB0CBB6AAC4AC9FBBA092B19484A789789E8070967A69\
9075648A6F5F876858866252875D4D8D5D4C966250A26B57AE7661B8816ABF8972
C49079C7957FCA9B84CDA089D0A68ED3AB92D5B096D7B49AD9B69DDAB89FDAB8A0DAB89FD9B69D\
D8B49AD6B197D4AE94D2AB92D0A88FCEA58DCDA28BCDA088CD9D86CD9C85CD9C84
CD9D85CC9F88CCA48ECBAA97CAB1A2C9B8ADC8BEB6C8C2BCC8C4BFC9C6C1CAC7C2CCCAC6CFCDCC\
D2D2D2D6D7D9D9DCDEDCE0E1DFE4E3E2E7E4E3E9E5E4EAE5E5EAE5E4EAE4E4E9E4
E4E9E4E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E2E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0\
E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DDE7E6DFE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E0E6E6DEE4E3DCE2E2DAE2E1D9E2E0D9E2E1D9E2E1D9E2E1DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE2E5DFE2E6E0E2E6E0E2E6E0E2E5DFE2E5DFE1E4DEE0E4DDDFE2DD\
DEE0DCDADCDAD3D3D4C6C4C7B2ADB19890927E73726D5D596A574E796355937B69
B09781CAB098DBC0A7E3C8AEE5CBB1E5CAB1E4CAB0E3C9AFE3C8AEE3C8ADE2C6ACE2C5ABE2C5AB\
E2C5ACE2C5AEE2C6B0E3C8B3E3CAB7E3CBB9E4CCBAE3CAB8E2C7B5E1C1AEDEB9A5
DBB19AD6A88FD0A084CA987AC49171BF8A6ABB8363B87A5DB37056AC644EA15743954A3A8C4134\
8941358F4A3F9D5D52AF7468C18C7FCFA092D8AFA0DEB9A9E0BFADE1C1AFE0C1B0
E0C0B1E0C1B3E0C5B9E1CBC0E2D2C8E3D8CEE4DBD1E4DBCFE5D9CBE5D6C7E5D4C3E5D2C0E4D0BE\
E3CEBAE1C9B6DFC3B0DCBEABDABAA9DABAAADABDB0DCC2B6DDC6BCDDC8BDDDC5B9
DBC0B3DABCADD9BAAAD9BBABD8BDAED7BEAFD3BBACCDB4A4C5A999BD9F8DB49583AC8E7CA58978\
9D8373957C6D8D7263866759825E4F83594A8B5A4A96604EA46A56B07460B97E69
BF8872C4907AC79882CB9F88CFA68DD3AB91D6B095D8B599DAB89DDBBAA0DBBBA1DBBAA1DAB79F\
D8B59BD6B198D4AE95D2AB92D0A890CEA58DCDA28BCC9F88CC9D86CC9B84CC9B83
CC9C84CC9E87CCA28CCBA893CAAF9DC8B5A6C7BBAEC7BFB4C6C1B7C6C2BAC7C3BCC9C4C1CBC8C7\
CECCCED1D1D5D5D6DBD9DCDFDDE1E2E1E5E4E3E8E5E4EAE5E5EAE5E5EAE4E4E9E4
E4E9E4E4E8E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0\
E3E6E0E3E6DFE3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DFE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E5DDE9E9E1E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE3E6E0E3E6E0E3E6E0E2E6E0E1E5DEE0E3DCDDE0D9DADCD5D6D7D0\
D1D1CCCBC9C7C2BFC0B5B0B3A49C9F8F83857B6C6B705D58705A5180685A997F6D
B59A84CCB299DBC1A7E3C9AEE5CBB0E5CAAFE4C9AFE3C8ADE3C7ADE3C6ACE3C6ABE3C5ABE3C5AB\
E3C6ACE3C6AEE3C7B1E3C8B3E3CAB6E4CBB8E4CCB9E3CAB7E2C6B3E0C0ABDDB7A2
D9AE97D5A58CCF9D82C9977AC49273BF8D6DBC8768B97F62B5765CAF6C55A6614D9D5746965142\
9451439A594CA7685BB77A6DC78D7FD39D8EDAA999DDB2A0DEB6A4DEB8A5DEB7A5
DDB7A6DDB8A9DDBCAEDEC2B6E0C9BDE1CEC3E2D1C5E3D0C3E3CEBFE3CBBAE3C9B7E3C7B4E2C6B2\
E0C4B0DEBFABDCB9A6D9B2A1D7AE9ED7AD9ED7AFA3D8B3A8D9B7ACD9B7ADD8B5A8
D7B1A3D7AE9ED7AE9DD8B2A1D9B8A7D9BCABD7BCABD3B7A5CCAF9CC5A592BE9D8AB89785B19382\
AA8D7EA08678957A6D8A6D618161547E584B8355478C5847995E4CA56754B0725F
B87E6ABF8A75C5957FCA9E86CFA58CD3AB90D6B195D8B599DAB99EDBBBA1DCBCA3DBBBA2DAB9A0\
D8B59CD6B198D4AE95D2AB92CFA890CEA58DCDA28BCC9F88CB9D85CB9B84CC9B83
CC9B84CC9E86CBA28ACBA790CAAD98C8B3A0C8B8A7C7BCADC7BFB2C7C1B6C8C2BBC8C4C0C9C5C6\
CBC8CCCECCD2D1D1D8D6D8DCDBDEE0E0E4E3E3E8E4E4EAE5E5EAE5E5EAE4E4E9E4
E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0\
E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE3E6E0E3E7E1E3E7E1E3E6E0E1E4DEDDDFD8D7D8D1CFCFC7C7C5BD\
BEBAB4B4AFABAAA3A29E95969185878474747A6664765F597C63588D7262A48875
BCA08AD0B59CDDC2A8E3C9AEE5CAAFE4C9AEE4C8ADE3C6ACE3C5AAE3C4A9E3C4A9E3C4A9E3C4AA\
E3C5ABE3C6ADE3C7AFE3C8B2E3CAB5E4CBB7E4CCB7E3CAB6E2C6B1E0BFA9DCB59F
D8AC94D4A38ACF9D82CA997CC69678C29374C08F71BE8A6EBB8369B77C65B1755FAA6E5BA66B58\
A56B5AAA7061B57A6CC18679CE9386D69E90DBA798DDAD9CDDB09EDDB19FDCB19E
DBB09FDBB1A1DBB4A6DCB9ACDDBFB2DEC3B7DFC5B8E0C4B6E1C1B2E1BEAEE1BCAAE0BBA8DEBAA7\
DDB8A4DAB3A1D8AD9BD6A696D4A192D49F91D49F93D5A297D5A499D5A499D4A295
D39F91D29E8ED3A190D5A896D7B09ED8B7A4D7B9A6D4B6A2CFAF9ACAA692C49F8BBF9A88BA9686\
B39284A98B7E9D807591736886665B805B4F8054478551438E5343995A49A46554
AF7361BA826FC3907BCA9B84CFA48BD3AB90D6B094D8B599DAB99EDCBCA1DCBDA3DCBCA2DAB9A0\
D8B59CD6B198D4AE94D1AA91CFA78FCDA58CCCA28ACB9F88CA9D86CA9C84CA9B84
CB9C84CB9E87CBA28ACAA68ECAAB94C9B09AC9B5A1C9BBA9CABFB0CBC3B7CCC6BECCC7C3CBC7C8\
CBC7CCCCC9D0CFCDD5D4D4DAD9DBDEDFE2E1E2E7E4E4EAE5E5EAE5E5EAE4E4E9E4
E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E2E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0\
E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE3E4DD
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE2E5DFE3E6E0E4E7E1E4E7E2E3E6E0DFE2DCD8DAD3CECEC6C2BFB6B4AFA6\
A69F9799908A8D827F8377747C6D6B7965627A625D80645C8C6E629D7F6EB1937F
C5A891D4B9A0DEC4A9E3C9AEE4CAAFE4C9ADE3C7ACE3C5AAE3C3A8E3C2A7E3C1A6E3C1A6E3C1A7\
E3C2A9E3C4ABE3C6AEE3C8B0E3CAB3E4CBB5E4CCB5E3CAB4E2C5AFDFBEA7DCB49D
D8AB93D4A28AD09D83CC9B7FC99A7DC79A7DC6997CC5977CC3947AC19179BE8D76BA8A74B88874\
B98975BD8B7AC49081CC9789D49E90DAA496DDA99ADEAC9CDDAE9DDCAE9CDAAD9C
D9AD9CD9AD9DD9AFA0D9B3A4DAB7A9DBBAACDDBAACDEB8AADFB5A6DFB1A3DEAFA0DDAF9EDBAE9D\
D9AC9BD6A997D4A392D39C8CD29687D19285D29185D29186D29286D29185D09083
CF8F81CF9080CF9584D19E8CD3A895D5B09CD5B49FD3B19CCFAB96CBA38EC79C88C39886BE9485\
B89184B08B80A5837999786E8E6C61866054815548804D3F844A3C8C4E3F985849
A66857B37968BF8A77C89781CFA289D3A98ED6B093D8B598DAB99DDCBCA1DCBDA3DCBCA2DAB99F\
D8B59BD6B196D4AD92D1A98FCFA68DCDA48BCBA189CA9F87C99D86C99C85C99C85
CA9D86CA9F87CBA28ACAA58DCAA991C9AD96CAB39DCBB9A5CDC0AFCFC5B9D0C9C1CFCAC7CDC8CA\
CBC7CDCBC7CFCDCBD2D2D1D7D8D9DCDEE1E0E2E7E3E4E9E4E5EAE5E5EAE4E4E9E4
E4E9E3E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0\
E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE3E5DFE3E6E0E4E7E1E4E7E2E2E5E0DDDFD9D3D3CCC4C2BAB1ADA39E978D\
8B82787B70676F625B6859546855516E58527A60588A6C619C7C6DAE8E7CBFA08B
CEB099D9BDA4E0C5AAE3C9AEE4C9AEE4C8ADE3C5ABE3C2A8E3C0A6E3BEA5E3BEA4E3BEA4E3BEA5\
E3C0A6E3C2A9E3C5ABE3C7AEE3C9B1E4CBB3E4CBB3E3C9B1E1C4ADDFBCA5DCB39C
D8AA92D4A28AD19E85CE9C82CC9D82CB9F84CBA187CCA389CCA48BCCA58DCBA58ECAA58ECAA58F\
CBA591CEA693D2A796D7A89ADBAA9DDEAC9FDFADA0DEAEA0DDAF9FDCAF9EDAAE9D
D9AD9CD8AD9DD8AE9ED8B0A1D8B2A3D9B3A4DBB2A4DCAFA1DDAC9EDDA89BDDA699DBA697D8A596\
D6A494D3A190D29B8BD19586D08F80D08A7CD0887AD08679D08578CF8476CE8375
CD8375CC8677CC8D7CCE9684CFA08DD1A995D1AD97D0AB95CEA58FCB9D88C89683C59281C18F81\
BC8C81B5897EAC8379A27B719770658D64588456497F4A3D7E43368243358D4C3E
9C5C4EAC6F5FBB8270C6917DCD9D85D2A68CD5AE92D8B497DAB89DDCBBA1DCBCA2DCBBA1DAB99E\
D8B599D6B095D4AC91D1A98ECFA58BCDA289CBA088C99E87C89D86C89D85C89D86
C99E86CAA088CBA28ACBA58CCAA78FCAAB92CAAF98CCB6A1CEBDACD0C4B7D1C9C1D0CAC7CDC8CA\
CBC6CBCBC6CDCDC9D0D2D0D5D8D8DADEE0DFE2E6E2E4E9E4E5EAE4E5E9E4E4E9E3
E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E4E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0\
E3E6E0E3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DDE2E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DB
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE2E5DFE3E6E0E3E6E0E4E7E1E4E6E1E1E3DED9DAD5CBCAC4B7B4ACA09A90877F74\
71665B5F524853453D503F3857433C674E467C6056947568AB8A7ABE9C89CCAC96
D6B8A0DDC1A7E1C6ACE3C9ADE4C8ADE4C6ACE3C3A9E3C0A7E3BDA5E3BBA3E2BBA2E2BBA2E2BCA3\
E2BEA5E2C1A7E2C4AAE3C6ADE3C8AFE3CAB1E4C9B1E3C7B0E1C2ABDFBBA4DCB29B
D8A992D4A28AD19E85CF9D84CE9F85CEA288CFA78DD1AC93D3B198D4B69DD6B9A2D7BCA4D9BDA6\
DABDA7DBBCA8DDB9A8DFB7A8E0B5A8E0B4A8E0B4A7DFB3A5DEB3A4DDB2A2DBB1A1
DAB1A0D9B1A0D8B1A1D8B1A1D8B2A2D9B1A2DAAFA0DCAC9EDDA99BDDA699DCA496DAA395D7A293\
D4A091D29D8DD19989D09384D08E7ED0897AD08576D08273CF8070CE7E6FCD7E6E
CC7F6FCB8373CB8978CC9280CD9B88CEA38ECEA690CEA38ECD9E89CB9683C9907EC68B7CC3897C\
BF867BB9847AB28076AA7A6FA071659565598A564980483B7B3E317C3B2F864336
945244A56456B57867C18875C99680CFA188D3AA8FD7B296DAB79CDBBAA0DCBBA1DCBAA0DAB89C\
D8B498D6B093D4AC8FD1A88CCFA48ACDA188CB9F87C99D86C79D85C79D85C79D86
C89F87C9A088CAA28ACBA48BCBA68DCBA88FCAAB94CAB09BCAB6A4CBBCAECBC0B8CBC2BFCAC3C4\
C9C3C7CBC5CBCECACFD3D1D5D9D9DADEE0DEE1E5E1E3E8E3E4E9E3E4E9E3E4E9E3
E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E3E7E2E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0E3E6E0\
E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DDE2E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E1DAE2E1D9E2E1D9E2E1DAE2E1DAE2E2DB
E2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE3E5DFE3E6E0E3E6E0E4E6E1E3E4E0DEDFDBD4D4CFC3C0BBABA69F8E877F72695F\
594E44473A313E2F273F2E264C3830634B428064589E7F70B89785CAA995D6B6A0
DDBFA6E1C4AAE3C7ACE3C8ADE4C7ACE3C4AAE3C1A8E3BDA6E3BBA4E2B9A3E2B8A2E1B9A2E1BBA3\
E1BEA4E1C1A7E2C4A9E2C6ACE3C8AEE3C8B0E4C7B0E3C4AEE1BFA9DFB8A3DCB09B
D8A992D4A28AD19E85CE9C82CD9D83CDA187CFA78ED3AF96D6B8A0DABFA8DDC6AFE0CAB3E1CCB6\
E3CBB6E3C9B6E3C6B5E3C2B3E3BFB1E2BCAFE2BAADE1B9ABDFB8AADEB8A8DDB8A8
DCB8A7DBB7A7DAB7A7DAB7A6DAB6A6DBB4A4DCB2A3DDAFA0DEAD9EDEAA9BDCA899DAA697D8A495\
D5A292D3A08FD29C8BD29786D29382D18E7DD18A79D18775D08472CF8370CE8270
CD8371CC8675CB8B7ACC9280CC9985CC9E89CDA08BCD9D88CD9784CC917FCA8A7BC88678C58377\
C28176BD7E74B77B70AF766AA66E619B63558F55478447397D3C2F7C382C833D31
8F493C9E594CAE6C5CBA7D6BC48D78CB9B83D1A68CD6AF94D9B59BDBB89EDCBAA0DCB99EDAB79B\
D8B397D6AF92D4AB8ED1A78BCFA389CDA087CA9E86C89C85C79C84C69C84C69D85
C89E86C9A087CBA289CCA48ACCA58CCBA68DC9A78FC5A893C2A997BFAC9DBDAFA5BEB3ADC1B8B6\
C5BEBFCBC5C8D1CCCFD6D3D5DBDADADEDFDDE1E3DFE2E6E1E3E7E2E4E8E3E4E8E3
E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0E3E6E0\
E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DDE2E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DAE2E1DAE2E0D9E2E0D9E2DFD8E2E0D8E2E0D9E2E1DA
E2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE2E5DFE3E6E0E3E6E0E3E6E0E3E5E0E1E2DEDCDBD7D0CDCABCB7B4A09A95817973625951\
483E35382C2332241B37271F49362C654E43866B5EA7897AC2A290D4B49FDDBFA7
E2C4ABE3C6ACE3C7ACE3C7ACE3C5AAE3C3A9E3BFA7E3BBA6E3B9A4E2B7A3E1B7A3E1B8A3E0BBA4\
E0BEA5E0C1A7E1C4AAE2C6ACE3C7AEE3C7AFE4C4AFE3C1ACE2BBA8DFB5A2DCAF9B
D8A892D4A28BD09D84CC9A80CB9A7FCB9D83CEA48BD2AE96D8B9A2DDC3ADE1CBB6E4D0BBE6D3BE\
E6D3BFE6D1BEE6CDBCE5C9B9E4C5B7E3C3B4E3C1B3E2C0B1E1BFB0E0BFAFDFBFAF
DEBFAFDDBFAFDDBFAFDDBEAEDDBDACDDBBABDEB9A9DFB7A7DFB5A4DFB2A2DEB09FDCAD9CDAAB99\
D7A896D6A593D5A290D59F8CD49C89D49885D39581D2927DD18F79D08D78CF8D77
CF8D79CE8F7BCD927ECD9682CC9985CC9C87CD9B87CD9884CD9381CD8C7DCC8779CB8276C87F74\
C47C72BF7A6FBA766AB37264AB6A5CA160519554458B4739833D3181382D853B2F
8E44389A5144A76152B37361BE8470C7947DCEA189D4AB92D8B299DAB69DDCB89EDBB89DDAB69A\
D8B396D6AF91D3AB8ED1A78BCFA388CCA087CA9D85C89C84C79B83C69A83C69B83
C79D85C99E86CBA188CDA38ACDA48BCBA48BC7A38BBF9F89B79B88AF9888AB988DAD9E97B5A9A5\
BFB6B5CAC4C4D3CFCFD9D7D7DDDCDBDFDFDCE0E2DEE1E4DFE2E6E0E3E7E2E4E8E2
E4E8E3E4E8E3E4E8E2E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0E3E6E0\
E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE3E4DDE2E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DAE2E1DAE2E0D9E2DFD8E2DFD7E2DFD8E2E0D9E2E1DA
E2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE3E6DFE3E6E0E3E6E0E3E5E0E2E4DFE0DFDCD9D7D5CCC8C6B7B1AF9A93907A736D5C534C\
433A31352A2132251C3B2B214F3C326C564B8E7567AF9383CAAC99DABCA7E2C5AD
E4C8AEE4C8ADE4C7ACE3C6AAE3C4A9E3C1A8E3BEA7E3BAA6E3B8A5E2B6A5E1B7A4E0B8A4DFBBA5\
DFBFA6DFC2A8E0C5AAE1C6ACE3C7AEE3C5AEE4C2AEE3BEACE2B9A8DFB4A2DCAE9B
D8A893D3A28BCF9C83CB987DC8967BC8997DCBA086D1AB92D7B8A1DEC3AEE2CCB8E5D2BEE6D4C1\
E7D5C2E7D3C1E6D0BFE5CDBDE5CABBE4C8B9E3C6B7E3C5B6E2C5B5E2C6B5E1C6B6
E1C7B6E0C7B7E0C7B7E0C6B6E0C5B4E0C3B2E1C1B0E1C0AEE1BEACE1BCA9E0B9A6DEB6A2DCB29F\
DAAF9BD9AC98D8AA96D8A894D7A691D7A48ED6A18BD59F87D49C84D29A82D29981
D19982D09983D09A84CE9B85CD9B86CD9B85CD9984CD9582CE907FCF8A7CCE8579CC8176CA7E72\
C67B6FC1786BBC7466B66F60AF6858A6604F9D5646934C3D8C4336893F328A3F33
904338984D40A25A4CAD6B5AB87C69C28E78CB9D85D2A88FD7AF96DAB49ADBB69CDBB69BDAB498\
D8B295D6AE91D3AB8DD1A78ACFA388CCA086CA9D85C89B83C69A82C69982C69A82
C79B83C99D85CB9F87CDA289CEA48ACBA38AC59F87B99780AB8C799F85749983759C8A80A89A93\
B8AEAAC8C2BFD5D1CEDCD9D7DFDEDBE0DFDCE0E1DCE1E2DEE2E4DFE3E6E1E3E8E2
E4E8E3E4E8E3E4E8E2E4E8E2E3E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0\
E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DAE2E1D9E2E0D8E2DFD8E2DED7E2DFD8E2E0D8E2E1DA
E2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE3E6DFE3E6E0E3E6E0E3E5E0E1E2DFDEDDDBD7D4D3CAC4C5B6AFAF9B93917E7571635952\
4D433942362B4133284B3A2E5F4B3F7B64579A8172B89D8BD0B4A0DEC2ABE4C8B0
E6C9B0E4C8ADE4C7ABE3C5A9E3C3A8E3C0A7E3BDA7E3BBA6E3B8A6E2B7A6E1B7A6E0B9A6DFBBA6\
DEBEA7DFC1A9E0C4AAE1C6ACE2C6ADE3C5AEE4C2ADE3BEABE2B9A8DFB4A2DCAF9C
D8A994D3A38CCE9C83C9967BC69378C6957ACA9C82CFA88FD6B59EDDC1ACE2CBB7E5D0BEE6D3C1\
E6D3C2E6D3C1E5D1C0E5CFBEE4CDBDE4CCBBE4CBBAE3CABAE3CABAE3CBBAE3CCBB
E3CDBCE2CDBDE2CDBDE2CDBCE2CCBBE3CAB9E3C8B7E3C7B5E3C5B3E2C3AFE1C0ACE0BCA7DEB8A3\
DDB5A0DBB29DDBB19CDBB09ADAAF99D9AE97D8AC94D7AA91D5A88ED4A68CD4A48B
D3A38BD3A28AD2A18AD0A089CE9E87CD9B85CD9883CD9481CE8F7FCF8B7CCF877ACD8376CA8073\
C77D6FC3796ABE7565B9715FB36B58AC6452A45C4B9D5544974E40944A3D93483C
954A3E9A5043A15A4CAB6858B57966BF8A74C99981D0A48BD5AC93D8B197DAB39ADAB499D9B397\
D8B194D6AE90D3AB8DD1A78ACFA388CCA086CA9D84C89B82C69981C69980C69980
C79A82C99C83CC9F86CEA188CEA38ACBA289C39C84B4907AA2826E9376658B72648E7B6F9D8E85\
B1A69FC5BEB9D4D0CBDCDAD6E0DEDAE0DFDBE0E0DCE1E2DDE2E4DFE3E6E1E3E7E2
E4E8E3E4E8E3E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DF\
E3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DDE2E4DDE2E4DD
E2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DAE2E1DAE2E0D9E2DFD8E2DFD8E2DFD8E2E0D9E2E1DA
E2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE3E6DFE3E6E0E3E6E0E2E4DFE0E1DEDCDBDAD5D2D3C9C4C6B8B1B2A39A998C827D776B62\
67594E5F4F415F4C3E6852447861528F7666A98E7DC1A692D4B9A3DFC4ADE4C9B0
E5CAB0E4C8ADE4C6ABE3C4A9E3C2A8E3C0A7E3BEA7E3BCA7E3BAA7E2B9A7E1B9A7E0B9A7DFBBA7\
DFBDA8DFC0A9E0C3ABE1C5ACE3C6ADE3C5AEE4C3ADE3BFACE2BAA8DFB6A3DCB19D
D8AB95D3A48DCE9D84C9977CC69378C69479C99B80CFA58DD6B29BDCBFA9E1C8B4E3CEBBE5D1BF\
E5D2C0E5D2C0E5D1C0E4D0BFE4CFBEE4CEBDE4CEBDE4CDBCE4CDBCE4CDBDE4CEBE
E4CFBFE4D0C0E4D1C0E4D1C0E4D0BFE4CFBEE4CDBCE4CBBAE4C8B7E3C5B3E2C2AFE1BEAADFBBA6\
DEB8A2DDB6A0DDB59FDCB59EDCB59EDBB49CDAB39AD8B197D7AF94D6AD92D5AB91
D5A990D4A88FD3A68DD1A38BCFA088CD9C85CC9882CC9480CD917FCD8D7DCD8A7BCC8778CA8475\
C78271C47F6DC07C68BC7763B7725EB26D59AD6755A86251A35D4DA05A4B9E574A
9E564AA0594DA56053AC6C5CB57A66BE8972C7967DCDA187D3A98ED6AE94D8B197D9B297D8B296\
D7B093D5AE90D3AA8DD1A78ACFA388CCA086CA9D84C89B82C69A80C6997FC69980
C79A81C99C82CC9E85CEA188CEA289CBA088C19A82B18D779E7D698D705F836B5C87736795867C\
ABA097C0B9B1D1CCC5DBD8D2DFDED8E0E0DBE0E1DCE1E3DEE2E5E0E3E6E1E3E7E2
E4E8E2E4E8E2E4E8E2E4E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DF\
E3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DDE2E4DDE2E4DD
E2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DAE2E1DAE2E1D9E2E0D9E2E0D9E2E0D9E2E1D9E2E1DA
E2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DF
E2E5DFE3E6DFE3E6E0E3E6E0E2E4DFDFE0DDDBDADAD4D1D3CAC5C8BEB6B9B0A6A4A1948E938479\
897768846F5E846C5A8B705E967A68A68A76B89C87C9AD97D7BCA4DFC4ACE3C8AF
E4C9AEE4C8ADE3C6ABE3C4A9E3C2A7E3C1A7E3BFA7E3BEA8E3BDA8E2BCA9E2BBA9E1BAA8E0BAA8\
E0BBA8E0BEA9E1C1ABE2C4ACE3C6AEE3C6AEE3C5AEE3C2ADE2BEA9DFB9A5DCB49E
D8AD97D3A68ECE9F86CA987EC8957AC8957BCA9B81CFA48CD5B099DBBBA5DFC4B0E2CAB7E3CDBB\
E4CFBEE4D0BFE4D1C0E4D1C0E4D1C0E4D0BFE4CFBEE4CFBEE4CEBDE4CFBEE4CFBE
E4D0BFE4D1C0E4D2C1E5D2C2E5D2C2E5D1C1E5CFBFE5CCBCE5C9B8E4C5B4E3C1AFE2BEABE0BBA7\
DFB9A3DEB8A1DDB7A0DDB7A0DCB79FDBB79EDAB59CD8B49AD7B298D6B096D6AE94
D5AC93D4AA91D3A78FD1A48BCEA188CC9E84CA9A82CA9680CA937FCB907ECB8E7CCA8C7AC88B78\
C68975C48772C1846EBE816BBB7D67B87964B57561B1725EAE6E5DAB6B5BA9685A
A8675AA9675BAC6B5EB17363B77E6ABE8A72C5957ACC9F82D1A68AD4AB90D7AF94D8B095D8B095\
D7AF92D5AD8FD3AA8CD1A68ACFA388CCA086CA9D83C89B81C69A80C69A7FC69A7F
C79A80C99C82CC9E84CEA087CEA188CA9F87C09881B08B769C7C688A6F5E80695B837064918278\
A59B91BBB4ABCDC8BFD8D5CEDEDDD6E0E1DBE1E3DEE2E5E0E3E6E1E3E7E2E4E8E2
E4E8E2E4E8E2E4E7E2E3E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DF\
E3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE3E4DDE2E4DDE2E4DD
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DB
E2E2DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DF
E2E5DFE3E6DFE3E6DFE3E5DFE1E4DEDEE0DDDAD9D9D4D1D3CDC8CBC5BDBEBEB3B0B7A8A0B19F91\
AD9784AA907CAA8D78AD8F79B4947EBD9D87C7A891D0B49CD9BDA4DEC3AAE1C7AC
E2C7ADE3C7ACE3C5AAE3C4A9E3C2A8E3C1A7E3C1A8E3C1A9E3C1AAE2C0AAE2BEAAE2BCAAE1BAA9\
E1BAA9E1BCAAE2C0ACE2C3ADE3C6AFE3C8AFE3C7AFE3C5AEE1C2ABDFBDA6DCB7A0
D8B099D4A991D0A289CC9B82CA977ECA977ECC9C83D0A48BD5AE96DAB8A1DDC0AAE0C6B1E2CAB7\
E3CDBAE3CFBDE4D0BFE4D1C0E4D2C0E4D1C0E4D1BFE4D0BEE4CFBEE4CFBEE4CFBE
E4CFBFE4D0C0E5D2C1E5D3C2E5D3C2E5D2C2E5D0C0E5CCBCE5C7B8E4C3B4E3BFAFE2BCAAE0BAA6\
DFB8A3DEB7A1DDB7A0DDB79FDCB79FDBB69EDAB59CD8B49AD7B298D6B096D5AE95
D5AC93D4AA91D2A78ECFA58BCCA287C99E84C89B82C79880C7957FC7937EC7927DC7917CC6907A\
C59078C48F76C28D74C08A72BF8770BD856EBB826DB9806CB77E6BB57C6AB37969
B27769B27669B3786AB67D6CBA846FBF8D73C59679CA9E80CFA487D2AA8DD5AD92D6AF94D7AF94\
D6AE92D5AC8FD3A98CD1A68ACEA287CC9F85CA9D83C89B81C69B7FC59A7EC69A7F
C79B7FC99C81CB9E84CDA086CDA187C99F86BF9880AF8B769B7C6A8970607F6B5E8171668E8177\
A1978EB7AFA6C8C3BBD5D2CBDDDCD5E0E1DCE2E5DFE3E6E1E3E7E2E4E8E2E4E8E2
E4E8E2E4E8E2E3E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DF\
E3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DD
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DF
E2E5DFE3E6DFE3E6DFE2E5DFE1E3DEDEDFDCDAD9D8D5D2D2D0CACBCDC3C2CBBEB8CBB9AECBB5A4\
CAB19CCAAD95C9AA92CAA991CCAA92CFAE96D3B39AD6B99FDABEA4DDC2A7DFC4A9
E1C6AAE1C6AAE2C5AAE2C4A9E2C3A8E3C3A8E3C3A9E3C4AAE3C4ABE3C3ACE2C0ACE2BDABE2BBAB\
E2BBABE2BCACE2C0ADE3C4AFE3C7B0E3C9B1E3CAB1E3C8B0E2C5ADDFC0A8DCBBA2
D9B49BD5AD94D1A58CCF9F86CD9B82CD9A82CE9D84D0A38AD4AA92D8B39BDBBAA4DEC1ABE0C6B1\
E1CAB6E2CDBBE3CFBEE3D1C0E4D2C0E4D2C1E4D1C0E4D0BFE4CFBEE4CFBDE4CEBD
E4CFBEE4CFBEE4D1C0E4D2C1E5D3C2E5D2C2E5D0C0E5CCBDE5C7B8E4C1B3E3BDAEE2BAA9E0B8A5\
DFB7A2DDB6A0DDB59EDCB59DDBB49CDBB39BD9B39AD8B299D7B197D6AF95D5AD94
D4AB91D2A98FD0A68CCDA489C9A186C69F83C49C81C39980C3977EC4957EC4947DC4947CC4947B\
C3947BC3947AC29379C19178C18F77C08E76BF8C76BE8B75BD8A75BC8874BB8674
B98474B98374B98374BB8674BD8B74C19176C59779CA9E7FCEA486D1A88CD4AC91D5AE93D6AE93\
D6AD91D4AB8ED3A88CD0A589CEA187CB9E84C99C82C79B80C69B7FC59A7EC59B7E
C79B7FC89C81CB9E83CC9F85CCA086C89E84BE977FAD8B759A7C6A8870617E6B5F7F71678B8078\
9E958EB4ACA5C6C1BAD3D1CADCDCD6E1E2DDE3E6E1E4E8E3E4E8E3E4E8E3E4E8E2
E4E8E2E3E7E2E3E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DF\
E3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DD
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE3E6DFE3E6E0E2E5DFE1E3DEDFDFDADBD9D6D8D3CFD5CCC8D4C7C1D5C5BBD8C3B5DBC2AF\
DCC1ABDDBFA7DCBCA4DCBBA2DBBAA1DBBAA1DABBA2DABDA3DBBFA4DCC1A6DDC3A7
DFC4A8E0C4A9E1C4A9E1C4A9E2C4A9E2C4A9E3C5AAE3C5ACE3C6ADE3C5AEE3C2AEE3C0AEE3BEAD\
E3BDADE3BFAEE3C2B0E3C5B1E3C9B3E3CBB4E3CBB3E3CAB2E2C7AFE0C3ABDDBDA5
DAB79ED6B097D3A990D1A38BCF9F86CF9D85CF9E85D0A189D3A68ED5AD95D8B49CDBBBA4DDC1AB\
E0C6B2E1CBB7E2CEBCE3D1BFE3D2C0E4D2C1E4D2C1E4D1C0E4D0BFE4CFBEE4CEBD
E4CEBDE4CFBEE4D0BFE4D2C0E4D2C1E5D2C2E5D0C0E5CCBDE4C7B8E4C2B3E3BEAEE1BBA9E0B9A5\
DEB7A2DDB59EDCB39CDBB29ADAB099D9B097D8AF97D7AF96D6AF95D5AE94D4AC92
D2AA8FD0A78CCDA48AC9A287C6A085C39E83C19C81C0997FC0977DC0967CC1957BC1947BC2957A\
C1957AC1957AC1957AC1947AC19379C19279C19179C19179C09079C08E79BE8C79
BD8B79BD8A79BD8B79BE8D78C09078C3957AC69A7CCA9F81CDA487D1A88CD3AB90D5AD92D6AD92\
D5AC90D4AA8ED2A78BD0A388CDA086CA9D83C89B81C69A7FC5997EC59A7EC59A7E
C69B7EC89C80CA9D81CB9F84CBA085C69D83BC957DAB8974977A68856E5F7A695E7C6E66887E78\
9C948FB3ACA8C6C1BDD4D2CDDCDDD8E1E4DFE3E7E2E4E9E3E4E9E4E4E9E3E4E8E2
E4E8E2E3E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DF\
E3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE3E4DDE2E4DDE2E4DDE2E4DD
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE2E6DFE2E6E0E2E5DFE1E3DDE0DFD9DDD9D3DBD3CBDACDC4DAC9BEDCC8B9DFC8B6E2C8B4\
E5C8B2E5C8B0E5C6AFE4C5ADE2C3ABE0C2A9DEC1A7DCC0A5DCC0A4DCC0A5DCC1A6
DDC2A7DEC3A8DFC3A8E1C4A9E1C4A9E2C5AAE3C6ACE3C7AEE3C7AFE3C6B0E3C4B0E3C2B0E3C1B0\
E3C1B0E3C2B1E3C5B3E3C8B4E3CBB6E3CCB6E3CCB6E3CBB4E2C8B1E0C4ADDEC0A8
DBBAA1D8B49BD5AD94D3A78FD2A38AD09F87D09E86D09F87D1A28AD3A78FD5AD95D8B59DDBBCA6\
DEC3ADE0C9B4E1CDB9E2D0BDE3D2C0E4D3C1E4D3C1E4D2C1E4D1BFE4CFBEE4CFBD
E4CEBDE4CEBDE4CFBEE4D1C0E4D2C1E4D2C1E4D0C0E4CDBDE4C9B8E4C5B3E3C1AEE1BDAAE0BAA5\
DEB7A1DCB49DDBB19ADAAE97D9AC94D8AB93D7AC93D6AC92D5AD92D4AC91D2AB8F
D0A88CCDA58AC9A287C6A085C29E83BF9C81BD9A80BD987EBD967CBE957ABF9479BF9378C09378\
C09378C09378C09378C09378C09379C09379C09279C19279C19179C08F79BF8E79
BF8D79BE8E79BF8F79C0917AC2947BC4987DC79D80CBA185CEA589D1A98ED3AB91D5AC92D5AC91\
D5AA90D4A88DD1A58ACFA187CC9E84C99B82C79980C5987EC4987DC4987DC4997D
C59A7DC79B7FC89D80CA9F82CA9F83C59C81BA947BA886719276647F695B746359766A63857B77\
9B9391B3ADACC7C3C2D5D4D2DEDEDCE2E5E1E4E8E3E4E9E4E4E9E3E4E9E3E4E8E2
E4E7E2E3E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DF\
E3E5DFE3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E4DD
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E6E0E2E5DFE1E3DCE0DFD7DFD9CFDED3C7DDCDBEDECAB8E0C8B5E2C8B3E4C8B3\
E6C9B3E7CAB3E6C9B3E5C9B2E3C7B0E1C5ADDEC3AADCC1A7DBC0A5DABFA5DBC0A5
DCC1A6DDC2A7DEC3A8E0C4A9E1C5AAE2C6ACE3C7AEE3C8AFE3C8B1E3C7B2E3C6B3E3C5B3E3C4B3\
E3C5B3E3C6B5E3C8B6E3CBB8E3CCB9E3CDB9E3CDB8E3CCB7E2C9B4E0C5AFDFC1AA
DCBCA4DAB69ED8B198D6AB92D4A68ED2A28AD19F87D09D85D09E86D1A189D3A78FD5AF97D9B8A0\
DCC0A9DEC7B1E1CCB7E2CFBCE3D1BFE4D3C1E4D3C1E4D2C1E4D1C0E4D0BFE4CFBE
E4CEBDE4CDBCE4CEBDE4CFBEE4D0BFE4D1C0E4D0BFE4CFBCE4CCB8E3C8B4E2C4AFE1C0AADFBBA5\
DEB7A0DCB39CDAAF97D9AB93D7A891D6A78FD6A88ED5A98ED4AA8ED2AA8DD0A88C
CDA689CAA386C6A084C29E83BF9C81BC9A80BB987EBA967CBB9479BC9377BD9176BD9075BE9075\
BE9075BE9075BE9075BF9176BF9176BF9176BF9176BF9076BF8F76BF8E76BE8D75
BE8D75BE8E76BF9077C09379C3977CC69B80C99F84CCA488CFA78CD2A98FD3AB91D5AB91D5AA91\
D4A98FD3A68CD1A389CE9F86CA9C83C89980C6977FC4967DC4967DC4967CC4977C
C5997DC69B7EC79D7FC99F81C89F82C39B80B8927AA4836E8D71607963556D5D5470645F807776\
989293B3AEB0C8C5C7D7D6D6DFE0DFE3E5E2E4E8E3E4E9E3E4E9E3E4E8E3E4E8E2
E4E7E2E3E7E1E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DF\
E3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DE
E2E5DFE2E5DFE2E5DFE1E4DEE1E2DBE0DED5E0D8CCE0D2C2E0CDB9E1C9B3E1C6AFE2C6AFE3C6AF\
E4C7B0E4C7B1E3C7B1E2C7B1E0C6B0DEC4ADDCC2ABDAC0A8D9BFA6D8BFA5D9BFA5
DBC0A6DCC1A6DEC2A8E0C4A9E1C5ABE2C7ADE3C8AFE3C8B1E3C9B3E3C8B4E3C8B5E3C8B5E3C8B6\
E3C8B6E3CAB8E3CBB9E3CDBAE3CEBBE3CEBBE3CEBAE3CCB9E2C9B6E1C6B2E0C2AD
DEBDA7DCB8A1DAB39BD8AE96D6A991D4A48CD2A088D09D85CF9C84D09E86D1A38BD4AA92D7B49B\
DBBDA5DDC4ADE0CAB4E2CEBAE3D0BEE3D2C0E4D3C1E4D3C1E4D2C1E4D0BFE4CEBD
E4CCBCE4CBBBE3CBBBE3CCBCE3CEBCE3CFBDE3D0BCE3CFBBE3CDB8E3CAB4E2C6AFE1C2AADFBDA5\
DDB7A0DBB29AD9AD95D7A891D6A58DD5A48BD4A48AD3A58AD2A68AD0A689CEA588
CBA386C7A184C49E82C09C81BD997FBA977EB9957CB9937AB99277BA9175BC8F73BC8E72BD8D72\
BD8D72BD8D73BD8D73BE8E73BE8F73BE9072BE8F72BE8E72BD8C72BD8B71BD8B71
BC8B71BD8C71BE8F73C09377C4987CC79D82CBA187CEA58BD0A88ED2AA90D4AA91D4AA91D4A990\
D4A78ED2A48BCFA188CC9D85C99A82C6977FC5957DC4947CC3947CC3957CC3967C
C4987DC59A7DC69C7FC89F81C89F82C29B80B69178A1806B886D5C725C5065564E695D597B7272\
958F91B1ADB0C8C6C9D7D7D8E0E1E0E3E6E2E4E8E3E4E9E3E4E9E3E4E8E3E4E8E2
E4E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DF\
E3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DE
E2E5DFE1E4DFE1E4DFE0E3DDE0E0D9E0DCD3E0D7C9E1D1BFE1CCB6E2C8AFE2C5ABE2C3AAE1C3AB\
E1C3ABE1C3ABE0C3ABDFC2ABDDC2ABDAC0AAD8BFA9D6BEA9D5BDA8D6BDA7D7BEA6
DABFA6DCC1A7DEC2A8E0C4AAE1C6ACE2C7AFE3C8B1E3C9B4E3CAB5E3CAB7E3CAB7E3CAB8E3CBB8\
E3CBB9E3CCBAE3CDBBE3CFBCE3CFBDE3CFBDE3CFBCE3CDBAE2CAB8E2C6B4E1C2AF
DFBDA9DDB8A4DCB49EDAB099D8AB94D6A78FD3A28AD19E86D09C84D09C84D1A088D4A78FD7B098\
DAB9A1DDC1AADFC7B1E1CBB7E3CFBCE3D1BFE4D2C1E4D2C1E4D1C1E4CFBFE4CCBC
E4CABAE3C8B8E3C7B8E3C8B8E2CAB9E2CCB9E2CEB9E3CEB8E3CDB6E3CBB3E2C7AFE0C2AADEBDA4\
DCB79EDAB199D8AC94D6A78FD5A48CD4A289D3A187D1A086D0A085CEA084CBA083
C89F83C59E82C29C81BF9A7FBC977EBA947CB8927AB89177B99075BA8F73BB8E71BB8D71BC8C71\
BC8B71BC8B71BD8C71BD8E71BE8F70BE8F70BE8E70BD8D70BC8B6FBC8A6EBB896E
BB896DBC8B6EBE8E70C19275C4977CC99D82CCA288D0A68DD2A88FD3A990D4A990D4A890D4A78E\
D3A58CD1A289CE9F86CB9B83C89880C5967EC4947DC3937CC3937CC3947CC3957C
C3977DC49A7EC69C7FC89F82C89F83C29B80B590789F7E6A8469596C574C5E4F48615754746D6D\
908B8CAEAAADC7C4C6D7D6D6DFE0DEE3E5E2E4E8E3E4E8E3E4E9E3E4E8E2E4E8E2
E3E7E2E3E7E1E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DF\
E3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DE
E2E4DEE1E4DEE0E3DDE0E1DBDFDED7DFDAD0E0D5C7E1D0BDE1CBB4E2C7ADE1C4A9E1C1A7E0C0A6\
DFBEA5DEBDA4DDBDA3DBBCA2D9BBA3D6BBA4D3BBA6D1BBA8D1BBA9D3BCA9D6BDA8
DABFA7DDC0A7DFC2A8E1C4AAE2C6ADE2C7B0E3C9B3E3CAB5E3CBB7E3CBB8E3CCB9E3CCBAE3CDBA\
E3CDBBE3CEBBE3CFBCE3D0BDE3D0BEE3D0BEE3CFBDE3CEBCE3CBB9E2C7B5E1C2B1
E0BDABDFB8A6DEB4A1DCB19CDAAD97D7A992D5A58DD3A088D19D85D19D84D2A087D4A68DD7AE95\
DAB69EDDBEA6DFC4AEE1C9B5E2CDBAE3D0BEE4D2C0E4D2C1E4D1C0E4CEBEE4CBBB
E4C7B8E3C4B6E3C3B4E2C4B4E1C6B4E1C9B5E1CBB6E2CDB6E2CDB4E2CBB2E1C8AEDFC2A9DDBCA3\
DBB69DD8B098D7AB93D5A78FD4A38BD3A088D19E85CF9C82CD9B80CB9B7FC99B80
C69C80C49B80C19A80BF987EBC957CBA927AB98F77B98E74B98D72BA8D71BB8D70BB8C70BB8B71\
BC8B71BC8B72BD8C71BE8E71BE8F70BE8F6FBE8F6FBD8E6EBC8C6EBB8A6DBB896C
BB896BBC8A6CBE8D6FC19174C6977BCA9D82CEA289D1A58DD3A88FD4A890D4A88FD4A78ED3A58C\
D1A38ACFA088CD9D85CA9A82C79780C5957DC4937CC3937BC3937BC3947CC3957C
C3977DC4997EC69C80C89F83C8A084C39B81B590789E7D69816757675349574A445A504E6D6665\
8A8484A9A4A4C2BFBED4D2D0DDDEDBE2E4E0E4E7E2E4E9E3E4E9E3E4E8E3E4E8E2
E4E7E2E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DF\
E3E5DFE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E5DEE2E5DEE2E5DE
E2E4DEE1E3DDE0E1DBDFDED8DEDBD3DED7CCDFD3C4E0CEBBE1CAB2E1C6ABE1C2A7E0BFA4DEBDA2\
DDBA9FDBB89DD9B69AD7B599D5B49AD2B59ECFB6A3CDB8A7CEB9AAD1BBAAD5BCA9
DABEA8DEC0A8E0C1A9E2C3ABE2C5AEE3C7B2E3C9B5E3CBB7E3CCB9E3CDBAE3CEBBE3CEBBE3CEBB\
E3CFBCE3CFBCE3D0BDE3D0BDE3D0BEE3D1BEE3D0BEE3CFBDE3CCBAE3C8B7E2C3B2
E2BDADE1B8A8DFB5A3DEB29EDCAF9AD9AC95D7A88FD5A38AD3A087D39E85D3A087D5A58CD7AB93\
DAB39BDCBAA3DFC0ABE1C6B2E2CBB8E3CEBCE4D1BFE4D2C0E4D1C0E4CEBEE4C9BA
E4C5B7E3C1B4E2C0B2E1C1B1E1C3B1E0C6B2E0C9B3E1CBB3E2CCB3E2CBB1E1C7AEDFC2A9DCBCA3\
DAB59DD8B098D6AB93D5A790D4A48CD2A088D09C84CD9980CB967DC9967CC7977D
C5987EC49980C29980BF977EBD937BBB8F77BA8D74BA8B72BA8B70BA8C70BB8C70BB8C70BB8C71\
BC8C72BC8C72BD8E72BE8F71BF9070C0916FBF906FBE8F6EBD8D6EBC8B6DBB8A6C
BB896BBC8A6CBF8C6FC39174C7977BCC9D82D0A289D2A58DD4A78ED4A78FD4A68ED3A58CD1A38A\
D0A188CE9E86CB9C84C99981C7977FC5957DC4937CC3937BC3937BC3937BC3957C
C3977DC4997FC69C81C89F84C9A085C39C82B591799D7D697E6557635047514540524A47645E5C\
807B79A09B98BBB6B3CECBC7DAD9D4E0E2DDE3E6E1E5E9E3E5E9E4E5E9E3E4E8E2
E4E7E2E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DF\
E3E5DEE3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E5DEE2E5DEE2E5DFE2E5DE
E2E4DDE1E2DBE0DFD8DFDCD4DED8CFDED4C8DFD0C0E0CCB9E1C8B1E1C5ABE0C1A6DEBDA2DDBA9E\
DAB69AD8B296D6B092D4AE91D1AE93CFB098CCB29FCBB5A5CDB8A9D0BAABD5BBAA
DABDA8DFBEA8E1C0A9E3C2ACE3C5AFE3C7B3E3C9B6E3CBB8E3CDBAE3CEBBE3CFBCE3CFBCE3CFBC\
E3CFBCE3D0BDE3D0BDE3D0BDE3D1BEE3D1BEE3D1BEE3D0BDE3CDBBE3C9B8E3C4B3
E2BEAFE2B9AAE1B6A5DFB4A1DDB29CDBAF97D9AB92D7A78DD5A389D4A187D4A188D5A48BD7A990\
D9AF97DCB69FDEBDA7E0C3AFE2C8B6E3CDBBE4D0BEE4D1C0E4D0BFE4CDBDE4C9BA
E4C4B6E3C0B3E2BEB0E1BFAFE0C1AFE0C5B0E0C8B1E1CAB2E1CBB2E2CAB1E1C6AEDFC1A9DCBBA3\
D9B59DD7B098D6AC94D5A991D4A58DD2A189CF9C84CC977FCA947CC7937AC6947B
C5967EC49880C29880C1957DBF927ABD8D76BB8A72BB8970BA896FBA8A6FBB8B6FBB8C71BB8C72\
BC8D73BC8D74BE8F73BF9073C09172C19271C19170C09070BF8F6FBE8D6FBD8C6E
BD8B6DBF8B6EC18E71C59276C9987DCD9E83D1A289D3A58CD4A68DD4A58DD3A48CD2A38AD0A188\
CE9F86CC9D85CA9B83C89981C7977FC5957DC4947CC4937CC3937BC3947BC3957C
C3967DC4997FC69C81C99F84C9A085C49C82B691799C7D697D6456604E454C413C4B43405A5451\
756F6B948E89B0AAA4C5C1BBD4D3CCDDDED9E3E5E0E5E9E4E6EAE4E5E9E4E4E8E2
E4E7E2E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DF\
E3E5DEE3E5DEE3E5DEE3E4DEE3E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DE
E2E3DDE1E1DAE0DDD5DFD9CFDED5C9DED1C3DFCEBCE0CAB6E1C7B0E0C3ABDFBFA6DDBBA0DBB79B\
D8B296D6AE91D3AA8DD1A98BCFA98DCDAC93CCB09BCCB4A3CEB7A8D2B9AAD6BAA9
DBBBA8E0BCA8E2BEA9E3C1ACE3C4B0E3C7B3E3C9B6E3CCB9E3CDBAE3CFBCE3CFBCE3D0BDE3D0BD\
E3D0BDE3D0BDE3D0BDE3D0BDE3D1BEE3D1BEE3D1BEE3D0BDE3CEBCE3CAB9E3C5B4
E3C0B0E2BCABE2B9A7E1B7A3DFB49EDDB29ADBAE95D8AA90D6A68BD5A388D5A288D5A489D7A78E\
D9AC94DBB29BDEB9A4E0C0ACE2C7B4E3CCBAE4CFBEE4D1C0E4D0BFE4CDBDE4C9BA
E4C5B7E3C1B3E2BFB1E1C0B0E0C2AFE0C4B0E0C7B1E1C9B2E2CAB3E2C9B2E1C6AFDFC1AADCBBA5\
DAB59FD8B09AD6AD96D5AA93D4A78FD2A38BCF9D85CC9880C9957DC7937BC6947C
C6967EC59880C49780C2957DC09079BE8C74BC8971BB876EBB876EBB886EBB8A6FBB8B71BB8C72\
BC8D74BC8E74BE9075BF9174C19274C29373C29273C29272C19072C08F71C08E71
C18E71C28F72C59175C8967ACB9B80CF9F85D2A38AD3A58CD3A58CD3A48BD2A28AD0A188CF9F86\
CD9E85CC9C84CA9B82C99981C7987FC6967EC5957DC4947CC4937CC3947BC3957C
C3967DC4997EC69C81C99F83C9A084C49C81B590799C7C697D63555E4C43493D38443C39504946\
67605C847D77A19A93B9B4ADCCCAC3DADAD4E3E4DEE6E9E4E7EAE5E6EAE4E5E8E3
E4E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DF\
E3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DE
E2E3DCE1E0D8E0DCD2E0D7CBDFD2C3DFCEBDE0CBB8E1C9B3E1C6AFE0C2AADEBEA5DCB99FD9B499\
D6AE92D3AA8DD1A689CFA588CDA68BCDAA91CDAF99CEB4A0D1B7A6D4B9A8D9B9A8
DDB9A8E0BAA8E2BCA9E3BFACE3C3B0E3C6B4E3CAB7E3CCB9E3CEBBE3CFBCE3D0BCE3D0BDE3D0BD\
E3D0BDE3D0BDE3D0BDE3D0BDE3D1BEE3D1BEE3D1BEE3D0BEE3CEBCE3CBB9E3C8B5
E3C4B1E3C0ADE2BDA9E2BAA5E0B7A0DEB59CDCB197DAAD92D7A98DD5A68AD5A488D5A388D6A58B\
D7A890DAAE97DDB6A0DFBEAAE1C5B2E3CBB9E4CFBDE4D1BFE4D0BFE4CEBEE4CBBB
E4C7B8E3C4B5E3C2B3E2C2B2E1C4B2E1C6B2E1C8B3E2CAB4E2CAB5E2C9B4E1C6B1DFC1ACDDBCA7\
DAB6A1D8B19CD7AE98D5AB95D4A891D2A58DCFA088CC9B83CA977FC8957EC7967E
C79780C69881C59780C3947DC19078BE8B74BC8870BB866EBB866DBB876EBB896FBB8A71BB8B72\
BC8D74BD8E75BE9076C09176C19276C29376C39376C39275C39275C49175C49176
C59276C79478C9967BCB9A80CE9E84D1A288D2A58BD3A58CD2A58CD1A38AD0A188CF9F86CD9E85\
CC9D84CB9C83CA9B82C99A81C89980C7977FC6967EC5957DC4947CC3947BC3957B
C3967CC4997DC69C7FC89E82C89F83C39B80B590789D7D697E6455604D42493C35413732483F3B\
5A524C746B64908880ABA49DC2BEB7D4D2CCE0E0DAE6E7E2E7EAE4E6E9E3E4E8E2
E3E7E1E3E7E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DE\
E3E5DEE3E5DEE3E4DEE3E4DEE3E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE3E3DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E5DEE2E5DFE2E5DFE2E5DE
E2E3DCE1E0D6E1DBCFE1D5C6E1D0BEE1CCB8E1C9B4E1C7B1E1C5AEDFC1A9DDBCA3DAB69DD7B095\
D4AB8FD1A68ACFA487CEA387CDA58ACEAA90CFAF97D2B49ED4B8A3D8B9A6DBB8A7
DEB8A7E1B8A8E2BAAAE3BEADE3C2B0E3C6B4E3C9B7E3CCB9E3CEBBE3CFBCE3D0BDE3D0BDE3D0BD\
E3D0BDE3D0BDE3D0BDE3D0BEE3D0BEE3D1BEE3D1BEE3D0BDE3CFBCE3CDBAE3CAB6
E3C7B2E3C4AEE3C1AAE2BEA7E1BBA3E0B79EDDB499DBB094D8AC8FD6A88BD4A588D4A387D4A388\
D6A68CD8AB94DBB39DDEBCA7E1C4B1E2CAB8E3CEBCE4D0BFE4D0BFE4CFBEE4CCBC
E4C9B9E3C7B7E3C6B6E3C6B5E2C7B5E2C8B5E2C9B6E2CBB7E3CBB7E2C9B6E1C6B3E0C2AEDEBCA9\
DBB7A4D9B39FD8AF9AD6AD96D4AA92D2A68ECFA28ACD9E86CB9B83C99981C99981
C89982C89982C69880C4947DC19079BF8C74BD8870BC866EBB866DBB876EBB886FBB8970BB8B72\
BC8C73BC8E75BE8F76BF9177C19278C39378C49379C59379C69379C7947AC8957B
CA977DCC997FCD9C82CFA086D1A389D2A58CD3A68DD2A68DD1A58CD0A28ACFA087CD9E86CC9D84\
CC9C84CB9C83CA9B83CA9B82C99A81C89980C7977FC6967EC5957DC4947CC3957B
C3967CC4997DC59B7EC89E81C89F82C39B80B690789F7E698267566550444E3E3543362F443932\
51463F665B5380756D9B928BB5AEA7CAC6C0D9D8D2E1E1DCE4E6E0E4E7E1E3E7E1
E3E7E1E3E7E1E3E6E1E3E6E0E3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DE\
E3E5DEE3E5DEE3E4DEE3E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E5DEE2E5DFE2E5E0E2E5DF
E2E3DCE2DFD5E2DACDE2D4C3E2CFBAE2CBB4E2C8B0E1C6AEE0C4ACDEBFA8DBB9A1D8B299D4AC91\
D1A68ACFA387CDA286CDA387CEA68BD0AB91D2B098D5B59DD9B8A2DBB8A4DEB8A6
E0B7A7E1B8A8E2BAAAE3BEADE3C2B0E3C6B4E3C9B6E3CCB9E3CEBBE3CFBCE3D0BDE3D0BEE3D1BE\
E3D1BEE3D1BEE3D1BEE3D0BEE3D0BEE3D0BEE3D0BEE3D0BDE3CFBCE3CEBAE3CCB7
E3C9B4E3C7B0E3C4ACE3C1A9E2BEA5E1BAA1DEB79CDBB296D8AE91D6AA8CD4A688D3A386D3A287\
D5A48AD7A991DAB19ADDBAA5E0C2AEE2C9B6E3CDBBE3CFBDE3D0BEE4CFBDE4CDBC
E4CCBAE3CAB9E3C9B8E3C9B7E3CAB7E3CAB8E3CBB9E3CCB9E3CCB9E3CAB7E2C7B5E0C3B0DEBEAB\
DCB9A6DAB4A0D8B09CD6AD97D4AA93D2A78FCFA38BCDA088CC9D85CB9C84CA9B83
C99B83C89A83C79881C5957DC29179BF8D75BE8971BD886FBC876EBC876EBC886FBC8970BC8A71\
BC8B73BC8D74BE8F76BF9078C19279C3937AC5947BC7947CC9957DCA977FCC9981
CE9B83D09F86D2A289D3A58BD3A78ED4A88FD3A88FD2A78ED0A58CCFA38ACDA088CC9F86CB9E85\
CB9D84CB9D84CA9C83CA9C83C99B82C99A81C79880C6977FC5967DC4957CC3957C
C3977CC4997CC59B7EC79E80C79F82C39B80B79279A4826B8A6C5A6F57475944384B392F48372E\
4E3E355D4D4572645C8B7F77A59B94BBB5AECCC9C3D7D6D0DDDED8E0E2DDE2E5DF
E3E6E0E3E7E1E3E7E1E3E7E1E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DE\
E3E5DEE3E4DEE3E4DEE3E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E5DEE2E5DFE2E6E0E2E5DF
E2E3DCE2DFD5E2DACBE2D4C1E2CEB8E2CAB1E2C8AEE1C6ACDFC2AADDBDA5D9B69CD4AD93D0A68A\
CDA185CC9F83CCA184CEA489D0A98ED3AD94D6B299D9B59EDCB7A1DEB8A4E0B8A5
E1B8A7E2B9A8E2BCABE3BFADE3C3B1E3C6B4E3C9B6E3CCB8E3CEBAE3CFBCE3D0BEE3D1BFE3D2C0\
E3D2C0E3D2C0E3D1BFE3D1BFE3D1BEE3D0BEE3D0BEE3D0BDE3CFBCE3CEBAE3CDB8
E3CBB5E3C9B2E3C7AFE3C4ABE3C1A8E1BEA3DFB99EDCB599D8B093D5AB8ED3A789D3A486D3A286\
D4A489D6A98FD9B098DCB9A2DFC1ACE1C7B3E2CCB9E3CEBBE3CFBCE3CEBCE4CEBB
E4CDBAE4CCB9E4CCB8E4CCB9E4CCB9E4CDBAE4CDBBE4CDBBE3CDBBE3CBB9E2C8B6E1C4B2DFBFAC\
DDBAA7DAB5A1D8B19CD5AD97D3AA92D1A68ECFA38BCDA188CC9F86CB9E85CA9D85
C99C84C89B83C79981C5967EC2927BC08E77BF8B73BE8A71BE896FBD896FBD896EBD8A6FBC8A70\
BC8B71BC8C73BD8D75BF8F78C1917AC3937CC6947EC8967FCB9881CD9A83D09D86
D2A089D4A38CD5A68ED5A990D5AA91D5AA91D3AA91D2A88FD0A68DCEA48BCCA289CCA087CB9F86\
CB9E86CB9E85CA9D84CA9D84C99C83C89B82C79981C6987FC4977EC4967DC3967C
C3977CC3997DC59C7EC69E81C79F82C39C81BA957BAA876F95755F7E614E6A503E5B4333543C2F\
543D325C463C6A564D7C6B6391847CA69C95B8B2ACC7C4BED3D2CCDBDCD7E0E3DD
E3E6E1E4E8E2E4E8E2E4E7E1E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DE\
E3E5DEE3E4DEE3E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E5DEE2E5DFE2E5E0E2E5DF
E2E3DBE2DFD4E2D9CAE2D3C0E3CDB6E2C9AFE2C6ACE0C4A9DEC0A6DABAA0D5B196D0A78CCC9F83\
CA9B7ECA9C7FCCA084CFA68BD2AC92D6B098D9B39CDCB5A0DEB6A2E0B7A4E1B8A5
E2BAA7E2BCA9E2BEABE2C1AEE3C4B1E3C7B4E2C9B6E2CBB8E2CDBAE3CFBCE3D1BFE3D2C0E3D3C2\
E3D3C2E3D3C2E3D2C1E3D1BFE3D1BEE3D0BEE3D0BDE3D0BDE3CFBCE3CEBBE3CDB8
E3CCB6E3CAB3E3C8B1E3C6AEE3C4AAE1C0A6DFBCA1DCB79BD8B295D5AC8FD3A88BD2A588D2A487\
D4A689D6AA8FD8B197DBB9A0DDC0A9DFC6B1E1CAB6E2CCB9E3CDBAE3CDBAE3CDBA
E4CDB9E4CDB8E4CDB8E4CDB9E4CEBAE4CEBCE4CEBDE4CEBDE4CDBCE3CBBAE2C8B6E1C5B2DFC0AD\
DDBBA7DAB6A1D7B19BD4AC95D2A890D0A48CCEA289CDA087CC9F86CB9E86CA9D85
C99D85C89C84C69A82C4977FC3947CC19079C08E75BF8D73BF8C70BF8C6FBE8B6EBE8B6EBD8A6F\
BC8A70BC8A72BD8C74BF8E77C1907AC3937DC69580CA9882CD9A85D09D88D2A18B
D5A48ED6A890D7AA92D7AC93D7AC93D5AC93D4AB92D2A990CFA88ECEA68DCCA48BCBA389CBA188\
CBA087CA9F86CA9E85C99D84C89C83C79B82C69A81C59980C4987FC3977EC3977D
C3987DC3997EC49C7FC69E82C69F83C49E83BE997EB28E74A27F66906F577E5E4870503C664735\
614333614538674D42715B527F6E6690837CA39A94B5B1ABC6C5BFD5D6D0DEE1DB
E3E7E1E5E9E3E5E8E2E4E7E1E3E6E0E3E6E0E3E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DE\
E3E5DEE3E4DEE3E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E5DFE2E5DFE2E4DD
E2E2DAE2DED2E2D8C8E2D1BDE2CBB4E1C6ACE0C3A8DFC0A5DCBBA0D7B499D2AA8FCCA084C8997B\
C69678C7997CCBA083CFA98DD4AF96D8B39CDBB59FDEB5A2E0B6A3E1B8A4E2BAA6
E2BCA8E2BFAAE2C1ACE2C3AFE2C5B1E2C7B4E2C9B6E2CBB8E2CDBAE2CFBDE3D1BFE3D2C1E3D3C3\
E3D4C4E3D4C3E3D3C2E3D2C0E3D1BEE3D0BEE3D0BDE3D0BDE3CFBCE3CEBBE3CDB9
E3CCB7E3CAB5E3C9B2E3C8B0E3C6ADE1C3A9DFBEA3DCB99ED8B397D6AE92D4AA8DD3A78AD3A789\
D4A98BD5AD90D8B397DAB99FDCC0A7DEC5AEE0C8B3E2CAB6E2CBB8E3CCB8E3CCB7
E3CCB6E3CCB6E3CCB6E3CDB8E4CEBAE4CEBCE4CFBDE4CEBDE4CDBCE3CBB9E2C8B6E1C4B1DFC0AC\
DDBBA6DAB69FD6B099D3AA93D0A68DCEA28ACD9F87CC9E86CB9D85CA9D85C99D85
C89C84C69B83C59A82C49880C3957DC2927AC19077C08F74C08E71C08E6FBF8D6EBE8B6DBD8A6D\
BC896EBC8970BD8B73BF8D76C1907AC4937DC79781CB9A85CE9D89D1A08CD4A48F
D6A892D8AB94D9AD95D9AE95D7AE95D6AD94D4AB92D2AA91CFA98FCDA78ECCA68DCBA58BCBA38A\
CAA289CAA087C99F86C89E85C79D83C69B82C59A81C49980C49980C3987FC3987E
C3997EC39A7FC49B80C69E83C6A085C5A085C19C82BA957AAF8A6EA27D60946E528760467B553E\
724D396D493A6B4B3E6D5248745F56807169928881A7A29BBDBBB5CFD0CBDDDFDA
E4E7E1E6EAE4E6E9E3E4E7E1E3E6E0E3E6E0E3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DE\
E3E4DEE3E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DEE2E4DDE2E2DB
E2DFD6E2DBCFE1D4C4E1CDB9E0C7AFDFC1A7DEBCA1DCB89DD8B398D4AB90CEA286C8997CC49375\
C39274C5987AC9A184CFAB8FD4B299D9B69FDCB7A2DFB7A4E0B7A4E2B9A5E2BCA7
E2BFA9E2C2ABE2C4ADE2C5AFE2C6B1E2C8B4E2C9B6E2CBB8E2CDBAE2CFBDE2D1BFE3D3C2E3D4C4\
E3D4C5E3D4C4E3D3C2E3D2C0E3D1BEE3D0BDE3D0BDE3D0BDE3CFBCE3CEBBE3CDBA
E3CBB8E3CAB6E3C9B4E3C8B1E2C7AEE1C4AADEC0A5DCBA9FD9B59AD6AF94D4AC90D3AA8ED4AB8D\
D5AD8FD6B093D8B599DABBA0DCC0A6DEC4ACE0C7B1E1C9B4E2CAB5E3CAB5E3C9B4
E3C9B3E3C9B3E3CAB3E3CBB5E3CDB8E3CEBAE4CEBCE4CDBCE4CBBAE3C9B8E2C6B4E1C3AFDEBFA9\
DCBAA3D9B49CD5AE96D2A88FCFA38ACD9F87CB9D84CB9C83CA9B83C99B83C89B83
C69B83C59A82C49981C3977FC2967DC2947AC19277C19174C09071BF8F6EBE8D6DBD8B6CBC896C\
BC886DBC886FBD8A72BF8D76C1917AC5957EC89883CC9C87CFA08BD3A38FD5A792
D8AA95D9AD96DAAF97D9AF97D8AF96D6AD94D4AC92D2AA91CFA990CDA88FCCA78ECBA68DCBA48B\
CAA389CAA188C99F86C89E85C79D83C59B82C49B81C49A80C39A80C3997FC3997E
C3997EC4997FC59B81C69D83C7A086C7A187C5A085C09B7FBA9375B1896AA77C5D9C6F52906349\
8559437C5341755142715347735B527B6A628A8079A09B95B8B6B0CDCEC8DCDFD9
E4E7E1E6EAE4E6E9E3E4E8E1E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DE\
E3E4DEE3E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E4DDE2E3DCE2E2DAE2DFD7
E2DCD1E1D6C8E1CFBDE0C7B2DEBFA7DDB89EDAB297D8AC92D4A68CD09F85CA977CC69175C28E71\
C19073C3977AC7A286CDAC92D2B49CD7B8A2DBB9A5DEB9A6E1B9A6E2BBA7E3BEA8
E3C1A9E3C4ABE2C6ADE2C7AFE2C7B1E2C8B4E2C9B6E2CBB8E2CDBAE2CFBCE2D1BFE2D2C1E3D3C3\
E3D4C4E3D3C3E3D3C2E3D1C0E3D1BEE3D0BDE3D0BDE3D0BDE3CFBCE3CEBBE3CDBA
E3CBB8E3CAB6E2C9B4E2C8B2E1C7AFE0C4ABDEC0A6DBBBA1D9B69CD7B297D5AF94D5AE92D5AF92\
D6B194D7B597D9B99CDBBDA1DDC1A7DEC5ACE0C7AFE1C8B2E2C9B3E2C8B2E2C7B1
E2C6B0E2C6AFE2C7B0E2C9B2E2CBB5E3CCB8E3CCB9E4CBB9E4C9B8E3C6B5E2C3B1E0BFACDEBCA6\
DBB79FD7B298D4AC92D1A68CCEA087CC9C84CA9A82C99981C89981C79981C69981
C49981C39880C2977EC2967DC2957BC29479C19376C09173BF8F70BD8D6DBC8B6BBB896ABA876A\
BB866CBC876EBD8A72C08E76C2927BC69780C99B85CD9F89D0A28DD3A691D6A994
D8AC96DAAF98DAB098DAB097D8AF96D6AD94D4AC92D2AA91CFA990CDA88FCCA78ECBA68DCBA48B\
CAA289CAA187C99F86C89E84C79C83C69B82C59B81C49A80C39A7FC39A7EC3997E
C3997EC4997EC59A80C79D83C89F86C8A287C7A287C59F82C1997BBC9171B58767AB7B5DA17054\
96674E8D604C855E4D8060527F675D85756C928982A5A19BBBBAB4CED0CADCDFD9
E4E7E1E6E9E3E6E9E3E4E7E1E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DE\
E3E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E1E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DEE2E4DEE2E3DDE2E2DAE2E0D7E2DCD1
E2D6CAE1D0C0DFC8B5DEBFA9DCB69DD9AD93D6A58BD39E84CF977ECB9178C78C73C48A6FC18B6F\
C18F74C2987DC5A388CAAD94CFB59DD5B9A3D9BBA6DDBCA7E0BDA7E2BEA8E3C1A9
E3C3AAE3C5ABE2C6ADE2C7AFE2C7B2E2C8B4E2C9B6E2CBB8E2CDBAE2CFBCE2D0BEE2D2C0E2D2C2\
E3D3C2E3D2C2E3D2C0E3D1BFE3D0BEE3D0BDE3D0BDE3D0BDE3CFBCE3CEBBE3CDBA
E3CBB8E2CAB6E2C9B4E1C7B1E0C6AEDFC4AADDC0A6DBBCA2D9B89ED8B59AD7B398D6B397D7B497\
D7B699D9B99CDABCA0DCC0A4DEC3A8DFC6ACE1C8AFE2C8B1E2C8B1E2C6B0E1C4AE
E1C3ADE0C2ACE0C3ADE1C5AFE2C8B2E3CAB5E3CAB6E4C8B6E4C6B5E3C2B2E1BFADDFBBA8DCB8A1\
D9B49BD6AF94D3A98ED0A388CD9E84CB9A81C99880C8977FC7977FC6977FC4967F
C2967EC1957DC1957BC1947AC19478C19376C09273BF9070BC8D6EBA8B6BB8886AB88669B88569\
B9856BBB876EBE8A72C18F77C4947DC79A82CA9E87CEA28BD1A58FD4A892D6AB95
D9AE97DAB098DAB198DAB098D8AF96D6AD94D4AC92D1AA91CFA98FCDA88ECCA68DCBA58BCBA38A\
CAA188CA9F86CA9E85C99D83C89C82C79B81C59B80C49A7FC49A7EC39A7DC3997D
C4987CC5987DC6997FC89B82C99F85C9A187C9A288C8A185C59D7FC29677BD8D6EB68466AE7B5F\
A5745A9E705A98705D947466957E729A8B82A49D96B3B1AAC3C4BED2D5CFDDE0DA
E3E6E0E5E8E2E5E8E2E4E7E1E3E6E0E3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DE\
E2E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E5DEE2E5DEE2E4DEE2E3DCE2E1D9E2DDD3E2D7CC
E1D1C2E0C9B7DEBFABDCB59FD9AB93D6A188D2977FCF8F77CB8871C8846DC5826BC2846BC1896F\
C19076C2997FC4A48BC8AD95CCB59ED2BAA4D8BDA7DCBFA8E0C0A9E2C2A9E3C3AA
E3C5ABE3C6ACE2C7AEE2C7B0E2C7B2E2C8B4E2C9B6E2CBB8E2CDBAE2CEBCE2D0BDE2D1BFE2D1BF\
E2D1C0E3D1C0E3D1BFE3D0BEE3D0BDE3D0BDE3D0BDE3CFBCE3CFBCE3CEBBE3CCBA
E3CBB8E2C9B6E1C8B3E0C7B0DFC5ADDEC3A9DCC0A6DBBDA2DABA9FD9B79DD9B69CD8B79CD8B89D\
D9BA9FDABDA1DCC0A4DEC3A7DFC5ABE1C7ADE2C9AFE2C9B0E2C8B0E2C6AFE1C3AD
E0C0ABDFBFAADFC0AAE0C2ACE1C5AFE2C7B2E3C8B3E4C6B3E4C2B1E3BEAEE1BAA9DEB7A4DBB49D\
D8B096D5AC90D2A68ACFA085CC9B82CA987FC8967EC7957DC5957DC4947DC2937C
C0937BBF9279BF9278BF9276C09274C09272BF9070BD8E6EBA8B6CB7886AB58569B58368B68369\
B9856CBC886FBF8C74C2927AC5977FC99D85CCA189CFA48DD1A790D4AA92D6AC95
D8AE97DAB098DAB198DAB098D8AF96D6AD94D4AB92D1AA90CFA88FCDA78DCCA58CCBA38ACBA188\
CAA086CA9E85CA9D84C99C83C99B82C89B81C79A80C59A7FC49A7DC4997CC4987B
C5977BC6967CC7977EC89A81C99D84CAA187C9A288C8A186C79E81C4987BC09073BC896CB78267\
B27F65AE7E68AB836FAB8C7CAD988CB3A79DBBB6AFC5C4BECFD1CBD8DBD5DFE2DC
E2E6E0E4E7E1E4E7E1E4E6E0E3E6E0E3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E5DEE3E4DE\
E2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E5DEE2E5DFE2E4DEE2E3DCE2DFD7E2DAD0E2D3C6
E1CBBBE0C1AFDDB7A2DAAC96D7A18AD3967FCF8C75CB826DC77C67C57964C37B65C18069C18870\
C19178C29B82C4A58DC7AE97CBB69FD1BBA5D6BFA8DCC2AAE0C3ABE2C5ABE3C6AC
E3C6ACE3C7ADE2C7AFE2C7B0E2C7B2E2C8B4E2C9B6E2CBB8E2CDBAE2CEBBE2CFBCE2D0BDE2D0BE\
E2D0BEE3D0BEE3D0BEE3D0BDE3D0BDE3D0BDE3CFBDE3CFBCE3CEBBE3CDBAE3CCB9
E3CBB7E2C9B5E1C8B2E0C6AFDEC4ACDDC2A8DCBFA5DBBDA3DBBBA0DBBA9FDAB99FDABA9FDABCA1\
DBBEA3DCC0A5DDC3A8DFC5ABE0C7ADE2C9AFE2CAB1E3CAB1E2C9B1E2C6AFE1C2AD
DFBFABDFBEA9DFBEAAE0C0ABE1C4AEE2C6B0E3C6B1E4C4B0E4C0AEE3BBABE1B7A6DEB4A0DBB19A\
D7AD93D4A98DD1A488CE9E83CB9A80C9967EC7947CC5937CC3927BC1927AC09179
BE8F78BD8F76BD8E74BD8F73BE8F71BE8F6FBD8E6DBB8C6CB7886AB48569B38369B38369B6836B\
B9866EBD8A72C18F77C4957DC79B82CAA088CDA48BD0A78FD2A991D4AB93D6AD95
D8AF97DAB098DAB198DAB097D8AF96D6AD94D4AB92D1A990CFA78ECDA58CCCA48ACBA288CAA087\
CA9E85CA9D84CA9B83CA9A82CA9A81C99A81C89980C6997EC5997DC5987BC5977A
C6957AC7957BC8967DC99980CA9C84CAA087C9A288C8A186C69D82C4977CC29175BF8B70BC876C\
BA876DBA8B73BC947FBFA190C4B1A4CAC1B7D0CEC6D5D7D1DADED8DEE2DCE0E4DE
E2E5DFE3E6E0E3E6E0E3E6E0E3E6DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE2E4DE\
E2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E5DFE2E5DFE2E5DEE2E2DCE2DED6E2D7CDE2CFC2
E1C5B5DFBAA8DDAF9BD9A48FD59983D18E78CD836EC97A66C57561C37360C17762C17E68C18870\
C2937AC39D85C5A78FC8B098CCB7A0D1BCA5D7C1A9DCC3ABE0C5ACE2C7ADE3C7AE
E3C8AFE3C8AFE2C8B0E2C7B1E2C8B2E2C8B4E2C9B6E2CBB8E2CCB9E2CEBBE2CFBCE2CFBCE2D0BC\
E2D0BDE3D0BDE3D0BDE3D0BDE3D0BDE3CFBCE3CFBCE3CEBBE3CDBAE3CCB9E3CBB8
E2CAB6E2C9B3E1C7B1DFC5AEDEC3ABDCC1A8DCBFA5DCBDA3DCBCA1DCBBA1DCBBA1DCBCA2DCBEA4\
DCC0A6DDC2A8DEC4ABE0C6ADE1C8AFE2CAB1E3CBB2E3CBB3E3CAB2E2C7B1E1C4AF
E0C1ACDFBFABDFBFABE0C1ACE1C3AEE2C5AFE3C5B0E4C2AFE3BEACE2BAA8E0B6A3DEB39DDAAF97\
D6AC91D3A78CD0A287CD9D82CA987FC8957CC6937BC3917AC19079BF8F78BD8E77
BC8D75BB8C73BA8B71BB8C70BC8C6EBC8C6DBB8B6CB9896AB6876AB48469B3836AB4846CB7866E\
BB8A72BF8E76C3937BC79980CA9E86CCA38ACFA78ED0A990D2AB92D4AD94D6AE96
D8B097D9B198DAB198D9B097D8AF96D6AD94D4AB91D1A98FCFA78DCDA58BCCA389CBA187CA9F85\
CA9D84CA9C83CA9A82CA9981CA9981CA9880C9987FC8987EC7977DC6967BC6957A
C69479C7947AC8957CC9987FC99C84C99F87C9A188C8A087C69C82C4967CC19075C08B70BF896E\
BF8B71C2927AC69F8ACCAF9ED3C1B4DAD2C8DEDED6E1E4DEE2E6E1E2E6E1E2E6E0
E2E6E0E3E5DFE3E6DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE2E4DEE2E4DE\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E5DFE2E5DFE2E5DEE2E2DBE2DDD5E2D5CBE2CBBF
E1C0B1DFB4A4DCA997D99E8AD4937ED08874CC7E6AC87663C4725FC2715FC17662C07E69C18972\
C2947CC49F86C7A990CBB199CFB8A0D4BEA6D9C2AADDC5ACE0C7AEE2C8B0E3C9B1
E3C9B1E3C9B2E2C9B2E2C8B3E2C8B3E2C8B4E2C9B6E2CBB7E2CCB9E2CEBAE2CFBBE2CFBCE2CFBC\
E2CFBCE2CFBCE3CFBCE3CFBCE3CFBCE3CFBCE3CEBBE3CDBAE3CCB9E3CBB7E3CAB6
E2CAB4E2C8B2E0C7AFDFC5ACDDC3AADCC1A7DCBFA5DDBDA3DDBCA1DDBCA1DDBCA1DDBDA3DDBFA5\
DDC1A7DDC3AADEC5ACE0C7AFE2C9B1E3CAB3E3CBB5E3CCB5E3CBB5E2C9B4E1C6B2
E0C3B0E0C1AEE0C1AEE1C2AFE1C4B0E2C5B0E3C5B0E4C2AEE3BEAAE2BAA6E0B6A1DDB29CDAAF96\
D6AB91D2A68BCFA186CC9C82C9987EC6947CC4917AC29078C08F77BD8D76BB8C74
BA8A72B88971B8896FB8896EB9896CB9896BB8896BB7886AB5866AB4856BB5856DB7876FBA8A72\
BE8F76C2937BC69880C99D84CCA289CEA68CD0A98FD1AB92D3AD94D4AE95D6B096
D8B098D9B198DAB198D9B097D8AE95D6AD93D4AB91D1A88FCFA68DCDA48BCCA289CBA087CA9E85\
CA9C83CA9B82CA9981CB9881CA9780CA9680C9967FC9967FC8957DC7957CC6937B
C6937AC7937AC7947CC8977FC89B84C99F88C8A189C79F87C59A81C3947AC18E73BF8A6EBF896E\
C18D72C5967DCBA48FD3B6A5DBCABCE2DAD1E6E6DEE7EBE5E6EBE6E5E9E4E3E7E1
E3E6E0E2E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E4DEE2E4DEE2E4DE\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DEE2E5DEE2E5DFE2E4DEE2E1DAE2DBD3E3D3C9E2C8BC
E1BCAEDFB0A1DDA594D99B88D5907CD08672CC7D6AC77663C4725FC27360C07863C0806AC18B73\
C3967DC6A187CAAB91CEB399D3BAA1D7BFA6DBC3ABDEC5AEE1C7B0E2C9B2E3CAB3
E3CAB4E2CAB4E2CAB4E2C9B4E2C8B4E2C8B5E2C9B6E2CBB7E2CCB9E2CDBAE2CEBBE2CFBBE2CFBB\
E2CFBBE2CFBBE2CFBBE2CFBBE2CEBBE2CEBBE2CDBAE3CCB8E3CBB7E3CAB5E3C9B4
E2C8B2E2C7B0E0C6ADDFC4ABDDC2A9DCC0A6DCBEA4DDBDA2DEBCA1DEBBA1DEBCA1DEBDA2DDBFA4\
DDC1A7DDC3AADFC5ADE0C7B0E2C9B3E3CAB5E3CCB6E3CCB7E3CCB7E2CBB6E2C9B5
E1C6B3E1C5B2E1C4B2E1C5B2E2C6B2E3C6B2E3C5B1E4C2AEE3BEAAE2BAA5E0B6A0DDB29BDAAE96\
D6AA91D2A68CCEA187CA9C82C7977EC5937BC29179C08F77BE8D75BC8C74BA8A72
B88971B7876FB6876EB6876CB6876CB6876BB6876BB6876BB6876CB6876EB78970BA8B73BD8F77\
C1947CC59980C99D84CCA188CEA58BD0A88ED1AA91D2AC93D3AE95D5AF96D6B097
D8B198D9B198DAB097D9AF96D8AE95D6AC93D4AA90D1A88ECFA68CCDA48ACCA288CBA086CA9E84\
CA9C83CA9A81CA9880CB9780CA9580CA9580CA947FC9947FC9937EC8937DC7927B
C6927AC6927AC6947CC79780C89C85C89F89C8A08AC79E87C59981C29379C08D71BF896CBF896C\
C28D72C6967ECDA590D5B8A7DDCBBEE4DCD2E7E7E0E8ECE6E7ECE7E5EAE4E4E7E2
E3E6E0E2E5DFE2E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE3E5DEE2E4DEE2E4DEE2E4DE\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DEE2E4DDE2E3DCE2E0D8E3DAD0E3D1C6E3C6BA
E2BAACE0AF9FDDA492DA9987D5907CD18673CC7E6AC87864C47561C27661C07B65C0836CC28D75\
C5987FC9A388CDAD92D2B59AD7BBA2DAC0A7DDC3ACE0C6AFE1C7B2E2C9B4E2CAB5
E2CBB6E2CBB7E2CBB7E2CAB6E2C9B5E2C9B5E2C9B6E2CBB7E2CCB8E2CDBAE2CEBAE2CEBBE2CEBB\
E2CEBAE2CEBAE2CEBAE2CDBAE2CDB9E2CCB8E2CBB7E2CAB6E3C9B5E3C8B3E3C7B2
E3C6B0E2C5AEE0C4ACDFC3A9DDC1A7DDBFA5DDBDA3DDBCA1DEBBA0DFBAA0DFBAA0DEBCA1DDBDA3\
DDC0A6DDC2A9DEC4ADE0C6B0E1C8B3E2CAB6E3CCB8E3CDB9E3CDB9E3CCB8E2CBB7
E2C9B6E2C8B5E2C7B5E2C7B5E3C7B5E3C7B4E3C5B2E4C2AEE3BFAAE2BAA5E0B6A0DDB29ADAAE95\
D6A991D2A58CCDA087CA9B82C6967EC3937BC19078BF8E76BD8C74BB8B73B98971
B7886FB6866EB5866DB4866CB4866CB4866CB5876DB5876DB6886EB88A70BA8C73BD9077C1947B\
C49980C89D84CBA188CEA48BD0A78DD1A990D3AB92D3AD94D4AF96D5B097D6B198
D8B198D9B198D9B097D9AE95D7AD94D5AB92D3A990D1A78ECFA58CCDA38ACCA188CB9F86CA9D84\
CA9B82CA9980CA9780CA957FCA947FCA937FCA927FCA927EC9927EC8917DC7917B
C6917AC5927AC5947CC69880C79C85C89F89C8A08BC79E88C59981C29278C08C70BF886BBF886B\
C18C71C5967DCBA48FD3B6A5DAC9BBE1D9CFE5E4DDE6E9E3E6EAE5E5E9E3E3E7E1
E3E6E0E3E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE3E5DEE2E4DEE2E4DEE2E4DEE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E4DCE2E3DBE2E1D8E2DDD4E3D7CCE3CFC2E3C5B7
E2BAABE0AF9EDEA593DA9B88D6917DD18974CC816CC87B66C47963C17A63C07E67C1866EC39076\
C69A80CBA58AD0AF93D5B79CDABDA3DDC1A8DFC4ADE1C6B0E2C7B2E2C9B5E2CBB7
E2CCB8E2CCB8E2CCB8E2CBB7E2CAB7E2CAB6E2CAB7E2CAB7E2CBB8E2CCB9E2CCB9E2CDB9E2CDB9\
E2CCB9E2CCB8E1CCB8E1CBB7E1CBB6E1CAB5E1CAB4E2C9B4E2C8B3E3C7B1E3C5B0
E3C4AEE2C2ACE1C1AADFC0A8DDBFA6DDBEA4DDBCA2DDBAA0DEB99FDFB89EDEB99EDEBA9FDDBCA2\
DDBEA5DDC1A8DEC3ACE0C6B0E1C8B3E2CAB6E3CBB8E3CCB8E3CDB9E3CDB8E3CCB8
E3CBB7E3CAB7E3C9B7E3C9B7E3C9B6E3C7B5E3C5B3E4C2AFE3BEAAE2BAA5E0B5A0DDB19ADAAC95\
D6A88FD1A38ACD9E86C99A81C5967DC2927AC08F78BE8D75BC8C74BA8A72B88970
B7876FB6866EB5866EB4866DB3866EB3876EB4886FB58970B78B71BA8D73BD9076C0947AC3987E\
C69D83C9A087CCA48ACFA68DD1A88FD3AA91D4AC93D5AE95D5B096D6B198D7B198
D8B198D8B097D8AF95D8AD94D7AB92D5AA90D3A88ED1A68DCFA58BCDA389CCA187CB9F85CA9D83\
CA9A81CA987FCA967ECA947ECA937DCA927DCA917EC9917DC9917DC8917CC6917B
C5917AC4937AC4957CC59980C69D85C7A08AC8A18BC79E88C59982C39379C18D71C0896CC0896C\
C18D71C4957CC9A28DCFB2A1D5C3B6DBD2C9DFDDD6E2E4DEE3E6E1E3E7E1E3E6E0
E3E6E0E3E5DFE3E5DFE3E5DFE3E5DFE3E5DFE3E5DEE3E5DEE2E5DEE2E4DEE2E4DEE2E4DEE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E3DCE2E2DAE2E1D8E2DED4E2DACEE3D4C6E3CDBDE3C4B3
E2BBA8E0B19DDEA793DA9D88D6947ED18B75CC846DC77F67C37C64C07D64C08268C1896FC49278\
C89D81CDA78BD3B095D8B99DDCBFA4DFC2A9E1C5ADE2C6B0E2C7B3E2C9B5E2CBB7
E2CCB8E2CDB9E2CDB9E2CCB9E2CBB8E2CBB7E2CAB7E2CAB7E2CAB7E2CBB8E2CBB8E2CBB8E2CBB8\
E2CBB7E1CAB6E0C9B4E0C9B3E0C8B2E0C8B1E1C8B1E1C7B0E2C6B0E3C5AFE3C2AD
E3C0ACE2BEAAE1BDA8DFBDA6DDBCA4DCBCA2DCBAA0DDB99EDDB79DDEB79CDDB79DDDB89EDCBAA0\
DCBDA3DDBFA7DEC2ABE0C5B0E1C7B3E2C9B6E3CBB7E3CCB7E3CCB7E3CCB7E3CCB7
E3CBB7E3CBB7E3CAB8E3CAB8E3C9B7E3C8B6E3C5B3E3C2B0E3BEABE2B9A6E0B4A0DDAF9ADAAA94\
D6A58ED1A189CD9C84C99880C5957DC2927ABF8F77BD8D75BB8B73BA8A72B98970
B8886FB6876FB5876FB4876FB38870B38971B48A72B68C73B88E74BB9176BF9478C2977CC59B80\
C89F84CAA288CDA58BCFA78DD1A98FD3AB91D5AC93D6AE95D6B097D7B197D7B198
D8B097D8AF96D7AD94D7AB92D6AA90D4A88ED3A68DD1A58BCFA48ACDA289CCA187CB9E85CA9C82\
CA9980CA967ECA947DCA937CCA927CCA917CCA907CC9907CC8907CC7907BC5917A
C49279C4937AC4967CC49A80C69E85C7A08AC8A18CC89F89C69A83C5947BC38F74C28B6FC18B6F\
C28E73C3957CC7A08BCBAE9DD0BCAFD5CAC1D9D5CEDCDCD7DFE1DCE1E4DEE2E5DF
E3E6DFE3E6DFE3E6DFE3E5DFE3E5DFE3E5DEE3E5DEE2E5DEE2E4DEE2E4DEE2E4DEE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E3DBE2E1D8E2DED4E2DACEE2D5C7E2D0BFE2C9B6E2C2AE
E1BAA4DFB19BDCA891D89F87D3957ECE8D74C9866DC48167C07F64BF8064BF8469C18C70C59579\
C99F83CFA98DD5B297DABA9FDEC0A5E1C4AAE2C5AEE2C7B1E2C7B3E2C9B5E2CAB7
E2CCB8E2CDB9E2CDBAE2CDB9E2CCB9E2CCB8E2CBB7E2CAB7E2CAB6E2C9B6E2C9B6E2C9B6E2C9B5\
E2C9B5E1C8B3E0C7B1DFC6AFDEC5AEDFC6ADDFC6ADE0C6ADE1C5ADE2C2ACE2BFAB
E2BDA9E1BAA8E0B9A6DFB9A4DDB9A2DCB9A1DCB99FDCB79DDCB69CDCB59BDCB69BDCB79DDCB99F\
DCBBA2DDBEA6DEC1ABE0C4AFE1C7B2E2C9B5E3CAB5E3CBB5E3CBB5E3CBB5E3CBB5
E3CBB6E3CAB7E3CAB8E3CAB8E3C9B7E3C8B6E3C5B4E3C2B1E3BDACE2B8A7E0B2A0DDAD99DAA892\
D6A38CD19F87CD9B82C9977FC5947CC29179BF8F77BD8D75BB8B73BA8A72B98971
B88870B78870B68870B58971B48A72B48B73B48D74B68F75B99176BD9478C0977AC39A7EC69D81\
C9A085CBA389CDA58BD0A78ED2A98FD3AB91D5AC93D6AE95D7AF96D8B097D8B097
D7AF96D7AE94D6AC93D5AA91D5A88FD4A78DD3A58CD1A48ACFA389CDA288CCA087CB9E84CA9B82\
CA987FCA967DCA947CCA927BCA917BCA917BC9907BC8907BC7907AC5907AC49179
C39278C39479C3977CC49B80C59E85C7A18AC8A18CC89F8AC89A84C7957DC59076C48D72C38D71\
C39075C3957DC59E88C7A997CAB5A7CEC1B7D3CBC4D7D4CEDBDBD6DFE0DBE1E4DE
E3E5DFE3E6E0E3E6E0E3E5DFE3E5DFE3E5DEE2E5DEE2E5DEE2E4DEE2E4DEE2E4DEE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC
E2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DD\
E2E4DEE2E4DEE2E4DDE2E2DAE1DFD6E1DBCFE1D5C7E1D0BEE1CAB6E0C4AEDFBDA6
DEB69EDBAF95D7A68CD39D83CE947AC98C71C3856ABF8165BD8063BC8164BE8669C18E71C5977B\
CBA185D1AB8FD7B499DCBCA0DFC1A7E1C4ABE2C6AEE2C7B1E2C7B3E2C8B5E2CAB6
E2CBB8E2CCB9E2CDB9E2CDB9E2CCB9E2CCB8E2CBB7E2CAB6E2C9B5E2C8B4E2C8B4E2C7B3E2C7B3\
E1C6B1E0C5AFDFC4ADDEC3ABDDC3A9DDC3A9DEC3A9DFC3AAE0C2AAE1BFA9E1BCA8
E1B9A7E0B6A5DFB6A3DEB6A2DDB7A1DCB79FDBB79EDBB79DDBB69CDCB59BDBB59BDBB79CDBB89E\
DCBBA1DDBEA5DEC1AAE0C4AEE1C7B2E2C8B3E3C9B4E3CAB4E3CAB3E3CAB3E3CAB4
E3CAB5E3CAB6E3CAB7E3CAB8E3C9B7E3C8B6E3C5B4E3C2B1E3BDADE1B7A7E0B2A1DDAC99D9A792\
D5A28BD19D85CD9981C9967EC5947BC29179BF8F77BD8D75BB8B73BA8A72BA8971
B98971B98971B88A72B78B73B68C74B58E76B69077B89278BB9479BE967AC1997CC49B7FC79E82\
C9A086CCA389CEA58CD0A78ED2A88FD4AA91D5AC93D7AE94D8AF96D8B096D8AF96
D7AE95D6AD94D5AB92D5AA90D4A88ED3A68CD2A58BD1A48ACFA389CDA288CCA087CB9E84CA9B82\
CA987FCA967DCA947BCA927ACA927AC9917AC8917AC79079C59079C49079C39178
C29278C29579C3987CC49B80C59F86C7A18AC8A18CC89E89C89A84C8947DC79077C68E73C58E73\
C49176C3967DC49D86C4A492C6AD9FC9B7ACCDC1B9D3CBC5D8D5CFDDDDD7E1E2DC
E3E5DFE3E6E0E3E6E0E3E6DFE3E5DFE3E5DEE2E5DEE2E4DEE2E4DEE2E4DEE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DB
E2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DD\
E2E4DEE2E4DEE2E4DDE1E1D9E1DDD3E0D7CAE0D0BFDFC9B5DEC2ABDDBCA3DBB69B
D9AF94D5A78DD09F84CA967BC48E73BF866BBB8165B87E61B77E61B98164BC876AC19073C6997D\
CCA388D3AD92D8B69ADDBDA2E0C2A7E2C5ACE3C6AFE3C7B1E2C7B3E2C8B4E2C9B6
E2CAB7E2CBB8E2CCB8E2CCB8E2CCB8E2CBB7E2CAB6E2C9B5E2C8B3E2C7B2E2C6B1E2C6B0E2C5AF\
E1C4AEE0C3ACDEC2AADDC1A8DCC1A6DCC0A6DDC0A6DEC0A6DFBEA6DFBCA6DFB9A5
DFB6A3DEB3A2DDB3A1DCB3A0DCB49FDBB59EDBB69EDBB69DDBB69CDBB69CDBB79DDBB89DDBB99F\
DCBCA2DDBEA5DEC1A9E0C4ADE1C6B0E2C8B2E3C9B3E3C9B2E3C9B2E3C9B2E3C9B3
E3C9B4E3C9B6E3C9B7E3CAB7E3C9B7E3C8B6E3C6B4E2C2B1E2BEADE1B8A8DFB3A1DCAD9AD9A792\
D5A18AD19D85CD9980C9967DC5937BC29179BF8F77BD8D75BB8B73BA8A72BA8A71
BA8971B98A71B98B72B88C74B88D75B78F77B89178BA9379BC967ABF987CC29A7EC59C80C89E84\
CAA087CDA28ACFA48CD1A68ED2A88FD4AA91D5AB92D6AD93D7AE94D8AF95D7AF95
D6AE94D5AD93D4AC92D4AA90D4A88ED3A68DD2A58BD1A48ACFA389CDA288CCA087CB9E85CA9C82\
CA9980CA977ECA957CC9947BC9937BC8927AC79279C59179C49178C39178C29177
C29278C29479C3977CC49B81C69E86C7A18AC8A08BC89D88C89882C7927AC68D74C68C71C58D72\
C49176C4967DC39B84C3A08CC4A695C6ADA0CAB6ACD0C2BAD6CEC7DCD9D2E0E1DA
E3E5DFE3E7E0E3E6E0E3E6DFE3E5DFE3E5DEE2E4DEE2E4DEE2E4DEE2E4DEE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DB
E2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DD\
E2E5DEE2E5DEE2E4DDE1E1D8E0DBD0DFD4C5DECBB8DCC2ABDAB99FD8B296D5AB8F
D1A488CC9C80C59478BD8B70B78469B27D62AF7A5EAE795CB07B5EB48062B9876AC09174C79B7F\
CEA68AD4B094D9B89CDEBEA3E0C3A8E2C5ACE3C6AFE3C7B1E2C7B2E2C7B4E2C8B5
E2C9B6E2CAB6E2CAB7E2CAB7E2CAB7E2CAB6E2C9B5E2C8B3E2C7B1E2C6B0E2C6AEE2C5ADE2C4AC\
E1C3ABE0C2A9DEC1A8DDC0A6DCBFA5DCBEA4DCBEA4DDBCA4DDBBA3DDB8A2DDB6A1
DCB3A0DCB29FDBB19EDBB19EDBB39EDBB49EDBB59EDBB69EDBB79EDBB89EDBB99EDBBA9FDBBBA1\
DBBDA3DDBFA5DEC2A9E0C4ACE1C6AFE2C8B1E3C8B2E3C9B2E3C9B2E3C9B3E3C9B3
E3C9B4E3C9B6E3C9B6E3C9B7E3C9B7E3C8B6E2C6B4E2C3B1E1BFADDFBAA8DDB5A1DBAE9AD8A892\
D5A28BD19D85CD9980C9967DC5937BC29178BF8F76BD8D75BB8B73BB8A72BA8A71
BA8A71BA8A72BA8B73BA8C74BA8E76BA9078BB9279BC947ABE967BC0987DC39A7FC69C82C99E85\
CCA088CEA28BD0A48DD1A68ED3A88FD4A990D5AB91D6AC92D6AD93D7AD94D6AE94
D5AE94D5AD94D4AC93D4AB91D3A98FD3A78DD2A68CD1A48ACFA389CDA288CCA187CB9F85CA9D83\
CA9B81CA9980C9977EC9967DC8957CC7947BC5937AC49279C39178C29178C29177
C29178C2937AC3967DC49A82C69E87C7A08BC8A08BC89B86C7947EC68D75C5886FC4886DC48B6F\
C49175C4967CC49A82C39C86C39F8CC5A393C9AD9FCEBAAFD5C8BFDBD6CEE0DFD9
E3E5DFE3E7E1E3E7E1E3E6E0E3E5DFE2E5DEE2E4DEE2E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DB
E2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DE\
E2E5DFE2E5DFE2E4DDE1E0D7E0D9CEDED0C0DBC5B0D8BAA0D5AF93D1A688CD9E80
C79679C08E72B7866BAF7E63A8775DA37258A27056A37156A7755AAE7C60B5856ABE9175C69D81\
CEA88DD5B296DBBA9EDEBFA4E1C3A9E2C5ACE3C6AFE3C7B1E2C7B2E2C7B3E2C7B4
E2C8B4E2C8B5E2C9B5E2C9B5E2C9B5E2C9B4E2C8B3E2C8B1E2C7B0E2C6AEE3C5ADE3C4ABE2C3AA\
E1C2A9E0C1A8DEC1A7DDC0A6DCBFA5DCBEA4DCBCA3DCBAA3DCB8A2DCB6A0DBB39F
DAB29DD9B19CD9B09CD9B09CDAB19CDAB29DDAB49EDAB69EDAB79FDAB99FDABAA0DABBA1DABDA2\
DBBEA3DCC0A6DEC2A8E0C4ABE1C6AEE2C8B0E3C8B1E3C8B2E3C8B3E3C8B3E3C8B4
E3C8B5E3C9B6E3C9B6E3C9B6E3C9B6E3C8B5E2C6B4E1C4B1E0C1ADDEBCA8DCB7A1DAB09AD7AA92\
D4A38BD09E86CD9981C9967DC5937BC29078BF8E76BD8C74BB8B73BA8A71BA8971
BA8971BA8A71BA8B72BB8C74BB8E76BC9078BD9279BE957BC0977CC2997EC49B80C79D83CA9E86\
CDA089CFA28CD1A48DD2A68ED3A78FD3A990D4AA90D5AA91D5AB91D5AC92D5AC93
D4AD93D4AD93D3AC93D3AB92D3AA90D3A88ED2A68CD0A58BCFA389CDA288CBA187CA9F86CA9E84\
CA9C83C99B82C89A80C8987FC6977EC5967CC4947BC39379C39278C29178C29078
C29178C2927AC3957EC49983C69D88C79F8BC79E8AC79984C5917AC4896FC38468C28467C3886C\
C48F73C4967AC4987FC49881C39883C59B88C8A494CEB2A5D5C3B8DBD3CAE0DED7
E2E5DFE3E7E1E3E7E1E3E6E0E3E5DFE2E5DEE2E4DEE2E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E9E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DE\
E2E5DFE2E5DFE2E4DDE1DFD7DFD8CBDDCDBBD9BFA9D4B196CFA486C9997AC28F71
BA8669B17E62A8765C9F6F56996A5195674E94664D9768509D6E55A5765DAF8268BA8F75C59D83\
CEA98ED6B398DBBBA0DFC0A5E1C4AAE2C5ADE3C6AFE3C6B1E2C6B2E2C6B2E2C6B2
E2C7B3E2C7B3E2C7B3E2C7B3E2C7B3E2C7B2E2C7B1E2C7B0E2C7AFE3C6ADE3C5ACE3C4ABE2C3A9\
E2C2A8E1C1A8DFC1A7DEC1A7DDC0A6DDBEA6DDBCA5DCB9A3DCB7A2DBB5A0DAB39E
D9B19CD8B09BD8B09AD8AF9AD9AF9BD9B09CD9B29DD9B49DD9B79ED9B99FD9BBA0D9BCA1DABDA2\
DBBFA4DCC0A6DEC2A8DFC4AAE1C6ACE2C7AFE2C8B0E3C8B2E3C8B3E3C8B4E3C8B5
E3C8B5E3C8B6E3C9B6E3C9B6E3C8B6E2C8B4E2C6B3E0C4B0DFC1ACDDBDA7DBB8A1D9B19AD6AB92\
D3A48CD09E86CC9981C8957EC4927BC18F78BE8D76BC8C74BB8A72BA8971B98970
B98970BA8970BA8A72BB8C73BD8E75BE9077BF927AC0957BC1977DC3997FC59B82C89D84CB9E87\
CDA08AD0A28CD1A38DD2A58ED2A68ED3A88FD3A88FD3A98FD4A990D4AA90D4AA91
D3AB92D3AC92D3AC92D2AB91D2AA90D2A88ED1A68DCFA58BCEA389CCA288CAA086CA9F85C99E85\
C99E84C89D83C89C82C69A81C5997FC4977DC3957CC2947AC29279C29178C29078
C29079C2917BC3937FC49783C59B88C69E8AC69D88C59781C38E75C1856AC08063C08062C18668\
C38E70C49478C4967BC4957BC4937BC5957FC99D8BCEAC9DD5BFB3DBD0C7E0DDD6
E2E5DEE3E7E1E3E7E1E3E6E0E3E5DFE2E5DEE2E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE3E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DE\
E2E5DFE2E6E0E2E4DDE1DFD6DFD6C9DCC9B7D7BAA2D1A98DC89A7BBF8B6CB57F61
AA7559A16D5398674E91624A8B5F47885D46885D478B5F4992654F9B6F59A87D66B58C74C39C82\
CEA98FD6B49ADCBCA1E0C1A7E1C4ABE2C6AEE3C6B0E3C6B1E2C6B2E2C6B2E2C6B1
E2C6B1E2C6B1E2C6B0E2C6B1E2C6B0E2C7B0E2C7B0E2C7AFE3C7AFE3C6AEE3C5ADE3C4ABE3C3AA\
E2C3AAE1C2A9E0C2A9DFC2A9DEC1A9DEC0A9DEBDA8DEBBA6DDB8A4DCB6A2DAB49F
D9B29DD8B19BD7AF9AD7AE99D8AE99D8AE9AD8AF9AD8B19BD7B49CD7B69DD7B89ED8BAA0D9BCA1\
DABEA3DCC0A5DDC2A7DFC4A9E0C5ABE1C6ADE2C7B0E2C8B2E2C8B3E2C8B5E3C8B5
E3C8B6E3C8B6E3C9B6E3C9B5E3C8B4E2C8B3E1C6B1E0C4AEDEC1AADCBDA5DAB79FD7B199D5AA92\
D2A48BCE9D86CA9881C7947EC3907BC08D78BE8C75BC8A73BB8A71BA8970B9886F
B8886EB9886FBA8970BB8B72BD8D74BF8F77C1927AC2957CC3977EC49A81C69C83C99D85CB9E87\
CE9F89D0A18BD1A28CD1A48DD1A58DD2A68DD2A78ED2A78ED3A78FD3A78FD3A890
D2A990D2A990D1A990D1A990D1A88FD0A78DCFA68CCEA48ACCA288CBA187C99F85C89E85C89E84\
C79E84C79D83C69C82C59B81C49A80C3987EC2967CC2947AC29279C29178C29078
C28F79C2907BC3927FC49683C59987C59C88C59A85C4957DC18C72BF8467BD7F5FBD7F5FBF8564\
C18C6DC39274C39377C39176C48E75C59079C99985CFA999D5BCB0DBCFC5E0DDD5
E2E4DEE3E7E2E3E7E1E3E6E0E3E5DFE2E5DEE2E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E5DE\
E2E6DFE2E6E0E2E4DDE1DFD6DFD5C8DBC6B4D6B59DCDA286C29071B57F60A87153
9B664A905E45895A428457408055407F55407E5541805744865D4A9067549F7662AF8872BF9A81\
CDA990D7B59BDDBCA3E0C1A8E2C4ACE2C6AFE3C6B1E3C6B1E2C6B1E2C6B1E2C6B0
E2C6AFE2C6AFE2C6AEE2C6AEE2C6AEE2C6AEE2C6AFE2C6AFE3C7AFE3C6AEE3C6AEE3C5ADE3C4AC\
E2C3ACE2C3ABE1C3ACE0C3ACE0C3ACDFC2ACDFC0ABDFBDA9DEBBA7DDB8A4DBB6A1
D9B39ED8B19BD7AE99D7AC98D7AB97D7AB97D6AB97D5AD97D4AF97D4B198D5B49AD6B79CD8BA9F\
DABCA1DBBFA4DDC1A6DEC3A8DFC4AAE0C5ACE1C6AFE1C7B1E2C8B3E2C8B5E3C8B6
E3C8B6E3C8B6E3C9B5E3C9B4E3C8B3E2C7B2E1C6B0E0C3ADDEBFA9DCBBA4D9B59ED6AF97D3A990\
D0A28ACC9C85C99680C5917DC18E7ABF8B77BD8A75BB8972BA8970B9886EB8886D
B8876DB8876DB9886FBA8971BD8C74BF8F77C1927AC3957CC4987FC69A82C79C84C99D85CB9E87\
CD9E88CE9F89CFA089CFA28AD0A38BD0A58CD0A58DD1A58DD2A58ED2A58ED2A58E
D1A58ED0A68DD0A68DCFA68CCFA68CCFA58BCEA48ACCA389CBA187C99F85C79E84C79D83C69D83\
C69D83C69D83C59C82C49B81C39A80C2987EC2967CC2947BC29279C29178C28F78
C28F7AC2907CC2917FC39482C49885C49985C49882C2937ABF8C6FBD8465BB7F5EBB7F5DBC8361\
BE8968C08E6EC18E71C28C70C38A71C58D76C99683CFA797D5BBAEDBCEC4E0DCD5
E2E4DEE3E7E1E3E7E1E3E6E0E3E5DFE2E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E5DE\
E2E6DFE2E6E0E2E4DDE1DED5DFD3C6DBC4B2D5B199CB9D80BE886AAE76579D6749
8E5B3F83533A7D50387A4E39784E3A774E3C764E3D764F3F7B554586604F96705EA9846FBC9780\
CCA88FD7B59BDDBDA4E0C2AAE2C4ADE2C6B0E2C6B1E2C6B1E2C6B1E2C6B0E2C5AF
E2C5AEE2C5ADE2C5ACE2C5ACE2C5ACE2C5ADE2C6ADE2C6AEE2C6AEE2C5AEE2C5AEE2C4AEE2C4AD\
E1C3ADE1C3ADE0C3ADE0C3ADE0C3ADDFC2ADDFC1ACDFBFABDEBCA9DDBAA6DBB6A2
DAB39FD8B09BD7AC98D6AA96D6A894D5A793D4A792D2A792D2A992D1AC93D2AF95D4B298D7B69B\
D9BA9EDBBCA1DCBFA4DDC1A6DEC2A8DFC4ABE0C5AEE1C6B1E2C7B3E2C8B5E3C8B6
E3C8B6E3C8B6E3C9B5E3C9B4E3C8B2E2C7B0E1C5AEE0C2ABDEBEA7DBB9A2D9B39CD6AD96D2A78F\
CFA089CB9A83C7947FC38F7CC08B79BD8976BC8874BB8771BA886EB9876CB8876B
B7866BB7866CB7876DB98870BC8B73BF8E76C19279C3957DC5987FC69B82C79C84C99D85CA9D85\
CB9D85CC9D86CD9E87CDA088CDA189CEA38ACFA38BD0A48CD1A48DD1A38DD1A38C
D0A28BCFA28ACEA289CDA289CDA389CDA389CCA288CBA187C9A086C79E84C69D83C59C82C59C82\
C49B81C49B81C49B81C39A80C3997FC2987EC2967CC2947BC29279C29178C28F79
C28F7AC28F7CC2917EC39381C39682C39782C2967EC09177BD8B6DBA8564B8805DB77F5BB8815E\
BA8563BC8867BE886ABF866AC1866DC48A74C89582CFA697D5BBAEDBCEC4E0DCD5
E2E4DEE3E7E1E3E7E1E3E6E0E3E5DFE2E4DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E5DE\
E2E5DFE3E6DFE2E3DCE1DDD4DFD2C5DBC2B0D5AF98CA997EBC8467AA7153976144
8754397B4D34764A33744935734A37714A396F493A6E493C724E417D594B8F6B5AA4806CB9957F\
CAA78FD6B49BDDBDA4E1C2AAE2C4AEE2C5B0E2C6B1E2C6B0E2C5B0E2C5AFE2C5AE
E2C5ADE2C5ACE2C5ABE2C5ABE2C5ABE1C5ABE1C5ABE1C4ACE0C4ACE0C3ADE0C3ADE0C2ACDFC2AC\
DFC1ACDFC1ABDEC0ABDEC0AADDBFAADDBFAADDBEAADCBDA9DCBBA7DBB8A4DAB5A1
D8B19DD7AD99D5A996D4A693D3A491D2A28FD1A18ECFA28CCFA38CCFA68DD0A98FD2AD93D5B297\
D8B69BD9B99EDBBCA1DBBEA3DCC0A6DDC2A9DFC4ADE0C6B0E1C7B3E2C8B5E3C8B6
E3C8B6E3C8B5E3C9B5E3C9B3E3C8B2E2C7B0E1C4ADE0C0AADEBCA6DBB6A1D8B09BD5AA94D1A48D\
CD9E87C99882C5927EC18D7BBE8978BC8775BB8672BA866FB9866CB8876AB7866A
B6856AB6856BB6866CB8876FBB8A72BE8D75C09178C2947CC4987FC59A81C69C83C79C83C79C83\
C89B83C99B83C99C83CA9E85CA9F86CBA188CDA28ACEA28BD0A38CD0A28CD0A18B
CEA089CD9F87CC9F86CB9F85CBA086CBA086CAA086C9A086C89F85C69D83C59C82C49B81C49A80\
C39A80C39A80C39A80C39A7FC2997FC2987EC2967CC2947BC29279C29178C28F79
C28F7AC28F7BC2907DC3927FC39480C2957FC1947BBE9074BA8A6CB78463B47F5CB37D59B37D59\
B47E5CB67F5FB87F61BB7F63BE8168C28771C79481CEA697D5BBAFDBCEC4E0DCD4
E2E4DEE3E7E1E3E7E1E3E6E0E3E5DFE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DD\
E2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DD\
E2E5DEE3E5DEE2E2DAE1DCD2DFD1C3DBC1AFD5AE98CA997FBC8468AA7154986145
87543A7B4C347549327147336F47356C46366944366845386C4A3E7755488A6758A07D6AB7937D\
CAA68ED6B49BDDBDA4E1C2AAE2C4ADE2C5AFE1C5AFE1C5AFE1C4AEE1C4ADE1C5AD
E1C5ACE2C5ACE2C6ABE2C6ABE2C5AAE1C4AAE0C3A9DFC2A9DDC0A9DDBFA8DCBEA8DCBEA8DCBEA8\
DBBDA7DABCA6D9BBA5D8B9A4D7B8A3D7B7A2D7B7A2D7B6A1D7B5A0D6B39ED5AF9B
D4AC98D3A895D2A492D0A08FCF9E8DCE9C8BCD9C89CD9C88CC9E88CDA188CEA48BD1A88ED3AD92\
D6B196D7B59AD9B89DDABBA0DBBEA4DCC0A8DEC3ACE0C5AFE1C6B2E2C7B5E3C8B6
E3C8B6E3C8B5E3C9B5E3C9B3E3C8B2E2C6B0E1C4ADE0BFA9DEBAA5DBB4A0D8AE9AD5A893D1A38C\
CC9D86C89780C4917CC08C79BD8876BB8672BA856FBA856CB9856AB88569B78568
B68569B5856AB5866CB7876EB98971BC8C74BF9077C0937AC2967DC29880C39A81C39A81C39980\
C49980C49980C59A80C69B82C79D84C99F86CBA189CDA28BCEA28CCFA28CCEA08A
CD9F88CB9D85CA9D83CA9D83C99E84C99F84C99F85C89F85C79E84C69D83C59C82C49B81C39A80\
C3997FC2997FC2997FC2997FC2987EC2977DC2967CC2947AC29279C29178C28F78
C28F79C28F7BC2907DC2927EC2937FC1947DBF9279BC8E72B7886AB38261AF7C59AC7755AC7553\
AD7553AF7555B27657B5775BBA7B61BF846DC6937FCDA696D5BBAEDBCEC4E0DCD4
E2E4DEE3E7E1E3E7E1E3E6E0E3E5DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DD\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DDE2E4DD\
E2E4DDE2E3DBE2E0D7E1DACFDFCFC1DCC0AFD5AE99CB9A82BE876DAE755A9D654A
8D593F805037774A347147336C453368423364413363413668473B7453468766579F7C6AB6937D\
C9A68ED6B49BDDBDA3E1C2A9E2C4ACE1C4ADE1C4ADE0C4ACDFC3ACE0C3ACE0C4AC
E1C5ACE2C5ACE2C6ACE2C6ABE2C5AAE0C4A9DEC1A7DCBEA5DABCA3D8BAA2D7B9A2D7B8A2D7B8A1\
D6B7A0D4B59ED2B29CD0AF99CFAD97CEAC96CEAB95CEAB95CEAA94CDA993CDA692
CCA390CBA08ECA9C8BCA9989C99787C99686C99684C99783CA9983CB9C84CCA086CEA389D1A78C\
D3AB90D4AE94D6B298D7B69CD9BAA0DBBDA5DDC1A9DFC3AEE1C6B1E2C7B4E3C8B5
E3C8B6E3C8B5E3C8B5E3C8B4E3C8B2E2C6B0E1C3ADE0BFAADEB9A5DBB3A0D8AD99D4A792D0A28B\
CC9C85C8967FC3917AC08C76BD8873BB8670BA856CB9846AB98468B88467B78567
B58569B5856AB5866CB6876EB88971BB8B73BD8E76BE9178BF947BBF967DBF977EBF977EBF977E\
BF977DC0977DC1977EC29980C49B82C79D84C9A087CBA18ACCA28BCDA28BCCA089
CB9E87C99D84C89B82C89B82C89C82C89D83C89E84C89F85C89E84C79D83C59C82C49B81C39A80\
C3997FC2997FC2987EC2987EC2987EC2977DC2967CC2947AC29279C29078C28F78
C28F79C28F7BC2907DC2927EC2937EC1937CBE9178BA8C71B48568AE7D5EA97655A5704FA46C4B\
A56A4AA7694BAB6B4DAF6E52B5755ABC8068C4917BCDA594D4BBADDBCEC4E0DCD4
E2E4DEE3E7E1E3E7E1E3E6E0E3E5DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DD\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DDE2E4DDE2E4DDE2E3DC\
E2E3DBE2E1D8E2DED3E1D7CBDFCDBEDCBFAED6AF9BCD9D86C18B73B27A61A26B51
935E4585533C794C36704633684231623F305E3D305E3E3364443A7251458665569E7B69B5927C\
C9A68DD6B49ADDBDA3E1C2A8E1C3AAE1C4AAE0C3AADFC2A9DEC2A9DFC2AAE0C3AB
E1C4ACE2C5ADE2C6ADE2C6ACE2C5AAE0C3A8DDBFA5DABBA1D7B79ED4B49CD3B39AD2B29AD1B199\
D0AF97CDAC94CAA890C7A48CC4A089C39E87C29E86C29D86C29D86C19C86C19A85
C09885C09584C09282C09081C18E7FC28D7FC38E7EC5917EC6947EC8977FCA9A81CB9D83CDA085\
CEA388CFA68BD1AA8FD3AE94D5B399D7B89FDABCA5DDC0ABDFC4AFE1C6B3E2C7B5
E3C8B5E3C8B5E3C8B5E3C8B4E2C8B3E2C6B1E1C3AEE0BFAADEB9A5DBB3A0D8AD99D4A792D0A18B\
CC9C84C7967EC39179C08D74BD8970BB876DBA856AB98467B98466B88466B68467
B58569B4866BB5876DB6886FB88971BA8B72BB8D74BC8F77BC9279BC947BBB957CBB957CBB957C\
BB957CBC957CBE967DC0987EC29A80C59C83C79F86C9A188CBA28ACBA28ACAA189
C99E86C79C83C69B81C69B81C79C82C79D83C89E84C89F85C89F85C89E84C79D83C59C82C49B80\
C3997FC2997FC2987EC1987EC1987DC1977DC1957BC1947AC29279C29078C28F78
C28F79C28F7BC2907CC2927EC2937EC1937CBE9178B98B70B28266AA795BA36F519F67499D6144\
9D5E419F5E41A46044AA6549B16E53B97C62C28E77CCA491D4BAABDBCEC3E0DCD4
E2E4DEE3E7E1E3E7E1E3E6E0E3E5DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DAE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DDE2E3DCE2E3DB\
E2E1D9E2DFD5E2DACFE1D3C6DFCABADCBEACD6AF9BCE9F8AC28E77B47D66A56D56
95604885543E784B366C4431623E2D5B3A2C58392D593B306042386F50448564559D7B69B5927C\
C9A68DD6B499DDBDA1E0C1A6E1C3A8E0C3A8DFC2A7DEC1A7DEC1A7DEC1A8DFC2AA
E0C4ACE2C5AEE2C6AEE2C6ADE2C5ABE0C2A7DCBEA3D8B99ED4B49AD1B096CFAD94CDAB92CBAA90\
C9A78EC5A28AC19D84BD987FB9937BB69179B58F77B48E77B38E77B28D78B18C78
B18A78B18877B28677B38476B58375B78475BA8676BE8977C18D78C39179C5947AC6957BC7967C\
C8987EC89A80CA9E84CCA289CFA88FD2AE96D6B59EDABBA5DEC0ACE0C4B0E2C6B3
E3C7B4E3C8B5E3C8B5E3C8B4E2C7B4E2C6B2E1C3AFE0BFABDEB9A6DBB3A0D8AD99D4A792D0A18B\
CC9C84C7977EC39278C08E73BD8A6EBB886ABA8668B98566B88465B78465B68567
B58669B4876BB4886EB6896FB78A71B98B72BA8D74BB8F76BA9178BA937AB9947BB9947CB8957C\
B9957CBA957CBC967DBF977EC29980C49B82C79E85C8A087C9A189C9A189C8A087
C69E85C59B82C49A81C49A80C59B81C79D83C89E84C99F85C99F85C99F85C89E84C69D83C59B81\
C39A80C2997FC1987EC1977DC0977DC0967CC0957BC0937AC09278C09078C08F78
C18F79C1907BC2917CC3937EC3947EC1947CBE9177B88A6FB08065A774599F694E99604497593E\
97553A99553A9E573CA55E41AE684CB7785CC18B73CBA28ED3B9A9DBCDC2E0DCD4
E2E4DEE3E7E1E3E7E1E3E6E0E2E5DEE2E4DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E1E9E8E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DAE2E2DBE2E2DBE2E2DBE2E2DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DDE2E4DDE2E3DCE2E2DA\
E1E0D6E1DCD0E1D6C9E0CFBFDFC6B5DCBBA9D6AE9BCE9F8BC18E7AB27D68A06B56
8E5B467E4E3A6F4431623D2C59382952352750342952372D5B40356C4F438264559C7B69B5937D\
C9A68DD6B499DDBDA1E0C1A4E0C2A6DFC2A6DEC1A5DEC0A5DEC0A5DEC1A7DFC2A9
E1C3ABE2C5ADE2C6AEE2C6ADE2C5ABE0C2A7DCBEA2D8B89DD4B397CFAE93CCAA8FC9A78CC6A489\
C3A086BE9A80B8947AB38E74AE8870AA856CA7826BA4816AA27F6AA07E6A9F7D6A
9E7B6A9E796AA07869A27669A67669AA7869AF7C6BB4816EB98570BD8972BF8B72C08B72BF8B71\
BF8A71BF8B72C08E75C29279C59980CAA189D0AA93D6B39DDBBBA6DFC1ADE1C5B1
E2C7B3E3C8B4E3C8B5E3C8B5E2C7B4E2C6B2E1C3B0E0BFABDEBAA6DBB4A0D8AE99D4A892D0A28B\
CC9C84C8977DC49277C08E71BD8B6DBB8969B98766B88665B78564B68565B58566
B48669B4876BB4886EB58970B78A71B98C73BB8E75BB9077BB9279BA947BBA957CB9957DB9967D\
BA967DBB967DBD977EC0987EC39980C59B82C79D84C89E86C89F87C79F87C59E86
C39C83C29A81C19980C29980C49B81C69C83C89E84C99F85CAA086CAA085C99F85C79D83C69C82\
C49A80C2997FC1987EC0977DBF967CBE957BBE947ABE9279BE9178BE9077BF8F78
BF9079C0907AC2927CC3947EC3957EC1957CBE9178B7896FAF7E64A572589D664C975B4294543B\
934F36964F359B5137A2583CAB6347B57358C0886FCAA08BD3B8A8DACDC1DFDCD3
E2E4DDE3E7E1E3E7E1E3E6E0E2E5DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DDE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E5DCE9E9E1E9E9E0E6E6DEE4E4DCE2E3DBE2E2DAE2E2DBE2E2DBE2E2DBE2E2DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DDE2E4DDE2E3DCE2E2D9\
E1DED4E1D9CCE0D2C3DFCAB9DEC2AEDCB8A4D7AD98CD9E8ABF8D79AC7965966452
8152406F43326039295533244D3022482E22472F244B3329553C32674C407F62539B7B69B5937D\
C9A78ED7B599DDBDA0DFC0A3DFC1A4DFC0A4DEC0A3DEBFA3DEBFA4DFC0A6E0C2A8
E1C3AAE2C5ACE2C6ADE2C6ACE2C5AAE0C2A7DDBEA2D9B99DD5B397D0AD92CBA88DC7A489C29F85\
BD9A80B79479B18D73AB866DA580689F7C649A78629675619172608E705F8B6E5E
8A6B5D8A6A5C8B685B8F685A94695A9A6B5BA1705EA87662AF7C66B48068B68169B78067B67E65\
B57C63B47B62B57C64B78068BB876FC1927AC99E86D1AA94D8B69FDDBEA9E0C3AF
E2C6B2E3C7B4E3C8B5E3C8B5E2C7B4E2C6B3E1C3B0E0C0ACDEBBA6DBB5A0D8AF99D4A992D0A38B\
CC9D83C8977DC49276C08F71BD8C6CBA8A68B98866B78765B68764B58665B38666
B28568B2866AB3876CB4886FB78A71B98D74BB8F76BD9279BD947BBD967DBD977EBC987FBC987F\
BD987FBE987FC0987FC2997FC49A80C69A81C79B83C79C84C69C85C59C85C29A83
C09981BF987FBE977EC0987FC29A80C59C82C89E84C9A086CAA086CAA086C99F85C89E84C69C82\
C49A80C2997EC0977DBE967CBD957BBC947ABB9379BA9178BB9077BB9077BC9078
BE9079BF917AC1937CC2957EC3967EC1957CBE9178B7896FAE7E64A571589C644B965A4193523A\
924D35954C349A4F35A2553AAB6044B57055BF856DC99E89D3B6A6DACCC0DFDBD3
E2E4DDE3E7E1E3E7E1E3E6E0E2E5DEE2E4DDE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E5DDE9E9E1E9E9E1E6E7DFE4E4DCE2E3DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E5DEE2E5DEE2E4DDE2E2D9\
E2DDD2E1D7C9E0CFBDDFC6B2DEBEA8DCB59FD6AA94CC9C87BB8976A473618A5B4B
7246375D36294F2D2046281C40271C3E281D3E2920432F254F392F624A3E7C6152997B68B4947D\
CAA88ED7B59ADDBDA0DFC0A3DFC0A3DEBFA3DEBFA2DEBFA2DFBFA3E0C0A5E0C1A7
E1C3A9E2C5ABE2C6ACE2C6ABE2C5AAE0C3A7DEBFA3DBBB9FD7B599D2AF94CCA98EC6A388C09C82\
BA967CB38F75AD896FA682699F7C6498776090715D896C5A8268587C6355786053
755C50755A4E77584C7B594B815A4B895E4D9264519B6B56A2725BA9765EAC775FAD755DAC7159\
AB6E56AA6B54AA6C54AC6F58B17760B8836CC2927BCCA28BD5B199DCBBA5E0C2AC
E2C6B1E3C7B4E3C8B5E3C8B6E3C8B5E2C6B4E1C4B1E0C1ACDEBCA7DBB7A0D8B199D4AA92D0A38B\
CC9D83C7977CC39276C08E70BC8B6BBA8A68B88966B68865B48864B28664B08464
AF8365AF8266B08369B2856CB58970B98D74BC9177BE947AC0967DC0987FC09980C09A80C09A80\
C19A80C19A80C2997FC4997FC5997FC69980C69880C59881C49882C29781C09680
BE967FBC957DBC967DBD977EC0997FC49C82C79E84C9A085CAA086CAA086C99F85C89E84C69C82\
C49A80C2987EBF977DBD957BBA947AB99279B89178B79077B79076B88F77BA9077
BC9179BE927AC0947CC2967EC3977EC1957CBD9177B7896FAE7E64A571589D654C975A4293533B\
934E36964D349B4F35A2543AAB5E44B56E54BF836CCA9C88D3B5A6DACBC0DFDBD3
E2E4DDE3E7E1E3E7E1E3E6E0E2E5DEE2E4DDE2E4DDE2E4DDE2E4DDE2E3DDE2E3DDE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E7DFE4E5DDE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE2E4DDE3E5DFE3E6E0E4E6DFE4E3DA\
E3DED2E2D6C7E0CCBADFC3ADDEBAA2DCB299D6A790CA9984B785729C6D5C7F5345
643C304F2C2141231939201636201735221937241C3D2A2249362C5E473C796051987B68B4957E\
CAA98FD8B79BDEBDA1DFC0A3DEC0A3DEBFA2DEBEA2DFBEA2E0BFA3E0C0A4E1C1A6
E1C3A8E2C5AAE2C6AAE2C6ABE2C5AAE1C4A8DFC1A5DDBDA1D9B89DD4B297CEAB90C7A389C09C82\
B9957BB38E74AC886FA682699E7C649575608B6E5B8067577660526E594D675349
634F45614B41634A3E684A3C6F4D3D78523F8259458C604B9567519C6C56A06D56A26B54A36750\
A2634CA26049A26049A5644DAA6C55B37A62BD8B72C99D84D3AD95DAB9A2DFC1AB
E1C6B0E2C8B4E3C9B6E3C9B7E3C9B6E2C8B5E1C6B2E0C2AEDEBEA8DBB9A1D8B39AD4AC92D0A48B\
CC9D83C7977CC39175BF8D70BB8A6BB88968B68966B48864B18763AF8562AC8160
AA7D5FA97B5FAA7B62AD7F66B2846BB78A71BC9076BF947AC2977DC3997EC39A7FC39B80C39B80\
C39A80C39A7FC3987EC3977DC3967CC3957CC3947CC2947DC2937DC0937EBE937D
BB937CBA937CBA947BBC967DBF997FC39C81C79E83C99F85CAA085CAA085C99F85C89E83C69C82\
C49A80C1987EBE967CBB947AB99278B69177B58F76B48F76B48F76B68F76B89077
BA9179BD937AC0947CC2967DC2967DC1957BBD9076B6886EAE7D64A571589D654D975B4394543D\
945039974F379C5138A3553CAC5F46B66E55C0826CCA9B89D3B5A6DBCBC0E0DBD3
E3E4DEE4E8E2E3E7E1E3E6DFE2E5DEE2E4DDE2E4DDE2E4DDE2E3DDE2E3DDE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E7DFE4E5DDE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DEE3E6E0E5E8E1E6E8E1E6E6DD\
E5E0D4E4D7C7E2CCB8E0C1AADEB79EDBAE95D5A48BC8967FB4826E9869597A4F42
5D382D47271E391F16321B132F1C142F1E1632211939271F4633295B453A785F4F977B68B4957E\
CBAB90D8B89CDEBFA2E0C1A4DFC0A3DEBFA3DEBEA2DFBEA2E0BFA3E0C0A4E1C1A6
E1C3A7E2C5A9E2C5AAE2C6AAE2C5AAE2C4A9E1C2A7DFBFA4DCBBA0D7B59BD0AD93C9A58BC19D83\
BB967CB59077B08B72AA866EA280699778648A6F5D7C65566F5B4E6352475A4A40
55433B523F36543D32583E31604131694634734E3B7D5642865E4A8E634F94655098634E9A604A\
9C5D469D5B449F5C45A36149A96A52B27860BD8A71C89C82D2AC93DAB9A0DEC1AA
E1C6B0E2C8B4E3CAB7E3CBB9E3CBB9E2CAB8E1C8B5E0C5B0DEC0AADBBBA3D8B49BD4AD93D0A58B\
CB9D83C7967CC29075BD8C6FB9896AB68767B48765B18663AE8461AA805EA67A5A
A27457A07055A17057A6745DAC7C64B4856CBA8D73BF9378C2967AC3987BC4987CC4997CC3997D\
C2987CC1977CBF947ABE9278BD9076BC8E75BD8D76BD8E77BD8E78BD8F7ABB907A
BA917AB9927AB9947BBB967CBF987EC39B80C69D81C89F83CA9F84CA9F84C99E84C89D83C69C82\
C49A80C1987EBE957BBA9379B79177B48F75B38E74B28D74B28E75B48F76B69077
B99179BC937ABF947CC1957DC1957CBF937ABB8E75B4866DAB7B62A36F579B644D965B4494563E\
95533B98523A9E543BA55840AE6149B76F59C1846FCB9C8BD4B6A8DCCCC2E1DCD4
E3E5DEE4E8E2E4E8E1E3E6DFE2E5DEE2E4DDE2E4DDE2E3DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E7DFE4E5DDE2E4DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE1E3DCE2E3DCE2E4DEE4E6E0E5E8E2E7E9E2E8E7DE\
E7E1D5E6D7C7E3CBB7E1BFA7DEB59BDBAB91D4A187C7937BB37F6B9768577A5042
5D3A2F472921392018301B142D1B142D1C152F1E1737241D4530275B4438785E4E977B67B5967F\
CBAC92D9B99DDFC0A3E0C2A5DFC1A4DEC0A3DEBFA3DEBEA2DFBFA3E0C0A4E0C1A5
E1C3A7E2C4A8E2C5A9E2C6A9E2C6AAE2C5A9E1C4A9E0C2A7DEBEA4D9B89FD3B097CCA88FC5A086\
BF997FBB947BB89179B38D76AB87729E7E6B8F73617E66576D594C5F4D4354433A
4D3C3349372E4A342A4E35285538295D3E2D674634704E3C7A5644825C4A895F4C8F5F4B945D48\
995C469D5C45A15F48A6654EAD7057B67D65C08E74CA9F85D3AE94D9BAA0DEC2AA
E0C7B0E2C9B5E2CBB9E3CDBBE2CDBCE2CCBBE1CBB8DFC7B3DDC3ACDBBDA4D8B69CD4AE94D0A68B\
CB9E83C6967BC08F74BB8A6EB78669B48566B18464AF8361AB805EA67A59A07152
9A684D96624997624B9C6852A5725BAE7E65B7886EBC8F73C09275C19475C19475C09475BF9376\
BD9276BB9075B88D72B5896FB2866DB2856CB3856DB58770B78973B98B75B98D77
B88F78B79179B8937ABA957BBD977CC19A7DC59C7FC79D80C89E81C89E82C79D82C69C82C59B81\
C3997FC0977DBD957BBA9278B68F75B38D74B28C73B18C73B18D74B38E75B58F77
B99179BC927ABF937BC0947CC0937BBD9178B88B72B1836AA878609F6D5598624C935A4492563F\
94543D98553D9F573FA65C44AF654EB8735EC38774CD9F8FD6B8ABDDCEC4E2DDD5
E4E6DFE5E8E2E4E8E1E3E6DFE2E4DEE2E4DDE2E3DDE2E3DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E7DFE4E5DDE2E4DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE3E5DFE4E7E0E5E7DFE6E4DB\
E6DED1E4D4C4E3C9B4E1BDA5DEB398DBA98ED49F84C79178B37F6A9A6A587E5445
633F344D2F273D251D331F182E1C152C1B152E1D1636221B442E265B4237785D4E977B67B59780\
CBAD93D9BB9FE0C2A5E1C3A6E0C2A6DFC1A4DEBFA3DEBFA3DEBFA3DFC0A4E0C1A5
E1C3A6E1C4A8E2C5A9E2C6A9E2C6AAE2C5AAE2C5AAE1C3AADFC0A8DBBBA3D5B49CCFAB93C9A38A\
C59D84C29A81C19880BD967FB6907BA88673977967846A5A715B4D614E42544238
4C3A3148342B4731274B3125503426583A2A604131684A39705241795848815C4B895E4B915E4A\
995F49A0624BA6684FAD7057B47A61BC876EC5967BCDA48AD4B197DABBA2DEC2AA
E0C7B1E1CBB6E2CDBAE3CFBDE2CFBFE2CFBEE1CDBBDFCAB6DDC5AEDBBFA6D8B79DD4AF94D0A68C\
CB9E83C5957BBF8E74BA886DB58468B18265AF8162AC805FA87C5BA274549A684B
925D438D553E8D543F935B479D6852A8765EB18268B7896DBA8C6EBA8D6DB98C6CB78B6CB58A6C\
B2886CAF856BAB8168A77D64A57A62A57A62A77B64AB7F68B0836CB38770B48A73
B48C75B48E76B59077B79278BA9478BE967AC1987BC39A7CC49A7EC59A7FC49A7FC49A7FC3997F\
C2987DC0967CBD9379B99076B68E74B38C72B18B71B08B72B18C73B28E75B58F77
B89078BC917ABE917BBF927BBE9179BB8E75B5886FAD7F67A3745D9A6953925F4A8E58438E553F\
91553E9757409E5B43A76149B06A53BA7863C48B79CFA394D8BBAFDFD0C6E3DFD7
E5E7E0E5E9E3E4E8E2E3E6DFE2E4DEE2E4DDE2E3DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE2E9EAE2E6E8DFE4E5DDE2E4DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E4DCE2E4DDE2E4DDE2E4DDE1E3DCE0E2DCDFE1DADFDED7DEDAD0\
DED3C7DECBBADEC1ADDFB8A0DEB095DBA88CD49E82C89178B6816A9F6E5B855A4B
6C473B56382E452C2439241D311F192E1C162E1C1635211A442D245A4136775C4D977A67B49780\
CBAE93DABCA0E0C3A6E2C4A7E1C3A6DFC2A5DEC0A4DDBFA3DDBFA3DEC0A4DFC1A5
E0C3A6E1C4A7E1C5A8E2C5A9E2C5A9E2C5AAE2C5ABE1C4ACE0C2ABDDBEA7D8B7A0D2AF97CEA88F\
CAA38ACAA188C9A088C79E87C09983B38E7BA1806E8D705F7A61516953455C473B
533E334F382D4D35294F3427533628593B2B5F41316649396D51417558487E5D4C88604D92634E\
9C664FA56C53AD7359B57C62BD866CC49278CB9E83D1AA8FD6B49ADABDA3DDC3AB
E0C8B1E1CBB7E2CEBBE2D0BFE2D1C1E2D1C0E1CFBDDFCBB8DDC6B0DBC0A7D8B89ED4AF95D0A68C\
CB9D83C5957BBF8D73B8876CB38267B07F63AD7E60AB7C5DA777589F6E50966146
8C543C864C36854A378B523F96604BA16F58AB7B62B08267B28567B08465AD8263AA8061A67D60\
A27A5F9E765E99725B966F58956D56976E579B725AA17760A67D65AA816AAC856D
AC876FAC8870AD8A71B08C72B38E73B79174BA9375BD9477BE9578BF9579BF957AC0957AC0957A\
BF947ABE9379BC9177B98F75B68D72B38B71B18A71B08B71B18C73B38D75B58E76
B98F78BC9079BE907ABE8F79BC8E77B88B73B1856CA87B649E705A9465508C5B4788554189533E\
8D543E9458419C5D46A6644DB06F59BB7D69C6917FD1A899DABFB2E1D3C9E5E1D9
E6E8E1E6E9E3E5E8E2E3E6DFE2E4DEE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E6DDE9EAE2E9EAE2E6E8E0E4E5DDE2E3DBE2E2DBE2E2DAE2E2DAE2E2DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE2E3DCE2E4DDE3E5DEE4E6DFE3E5DEE0E2DBDCDDD6D6D5CED1CDC5CEC5BB\
CEBEB1D1B8A8D5B49FDAB098DDAC91DCA78AD69F83CB9479BA856DA4745F8D6150
754F415F3F354D332B3E292334221D2F1E192E1D1834201B422C24583F34765B4C967A66B49780\
CBAE94DABCA0E0C3A6E2C5A8E1C4A7DFC2A5DEC1A4DDC0A3DDC0A3DDC1A4DEC2A5
DFC3A6E0C4A7E0C4A7E1C4A8E1C5A9E1C5AAE1C5ACE1C5ADE0C3ACDEC0A9DABAA3D6B39CD2AD94\
D0A98FD0A78ED0A68ECEA48DC89F89BC9580AB8874997965866A58775D4C6C5243
634A3C5E44375C40325D3F305F3F2F6242316647356B4D3C715443785B4981604E8B6551966A54\
A16F57AB765CB47E63BD876CC49076CA9A80CFA48AD4AE93D7B69CDBBDA4DDC3AB
DFC8B2E1CCB7E2CFBCE2D1C0E2D2C2E2D2C1E1D0BEDFCCB8DDC6B0DBC0A7D8B89ED4AF94D0A68B\
CB9D82C5947ABF8D72B9866BB38166AF7E62AD7C5FAA795CA674579E6B4F945E44
8B513A844834834734884F3C915C499B6A56A3765FA77C63A67D62A37B5E9D765A977256906C53\
8B685187644F84614C845F4B85604B89634D8F6852966F589B755E9F7A63A07D66
A07E67A07E67A17F68A38169A8846AAC876CB18A6EB48C6FB68D70B78D71B88E72B98E72BB8F73\
BC8F74BC8F74BB8E73B98D72B68C71B38B70B18A71B08B71B18C73B38D75B68E76
B98F78BC8F79BD8E79BD8D77BA8C75B58870AD8169A37860976C568D614C85574481513E82503C\
86523D8E5741985E47A36750AF725DBC826EC89684D2AC9DDBC2B6E2D5CBE6E2DA
E7E8E1E6EAE3E5E8E2E3E6DFE2E4DEE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E6DDE9EAE2E9EAE2E6E8E0E4E5DDE2E3DBE2E2DAE2E1D9E2E1DAE2E2DAE2E2DAE2E3DB\
E2E3DBE2E3DBE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE1E3DBE2E3DCE2E3DCE3E4DDE4E6DFE5E7E0E3E5DEDEDFD9D5D4CDC8C4BDBDB4ACB6A79D\
B59F93BC9E8DC7A08BD1A48BD9A68BDBA589D7A084CD977BBD8970A97963936754
7C554666453A523830432D283725222F1F1D2D1D1A32201C3F2B24563E34735A4B947966B3977F\
CBAE94D9BCA0E0C3A6E1C4A7E0C3A6DFC2A5DEC1A4DDC1A4DDC1A4DEC1A4DEC2A5
DEC2A5DFC3A6DFC3A6DFC3A6DFC3A7E0C4A9E0C4ABE1C4ADE0C4ADDFC1ABDCBDA6D9B8A0D6B39A\
D4AF95D4AC93D4AB92D2A890CDA38CC29A84B58E79A5826D9675618A6B58806250
795B4B755646725241714F3D714E3A724E3A74513D7756417B5B4781614C896751936D569E735A\
A8795FB28065BB876CC28F74C9987DCEA085D2A88DD6B095D9B79DDBBEA4DDC3AB
DFC8B2E1CCB7E2CFBCE2D1BFE2D2C1E2D1C0E1CFBDDFCBB7DDC6AFDBBFA6D8B79DD4AF94D0A68B\
CB9D82C5947ABF8D72BA866BB58165B17E61AE7B5FAA785CA673579F6B50965F46
8D543D874C37854B388952408F5D4B9769569C735F9D77619A765F94725A8B6B5381634C785B46\
7054426C4F3F6C4E3D704F3E7653417D594585604C8B68528F6E5891715B91725C
90725C8F715B8F715B93735C99775F9F7C63A48066A88267AB8368AD8468AF8568B28669B5886B\
B8896CBA8B6EBA8B6FB88B70B68B70B38B71B18B71B18C72B18D73B38D75B68E76
B98E77BB8E77BD8D77BC8C75B88972B1856DA87E659D745C916852855C487D5340794D3B794B39\
7E4E3B87543F925C47A06751AE755FBC8671C99B88D4B0A0DDC5B8E3D7CDE6E3DB
E7E8E2E6EAE3E5E8E2E3E6DFE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E6DDE9EBE2E9EBE2E6E8E0E4E5DDE2E3DBE2E1D9E2E0D9E2E0D9E2E1D9E2E2DAE2E3DB\
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E3DCE2E3DCE1E3DCE2E3DCE2E4DDE4E6DEE4E6DFE1E2DBD9D9D2CAC7C0B7AFA8A5978F99847B\
997C70A37F6EB48874C4937BD19C81D6A084D49E82CB977CBD8B72AB7B65956A56
7F584869483C553A32452F2B3727252F20202B1D1C2F201C3C2A23523D3371594A927865B2967F\
CAAE93D9BCA0DFC2A5E1C3A7E0C3A6DFC2A5DEC1A5DEC1A5DEC1A5DEC1A5DDC1A4
DDC0A4DDC0A4DDC0A3DDC0A4DDC0A5DEC1A7DFC2A9E0C3ACE0C3ADDFC2ADDEC0A9DBBCA5D9B8A0\
D7B59BD7B298D6AF95D4AB92D0A68EC89E87BD957EB28C75A7826C9E7B65977560
92705B8E6B578B675288634D876049865E46865F468761498A654D8F6A519670569E765CA77C61\
B08367B9896DC19073C7967ACD9C81D1A388D4AA8FD7B096D9B79CDBBDA4DDC3AB
DFC7B1E1CCB7E2CFBBE2D1BEE2D1BFE2D0BEE1CEBBDFC9B5DDC4ADDBBDA5D8B69CD4AE93D0A58A\
CB9D82C6957AC18D72BB876BB78265B37E61AF7C5FAC795CA77458A16D529A634A
935A438E553F8C54408D5946916250956B5A96726095746290715E876A577B604E6D5544604A3B\
564134523B30553B2F5D403267473872503E7B594681604C836551836853816753
7E64507C614E7C614D81644F886954906F5997745D9D785FA07A5FA37B5FA67C5EAA7E60AF8062\
B48365B78668B8886BB88A6DB68A6FB38B71B18C72B18C73B18D74B38E75B68E76
B98E76BB8E76BC8C75BA8A73B5876FAD8269A27A6296705889644E7E5844754E3C704837714735\
7649377F503C8C59459B6650AB7660BB8873C99D8AD5B3A2DEC7BAE4D8CDE7E3DB
E7E8E1E6E9E3E5E8E1E3E6DFE2E4DDE2E3DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E5DDE9EBE2E9EBE3E6E8E0E4E5DDE2E2DBE2E1D9E2E0D8E2E0D8E2E1D9E2E2DAE2E2DB\
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E3DCE2E3DCE2E3DC
E2E3DCE2E3DCE2E3DCE1E3DCE1E3DBE1E3DBDFE1D9DADAD3CECCC5BAB4ADA2968F8C79717D6359\
7D5A4E8960509D6E5BB37F68C38D74CB957ACC977CC59278B88870A77A63936855
7D574868473C553A33442F2C3627272D2121291D1D2D201D392923503D326F594A917864B1967E\
C9AD93D8BB9FDFC1A5E0C3A6DFC2A5DEC1A5DEC1A5DEC1A5DEC1A5DEC0A4DDBEA3
DBBDA1DABCA0DABB9FDABB9FDABCA0DBBDA3DDC0A6DFC2AAE0C3ADE0C3AEDFC2ACDEC1A9DCBEA5\
DABBA1D9B79DD8B399D6AF95D2A990CDA38AC69C84BE957DB78F78B28A73AD876F
AA836CA77F68A37B63A0765D9C72589A6F54986D52996E529B70549E7458A3795DAA8062B18668\
B98C6EC09274C69779CB9B7FCFA084D3A589D5AA8FD8B095DAB69CDBBCA3DDC2AA
DFC7B0E1CBB6E2CEBBE2D0BDE2D0BEE2CFBCE1CCB8DFC8B2DDC2ABDBBBA3D8B49BD4AD93D0A58A\
CB9D82C7967AC28F73BD896CB98466B58062B17D5FAD7A5DA9765AA471569F6A50
9A634B965F48955F4995634F956957966F5F9573649173648A6F5F7F66576F5A4C5E4B3F4D3C33\
4031293C2B24402C244C32285A3C30684738715140765947775D4B755E4C715B49
6D57456A53426A5241705544795C498263508C6A55926E579771589B72579F7457A57758AB7B5C\
B17F60B68364B88668B8896CB68A6FB48B71B28C73B18D73B28D74B38E75B68E75
B98E75BB8E75BB8C73B88970B1846CA77E659C755D8E6A54815E497653406D4A38684433694231\
6E4533774B3985554196634EA8745EBA8872C99E89D5B3A1DEC7B9E3D8CDE6E3DA
E7E8E1E6E9E3E5E8E1E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E2DAE4E4DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7CFE5E5DDE9EBE2E9EBE3E6E8E0E4E5DDE2E3DBE2E1D9E2E0D8E2E0D8E2E1D9E2E2DAE2E3DB\
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E3DC
E2E4DCE2E4DDE2E4DCE1E3DBDFE0D9DCDCD5D6D6CECCCAC2BCB7AFA69C948C7C74745E5666483E\
6540357246388655439C6853AE7861B8836ABB886FB7866EAC7F689D725E8A6251
76524462433A503731402E2B3426262B2021281D1D2C201D382A234F3D326E594A907864B0967E\
C9AD92D7BB9EDEC1A4DFC2A5DEC1A5DEC1A5DEC1A6DFC1A6DFC0A6DDBEA3DBBAA0
D9B79DD7B59AD6B399D6B499D7B69BD8B89EDBBCA3DDBFA8DFC2ACE1C4AFE1C5AFE0C4AEDFC3AB\
DDC0A7DCBDA3DAB89FD8B39AD5AE95D2A990CDA48BC99F87C59B82C1977FBF957C
BC9279BA8F75B68B70B2866BAF8265AB7E61AA7C5EA97B5DAA7C5EAC7E60B08364B58969BB8F6F\
C19575C6997ACB9D7FCFA083D2A387D4A68BD6AB90D8B095DAB59BDCBBA2DDC1A9
DFC6B0E0CBB6E2CEBAE2CFBCE2CFBCE2CEBAE1CAB6DFC6B0DDC0A9DBBAA2D7B39AD4AC93D0A58B\
CB9E84C7977CC39174BF8B6DBB8667B78263B38060AF7D5FAB7A5DA7765AA47155
A16D529F6A509E6A529D6D579C715E9B75649978689476678B71627E66596D584C57463D43352E\
3327222C1F1C31201B3E28204F33285E3F3268493A6D51416D55456A5545645142
5F4C3D5C48395C4738634A3B6D5141785A4883624E8B6751916B52966D529B7053A27455AA7959\
B17E5EB68263B88667B8896BB78A6EB48B71B38C72B28D73B28D74B48E74B68F75
B98F75BB8E74BA8C72B5876EAC8168A07860936E5885634E7858446D4E3B65453461402F623E2E\
6740307046357F503D915E49A47059B7846DC79A85D4B19EDDC5B7E3D6CBE5E1D9
E6E7E0E6E8E2E4E7E1E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7CFE5E5DDE9EAE2E9EBE2E6E8E0E4E6DEE2E3DBE2E2DAE2E1D9E2E1D9E2E1D9E2E2DAE2E3DB\
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E4DC
E3E4DDE3E5DEE3E5DDE1E3DBDDDDD6D5D4CCC9C6BEBAB3ABA69B948E7F7876625A61484055352C\
542F245E33266F3F30824F3D935E4A9F6B55A4725CA3745E9B6F5B8D65547C584A
69493F573C3547322E3A2A28302424291F1F271D1C2C201C392A24503E336F594A917865B1967E\
C9AD92D7BA9EDDC0A3DEC2A5DEC1A5DEC1A6DEC2A7DFC1A7DEBFA6DCBBA2DAB59D
D6B098D4AC93D2AB91D2AB91D3AE94D5B298D8B79EDBBCA4DEC1AAE0C4AFE1C6B1E1C7B1E0C6AF\
DFC4ADDEC1A9DCBDA5DBB9A0D9B49CD6AF97D4AB93D1A78FCEA38BCCA087CA9D84
C89A81C5987DC29479BF9174BB8D70B88A6CB68769B58667B68667B78769BA8B6CBE9070C29675\
C79B7ACB9F7FCFA183D1A386D4A68AD6A88DD7AC91D9B096DAB59BDBBBA1DDC0A8
DFC6AFE0CAB5E1CDB9E2CFBBE2CFBBE2CDB9E1C9B5DFC4AFDDBEA8DBB8A1D7B29AD4AC93D0A68C\
CBA085C7997EC39376BF8D6FBB8869B88564B48262B18160AD7F5FAB7C5DA9785A
A87558A77357A67359A6765EA57964A37D69A17E6C9C7C6B937666866B5C725B4F5B483E43342E\
302421261B192A1B1836221C462D2356392D604335654A3C654E40624E405C4A3D
5645395341355440335B4436664C3C7254437F5D4988634D8F684F956B519C6F53A37456AB7A5A\
B2805FB78464B98868B98A6CB88B6EB68B70B38B72B28C73B28D73B48E74B78F75
BA9075BB8F74B98C71B2866BA77D6499725B8A66517B5A486F503E6547365F41305B3D2C5C3B2B\
613D2C6B42307A4B388C5843A06953B47E67C5947FD2AC99DBC1B2E1D3C8E4E0D7
E5E6DFE5E8E2E4E7E1E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7CFE5E5DDE9EAE2E9EAE2E6E9E0E4E6DEE2E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DBE2E3DB\
E2E3DBE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E4DC
E3E5DDE4E6DFE4E6DFE1E3DBDADAD2CDCAC3BBB4ADA59A938E7E7777635B624B4352382F492B22\
48251B4F271B5A2E2169382A77453583513F8A5A478B5F4C865D4C7A55476B4A40
5A3E384A33303D2B293326242C2120281E1C281D1A2E211C3B2B24523F34715A4B927965B1967F\
C9AD92D7BA9EDDC0A3DEC1A5DEC1A5DEC1A6DFC2A8DFC1A8DEBEA6DCB8A1D8B19A
D4AA93D1A58DCFA38ACEA38ACFA78DD1AB92D5B198D8B8A0DCBDA7DFC2ADE0C5B0E0C7B1E0C7B1\
DFC6AFDEC3ACDDC0A9DCBCA5DAB8A1D8B39DD6AF98D4AB94D2A690D0A38BCD9F87
CB9C83C8997FC6977BC39578C19276BF9073BD8E71BD8D6FBD8C6EBE8D6FC09071C39474C79978\
CA9D7DCDA181D0A485D3A688D5A88CD7AA8FD8AD92D9B196DAB69BDBBBA1DDC0A8
DFC5AFE0CAB5E1CDB9E2CEBBE2CEBBE2CCB8E1C8B4DFC3AEDDBDA8DAB6A1D7B19AD4AB94D0A68E\
CBA187C79C80C39578BF8F71BC8A6AB88766B58563B28462B08361AE8160AD7E5E
AD7C5CAE7A5CAE7B5EAE7D63AE8169AD846EAB8570A7836F9F7D6A9272617F6253654E434B3A33\
3629252A1F1C2B1D1935221C432B2252362A5B3F3260453861493C5E493D59463B
534237503F34523F32594335644A3A7253417F5B4789624C91684F986C529F7155A67759AD7D5E\
B48363B88867BB8A6BBB8B6DB98B6FB78B70B58B71B38B72B38C73B58E74B79075
BA9175BB9074B78C70AE8469A17860906B56805D4B7151416648395D4132583C2D563929573828\
5D3929673E2C75463388523D9C624BB0755FC18C77CFA592D9BCADDFD0C5E3DED5
E4E5DEE4E8E1E4E7E1E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DCE2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DB
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7CFE5E4DCE9EAE2E9EAE2E6E8E0E4E6DEE2E4DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DCE2E3DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE2E4DD
E4E5DEE5E7E0E5E7E0E1E2DBD7D6CFC6C1BAAEA49D93847C78655D624B43523930482D2443251C\
4221184520164B221754271B5E3022693A2C714434744A3B704B3D67453B593D36
4A33303D2B293425242D2120291F1C281D19291D1830211B3F2C24553F34735B4C947966B2967F\
CAAD92D7BA9DDEC0A3DFC1A4DEC1A5DEC1A7DEC1A8DFC0A9DEBDA6DBB6A0D7AE99
D3A691CFA08ACD9D86CC9E86CCA188CEA68CD1AB92D4B19AD8B7A1DBBCA7DCC0ABDDC2ADDDC3AD\
DCC3ADDCC1ABDBBFA9DABCA6D8B8A2D7B49ED5AF99D2AA94CFA58FCCA08AC99B84
C7987FC4957BC29378C09277BF9176BE9175BE8F74BE8E72BE8E71BF8E71C19072C39375C69778\
C99C7CCC9F80CFA384D2A689D5A88DD6AB90D8AF94D9B297DAB69CDBBBA1DDC0A8
DFC5AEE0C9B4E1CCB8E2CEBAE2CEBAE2CBB7E1C7B3DFC2ADDDBBA7DAB5A0D7B09AD4AB94D0A78F\
CBA389C79E82C3977BBF9173BC8C6CB98967B68765B38763B28662B18561B18360
B2815FB38060B48162B58467B5876CB58A71B48C74B28A73AC846EA07A668E6B5A75594B5B453C\
45342E3729253626213C292148302554382B5C3F3261443762473B5F483C5B453B
5642385440355541355D4537684C3C765542835D488E654D966B519E7055A47659AB7C5EB18263\
B68768BA8C6BBC8D6EBC8D6FBB8C6FB98B6FB78B70B58B71B58D73B68F74B89176
BB9376BA9174B68C6FAB82679B745C89645077554568493B5D4133563B2D533829523627543626\
593726633A2971412E844B36985943AC6D56BE846FCC9E8BD6B7A8DDCDC1E1DCD3
E3E4DDE4E7E1E3E7E0E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7CFE5E4DCE9EAE1E9EAE2E6E8E0E4E6DEE2E5DDE2E4DCE2E4DCE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DEE6E8E0E5E8E0E1E2DBD5D4CCC0BAB3A4989185746C69534A553B32482D2442261D40241A\
402118401E15421C13461D134D2217562B1F5D3427603A2D5D3C3154383048312D
3C29283223232C1F1F291E1C281D19291D172C1D1734221B422D24584034755B4C967966B3967E\
CAAC92D8B99DDEBFA2DFC1A4DFC1A5DEC1A6DEC1A8DEC0A8DDBCA6DAB6A0D7AE99
D3A692D0A08BCD9D87CB9D85CA9E85CBA188CDA58CCFAA91D1AE97D3B29CD5B6A0D6B8A3D6BAA4\
D6BBA5D6BAA4D5B9A3D4B6A0D2B29DD0AE99CDA994CAA38FC69D89C29782BF927C
BC8D77B98A73B78970B78970B68A70B78A70B78A70B88A6FB9896FBA8A6EBC8B6FBE8D70C19172\
C49576C7997BCB9E80CFA386D2A78CD5AC90D7AF94D8B398DAB79DDBBBA2DDC0A8
DFC5AEE0C9B3E1CBB7E2CDB8E2CDB8E2CAB5E1C6B1DFC1ABDDBAA5DAB49FD7AF99D4AB95D0A890\
CBA48BC79F84C3997DBF9375BC8D6EB98A69B78866B58864B48863B48863B48762
B58662B68563B78665B9896ABB8C6FBC8F73BC9176BB9076B68B72AC826B9D76618765556F5448\
5B453C4D3B334A362E4D372D553B2F5E403264453668493A684A3D664A3E62483C
5E463A5D45395F4639664B3B7152407E5A458A624B956A509E7055A57559AA7B5DB08062B48667\
B88B6BBA8E6EBC8F70BC8F70BB8D70BA8C70B98C70B78C72B78E73B89075BA9276
BB9376BA9274B48C6FA78065967059825F4C6F4F40604335563B2E5036294E34264E3325503324\
5634246037266E3C2980453195523DA8654FBA7C68C99785D4B2A4DBCABFE0DAD2
E3E4DDE3E7E1E3E7E0E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DC\
E2E3DBE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E5DDE9EAE1E9EAE2E6E8E0E4E6DEE2E5DDE2E4DCE2E4DCE2E4DCE2E3DCE2E3DCE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DFE6E8E1E6E8E0E0E1DAD3D2CABCB6AE9E928A7E6B636249414E322943271D402419402419\
4023183F20153F1C13401B11441D144A24194F2B205130254D3128452D273B2725
3121212A1D1E271B1B271B19291C182C1D17301E1737231B452D245B4034775B4B977965B4957E\
CBAB91D9B99CDFBFA2E0C0A4DFC0A4DFC0A5DEC0A6DEBFA6DCBCA5DBB7A1D8B19C
D5AA96D2A590CFA28CCCA088CA9F86C9A086C8A087C8A188C9A38BCAA58ECBA891CCAB94CDAD96\
CDAE98CCAF98CBAE97CAAB95C7A892C4A38EC09D89BC9784B8917EB48A77B08571
AC806BAA7D67A97C65A97C64A97E65AB7F66AC8066AE8067B08066B18166B38166B58367B78669\
BB8A6DBF9073C4977ACA9E82CFA58AD3AB90D5B095D8B499D9B89EDBBCA3DDC0A8
DFC4AEE0C8B2E1CAB5E2CBB6E2CBB6E1C9B3E0C5AFDFBFA9DDB9A3DAB39DD7AF98D4AB94CFA890\
CBA58BC7A085C39A7EBF9376BC8E6FB98A6AB78866B68764B68863B58863B58862
B68863B78964B98A67BB8D6BBD9070BF9374C09477C09377BD9075B58970A9806998735F856655\
755A4C695144654C40664B3D6A4D3D6F4F3E72503F7451417351417150416D4E40
6A4C3E6A4C3D6D4E3E7453427E5A4689624C956A519E7056A6765AAC7B5DB08061B48565B68969\
B88D6DBA8F70BB9071BC9072BC8F71BC8E71BB8E71BA8E73BA9074BA9176BB9377
BB9477B99175B18A6EA37E64916D577C5B48694B3B5A3E3150362A4B32264A30244A30234D3022\
5432225E34246C39267E412C924D37A55F49B77662C69280D2AEA0DAC7BCDFD9D1
E2E3DCE3E7E1E3E7E0E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DB\
E2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE2E9EAE2E6E8E0E4E6DEE2E5DDE2E4DCE2E4DCE2E4DCE2E3DCE2E3DCE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DFE6E8E1E5E8E0E0E1DAD2D0C9BBB4AD9C8F877C68605F463E4C302642261B402418412519\
4125194023183F1F153F1D14401E1543221946271D462A21422A223A272131211F
291C1B241919241918271A172B1C172F1E17331F183B241B482E255C4035785A4B977865B5947D\
CBAA90D9B89BE0BEA1E1C0A3E0BFA3DFBFA4DEBFA4DDBEA5DCBCA4DBB9A3DAB6A0
D8B19CD6AD98D3A993CFA68FCCA38AC8A086C59D83C39A81C19980C19880C19A82C29C85C39E87\
C3A089C2A189C0A088BE9E86BB9A83B79580B2907CAE8A77A98371A57D6BA07765
9D725F9B6F5B9A6E599A6F589B71599D725A9F745BA2755CA4755CA7765CA8765CAB775DAD7A5F\
B17F63B7866ABD8F73C4997ECBA387D0AA8FD4B195D7B69BD9BA9FDBBDA4DDC1A9
DFC4ADE0C7B1E1C8B3E2C9B4E2C9B3E1C7B0E0C3ACDFBEA6DDB8A1DAB39CD7AF97D3AB93CFA88F\
CBA58BC7A086C39A7FBF9377BB8D70B9896BB78666B68564B68562B58561B58661
B58762B68964B88C67BA8E6BBD916FBF9473C19576C29577C09377BB8F74B38870A8806A9B7763\
906F5D87685783645382625083614E84604C845F4B835D49815B487E58467B5644
7955437955437D5845835D498C644E966B54A07259A8785CAE7D5FB38161B68564B78867B88B6B\
B88E6FB88F71B99072BB9173BC9072BD9072BD9073BD9174BC9276BC9377BD9478
BC9478B79175AE896E9F7C628C6B54775845644738553A2D4B3227462E23462D22472E214C2F22\
5331225D34236C38267D3F2A904A34A35B45B4725EC48F7DD0AC9ED9C6BBDFD9D0
E2E3DCE4E7E1E3E7E1E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DB\
E2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE2E9EAE2E6E8E0E4E6DEE2E4DCE2E4DCE2E4DCE2E4DCE2E3DCE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DFE6E8E1E5E7E0E0E1D9D2D0C9BBB4AC9D8F877C696060473E4D312743271B412518412619\
42271A41261A4023183F21173F211840231A40261D3E271F39261F32221D2B1D1A
241917221716231816281A162D1D17321F183621193D251D4A2F265E4135795A4B987764B5937C\
CBA98ED9B69AE0BDA0E2BFA2E1BFA2DFBEA2DEBEA3DDBEA3DCBDA4DCBCA4DCBBA4
DBB9A3DAB6A1D7B29CD3AE96CEA990C9A389C49D83C0977DBC9279BA8F76BA8F76BA9078BA927A\
BA937BB8937BB6927AB29079AE8D76AA8873A6836FA17E6B9D7866997260956C5B
9168558F65528E644F8F644F90664F926850956A51986B529B6C529D6C539F6D53A26E54A57056\
AA765BB07E64B88A6FC1967BC8A186CFAB90D3B297D7B79CD9BBA1DCBFA5DEC1AA
DFC4ADE1C5B0E2C7B2E2C7B2E2C6B0E1C4ADE0C1A9DFBCA4DDB79FDAB39AD7AF96D3AC92CFA98F\
CBA58BC7A086C29A7FBE9378BB8C71B8866BB68265B58061B47F5FB3805DB2815D
B1835EB28661B48A64B78D68BA916DBE9371C09575C29677C19678BF9377BA9075B48C72AE876F\
A7826BA27E689E7A649C77619A745E99715B976E57946A539066508D624D8A604B
895F4A89604B8D634D9268519A6E56A2755CAA7B60B08063B58464B88765B98967B98B69B98C6C\
B88E70B78F72B89073BA9174BB9173BD9273BE9274BE9375BE9477BE9478BE9579
BB9378B68F74AB876C9B79618767527155425E44344F372A452F23412B20412A20452C214B2F22\
5432246036266E3A277F402B904A34A25943B2705CC28D7BCFAB9DD9C6BBE0D9D1
E3E4DDE4E8E1E4E7E1E3E6DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE2E9EAE1E6E8E0E4E5DDE2E4DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DFE6E8E1E5E7E0E0E1D9D2D0C9BCB5AD9E90887E6A6162493F4F332844271B402417402618\
41271A40261A3F251A3E241A3D231B3C241C3B251D38251E34231D2E201B281C18
231815221714241815291B162E1D1833201937221A3F271F4B31285F43377A5B4C987764B4927A\
CAA78DD9B498E0BB9EE2BEA1E1BEA1E0BEA1DEBEA2DDBEA3DDBEA4DDBFA6DEBFA8
DEBFA9DDBDA7DABAA4D6B59ED2AF97CCA88FC6A086C1997FBC9278B98D73B78B71B68A71B68A72\
B48A72B18972AD8870A9856FA5826DA17F6A9E7B679A7764977260946C5B906756
8D63518B604D8A5F4B8A604A8C614A8E634B90644B93654C95664D98674D9B674E9E694FA26C53\
A77259AE7C62B7886EC0967BC8A287CFAC91D4B499D7B99FDABDA3DCC0A7DEC2AB
E0C4AEE1C5B0E2C5B0E2C4B0E2C3ADE1C1AAE0BEA6DFBAA2DDB69DDAB299D7AF95D3AC92CFA98F\
CBA58BC7A086C29980BE9279BA8A72B7836AB47E64B17A5EAF785AAD7757AB7857
AB7B58AB7F5BAE845FB18864B68D69BB916EBE9572C19776C29778C29779C09679BE9478BB9277\
B99076B68E73B38B71B1876EAE846BAB8067A77B62A3765D9F72599B6E55986B53
976A52976B539A6E559F7259A5775EAC7D63B28366B78768BA8969BB8B69BB8C6ABA8D6CB98D6E\
B88E71B78E73B88F74B99075BB9274BC9374BE9475BF9476BF9577BF9578BE9578
BA9276B38D72A7846A96755E81644F6B513F5740304833263E2B203B281E3D281E432C214D3125\
593728673C2B75402D83442F924C36A15A44B16F5BC08C7BCEAA9DD9C6BBE0DAD2
E4E5DEE5E9E2E4E8E1E3E6DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E7DFE4E5DDE2E4DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DEE6E8E0E5E7E0E0E1D9D3D1C9BCB5AD9F9289806C62644B4050332844271A3F23163D2316\
3D24183C25193B241A39241A38241B37241C36241C34231C30211B2C1E19271B16
241914231814251914291B162D1E1731201937231C3F29214C342A6045397A5D4D977764B29079\
C9A58AD7B296DFB99DE2BDA0E2BEA1E1BEA1DFBEA2DEBFA3DEC0A5DFC1A8DFC2AA
E0C2ACDFC1ACDDBFA9DABAA4D6B59ED1AE96CBA78EC6A086C1997EBD9378BA8E75B88B72B68971\
B3866FAE846EA9826CA37F6B9F7D699D7A689B78669B7563997260976E5C946957
9165528F624F8E624C8E624C8F634C90654C92664D93664D96664D98674D9B684E9F6A51A46E55\
AA765CB28066BA8C72C29A7FCAA68BD0B095D5B79CD9BCA2DBBFA6DDC1AADFC3AD
E0C4AFE1C4B0E2C3B0E2C2AEE2C0ABE1BDA8E0BAA4DFB8A0DDB59CDAB299D7B096D3AD92CFAA8F\
CBA68BC7A087C39981BE917ABA8873B5806AB17962AC735AA86F54A46D50A26D4F
A2704FA37452A67A57AB815DB08763B68E69BB936FBF9673C19877C29979C3997AC3997BC3987B\
C2987AC19679C09478BD9176BB8E73B78A6FB4866BAF8166AB7D62A7795EA4775C
A3755BA3765CA5785EA97B61AE8065B38569B8896BBB8C6DBC8D6DBC8E6DBB8E6DBA8E6EB98E71\
B98E73B88E75B88F75B99075BA9175BB9275BD9475BE9476BF9576BF9577BD9476
B99174B08A6FA3806690715A7A5F4B634C3B4F3B2D3F2E2236271C34241B39261D432D22513529\
613E2F7145337F49348B4C3596503AA25B45AF6F5BBE8B7ACCAA9CD8C6BCE0DBD2
E4E5DFE5E9E2E4E8E1E3E5DFE2E4DDE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E7DFE4E5DDE2E4DCE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DEE6E8E0E5E7E0E0E1D9D3D1C9BDB6AEA1938A826E63664C405034274326193C2013391F13\
38201536211635221833221933221A32221A31221A30211A2E20192B1E17281B15
261A14251914261A14281B152B1E172F201935241D3E2B234C362D60483C7A5E4F967763B08F77\
C6A288D4AF93DDB79AE0BB9EE1BDA0E1BEA1E0BFA2E0C0A4DFC1A6E0C3A9E0C4AB
E1C4ADE0C3AEDFC2ACDDBFA9DABAA4D6B59ED1B097CDAA90C8A389C49D83C1977EBE9279BA8D75\
B58872AF8470A8816EA27E6C9F7D6B9E7C6B9F7B6AA17A69A27866A175639E715E
9C6E5A996B56986B54976B54986C54996D54996D549A6D539B6C539D6C53A16E55A57158AB775D\
B17E65B9896FC0947AC7A085CEAB90D3B499D7BAA0DABEA5DDC1A9DEC3ACE0C4AE
E1C4B0E1C4B0E2C2AFE2BFADE2BCAAE1BAA6E0B7A3DFB5A0DDB49CDAB399D7B196D3AE93CFAB90\
CBA68CC7A087C39982BF907CBA8774B47E6BAE7561A76E58A168509C644A996347
98644799684A9D6F4FA27755A97F5CB08763B58E6ABA936FBD9573C09776C19878C39879C4997A\
C5997AC5997AC5987AC49679C29477C09175BD8D71B98A6DB5876AB28466AE8165
AC8064AB8065AD8166B08468B4876BB88B6DBB8D6FBC8F70BC9070BB8F6FBA8E70B98E71B98D73\
B98D74B98D76B98E76B98F76B99075B99175BB9375BD9475BE9476BE9475BC9274
B68E71AC866B9D7B62896B557259465B4736463629372A1F2F23192E211935261D432F24553B2D\
6947367C4F3C8A533D93543C9B563EA25D47AC6F5ABA8978C8A799D5C3B9DED8D0
E2E3DCE4E7E1E3E6E0E2E5DEE2E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E7DFE4E5DDE2E3DBE2E2DBE2E2DBE2E2DBE2E2DBE2E3DBE2E3DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DCE3E4DD
E4E6DEE6E8E0E5E7E0E0E1D9D4D1C9BEB7AEA2958A847064684E415134274325183A1E11351B10\
321C11301D132F1E152E1F172D20182D20182D20182C1F182B1E172A1D16281B15
271A14261A13261A14271B14291D162C201933251E3D2D254C392F604A3E795F50947663AD8D75\
C29F85D1AC90DAB598DFB99CE0BC9FE1BEA1E1C0A3E1C1A5E0C2A7E1C3A9E1C4AC
E1C4AEE1C4AFE0C3AEDFC2ADDDBFAADBBCA6D8B9A1D4B59CD1B096CDAA90CAA38AC69C84C1957E\
BB8F7AB38A77AC8675A68373A38273A48373A78373AB8473AE8371AE816EAC7E6A
AA7B66A77963A57961A57961A57A61A57B62A57A61A47960A5785EA6775EAA7960AF7D64B58369\
BB8B71C29479C89E83CDA88DD2B196D6B89EDABDA4DCC1A9DEC3ACDFC4AEE0C5B0
E1C5B0E1C3AFE1C1AEE1BEABE1BAA8E1B7A5E0B5A2DEB49FDCB49DDAB39AD7B297D3B094D0AC91\
CCA78DC8A189C49A84C0917EBB8877B57F6DAD7563A46C589D644E965E46925B42
905B41915E42946347996C4D9F7554A67E5CAC8662B18B68B58E6CB8906FBA9171BD9373BF9475\
C19576C39677C49778C59779C59679C59578C39376C09173BD8F70BA8D6EB68B6C
B4896CB2896CB2896DB48B6EB78D70BA8F71BC9172BC9172BB9172B99072B88E72B88D72B88D74\
B98C75B98C76B98D76B88D76B88E75B89075BA9175BC9375BD9375BD9273BA9071
B28A6DA7816697755C82654F6A53405341323E312530251C28201829201833261D4432265A4032\
724E3C865943945C459B5B429F5A41A25E47A96C58B48473C1A092CDBCB1D7D0C8
DDDDD6E0E2DCE1E3DDE1E3DCE1E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E3DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E7DFE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DB\
E2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE3E4DD
E4E6DEE5E8E0E5E7E0E0E1D9D4D2CABFB8AFA4968B8672656A5042533527432517391C1033180E\
2F180F2D1A112B1B132A1D14291E16291E162A1E162A1D16291C15281B14271A13
261913251912241913251A14271C162B201932261E3C2E264B3B315F4B3F785F50917562AA8A73\
BE9B82CDA88DD7B195DCB79ADFBB9EE1BEA1E1C0A3E1C2A5E1C3A8E1C4AAE1C4AC
E1C4AEE1C4AFE1C4B0E0C4B0E0C3AEDEC2ACDDC0AADBBEA6D8BBA2D5B69CD2AF96CDA790C8A08A\
C29985BB9382B4907FAE8E7EAC8D7EAE8E7FB28F80B79180BB917FBC907CBB8E79
B88C76B68A73B48A72B48A72B38B72B38B72B28A71B18870B1876EB2866EB5886FBA8C72BF9177\
C5987ECAA085CFA88CD3AF94D6B69BD9BCA2DBC0A7DEC3ACDFC4AFE0C5B0E0C5B1
E0C5B0E0C3AEE0C0ACE0BCA9E0B9A7E0B6A4DFB4A1DEB49FDCB49DDAB49BD7B398D4B195D0AD92\
CDA88ECAA38AC69C86C39581BE8C7AB78372AF7967A66F5C9D6651955F488F5942
8C563F8B563F8C5A418F614694694C9972529E7A58A27E5DA68261A98464AC8666B08869B58B6C\
B98E6FBD9172C19375C49578C6967AC7977AC69779C59678C29576BF9474BC9272
BA9072B88F72B78F72B89073BA9173BB9273BC9273BB9273BA9173B88F73B78D73B68C73B68B73\
B78A74B88A75B78B75B78B75B78D75B78E75B99075BC9275BD9274BB9072B78C6E
AE8568A07A5F8F6D55795D48624B3A4C3A2D392C222B231A251F1728201933281F4635295E4535\
7854418D5E489B6249A05F46A15C43A05E46A36853AA7B6AB49486C0ADA2CAC2B9
D2D0C9D8D9D3DCDED8DFE1DAE1E3DCE2E3DCE2E3DCE2E3DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DCE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE1E9E9E1E6E7DFE4E4DCE2E2DAE2E1D9E2E0D9E2E1D9E2E1D9E2E2DAE2E2DA\
E2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE1E3DBE2E3DBE3E4DC
E4E6DEE5E7E0E5E7E0E0E1D9D4D2CAC0B9AFA6988C8874666C5243553729452518391B0F33170D\
2E160D2B170F291911281B13281D15281D15281D15271C15261B14251913231812
221611211611211711231912261C152B201932261F3C2F274B3B325F4B3F765E4F8E735FA68670\
BA977EC9A489D3AE92DAB598DEB99DE0BDA0E1C0A3E1C2A6E2C3A8E2C4AAE1C4AC
E1C4AEE1C5AFE1C5B1E1C6B2E1C6B2E1C6B1E0C6B0DFC5AEDDC2AADBBEA6D8B9A1D4B29CD0AB96\
CAA592C4A18FBE9E8DBA9C8CB99C8CBA9D8DBE9E8EC3A08EC6A18EC8A08CC79F8A
C69D87C49C85C29C84C29C84C19C84C19C84C09B84BF9A82BE9981BF9880C19981C59C83CAA086\
CEA58AD2AA8FD4B094D7B599D9BA9FDBBEA4DDC2A9DEC4AEE0C6B0E0C6B1E0C6B1
E0C4AFDFC2ADDFBFAADEBCA7DEB9A5DEB6A3DEB5A1DDB59FDBB59DDAB49BD7B398D4B196D1AE93\
CEAA90CCA58DC9A089C69A85C29380BC8B78B4826EAC7864A26F599A654F925D48
8C574288543F86543F865841885E458B65498D6A4D906E50927053957356997559A0795CA77E61\
AE8366B6896BBC8E70C19275C59579C7977BC7987BC6997AC59878C29777C09675
BE9575BC9475BB9375BA9375BA9375BB9375BB9274BA9174B99073B78E72B68C72B58A71B48971\
B48871B48872B48873B58974B68B75B88D76BB8F76BD9176BD9074BA8D70B3886A
A87E6298725885644D7054405A433346352835291F2A221A261F1829221B352B2149382B614737\
7B5642905F489D6349A16046A05C429D5B439C614B9E6E5DA48273AC988DB7ADA4
C2BFB7CDCDC6D6D8D1DDDFD8E1E3DCE3E4DDE3E4DDE3E4DCE2E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E1D9E2E0D8E2DFD7E2DFD8E2E0D8E2E1D9E2E2DA\
E2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE1E3DBE1E3DBE2E3DBE3E4DC
E4E5DEE5E7E0E5E7E0E0E1D9D5D2CAC1BAB0A79A8E8A76686F5446583A2B47271A3B1C1034170D\
2F160D2C170E2A1911291B13281C14281D15271D15261C14241A132117111F1510
1D130F1D130E1E140F211711251B142B201933271F3D30274B3B325E4B3F745D4D8B705DA2836C\
B6937AC5A085D0AB8ED7B295DCB89BDFBC9FE0BFA3E1C2A5E2C3A8E2C4AAE2C4AC
E2C4AEE2C5B0E2C6B1E2C7B3E2C8B4E2C9B4E1C9B4E1C8B2E0C7B0DEC4AEDCC0AAD9BCA6D6B7A2\
D2B29FCEAF9DCAAD9CC7AC9BC6AC9BC7AC9CCAAE9CCEAF9DD0B09CD2AF9BD1AF9A
D0AE98CFAD97CEAD96CEAD96CDAD96CDAD96CCAC96CBAB95CBAA94CBAA93CDAA93CFAC93D2AE94\
D5B196D7B498D8B79BD9BA9EDABDA1DCC0A6DDC3ABDFC5AFE0C7B1E0C7B2E0C6B0
DFC4AEDEC1ABDDBFA8DDBCA5DDBAA3DDB8A2DCB7A0DCB69FDBB59DD9B59BD7B499D5B196D2AF94\
D0AB91CEA88FCCA48DCAA08AC69A85C2947FBC8D78B4846EAC7B65A2715B996652
905D4A8956458453418053407F55407E59427E5C437D5E447E5F4680614785644B8D694F977055\
A2775CAC7F63B5866ABB8C70C09175C39578C49779C49879C39878C19776C09675
BE9575BD9475BB9475BA9375B99274B89174B79073B78F72B68D72B68B71B48970B3876FB1866E\
B0856EB0856EB18670B38872B68A74BA8C76BD8F77BF9077BE8F74B98B6FB08367
A1775D9069517C5A45674A38533C2D41302434261D2B221A28211A2D251D382E244B3A2D624737\
7A54408D5C459A5F469E5C429D583E98553D94574291604E926E5F978074A2958C
B1ABA3C1BFB8D0D0C9DBDCD5E1E3DCE4E5DEE4E5DEE3E4DDE2E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E6DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D9E2DFD7E2DED7E2DFD7E2DFD8E2E1D9E2E2DA\
E2E2DBE2E3DBE2E3DBE2E3DBE2E3DBE2E3DBE1E3DBE1E3DBE1E3DBE2E3DBE2E4DC
E4E5DEE5E7E0E5E7DFE0E1D9D5D3CAC2BBB1A89B8F8B786A705748593C2E48291C3D1E1235190E\
31170E2E170F2C19112A1B13291C14281D15271D15251C142219121E16101B130E
19100D19100C1C120D201510251A142C201934271F3E30274C3B315D4A3E725B4B896D5A9F7F69\
B28F76C29D82CDA78BD5B093DAB699DEBB9EE0BFA2E1C1A5E1C3A8E2C4AAE2C4AC
E2C4AEE2C5B0E2C6B2E2C7B3E2C9B5E2CAB5E2CBB6E1CBB5E1CAB4E0C8B3DFC6B1DDC4AFDBC1AD\
D9BEABD7BDAAD4BBA9D3BBA9D3BBA9D3BBA9D5BCAAD7BCAAD8BDA9D9BDA9D9BCA8
D9BCA7D8BCA6D7BBA6D7BBA6D7BCA6D6BBA6D6BBA6D5BBA5D5BAA5D6B9A4D6B9A2D8B9A1D9BAA1\
DBBBA0DBBBA0DBBCA0DBBDA1DBBEA3DCC1A7DDC3ABDFC6AFE0C7B1E0C7B1DFC6AF
DEC4ACDDC1A9DCBEA6DBBCA3DBBBA2DBB9A1DBB8A0DBB79EDAB69CD9B59AD8B398D6B196D4AF94\
D2AD93D0AB91CFA990CDA68ECBA38BC89E87C49981BE927AB68971AD7E68A3735F
9867568E5D4E8657488053437B524177523F74523E71523C6F513C70523D74553F7D5B4488624B\
956B52A0745AAA7C62B18369B6896FBA8D72BC9074BD9274BC9273BC9272BB9272
BA9271B99171B89172B69072B58F71B38D71B28C70B28A6FB2886EB2866CB2856BB0846AAE836A\
AD826AAC836BAF846EB28771B78974BC8C77BF8E78C18F77BF8D74B8886EAC7E64
9B705887614B72503D5E41314C35273D2B2033251C2D221A2C231C3028203B30264C3A2E604536\
754F3C87553F92573F97553C965239914E378A4D3884513F805A4C836A5E8E7F75
A09991B6B3ABCAC9C2D9DAD3E1E3DCE5E6DFE5E6DFE3E4DDE2E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E6DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D8E2DFD7E2DED6E2DED7E2DFD8E2E0D9E2E1DA\
E2E2DAE2E3DBE2E3DBE2E3DBE2E2DBE1E2DBE1E2DBE1E2DBE1E2DBE2E3DBE2E4DC
E4E5DEE5E7E0E5E7DFE0E1D9D5D3CBC1BBB2A89C908C796C70584B5A3E30492C1F3E2115371B11\
3319103019112E1A122C1C132B1D152A1D15281D15251C142119121D151019120D
170F0B170F0B1A110C1F140F261A132D201835271F3F30274C3B315D483C71594A876A589D7C66\
B08C73BF9A7FCBA589D3AE91D9B598DDBA9DDFBEA1E1C1A5E1C3A7E2C4AAE2C4AC
E2C4AEE1C5B0E1C6B2E1C8B4E2C9B5E2CBB6E2CBB7E1CBB7E1CBB6E1CBB6E0CAB6E0C9B5DFC9B5\
DEC8B5DDC7B5DCC7B4DCC7B4DCC6B4DCC7B4DCC7B4DDC7B4DEC7B4DEC7B3DEC6B3
DEC6B2DEC6B2DEC6B2DDC6B2DDC6B2DDC6B2DDC6B2DDC6B2DDC6B1DDC5B0DDC4AEDEC4ACDEC3AA\
DEC2A8DEC1A6DDC0A5DDC0A4DCC0A5DDC1A7DEC4AADFC6AEE0C7B0E0C7B0DFC6AE
DEC3ABDDC1A7DCBFA4DBBDA2DABBA1DABAA0DAB99EDAB79DDAB69BD9B499D8B398D6B196D5B095\
D4AF94D3AE93D2AD93D1AB92D0AA90CEA78ECBA38AC79D84C1957EB88B75AE806C
A2746397695A8D6052865A4C7F564779534373513F6E4E3C694C39684B386A4C3972513D7C5742\
875F499267509B6F58A1765EA77C64AA8168AD846AAF866BB1886BB1886BB2896B
B18A6BB18A6CB08A6CAE896CAC886CAB866BAA846AAA8268AB8167AC8066AD7F65AC7F65AB7F66\
AA8068AB826AAE846DB38771B98A74BE8C77C18E78C28E77BF8C73B7856CA87961
956A547F5945694837553A2B462F223A271D32231A2E221B2E241D3329223D30274B382D5B4032\
6D47367C4B37864D378C4B348C483188452F80442F784533734B3D74594D806F65
958B83ADA9A2C5C4BDD7D8D1E1E3DCE5E7E0E5E6DFE4E5DEE2E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9EAE2E9E9E1E6E6DEE4E3DBE2E0D9E2DFD7E2DFD7E2DFD7E2E0D8E2E1D9E2E2DA\
E2E2DAE2E2DBE2E2DBE2E2DBE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE2E3DBE2E4DC
E4E5DEE5E7E0E5E6DFE0E1D9D5D3CBC1BBB2A79C918A7A6E6F5A4D594033492F223F2419381F15\
341D13311C132F1C142E1C142C1D152B1D15291D15261C142219121D161019120D
17100B170F0B1A110C20150F261A132E201835271F3F2F274C3A305C483C7057488669569B7A64\
AF8A71BE987DCAA387D3AD90D9B497DDBA9DDFBEA1E0C1A5E1C3A7E1C3AAE2C4AC
E1C4AEE1C5B0E1C6B2E1C8B4E1CAB5E1CBB6E1CCB7E1CCB7E1CCB8E1CCB8E1CDB9E1CDBAE1CEBB\
E1CEBCE1CEBCE1CEBCE1CEBCE1CEBCE1CEBCE1CEBCE1CEBCE1CEBBE1CDBAE1CDB9
E1CCB9E1CCB8E1CCB9E1CDB9E1CDBAE1CDBBE1CDBBE1CDBAE1CDB9E1CCB8E1CBB5E1CAB3E1C8B1\
E0C7AEE0C5ABDFC3A8DEC2A7DEC2A6DEC2A7DEC4AADFC5ACE0C7AEE0C7AEDFC5AC
DEC3AADDC1A6DCBFA4DBBDA2DABCA0DABA9FDAB99DD9B79BD9B59AD9B398D8B297D7B196D6B096\
D5B095D5B095D4B095D4B095D4AF94D3AD92D1AA90CEA58CC99F87C29781B88C79
AE8271A377689A6E609267598B6153845D4D7D58487553436F4F3F6A4C3B6A4B3A6D4D3B74513E\
7C5642835B4689614C8E6751926C559670599A745C9E775EA1795FA37B60A47D61
A47E63A38064A38064A27F64A17E64A07D63A07B61A17960A2785EA4775EA5785EA77960A87C63\
AA7F67AD826AB1856EB68872BB8A74BF8C76C38E77C38D76BF8A72B5826AA4755E
8F65507752406141324E3327402A1F37241B31211A2F221B30241E3429223C2E2747332A54382D\
613C2E6E3F2E77402D7D3F2B7F3E297D3C27773B286F3C2B6A42346C504478665D
8F847CA9A49DC3C1BAD6D6CFE1E2DBE5E7E0E5E7E0E4E5DEE3E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E1E6E6DEE4E3DBE2E1D9E2E0D8E2E0D8E2E0D8E2E0D9E2E1D9E2E2DA\
E2E2DAE2E2DBE2E2DBE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE2E3DBE2E4DC
E4E5DEE5E7E0E5E6DFE0E1D9D4D3CBC0BBB3A69C92897A6F6E5B4F58423649312640281D3A2319\
362017331F17311E162F1E152D1D152B1D152A1D15271C142419121F17101C140E
19120C19110C1C130D211610271A132E201936271F3F2F274C3A305C473B7056478567549B7862\
AE886FBD967BC9A286D2AB8FD8B397DCB99CDFBEA1E0C1A4E1C2A7E1C3A9E1C4AC
E1C4AEE1C5B0E1C6B2E1C8B4E1C9B5E1CBB6E1CBB7E1CCB7E1CCB8E1CDB9E2CEBAE2CFBCE2D0BE\
E2D1C0E2D2C1E3D2C1E3D2C2E3D3C2E3D2C2E3D2C1E2D2C1E2D1C0E2D1BFE2D0BD
E2CFBCE2CFBCE2CFBCE2D0BDE2D1BFE2D1C0E2D1C0E3D1BFE3D0BDE3CFBBE3CEB9E2CCB7E2CBB4\
E1C9B2E1C8AFE0C6ACDFC4A9DFC3A8DFC3A8DFC4A9E0C5ABE0C6ACE0C6ACE0C5AB
DFC4A9DEC2A6DDC0A4DCBEA2DBBC9FDABA9ED9B79CD9B59AD9B398D9B297D8B196D8B196D7B196\
D7B196D6B297D6B297D6B297D6B297D6B096D5AE94D3AB92CFA68FC99F8AC29784
B98F7EB18777A97F70A278699C7262956C5C8D6556855F4F7C59497554447051406F4F3E714F3D\
74503D77523F7955417C58447E5C47825F4A86634D8B6650906A53936D55956F57
95725994745B94755C94755C95745B96735A9772589870579A6F569B6F569E7158A1745CA67961\
AB7E67B0836CB58770B98973BD8B75C08D76C38E76C28D74BD8870B28068A0725C
8A604D714E3D5A3C2E482F233C261C3421193020192F211B30241E3427223A2B25412E274A3027\
5431265E32246633236D33217133207133206D3322683626653E30694C4176645A
8D827AA8A39BC2C0B9D6D6CFE1E2DBE5E7E0E5E7E0E4E5DEE3E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DDE9E9E1E9E9E0E6E6DEE4E4DCE2E2DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1DAE2E2DA\
E2E2DAE2E2DAE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE2E3DBE2E4DC
E4E5DEE5E7DFE5E6DFE0E1D9D4D3CBC0BBB3A59C93887B716C5C5157443949342A412C223C271E\
38251C35231A3221182F1F172D1E162C1D152A1D15281C14261A132218111F160F
1D140E1C140E1F150F231811281C152F211A3627203F2F274C3A305C463B6F55468566539A7660\
AD866DBC9479C8A084D1AA8ED7B296DBB99CDEBDA0E0C0A4E1C2A7E1C3A9E1C4AB
E1C4ADE1C5AFE1C6B1E1C8B3E1C9B5E1CAB6E1CBB6E1CBB7E1CCB8E1CDB9E2CEBBE2CFBDE2D1C0\
E2D2C2E2D3C3E3D4C4E3D4C4E3D4C4E3D4C5E3D4C4E2D4C4E2D3C3E2D2C1E2D1BF
E2D0BEE2D0BDE2D0BEE2D1BFE2D2C1E2D3C2E2D2C2E3D2C0E3D0BEE3CFBCE2CEBAE2CDB8E2CCB6\
E2CBB4E1C9B2E1C7AFE0C6ACE0C5AAE0C4A9E0C4A9E0C5AAE0C5AAE0C5AAE0C5AA
E0C4A8DFC2A7DEC0A4DCBEA2DBBC9FDAB99DD9B69AD9B498D9B297D9B195D9B095D8B095D8B196\
D8B297D8B397D8B498D8B498D8B398D8B298D7B097D6AE96D4AA94D0A691CAA08D
C49B89BD9583B78F7EB28978AD8372A77C6CA07665976F5E8D68578461507C5B4A775645735240\
714F3D704E3C6F4E3B6E4E3B6F503D72523F7655417C5945815C4886604B87634E
876651876953876A54896B548B6B548E6B53906A51926950936950956A51986D549E715AA57861\
AD7E68B4846FB98873BC8B75BF8C76C08D75C18D75C08C73BA876EAF7E669C6F59
855D4A6C4A3A55382C442B2138231B3220182F1F182E201A30221D3225203627223B2822402821\
47271F4E271C55271A5D2819622919652B1B642E1E623325623C30684D4277655B
8E847BA9A49CC3C1B9D6D6CFE1E2DBE5E7E0E5E7E0E4E5DEE3E3DCE2E3DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E5DDE9E9E1E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE2E2DAE2E2DA\
E2E2DAE2E2DAE1E2DAE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE1E2DBE2E3DBE2E3DC
E4E5DEE5E7DFE5E6DFE0E1D9D4D3CBC0BBB3A59D94877B726D5D5358463C4B382E443027402C23\
3C292138261E33231B2F20182D1E162B1D152A1C14291C14271B13251912221810
201710201710221811251A132A1D1730221B3628213F30284B3A315B463A6E554583645198745E\
AB846ABA9277C69E82CFA88CD5B194DAB79BDDBCA0E0C0A4E1C2A6E1C3A9E2C4AB
E2C4ADE1C5AEE1C6B0E1C7B2E1C8B3E1C9B5E1CAB6E1CBB6E1CBB7E1CCB8E1CEBAE1CFBDE2D1BF\
E2D2C2E2D3C3E2D4C4E2D4C5E2D5C6E2D5C6E2D5C6E2D4C6E2D4C4E2D3C3E2D1C0
E2D0BFE2D0BEE2D0BFE2D1C0E2D2C2E2D3C3E2D2C2E2D1C0E2D0BEE2CEBBE2CDB9E2CDB8E2CCB7\
E1CBB6E1CAB4E1C9B1E1C7AFE1C6ACE1C5ABE1C5AAE1C5A9E1C5A9E1C5A9E1C5A9
E0C4A8E0C3A7DFC1A5DDBEA2DCBB9FDAB89CD9B59AD9B397D9B196D9B095D9B095D9B095D9B196\
D9B297D9B397D9B498D9B498D9B499D9B399D9B299D8AF98D6AD97D4AA96D0A793
CCA491C7A08DC39C89C09784BC927FB78C79B08572A87E6B9E7664946F5C8A675582604E7B5A48\
76554271513E6D4E3B6A4C39694C396B4D3A6F4F3C74513E7955417D58447E5B47
7F5E4A7F614C7F634E82654F86664F8A664E8E674E90674D91674E936950976C549E715AA67862\
AF7E6AB68471BB8875BE8B76BF8C76BF8D75BF8D73BD8B71B7866CAB7C64986D58
815B4868473952362A41292036221A301F172E1E172E1F192E211C30221E32231F34231E37211C\
3A1F183F1E15461E134E20135422155926185B2A1D5C3124603D31684E4479675E
90867DABA69EC4C2BBD7D7D0E1E3DBE5E7E0E5E7E0E4E5DEE3E3DCE2E2DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DBE1E2DBE1E2DBE1E2DBE2E3DBE2E3DC
E4E5DDE5E7DFE5E6DFE0E1D9D4D3CBC0BCB4A59D95887C736E5E555B483F4F3B3249342B453128\
402E253B2A2135251D2F21192C1E162A1D152A1C142A1C14291B13271B12251A12
241911241912251A13281C162C1F1931231D3729234030294B3A315A463A6D534481635095725C\
A78168B68F74C29B7FCCA589D3AE92D8B699DCBB9FDFBFA3E1C2A6E1C3A8E2C4AA
E2C4ACE1C5ADE1C5AFE1C6B0E1C7B2E1C8B3E1C9B5E1CAB5E1CBB6E1CCB8E1CDBAE1CEBCE1D0BE\
E1D1C0E1D2C2E1D3C4E1D4C5E2D4C6E1D5C7E1D5C7E1D4C6E1D4C5E1D3C3E1D2C2
E1D1C0E1D1C0E1D1C0E1D2C2E1D3C3E1D3C3E1D2C2E1D1C0E1CFBDE1CEBBE1CDB9E1CCB8E1CCB7\
E1CBB7E1CBB5E1CAB3E1C9B1E1C8AFE1C7ADE1C6ABE1C5AAE1C5A9E1C5A8E1C4A8
E1C4A8E0C3A7DFC1A5DEBEA2DCBB9FDBB89CDAB599D9B397D9B196D9B095D9B095D9B095D9B095\
D9B196D9B297D9B397D9B498D9B499D9B399D9B29AD9B09AD8AE99D6AC98D4AB97
D1A995CEA793CBA48FC8A18CC59C87C19782BC917CB48A75AC836EA27B67997460906C58886652\
815F4C7A5A477556437153406F513E6F513D71513D75523E7854407B56427C5844
7C5A477D5D497E5F4B82624C87644D8D664E91684F936950956B51976D549A7058A0745EA87A65\
B07F6CB78472BB8775BD8A76BD8B75BD8C74BC8C72B98A70B2856BA77B62946C56
7D59476546374F35293F281F3521192F1E172D1E172D1E182D201A2D201C2E201C2E1F1A2F1D18\
301B143419113A1910411B10481E134F231753281C5731255C3D32674F45796960
92877FACA79FC5C3BCD7D8D0E2E3DCE6E7E0E5E7E0E4E5DEE2E3DCE2E2DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E2E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DBE1E2DBE1E2DBE2E2DBE2E3DC
E4E5DDE5E7DFE5E6DFE0E0D9D4D3CBC0BCB4A69D958A7D747160575F4B42543E354E382F4A352C\
4532293E2D2536281F30221A2B1F17291D15291C142A1C142A1C13291B13281B13
271B13281B14291C162B1E182F201C332420392A2541312A4B3A315A45396B52437E604D916F59\
A37E64B18B70BE977BC8A286CFAB8FD6B397DBBA9DDEBEA2E0C1A5E1C3A8E2C4A9
E2C4AAE1C4ABE1C5ADE1C5AFE1C6B0E1C7B2E1C8B3E1C9B5E1CAB6E1CBB7E1CCB9E1CDBAE1CEBC\
E1CFBEE1D1C0E1D2C2E1D3C4E1D4C6E1D4C6E1D5C7E1D4C6E1D4C6E1D3C4E1D2C3
E1D2C2E1D2C2E1D2C2E1D2C3E1D3C4E1D3C4E1D2C2E1D0C0E1CFBDE1CDBAE1CCB9E1CCB8E1CBB7\
E1CBB7E1CBB6E1CAB5E1CAB3E1C9B1E1C8AFE1C6ADE1C5ABE1C5A9E1C4A8E1C4A8
E1C4A7E0C3A7DFC1A5DEBEA2DCBB9FDBB89CDAB599D9B398D9B296D9B196D9B095D9B095D9B095\
D9B195D9B196D9B297D9B398D9B398DAB399DAB29ADAB09AD9AF9AD8AD99D6AD98
D4AC97D1AB95CFA992CDA68FCAA38BC79E87C39982BD937CB68D76AE8670A680699E796397735D\
906D5889685384644F7F604B7C5D487B5B467B5A457C59447E59447F59447F5A45
805C47805E4883604A87634D8D664F936A51986D539B6F569C72589E745BA1775FA67A64AC7D69\
B2806EB88372BA8675BB8875BB8A74B98B73B88B71B4896EAE8369A27960906A54
7A57456244364E34293E281F3421192F1E172D1D162C1E172B1F192B1F192A1E19291D17291B15\
2918122B170F30170F3719103E1D134621174B281D513025593D33664F46796960
92877FADA79FC5C3BBD7D7D0E1E2DBE5E7DFE5E6DFE4E4DDE2E3DCE2E2DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DBE1E2DBE2E2DBE2E3DC
E4E5DDE5E7DFE5E6DFE0E0D9D4D3CBC1BCB4A79E958C7E75746158624C43584037523B314F382F\
49352B413027382A2130241B2B1F17291D15291C142A1C142B1C142B1C132B1C13
2A1C142B1C152C1D172E1F1A31221E3526213A2B2642312B4C3A315844386850417A5E4B8C6C55\
9D7A61AC876CB89377C39E82CCA88CD3B094D9B89BDDBDA1E0C1A4E1C3A7E2C4A8
E2C4A9E1C4AAE1C4ABE1C4ADE1C5AFE1C6B1E1C7B2E1C8B4E1CAB5E1CBB7E1CCB8E1CDB9E1CDBA\
E1CEBCE1D0BEE1D1C0E1D2C3E1D3C4E1D4C6E1D4C6E1D4C6E1D4C6E1D3C5E1D3C4
E1D3C4E1D3C4E1D3C4E1D3C4E1D3C5E1D3C4E1D2C2E1D0C0E1CFBDE1CDBAE1CCB8E1CCB7E1CBB7\
E1CBB7E1CBB6E1CBB6E1CAB5E1C9B3E1C8B1E1C7AEE1C6ACE1C5AAE1C4A8E1C4A8
E1C3A7E0C2A6DFC0A4DEBDA1DCBA9EDBB79BDAB599D9B398D9B297D9B297D9B196D9B196D9B095\
D9B095D9B095D9B196D9B297D9B398D9B399DAB299D9B099D9AF99D8AD98D7AD97
D5AC96D3AC94D1AA92CFA890CDA68DCAA289C69E85C29980BD947CB88F76B28A71AC856DA68068\
A07C649A776095745C9170598D6D568B6A528A675089644D88624B88614A87604A
87614A88624B8B654D906850966C539C7057A1735AA4775DA67A60A77C63A97E67AC806AB0806D\
B58170B88372B98574BA8774B88973B78A72B48A70B0876CA981669D775E8B6752
7655436043354D33283E271F3521192F1E172D1D162C1E172B1E172A1E18281D17271C16251A13\
25181126170F2A170F301910371D133E211844271D4B2F25553C32634E4477675E
90857CABA49CC3C0B8D5D4CDE0E0D9E4E5DEE4E5DEE3E4DDE2E3DCE2E2DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DBE2E2DBE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D9D5D3CBC1BCB3A89E958E7E74766157654D425B4136553C3151392F\
4C362C4331283A2B2232251D2C21182A1E16291D152A1C142B1C142C1C132D1C13
2D1C142E1C152F1E1831201B34231E3726223C2B2643312B4C3930574236654E3E755A47866751\
96755CA58268B38E73BF9A7EC9A488D1AE91D7B599DCBC9FDFC0A3E0C2A6E1C4A7
E1C4A8E1C4A9E1C4AAE1C4ACE1C4AEE1C5B0E1C6B2E1C8B3E1C9B5E1CBB7E1CCB8E1CCB9E1CDBA\
E1CEBBE1CFBDE1D0BFE1D1C1E1D2C3E1D3C4E1D3C5E1D4C5E1D4C5E1D4C5E1D4C5
E1D4C5E1D4C5E1D4C5E1D4C6E1D4C5E1D3C4E1D2C2E1D0BFE1CEBCE1CDBAE1CCB8E1CBB7E1CBB7\
E1CBB7E1CBB6E1CBB6E1CAB5E1C9B3E1C8B1E1C7AFE1C6ACE1C5AAE1C4A9E1C4A8
E1C3A7E0C1A5DFBFA3DEBCA0DCB99DDBB69ADAB499D9B398D9B397D9B397D9B297D9B196D9B195\
D9B095D9B095D9B095D9B196D9B297D9B298D9B198D9AF98D9AE98D8AD97D7AC96
D5AC94D3AB92D1AA90CFA88ECDA68CCBA389C9A086C69D83C3997FBF957BBB9178B68E74B28B71\
AD876EA9856CA58269A27F669F7C639C785F99745C977158956D55936B52926951
926951936A52966C539B6F56A0735AA6775DAA7B61AD7E65AF8168B0846BB1856EB28570B58471\
B78372B98372B98473B98673B78872B58970B1886DAC8469A47D6397725A87644E
7353405E41334C32273E271F352119301E172D1D162C1D162B1E172A1E17291E16271C15241B13\
2319122318102619102B1A12311D143821183F271D462E24513A305F4B41746359
8D8077A79E96BFB9B2D1CEC7DCDBD4E2E1DAE3E3DCE3E3DCE2E3DBE2E2DBE2E2DBE2E2DBE2E2DB\
E2E2DBE2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D9D5D3CBC2BCB3A99D948F7D73776155664C405C4034563B2F52392D\
4C362B4532273C2D2335271E2F231A2C20182B1E162B1D152C1C142D1B132E1B13
2F1B13301C15321E1734201B36231E3A27223E2B254431294C382E564033624A3A7056437F624D\
8F6F579E7C63AD896FBA957AC5A085CEAB8FD5B397DABA9DDDBEA2DFC1A4E0C3A6
E1C3A7E1C3A8E1C3A9E1C3ABE1C4ADE1C4AFE1C6B1E1C7B3E1C9B5E1CBB7E1CCB8E1CDB9E1CDBA\
E1CEBCE1CFBDE1CFBEE1D0BFE1D1C1E1D2C2E1D2C3E1D3C4E1D4C5E1D4C6E1D4C6
E1D4C6E1D4C6E1D4C6E1D4C6E1D4C6E1D3C4E1D2C2E1D0BFE1CEBCE1CDBAE1CCB8E1CBB7E1CBB7\
E1CBB6E1CBB6E1CAB5E1CAB4E1C9B2E1C8B0E1C7AFE1C5ADE1C5ABE1C4AAE1C3A8
E1C2A7E0C0A5DFBEA2DEBB9FDCB79CDBB599D9B398D9B397D9B397D9B397D9B397D9B297D9B196\
D9B195D9B095D9B095D9B095D9B196D9B096D9B096D9AE96D9AD96D8AC95D6AB94
D5AB92D3AA90D1A98ED0A78CCEA58ACDA388CBA186C99E83C79C81C4997EC1967CBE947ABA9277\
B78F75B48D73B28C72AF8A70AD876DAA846AA78167A47D63A2795F9F765C9E745B
9E745A9F745AA1755CA5785EAA7A61AE7E64B28167B4846BB6866EB68870B78972B88873B98774\
BA8573BA8573BA8572B98671B78770B4876EAF856AA880659F785E926D54815F49
6E4F3C5C3F304B31263E271E352119301E172E1D162D1E162D1E162C1F172B1E16291E16261C14\
241B13231A12241A12281B132D1D153321183A251C422C224C372C5B473C6F5D52
88786EA1958CB9B0A8CBC5BED7D3CDDEDCD5E1E0D9E2E2DBE2E3DBE2E3DBE2E3DBE2E2DBE2E2DB\
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D9D5D3CAC2BBB2A99D938F7C71775F53664B3D5B3F3055392B513729\
4C35284632263F2E2338292032251C2F221A2D1F172C1D152D1C142E1B122F1A12
301A12321B14341D16361F1938231D3B26203F2B234430274B362A543E305E46366A503E785C47\
87685297755EA7836AB69076C29C81CCA78BD3B094D8B79BDCBDA0DEC0A3E0C2A5
E1C3A6E1C3A7E1C3A9E1C3ABE1C3ADE1C4AFE1C5B1E1C7B3E1C9B5E1CBB7E1CCB9E1CDBBE1CEBC\
E1CFBDE1CFBEE1CFBEE1CFBEE1D0BEE1D0C0E1D1C1E1D2C3E1D3C5E1D4C5E1D4C6
E1D4C6E1D4C6E1D4C6E1D4C6E1D4C6E1D3C4E1D2C2E1D0BFE1CEBCE1CDBAE1CCB8E1CBB7E1CBB6\
E1CBB6E1CAB5E1CAB3E1C9B2E1C8B0E1C7AFE1C6AEE1C5ADE1C4ACE1C3AAE1C2A9
E1C1A6E0BFA4DFBCA0DEB99DDCB69ADAB398D9B296D9B296D9B297D9B397D9B398D9B397D9B297\
D9B196D9B195D9B095D9B095D9AF95D9AF95D9AE95D9AD95D8AD94D8AC93D6AB92
D5AA90D3A88ED1A78CD0A58ACFA488CEA287CCA085CB9F83C99D82C79B80C5997EC2987DC0967B\
BD947ABB9378BA9277B99176B78F75B68D73B38A70B0876CAD8469AB8166AA7F65
AA7E64AA7F64AC7F65AF8066B28268B5846AB8866CB9886FBA8971BB8B74BB8B75BB8A76BB8975\
BC8874BC8773BB8772BA8771B7866FB3856BAD8167A57B609A72578C664E7B5843
694A38583B2D492F243D261E352119301E172E1D162E1E162E1F172F1F172E20172C1F17291E16\
261C14241B13241B13261B142A1D1530201736231A3E2A1F4833285742366A564A
816F649A8A81B1A49CC3BAB3D1CAC4DAD5CFDEDCD6E1E1D9E2E3DBE2E3DCE2E3DCE2E3DBE2E2DB\
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E1DAE2E2DAE2E2DAE1E2DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D9D5D2CAC2BBB1A99C918E7B6F765E5064493A593C2D5337274F3526\
4B3426463225412F243B2B2136271E32241C2F21192E1E162E1C142E1A122F1911
311911321A12341C14361E1738221B3B261E3F2A21442E234A3427513A2B594231644B39705542\
7F614C8F6E57A07C64B08A70BE977CC9A386D0AD90D6B598DABB9EDDBFA2DFC1A4
E0C3A6E1C3A7E1C3A9E1C3ABE1C3ADE1C4AFE1C5B1E1C7B3E1C9B5E1CBB7E1CDBAE1CEBCE1D0BE\
E1D0BFE1D0BFE1CFBEE1CFBDE1CFBDE1CFBEE1D0C0E1D1C2E1D3C4E1D3C5E1D4C5
E1D4C6E1D4C6E1D4C6E1D4C6E1D3C5E1D3C4E1D1C1E1D0BEE1CEBCE1CDB9E1CCB8E1CBB7E1CBB6\
E1CAB5E1CAB4E1C9B2E1C8B0E1C7AEE1C6ADE1C5ACE1C4ACE1C4ACE1C3ABE1C1A9
E1C0A6E0BDA2DFBA9FDDB79BDCB498DAB296D9B195D9B195D9B196D9B297D9B397D9B397D9B397\
D9B296D9B196D9B095D9AF94D9AE94D9AE93D9AD93D9AD93D8AC93D7AB92D6AA90
D4A98ED3A78DD1A58AD0A488CFA287CFA085CE9F84CC9E83CB9D82C99C81C79B80C49A7EC2987D\
C1977CBF967BBF967BBF957ABE957ABD9479BC9176B98F74B78C71B58A6FB4896E
B4886DB4886DB5886DB6886DB8886EBA896FBB8970BC8A72BC8B74BD8C75BD8C76BD8B76BD8B76\
BD8A74BD8973BC8871BA8870B7866DB28269AA7D63A0755B936A51845E4774513C
63443253372A452D223B251D342119301E172E1E172F1E17301F183120183120192F20182B1F17\
281D15251C14241B13251B13281C142C1E1532211739261B432F23513C2F644E42
7A655A917E74A8978FBBAEA7CAC0BAD5CEC8DCD9D2E0DFD8E2E2DBE3E4DCE3E3DCE2E3DBE2E2DB\
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E4DCE2E2DAE2E1DAE2E1DAE2E1DAE2E2DAE1E2DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D9D4D2CAC1BAB1A89B908D7A6D755C4D624737573B2A5135254D3425\
4A34264732264230253E2D2339292035261D32221A301F172F1C142E1A122F1810
2F1810311911321A13341D153720193A241B3D281E412B204630234C3627543C2C5E4433694E3C\
78594588665099745CAA8368B89075C49D80CDA88BD4B194D9B89BDCBDA0DFC1A4
E0C2A6E1C3A7E1C3A9E1C3ABE1C4ADE1C4AFE1C5B0E1C7B3E1C9B5E1CBB7E1CDBBE1CFBDE1D1C0\
E1D1C1E1D1C0E1D0BFE1CFBDE1CEBCE1CFBDE1CFBEE1D1C0E1D2C2E1D2C3E1D3C4
E1D3C5E1D3C5E1D3C5E1D3C5E1D3C4E1D2C2E1D1C0E1CFBDE1CEBBE1CCB9E1CCB8E1CBB7E1CBB6\
E1CAB5E1C9B3E1C8B0E1C7AEE1C6ACE1C5ABE1C4ABE1C4ABE1C3ABE1C2AAE0C1A8
E0BEA5DFBCA1DEB99DDDB69ADBB397DAB195D9B095D9B095D9B195D9B296D9B297D9B397D9B297\
D9B296D9B196D9B095D9AF94D9AE93D9AD92D9AC92D9AC92D8AB91D7AB90D6A98F
D4A88DD3A68BD1A489D0A287D0A185CF9F84CE9E83CD9D82CB9D81C99C81C79C80C59B7FC49A7E\
C3997EC2987DC2987DC2987DC2987DC2977CC1967BC09479BE9277BD9176BC9075
BC8F74BB8F74BC8F74BC8E73BC8D72BC8C72BC8B72BC8B73BC8B74BC8C76BC8C76BD8C76BD8C75\
BD8B74BC8B72BB8A71B9886EB5856BAF8066A6785E996F558B634B7B57406A4A36
5A3D2D4C3225402A1F37241B3220192F1E182F1E182F1F183120193220193220193020192C1F17\
281D16251C14231A13231A12241912281A132D1D143422173E2A1E4C36295E463A
735B508973699F8B82B3A29BC3B7B0D0C8C1D9D5CEDFDED6E2E2DBE3E4DDE3E4DCE2E3DCE2E2DB\
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DCE2E2DAE2E1DAE2E1DAE2E1DAE1E1DAE1E2DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D9D4D2C9C0BAB0A79A8E8B786B725A4B604535553A294F35254D3526\
4B35274733274331263F2E243B2A2138271E35231B322018301D152E1B122D1810
2D170F2E180F2F1911311C14341F173722193A251B3D281D412C1F4730234E3728573E2E634736\
71523E815E48916C53A27A5FB1886CBE9679C9A385D1AE90D7B699DCBC9FDFC0A3
E0C2A6E1C3A7E1C3A9E1C3ABE1C4ADE1C4AFE1C5B0E1C7B2E1C9B5E1CBB8E1CEBBE1D0BEE1D1C1\
E1D2C2E1D2C2E1D1C1E1D0BFE1CFBDE1CFBDE1CFBDE1D0BEE1D0C0E1D1C1E1D2C3
E1D3C4E1D3C4E1D3C4E1D2C3E1D2C2E1D1C0E1CFBEE1CEBCE1CDBAE1CCB8E1CBB7E1CBB7E1CBB6\
E1CAB5E1C9B3E1C8B0E1C6ADE1C5AAE1C4AAE1C4AAE1C3AAE1C3AAE0C1A9E0C0A6
DFBDA3DEBAA0DDB89CDCB599DBB297DAB195D9B094D9B094D9B095D9B095D9B196D9B196D9B196\
D9B195D9B095D9AF94D9AE93D9AD92D9AC91D9AC91D9AC91D8AB91D8AA90D6A98E
D4A78CD3A58AD1A388D0A186CFA084CE9E83CD9D82CC9C81CB9C81C99C81C89C81C69C80C59B80\
C49B7FC49A7FC49A7FC49A7FC4997EC4997DC4987CC4967BC3957AC29579C19479
C19479C09378BF9378BE9176BD9075BC8E74BB8D73BB8C74BA8C74BA8C75BB8C76BB8C76BB8C75\
BB8C74BA8B72B98A70B6876DB18369AA7D639F745B916951815C46704F3B604231
503728432D2139261C3321192F1F182E1F192F1F19301F1A30201A30201A2F1F1A2D1E182A1D17\
271C15241B132119122017102016102216102718112E1D1439241A463024584034
6C534781695F978077AB9890BDAEA7CBC2BBD6D2CADEDCD5E2E2DBE3E4DDE3E4DDE2E3DCE2E2DB\
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DCE2E2DAE2E1D9E2E1DAE2E1DAE1E1DAE1E1DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E7DFE5E6DFE0E0D8D4D2C9C0B9AFA5998D89776970594A5E4434533A2A4F36274D3628\
4B362A48352A453228402F253D2B223A281F37251C352219321F162F1C132C1911
2A180F2A180F2B19102E1B13311E1533201735221838241A3C271C412C1F4831245239295D4130\
6B4B3879574189634A997155A87F62B78E70C39D7FCEA98CD6B396DBBB9EDFBFA2
E0C2A5E1C3A7E1C3A9E1C3ABE1C4ADE1C4AFE1C5B0E1C7B2E1C9B5E1CBB8E1CDBBE1D0BEE1D1C1\
E1D2C3E1D2C3E1D2C2E1D1C1E1D0BFE1CFBEE1CFBDE1CFBDE1CFBEE1D0BFE1D1C1
E1D2C2E1D2C3E1D2C3E1D2C2E1D0C0E1CFBEE1CEBCE1CDBAE1CCB9E1CCB8E1CBB7E1CBB7E1CBB6\
E1CAB5E1C9B2E1C7AFE1C6ACE1C5AAE1C4A9E1C3A9E1C3A9E0C2A9E0C1A7DFBEA5
DEBCA1DDB99EDCB69BDBB498DAB297D9B196D9B095D9B094D9AF94D9AF94D9AF94D9AF94D9AF94\
D9AF94D9AF94D9AE93D9AD92D9AC91D9AC91D9AC91D9AB91D8AB90D7AA8FD6A98E
D4A78CD2A58AD1A388CFA186CE9F84CD9E82CC9D81CB9C81CA9C81C99C81C89C81C79D81C69D82\
C59D81C59C81C59C80C49B80C59A7FC5997DC5987DC5977CC5967BC5967BC4967B
C4967AC2957AC19479BF9378BC9176BB8F75B98D74B88C73B88C74B88C74B88C75B88C75B88C74\
B88C73B78B71B5896FB2866BAC8166A3795F976F5787634C765642654837553C2D
4631243B281E3322192E1F182D1E182D1F192F1F1B2F201C2F1F1C2E1E1B2C1D19291C17261B15\
241A142119121E17101C140E1B130D1D120D21140E281811332017412B2052392E
654B407A60568F776EA49087B7A79FC7BDB5D4CFC7DDDBD4E2E2DBE3E4DDE3E4DDE3E3DCE2E2DB\
E2E2DBE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E2E1D9E2E1DAE1E1DAE1E1DAE1E2DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E7DFE5E6DFE0E0D8D4D1C9BFB9AEA4988C8876686E58495C4434523A2A4F37294D382B\
4C382D49372C46342A4230273E2C233C29203A261E37231B342018301D152C1A12
2819102718102819102B1A122D1C14301E1631201734221837241A3C281D432E214D3527583D2D\
65463373503A815B4390684D9F7759AF8669BD9678CAA587D4B093DBB99CDEBEA1
E0C1A4E1C2A7E1C3A9E1C3ABE1C3ADE1C4AEE1C5B0E1C7B2E1C9B4E1CBB7E1CDBAE1CFBEE1D1C0\
E1D2C3E1D3C3E1D2C3E1D2C2E1D1C1E1D0BFE1CFBEE1CFBDE1CFBDE1CFBEE1D0C0
E1D1C2E1D2C2E1D2C2E1D1C0E1CFBEE1CEBCE1CDBAE1CCB8E1CBB8E1CBB7E1CBB7E1CBB7E1CBB6\
E1CAB5E1C9B2E1C7AFE1C6ACE1C5AAE1C4A8E1C3A8E0C3A8E0C2A7DFC0A5DEBDA3
DDBB9FDCB89CDBB59ADAB498D9B297D9B196D9B195D9B094D9AF94D9AE93D9AE93D9AE93D9AE93\
D9AE92D8AD92D8AD92D8AC91D8AC91D9AB91D9AB91D8AB90D8AB90D7AA8FD6A98D
D4A78CD2A589D0A387CFA185CD9F84CC9D82CA9C81CA9C81C99C80C89C81C89D81C79D82C79E83\
C69E83C69E83C59D82C59B80C49A7EC4987DC5977CC5967BC6967BC6967BC6967B
C4967BC3957AC09479BE9378BB9176B88F75B68D74B58C73B58C73B58C73B58C73B68C74B68C73\
B58C72B48A70B1886DAD8469A67D639B755C8E6A537D5D486C4F3D5A42334B3629
3D2C2133251B2D20172A1D162A1D182C1E1A2E1F1C2E1F1D2C1E1C2A1D1A271B18241916221814\
2017121D16101B140E18110C170F0B180F0A1C100C23140F2E1C153C261E4D342A
5F453B73594F8970669E897FB2A299C4B9B1D2CCC4DCDAD3E1E2DAE4E5DDE4E5DDE3E3DCE2E2DB\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E2E1D9E2E1DAE1E1DAE1E1DAE1E1DA\
E1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DBE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D8D4D1C9BFB8AEA4988C8776686E58495C4435523A2C4F382A4E392D\
4D3A2F4A392F47352C433229402E253E2B223C281F39251D36221A311F162C1C14
291A12271911271A11291B122B1C142D1D152F1E1630201733221939261C402C214A3226553A2B\
6042316C4B3679553D876146966F53A77F62B79072C6A082D1AD90D9B699DEBC9F
E0BFA3E1C1A6E1C2A8E1C3AAE1C3ACE1C4AEE1C5B0E1C6B2E1C8B4E1CAB6E1CCB9E1CEBCE1D0BF\
E1D1C1E1D2C3E1D3C4E1D2C3E1D2C2E1D1C1E1D0BFE1CFBDE1CEBDE1CFBEE1D0BF
E1D1C1E1D2C2E1D1C1E1D0BFE1CEBCE1CDBAE1CCB8E1CBB7E1CBB7E1CBB7E1CBB7E1CBB7E1CBB6\
E1CAB5E1C9B3E1C7B0E1C6ADE0C4AAE0C3A9E0C3A7E0C2A6DFC1A5DEBFA3DDBCA1
DCB99EDAB79BDAB599D9B397D9B297D9B196D9B195D9AF94D9AE93D9AD92D9AD92D9AC91D9AC91\
D8AC91D8AC91D8AC91D8AC91D8AB91D8AB90D8AB90D7AB90D7AA8FD6A98ED5A88D
D4A68BD2A589D0A387CEA185CC9F84CB9D82C99C81C99C80C89C80C89C81C89D81C89E82C89F83\
C79F84C79F84C69E82C59C81C49A7EC4987CC4967BC5967BC5957AC6957AC5957A
C4957AC2957AC09479BD9278B99176B68F74B48D73B38C72B38C72B48C72B48C73B58C73B58C72\
B48B71B1896FAE866BA881669F796094705885644E745744624939523C2F433126
38291F2F221A2A1E17281D16291D182A1E1A2B1E1C2B1E1C281C1B251A192218171F17141D1612\
1C14101A130E18110C150F0A140D09150C09180E0B20120E2A191338231C473027
5940366D5349826A5F988378AD9D93C1B6ADD0CAC2DBD9D2E1E2DAE4E5DDE4E5DDE3E4DCE2E3DB\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E2E1D9E1E1D9E1E1DAE1E1DAE1E1DA\
E1E1DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DAE2E3DC
E4E5DDE5E6DFE5E6DFE0E0D8D4D1C9BFB9AEA4988C8876686F594A5D4535533B2C4F382B4E3A2E\
4D3B304B3A3048372E45342B423027402D243E2A213B271F38241C3321192F1E16
2B1C14291B13291B122A1B132B1C142C1D152E1E1630201833221A38261D3F2C2248322752392C\
5C413067483572513B7F5C438E694E9F795DB18A6EC19A7ECEA88CD7B296DDB99D
E0BDA1E1C0A4E1C1A7E1C2AAE1C3ACE1C3AEE1C4B0E1C5B1E1C7B3E1C9B5E1CBB7E1CDBAE1CEBD\
E1D0BFE1D1C2E1D2C3E1D3C4E1D2C3E1D2C2E1D0C0E1D0BFE1CFBEE1D0BFE1D0C0
E1D1C1E1D1C2E1D1C1E1CFBEE1CEBBE1CCB9E1CBB7E1CBB6E1CAB6E1CBB6E1CBB6E1CBB7E1CBB6\
E1CAB5E1C9B3E1C7B1E0C6AEE0C4ABE0C3A9DFC2A7DFC1A6DEC0A4DDBEA1DCBB9F
DAB89CDAB69AD9B498D9B397D9B296D9B195D9B094D9AF93D9AD92D9AC92D9AC91D9AB91D9AB90\
D8AB90D8AB90D7AB91D7AB91D7AB90D6AB90D6AA90D6AA8FD6A98ED5A88DD4A78C
D3A68AD1A489D0A387CEA185CC9F84CA9D82C99C81C89C80C89B80C89C81C89D81C89E82C89F83\
C89F84C79F84C69E83C59C81C49A7FC4987DC4967BC4967AC5957AC5957AC4957A
C3957AC29479BF9479BC9277B89076B58E74B38D73B28C72B38C72B48C72B58C72B58C72B58C71\
B38A70B0886DAA8369A37D6399745C8C6A537D5D496C503F5B43354C372C3F2E24
35271E2F221A2B1F18291E17281D18281C19281C1A261B1A241A192118181E16161C15131A1310\
18120E16100C150E0A130D0A120C09140C0A170D0B1E110E28181334211A432D25
543C33674F447C655A937E74A9998FBEB3AACFC9C1DBD9D1E1E2DAE4E5DEE4E5DEE3E4DCE2E3DB\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E2E1D9E1E1D9E1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DAE2E3DB
E4E5DDE5E6DFE5E6DFE0E0D8D4D2C9C0B9AFA6998D8A7769705A4B5E4536543B2D4F382C4E392E\
4D3B314C3B314A393047362D44332A423027402D243D2A213A271E36241B322119
2F1F172D1D152C1D142B1C142C1C142D1D152E1F1730211934241C39281F402D24483429513A2E\
5940326247366C4E3B78584187644C98745AAB8569BC9579CBA387D5AE91DBB699
DFBB9EE0BEA2E1C0A6E1C2A9E1C2ACE1C3AEE1C4AFE1C5B0E1C6B2E1C7B3E1C9B5E1CBB7E1CDBA\
E1CEBDE1D0BFE1D1C1E1D2C3E1D2C3E1D2C3E1D1C2E1D1C0E1D0C0E1D1C0E1D1C1
E1D2C2E1D1C2E1D1C0E1CFBEE1CDBBE1CCB8E1CBB6E1CAB6E1CAB6E1CBB6E1CBB6E1CBB6E1CBB6\
E1CAB5E1C9B4E1C7B1E0C6AFE0C4ACE0C3AADFC1A7DEC0A5DDBEA3DBBCA0DABA9E
DAB89BD9B599D9B397D8B296D8B195D8B094D8AE93D9AD92D9AC92D9AC91D9AB90D9AB90D8AB90\
D8AB90D8AB90D7AB90D6AB90D5AB90D5AA90D4AA8FD4A98ED4A88DD4A78CD3A68B
D2A58AD1A488CFA287CDA185CB9F84CA9D82C89C81C89C80C79B80C79C80C89C81C89D82C89E83\
C89E83C79E83C79D82C69C81C59A7FC4987DC4977CC4967BC4957AC49579C39479
C29479C19479BE9378BB9277B89075B58E74B38D72B38C72B48B71B58B71B68C71B78B71B68B70\
B3896EAE856BA780669E7860926F5785634E755744654A3A553E314833293D2C22
36261E31231B2D211A2B1F19281D18261B182419182218172017171E16161B141419131217110F\
150F0D140D0B120C0A120C0A120C0A140D0B180F0D1E120F26181332201A402C23
503A31644D43796358907D72A7988EBDB3A9CEC9C1DBD9D1E1E2DAE4E5DEE4E5DEE3E4DCE2E2DB\
E2E2DAE1E2DAE1E2DAE1E2DAE2E2DAE2E2DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E2E1D9E1E1D9E1E1D9E1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DAE2E3DB
E4E5DDE5E6DFE5E6DFE0E0D8D4D2C9C1B9AFA79A8E8B796B725B4C604638553C2E4F382C4E392E\
4D3B314D3B324B3B324A393047362D45332A4230273F2C243C292139261E37241B
3422193220172F1E162E1D152D1D152D1D152E1F1731221A35251D3B2A21412F2649352B503B30\
584134604737684D3B73564182614B936F57A67F65B88F74C79E82D2A98CD9B195
DDB79BE0BCA0E1BFA4E1C1A8E1C2ABE1C3ADE1C3AEE1C4AFE1C5B0E1C6B1E1C7B3E1C9B5E1CBB7\
E1CCBAE1CEBDE1D0BFE1D1C1E1D2C3E1D2C3E1D2C3E1D2C2E1D1C2E1D2C2E1D2C3
E1D2C3E1D2C2E1D1C1E1CFBEE1CDBBE1CCB8E1CBB7E0CAB6E0CAB6E0CBB6E0CBB6E0CBB6E0CAB6\
E1CAB5E1C9B4E1C7B2E0C6B0E0C4ADDFC2ABDEC1A8DDBFA5DCBEA2DBBC9FDAB99D
D9B79BD9B599D8B397D8B195D8AF94D8AE93D8AD92D8AC91D8AB91D8AB90D8AA90D8AA90D8AA90\
D8AA90D7AA90D6AB90D5AA90D4AA90D3AA8FD3A98ED3A78CD2A68BD2A58AD2A489
D2A489D1A388CFA286CDA085CB9F84CA9D82C89C81C89C80C79B80C79C80C89C81C89C81C89D82\
C89D82C79D82C79C81C69B80C69A7FC5997EC4987CC4967BC3957AC29479C29479
C19478C09378BE9277BB9176B88F75B58E73B38C72B48B71B58B71B78B71B88B70B88A70B6896E\
B2866CAC8268A37B6299735B8C68537E5D496F503F5F443551392D4530263D2A21
37261E33241D30231C2C201A281D182419162016151D15141C14141B1314191313181211160F0E\
140D0C120C0A110B09120B0A130D0B160E0D1A100E1F131026191431211A3F2C24
503B32634F4579665B918075A89B91BDB5ACCFCAC2DBDAD2E2E2DAE4E5DEE4E5DDE3E3DCE2E2DB\
E2E2DAE1E2DAE1E2DAE1E2DAE1E2DAE1E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E2E1D9E1E1D9E1E1D9E1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E2DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DAE2E3DB
E4E5DDE5E6DFE5E6DFE0E0D8D4D2CAC1BAB0A89B8F8D7A6D745D4E61483A563D2F50392D4E3A2F\
4E3B324E3C334D3C334C3B324A393047362D44332A412F273F2C233C29213B261E
38241C352119321F172F1D152D1D152C1D152E1F1732221A37261E3D2B234331284A372D513C31\
5842355F4738674D3C7255427F5F4A906C55A27B61B48A6FC3987BCFA386D7AD90
DCB497DFB99DE0BDA3E1C0A7E1C1AAE1C2ACE1C3ADE1C3AEE1C4AFE1C4B0E1C5B1E1C7B2E1C8B4\
E1CAB7E1CCBAE1CEBDE1D0BFE1D1C1E1D2C2E1D2C3E1D2C3E1D2C3E1D3C4E1D3C4
E1D3C4E1D2C3E1D1C1E0D0BFE0CEBCE0CDBAE0CCB8E0CBB7E0CBB6E0CBB6E0CBB6E0CBB6E0CAB6\
E1CAB5E1C9B4E1C7B3E1C6B1E0C4AEDFC2ACDEC1A8DDBFA5DBBDA2DABB9FD9B99D
D9B79BD8B599D8B397D8B095D7AF93D7AD92D7AC91D7AB90D7AA8FD7AA8FD8AA8FD8A98FD8A98F\
D8A990D7AA90D6AA90D4AA8FD3A98FD2A88ED1A78CD1A68BD1A489D1A388D1A388
D1A287D0A287CFA186CDA085CB9E83CA9D82C89C81C89C80C79B80C79C80C89C80C89C80C89C80\
C89B80C79B80C79B80C79A7FC69A7FC5997EC4987DC3967BC2957AC19479C09378
C09377BF9277BD9176BB9075B88E74B68D72B58C71B68B71B78A70B88A70B9896FB8886EB5866C\
AF8269A87D649E765E936D5686624D775644694A3A5B3F314E3429442D233D281F
38261D35241D31231C2D201A271C182118151C14131A1212181112181212181111171010150F0E\
130D0B110B0A110B0A120C0B150E0D18100F1B1210201512271A1532221C402F27
53403768564C7F6E6496887EADA299C1BAB1D1CDC5DCDBD3E2E2DBE4E5DDE4E4DDE3E3DCE2E2DB\
E2E2DAE1E2DAE1E2DAE1E2DAE1E1DAE1E1DAE1E1DAE2E1DAE2E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E2DAE1E2DAE1E2DAE1E2DAE2E2DAE2E3DB
E4E5DDE5E6DFE5E6DFE0E0D9D5D2CAC1BBB1A89C918D7B6F745E5161493C563E31503A2E4F3B30\
4F3D334F3E354F3E354E3D344D3C334A393047362D44332A422F26402C233E2920
3B261D37221A3320172E1D152B1C142B1C142D1E1631221937261E3E2B224531274C372C533C31\
594235604738684D3C735441805E488F6A52A0775DB18569C09275CB9E80D4A88A
D9B093DDB79BDFBCA1E0BFA5E1C1A8E1C2ABE1C3ACE1C3ADE1C3AEE1C4AFE1C4B0E1C5B1E1C7B2\
E1C8B4E1CAB7E1CCBAE1CEBCE1D0BFE1D1C1E1D2C2E1D2C3E1D3C4E1D3C5E1D3C5
E0D3C4E0D2C3E0D1C2E0D0C0E0CFBEE0CEBBE0CDBAE0CCB8E0CBB7E0CBB7E0CBB6E0CAB6E0CAB6\
E0CAB5E1C9B4E1C7B3E1C6B1E0C4AFDFC2ACDEC1A9DDBFA6DCBEA3DBBCA0DABA9D
D9B79BD8B599D8B296D7B094D7AE93D6AC91D6AB90D5AA8FD6A98ED6A88ED6A88ED7A88ED7A88F\
D7A88FD7A88FD5A88FD4A88ED2A88DD1A78CD1A58AD0A489D0A387D1A187D1A186
D1A086D0A086CF9F86CD9F85CC9E83CA9D82C89C81C89C80C79C80C79C80C89B80C89B7FC89A7F\
C89A7FC7997EC7997EC6997EC6997DC5987DC4977CC2967BC1957AC09478BF9277
BE9176BE9075BC8F74BB8E73B98D72B88C71B78B71B88A70B8896FB9886EB8866CB5846BB18168\
AA7D65A17760976F598B66517F5B4871503E644535573A2D4C3126422B213C261E
37241C33231B2F221A2B1F19251B161F17141B1312181111171011171010171010160F0F150E0D\
130D0B120C0A130C0B140D0C160F0E1911101C1311211512291B1634241E45342C
5A49407262588A7C73A2968DB7AEA5C8C2BAD5D2CADDDDD5E2E2DBE3E4DDE3E4DDE3E3DCE2E2DB\
E2E2DAE1E2DAE1E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E1DAE2E1DA
E2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E2DAE1E2DAE2E2DAE2E3DB
E4E4DDE5E6DFE5E6DEE0E0D8D4D2CAC1BBB2A79D928C7C71735F53614B3F564034513C30503C32\
503E34513F36514037513F364F3E354D3C334A393047362D453229432E26402B22
3D271E38231B321F172D1D142A1B13291B132B1D1530211837251D3E2A214630264D362B543B2F\
5B41336347376B4D3B755440825D4790684FA07358AF8063BD8C6EC8987AD1A385
D7AD8FDBB598DEBA9FE0BEA3E0C1A7E1C2A9E1C3ABE1C3ACE1C3ADE1C3AEE1C3AFE1C4AFE1C5B1\
E1C7B2E1C8B4E1CAB7E1CCBAE1CEBCE1D0BFE1D1C1E1D2C3E0D3C4E0D3C5E0D3C5
E0D3C5E0D3C4E0D2C3E0D1C1E0D0C0E0CFBEE0CEBCE0CDBAE0CCB8E0CBB7E0CBB6E0CAB6E0CAB5\
E0C9B5E0C8B4E0C7B3E0C6B1E0C4AFE0C3ADDFC1AADEC0A7DDBEA4DCBCA1DBBA9E
DAB89BD9B599D8B296D6B094D6AE92D5AC90D4AA8FD4A98ED4A88DD4A78CD5A78DD6A78DD7A68E\
D7A78FD6A78FD5A78ED4A78DD2A68CD1A58AD0A488D0A287D0A185D0A085D09F85
D09F85D09E86CF9E86CD9E85CB9D83CA9C82C89C81C89C80C79B80C79B80C79B7FC89A7FC8997E\
C7987DC7987CC6977CC6977CC5977CC4977CC3977BC1967AC09579BF9378BE9176
BD8F74BC8E73BB8C71BB8C71BA8B71B98B70B98A70B9896FB9886DB8866CB68369B18067AB7C64\
A377609A715B8F6954845F4B7855426B4A395F403154372A4A2F2441291F3A251C
35221A3021192C1F18271C162219141E16131A1312181111171010161010160F0F160F0E150E0D\
150E0B140E0B150E0C160F0D18110F1A12101D13112216122B1C173827214B3A32
63534B7E7068998E85B0A89FC3BDB5D0CDC5D9D8D0DFDFD7E2E2DBE3E3DCE3E3DCE2E3DBE2E2DB\
E2E2DAE1E2DAE1E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E1DA
E2E1DAE2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DEE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E2DAE2E3DB
E4E4DCE5E6DEE4E5DEE0DFD8D4D2CAC0BBB2A69D938B7D72726055604C41554136513D32503D33\
513F355241375341385241385140374F3E354D3C324A382F47352C443027412C23
3D271F37231A311F172C1C14281A12271B122A1C1430201737241B3E2920462E244D3428553A2D\
5C40316546356E4D3A79553F855D4592664CA07054AE7B5EBA8768C59374CE9F81
D4AA8CD9B296DDB99DDFBDA2E0C0A5E1C2A8E1C3AAE1C3ABE1C3ADE1C3AEE1C3AEE1C3AFE1C4B0\
E1C5B1E1C7B3E1C9B5E1CBB7E1CDBAE1CEBDE0D0BFE0D1C2E0D2C4E0D3C5E0D3C5
E0D3C5E0D3C4E0D2C4E0D2C3E0D1C2E0D0C0E0CFBEE0CEBBE0CCB9E0CBB8E0CBB6E0CAB6E0CAB5\
E0C9B5E0C8B4E0C7B3E0C5B1E0C4AFE0C3ACDFC2AADFC0A7DEBFA4DDBDA1DCBB9E
DAB89BD9B599D7B296D6AF94D5AD92D4AB90D3AA8FD3A88DD3A78CD3A68BD4A58BD5A58CD6A58D\
D6A58ED6A58ED5A58DD3A58CD2A48AD1A389D0A287D0A185D09F84D09E84D09D84
D09D85D09D85CF9D85CD9D85CB9C83C99C82C89B81C79B80C79B80C79B7FC79A7FC7997EC7987D\
C7977CC6967BC6967BC5967AC3967BC2967BC1967AC1957AC09479BF9277BE9075
BD8E73BC8C71BB8A6FBB8A6FBB8A6FBB8A6FBB8A6FBA886EB9866CB68469B28066AD7C63A57860\
9D725C936B5688634F7D5946714F3D6645355B3C2D513427482D2240281E38231B
3220182C1E16281C15231A142018131D16121A1412191211171111171010160F0F160F0D160F0C\
16100C17100C17110D18120E19120F1B13101E13112316122C1C173C2A23524039
6E5E568C7F77A89F97BFBAB2CFCCC4D9D7D0DEDED6E1E1D9E2E2DBE2E3DBE2E2DBE2E2DBE2E2DA\
E1E2DAE1E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA
E2E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE2E1DAE2E2DA
E3E3DCE5E4DDE4E4DCDFDED6D3D0C8BFB9B1A59C93897C737060565E4C42544137503D33503E34\
5240365341385442395442395341385140374F3E344C3A3149362D453128412C23
3C271E36221A301F162B1C14281B12281B132A1D1530201836241B3E281F452D234C322754382A\
5C3F2F664634704D397B553E875D4494654AA16F51AD795AB88464C39071CB9C7D
D2A789D7B094DBB89BDEBDA0DFC0A4E0C2A7E1C3A9E1C3ABE1C3ACE1C3ADE1C3AEE1C3AFE1C4B0\
E1C5B0E1C6B2E1C8B3E0C9B5E0CBB8E0CDBBE0CFBEE0D1C1E0D2C3E0D3C4E0D3C5
E0D3C5E0D3C5E0D3C5E0D3C4E0D2C3E0D1C2E0D0C0E0CEBDE0CDBAE0CCB8E0CBB7E0CAB6E0CAB5\
E0C9B5E0C8B4E0C6B2E0C5B0DFC3ADDFC2ABDFC1A9DFC0A7DFBFA4DEBDA1DCBA9E
DBB79BD9B498D7B196D6AF93D4AD92D3AB90D3AA8FD2A88DD2A78CD3A68BD3A58BD4A48CD5A48C\
D6A48DD5A48DD4A48CD3A48BD2A389D1A287D0A185D09F84D09E83D09D82D09C83
D09C84CF9C85CE9D85CC9C85CB9C83C99C82C89B81C79A80C69A7FC6997FC6987EC6977DC6967C\
C6957BC5957AC49479C39479C29579C19579C09579C09479C09478BF9277BE9074
BD8D72BB8A70BB896EBB886EBB896EBB896FBB896FBA876DB7856AB48167AF7D64A87960A0745C\
976E578D6652825E4A7755426C4B3962423158392A4F3225462C213F271D37231A
301F172A1C14241A122118121E17121D16121B15121A141219121118111017100F17100D18110D\
18120C19120D1A130D1A140F1B14101C14101F14102416122E1D183F2C2657463E
76675F978C84B5AEA6CCC9C1DAD9D1E0E0D9E2E3DBE2E2DBE2E2DBE2E2DBE2E2DAE2E2DAE2E2DA\
E1E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA
E1E1DAE2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E2E1D9E2E1D9
E3E2DAE4E3DBE3E2DADEDCD4D2CEC6BDB7AFA39A92877B726E5F565C4B425241374F3D334F3D34\
514036534138544239544339544239524138503F354D3B3249372E4431283F2B23
3A261E342219301F162C1D152A1D142A1D152D1F1731211937251C3D281F432C224A3126513729\
5A3D2E644532704C387C553D885D43956549A16D50AC7759B78163C08D6FC9997B
D0A587D5AF92DAB69ADDBC9FDFBFA3E0C1A6E1C2A8E1C3AAE1C3ACE1C3ADE1C3AEE1C4AFE1C4B0\
E1C5B1E0C6B2E0C8B3E0C9B5E0CBB7E0CDBAE0CFBDE0D0C0E0D2C3E0D3C4E0D3C5
E0D3C5E0D3C5E0D3C5E0D3C5E0D3C4E0D2C3E0D1C1E0CFBEE0CDBBE0CCB8E0CBB7E0CAB6E0CAB5\
E0C9B4E0C8B3DFC6B1DFC4AEDFC2ABDFC1A9DFC0A7DFC0A5DFBEA3DEBCA0DDB99D
DBB69AD9B397D8B095D6AE93D5AC91D4AB90D3AA8FD3A88DD3A78CD3A68BD4A58BD4A48BD5A48C\
D5A38CD4A38CD4A38BD3A38AD1A288D1A186D0A084D09E83D09D82D09C82CF9C83
CF9C84CE9D85CD9D85CB9D84CA9C83C99C82C79B80C6997FC6987EC5977EC5967DC5957CC5947B\
C5947AC49479C39478C29478C19479C09479C09479C09479BF9378BF9277BE8F74
BD8D72BC8A6FBB896EBB886EBB896EBB896FBA896EB8876CB48469B08065AB7B61A4765D9D7159\
946B548A644E7F5B4774523E6948365E3F2E5537284C3023452B203E261C362219
2F1E16281C142319122018111E17121D17121D17131C16131B15121A13111A130F19120E1A130D\
1A130D1B140D1B150E1C150F1C15101E15102015102517122F1E18412E275B4941
7C6D659E948CBDB8B0D4D2CAE1E1D9E6E6DFE5E6DFE3E4DCE2E2DBE1E2DAE1E2DAE1E2DAE1E2DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA
E1E1DAE1E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E2E0D9E2E0D8
E3E0D9E4E1DAE3DFD8DDD9D2D0CBC4BCB5ADA1988F8579706C5D555A4A41513F364D3C324E3C33\
503F35524137544239544339544339534138513F364D3C3349372E4431283E2B22
38251D3322193020172E1F172D20172E211831221A34241C38261E3D2920412C234731254E3629\
573C2D6244326E4C377B543D885C43956549A06D50AB7659B58062BE8C6EC6977A
CEA386D3AD90D8B598DCBA9EDEBEA2E0C1A5E1C2A8E1C3AAE1C3ACE1C3AEE1C4AFE1C4B0E0C5B1\
E0C6B1E0C7B2E0C8B3E0C9B4E0CBB6E0CCB9E0CEBDE0D0C0E0D2C2E0D3C4E0D3C5
E0D3C5E0D3C5E0D3C5E0D3C5E0D3C4E0D2C3E0D1C1E0CFBEE0CDBBE0CCB8E0CBB7E0CAB6E0CAB5\
E0C9B4DFC7B2DEC5AFDEC3ACDDC1A9DEC0A6DEBFA5DFBEA3DFBDA1DEBB9FDDB89C
DBB599D9B196D8AF93D6AD92D5AC91D5AB90D4AA8FD4A98ED4A88DD4A78CD4A68BD4A58BD4A48B\
D4A38BD3A38AD2A38AD2A289D1A287D1A186D09F84D09E82D09D81CF9C81CF9C82
CE9D84CC9D85CB9E85CA9E84C99D83C89C81C79A80C6987FC5967DC4957CC4937BC3937AC3937A\
C39379C39378C29378C19378C09378C09478C09478BF9478BF9378BF9277BE8F74
BE8D72BD8B70BC896FBB896EBA896FB9896FB7886EB4866BB18268AC7E63A7795FA1745B9B6F56\
92695189624B7E5944724F3C6646335A3D2C5135264A2F22432A1F3D251C362219
2F1F16281C14231A122019121F18121E18131E18131E18131E17131D16121C15111C150F1C150E\
1C150E1C150D1C160E1D160F1D16101F1610211610261811311F18422F285D4B43
7F7068A29890C2BCB5D8D7CFE5E5DDE8E9E2E7E8E1E4E5DDE2E3DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA
E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E2DAE1E1DAE1E1D9E1E0D9E2E0D8E2DFD8
E3DFD8E4DFD8E2DED6DCD7D0CFC9C2BAB2AB9F958D83776E6A5B5359483F4F3D344C3A304D3B31\
4F3D34524036534138544239544239534238513F364E3C3349372E4331283D2B22
37261D33221A31211931221932231B33251C35261E37271F3A29203D2A21402D234430264B3529\
543B2D5F43326C4B377A543D875C4393644A9E6D51A97559B27F62BC8A6DC49579
CBA084D2AA8ED7B296DBB99CDEBDA1DFC0A4E0C2A7E1C3AAE1C3ACE1C3AEE1C4AFE1C5B0E0C6B1\
E0C7B2E0C8B3E0C8B4E0C9B5E0CBB6E0CCB9E0CEBCE0D0BFE0D1C2E0D2C3E0D3C4
E0D3C4E0D3C4E0D3C4E0D3C4E0D2C4E0D2C2E0D0C0E0CFBDE0CDBAE0CBB8E0CAB6E0CAB5E0C9B4\
DFC8B3DEC6B0DDC4ADDCC1A9DCBFA6DCBEA3DDBDA2DEBCA1DEBB9FDEB99DDDB69A
DBB397D9B094D8AD92D7AC90D6AB8FD6AA8FD5AA8ED5A98ED5A88DD5A88DD5A78CD4A58BD3A48A\
D3A38AD2A389D1A288D1A287D1A287D0A185D09F84D09E82D09D82CF9C82CE9D82
CD9E83CB9E84CA9F85C99E84C89D83C79C81C79A7FC5977EC4957CC3927BC2917AC29179C29179\
C19278C19278C19378C09378C09378C09378BF9378BF9378BF9377BF9176BF9075
BE8D73BD8B71BC8A70BB8A6FB9896FB7896FB4886DB0856AAC8166A87C61A3775D9E7258986D54\
91674F875F497C57416F4D39634331573A2A4E3324472D2041281E3B251B352119
2E1F17291C15241B13211A122019121F19132019132019131F19131F18121E17111D16101C160F\
1C150E1B150D1B150E1C160E1D160F1F1610221610271811311F184330285E4C44
807169A49991C3BEB6DAD8D0E6E6DEE9EAE3E8E9E1E5E5DEE2E3DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA
E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E2DAE1E1DAE1E1D9E2E0D9E2DFD8E2DFD7
E3DFD7E4DFD8E2DDD6DCD6CFCEC8C1B9B1A99E948C82756C695A5057463D4E3C324B382E4D392F\
4F3C32513E34534036544138544238534138513F364E3C3349382F4332293D2C24
38271F35251C34241C35251C36271E3828203929213A2A223C2B223D2C233F2E24433026483529\
513B2D5C4232694B3877543E855C4491644A9B6C51A57459AF7D62B8886CC19277
C99D81CFA78BD5B093D9B79ADCBC9FDFBFA3E0C1A7E0C2AAE1C3ACE1C3AEE1C4AFE0C5B1E0C6B2\
E0C7B3E0C8B3E0C9B4E0CAB5E0CBB6E0CCB9E0CEBBE0CFBEE0D0C0E0D1C2E0D2C3
E0D2C3E0D2C3E0D2C3E0D2C3E0D1C2E0D1C1E0CFBFE0CEBCE0CCB9E0CAB7E0C9B5E0C9B4DFC8B2\
DFC6B0DDC4ADDCC2AADBBFA6DBBDA3DBBCA0DCBB9FDDBB9FDDBA9EDDB89CDCB599
DBB296D9AE93D8AC91D7AA8FD6AA8ED6A98DD6A98DD6A98DD6A88DD5A88CD5A78BD4A68AD3A589\
D2A388D1A387D1A287D0A286D0A286D0A185D0A084D09E83D09E82CF9D82CD9E83
CC9E83CA9F84C99F84C89F84C89E82C79C81C6997FC5967DC4937CC3917AC29079C19079C19078\
C09178C09278C09277C09377C09277BF9277BF9277BF9277BF9277BF9176BF8F75
BE8E73BD8C72BC8B71BA8A70B78A6FB3896EB0876CAC8369A87F64A4795F9F745A9A6F55956951\
8D634C845C4679533E6C4A365F402F5338284A3123432B1F3D271C38241A332118
2D1E16281D15241B14211A13201A13201A13201A13201A142019132019131F18121D17101C150F\
1A140D19140D19140D1A140D1C150E1E150F21160F2718113220184430285F4C44
817169A49991C3BDB5DAD7D0E5E5DEE9EAE2E7E8E1E5E5DEE2E3DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E0D9E2E0D8E2DFD8
E3DFD8E4E0D8E2DED6DCD7D0CFC9C1B9B1AA9D938B80746B67584F56443A4D3A2F4B372C4D382D\
503B30523D32533F35534036534137524137513F364E3D344B393046352C403027
3C2B2339292038281F3928203A2A213B2B223C2C233D2D243D2D243E2E25402F25433126483529\
503A2D5B4232674B3975543F815D468D644B976B51A17258AA7A5FB48469BD8E73
C6997ECDA387D3AC90D8B497DBBA9DDDBEA2DFC0A6E0C2A9E0C2ABE0C3ADE0C4AFE0C5B1E0C6B2\
E0C7B3E0C8B3E0C9B4E0C9B5E0CAB6E0CCB8E0CDBAE0CEBDE0CFBEE0D0C0E0D0C0
E0D0C0E0D0C0E0D0C0E0D0C0E0D0C0E0CFBFE0CEBDE0CCBAE0CAB7E0C9B5E0C8B3DFC7B1DEC5AF\
DDC4ADDCC2AADBBFA6DABDA2DABBA0DABA9EDBBA9DDBBA9DDCB99CDCB79BDBB498
DAB195D9AE92D8AB8FD7A98DD6A98CD6A88BD6A88BD5A88BD5A88BD5A78BD4A78AD3A589D2A488\
D1A386D0A386D0A285D0A285D0A286D0A185D0A085D09F84CF9F83CE9E83CD9E83
CB9F83C99F83C89F83C79E83C79D82C79B80C6997FC5967DC4937BC3917AC29079C18F78C09078\
C09177C09277BF9277BF9277BF9176BF9176BF9176BF9176BF9075BF9075BF8F74
BE8E73BC8C72BA8B71B78A70B4896FB0876DAC856AA88166A47C61A0775C9B7157966B528F654D\
885E487E5742734E3B6645335A3C2C4F3426462E213F291D39251B352219302017
2B1E16261C14231B13211A122019122019132019132019132019131F18121D17111C151019140E\
17120C16110B15110B16120C18130D1C140E20150E281811342019473129614D45
837169A59991C3BDB5D9D7CFE5E4DDE8E9E2E7E8E1E4E5DEE2E3DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E0D9E2E0D8E2E0D8
E3E0D9E4E1DAE3E0D8DDD9D2CFCAC3B9B3AB9D948C7F736B66574D5543384D392D4C36294F372B\
513A2E533C30533E33533F355240365240375140364F3E354D3B3249382F45342B
4130273E2D253C2C233C2B233C2C233D2C243D2D253E2E253F2F26402F26413026443226483528\
503B2C5A4333664C3A7255417D5D4788634C9169509B6F55A4765CAE7F64B8896E
C29479CA9F83D1A88CD6B094D9B79BDCBCA0DEBFA5DFC1A8E0C2ABE0C3ADE0C3AFE1C4B0E1C5B1\
E0C6B2E0C7B2E0C8B3E0C9B4E0CAB6E0CBB7E0CCB9E0CDBAE0CEBCE0CEBDE0CEBD
E0CEBDE0CEBDE0CFBDE0CEBDE0CEBDE0CDBCE0CCBAE0CBB8E0C9B5E0C7B3DFC6B0DEC4AEDDC3AC\
DCC1A9DBBFA6DABDA2D9BA9FD9B99DD9B89CDAB89CDAB89CDBB89CDBB69ADAB498
DAB095D9AD91D7AA8ED6A88CD6A78AD5A789D4A688D4A689D4A689D4A689D3A589D2A587D1A486\
D1A385D0A384D0A284D0A285D0A285D0A185D0A185D0A085CFA084CE9F84CD9F83
CB9F83C99E83C89E82C79D82C79D81C79B80C6997EC6967DC5947BC49279C39078C29078C19077\
C09177BF9277BF9176BF9176BF9075BF8F75BF8F74C08F74BF8F74BF8E74BE8E73
BC8D73BA8C72B78B71B4896FB0886DAC856BA88267A47E63A0795E9C7358966D5390664E895F49\
80584376503D6B47375F3F305437294A3023412A1F3B261C35231A3020182C1E16
281C14241B132119122019121F18121F18121F18131F18131E17131D16121B141019130E16110C\
130F0B110E0A110E0A120E0A15100B1A120D20140F29191237221B4B342D665048
86746CA79B92C4BDB5D9D6CEE4E4DCE7E8E1E6E7E0E4E5DDE2E3DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E6DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E2E1D9E2E1D9
E3E2DAE5E3DBE4E2DADEDBD4D0CDC5BAB5AD9D958D7F746B66564C5542374E382B4D3528503629\
53392C543C2F533D31523E33513F35514036514037513F364F3E354C3B3249382F
46352C433229402F273F2E253E2D243E2D243E2E253F2F264030264131264331264633264A3628\
513B2C5A4333644D3B6F5542795D4882624C8B664F946A529D7057A8795EB38368
BE8E73C7997ECEA488D4AD91D8B598DBBA9FDDBEA4DEC0A8DFC2ABE0C2ADE0C3AEE1C4AFE1C4B0\
E0C5B0E0C6B1E0C7B2E0C8B3E0C9B5E0CAB6E0CBB7E0CBB8E0CCB8E0CCB9E0CCB9
E0CCB9E0CCB9E0CCB9E0CCB9E0CCB9E0CBB8E0CAB7E0C9B5E0C7B3E0C5B1DFC4AEDEC2ABDCC0A8\
DBBFA5DABCA2D9BA9FD9B89DD8B79BD9B79AD9B79BD9B79BD9B79BDAB599D9B397
D9AF94D8AC90D7A98DD6A78AD4A687D4A586D3A486D3A486D2A487D2A487D2A487D1A486D1A385\
D0A383D0A283D0A283D0A284D0A285D0A285D0A185D0A185CFA085CE9F84CD9F83
CB9E82C99D82C89D81C79C80C79C80C79A7FC6997EC6977CC6947BC59379C49178C39178C19177\
C09177C09177BF9176BF9075BF8F74BF8E73BF8D73BF8D72BF8D72BE8C72BC8C72
BA8C71B78B71B48A6FB0886DAC856BA88268A37E64A0795F9B745A976E5491674F896049815844\
77503E6D483962403258392C4E3226452C213D271D36241A3121182C1F16281D14
251B13221A112018111F18111E17111E17121D17131D16131C15121A131118120F15100D120E0B\
0F0C090D0B080D0B080F0C09130E0B19110E2216112E1D173F2922543D356F5950
8E7B73AC9F97C6BFB7D9D6CFE3E3DBE6E7E0E6E7DFE4E4DDE2E3DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E2E1D9E2E2DA
E4E3DBE5E4DDE4E4DCDFDED6D2CFC8BBB7AF9E978E80756C66574D5642364F372A4E3426513627\
54392A543B2D533C30523D32513F355140365240375241375140364F3E354C3B32
49382F46352C433229402F263F2D253E2D243F2E24402F254230264432274532264834274C3729\
523C2D5A4434634D3C6C5543755B487D5F4B84624C8C654D966A51A17258AD7C62
B9886DC39478CC9F83D2AA8DD6B296D9B99DDCBDA3DEC0A7DFC2AAE0C2ACE1C3ADE1C3ADE1C3AE\
E1C4AEE0C5B0E0C6B1E0C7B2E0C8B3E0C9B4E0C9B5E0CAB5E0CAB5E0CAB5E0CAB5
E0CAB5E0CAB5E0CAB5E0CAB5E0CAB5E0C9B5E0C8B4E0C7B2E0C5B1E0C4AFDFC2ACDDC1A9DCBFA6\
DBBDA2DABB9FD9B99DD8B79BD8B699D8B699D8B699D8B69AD8B699D8B498D8B196
D8AE92D7AB8FD6A88BD5A588D3A485D2A384D1A283D1A284D1A285D1A285D1A286D1A285D0A284\
D0A283D0A283D0A283D0A284D0A285D0A185D0A185D0A085CFA084CE9F83CD9E82
CB9D81C99C80C89B80C79B7FC79A7FC79A7EC7987DC7977CC6957AC69479C59378C49278C29277\
C19277C09177BF9076BF8F74BF8D73BF8C72BF8B71BF8B71BE8B70BD8A70BA8A70
B78A70B4896FB0886DAC856BA88268A37E649F7A5F9B745A966E5590684F8A614A81594478513F\
6E49396441345A3A2E503328482D2340281F38241B3221192D1F17281D15251C13
231A122119101F18101E17101E16111D16121C15121B14121A1311181110160F0E130D0C0F0B0A\
0D0A080B08070B08070D0A08130D0B1C1210281A173726204B362F624B447D675F
99877FB4A89FCAC4BCDAD8D0E2E2DBE5E6DFE5E6DEE3E4DCE2E2DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE1E1DAE2E1DAE2E2DB
E4E4DCE5E6DEE5E5DEDFDFD8D3D1C9BDB8B0A0989083766D69584E58433750372A4F3425513526\
533829543A2C533C2F523E32523F35524037524138534138524137503F364E3D34
4B3A3147362D44322A412F263F2D243F2C23402D23412F244431254632264733274A35284D382A\
523D2E594535614D3C695443715947775C487E5D48855F488E634B9A6B52A7755B
B38267BF8F73C89B7FCFA78AD5B094D9B89CDBBDA2DEC0A6DFC2A9E0C2AAE1C2ABE1C2ABE1C3AC\
E1C3ADE0C4AEE0C5AFE0C6B1E0C7B2E0C7B2E0C8B2E0C8B2E0C8B1E0C8B1E0C8B1
E0C8B1E0C8B1E0C8B1E0C8B1E0C8B1E0C7B1E0C6B0E0C5B0E0C4AFE0C3ADDFC1ABDEC0A8DCBEA5\
DBBCA1DABA9ED9B89CD9B69AD8B598D8B498D8B498D8B498D8B397D8B296D7AF93
D6AB90D6A88CD5A589D3A385D2A283D1A182D1A082D0A082D0A083D0A084D0A085D0A184D0A184\
D0A283D0A283D0A283D0A284D0A285D0A185D0A085D09F84CF9E83CE9D82CD9D81
CB9C80C99B7FC89A7FC79A7EC7997EC7997DC7987CC7967BC7957AC79479C69378C49378C39277\
C19277C09176BF9075BF8E74BF8D72BF8B71BF8A70BF896FBD896EBB886EB8886E
B4876DB0866CAC856AA88267A37E649F7A5F9A745A956E558F685088614A81594578523F6F4B3A\
6643355C3C2F53352A4A2F25422A203B251C3422192F1F172A1E15261C14241B13
221A112119102018101F17101E16111D15121C14121A1312191111160F0F140D0D110B0B0E0A09\
0C08080B07070B08070F0908160E0C21161431231F45342F5D494376625A907E75
A99A92BEB4ACD0CAC2DBDAD2E2E2DAE4E5DDE4E5DDE3E3DCE2E2DBE1E2DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE2E2DAE2E3DB
E4E4DDE5E6DEE5E6DEE0E0D8D3D2CABEBAB2A39A9286786F6C5A505B443952382B4F3425513525\
523728533A2B533C2F533E335340365341385342395342395241385140364E3D34
4B3A3047362D443229412E253F2C233F2B21402C22432E234531244733264934274B36294E392B\
523E305845365F4C3C6652416C56447157447757437E5843875C4692644CA06E56
AD7B61BA896EC4977BCDA487D3AE92D8B79BDBBDA1DEC0A5DFC1A7E0C2A9E1C2A9E1C2A9E1C2AA\
E1C3ABE0C3ACE0C4ADE0C5AFE0C5B0E0C6B0E0C6AFE0C6AEE0C6AEE0C6ADE0C6AD
E0C6ADE0C6ADE0C6ADE0C6ADE0C6ADE0C5ADE0C5ADE0C4ADE0C3ADE0C2ACDFC1AADEC0A8DDBFA5\
DCBDA2DBBB9FDAB89CD9B69AD8B498D8B397D8B396D8B296D7B195D7AE93D6AB90
D5A88DD4A589D3A286D2A083D19F81D09E80D09E81D09E82D09E83D09E84D09F84D09F84D0A084\
D0A184D0A284D0A284D0A284D0A285D0A184D09F83D09E82CF9C81CE9B80CD9B7F
CB9A7FC99A7EC8997EC7997DC7987DC7977CC7967BC7957AC79479C79478C69378C49378C39377\
C19277C09176BF9075BF8E74BF8C72BF8B70BF896FBE886EBC876DB9866CB6866B
B1856AAD8369A88167A47E639F7A5F9B755A956F558F685088604A80594577513F6F4B3A674435\
5E3E3056382B4D3226452C223E271E37231A3120182C1E16281D15251C14231B13
231A122219112218112117112016121E15121C14121A1212181110160F0F130D0D110B0B0E0909\
0D08080C07070E0807120A091B110E291C183D2E2956453F72605A8D7D75A69890
BAB0A8CAC3BBD6D2CADDDCD5E1E2DAE3E4DCE3E3DCE2E3DBE2E2DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE2E2DAE2E3DB
E4E4DDE5E6DEE5E6DEE0E0D8D4D2CBC0BBB3A69C948A7B72705D535E473C543A2D503526503525\
51372752392B523C2F533F33534136544238544339544239534138503F354E3C33
4A392F47352B433127412D243F2B213F2A20412B20442E224630234933254A35274C372A4E3A2D\
513F315644375C4A3B624F3F6752416B524070523F76523F7F56418B5D47986850
A7755CB48469C09277C9A084D1AC8FD6B599DABB9FDDBFA3DFC1A6E0C2A7E0C2A7E0C2A8E0C2A8\
E0C2A9E0C3AAE0C3ABE0C3ADE0C4AEE0C4ADE0C4ADE0C4ACE0C4AAE0C4AAE0C4A9
E0C4A9E0C4A9E0C4A9E0C4A9E0C4A9E0C3AAE0C3AAE0C3ABE0C2ABDFC2ABDFC1AADFC0A8DEBFA5\
DDBEA2DCBC9FDBB99CDAB69AD9B497D8B296D8B195D7AF93D7AD92D6AB8FD5A88C
D4A589D3A286D29F83D19E81D09D80D09C7FCF9C80CF9C81CF9C82CF9C84CF9D84CF9E85CF9F84\
CFA184CFA184CFA285D0A285D0A184D0A084D09E82D09C80CF9A7ECE997DCC987D
CB987DC9997DC8997DC7987DC7977CC7967BC7957AC79479C79478C79378C69378C49377C39377\
C19277C09176BF9075BF8E73BF8C71BF8A70BE886EBD876DBB866BB8856AB38469
AF8268A98166A47E63A07A5F9B755B966F5590695089614A80594477513F6E4A3A6644355E3E30\
57392C503427482F23412A1F39251B3321182D1E16291C15261C14241B13241B13
241B12241A122419122418122217131F16131C14121A1212171010150E0E130C0C110A0B0F0909\
0E08080E0808110908170C0A21141032221E4A3933675750867770A3978FBBB2AA
CCC5BDD6D2CADCDAD2E0DFD7E1E1DAE2E2DBE2E2DBE2E2DBE2E2DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE1E1DAE2E2DAE2E3DB
E3E4DCE5E6DEE5E5DEE0E0D8D5D3CBC2BCB4A99F968E7F76756157624B40573D315137294F3627\
4F372850392B513C30533F34544137554239554339554239534137513E344D3B31
4A382D463429433026412C23402A21402A20422B20442D214730234933254A35284C372B4D3A2F\
503E3254433659483A5D4B3C614D3D654D3C694C3B6F4D3B77503D83574391624C
A07057AE7E64BB8D71C59B7FCEA88BD4B295D9B99CDCBDA0DEC0A3DFC1A4E0C1A5E0C2A6E0C2A6\
E0C2A7E0C2A8E0C2AAE0C2ABE0C3ACE0C3ABE0C3AAE0C3A9E0C3A8E0C3A7E0C3A7
E0C3A7E0C3A7E0C2A6DFC2A6DFC2A6DFC2A7DFC1A7DFC1A8DFC1A9DFC1AADFC1A9DFC1A8DFC0A6\
DEBFA3DDBDA0DCBA9DDAB69AD9B397D8B194D7AE92D7AC90D6AA8ED5A78CD4A589
D3A286D29F83D09D81D09C7FCF9B7ECF9B7ECE9A7FCE9A80CE9B82CE9B83CE9C84CE9D84CE9F85\
CFA085CFA185CFA185CFA185CFA084CF9F83CF9C80CF9A7ECE987CCD977BCC967B
CA977BC9977CC7977CC7977CC7957BC7947AC79379C79378C79378C69377C59377C49377C29377\
C19276C09175BF9074BF8E72BE8C71BE8A6FBD886DBC866CB9856AB68469B18267
AC8066A67E63A17A609C765B977056916A508B624A825A4478523F6E4A3A6543355D3D3057392C\
5035274A3123432C1F3C271C3522182F1F162A1C14261B14241B13241B13241B13
251B13261B13271A132619132418132116131D14131A1211171010150E0E130C0C110A0A100909\
0F0909100908140A081B0E0B2717133A282254433C75655E978A83B5ADA5CCC7BF
D9D6CFE0DED7E2E1D9E1E1DAE1E1DAE1E2DAE1E2DAE1E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE2E2DAE2E2DB
E3E4DCE5E5DEE4E5DEE0E0D8D5D3CCC4BEB6ACA29992837A7A665C6750455A4235523A2D4F3729\
4E382A4F392C503C30523E34534137554239564339564238544036513E334E3B2F
4A372C473328443025422D23412B21412B20422C20442D214630234832254935284B372C4D3A2F\
4F3E335241355544375846395B47395E4738624738674839704C3B7C53418A5E49
996B53A7795FB4876BC09578C9A284D0AC8ED6B496DABA9CDCBDA0DEBFA2DEC0A3DFC1A4DFC1A4\
DFC1A5DFC1A6DFC1A8E0C2A9E0C2AAE0C2A9E0C2A9E0C2A8E0C2A6E0C2A6E0C2A5
E0C2A5E0C2A5DFC1A4DFC1A4DEC0A4DEC0A4DEC0A5DDBFA6DDC0A7DEC0A8DEC0A8DFC1A7DFC0A6\
DEBFA4DEBDA1DCBA9DDBB699D9B296D8AF93D7AB90D6A98DD5A78BD4A488D3A286
D2A083D19E81D09C7FCF9B7ECE9A7DCD997DCD997ECD997FCD9981CD9A82CD9B83CD9C84CD9E84\
CD9F84CE9F84CEA084CFA084CF9F83CF9D81CF9B7FCE987DCD967BCC9579CB9579
C9957AC8967BC7967BC7957BC7947AC79279C69178C69177C69177C59277C49377C39377C29376\
C19275C09174BF8F73BE8D71BE8B6FBD896EBC876CBA856BB78469B48368AF8166
AA7F64A47C619E775D987258926B528C644B845C457B533F714B3A6744345E3E3056382B503427\
493023432C1F3D281C3624183020162A1C14261A13241912221913221A13241A14
261B14281B14281B14271A142519142217141E15131A121117100F140D0D120B0B10090A100909\
100809120908160A091D0F0C2A19143F2C255B49427D6E66A0968EC0B9B2D6D3CB
E2E1D9E6E6DEE5E5DEE3E3DCE2E2DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E2DB
E3E4DCE4E5DEE4E5DDE0E0D8D6D4CCC5C0B8AFA59C96877E7E6B616B554A5D463B543D31503A2D\
4E392C4E3A2E4F3B30513E33534036554138564239574238554036533D324F3A2E
4B362A483327453025432E23422D22412D22422D22432E22442F2346312547342849372C4B3A2F\
4D3C324F3F345140355241355442355742355B433560453769493A75503F835A46
91664FA07359AD8164B98E70C39A7CCBA586D2AE8FD7B596DABA9CDCBD9FDDBFA1DDBFA2DDBFA3\
DDC0A3DEC0A4DEC0A5DFC1A7E0C1A8E0C2A8E0C2A7E0C2A6E0C2A6E0C2A5E0C2A5
E0C2A4E0C1A4DFC0A3DEC0A3DDBFA2DDBEA2DCBEA2DCBEA3DCBEA4DCBEA5DDBFA6DEC0A6DEC0A5\
DEBFA3DEBDA1DCB99DDBB599D9B094D7AC91D6A98DD5A68AD4A388D3A285D2A083
D19F81D09D7FCF9C7ECE9A7CCD997CCC987CCB977CCB977ECB987FCB9981CB9A82CB9B82CB9C83\
CB9D83CC9E83CD9E83CE9E82CE9D81CE9C80CE997ECD977BCC957ACB9478CA9478
C99479C89479C7947AC79379C79279C69078C69077C69077C59077C49177C39277C29376C19375\
C09274BF9173BE8F71BD8C6FBC8A6EBB876CBA866BB8846AB58369B28267AD8065
A77E63A17A5F9B745A946E548D664E865D477E5540744D3A6A4634613F3058392B503427493023\
432C1F3D281C3724183020152B1D13261A12231811211811201812211813231914
251A14281B14291B14281A142619142217141E15131A1211160F0F130C0C110A0A1009090F0808\
100808120908170B091F100C2C1A15412E275E4C4481726AA49A92C4BEB7DAD8D0
E5E5DEE8E9E2E7E7E0E4E4DDE2E2DBE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE2E2DB
E3E4DCE4E5DDE4E5DDE0E0D8D7D4CDC6C1B9B1A79E998B818270666E5A4F604B3F564135513C30\
4E3A2F4D3A2F4E3B314F3D33523F35544037564138574137564035543D31513A2D
4D3729493426463125443024432F24412E24412E23412E23422E2443302545332848362C4A392F\
4C3B314D3C324D3D324E3D324F3D32513E32553F345A42366347396E4E3D7B5643
8A614A986C53A5795DB28668BC9273C59D7DCDA787D2AF90D6B597D9BA9CDBBC9EDBBDA0DCBDA0\
DCBDA1DDBEA2DDBFA3DEC0A4DFC0A5E0C1A6E0C1A6E0C1A5E0C1A5E0C1A4E0C1A4
E0C1A4DFC1A3DEC0A3DDBFA2DCBEA1DBBDA0DABCA0DABCA0DABCA1DBBDA2DCBEA3DDBFA4DEBFA3\
DEBFA2DEBCA0DCB89CDBB498D9AF93D7AA8FD5A68BD4A387D3A185D29F82D19E81
D09E7FCF9D7ECE9C7DCD9A7CCC987BCA977BCA967BC9967CC9977DC9987FC99980C99A80C99B81\
CA9C81CB9C81CC9C81CD9C81CE9B80CE9A7ECD987DCC967BCB9479C99378C89377
C79378C79378C79278C79178C69078C68E77C68E77C58E77C48F76C29076C19176C09275C09274\
BF9273BE9071BD8E6FBC8B6DBA886CB9866AB78469B58368B38267AF8166AA7F64
A57C619F775D977157906A518861497F5842774F3B6D47356440305B3B2B5235274A3123432C20\
3C281C3624193020152B1D13261A112218101F17101E16101E16111F1712211813
241914261A14281A14271A142519142117131D1412181110150E0D120B0B1009090F08080F0808\
100808130908180B0920100C2E1B15422E275F4C4481726AA59A92C3BEB6D9D8D0
E5E5DEE8E9E2E7E8E0E4E5DDE2E2DBE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DB
E3E3DCE4E5DDE4E4DDE0E0D8D7D5CDC7C2BAB2A9A09B8E84847469715E53624E43584439523F34\
4F3C314D3B314D3B314F3D33513E35544036564137574137573F34553D31513A2D
4E37294A3427473226453125423026412F253F2E253F2D243F2E24412F2643312846342B48372E\
4A39304B3A304B3A304B3A304B3A304D3B31503D325640345D4437684A3B74523F
815B458F654C9C7155A97D5FB4896ABE9474C69F7FCDA889D2AF91D6B597D8B89AD9B99CDABA9D\
DABA9EDBBB9FDCBDA0DEBEA2DFBFA3DFC0A4DFC0A4E0C0A4E0C0A4E0C0A3DFC1A3
DFC0A3DFC0A3DEBFA2DCBEA1DBBDA0DABC9FD9BB9ED9BA9ED9BA9EDABB9FDBBCA0DCBDA1DDBEA1\
DDBDA1DDBB9EDCB79BDAB296D8AD92D6A88DD4A489D2A085D19E82D09D80D09D7F
CF9D7ECE9D7DCD9C7CCC9A7BCA987AC99679C89579C8957AC8967BC8977CC8987DC8987EC8997E\
C89A7EC99A7FCA9A7FCC9A7FCD9A7ECD997DCC977BCB957AC99478C89377C79277
C69277C69177C69077C68F76C68E76C58D76C58C76C38D76C28E75C18F75BF9074BF9173BE9172\
BD9071BC8E6FBB8C6DB9896BB78669B58368B38267B18066AF7F64AB7E63A77C61
A2795E9B745A946E548C654D825C4579523D6F49366641305D3B2B5436274C3223442D203D281C\
3624193020162B1D13261A1122180F1F160E1D150E1B140F1C14101D15111F1612
2217132418132518132518132217131F15121A1211160F0F120C0C0F090A0E08080E07070F0807\
120908160B091B0D0A23110C2F1B15432E265F4B43807168A39890C1BCB3D7D5CE
E3E3DCE7E8E1E6E7E0E4E5DDE2E3DBE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DB
E3E3DCE4E5DDE4E4DDE0E0D8D7D5CDC8C3BAB3ABA09C908486766A7260546451455A473B544136\
503E344E3C334E3C334F3D34513E35533F36554036564036563F34543D31513A2D
4E372A4A3528473327443126412F263F2E263E2D253D2C243D2D243F2E2541302744332A47362C\
49382E4A392F4A39304A39304A392F4B3A304E3C31523E325941346146366C4C3A
78543F855D4592684E9F7457AA8061B58C6CBF9777C7A081CDA88AD2AE91D5B295D6B497D7B599\
D8B69ADAB89BDBBA9DDCBB9FDDBDA0DEBEA1DEBEA1DFBEA1DFBEA2DEBFA2DEBFA2
DEBFA2DDBFA2DDBEA1DBBDA0DABC9FD9BB9ED8BA9DD8B99CD8B99CD9B99DDABA9DDBBB9EDCBB9F\
DCBB9EDCB99CDAB599D9B195D7AC90D4A78CD2A287D19F83CF9C80CF9B7ECE9B7D
CE9B7CCD9B7CCC9B7BCB997ACA9779C89579C79478C79378C79479C7947AC7957AC7967BC7977C\
C7977CC8987CC9987DCA987DCB987CCB977CCB967ACA9579C89378C79277C69176
C59176C59075C58F75C58D75C48C75C48B75C38B74C28B74C08C73BF8D73BD8E72BC8E71BC8E70\
BB8E6EB98C6DB88A6BB58769B38467B18165AE7F64AC7D62A97B61A67A5FA2785C
9D74599770559069508761497D5741724D396844325E3C2B5536264D3123452D1F3E291C37251A\
3121172C1E14271B122318101F170E1D150D1B140D1A130E1A130F1B13101C1311
1F14112115122216112116111E14111B121016100E120D0C0F0A0A0C08080C07070D0707110908\
150B0A1A0D0B200F0B27130D331C15452E255F4A40806F65A2968DC0BAB1D6D4CC
E2E2DAE6E7E0E6E7DFE4E4DDE2E3DBE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DA\
E1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA
E3E3DCE4E5DDE4E4DDE0E0D8D8D6CDC8C4BAB4ABA19D918486776A7462556553465C493D554338\
524036503E35503E35503E35513F35533F36543F36543F35543E33533C31513A2E
4E382C4A352A4633284330273F2E273D2C263C2B253B2B243C2C243E2D25402F2743322945352B\
47372D49382F4A39304B3A304B3A304C3A304D3B2F503C2F553E305C4131644634
6F4D387A553E876046946B50A0775AAC8365B68E70BF987AC6A082CCA689D0AA8ED3AD91D4AF93\
D6B194D8B396D9B599DBB89BDCB99CDCBA9DDDBB9EDDBB9EDDBC9FDDBC9FDDBDA0
DCBDA0DCBDA0DBBDA0DABC9FD9BB9ED9BA9DD8B99CD8B89BD8B79BD8B79BD9B89BDAB89BDAB89C\
DBB89BDAB69AD9B397D7AF94D5AB8FD3A68AD1A186CF9D82CD9A7ECC997CCC987B
CC997ACB997ACB987ACA9779C89678C79478C79377C69277C69277C69277C69277C69378C69479\
C7957AC7967AC8967BC9967BCA967ACA957AC99579C89478C79377C69276C59075
C48F74C38E74C38D73C38C73C38B73C28A73C28A72C08A72BF8A71BD8A70BB8B6FBA8B6EB98B6D\
B88A6CB6896BB48769B18467AE8165AB7E63A87B60A6795EA3765CA074599C7257
986E54936A508B644B825C4477523C6B4834603F2D5637274D3122452D1F3E291C382519322217\
2D1F15281C13241A1121180F1E160E1C140D1A130C18120D18110E18110F1A110F
1B12101D12101D13101C120F19110E150F0D110D0C0D0A0A0A08080906060A06060D0807130B09\
190E0C20110D26140E2D170F381F16493025624B40816F65A2968CC0B9B0D5D3CB
E1E1DAE6E6DFE5E6DFE4E4DDE2E2DBE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA
E3E3DCE4E5DDE4E4DDE0E0D9D8D6CEC9C4BBB5ADA29E928688796B7664566855485E4B3F58453A\
544238524037513F36523F36523F36523F36533F35523E35523E33513D32503B30
4D392E4A362C46332A4230283E2D263C2B253A2A243A2A233B2B233D2D243F2F2642312844342A\
47362D49392F4B3A314C3B324D3C324D3B304E3A2F4F3A2D523A2C563C2C5D402E
654532704D387C5740886349956F54A17A5EAC8568B68E72BE9679C49C80C9A184CDA488D0A78B\
D2AA8ED4AD91D6B093D8B396D9B598DAB699DBB79ADBB79BDBB89BDBB99CDBB99D
DABA9EDABB9EDABB9ED9BB9ED8BA9ED8B99DD7B89BD7B79AD7B699D8B599D8B599D9B599D9B599\
D9B598D8B397D7B195D5AD92D3A98ED0A489CE9F84CC9B7FCA977CC99579C99578
C89578C89578C89577C79477C79377C69276C69175C69075C68F74C68F74C69075C69075C69276\
C69377C79378C79478C89478C89478C89378C89378C79277C69276C59175C49074
C38E73C28D72C28C72C18B71C18A71C18971C08970BE886FBD886EBB876DB9876CB8876BB6876A\
B58669B38668B08467AD8265A97F63A67B60A2785D9F745A9C7156996D53966B50
92674D8D634A865E457C563F714D37654330593A294F3323462D1F3E281B3824193221172D1F15\
291D14251B122219111F170F1D160D1B140C19120C18110C17100D170F0D170F0E
180F0E190F0E180F0D170F0D140D0C100C0A0C09090907070706060605050806060E0908150D0B\
1E110E2716112E1912361D1440261B50362A685045867368A5998FC1BBB2D6D3CB
E1E1DAE5E6DFE5E6DFE3E4DCE2E2DBE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA
E3E3DCE4E4DDE4E4DDE1E0D9D9D7CFCBC6BDB7AFA4A296898C7D707A685B6C584C614E425B473D\
56433A544138534137534037534037524036513F35513E34503D33503D334F3C32
4E3B314B382F47342C4230293E2C263B2A243A29233A29223B2A223D2C24402E2542312844342A\
47372D4A39304C3B324E3D334E3D334F3C314E3B2E4F392B503829523829563A2A
5D3F2D654633704F3A7C5A4489664E957258A07C61AA8469B28B70B99175BF957AC4997EC89D81\
CCA185D0A589D3A98DD5AD90D7B093D8B295D8B296D8B396D8B397D8B498D8B599
D8B79AD8B89CD8B89DD7B99DD7B89CD7B79CD6B69AD6B599D6B497D7B397D7B396D7B396D7B396\
D7B296D6B195D5AE93D3AB90D0A78CCDA287CA9D81C8987CC69478C49176C49074
C49074C49074C49074C49074C59074C58F73C58F73C58E72C58D72C58D72C58D72C58E73C58F74\
C69075C69176C69176C69176C69176C69175C69175C69075C69075C59074C48F73
C28D72C18C70C08B6FC08A6FBF896FBF896FBE886EBC876DBB866CB9856AB78469B58368B48367\
B28367AF8266AC8165A97F63A57C61A1795E9D745A997055956B5191674D8E634A
8B6046865C437F563F754F396A47325E3E2C523626482F203F291C3824193220162D1E15291C14\
261B13231A122118101E170F1C150D1A130C18110C17100B160E0C150D0C150D0C
150D0C150D0C140C0B120B0A0F0A090B08080807060505050404040504040806050E0908170E0C\
2214102D1A1436201840261C4C31255C4236735C508F7D72ACA095C5BFB6D7D5CD
E1E1DAE5E6DEE5E5DEE3E4DCE2E2DBE1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA
E3E3DBE4E4DDE4E4DDE1E1D9DAD8D0CDC9C0BCB4AAA89C91938479816F64725F536652485E4A40\
59453B564239544138544138534137524036513F35503E34503E34503E34503E34
4F3D334D3B3249372E45322A402D273D2A233C28213B28213C29213E2C23402E2543312846352B\
48382E4B3A314C3C324E3D334F3D334F3C314F3B2E4E392C4E37294F3628513728
553A2A5C3F2E65483671533E7D5E488969519372599C7960A47F65AB836AB2886EB88C72BE9176\
C4967BC99C80CDA285D1A68AD3AA8ED4AC90D5AD90D5AD91D4AE91D4AF92D4B094
D5B297D5B499D5B59AD5B59BD5B59BD5B49AD4B398D4B297D4B195D4B094D5B093D5B093D6B093\
D5AF93D4AE92D3AC90D0A88DCDA488C99F83C5997DC29378BF8F73BE8C70BD8A6F
BD8A6EBE8A6EBF8A6FC08B6FC18B6FC28B6FC38B6FC38B6FC48B6FC48B70C48C71C48D72C58E73\
C58E74C48E74C48E73C48D72C48D72C48D72C58D72C58E73C48E73C48E72C38E71
C28D6FC18B6EC08A6DBF896CBE896CBD886CBC876CBB856BB98469B78267B58166B38065B17F64\
AF7F63AC7E63A97E62A57C61A17A5F9D765B987157936B528F654C8A6048875B43
8358407E533C774F386E483363412D5839284D3222432B1E3B261A3421172F1E152A1C13271B12\
241A112119101F170F1D160E1B140D19120C17100B160F0B150D0B140C0B140B0B
130B0B120A0A1109090E08080B07070806060505050304040304040404040806060F0A08180F0C\
241611311E173E271E4B33285B41366E5549846F639D8D82B6ABA1CBC5BCD9D7CF
E1E1DAE4E5DEE4E5DDE3E3DCE2E2DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA
E2E3DBE3E4DCE3E4DCE1E1D9DBD9D2D0CCC4C1BAB2B0A59C9D8E868B79707A675E6D584F624D44\
5B463D574339554138544137534137524036503E354F3E344F3E34503F35514036
513F36503D344D3A3048352C443027402C233E29203D281F3D29203F2B22412E2544322947362D\
4A39304C3B324D3C324D3C324E3C324E3C314E3B2F4E3A2D4E382B4D36294D3528
4F3629543B2C5C4232664C3A7257437C604B8668518D6E5694725A9B765EA37A61AA7F65B2846A\
B98A70C09176C6997DCB9F83CEA387D0A689D0A78AD0A78ACFA78BCFA88CD0AA8F
D0AC92D1AE95D1AF97D1B098D1B097D1AF97D1AE95D1AD93D1AD92D1AC91D2AC90D3AD90D3AD91\
D3AC90D2AB8FD0A88CCDA489C99F84C49A7EC09378BB8D72B8886DB6856AB58368
B68368B78368B98468BB8568BD8568BE8669C0876AC1886BC2886CC2896EC38A6FC38B71C38C72\
C38C72C38C71C38B70C2896FC2886EC2886EC3896EC38A6FC38C70C28C70C28C6F
C18C6DC08B6BBF8A6ABE8969BD8869BC866ABA8569B88368B78167B58065B37E63B17D62AF7C61\
AC7B60AA7B60A67A5FA2795E9E775C997359946D548E674E8960488459437F543E
7B4F39764B356F463166402D5C3A28513324472D203F281C372319311F162C1C14281B12251911\
2218101F170F1D160E1B140D19120C18110C160F0B150E0B140C0B130B0A120A0A
1109091008090E07080C06060905050604040404040304040304040605050A0706100A08190F0B\
24161133211A442F265741366C564B826D6299877CAEA197C2B9AFD1CCC4DCDAD2
E1E1DAE3E4DDE3E4DCE2E3DBE2E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA
E2E2DBE3E3DBE3E3DBE1E1D9DCDBD3D4D0C9C8C1BBB9AFA9A89A9496857F84716A745F57675148\
5E483E584339554137544036524036513F35503E354F3E34503E35514036534138
534138524036503C324C382D483228432E23402A203E281F3E281F402B22432E2546332A49372E\
4C3A314C3B324C3C324C3B314C3B314D3B304E3B304F3B304E3A2E4C372C4B352A
4A35294D382B543E305D473667503E705845785E4A7E624D8466508B6953936C569B7159A4775E\
AE7E64B6866CBE8F73C4967AC89B80C99E82C99F83C99F83C89F83C8A085C8A288
C9A48CCAA78FCBA891CBA992CBA992CBA991CBA890CCA78ECCA78DCCA78CCDA88CCEA88CCFA98D\
CFA88DCEA78BCCA488C89F84C49A7EBE9378B88C71B3866BAF8166AD7D63AC7B61
AD7B60AF7B60B17C60B47E61B77F61B98062BB8264BD8466BE8569BF876BC0886DC0896FC18A6F\
C18A6FC1896EC0876CC0856AC08469C08469C0856AC0876CC0886DC08A6DBF8A6C
BF8A69BE8967BD8866BC8766BB8566B98466B88266B68166B47F64B27D63B07B61AE7A5FAC795E\
A9785DA7775DA3775C9F765B9B7359956F5690695189624B835A447D533E784D39
7348346D432F663E2B5E39275533244B2E2043291D3B251A3521172F1E152B1B13271A11231810\
20170F1D150E1B140D19120C17100B160F0B150D0B140C0B130B0A120A0A110909
1008080E07070C06060905050704040504040303040304040505050806060C0707120A08190E0B\
24161134231C49362E624F457D6A6097867CAEA096C0B6ADCEC7BFD8D4CCDEDDD5
E1E1DAE2E3DBE2E3DBE2E2DBE1E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DA
E2E2DAE2E3DBE2E3DBE1E1D9DEDDD5D8D5CFCFC9C4C3BAB6B3A7A3A1928D8E7C767C675F6C564D\
604A40594338554035533F35513F35503E344F3D344F3D34503E35514037534238
554239544137523E334E3A2E4A3528463023422B203F291E3F281F402A21432E2547332A4B382E\
4D3B314D3B314C3B314B3A304B3A304C3B314E3C324F3D334F3C324D3A2F4A372D
48352B4A362B4E3B2F5642345E4A3A6651406C5643715946765B487C5D4A84614C8D654F976B54\
A1735AAB7B61B38469BA8C71BF9276C09479C0957ABF957ABE957BBE967DBE9881
BF9B84C19D87C29E89C29F8AC39F8AC49F89C49F88C4A087C5A086C6A186C7A286C9A387C9A388\
C9A387C8A185C59D82C1987DBC9277B68B71B0856AAA7E64A6795FA3755BA37459
A47358A67358A97559AC7659AF7859B27A5BB57C5DB87F60BA8164BB8367BC856ABD866BBD876C\
BD866BBD856ABE8368BE8166BE8065BE8065BE8166BE8368BD8569BD8669BC8768
BB8665BB8563BA8461B88361B78261B68062B57F63B37D62B17C61AF7A60AD785EAB775DA9755B\
A6745AA373599F73599B7158976F55916B528B644D845D477E5540774D3A714634
6B402E653B2A5E37265632224E2D2046291D3E251B382218321F162D1C14291A1225191022170F\
1E150D1B130C19120B17100B150E0A140D0A130B0A120B0A110A0A100A090F0908
0E07070C06060A05050804040603030403030303030404040706050A07070F0907140B081A0E0A\
25161035251E4D3C346B5B528B7C73A89C94C0B6AECFC9C0D9D4CCDEDBD3E0DFD7
E1E1DAE2E2DAE2E2DBE2E2DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1DA
E2E2DAE2E2DAE2E2DAE1E1DADFDED7DBD9D3D5D1CCCBC4C1BEB3B0AC9E9A988781837067715B51\
634D41594438543F34513E334F3D334E3D334E3C334E3C334F3E34514036534138
544238544137523F334E3B2E4A3629453124422C213F291F3E281F3F2A21432D254732294B372D\
4D3A2F4D3B304C3A2F4B392F4B3A2F4C3B314F3D34513F35513F354E3D334B3A30
49372E49372D4C3A2F513F335745375D4A3B624E3E6650406A5242705543785845815C488B624C\
9569519F7158A8795FAE8066B3866BB5896FB48A70B38A71B28A73B18B75B18D78
B28F7BB3917DB5937EB6937FB8947EB9947EBA957DBC967DBD977DBE997EC09A7FC19C80C29C80\
C19B80BF997EBC947AB88F75B2896FAD8269A77C62A1765C9D71579B6E549A6C52
9A6B519C6C519F6D51A36F51A77152AA7354AE7656B1795AB37B5EB57E61B78064B88166B88266\
B98266BA8165BA8063BB7E62BC7D61BC7D61BC7E63BB8064BA8165B88265B78263
B68160B5805EB47E5CB37D5CB27C5CB17B5DB07A5EAF795EAE785DAC765CAA755BA7745AA47259\
A171589D6F569A6E55966C549169518C644D855E487F5642784E3B7147346A402F
643A295D35255630214F2C1F48281C40251A3A2219341F172F1D152B1B1327191123170F20150E\
1C130C19110B170F0A150D0A130C09110A09100A091009090F09090E08080D0707
0C06060A05050804040603030403030303030303030505050907060D0908120B09160C091C0F0A\
26171137272051413972645C958981B5ACA4CCC6BEDAD6CEE0DED6E2E0D9E2E1DA
E1E1DAE1E1DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DA
E2E2DAE2E2DAE2E2DAE1E1DAE0E0D9DEDDD7DAD7D2D3CECAC7BFBBB6AAA5A0928B8A786F766256\
6550445A4538533F334F3C314D3B314C3B314C3B314D3C324F3D34513F35524037
534137524035503E324C3A2E483629443125402D223D2A213D28203E2922422C244631274A352A\
4D382D4D392E4C392E4B392F4C3A304E3C33503F365241385341385140374E3D34
4C3B314B3A304C3B304F3E325342355745385A483B5E4B3D624D3E684F406F5242785644815B47\
8A614B9367509B6E55A1745BA57960A77C63A67D66A57E68A37E6AA27F6CA2816E
A28370A38471A58571A78571AA8670AD8770AF8870B18A71B38D73B58F74B69176B89377B89377\
B79277B58F74B18A71AC856CA77F66A279609D735A986E55956A5093674D92654B
92644993644996654999674A9D6A4BA16D4DA56F50A97253AC7457AE765AB0785DB17A5EB27C5F\
B37D60B57D5FB67C5EB87C5DB97B5DB97B5EB87B5FB77C60B57D61B37D60B17C5E
AF7A5BAE7958AD7756AC7656AC7556AB7457AB7358AB7358AA7358A87258A67158A270579F6E56\
9B6D55976B549368528F654F8A624C855D477F5642784F3C7148356A412F643A2A
5D3425562F214F2B1E49281C42251A3C2218361F17301D152C1B1328191124171020160E1D140D\
1A120C170F0A150D0A130B09110A080F08080E08070D07070C07070B07070A0606
0905050804040603040403030302030303030304040606050B0907100C09150E0A1A0F0A1F120C\
291A133B2A2255453D776A629B9189BCB5ADD3CFC7E0DDD6E4E3DCE4E4DCE3E3DB
E2E2DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1DAE2E2DAE2E2DAE2E2DAE1E1DAE1E0DADEDDD7D9D5D0CEC9C3BEB5AEA89C939181777B695C\
6955475C483A533F334E3B304B3A2F4B392F4B3A304C3B314E3C33503E34513F35
513F35503E344D3D31493A2E45362A4131273D2D243B2A223A28213C2822402B23442F25483327\
4B362A4C382B4C392D4C3A2F4D3B314F3E3552413854433A55443B54433A524138
503F364E3D344E3D334F3E3451403553423756453959473B5E4A3D634C3F694F40715342795644\
815B468960498F654D946951976D54986F5898715B96725E947260927362917463
9175649276649476639876629B77619F7861A27B62A57E65A88167AA846AAC876CAD886DAD886D\
AC876CA9846AA47F679F7A639A745E966F58926A538F664E8D634A8B60478A5E45
895D438A5D438C5E439060439463459866479C6849A06A4CA36C4FA66E52A87054AA7256AB7558\
AD7659AF7859B17859B47959B57959B5795AB4795BB2785CAF785CAC775BAA7558
A77355A57153A46F50A46E50A46D50A56C50A56D51A56D52A46D53A36D54A06D549D6C54996A53\
9468529066508B624E875F4A835A467E5541784F3B7148356B4130643B2A5D3526
573022502B1F4A281C43241A3D2218371F17311D152C1B1328191124180F21160E1D140D1B120C\
18100B150E0A130B09110A080F08070D07060C06060A0606090505080505070505
0604040504040403030303030303030303030404040807060D0B08130E0A18110C1D120C24150E\
2E1D16402E265B4A427C6F67A0968EC0B9B2D6D3CCE2E1DAE6E6DEE5E5DEE3E3DC
E2E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1DAE1E1DAE2E2DAE2E2DBE2E2DBE1E1DADDDBD5D4D0CAC4BEB6AFA59B978A7F807063\
6D5B4D5E4B3E5441354D3B304A392F4A382E4A39304C3B314E3C334F3D344F3E34
4F3E344D3D334B3B3147392E43362B3F31283B2D25382A233827223927213D2922412D23463125\
4A34274C372A4D392D4E3B304F3D3352403754433A57453C58463D57463D56453B
54433A53413851403751403651403653423755443958473B5C493E614C40674F416D5242735443\
7957447F5A45845E478860498A634B8A644F896652886655866758846759826859
8268588268578568558868548C6853916A53956D559971589C755C9F795FA17B61A27D63A17D63\
A07B629C786097735D926E598D69558A655187614C855E48845C45835942825840
82573E82573D84583D875A3E8A5C3F8E5F409261429662459964479C654A9F684CA16A4EA36D50\
A67052A87253AB7454AE7555AF7555B07556AE7557AC7457A87256A57155A26E53
9F6C509D694D9C674B9C664A9C654A9D654A9E664B9E674C9E674E9C684F9A6850966750926650\
8D634E88604C845C498058457B5340764D3B7047356A4130643B2A5D3626573122
512C204B291D45251B3F2219392017331E152E1C13291A1124180F21160E1E140C1B120C18100B\
160E0A140C0A120A091008070E06060C05050A0405080404070404050404040404
0303030303030303030303030303030404040606050A09070F0C0915100C1C130E22160F291A13\
35231B47342C62504883746CA49A92C2BCB5D7D5CDE2E2DAE6E6DFE5E6DEE3E4DC
E2E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1DAE2E2DAE2E3DBE3E4DCE3E3DCE0DFD8D8D5CEC9C4BCB5ADA39E928787786C\
7261556250455644394F3D324B392F4A382F4B39304C3B314E3D334F3E344F3E35
4E3E344C3D334A3B3146392F42362C3E32293A2D263629233526213626203927203E2B21432F23\
4833264B372A4E3A2E503D3252403554423956453C58473D5A483F5A483F5A483E
59473D57463C56443B55433A54433955443A57463B5A483D5D4B3F624E416650426B53436F5443\
7456437858437B59437D5A447E5B457E5C487D5C4B7B5D4D795D4F775C4F755C4E
755C4C755B4A775B497B5B477F5B47835D4788604A8C644D906850936C54956F57967158967159\
947058906D568B6954866451815F4D7E5B4A7C59467B56437B55407B533E7A523C
7B513A7B51397D52387F543982563986583B89593C8C5A3E8F5B40925D42955F459862479B664A\
9E6A4CA16D4EA46F4FA67050A87151A87051A66F52A36E51A06C509D6A4F9A684D
97664B966349956147946045945F44955F44955F4596604795624994634A92634B8F624C8B604B\
865D4A815A477D564378513F744C3A6F4635694130633B2B5C3626563123512D20
4C2A1E46271D41241B3B2219351F172F1C142A1A1225180F21160E1E150C1B130B19110B170F0A\
150D0A130B091109080F07070D06060B0404090404070303050303030303020303
0103030103030203030304030505040806050B08060E0B08130E0B18120D1E1610261A13302018\
3E2B23523E356C59518B7C73AA9F97C5BFB7D8D6CEE2E2DAE5E6DFE5E6DEE3E3DC
E2E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E2E2DAE3E3DBE4E4DDE4E4DDE1E1DADAD8D1CCC9C1BAB3ABA49A918D8077\
79696068574D5A493F5140364C3B314B392F4B3A304D3C324F3D344F3F354F3F35
4E3F354C3E344A3C33473A3043372E3F332A3A2E2635292232251F32241E36261E3B2920412E23\
4733264B372B4F3B30523F3454423857453B59473D5A483F5B49405C4A405C4B41
5C4A405B4A405A483F59473E58473D59473D5A493E5D4B40604E426451436753446A54446D5544\
7056437256437457427456417456427456437255457054476E54476D53466B5245
6B51426B50406D4F3E6F4F3D73503D77513E7B54407F5743835B46875F4989634C8B654E8A664F\
89654F85624E805F4C7B5A49765646735344715141714F3F714E3D724D3B734C39
744C37754C36774C35794E347B4F347D513580523682523884533A87543C8A573E8D5B41915F44\
9563469867489B694A9D6A4B9E6B4C9E6A4C9C694B99674B97654A946349926247
9060468F5E448E5D438D5B418D5A408C593F8C59408C5A418C5B438B5D45895D47875C47835A46\
7F57447A5341764F3D724B396D4635674130613B2B5B36275531234F2D204B2A1E
46281D42261C3D241B382119311E162B1B1326191022170E1E150C1C140B1A120A18110A160F0A\
140D0A120B091009080F07070D05050B0404080303060303040303020203010202
0002020103020203030505040907050D0907100C09130E0A17100C1B130F2117122A1E17372720\
49352D5F4A417A665C96867DB2A79EC9C3BBD9D7CFE2E2DAE5E5DEE4E5DDE3E3DC
E2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E2E2DAE3E3DBE4E4DCE4E4DDE2E2DADBDAD3CFCCC5BFB9B2ABA19B958983\
81726C6E5E57604F4755433B4F3D334C3A314D3B314E3D334F3E355040364F4036
4E40364C3F354B3D34493B3245382F41342B3B2E2635292231251E31241D33251D3929203F2E23\
4634284C392D503D3254413757453B59473D5A483F5C4A405D4B415D4C425E4C42
5E4D435E4D425D4C425D4B415C4B415C4B405E4C41604E426351436653446854456B55456C5644\
6E56446E56426E55416E54406D53406B51406A5041684E41664C40644A3F63493C
63483A6347376446366646366846366B47376F4939734C3B77503D7A53407D57427F59447F5B46\
7E5B477A59467656457152436C4F41694C3F674A3D67493B68483A6948386B4736
6D47356F4733704732724831734930754930764A31774A32794B347B4C367F4F3982533B87573E\
8B5C418E5F439161459263469363469262469061458E5F448C5D438A5C42895B41
885A41885A4087583F86563D84543B83533A82533A82533C81553E8156407F56417D55417A5240\
774F3D734C3A6F48376B4434664030603C2C5A37275432234D2D20482A1E44281D
41261D3E251C39241B3421192E1E15281A1222170F1F150C1C140B1A130A19120A18100A160F0A\
140D0A120A091008080E06070C05050A0404080303060202040202020202010202
0002030103030304040807050D0A07120D09170F0B19110C1B120E1E1510241A1530231D403029\
56423A6E595089756BA39289BAAFA6CDC7BFDAD8D1E1E2DAE4E5DDE4E4DDE3E3DB
E2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E2E2DAE2E3DBE3E4DCE4E4DCE2E2DADCDBD4D2CFC9C4BEB9B2A9A69E9390\
8A7C7977676266554F5A4840523F364E3C324E3B314F3D33503F355040364F4137
4E40374D40364C3E354B3C3348393043352C3D2F27372A2232261F31251D33271E392A213F2F25\
46352B4D3B3052403556443A59473D5B493F5C4A405D4B415E4C425E4C425F4D43
604E44604E445F4E445F4E435F4D435F4E43614F436350436552436753446954446B55446C5544\
6C55436C54426B534069523F67503E654E3D634B3D61483C5F463A5D44385C4235
5C40335C3F315C3F305D3E305F3F316140326441336743346B45356E4837714B39734E3C74513E\
7352407151406C4E3F684B3E63483C60463B5F44395E43385F4337614235634234
65413267413069412E6A422D6B422C6B422B6C422C6C422D6D432E6F4430724733764A367B4F38\
7F533B82563D84593E865A3F865A3F85593F83583E82563D80553C80553B7F553C
7F553C7F543B7F533A7D51387B4E36794C35774B35764C36764D38754E3A744E3B734C3B714A39\
6E47366B4433674131633E2E5F3B2B5937285332244C2E2146291E41261C3D251B
3B241B38241B35231A3020182A1C142419111F150D1C130B1A120A19120A18110A17100A160E0A\
140C0A120A091008080E06070C05050A0404070303050202030202020203010303
0203040304040706060C0908120C0A18100C1D120D1F130E1F140F221712291D193629244B3B34\
6451497F6A6299867CB0A197C3B9B0D2CDC4DCDAD2E1E1DAE3E4DDE3E4DCE2E2DB
E1E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E2E2DAE2E2DAE3E3DBE3E3DBE1E1DADDDCD5D5D2CDC9C4C1BAB2B0A89D9C\
94868580706D6D5C575F4C45554138503C334F3B314F3D33503F355040364F4037
4E40374E40364D3F354C3D344A3A3145362D4031293A2D24362921342820362A213B2D24413228\
48372E4E3D3354423858463C5B493F5D4B415E4C425E4C425F4D435F4D435F4E43
604E44604E445F4E445F4E445F4E43604E43614E42634F426550426751426952426B52426B5341\
6B52406A523F69503E664E3C634C3B614A3A5E47395B4438594136573F33563C30
553A2E55392C55392B56392C57392E583A2F5B3B2F5D3B2F603C2F623E30654132674434694737\
69493A674A3B64483B60463A5C4339594137574036573F35573E34583D325A3C30
5C3C2E5E3B2C603B2A613B29613B28613B28613B28613B28613B29633C2B663E2D69412F6D4532\
714934754C36774E37784F38785038775037764F37754E36744D35744D35744D35
754E36754E36744C35734A337047316E442F6C432F6B43306A4331694433694434674333664131\
643E2F613C2D5E3A2B5B38295735265232244B2E21452A1E3F261C3A231A362219
3422193222193020182B1E16261A1320170F1C130C19110A18100A17100917100A160F0A150E0A\
140C0A120A091008080E07070B0505090404060303040202030202020303030304
0405060706070B0909110C0B18100D1E130F221510231610241611261A142F221D3F312C574741\
73625A8F7E75A9988FBDB0A7CCC4BBD7D2CADEDCD4E1E1DAE3E3DCE3E3DBE2E2DB
E1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E2DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E2E1DAE2E2DAE3E3DBE3E3DBE1E1DADEDDD7D8D6D1CFCBC8C2BBBAB2A8A8\
9E9291897A7875635F64504958443B523D334F3B314F3C324F3E344F3F354F4036
4E3F364E3F354D3E354D3D334B3B3148372E43342B3F30273B2E253A2D243C2E2540312845362C\
4B3A31503F3555433A59473D5C4A405E4C425F4D435F4D435F4E435F4D435F4D43
5E4D435E4D425E4C425D4C425E4C415E4C41604C40614C40634C3F654D3E684D3E6A4E3E6B4F3E\
6B4E3D694E3B674C3A644A386148375D46365A4335574034543E33523B3050382D
4F362A4E35294E35294F352A50362C52372D53362C54362B56362A57362A59392B5C3C2E5E3F32\
5E42355E43375C4337594137564036533E34513C33503B32503A3051382F52372C
53352A5434285534265634255634245635245534245534245534255734265935275C3729603A2A\
633D2C66402E68432F6945306A46306A463069463068452F68452E68452F69452F
69463069463069442F67422D643F2B623C29603A295F39295E3A2A5D3A2B5D3A2C5C392B5A382A\
5936285734275532255231244E2F224A2D20442A1E3E261B382319332118301F17
2E1F162C1E16291D15261A132117101D140E19110B170F0A160F09160E09160E0A150E0A150D0A\
130C0A120A090F08080D07070A0505070404050302030202020202030304050506
0807080D090B120C0D180F0F1E1311231511261712271812291A132D1F183729234B3C36655750\
83746CA09189B7ABA2C9BFB6D4CEC5DBD8D0DFDED6E1E1DAE2E2DBE2E2DBE2E2DA
E1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E2DAE2E2DAE1E1DADFDED8DBD9D4D5D1CECAC4C3BCB3B3\
A99D9D9484827E6C676B564F5D473F543F35503C324F3C324F3D334E3E344E3E34
4E3E344D3E344D3D344D3C334C3B3149392F47362D44342B42332941332943342B46362D4A3A30\
4E3D3453413857453B5A483E5D4A405E4C42604E43604E44604E445F4D435E4C42
5C4B415B4A405A493F5A493F5B493F5C493E5D483D5F483C61483C63483B66483A68493A6A4A3A\
6A4A396849376647366245345E43335B4233574032543E32503B304D382E4B352B
4933284832274932274A33294C342B4D352C4D342B4D32294D31274D30264F322751352A53392D\
553C31553E33543E34533E34513C334E3B324D39304B372F4A362D4A342A4A3128
4A2F254A2E234B2D224B2D214A2E214A2E214A2E214A2E214A2D214B2D214D2D214F2E22523023\
5533255835265A38275C3A285C3C295D3D295D3D295C3D295C3D285C3D285D3D29
5D3E295D3D295C3C285A39275836255633235431235330235330235230245130245030244F2F23\
4E2E224C2D214B2C20492B1F462A1E42281D3D251B3723193120172D1E15291D14
271C13251A1223191120170F1D140E19110C170F0B150D0A140D09140D09140D0A140C0A140C0A\
130B0A110A090E08080C0606080505060303030202020202020203040404080607
0D090B130C0F1910121E1313231514271814291A142C1B142F1F1736261F44352D594B44756861\
938780AFA59DC5BCB4D3CDC4DBD7CFDFDDD5E1E0D8E1E1DAE2E2DAE2E2DAE1E1DA
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E2E2DAE2E2DAE2E2DAE1E1DAE0E0D9DEDCD7D9D6D3D2CCCBC5BDBC\
B4A8A79E8F8D877671735E57634D45584339523E344F3C334E3C334D3C334D3C33
4D3C334D3C334D3C334D3C324C3B324B3A314A392F48382E48372E48382E4A39304C3C324F3E35\
52413755433A57453C59473E5B493F5D4B415F4D435F4E435F4D435E4C425C4A40
59483E58463C57453C57453B57453B59453B5A453B5C453A5F4439614438644538664537684637\
6846366645346443326041315C4030583E30553D30513B304E392F4A372D47342A
45312844302745312747332949342B4A352C4A332A483028462D25452C23462D244830264A342A\
4C372D4E3A304E3A314D3A304C392F4A372E48362D47342B453229442F26432C23
422A2141281E40271D40271D40281E40291E3F291E3F281E40271D41271C42261C44271D47281D\
4A291E4C2C204E2F21503122513323513523513523513523513523513523513523
5135235135235033224E31214D2E1F4B2B1E4A291D49281D49281D48281E48281E47281E45271E\
44271D43261C42261C40251B3E251B3B231A372218311F162C1D15271B13241A11
22181020170F1E150D1C130C19110B170F0B150D0A140C0A130B0A130B09130B0A130B0A120B0A\
110A090F09080D08070A06060704040403030202020102020203030505050B0809
110C0E1910121F14162416172718162A19152D1C1631201838271F43332A54453C6B5E56877C74\
A49B93BDB7AFD0CBC3DBD8D0E0DED6E1E0D8E1E1D9E1E1D9E1E1DAE1E1DAE1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E2DAE1E1DAE1E1DAE0DFD9DDDBD7D7D3D0CDC6C4\
BDB3B1A89B9792817C7C69626B564E5E4A41564238513E344E3C334D3B324C3B31
4C3B314D3B324D3C324E3C324D3C324D3B324C3B314C3B314C3B314D3C324F3E34524036544239\
56443A57453B57453B58463C59473D5B493F5D4B415E4C425E4C425C4A4059473D
56453B5442395342385342385542395743395943395C43395E4338614337634337654436664435\
6543346342326040315D3E2F593D2E563C2E523B2F4F3A2F4C382E48362D45332A
43312842302744312847342A49352C4A352D49332B463028422C244029223F2A22402C24433028\
45342B47362D48372D48362D47352C46332A453229433027412E253F2B223D281F
3B251D39231B38221A37221A37231A36241B36241B36231A37221A3821193A21183C21183E2219\
41231A43251B45281C472A1D482C1E482E1F482E1F472E1E472E1E462E1E462E1E
462D1E462D1D452B1D44291C42271B41251A41231941221941221941221940221A3F221A3E2219\
3C22193B22193A2118392118382118352017311E162C1D14271B1223191020170F
1E160D1C140C1A130B18110A170F0A150D0A130C0A130B0A120A0A120A0A120A09110A09110A09\
0F09080D08070A07060805050504040203030102020102020303030706060E0A0B
160F101E14152517182919192B19172D1B16311E1838261E44332A54443B685A5281756D9B928A\
B4AEA6C9C6BED8D6CEE0DFD7E3E2DAE3E2DBE2E1DAE1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E1DAE2E1DAE1E1DAE0DED9DBD9D4D3CECA\
C5BDB9B2A7A29D8E8988767075625A66534A5B483F5341384F3D334C3A314B3A30
4C3A304D3B314E3C324E3D334F3D334F3D334E3D334E3C334F3D33503E3553413755443A58463C\
58473C58463C56453B55443A56443A57463C5A483E5B4A405C4A405A483E56453B
534138503F354F3E35503F355240375642385943395C44395F4439624538634437644437634335\
6242345F40325C3E30593D2F563B2E533B2E503A2F4D392F4A382E47362D44332A
42322942312844332948352C4A372E4B372E49342C453029402B253C28223B28223B2A233D2D26\
40312942332A43332A433229433027422F25412D24402B223E29213C271E39241C
362219342017321F17301F172F1F172F20182F20182F1F17301E16321E16341D15361D16391E16\
3B1F173E21183F231941251A41271B41281B40281B3F281A3E271A3D27193C2719
3C26193C26193B25183A2317392117392016391F163A1E163B1F173B1F173B1F173A1F17381F17\
361E16351E16341E16331E15321D15301D142D1C13281A1224181020170E1D150D
1B140B1A130A181109170F09150E09140C09130B09120A0A120A0A120A0A1109091009090F0808\
0D08070A07060805050504040303030202020102020203030504040A0707120C0C
1B12122317172A1B1A2D1B192F1B18311D1837231C422F2753423A695A5181756C999087B0A9A1\
C3C0B8D3D1C9DDDCD5E2E2DBE3E4DCE3E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1DAE2E2DAE2E2DBE1E1DADEDCD7D7D4CE\
CBC5C0BBB2ADA89B9694847E806F686F5D55614F4657443B503E344C3A314B392F
4C3A304D3B314E3C33503D34503E35503E35503E344F3D34503E3452403654423957453B5A483D\
5A483E58463C55443A53423752413754433957453B59483D5A483E58463C544339
503F354D3C334D3C324E3D33513F355541375944395D453961473A634739634639624538604336\
5D41355A3F33573D31543C30523A2F503A2F4E392F4C392F49382E47362D44342B
42322943322945342B49362D4C382F4D382F4A352D45302A3F2B263A28233827223829233A2C25\
3C2E273E30273F2F263F2D253F2B233F2A213E28203C271E3B251D38231B352119
321F172F1D152D1C142B1C14291C14291C14291C14291C142B1B142C1B132F1B13321B14351C15\
371E16391F173B21183C22183C23183B23183A2318382217362216352116342115
332015332015331F14321E14321D14321C13331C14341C14361D15371D15381E16361D15341D15\
321C14301C142F1B132F1B132E1B132C1A1229191125181021160E1E150C1B140B
1A130A191209181109160F09150D09140C09120B09120A091209091109091009090F08080D0707\
0A06060805050605040404040303030203030303030504040906060E0909160E0E
1F1413271A182E1E1B311F1B331F1A37221C402B244F3D3566564D80736A9A9188B1AAA2C3BFB7\
D0CFC7DAD9D2E0E0D8E2E3DBE3E3DCE3E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8E0\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1DAE2E2DAE2E2DBE2E2DBE0DFD8DAD8D2\
D1CCC6C3BCB6B2A8A29F928C8C7C7679676068564E5B483F523F364D3A314C392F
4C3A304E3B324F3D34513F35513F36513F36513E35503E34503E3551403654433957463B59483D\
59483E57463B544338514036503F3552413755443A58463C59473D56453B524137
4E3E344B3B314B3A314C3B32503E345441365944385E463962483A63493A6348396046385C4336\
584035553E33523C31503A304E3A2F4D392F4C392F4A382F48372E46362D44342B
42322A43332A45342C49362E4C38304D38304A352E45302B3E2B27392823362622362822372A24\
392C253B2D243B2B233B29213B271F3B251D3A241C39231B37221A352018321E16
2F1D142C1B13291A122619122519122419122419122519112619112919112B1A122E1B13311C14\
341D15361E16371F17382017372017362016341F15321E142F1D132D1C122C1B12
2C1B112B1A112B1A112B19112B19112C19112D1A12301B13321C14341D14351D15331D14311C14\
2E1B132C1A122B19112A191129191128181025170F22160E1F150C1C140B1A130A
19120A191209181109170F09150E09140C09120A09120A091109091009090F08080D07070B0706\
0906050605050504040404040404040505040706050A07060E0908130D0B1B110F
2317142B1C1832211B36231D3B261F412D254D3931614F477B6D64978D84B1ABA2C5C2BAD3D1C9\
DBDAD2DFDFD7E1E1DAE2E2DBE2E2DBE2E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE3E3DBE3E3DBE1E0D9DDDBD4\
D5D2CBCAC4BEBBB2ADA99D9896878282706A6F5C55604B435540374F3A314D392F
4D3A304F3C33513E35524036524037524036513F35503E35503E34503F3552413754443A56463B\
56463C54443A524237503F35503F3553413756443A58473C59473D56453B524238
4E3E344A3B31493A304B3B314E3D335340355843365D46386148386248386147385D4436584135\
533E334F3C324D3A304B392F4B382F4A382F4A382E49382E47362E45352C42332B
41322A41312B43332C47352E4A372F4B373048352E43302B3D2B27382724362622352722362822\
382A22392A2239282138261F37231D37211B36201A351F18331F17311E162E1C14
2B1B13281A1126181023181021170F20170F20170F21170F23170F2618102819112B1A122E1B13\
301C14321D15331E16331E16331E15311D142F1C132C1A1229191027180F26170F
25160E24160E24150E24150E25160E26160F2918102C19112F1B12311C13321C14301C132E1B12\
2B191128181027170F26160F25160F23150E22150D1F140C1D130B1B130A1A130A
19120A19120A18110A17100A160E0A140C0A120A091109091008080E08080D07070B0606090606\
0805050705050605040606050807050A08060C0A08100C0A150E0C1A110E201411
2719142E1D1835231C3D2921463129513E35624F4778686092867EADA59DC4BFB8D4D2CADDDDD5\
E1E1D9E2E2DAE1E2DAE1E1DAE1E1DAE1E1DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E3DBE3E3DBE1E1DADEDDD6\
D8D6CFCFCAC5C3BAB6B3A7A39F908C8A787376615B654E46584139513B314F3930
4F3B31503D34523F36534137534137534137523F36503E354F3E344F3E344F3F35504137514238\
51433851423750413651403652413755433958463C5A483E5A493E57473D534339
4E3F364A3C32493A31493A314C3B31503D325640345B43355F45356045355D4434594133533D31\
4E3A304A382F48372E47372E48372D48372D48372D47362D45352D43332C40312B
3E2F2A3D2F2A3F312C42332D45352E46352E45332D412F2A3C2B26372723352521352521362620\
37272037262037251F35221E34201C321E1A311D19301D172E1C152C1C142A1B13
281A1125191023170F20160E1F160D1E150D1E150D1F160D20160E23170F2518102819112A1A12\
2C1B132D1C142E1C142E1C142D1C132B1B1229191126180F24160E22140D20130C
1F120C1E110C1E110C1E120C1F130C21140D24160E28170F2B19112D1A122E1B122D1A122A1911\
27180F24160E22150D21140D20130D1F130C1E120C1C120B1B120A1A120A1A120A
1A120B19120B19110C17100B160E0B140C0A120A091009080E08080C07070B0606090606080505\
0805050806050907060A08060D0A08100C09130F0B18110E1D1410211612261813
2B1B15311F183A261E45322954413966554C7B6C6392867EA9A199BFBAB2D1CEC7DDDCD4E2E2DB\
E4E4DDE3E3DCE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DAE2E2DBE2E3DBE2E2DADFDFD7\
DBD9D2D4CFCAC9C1BDBAAFABA89895927F7A7D66606A524A5C433A543C32513A30
503C32513E34534036534138534138534137524036503E354F3D344D3D334C3D334C3D334C3E34\
4C3F354D3F354F403652413755433958463C5B493E5C4A405B4A4058483E54453B
4F41374B3E34483B31483A304A3A2F4D3B30523D30573F315B40315B4031593F30543C2E4E392D\
48362C45342B44342B44342B45352C46352C46352C45352C43332B40312A3D2F2A
3A2D2A392C2A3A2D2A3D302B3F322C41322C40312A3D2D2839292536262234242034231F35241E\
36241E35231D34211D321F1C301D1B2E1B1A2C1B182A1A16291A14281A12261911
24191022180F20160E1E150D1C140C1B140B1B140B1C140C1E150D20160E22170F241810261911\
271A12281A12281A12281A1227191226181024170F22150D1F140C1D120B1B100A
1A0F0A190E0A190E0A190F0A1B100A1D120B20140C24160E27180F2A19102B191129191027170F\
23160D20140C1D120B1C110B1A100B1A0F0B190F0A19100A19100919110919110A
19120B19110C18110C170F0C150E0C130C0A110A090F08080C07070A0606090505080505080505\
0906060B07060C09070F0B08120D0A15100C1A130E1F1611241914291B152C1C16
301E1737231B412D24513E3566554C7E6F67968A82ACA49CBFBAB2CECBC4DAD8D1E1E0D9E4E4DC\
E4E4DDE3E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DAE2E2DAE2E2DAE2E2DAE0E0D8\
DDDBD5D8D3CECFC7C3C1B6B3AFA09C9A8682836C6670564E60463D573E34533B32
523D33523F35534137534238544238534137524036513E354F3D334C3C324A3B31483A31483B31\
493C324B3E344F403653433957463C5A493E5C4B405D4C415C4B4159493F54463C
5042384B3E35483B3147392F47372D4A372C4E392C523A2C553B2C563B2C53392A4E3629483328\
43312741302740312841322943332A44342A44342A43332A41312A3D2F293A2C29
362A28352928352A29372C29392E293B2E283B2D27392B2636272334242133221F33211E34211C\
34201B321F1B301E1B2E1C1B2B1A1A291919271817251815241813231811221810
21171020160F1E150E1C140C1A130B19120A19120A1A130B1C140C1E150D1F160F21170F211710\
22171022181023181022181022171021160F1F150D1D130C1B120A191009170E09
160D09150C09150C09160D09180F091A100A1D130B21150C24160E26170F27170F25170F23150D\
1F140C1C110A19100A170E09150D09150C09150D08150D08160E08160F0917100A
17100B17100C160F0C150E0C140C0B120B0A1009090D08070B0606090505080505080505090605\
0B07060E0907100B09130D0A16100C1A130E1E1610241913291D162F1F1833211A
38251D402B234D3930614F467B6B63968A82AFA79FC3BEB6D1CEC6DAD8D1DFDED7E2E2DAE3E3DB\
E3E3DBE2E2DBE1E1DAE1E1D9E1E1D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E2DAE2E2DAE1E0D9\
DFDDD7DBD7D2D4CDC9C8BDBAB6A8A4A18E898A736D755C54654A415A4137553D33
533D33523F35534036534137534138534137524036513E354E3D334C3B32493A3047392F46392F\
473B314A3D334E403653443A57473D5B4A3F5D4B415D4C415B4B4058493E54453B
4F42384B3E34473A3045372D45352B46342A4935294D35294F36284F35274C3326483024422E23\
3E2C223D2C233E2E253F2F264131284232294232294131293E2F283B2C28372927
342727322627322726332826352A25362A2436292435272334252232222031201E311F1C311E1A\
301D192E1B182C1A182918182617182316172215152016142016121F16111E1610
1E160F1D150F1C140D1A120C18110A17100917100918110A1A120C1B130D1C140E1D150E1D150E\
1D150E1D150E1D150F1D150F1D140E1C140D1B130C1A110B181009160E08150C08
140B08130B08130B09150C09160E0919100A1C120B1E140C21150D23160E23160E22150E1F130C\
1C110B180F09150D08120B07110A07100907100A07110B07120C07130D08130E09
130E0A130E0B120D0B120C0B100B0A0F09090D08080B07070A06060906060906060A07060B0806\
0E0907100A08130C09150F0B18110C1B130E2016102519122B1D1632221A3A271F
422F264F3A325F4C4476655D91847CACA39BC3BEB6D3D1C9DDDCD4E1E0D9E2E2DAE2E2DAE2E2DA\
E2E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E2DAE2E2DAE2E2DAE1E1DA\
E0DFD9DEDBD5D8D3CECDC5C1BDB1ACA89792927C757C645B6A51485E453B574036
533E34523F35524036524037534137534137524036503E354E3D334C3B324A3A30483930483A30\
493B314B3E344F413753443A56473D59493F5B4A405B4A405A493F57473C524339
4E4036493C3246382E43352B423329433227453126483226493125493024462E22412B203D291F\
3A281E3A29203B2B223E2E244030264130274030283E2E273C2C26382926352726
3225253024253024243025223125213226203225203124203122202F201F2E1E1D2D1C1B2C1B19\
2A19172818162516152314152013151E12141D13131C13121C14111C14101C1510
1B140F1B130E19120D18100B160F0A150E09160E09160F0A18100B19110D1A120D1A120D19120D\
19120D19110D19120D19120D19120D19110C18100B170F0A150E09140C08130B08
120B08130B09130C09150D0A170F0A19110B1B120B1D140C1F140D20140E1F140E1E130D1B110C\
180F0A150D08120B070F09060D07050B07050B07050C08050D09050E0A060E0B07
0F0B080E0B090E0A090D09090C08080B07070A07060A06060A07060A07070B08070D09080F0A08\
110B09130C09150E0A160F0B18100C1B120D1E130E2416102B1B1434231B412D25
503C34624F4677655D8F8078A79D95BEB7B0D1CDC6DDDCD4E2E2DBE4E4DDE3E3DBE2E2DAE1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E1DAE2E1DA\
E2E1DAE0DED8DCD8D3D3CCC7C4BAB4B0A29B9A8880846F66725B51644D435B453A
554036523F35513F35524036524036524036523F36503E344E3D334D3B324B3B314B3B314A3C32\
4B3D334D3F354F413851443A54463C56473D58483E58483E57463C54443A504137
4C3D3348392F44362C423329403027402F25422F24432E24432E23422D213F2A1F3B271D38251B\
36241B37261D3929203C2C233E2E253F2F263E2E263C2B25392925362624332424
3123232F22222F22212E221F2E211D2E211C2E201C2E1F1D2D1E1D2C1D1D2B1B1C29191A271818\
2516152214131F12121D11111B1011190F111910101911101912101912101A1310
19120F19120E17100D160F0B140D0A140C09140C09150D0A160E0B170F0C17100D17100C160F0C\
160E0B160E0B160F0B170F0C17100C170F0C160E0B140D09130C08120A08120A08
120A08120B09140C0A160E0B18100B1A120C1B130C1D140D1D140E1D130E1C120E1A110D180F0B\
150D09120B080F08060B07050905040704030704030705030806040907040A0705
0A08060A07060907060906060806060805050806050906060B08070D09090F0B0A110C0A130D0A\
150E0A160F0A170F0A17100B18100B1A100B1D110B22130D2A191237241C49352C
5F4B4377655D908179A79B94BCB4ACCDC8C0D9D7D0E1E0D9E4E4DDE4E5DDE3E3DCE2E2DAE1E1D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1DAE4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA\
E2E2DBE2E1DADFDDD6D7D3CDCAC3BCB8AEA6A4958D8F7D747C685E6D584E614C42
59453B544137523F35513F35513F35513F35503E354F3D344E3C334D3C324D3C324D3D334E3E34\
4E3F354E41374F423850433A52453B53453C55463C55453C55443A5242384F3E35
4B3B3147372D43332A4030273F2E253E2D233F2C233F2C223F2B213D2A203A271D36241B342219\
32221934231A36271D3A2A213C2C233C2C243B2B24382823352622332422312221
3021202F201F2E201D2D1F1B2B1D192A1D182A1C18291B19291A1A28191B26181A241719221516\
1F13131C11111A100F180E0E160D0E160D0E160D0E160E0E17100F17100F18110F
18110F17100E160F0D140D0B130B0A120B09120B09130C0A140D0B150E0C150E0C150D0C140C0B\
130C0A140C0A150D0B160E0B160E0C160E0C150D0B130B09110A08100907100907
110A08120B0A150D0B170F0C19120D1B130D1C140D1C140E1C140E1B120E19110E170F0C150D0B\
120B090F08070C0605080504060303040202030202030302040302050403060403
0605040705040605050605050605040605050705050907070C09090F0B0A130D0C150F0C17100C\
19110C19110B1A110B1A110B1A100B1B100B1E100A23120B2D19113D271E533E35
6F5B528C7C73A79A92BDB4ACCDC7BFD8D4CDDEDDD5E2E2DAE3E3DCE3E3DCE2E2DBE1E1DAE1E1D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA\
E3E3DBE3E2DBE1E0D8DBD9D1D0CCC4C2BAB2B0A59C9D8E858A796F79675D6B584E
604D4358453B534137513E34503E344F3D334E3C334E3C324D3B324D3C324E3D334F3E34504036\
5041374F42384F42394F433950443A51443A53443B54443A5343395140374E3D34
4A393046352D433129402E263E2C233D2B223D2A213C2A203B292039271E36251C332219302017\
2F201730211833241B37271E39292039292137282134252032231F30211F2F201E
2F201D2E1F1C2C1D1A2A1C17281A152618142517142416152416172315182215182014161D1314\
1B1112181010160E0E150D0D140C0C130C0C140C0C140D0D150E0D160F0E160F0E
160F0E160F0E150D0D130C0B120A0A110909110909120A0A130C0B140C0C140C0C130C0B120A0A\
120A09130A09150C0A170D0B180E0C180E0C160C0A130A081008060E07060E0706
0F0908120B0A150E0C18100D1A130D1C140E1D150E1C150F1B140F1A120E17100E150D0C120B0A\
0F09080C0606080404050302030201010101010000010100020101030201040302
0504030604040605040605050605050605050806060A08080E0A0A120D0C160F0E19110E1C130E\
1D140E1E140D1F140D1F140D1F130D21130C24130B2A160D351E14472F2360493E
7F6B609E8E84B9AEA6CDC6BED9D5CDDFDDD5E1E0D9E2E2DAE2E2DAE2E2DAE2E1DAE1E1D9E1E1D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DA\
E3E3DBE3E3DBE1E1DADDDCD5D6D3CBCBC6BEBDB5ACADA2999B8E84897A7079685E
6A584E5F4C4257443A523F354F3D334D3B314C3A314C3A304C3B314D3C324E3D344F3F35504137\
5042384F42394F43394E43394F433950443A52443A54443A5443395240384F3D35
4B393147352E433129402D263E2B233D29203C28203B281F39281F37261E34241C3022192D1F17\
2C1E152D1F1630211833241B35251D34251E33241E30221D2E201C2D1F1B2D1F1B
2D1E1A2C1D192A1B172719142416122114112013111F12121E12131E12141D11141B11141A1112\
181011160F0F150E0E140D0C130C0C120B0B120B0B130B0B130C0C140D0D150D0D
150E0E150D0D140D0C130B0B110A09100909100909110A09120B0B130C0B130B0B120A0A110909\
110908130A09160C0A1A0E0C1C100D1B0F0C180D0A130A080E07050B05040B0605
0E0807110B0A150E0C18110D1B130E1C150E1D150F1D150F1B130F19110E160F0D130C0B0F0909\
0C0707080504050303030101010000000000000000000000010000030101050202
0604040805050906060907060907070A07070B08080D0A0A100C0C140E0E18110F1C1310201510\
2216102417102518102618102818102A19102E1A10361E1343281B563B2D705749
8E796DAC9D92C5BCB3D7D1C9E0DDD6E3E2DBE3E2DBE2E2DAE1E1DAE1E1D9E1E1D9E1E1D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DA\
E2E2DBE2E3DBE2E2DADFDFD7DBDAD1D4D1C9CAC5BDBDB6ADADA49B9B8F85897A70
78665C69564C5D4A405542384F3D334C3A304B392F4B392F4B3A304D3B324E3D344F3F364F4137\
4F42384F42394E43394E43394F433951443A53453B55453B55443B534239503E37
4C3A3448363044312B412D263E2A223C28203B271F3A271F39271E36261E33241C2F21192B1F17\
2A1D152A1E152C1F162F201830211930211A2E201A2C1F192A1E192A1D182B1D18
2B1C172A1B162819142416122013101D110E1B0F0E1A0E0E190E0F190F10190F11180F11170F11\
170F10160F0F150E0E140D0D130C0C120B0B120B0B120A0A120A0B120B0B130C0C
140C0D140D0D130C0C120A0B110909100808100808110909120A0A120B0B120B0B110A0A110909\
110808140A09190C0A1D0F0C20110E1F110D1B0E0B140B080E07060A05050A0606
0D0808110B0B160F0D19110E1C140F1D150F1D150F1C150F1B130F18110E150E0D110B0B0D0808\
090506060303030202010101000000000000000000010000030000050101070303
0905050B07070D09080E0A090E0A0A0F0B0A100B0B110C0C140E0E17100F1B12101F1411231612\
2718122B1A122D1C132F1D13321F143621153D2517472B1C563727694A3A826656
9D8779B7A89CCDC4BBDBD7CFE2E1DAE4E4DDE3E3DCE2E2DAE1E1D9E1E0D9E1E0D9E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DA\
E2E2DAE2E2DAE1E1DAE0E0D8DFDED6DBDAD2D5D3CBCCC8C0BFB8AFAEA49B9B8E84
87786E76645A67554A5B493E5340364D3B314B392F4A382E4B39304C3B314D3D334D3F354E4036\
4E41374D42384E42394E433950443A52453B55463C56463D57463D55443C53403A
4F3C364A383246332D422E283F2A233D28203B271F3A271E39271F37271E33251D2F221A2B1F17\
281D15281C15291C152A1D152B1D162B1D162A1D16291D16271C15281C15281B15
281B142819132517122114101D110E1A0F0D170D0C160C0C160C0C160D0D160D0E160E0F160F0F\
160F0F160F0F150F0F150E0E140D0D130C0C120A0A11090A11090911090A120A0A
130B0B130C0C130B0B120A0A1009090F08080F0808100809110A0A120A0A120A0A110A0A110909\
120908150A091B0D0B20110D23130F22130F1D100D160D0B100A090C08080C0909
0F0B0B130E0E1811101B13101D15101E15101D15101C140F1A120F18100E140D0C100A0A0C0707\
0805050403030202010101010101000101000201000401010602010803020B0504
0D0707100A09120C0B130E0D140F0E150F0E16100F17110F1811101A12111E1412221613271813\
2C1A14301D15341F153822173D2519442A1C4D31215A3B296A4A377E5E4B947866
AB9586C1B2A6D2CAC0DDDAD2E3E2DBE4E4DDE3E3DCE2E2DAE1E1D9E1E0D9E1E0D9E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E0E0D8DDDDD5D7D5CDCDC9C0BEB7AEACA299
998C8286776C7564596654495A473D523F354D3B314B392F4B3A304B3B314B3C334B3D344B3E35\
4C40364D41374E42384F433952453B54463C57473D58483E59473E58463E55433C
513F394D3A3548352F433029402C243D29213C281F3B281F3A282038282034261E2F231C2B1F19\
271C17261B15261A14261A14271A14271A13271A13261B13261A13261A13261A13
2619132518122316111F130F1B110E180F0C160D0B150D0B140C0B150D0C150D0D160E0E160F0E\
160F0F160F0F160F0F150E0E140D0D130B0B110A0A100909100808100808110909
110A0A120A0A120A0A1109091008080F07070F0707100808100909110A0A110A0A110A09120A09\
130A08170C091C0E0B21110D24130F2414102013101A1110140F0F110E10121011
1512131814141C16151E17151F17141F16121E15111C130F1A110E160E0D130C0B0F09090B0707\
0705040503030403020303020403020504020704020804030A05030C06040F0806
110A09140D0B160F0E1911101B13111C14131E15131E16141F16142016142217142518142A1A15\
301C16351F163A2217402619472B1D5033235D3E2C6D4C397F5E4A927360A68C7A
B9A596C9BCB0D6CFC5DEDCD4E2E2DBE3E4DDE3E3DCE2E2DAE1E1D9E1E0D9E1E0D9E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E2E1DAE2E2DBE3E3DBE1E2DADEDDD5D6D4CCCBC7BEBDB5AC
ACA198998C8287766C7563586652485A463C533F354E3C324C3C324B3C324A3C32493C32493C33\
4A3D344C3F354E413751433A54463C56473D59483E5A493F5B493F5A473F57453E
54423B503D374A383245332C412F273E2C233C2A213C2A213B2A2139292136272031241E2C201B\
281C19251A16241815231713241713241812241812251912251912251912251912
2418122217112015101D130F1B110E18100D170F0C160F0C160E0B160E0C160F0C160F0D170F0E\
170F0F160F0F150E0E150D0D130C0C120B0B1109090F08080F07070F07070F0808
1008091109091009091008080F07070E06060E06060F07070F0808100908110909120A09130B09\
150C09180D0A1C0F0B20110D22130F2315122115141E16171C17191A181B1B1A1D
1E1C1E201D1E231D1D231C1B231A182117161F15131C1210190F0E160D0C120B0A0F09080C0707\
0906050805050805040806040907050B08050C08050E0905100906110A07130B09
150D0B170F0D1911101D1412201715241A17261B18271C18271C18271B17281B162A1B162E1C16\
331E173921183F241946291C4F30215C3B2A6C4B397E5E4B927461A58B79B7A191
C5B6A7D1C7BBD9D5CBDFDDD5E2E2DAE2E3DBE2E2DBE1E1DAE1E1D9E1E0D9E1E0D9E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E2E2DAE2E3DBE3E3DCE3E3DBE1E1D9DDDCD4D5D3CACBC6BE
BDB6ADADA2989A8C8287756B7561576652475C483E5442384F3F354C3D344A3C32483B31483B31\
493C324C3E344F403752433956463C58483E5A493F5B49405B49405B484059473F
57443D5241394D3C3447372F42322A3F2F263D2E243D2D233D2D233B2B233828223325202E201E\
291C1B251918231716211614211612221611231711241811241811241811231711
2116112015111E14101C130F1B120E1A120E19120D18110D18110D18110D18110D18110E17100E\
17100F160F0E150D0D130C0C120B0B1109091008080F07070E06070E06070F0707
0F07070F08080F07070F07070E06060E06060D05060E06060E06060F0707100908120A08140C09\
160D09180F0A1B100B1E110D201310211514221919231C1F24202425232827252A
29272A2B27282B26262A2322291F1E261B1A2216161E12121A0F0F160D0C130B0A110A090F0908\
0E09080E09080E0A080F0B08110C09120D09140E09150E09160E09160F0A170F0B
180F0D19110F1C1311201714261B172A1F1A2E211C2F221C2F221C2F211B2F201A301F19321F18\
3620193C231A43261B4C2D1F5836276745347A59478E715FA38A79B6A292C5B6A8
D0C6B9D8D1C7DDD9D0E0DED6E1E1D9E1E2DAE1E1DAE1E1D9E1E0D9E1E0D9E1E0D8E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E2E1DAE2E2DAE3E3DBE3E3DBE2E2DAE0E0D8DCDBD3D6D4CC
CCC8BFBFB7AEADA1989A8A8087746976615768544A5D4B4155453B4F41374B3D33493B31483A30\
493A304C3C324F403653433956463C58473D5A493F5B493F5B49405B49405B4840
59473E55443B5040374A3B3245362D4133294031273F30263F2F253D2D253A2A24362622302120\
2B1D1D261A1A2317172016151F1513201611211611231711231711231711211611
1F14101D13101C13101B130F1B130F1B140E1B140E1B140E1B140E1A130E1A130E19120E18100F\
160F0E150E0D130C0C120B0B1109091008080F07070E07070E06060E06060E0606
0E06070E06060E06060E06060E06060D05050D05050D05050D05050E0606100706120A07140C08\
170E0919100B1B110C1C120E1E1411211717251C1F2822272C282F302D34333036
343135353132352F2F332B2A3026252C2020281A1B2316161E12121A0F0F170E0D160D0C150E0D\
160E0D17100E18110E19120E1A130E1B140D1B140D1B140D1B130D1B130D1B120E
1B120F1C13101F15132419162A1E1A30231D34261F37282037282036261F35251D36231C37231B\
3B231B41261C492B205533266340317452428969599E8474B39E90C4B6A9D1C8BC
D9D3C9DDDAD1DFDDD5E0DFD7E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D8E1E0D8E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E2E1DAE2E2DAE2E2DAE2E2DAE2E2DAE1E1D9DEDDD5
D7D5CDCDC7BFBEB5ACAD9F969A897F88756B78655B6A584E5E4E4356463C4F40364C3C324A3A30\
4B3A304D3C324F3E3452413755443A57463B58473D59483E5A493F5B49405B4A40
5B493F58473D54433A4E3F36493B3145372D43352A423328413127402F253D2B24382723332321\
2E1F1F281B1C2418182016161F15131F15122016112116112216102115101E1410
1C120F1A120F19120F1A120F1A130F1C150F1C150F1C150F1C150F1C140F1A130F19120F17100E\
160E0D140C0C120B0B1109091008080F07070F07070F07070E07070E07070E0606
0E06060E06060E06060D05050D05050D05050D05050D05050D05050D05050F0605110806130B07\
160E0918100B1A120D1C14111F1715231B1C2821252D272E332D3638333B3C373D
3E393D3F393A3F37363D33323A2E2D3628273122222B1C1D2618182215151F14131E14131F1513\
201715221915231A15241B15241B14241A13231A112119102018101F170F1E1610
1E15101F1612221814281C182E211B34261F392A223C2C233D2C243C2B233C2A213C281F3D271D\
41271D482B20523327603E31714F40846355997D6EAE978AC0B1A5CFC6BCD9D5CB
DFDDD4E1E0D7E1E0D8E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D8E1E0D8E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E3DBE3E3DBE2E2DA
DEDDD5D7D4CBCCC6BDBEB4ABAEA0979D8C838B796F7A685D6B594E5F4D4356453B5140364E3D33\
4E3C324E3D334F3E33503F3552413753423855443A56463C58483E5A493F5B4B40
5C4B415B4A3F57473D5344394E40354A3C3148392D46362A453328433025402D243B2923362521\
31211F2B1D1C261A192218161F16141E16121F15111F15111F15101E13101C120F
19100F18100E17100E18110D1A130E1B140E1C150E1D160F1C150F1B140F1A130F18110E160F0E\
140D0C120B0B1109090F08080F07070F07070F07070F07070F07080F07070F0707
0E06060D05060D05050D05050E06060E06060E05050D05050D04040D04040D05040F0705110906\
140C0817100B1B130F1E1715221C1B2720222C252A322B323730393C353E413940
443C40473E3E483E3B473B3844373441312F3B2B2A3626253021202C1E1D2A1C1B2A1D1B2B1F1C\
2D211D2F231E30241E2F231C2E221A2C2118291F15261C13241B12221911211811
221812241914271B162C1F1932231D3728203C2B233F2E25412F26412F26422E25432D23452C21\
492D225233275F3E316F4E41836355977A6DAB9387BDABA0CCC1B7D7D2C9DEDCD4
E2E1DAE2E2DBE2E2DAE1E1D9E1E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE2E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DAE2E2DBE3E3DCE3E3DB
E1E1D9DEDCD4D7D3CBCEC7BEC1B7AEB1A49B9E8F858B7A7079665C6B574D604C4259463B544238\
523F35503E344F3D334E3D334F3E334F3F3551413753443A55463C58493F5B4B41
5D4C425D4C415B4B4058483D54443A5041354D3D314B392D493529463226422E243E2B23392721\
3424202E201D291D1A241A172118141F17131F16121F15111E14111C13101A110F
18100E160F0D160F0D17100C19120C1A130D1B140E1C150E1B140F1A130F19120F17100E150E0D\
130C0B110A0A1008080F07070E07070F07070F07081008081008081008080F0707
0E06060D05060D05050E06060E06060F07070E06060E06060D05050D04040C04030D05030F0704\
120A07160F0C1B1511211B192621202B262730292E342C34392F393E333C43383E
483D3F4C403F4F423D4F413B4D3E384A3A35453430402F2C3A2A28362725342523352623372825\
392B263B2C263B2C25392B2336281F32251C2E2218291F15261C13241A12241A12
251B14281C162C1F1830221B35251E3929203D2C23412F264332284633294833294A32274E3226\
5435295E3D306E4D3F816254967A6DAA9387BCAA9FCABEB4D5CEC5DCD9D1E1E0D8
E2E3DBE2E3DCE2E2DAE1E1D9E1E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E2DBE3E3DB
E2E2DAE1E0D8DFDDD5D9D6CDD1CAC2C3BAB1B1A59B9D8D838A776D79645A6C574C634E435C483D\
574339534035503D334D3C314C3B314D3D334E3F3550423853453B57493E5B4B41
5E4D435F4E435E4D435C4B4159483E56453A534135503C2F4D382B493427453024412D233C2A21\
37262031231D2C201A271D17241B152219142118132017131F16131D14121B1211
19110F17100E17100D18100C19120C1A130C1B140D1B140E1A130E19120F18110E160F0D140D0C\
120B0A1009090F08080F07070F07070F07081008081009091109091008080F0707
0E06060D05060D05060E06060F07071008081008080F07070E06060D04040C04030C04020D0503\
100806150E0B1B1513221D1B2924232E292A322B2F352C33392D363D303843353A
493B3C4F403D53433D54443C53423A503F374B3A3446353041302D3E2D2A3C2C293D2D293F2F2A\
41312B43332B4232293F2F263B2C2336271E30231A2B1F16271C13251B12261B13
291D152D1F1731221A34241C37261E3B29203E2C22422F254633294B362B4F382D53392D593B2E\
6140336D4B3E7E5E5193766AA99186BCAAA0CBBEB5D5CDC5DCD7CFDFDDD6E1E1D9
E2E2DBE2E2DBE1E1DAE1E1D9E1E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE1E1DAE2E2DA
E2E2DAE3E3DBE3E2DBE1E0D8DCD9D0D1CBC3C1B8AFAFA1989B8A808A756B7B655A6F584D654F44\
5D483C574237523E334E3C314C3B314C3C324D3F354F413753453B57483E5B4C41
5E4E43604F45614F45604E435E4C415B483D584538554033513C2E4D372A4933264430243F2C22\
39282034251D2F221B2B2019281E17261D16251C16241B17231A162118161F1614
1D15131B13111A130F1A120D1A130C1B130C1B130C1B130D1A120E19110E17100E150E0D140C0C\
120A0A1109091008080F08080F08081008081009091109091009091008080F0707
0E06060D05050D05060E060710080911090A11090A1008090F07070D05050C04030C03020D0403\
0F0705140D0B1B1512221D1B2924232F2929322A2D342A2F372B313B2D33423235
4938374F3E3953423A54433A5241384F3E364B3A3346363042322D3F2F2B3E2E2A3F2F2A41312B\
43332C44342C42332A3F2F273A2B2335271E2F22192A1E16271B13261A12271B13
2B1E1530211834241B37261D3A271E3C291F3F2C214430244A342850392D573E315E4234664639\
704F417E5D50907266A58B80B9A69CCABDB4D6CEC6DDD8D0E0DED6E1E0D8E1E1D9
E1E1D9E1E1D9E1E1D9E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E2E2DAE3E3DCE5E5DDE5E4DDE1E0D8DAD7CFCEC7BFBFB4ABAE9F959C8A808B766B7C65596F574B\
644D405C4539564135523F33503E334F3F344F403650423853453B57483E5B4B41
5F4E44615045625146625045614E435F4C405C493C594538564133523C2F4D382A473327412E24\
3B2A2136271E32241C2F221A2D211A2C211A2B211B2B211B2A201C291F1B261D1A
241B182219152018131F16101E150E1D140D1D140D1C130D1B130E19120E18100E160F0D140D0C\
130B0B110A0A1109091009091009091009091009091009091008080F07070E0606
0D05050D05050D05060F070811090A120A0C120A0C120A0B1008090F07070E05040D05030E0503\
100806140D0A1A1311201B1826211F2B25252F272831272A35282B3A2B2D413030
4736334D3B35503E354F3E354C3C3348383043342D3F312A3C2E283B2C273B2C263C2D273E2F28\
3F30283F30283D2E263A2B2335272031231C2C1F18281C14261A12261A12291C13
2D1F1632221936251C39271D3C281E3E2A1F422D214831244F3728583D2E6144356B4C3D755547\
816154907166A1877DB49F96C5B6AED4CAC2DDD7D0E1DED7E2E1D9E2E1D9E1E1D9
E1E0D9E1E0D9E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E2E2DAE3E3DCE5E5DDE5E5DEE4E3DBDFDDD6D7D3CBCCC5BDBEB4ABAEA0959C8A7E8B75687A6254\
6D5446634B3D5C463958433755433753423751423852433854443A57473D5B4B40
5F4E43625045635146645146635045624F43604D415E4A3D5B473A574235513D304A372B433126\
3D2C2238281F35261D33251C32251C32251D33261F3327203327213126212F2520
2C231D29201B271E17251B1423191121170F20160E1F150E1D140F1B130F19120E17100E150E0D\
140C0C120B0B120A0B110A0A110A0A11090A1009091008080F07070E06060D0505
0C04050D05050E060710080A120A0C130B0E140C0F130B0E120A0B110809100706100705100805\
120A07150D0A19120F1E1714221C1A261F1E2A22212E2424332726392B293F302C
46342F4A38304B393048372F44342C3E2F28392B25352823342721332620342720352821362921\
372A21372A2135282032251E2F221B2B1F18281C16271A13271912281A122B1D14
30201734231A38261C3B281E3E2A1E422C1F472F214E3425573B2A6243326D4D3C795949866658\
93766AA2877EB19B94C0B0A9CEC3BCD9D3CBE0DCD5E3E1DAE3E2DBE2E2DAE1E1D9
E1E0D8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E2E1DAE2E2DBE3E4DCE4E4DCE3E3DCE1E1D9DEDCD4D7D3CBCDC6BDBFB4AAAD9E929A8679887061\
785E506D5345654D405F4A3D5B483C57463A54443953433854433956453B5A493E
5E4C42614F44635146645247655247645246645145635044604D415C493D5643374E3C3147352B\
402F253B2B2138281F37271E36271F372920392A223A2B243A2C25392C25372B24
34292231261F2E231C2B2018291D15271A132519112318112117101E16101C141019120F17100E\
150E0D130C0C120B0B120A0B110A0B11090A1009090F08080F07070E06060D0506
0D05050E05060F070812090C140C0F160E11160E12150D10140C0E130B0B130A09130B08150C08\
160D09180F0B19110E1B14111E1614221A18261E1C2C221F322723392C273F302A
44342C47352D46342C4231293B2C253527212F231E2C211B2C201A2C211A2D221A2E231B2F231B\
30241B2F231B2D211A2B1F19291D18271B16271A15271A14291B132B1C142F1F16
33221937251C3B281E3E2A1F422C1F472F214E3424573A2862432F6F4D397C5A478A695897796C\
A58B81B39D96BFAFA9CBBFB9D5CDC7DCD8D1E0DED7E2E2DAE2E2DAE2E1DAE1E1D9
E1E0D8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E2E2DAE2E2DAE2E2DBE2E2DBE2E2DAE1E1D9DEDDD5D7D4CCCCC5BCBCB0A5AA998C978274\
876F607A615270594A685245614D415A483C56443953413652413654433857463B
5C4A3F604E4363514665534866544967554A68564A67554A6554486250445B4A3F5443374C3B30\
45342A402F253C2B223A2A213A2A213B2A223C2C243D2E263E2F273D2F273B2E26
392C24362A2234271F31241C2F21192D1F172B1E16291D15261B14231A131F17121C151019110F\
160F0D140C0C120B0B110A0B11090A10090A10090A1008090F07090F07080F0608
0F0708100809120A0B150C0E170F11191114191114181013170F11160E0E170E0D180F0C1A110D\
1C120D1C130E1C130F1B12101C13111F1614241B192C211D3428223B2E2741322A
44342B45342B4231293D2C263627212F221D2A1E19281D18281D17291E172A1F172B20172C2017\
2B20172A1F17291E17281D17271C17271C17291C162B1D172E1F1731211834241A
37261D3B291E3E2B20422D214730224E3424573A2863432F704E3A7E5C478D6B589B7C6CA98E82\
B6A097C1B0ABCBBFBAD3CAC6D9D4CEDDDBD4E0DFD7E1E1D9E2E1DAE1E1D9E1E0D9
E1E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E2E2DAE2E3DBE3E3DCE2E2DADEDCD4D5D1C8C9C0B6BAACA1A9988A\
9984768A74667D6759715C4E6653455D4A3D564438513F34503E33513F34544238
59473C5E4B4162504565534868564B6A584D6C5A4F6C5B506A5A4F67574B6151465A4A3F534237\
4B3A3045342A4130263E2D233C2B233C2B233D2C243E2D263E2E273E2E273D2D26
3B2C24392B2238292037271F36261D34251C32241B2F231A2C2119281F17231B151F17131A1310\
160F0E130C0C110A0A10090A10080910080A11090B11090C120A0C120A0D120A0D
130A0D140B0E160D101910121B13151D15161D15171C14151B12141A11121B12111E1411211712\
2318132318132116121E14111D13121F1514251B192E231E372B243F312944352C
46352D45332C4130293C2B2535262130221D2C1F1A2A1E182A1F182C20182D21182D21182D2118\
2C20172B1F172B1F172A1E182B1F192C201A2F221B33241C37271E3A291F3C2B20
3E2C22402E23432F234831244E3425583A2963433071503B815F4A90705BA0816FAD9384B9A498\
C4B3ABCCC0BBD3CBC7D8D3CEDCD9D3DEDDD6E0DFD8E1E0D9E1E1D9E1E1D9E1E0D8
E1E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E5DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DBE3E3DCE3E3DBE1E0D8DCD9D1D3CEC4C8BFB5BBAEA3\
AC9C8F9B8A7C8B796A7B685A6D5A4C614E41584539523F344F3D324F3D32524035
56443A5B493F614E4365534869574C6D5B4F6F5D526F5F546E5F546B5C5167574C6151465A493F\
5342374C3B3146352B4130273E2D253D2C243C2C253D2C263D2C263D2C263D2C25
3C2B233C2A223C2A223C2B223C2B223B2B22392A2236292032271F2E241C28201A231B161D1613\
181110150E0D120B0B11090A10090A11090B130B0D150C0F160E11170E13170F13
180F131910141B12151E15162018182219192219192118191F16171F1517211717251A18291D19\
2C1F1A2B1E19271B17221715201514221716291E1B3326223D2F2845352D48382F
49372F46342D42302A3E2C2739282335252032241D31231C32241C32251C33251C33251C32251B\
31241A31231A30231B31231C33251E3627203A2A223E2E24423126443327453427
4533274633274934284F3628573B2A634330714F3A825F4A93725EA38674B29989BEAA9DC8B8AE\
D0C4BCD5CDC7D9D4CFDCD9D4DEDCD6DFDED7E0DFD8E0E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DAE2E3DBE2E3DBE2E1D9DFDED6DBD8D0D4CFC6CBC3B9\
BDB3A8ADA0949B8C7E8878697766576957495E4C3F564439524035503F34524036
5543395A473D5F4C4264524769574C6D5B50705F537161557061566E5F556A5C5166574C605046\
5A493F5342384C3B3246352C4231283F2E273E2D263E2C273E2C273E2C273E2C26
3F2C243F2C24402D24412E254130274130283F30283C2F27382D25332A222D251F27201C221B18\
1D1615191212160F0F150D0E150D0E160E0F180F121A11151C13181D141A1E141A
1E151A1F161A21171B231A1B261D1C281E1D281E1D261D1D251C1D251B1D281D1E2D201F312421\
34262133241F2E201C281B1A251918261B1A2E211F382A2642332C4A39314D3B32
4C3A3249362F45322C412F293E2C263C2B243B2A223B2A223B2A213B2B213B2B213B2A203A2A20\
39291F38291F3929203A2A223D2D244130274634294B382C4E3B2D503D2E4F3C2D
4D3A2C4D382C4F392C563C2E614432704F3B815E4993725DA58875B59D8DC3B0A3CDBFB4D4C9C1\
D8D1CADBD6D0DDDAD4DEDCD6DFDED7E0DFD8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DAE2E2DAE2E1D9E1E1D9E0DFD7DDDBD3D6D3CA\
CCC6BCBCB4A9AA9F92988A7C8677697767596B5A4E6251465B4A4157463D56443B
57443B59473D5D4A40624F446754496B594E6E5D526F5F546F60556E60556C5E54695B5165564D\
605047594A4053433A4D3C3348372F45342C43322B42312B42312B42302B43302A
44302945312946322A47332B47342C46352D44352D40342C3C322B372F28322B262D2623292221\
241D1E211A1B1F18191E16171E16161F161721181923191C241A1F241A20241A21
241A21251B21261D21291F212B21212D23212E24222D23222C22242D2225302426352728392A28\
3C2C273A2A253425212E201E2B1E1C2C1F1E3326233D2E2947372F4E3C34503D35
4F3B344C383148342E46312C45302A442F28442F27443026443026443026443025432F25412F24\
402F24402F2541302644322848352A4D392D533E305842335B45345C4534594232
553F2F543C2E563D2F5F44346C4F3D7E5E4B91715DA48774B69D8CC5B2A4D1C3B8D8CFC6DCD6CE\
DEDAD3DFDCD5DFDED7E0DFD7E0DFD8E0DFD8E0E0D8E0E0D8E0E0D8E0E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1DAE2E2DAE3E2DBE1E1D9DDDCD4\
D5D3CAC9C4B9BAB2A6A99F939A8D818C7E7280716776665D6D5C5465544C5F4E45
5C4A405B483E5C493F604C416351456755496A584D6B5B506C5C526B5D536A5D54695C53675A52\
63564E5F51495A4B4355453D5140384E3D354D3B344C3A334C3A344C3A344D3A33
4E3B334E3B334E3B324D3A324C3A324939324638314337303F352F3B342F38312E352E2D322B2C\
30292B2F27292E26272E25252D24242E24232E23232D22242D22252C21272B2027
2A20282A20282B21272E2326302525322725342827342929352A2C362B2F392D303D2F3040302F\
41302C3F2E283A2924342521312220322421392A2642312B4B3931513D35533E36
513C344E39324C362F4A342D4A332B4A332A4B33294C33284C33284C33284B3327493327483328\
47332847342949362B4C392D513D305741335E4636644A38674C39674B38624734
5D42305A3F2F5D4232674C3C785C4B8D705FA28775B59D8CC4B2A3D1C3B7D9D0C7DED9D1E1DED6\
E1DFD8E1E0D8E1E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DDE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E2DBE3E3DCE3E3DCE1E1D9\
DBDAD2D3D0C6C8C3B8BCB4A9AFA69BA4998F998C848E807983736D7867616E5C55
65534B604D435E4B405E4B40604D4262504564524765544966564C67584F675A52675B54665B55\
655A5463575160534C5E4F475C4B435A494059473F58463E58463F59473F59483F
59483F59473F57453D54423B503F394C3D37483B35453A354139343F38353E38373D37383D373A\
3E363B3F363A4037394036364035343E33313C302E392D2D36292C34272C31252C
30252D30252D30252C32272B342829372A2A392C2C3B2E303D31343F3338413439443537453534\
45332F42302A3E2C263A28233727223928233E2D2745332C4C3931513D34533E35
533C34513A324F37304F352E4F352C50342B51352A5135295235295135285036284F36294D362A\
4D372B4D392D4F3B2F533E31594234604737674C3A6D503C71523C70503A6B4B36
654532614332654838715647856C5C9C8575B29D8EC3B3A5D0C3B7D9D0C6DED9D0E1DED6E2E1D9\
E2E1DAE2E1D9E1E1D9E1E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E1D9E1E1D9E2E2DAE3E3DBE3E3DBE1E1DA\
DEDED6DAD8CFD3D1C7CCC8BEC3BDB5BBB3ABB1A7A1A79B969B8D888D7E797F6F69
73625A69574E6351465F4D435E4C415E4C425F4D42604E4461504662524962554E635853645A57\
645C59655B58665A5566585167564E66554C66544B66544A65544B66554C66554C
65554C63544B6050485B4B4456464050413C4B3E3A483D39453D3A443E3C454040474143494247\
4C44494F464A5147495247465146424E423E4A3C394436343F31313B2D30382A30
362931352931352930362A2E382A2D3A2C2D3D2E2F40323443353945383D473A3E48393B483736\
46343044312A402E263E2B243D2A233E2C2542302847342C4D3930513C32533C33
533B32533A3153382F53362D54362C55352B56362A56362957372957372856382955392A533A2C\
523B2E533D30553F325A42345F4636664A396E4F3C74533E78553F78543E74503A
6E4B376B4B397052427E6455937E6FAA998CC0B2A6CFC5BAD9D2C8DED9D0E1DED5E2E0D8E2E1D9\
E2E1DAE1E1D9E1E1D9E1E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E2E1D9E4E3DBE6E5DDE9E8DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E8E0E9E8E0E6E6DEE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1DAE2E2DAE2E2DAE1E1D9\
E0E0D8DEDED5DCDBD2D8D6CED3D0C8CDC8C2C6BEB9BDB3AFB1A5A1A3969194857F
85766E78685F6D5D5366544B614F465E4B425C49405C49405C4A415D4D455E514A5F5450605856\
635C5A665E5C6A605C6D605A706159716057726056716056716056706157706157
6F61566C5E5467595061534B5B4D465547425044404D43404C44424C46454E4849514B4E554E52\
5A50555E535660545561555260524E5B4D475546404E3E3A4737354132333D2F33
3B2E343A2D343A2D333A2C313B2C2F3D2D2E3F2F3042333545373A483A3E493B3E493A3B473735\
46342F433129422E26412D24412D25422F2645322948352C4C382E503A30523A30
543A3055392F56382D57372C58372C59372B5A372A5B382A5C392A5C3A2A5C3B2B5B3C2D5A3E2F\
593F315A41335B42345F44356447376A4B3972503C79543F7D57427F58437D5742
7956437959477F63538E7769A29184B8ACA1CBC4BAD8D3CADFDCD3E1DFD7E1E0D8E1E0D8E1E0D9\
E1E0D9E1E0D8E1E0D8E1E0D8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E2E1D9E4E3DBE6E5DDE9E7DF\
E9E8E0E5E4DCD8D7D0
D8D7D0E5E4DCE9E9E0E9E8E0E6E6DEE4E3DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E0E0D8DFDED7DDDBD4D9D6D0D4CECACCC5C1C2B9B5B6ACA7A89D97
9A8E868B7E767E6F6772625A685750614F475D4A425B483F5B483F5B4A425B4E485B514E5D5655\
605A5A665F5E6C6360726761776962796A617A6A617A6A6079696078695F76695F
74685D71655B6D6057675A5261544D5C4F4A584D48564C49554D4B56504F5952535C555761575A\
65595C685B5D6A5D5C6B5C5968595463544D5C4C4554433D4C3C38473635433434
4133354032363F31353E2F323E2E303E2E2F402F30423133443436463639463739463636453431\
44312C433028422F25432F2544302645312747332949352B4C372D4E382D52382D
55382D57382C5A382C5C382B5D382B5F382B60392B613A2B623C2C623E2D62402E624231624433\
6245356246366346366446366847366D4A38734E3B7A5440805946845E4B866250
8767558B6E5E937B6DA18F82B2A69BC4BDB3D4D0C7DDDBD3E1E1D9E2E2DAE2E1D9E1E0D8E1E0D8\
E1E0D8E1E0D8E1E0D8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E2E1D9E4E3DBE6E5DDE9E7DF\
E9E8E0E5E4DCD8D7D0
D8D8D0E5E5DCE9E9E0E9E8E0E6E6DEE4E4DBE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9E1E1D9\
E1E1D9E2E2DAE2E2DBE2E2DBE1E0DADFDDD7DCD8D3D6D2CDD0CAC4C7C0BABCB5AE
B0A7A0A1979092867F82746E74645F6A5752634F4A5F4C445D4B435D4C455C4F495B524E5C5655\
605B5B6660606E6664756B677C6F697F71698071697F70687D6F677C6F667A6E64
786C62756A5F71665C6D6158695C54655852625752615753605855625A58645B5B675D5D6A5E5F\
6D605F6F605F70615D705F5A6D5C5567564E604E47584640513F3A4C3B37493936
483837473737453536433333423031402E2F402E2E402F2F41303042323142323142322E42302B\
422F28422F26432F2645312647322848342949352B4A362B4C362C4E372C52372C
56382B5A382B5D382A60392B623A2B643B2C653C2D663E2D67402F6842306945336A48366A4A39\
6B4C3B6B4C3C6B4B3A6B4A396D4938704B39754F3D7C5544835D4D8A6757917062
977B6D9F887AA9978AB5A89DC2BAB0CFCAC1D9D7CFDFDFD7E2E2DBE2E2DBE1E1D9E1E0D8E0E0D8\
E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9
E1E0D9E1E0D9E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E2E1D9E4E3DBE6E5DDE9E7DF\
E9E8E0E5E4DCD8D7CF
D8D8D0E5E5DCE9E9E0E8E8E0E6E6DEE4E4DCE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9\
E1E1D9E2E2DAE2E2DBE3E2DBE2E2DBE1E0D9DFDDD7DCDAD3D9D5CFD4D0C9CDC9C1
C4BEB7B7B0A9A69D979589848475727765626E5B5769565066554D64554D635650615854615B5A\
635E5F696464706A69786F6D7E736F82756F83756F82756E80746D7F736B7D7269
7C7067796E64776B6274685F71655C6E625B6D615B6C615C6C625E6D63606E6361706361716361\
73636073635E73625C7160596E5C5469574E6250485C494256433D52403A503E39
4F3D394E3D394C3B3849383546343243312F412F2D402E2C402E2B402E2A402E29402E28412E27\
422E26432F264531274833294A352B4B372C4C382D4D382D4E382D50382C54382C
58392B5D392B613A2B643B2B663C2C683E2D693F2E6941306A43326C46346E4937704D3C735140\
75544376544476534275514075503F7651407A5545815C4E8966599273679C8176
A79186B2A297BDB1A7C7BFB5D0CBC2D7D5CCDDDCD4E0E0D8E1E1DAE2E1DAE1E1D9E1E0D8E0E0D8\
E0DFD8E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9
E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E2E1D9E4E3DBE6E5DDE8E7DF\
E9E8E0E5E4DCD8D7CF
D8D7D0E5E4DCE9E9E0E8E8E0E6E6DEE3E4DCE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9E1E1D9E1E1D9\
E1E1D9E1E1D9E2E1DAE2E1DAE2E1DAE1E0D9E0DFD8DFDED7DEDDD5DDDBD4D9D8D0
D3D0C9C8C4BDB9B2ADA79E9A9689878879767F6E6A79696376665F74665E71665F6E66626D6765\
6D6869716B6D766F707B737280757383777384777384777283767182767082766F
81756E7F736C7E726A7C70687A6E66796C64786B64776A65776A65776A66776965776863776661\
76655E75635C746159725F576F5B536A574E655149604C445C484059453E58443D
58443D57433C54413B513D384D393549353245322F44302C422F2A422F28422E26422F26432F25\
4430264632274934294C372C4E392E503B30513C31523C31533C31553C30583C2F
5C3C2E613D2D643D2D673F2D69402E6A412F6B42316B44326C45346D4837704C3B7552417A5847\
7E5C4C815F4F826050825F4F815E4E825F508563558B6A5E93756B9D837AA9948C
B6A69EC3B8AFCEC7BED5D1C9DAD8CFDDDCD4DFDED6E0DFD8E1E0D8E1E0D8E1E0D8E1E0D8E0E0D8\
E0E0D8E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9
E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E2E1D9E3E3DBE6E5DDE8E7DF\
E9E8E0E5E4DCD8D7CF
D8D7CFE5E4DCE9E8E0E8E8E0E6E6DEE3E4DCE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9E1E0D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E0E0D8
DCDBD3D4D1CBC7C2BDB8B1ADA99F9C9D918E9487838F827C8C80788A7E77877D77847C78817B79\
7F797A7E787A7E77797F7778817777827776847775857875877976887B77897C78
897C78897C78887B76867A7485787183756E82746C81726B80706A7F6E697E6C677C6A647A6860\
78655D76635A756158725E56705B536C585069544C665049634D46624C45624B43
614B43604A415D483F59443D54403A503C364D39334B37304A352E4A342B4A342A493429493428\
4A35294B362B4E392D513C30543E335641365842375942375B42375C42365F4234
6242336542326843316A44316B45326C46336C46336B46346B47356C4938704E3E7755467F5E50\
8766598E6D60917163937365937467957769977B6F9C8277A38B83AC9891B7A8A1
C3B8B1CFC8C0D8D4CCDEDCD3E0DFD7E1E0D8E0DFD7E0DFD7E0DFD8E0E0D8E0E0D8E0E0D8E0E0D8\
E0E0D8E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9E1E0D9
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E2E1D9E3E2DAE6E5DDE8E7DF\
E9E8E0E5E4DCD8D7CF
D7D7CFE5E3DBE9E8E0E8E8E0E6E6DEE3E4DCE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E2E2D9E2E2DAE3E3DBE3E3DB
E0E0D8DAD9D2D1CEC8C6C1BDBBB4B0B2AAA5ACA39DA89E98A59C95A39B94A099939D9793999392\
948F8F8F898B8A8286867D8083797C837879867978897B798C7E7C90827F928582
94878594888694878593858291827E8F7F798C7C758A797288766F86736C847069816D657E6A61\
7B675E78645B756259735F56715D556F5A536D58516C554F6B544D6B534C6B524B
6A5149685047654E45614B425D473F59433C564139553F37553E35553D33543D31533C2F523B2E\
513B2E523C2F543E315641355A44385D463B5F483D61493D63493D64493C66483A
6748386948376A49376C4A376D4B386E4C396D4C396C4B396B4A396C4C3C7151437A5A4D85665A\
9172679B7D73A1857BA68B80A89084AA9488AD988DB09E94B5A59DBCAEA7C4BAB3
CEC6C0D7D2CBDDDBD4E1E0D8E2E2DAE2E1D9E1E0D8E0DFD7E0DFD7E0DFD7E0DFD8E0E0D8E0E0D8\
E0E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9\
E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E2E1D9E3E2DAE6E5DDE8E7DF\
E9E8DFE5E4DCD7D7CF
D7D6CEE5E3DBE9E8DFE8E8DFE6E6DEE3E4DCE2E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9\
E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E1D9E1E1D9E2E1D9E2E2DAE3E3DBE2E2DA
E1E1D9DDDCD5D8D6D0D2CEC8CBC7C1C5C0BBC1BCB6BFB9B2BDB8B0BBB6AFBAB5AEB7B1ADB2ACAA\
ABA5A5A29B9D9890948F878B898083887D7F8B7E7E9082809587849A8C8A9E9190
A19495A29697A29596A092929D8F8C9A8A8698868095817B927D768F79728B766E87726A836E66\
7F6A637B675F78645C75615A735F58725D57715B56715A56715955725853715851
71574F6F554C6B5349675046634D43604A415F483F5F473E5F473D60473B5F46395D44375B4335\
5942335842345943355B45385E483B624A3E654C40674D41694E416A4E406B4D3E
6B4D3D6B4E3C6C4F3C6F513E71544172554372564371544370534371544676594D8063598D7168\
9B8079A88F88B29A93B8A49CBCABA2BFB0A7C2B5ABC4B9B0C7BDB5CBC3BBD0CAC3
D6D1CADBD8D1DFDED6E1E0D9E2E1D9E2E1D9E1E0D8E0DFD7E0DFD7E0DFD7E0DFD7E0E0D8E1E0D8\
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9\
E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E2E1D9E3E2DAE6E5DDE8E7DF\
E9E8DFE5E4DCD7D7CF
D7D6CEE4E3DBE8E7DFE8E7DFE5E6DEE3E4DCE1E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9\
E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E0E0D8DEDED6DCDBD4D9D8D1D7D4CDD4D2CBD2D0C8D1CEC7D0CDC6CFCCC5CECBC4CBC8C3C7C2BF\
BFBAB9B4AEAFA7A1A39C9598958C9093898B968A8A9B8E8CA29491A89B98ADA09F
B0A4A5B1A6A8B0A4A7AEA1A3AB9C9CA79795A4928EA18D889E89829A847D968079917C758B7771\
86726C806D687C696478656175625E74605D745E5D755E5C755D5C765C5A755B57
745A5372584F6F554C6B5349685046654E44644D43654D43674E43674D42674C40644B3D61493A\
5F47385D46375D47385F483A614A3D644B3F674D416A4E426C4F416D4F406C4F3F
6B4F3E6C503E6E5441725946775F4C7B63517D65547C65557C64557D645882695E8C736B99827B\
A8918CB5A19CC0AFA9C8BAB3CDC2BAD0C8C0D2CCC3D4CEC6D5D0C8D7D2CAD9D5CE
DBD8D1DDDBD4DFDED6E0DFD8E1E0D8E1E0D8E1E0D8E0E0D8E0DFD7E0DFD7E0E0D8E1E0D8E1E0D8\
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E0D9E1E0D9
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E1D9E3E2DAE5E4DCE8E7DF\
E8E7DFE4E3DBD7D7CF
D7D6CEE4E3DBE8E7DFE8E7DFE5E5DDE3E3DBE1E2DAE1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E0D9E1E0D9E1E0D9E1E0D8E1E0D9E1E1D9E1E0D9E1E0D8E0E0D8
E0DFD7DFDED7DEDED6DEDDD5DDDCD4DCDCD4DCDBD3DBDBD3DBDAD2DBDAD2DAD8D1D8D6D0D4D1CC\
CDC9C6C3BEBDB8B2B3ADA7A9A69FA1A49C9DA79D9CACA19EB2A7A3B7ADA9BCB2B0
BEB5B5BFB6B8BEB4B7BBB0B3B8ABADB4A6A6B1A1A0AF9D9AAC9994A99590A5918B9F8B86988582\
917E7C8A77768271707D6B6B786667766364756163756063765F61765E5F755D5A
745A557258506F554C6C53496951476750456750456850456950456A50446A4F43674E40654C3D\
624A3B60493A5F483A60493B61493D644A3E664B3E684C3E6A4C3D6A4B3B694B3A
684C3A6A503D6F574477614E806B5A8975648F7B6C917E6F917E71927F749683799F8C84AA9892\
B7A6A0C2B3AFCCBFBAD3C9C4D8D1CADBD7CFDCD9D1DDDBD2DDDBD3DEDBD3DEDCD4
DEDDD5DFDDD5E0DED6E0DFD7E0DFD7E1DFD8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8\
E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8
E1E0D8E1E0D8E1E0D9E1E0D9E1E0D9E1E0D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9\
E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9E1E1D9
E1E0D9E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D9E3E2DAE5E4DCE8E7DE\
E8E7DFE4E3DBD7D7CF
D7D6CFE4E3DBE8E8DFE8E8DFE6E6DEE3E4DCE2E2DAE1E2DAE1E2DAE2E2DAE2E1DAE2E1DAE2E2DA\
E2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DAE2E2DA
E2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1DAE2E1D9\
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9\
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E1E1D9E1E1D9E1E1D9E1E0D8
E0E0D8E0DFD8E0DFD8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0E0D8E0DFD8DFDDD7DCDAD4\
D7D4D0D0CDC9C8C4C2C0BCBBBBB7B5BAB5B2BBB5B2BFB9B4C4BDB7C8C1BCCBC5C1
CDC7C5CDC7C7CBC4C6C8C0C2C5BABDC2B6B8C0B2B3BFB0AFBDAEAABBABA6B7A6A2B1A09DA99897\
A08F909685888C7C808473787D6C7279686E77656C77646A776368766164755F5F
735C587159526F574D6C554A6A53486953476952476A52476B53476B53476B52466A5044674F41\
654D3F634C3E624B3E624B3E634B3E644A3D654A3C66493A664938664836654836
664A376A503D725B487F6A588E7B6A9B8A7BA59688AB9C8FAC9E93ADA096B0A39AB6A9A1BEB1AB\
C6BBB5CFC5BFD6CDC8DBD5CEDEDAD3E0DED6E1E0D7E1E0D8E1E0D8E1E0D7E1DFD7
E0DFD7E0DFD7E0DFD7E1DFD7E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E0D8E1E1D9E2E1D9E2E1D9\
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9\
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9\
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E1E1D9E1E0D9E2E1D9E3E2DAE6E5DDE8E7DF\
E8E7DFE4E3DBD7D7CF
D8D7D0E5E4DCE9E9E1E9E9E1E7E7DFE5E5DDE3E4DBE3E3DBE3E3DBE3E3DBE3E3DBE3E3DBE3E3DB\
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB\
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB\
E4E3DBE4E3DBE4E3DBE3E3DBE3E3DBE3E3DBE3E3DBE3E3DBE3E2DAE3E2DAE2E2DA
E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E2E1D9E0DFD8\
DEDDD6DBD9D3D7D5D0D3D1CCD1CFCAD0CEC8D1CFC8D3D1CAD6D3CCD8D6CEDAD7D1
DAD8D3DAD7D4D7D3D3D4CFD0D1CACDCFC6CACEC4C7CFC4C4CFC3C1CEC1BECABDBAC4B6B5BBADAF\
B1A2A7A5969D998B928E80888577807F717A7C6D777B6C757A6A727A686D786566
76625F745E58725C53705A506F594E6E594D6E584D6E584D6F584D6F584D6F584C6E574B6D5649\
6C55486A5447695346685245685044674F42674D3F674B3C674A39664937654936
674D396D55427963518A77669E8D7EB0A294BEB2A6C6BBB1CAC0B6CBC2B9CCC4BBCEC7BFD2CBC3\
D6D0C8DAD4CDDDD9D1E0DCD5E2DFD7E2E0D8E3E1D9E3E1D9E3E1D9E2E1D9E2E1D8
E2E1D8E2E1D8E2E1D9E2E1D9E3E1D9E3E2DAE3E2DAE3E2DAE3E2DAE3E2DAE3E2DAE3E2DAE3E2DA\
E3E2DAE3E2DAE3E2DAE3E3DAE3E3DBE3E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB\
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB\
E4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DBE4E3DB
E4E3DBE4E3DBE4E3DBE3E3DBE3E2DAE3E2DAE3E2DAE3E2DAE3E2DAE3E2DAE5E4DCE7E6DEE9E8E0\
E9E8E0E5E4DCD8D7CF
D9D9D1E7E6DEEBEBE3EBEBE2E9E9E1E7E7DFE6E5DDE5E5DDE5E5DDE6E5DDE6E5DDE6E5DDE6E5DD\
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD\
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD\
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE5E4DC
E5E4DCE4E3DBE4E3DBE3E2DAE3E2DAE2E1D9E2E1D9E2E1D8E2E1D8E2E1D8E2E1D9E2E2D9E3E2DA\
E3E3DAE3E3DBE4E4DBE4E4DCE4E5DCE5E5DCE5E5DDE6E6DDE6E7DEE7E7DEE7E7DF
E6E6DFE5E4DEE2E0DDDFDCDCDDD8DADBD5D9DCD5D8DDD6D7DFD7D6DFD6D4DCD3D1D6CCCCCDC2C5\
C3B6BDB6A9B2A99CA69D909B9286918B7F8B877B8685798383778082747A807173
7E6E6B7C6A647B685F79665C79655A78655A78645A786459786459786459786358786358786358\
776357776257756155745F54735D51715B4E70584A6F55466E53426D52406D533F
70574477614E85715F998778B0A093C5B8ADD6CCC2E0D8CFE4DED6E5E1D8E5E1D8E4E1D8E4E1D8\
E4E1D8E4E1D9E4E1D8E4E1D8E3E1D8E3E1D8E3E0D8E3E0D8E3E1D8E3E1D9E4E2D9
E4E2DAE4E3DBE5E3DBE5E4DCE5E4DCE6E4DCE6E4DCE6E5DCE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD\
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD\
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD\
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DD
E6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE6E5DDE5E4DCE5E4DCE6E5DDE7E6DEE9E8E0EBEAE2\
EBEAE2E7E6DDD9D8D0
DADAD2E8E8E0EDEDE4EDEDE4EBEBE2E9E9E0E8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E8DFE8E8DF\
E8E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DF
E9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DF\
E9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DF
E9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DF\
E9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE8E8DFE8E7DFE8E7DF
E8E7DFE7E6DEE6E5DDE5E3DBE4E2DAE3E1D9E2E0D8E1E0D7E1E0D7E1E0D7E2E1D8E2E2D9E4E4DA\
E6E6DDE9EAE0EDEEE3F0F1E6F2F4E9F3F5EBF3F6EBF3F5EBF2F4EBF1F4E9F0F2E8
EEF0E7ECEEE5EAEAE4E7E6E4E5E3E4E5E2E4E6E2E5E9E5E6EBE7E6EBE7E5E9E4E2E4DDDEDDD4D8\
D2C9CFC6BCC5BAAFB9ADA3AEA399A49B929D978E99948B9592899191878C8F8485
8D807E8B7D778A7B7289796F89786E89786E89786D88776D87776C87776C87776C88776D89776D\
89776D89776D88766C86746A857267836F63816C5F7F695A7D66567C65537C6654
806A58887463968474AB9B8DC1B4A8D7CCC2E8E0D7F2EDE5F7F4ECF8F7EEF7F6EDF4F4EBF1F1E7\
EEEEE4EBEAE0E8E7DDE6E4DAE5E2D8E3E0D7E3DFD7E3DFD7E3E0D8E4E1D9E5E2DA
E6E4DBE7E5DDE7E6DEE8E6DEE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DF\
E8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE9E7DFE9E7DFE9E7DF
E9E7DFE9E7DFE9E7DFE9E7DFE9E7DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DF\
E9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DF
E9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DF\
E9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E8DFE9E7DF
E9E7DFE9E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DFE8E7DEE8E7DFE9E8E0EBEAE2EDECE3\
EDECE3E8E7DFDAD9D1
DADBD3E9E8E0EDEDE4EDECE4EBEBE2E9E9E1E8E8E0E8E7DFE8E8DFE9E8E0E9E8E0E9E8E0E9E8E0\
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0\
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0\
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8DFE8E7DFE7E5DDE5E4DCE4E2DAE2E0D9E1DFD7E1DFD7E1DFD6E1DFD7E1E0D7E2E1D8E4E4DA\
E6E7DDEBECE1F0F1E6F4F6EAF8FAEEF9FBF0F9FCF1F7FBF0F6F9EFF4F8EDF2F6EB
F1F4E9EFF1E7EDEEE7EBEBE7EAE9E7EAE8E9EBEAEAEEECECF0EEEDF1EFECF0EDEBECE8E7E6E0E2\
DDD7DBD3CCD2C8C1C8BEB7BEB5AEB6AEA8B0AAA4ACA7A2A9A6A0A5A49EA1A29B9B
A19895A0968F9F948B9F92899F92889F91879E91879D90869D90869C90869C90879D91879E9188\
9F92899F91889E91879D8F859B8D83998A7F97877B958577948273938171938272
9786769E8E7FAB9C8EBCB0A3D0C5BAE2DAD1F1EBE3FAF7EFFFFDF5FFFFF7FEFFF6FAFCF2F6F8ED\
F2F3E8EDEEE3EAE9DFE7E5DBE5E2D8E3E0D6E2DFD6E2DFD6E3DFD7E4E1D9E5E2DA
E6E4DCE7E6DDE8E7DFE9E7DFE9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0\
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0\
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0\
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0
E9E8E0E9E8E0E9E8E0E9E8E0E9E8E0E9E8DFE9E8DFE8E7DFE8E7DFE8E7DFE9E8E0EBEAE2EDECE3\
EDECE4E9E8DFDADAD2
D9D9D1E5E5DDE9E8E0E8E8DFE7E6DEE5E4DCE4E4DBE4E3DBE4E4DCE5E4DCE5E4DCE5E4DCE5E4DC\
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC\
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC\
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE4E3DBE3E2DAE2E0D9E0DFD7DFDED6DFDDD5DEDCD4DEDCD4DEDDD4DEDDD5DFDED6E0E1D7\
E3E3DAE7E7DDEBECE1EFF0E5F2F3E8F3F5EAF2F5EAF1F4EAF0F3E9EEF1E7EDF0E5
EBEEE3EAECE2E9EAE2E7E8E2E7E7E3E7E7E4E8E8E6EAEAE7ECEBE8EDECE8ECEBE7EAE7E5E5E2E1\
E0DCDCD9D4D6D2CDCFCBC6C9C4C0C3C0BCBFBDB9BCBAB7B9B9B6B7B8B5B4B7B3B0
B6B1ACB5AFA8B5AEA6B4ACA4B5ACA3B4ABA2B4ABA2B3ABA2B3ABA2B2ABA2B3ABA2B3ACA3B4ACA4\
B5ACA4B5ACA4B5ACA3B4ABA2B3A9A0B1A79DB0A59BAEA398ADA295ACA194ADA294
B0A597B5AB9EBEB4A8CAC1B7D7D0C6E3DED6EEEAE2F4F2EBF7F7EFF8F8F0F7F8EFF4F5ECF0F2E8\
ECEEE3E9E9DFE6E5DBE3E2D8E1DFD6E0DDD4DFDCD4DFDCD4E0DDD5E1DED6E2DFD7
E3E1D9E4E2DAE4E3DBE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC\
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC\
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC\
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DC
E5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE5E4DCE4E3DBE4E3DBE4E3DBE5E4DCE7E6DDE8E7DF\
E9E8DFE5E4DCD9D8D1
D1D1CAD9D9D1DADAD2DAD9D2D9D8D1D8D7D0D7D7CFD7D7CFD7D7CFD7D7CFD7D7CFD8D7D0D8D7D0\
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0\
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0\
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0
D7D7CFD7D7CFD7D6CED6D5CED5D5CDD5D4CDD4D4CCD4D3CCD4D3CCD4D4CCD4D4CCD5D5CDD6D6CD\
D7D7CFD9D9D0DADBD2DCDDD4DEDED5DEDFD6DEDFD6DEDFD6DDDED6DCDED5DCDDD4
DBDCD3DADBD3DADAD3D9DAD3D9D9D3D9D9D4DADAD5DADAD5DBDBD6DBDBD6DBDBD5DAD9D4D8D7D3\
D6D4D0D3D1CED0CECBCDCBC8CAC8C6C8C6C4C6C5C2C5C4C1C5C3C0C4C3BEC3C2BD
C3C1BBC3C0BAC3C0B8C2BFB7C2BEB6C2BEB6C2BEB6C2BEB6C2BEB6C1BEB6C2BFB7C2BFB7C2BFB7\
C3BFB7C3BFB7C3BFB7C2BEB6C2BEB5C1BDB4C0BCB3C0BBB2BFBAB1BFBAB0C0BBB1
C1BCB2C4BFB5C7C3BACCC9C0D2CFC7D7D5CDDCDAD3DFDED6E0E0D9E1E1D9E0E1D9DFE0D7DDDED5\
DBDCD3DADAD1D8D8CFD7D6CED6D5CDD5D4CCD5D3CCD5D3CCD5D4CCD5D4CDD6D5CD
D6D6CED7D6CFD7D7CFD7D7CFD8D7CFD8D7D0D8D7D0D8D7CFD8D7CFD8D7CFD8D7CFD8D7CFD8D7CF\
D8D7CFD8D7CFD8D7CFD8D7CFD8D7CFD8D7CFD8D7CFD8D7CFD8D7D0D8D7D0D8D7D0
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0\
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0\
D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0D8D7D0
D8D7D0D8D7CFD8D7CFD8D7CFD8D7CFD7D7CFD7D7CFD7D7CFD7D7CFD7D7CFD8D7CFD9D8D0DAD9D1\
DADAD2D9D8D1D1D1CA
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Original) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
768 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5EFCEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BD\
EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADE7BDA5EFC6ADEFC6ADEFC6ADE7BDA5
E7B59CE7B59CE7BDA5DEB59CE7B59CDEAD94E7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94\
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEA58C
DEAD94D6A58CDEAD94DEAD94DEA58CD6A584D6A58CD6A58CD6A584D6A58CDE9C84D6A584D6A58C\
D6A58CD6A58CD6A584D6A584D6A584C69C84D69C84D6A58CD6A58CF7E7DEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7D6C6F7D6C6EFCEB5EFCEB5\
EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADE7BDA5E7BDA5
E7B59CDEB5A5E7B59CE7B59CE7BDA5DEAD94DEAD94DEAD94DEAD94DEAD94DEB59CDEAD94DEAD94\
DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEB59CDEAD94DEA58CDEA58CDEAD94
DEAD94DEAD94DEA58CDEA58CDEA58CD6A58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58C\
D6A584D6A58CD6A58CD6A58CD6A584D69C84D6A584C69C84EFBDADF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5\
EFCEB5EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5EFC6ADE7BDA5E7BDA5E7BDA5E7BDA5
E7BDA5E7B59CE7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94
DEAD94DEA58CDEA58CD6A58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A584D6A58CD6A584D6A58C\
D6A58CD6A584D6A584D6A58CD6A584C69C84D6A58CD6A58CF7D6C6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6AD\
EFC6ADE7BDA5EFC6ADE7BDA5E7BDA5E7BDA5E7BDA5E7BDA5DEB5A5E7B59CDEB59C
E7B59CDEB59CDEB59CDEB59CDEB59CDEAD94DEAD94DEAD94DEA58CDEAD94DEA58CDEA58CDEAD94\
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CDEAD94DEA58C
DEAD94DEA58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A584\
D6A58CD6A584D6A584D6A584D69C84D6A584D6A58CDEB59CF7E7E7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6AD\
DEB5A5EFC6ADE7BDA5E7BDA5DEB5A5E7BDA5E7BDA5DEB59CE7BDA5E7AD9CDEB59C
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CDEAD94D6A58CDEAD94DEA58CDEAD94DEAD94\
DEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEAD94
DEA58CDEAD94D6A58CDEAD94DEA58CD6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A58C\
D6A58CD6A58CD6A584D6A584D6A584C69C84D6A58CD6C6BDF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD\
EFBDADEFBDADDEB5A5E7BDA5E7B59CE7BDA5DEB59CE7AD9CDEB59CDEB59CDEAD94
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CDEA58CDEA58CD6A58CDEA58C\
DEAD94DEA58CDEAD94DEA58CD6A58CDEA58CDEAD94DEAD94DEAD94DEAD94D6A58C
DEA58CDEAD94DEA58CDEA58CD6A58CDEA58CD6A584D6A58CD6A58CDEA58CD6A58CD6A58CD6A584\
D6A58CD6A58CD6A58CD6A58CD6A584D6A584DEAD94EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFCEB5F7CEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
EFCEB5EFCEB5F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFCEB5D6C6B5EFC6ADD6C6B5EFBDADE7BDA5\
DEB5A5E7BDA5E7BDA5DEB5A5E7BDA5DEB59CDEB59CDEB59CDEB5A5DEB59CDEB59C
DEB59CD6A58CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CD6A58CDEA58C\
D6A58CD6A58CDEAD94D6A58CDEA58CDEA58CD6A58CDEAD94DEA58CDEA58CDEAD94
D6A58CD6A58CDEA58CDEA58CD6A58CDE9C84D6A58CDE9C84DEA58CD6A58CD6A58CD6A584D6A58C\
D6A584D6A58CD6A58CD6A584D6A58CD69C84DEB59CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5EFCEB5F7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6C6
EFCEB5F7D6BDD6C6C6EFCEB5EFCEB5EFCEB5D6C6B5EFC6ADEFBDADEFBDADEFBDADE7BDA5E7BDA5\
E7BDA5E7BDA5DEB59CE7AD9CDEB59CDEAD94DEB59CDEAD94DEAD94DEB59CDEB59C
DEB59CDEB59CDEB5A5D6A58CD6A58CDEA58CD6A58CDEAD94DEA58CD6A58CDEA58CD6A58CD6A58C\
DEA58CDEA58CD6A58CDEA58CD6A58CDEAD94DEA58CDEAD94D6A58CDEA58CDEAD94
DEAD94DEA58CD6A58CDEA58CD6A58CDEA58CD6A58CDEA58CD6A58CDEA58CDEA58CD6A58CD6A58C\
DEA58CD6A584D6A58CD6A58CD6A584D6A58CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5EFCEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6C6EFCEB5D6C6C6F7D6BD
EFCEB5EFCEB5D6C6BDEFCEB5D6C6B5EFBDADE7BDA5E7BDA5E7BDA5DEB59CE7AD9CE7BDA5E7AD9C\
DEAD94DEB59CDE9C8CDEAD94DE9C8CDEB59CDE9C8CDEB59CDEAD94DEB59CDEB59C
DEB59CDEB59CDEB59CD69C8CDEB59CD6A58CDEB5A5D6A58CDEAD94D6A58CD6A58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94D6A58CDEA58CDEA58CDEAD94
D6A58CDEA58CDEA58CDEA58CD6A584DEA58CDEAD94DEAD94D6A58CDEA58CD6A58CD6A58CD6A58C\
DEA58CD6A58CD6A58CD6A58CD6A584DEB59CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5F7D6C6EFCEB5F7D6C6EFCEB5EFCEB5
F7BDB5EFCEB5EFCEB5F7BDB5EFBDADEFBDADEFBDADEFBDADEFBDADEFBDADE7BDA5E7AD9CE7AD9C\
E7BDA5E7AD9CE7AD9CDEAD94DEAD94DE9C8CDEAD94DE9C8CDEAD94DE9C8CDEB59C
DEAD94DEB59CDE9C8CDEB59CDEB59CDEB59CD6A58CDEB5A5DEB59CD6A58CDEA58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A58C
DEAD94DEAD94DEAD94D6A58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58C\
D6A584D6A58CD6A58CD6A58CD6A58CEFBDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6F7D6BDF7D6BDF7D6BD
D6C6C6EFCEB5F7BDB5EFCEB5F7BDB5F7BDB5F7BDB5EFCEB5EFBDADEFCEB5EFBDADEFB5A5EFBDA5\
EFB5A5E7B59CE7BDA5E7AD9CE7AD9CE7AD9CDE9C8CDE9C8CDEAD94DE9C8CDEAD94
DE9C8CDEAD94DEAD94DEAD94DEAD94DE9C8CDEB59CD6A58CD69C8CDEB59CC6ADA5DEB59CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94DEA58C
DEA58CDEA58CDEA58CDEAD94D6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A584D6A58C\
D6A584D6A58CD6A58CD6A58CD6A584D6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6BDEFCEB5F7D6C6F7D6C6EFD6CEEFCEB5F7D6BDD6C6C6D6C6C6EFCEB5
F7BDB5F7D6BDEFCEB5F7D6BDF7BDB5EFCEB5F7BDB5EFCEB5F7BDB5F7BDB5EFCEB5F7BDB5EFBDAD\
EFBDA5EFBDA5EFB5A5EFB5A5E7B59CE7AD9CDEAD94DE9C8CDEAD94E7AD94DE9C8C
DEAD94DEAD94E7BDA5E7AD9CDEB59CE7AD9CDE9C8CDE9C8CDEA58CD6A58CD69C8CDEB59CDEB5A5\
DEB59CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94
D6A58CD6A58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6C6EFCEB5F7CEB5F7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6EFD6CEF7D6C6EFCEB5EFCEB5EFCEB5F7D6BDEFCEB5EFCEB5EFCEB5
F7D6C6F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDF7BDB5EFBDADF7BDB5\
EFC6ADEFBDADEFB5A5E7B59CE7B59CE7AD9CE7AD9CE7AD94DEAD94DE9C8CDEAD94
E7AD9CE7AD9CEFB5A5E7AD9CE7AD9CE7AD9CDEB59CDEAD94DE9C8CDE9C8CD6A58CD6A58CD6A58C\
DEAD94DEB5A5DEB59CD6A58CD6A584D6A58CD6A58CD6A58CD6A58CD6A584D6A58C
D6A58CD6A58CDE9C84D6A58CD6A58CDEA58CD6A58CD6A58CDEAD94DEA58CD6A58CD6A58CD6A58C\
D6A58CD6A58CDEAD94D6A58CDEAD94F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6EFCEB5\
F7D6BDF7D6C6EFCEB5EFCEB5EFCEB5F7D6C6EFCEB5D6C6C6F7D6BDF7D6C6F7D6BD
EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7BDB5EFCEB5EFCEB5\
EFCEB5EFBDADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CE7AD94E7AD94E7AD94E7AD94
E7AD9CEFB5A5E7BDA5E7BDA5E7BDA5E7AD9CE7AD9CE7AD9CDEAD94DE9C8CDE9C8CDE9C8CD69C8C\
D69C8CD6A58CDEAD94DEB59CD6A58CD6A58CD6A58CDEAD94D6A58CD6A58CD6A58C
DEAD94DEA58CD6A584DEA58CDEAD94D6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A584D6A58C\
D6A58CD6A58CD6A58CD6A58CDEB5A5EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6BDEFCEB5F7D6BDF7D6BDF7D6C6F7D6BD
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5EFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7BDB5F7D6BDEFCEB5F7BDB5\
F7C6ADEFBDADEFBDA5EFBDADEFBDADEFBDA5EFB5A5E7BDA5E7AD9CE7BDA5E7AD9C
E7AD9CE7B59CEFB5A5EFB5A5EFBDADEFB5A5EFB5A5E7BDA5E7AD9CE7AD94DE9C8CDEAD94DEA58C\
DE9C8CD69C8CD69C8CD69C8CDEB5A5D6A58CD6A58CD6A58CDEAD94DEAD94D6A58C
D6A58CD6A58CD6A58CD6A58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A58CD6A584D6A58CD6A58C\
D6A58CD6A58CD6A58CD6A58CEFBDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDEFCEB5\
F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BD\
EFCEB5EFBDA5EFBDADEFBDA5EFC6ADEFC6ADEFC6ADEFBDADE7B59CEFBDA5EFBDA5
E7BDA5E7B59CE7AD9CEFB5A5E7B59CEFB5A5EFBDA5E7B59CEFB5A5E7B59CE7AD9CDE9C8CDEA58C\
DEA58CDEAD94DE9C8CDEAD94DEA58CD6A58CDEB5A5DEB59CDEAD94D6A58CD6A58C
D6A58CD6A58CD6A58CDEA58CD6A58CDEA58CD6A584DEA58CD6A58CDEA58CD6A58CDEA58CD6A584\
D6A58CD6A58CD6A58CDEAD94DECED6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5F7D6C6F7D6C6EFCEB5EFCEB5F7D6C6\
EFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5\
F7BDB5EFC6ADEFC6ADEFBDADEFBDA5EFC6ADEFBDADEFBDA5EFBDA5E7BDA5EFBDAD
EFBDA5EFB5A5EFB5A5E7BDA5E7AD9CEFB5A5EFB5A5E7B59CEFBDA5E7AD9CE7AD9CE7AD94DE9C8C\
DE9C8CE7AD94DEAD94DE9C8CD69C8CD6A58CDEAD94DEB5A5DEB5A5DEAD94DEAD94
D6A58CD6A58CDEAD94D6A58CDEA58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58C\
D6A584D6A58CDEAD94DEB59CF7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6EFCEB5F7D6C6F7D6BD\
F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7CEB5F7BDB5EFC6ADEFC6ADEFBDADEFBDADEFC6ADEFBDADEFBDA5EFB5A5EFBDA5
EFBDADEFBDA5E7B59CEFB5A5E7BDA5EFBDA5EFB5A5EFB5A5E7B59CEFB5A5E7AD94E7AD94E7AD94\
DEAD94DE9C8CDEAD94DE9C8CDEA58CD69C8CD69C8CD6A58CDEB5A5DEB5A5DEAD94
D6A58CD6A58CD6A58CDEA58CD6A58CDEAD94D6A58CDEAD94D6A58CDEA58CD6A58CD6A584D6A58C\
DEAD94D6A58CD6A58CCEB5ADEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5EFCEB5F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECE\
F7D6C6EFCEB5F7BDB5F7C6ADEFCEB5F7C6ADEFBDADEFCEB5EFBDADEFBDADEFBDA5
EFBDADEFBDADEFBDADEFBDA5EFB5A5EFBDA5EFB5A5E7B59CEFB5A5E7B59CE7AD9CE7AD94E7AD9C\
E7AD9CDE9C8CE7AD94DE9C8CDE9C8CDEAD94DE9C8CDEAD94D6A58CDEB59CDEB5A5
DEB59CD6A58CD6A58CD6A58CDEAD94D6A58CDEAD94DEA58CDEA58CD6A58CDEAD94DEA58CD6A58C\
D6A58CDEAD94DEAD94F7BDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6BDF7D6C6EFCEB5F7D6C6EFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BD\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECE
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5EFCEB5F7C6ADEFBDADEFC6ADEFBDAD
EFBDA5EFCEB5EFBDADEFBDADEFB5A5EFBDA5EFB5A5E7B59CEFBDA5E7B59CE7AD9CE7AD9CE7AD94\
E7AD94DEAD94DE9C8CDEAD94DEA58CDEAD94D69C8CDE9C8CD6A58CDEAD94C6ADA5
DEB59CD6A58CD6A58CDEAD94DEA58CDEAD94DEAD94D6A58CD6A58CD6A58CDEAD94D6A58CD6A58C\
D6A58CDEAD94D6A58CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDEFCEB5EFCEB5EFCEB5F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5F7D6BDF7BDB5EFC6ADEFCEB5EFCEB5F7C6AD
EFBDADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFB5A5EFB5A5E7B59CE7B59CE7AD9CE7AD94E7AD9C\
E7AD9CE7AD94DE9C8CDEAD94DEA58CDE9C8CDEA58CDEA58CD6A58CDEAD94D6A58C
DEB5A5DEB59CDEAD94DEA58CD6A58CD6A58CDEA58CDEAD94D6A58CDEA58CD6A58CD6A58CD6A58C\
D6A58CDEAD94DEAD94EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDEFCEB5F7D6C6F7D6C6EFCEB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE
F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7BDB5EFCEB5EFCEB5
F7BDB5EFC6ADEFBDADEFBDA5EFC6ADEFBDADEFBDA5E7B59CE7B59CE7AD9CE7B59CE7AD9CE7AD94\
E7AD94E7AD94E7AD94E7A58CDE9C8CDEA58CDE9C8CDE9C8CDEA58CDEA58CD69C8C
DEB59CDEAD94C6ADA5DEAD94DEA58CD6A58CD6A58CDEAD94DEAD94D6A58CDEA58CD6A58CDEAD94\
D6A58CDEAD94DEAD94DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5
EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6\
F7D6C6F7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5F7BDB5EFCEB5
F7BDB5EFC6ADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CEFB5A5EFB5A5E7AD94E7AD94E7AD9CE7AD94\
E7AD94E7AD9CE7AD94E7AD94E7AD94DE9C8CDEA58CDEA58CDEA58CDE9C8CDEA58C
D6A58CDEB59CD6A58CDEB59CDEB59CDEAD94D6A58CD6A58CD6A58CDEA58CDEAD94D6A58CD6A58C\
D6A58CDEAD94DEB59CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7EFE7E7DEB5A5EFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6BDF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7BDB5F7D6BDEFCEB5F7C6AD
EFCEB5EFC6ADEFBDADEFBDADEFBDA5EFB5A5E7BDA5EFB5A5EFBDA5E7AD9CE7AD94E7AD9CE7AD94\
E7AD94E7AD94E7AD94DEAD94DEA58CDE9C8CDEA58CDEAD94DE9C8CDEA58CD6A58C
DEAD94DEB59CDEB59CD6A58CC6ADA5DEB5A5DEB59CDEA58CD6A58CDEA58CD6A58CDEAD94D6A58C\
D6A58CDEAD94DEB5A5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7E7DEE7C6ADADDEB5A5EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6EFCEB5F7D6C6
F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7DECEF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6\
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7CEB5F7BDB5EFCEB5EFC6AD
F7C6ADEFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59CE7AD9CE7B59CE7AD9C\
E7AD94DEA58CE7AD9CE7AD94E7AD94DEAD94E7A58CDEA58CDEA58CDEA58CDE9C8C
D6A58CD6A58CDEB59CBDA59CD6A58CDEB59CDEB5A5C6ADA5DEA58CD6A58CDEAD94D6A58CD6A58C\
DEAD94DEAD94CEB5ADEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
E7DEEFC6ADA5AD847BE7BDA5F7D6BDF7D6BDF7D6BDF7D6C6EFD6CEEFCEB5EFCEB5
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7CEB5F7BDB5EFC6AD
EFC6ADEFBDA5EFCEB5EFC6ADEFBDA5E7B59CEFBDA5E7B59CEFB5A5E7AD9CE7AD9CE7AD9CDEB59C\
E7AD94DEAD94E7AD94DEAD94E7AD94DEAD94DEA58CDEA58CDE9C8CDEA58CDEA58C
D69C84DEAD94DEAD94DEAD94DEAD94D6A58CD6A58CDEB59CD6A58CD6A58CD6A58CDEAD94DEAD94\
D6A58CDEAD94EFBDADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
B5A5A5846B5A9C7363EFC6ADEFCEB5F7D6BDF7D6C6EFD6CEEFCEB5F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7D6BD\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFC6AD
F7C6ADEFBDADEFC6ADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CEFB5A5E7B59CE7AD9CE7AD9CE7AD94\
E7AD9CE7AD94E7AD94E7AD94E7AD94E7AD94E7AD94DEAD94DEAD94DEA58CDEA58C
D6A58CD6A58CDEAD94DEAD94D6A58CD6A58CD6A58CDEB59CDEB59CD6A58CDEAD94DEAD94DEAD94\
D6A58CDEAD94EFCEB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6D6\
73524A634231AD846BEFC6ADEFCEB5F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6\
F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7BDB5EFCEB5EFC6AD
EFC6ADEFBDADEFC6ADEFBDA5EFBDA5EFB5A5E7BDA5EFB5A5E7BDA5E7B59CE7B59CE7AD94E7AD9C\
E7AD94DEAD94DEA58CDEAD94E7AD94DEAD94DEAD94DEAD94DEA58CDEA58CDEA58C
D69C84D6A58CDEA58CDEAD94DEAD94DEAD94D6A58CD6A58CDEB5A5DEB5A5D6A58CDEAD94DEAD94\
DEAD94C6ADA5D6C6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E78C7363\
5A3121634A42B58C73EFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7C6ADEFC6AD
EFBDADEFC6ADEFBDA5EFC6ADEFBDA5E7BDA5EFBDA5E7BDA5EFB5A5E7BDA5E7B59CE7B59CE7B594\
DEAD94E7AD94DEAD94DEA58CE7B59CE7AD94E7A58CDEAD94DEA58CDEAD94DEA58C
DEA58CDEA58CD6A58CDEAD94D6A58CD6A58CDEAD94D6A58CDEB59CCEB5ADDEB5A5DEAD94DEAD94\
DEAD94DEAD94EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7EFEFA584845A3129\
5A312163423194736BF7D6BDD6C6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6C6\
EFCEB5F7D6BDF7D6BDF7CEB5F7D6BDF7D6BDEFCEB5F7CEB5F7CEB5EFC6ADEFC6AD
EFC6ADEFC6ADEFBDA5EFBDADEFC6ADEFBDA5EFBDA5EFBDA5E7BDA5EFBDA5E7B59CE7AD9CE7B59C\
E7AD9CDEAD94E7AD94DEAD94E7B59CDEAD94DEA58CE7AD94DEA58CDEAD94DEA58C
DEA58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A58CDEB59CDEB5A5DEB5A5DEAD94\
DEAD94D6A58CEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C6B524A634231523129\
4229188C6352DEB5A5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5\
F7CEB5EFC6ADF7C6ADEFCEB5EFC6ADEFCEB5EFBDADEFC6ADEFC6ADEFC6ADEFBDA5
EFBDA5E7B59CEFBDA5EFBDA5E7BDA5EFBDA5E7B59CE7B59CEFBDA5E7B59CE7B59CE7AD9CE7AD94\
DEAD94E7AD94E7AD94E7AD94DEB59CE7AD9CDEAD94DEA58CDEAD94DEA58CDEAD94
DE9C84DE9C84D6A58CDEA58CD6A58CD6A584D6A58CD6A58CDEAD94D6A58CD6A58CDEB59CEFBDAD\
DEB5A5DEAD94F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF6B524A734A39634A42422918\
5A3129CEB5ADF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7C6AD\
EFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFB5A5EFBDA5EFBDA5EFBDA5EFBDA5
EFBDA5EFBDA5E7B59CE7B59CE7B59CEFBDA5E7B59CEFBDA5E7B59CE7B59CE7BDA5E7AD94DEAD94\
E7AD94DEAD94DEAD94DEA58CE7B594DEAD94E7AD9CE7AD94DEA58CDEA58CDE9C84
D6A584D6A58CDE9C84D6A58CDEA58CD6A584D6A58CDEA58CD6A58CDEAD94D6A58CDEAD94DEB5A5\
D6C6B5DEB59CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFD6C6CE6B524A634A425231295A3129\
DEAD94EFD6CEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7BDB5\
EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CEFBDA5EFBDA5EFBDA5
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5EFBDA5E7BDA5E7BDA5E7B59CE7B59CE7AD9CDEAD94\
E7AD94E7AD94DEAD94E7AD94E7AD9CDEAD94E7AD94DEAD94DEA58CDEA58CDEA58C
D6A584DEA58CD6A584DEA58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58CD6A58CD6A58CD6A58C\
DEB5A5D6C6BDF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7947B736B524A634231634231C6ADA5\
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5\
EFC6ADEFC6ADEFBDA5EFC6ADEFBDA5EFC6ADEFBDA5E7BDA5EFB5A5EFBDA5EFBDA5
E7BDA5E7B59CE7B59CE7B59CE7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CDEB59CE7AD94E7B594\
DEAD94DEAD94E7AD94DEAD94DEB59CE7AD94DEAD94DEAD94DEA58CDEA58CDE9C84
D6A58CD6A584DE9C84D6A58CD6A584D6A584D6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A58C\
DEB59CDEB5A5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFAD9C8C5A4239734A39734A39C69C84F7D6C6\
F7D6C6EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5\
EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59C
EFBDA5EFBDA5E7BDA5E7BDA5EFBDA5E7B59CE7B59CE7B59CE7B59CE7AD94E7AD94E7AD94DEAD94\
DEA58CE7B594DEAD94E7AD94E7B594DEAD94DEAD94E7A58CDEA58CDEA58CD6A58C
DEA58CD6A584D6A58CD6A58CD6A584D6A58CD6A584D6A58CD6A584DEA58CDEAD94D6A58CDEAD94\
DEAD94DEB59CF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFBDB5BD6B524A5A42396B524AAD9C8CEFD6CEF7D6C6\
EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7BDB5EFC6ADEFBDA5\
EFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59C
E7BDA5E7B59CE7BDA5E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CDEAD94DEAD94DEA58CE7AD94\
DEAD94DEA58CDEAD94DEAD94DEA58CE7AD94DEAD94DEA58CDEAD94DEA58CDEA58C
D6A58CD6A584D6A584DEA58CD6A584D6A584DEA58CD6A584D6A58CDEA58CD6A58CD6A58CDEAD94\
D6A58CDEB59CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7DEE77B635A5A4239634231AD846BF7D6C6F7D6C6EFCEB5\
F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7BDB5EFCEB5EFCEB5F7C6ADEFC6ADEFBDAD\
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CEFBDA5
E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7B594DEAD94E7B594E7AD9CE7AD94DEAD94DEAD94\
DEA58CDEAD94DEA58CDEA58CDEA58CDEA58CE7B594DEA58CDEA58CDEA58CDEA58C
DEA58CDE9C84D6A584D6A58CDEA58CD6A584D6A58CD6A58CD6A58CD6A58CDEA58CD6A58CDEAD94\
D6A58CDEAD94DEB5A5EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7FFFFFFC6ADBD634A426342315239317B6352F7DECEF7D6C6F7D6C6F7D6BD\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6
F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5F7BDB5EFCEB5F7BDB5EFBDADEFBDAD\
EFB5A5EFB5A5E7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD94E7AD94E7AD94
E7AD94E7AD94E7AD94E7AD94DEAD94E7AD94DEAD94E7AD94DEAD94E7A58CDEA58CDEA58CDEAD94\
DEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CDEAD94DEA58CDEA58CD6A584
DEA58CDEA58CDEA58CD6A58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58CDEA58CDEAD94D6A58C\
D6A58CDEAD94DEAD94DEB59CD6C6BDEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFE7E7947B73634231634A42734A39BD9C8CF7D6C6EFCEB5F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6\
F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6EFCEB5F7BDB5F7BDB5F7BDB5EFB5A5\
EFB5A5E7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD9CE7AD9CEFB5A5E7AD94E7AD9C
E7AD9CE7AD9CE7AD94DE9C8CE7AD94DEAD94E7AD94DEAD94DEA58CDEAD94DEA58CDEA58CDEA58C\
DEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CDEA58CDEA58CD6A584
DEA58CD6A584D6A584DEA58CDEA58CD6A58CDE9C84DEA58CDE9C84D6A58CDEA58CD6A58CDEAD94\
DEA58CDEA58CDEB59CD6A58CDEB59CEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFBDB5BD5A4239634A42734A39AD8C84EFD6CEF7D6C6F7D6BDF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BD\
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7BDB5F7BDB5F7BDB5F7BDB5EF948CEF948CEF948C\
EF948CE79484E79484E7847BDE9C84E7847BDE9C8CEF948CE7AD94DE9C8CEF948C
E7AD94E7AD94E7AD94E7AD94E7A58CDEAD94DEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58C\
DEA58CDEA58CD6A58CD6A58CDEA58CD6A584DEA58CDEA58CDEA58CDEA58CDEA58C
D6A58CD6A584DEA58CD6A58CDEA58CD6A58CD6A58CD6A58CDE9C84D6A584D6A58CDEA58CD6A58C\
D6A58CDEA58CD6A58CDEB59CDEB59CEFBDADEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7947B73634231634A428C7363EFD6CEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6\
F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7BDB5F7BDB5F7C6ADEF948CEF948CF7BDB5E7AD9CEF948C\
EF948CE7847BE7847BE7847BE7847BE7847BE7847BE7847BEF948CE7847BE7847B
E7847BD68C7BE79484E7A58CE7AD94E7AD94DEAD94DE9C8CDEA58CDE9C84DEA58CDEA58CDEA58C\
DE9C84D6A58CDEA58CDE9C84D6A584D69C84D6A584D6A584DEAD94DEA58CDEA58C
DEA58CDEA58CD6A58CDEA58CDEA58CDEA58CDEA58CDEA58CD6A584D6A584DEA58CD6A58CDE9C84\
DEAD94D6A58CDEAD94D6A58CDEB59CD6A58CEFCEB5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7E7DEEF7B635252393173524AEFBDADEFD6CEEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BD\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7BDB5F7BDB5F7BDB5D6BDC6F7C6ADEF948CEF948CEF948C\
E7847BE7847BE7847BE7847BDE7B6BE7847BE7847BDE9C84E7847BE7847BE7847B
DE7B6BE7847BE7847BD68C7BD68C7BE79484DE9C8CE7A58CDE9C8CDEA58CDEA58CD6A58CDEA58C\
DEA58CDE9C84DE9C84D6A58CD69C84D6A584D6A584DEA58CDEA58CDEA58CDEA58C
D6A58CDEA58CD6A58CDEA58CDEA58CDEA58CD6A58CD6A58CD6A58CDE9C84D6A58CDEA58CD6A58C\
DEA58CDEA58CDEAD94DEAD94DEAD94DEB59CDEB5A5DECED6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7CEB5B56B524A634231AD8C84F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5EFCEB5F7CEB5F7D6BDF7CEB5F7D6BD\
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7DECEF7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5EF948CEF948CEF948C\
E7847BE7847BE7847BE7847BE7847BE7847BE7847BEF948CE7847BE7847BE7847B
E7847BDE7B6BE7847BE7847BE7847BD68C7BE7847BCE8C84DE9C8CDE9C8CDEA58CDEA58CD6A58C\
D6A58CD6A58CD6A584D6A584D69C73D6A584D6A584D6A58CD6A584DEA58CDEAD94
DEA58CDEA58CDEA58CDEA58CDEA58CDEA58CDEA58CDEA58CD6A584DEA58CDEA58CD6A584D6A58C\
DEA58CD6A58CDEAD94D6A58CDEAD94DEB59CD6A58CEFBDADF7E7DEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7947B73523931846B5AEFCEB5F7DECEEFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7DECEF7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7D6C6F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7BDB5\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECE
F7D6C6F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7E7DEF7BDB5F7BDB5F7C6ADF7C6ADEFB5A5EF948C\
E7847BE78473E7847BE7847BE7847BE7847BDE9C8CEF948CE7847BE7847BE7847B
E7847BE7847BDE7B6BE7847BE7847BE7847BDE7B6BE7847BD68C7BDE9C8CDE9C8CDEA58CDEA58C\
DEA58CDEA58CDEA58CD69C84CE947BD69C84D6A584DE9C84D6A58CDEA58CDEA58C
D6A58CDEAD94DEA58CDEA58CDEA58CDEAD94DEAD94DEA58CDEA58CD6A584DEA58CDEA58CD6A58C\
D6A58CDEA58CDEAD94DEAD94D6A58CDEAD94DEB59CDEB59CD6C6C6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
D6C6C6AD9C8C634231AD846BEFD6CEF7DECEF7D6BDEFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDF7CEB5EFCEB5F7CEB5EFCEB5F7CEB5F7D6BDF7D6BDF7BDB5F7CEB5\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7BDB5F7BDB5
F7BDB5F7BDB5DECED6F7BDB5F7BDB5F7BDB5F7BDB5EF948CEF948CE7847BE7847BE78473E78473\
E77B6BE77B6BDE6B5ADE6B5ADE7B6BDE6B5AE7847BE7847BE7847BE77B6BE78473
DE7B6BE78473DE7B6BE78473E7847BE7847BE7847BE7847BD68C7BD67B6BE7847BD69C8CD69C84\
DE9C8CD6A584DEA58CD6A584D69C84D6A584D69C73D69C84DE9C84DEA58CDEA58C
DEA58CDEA58CDEA58CDEAD94DEA58CDEA58CDEAD94DEA58CDEA58CDEA58CDEA58CD6A584DE9C84\
DEA58CD6A58CDEA58CDEAD94D6A58CDEA58CDEAD94DEAD94DEB59CD6C6B5F7F7F7
F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECED6
9484849C8C8C5A3129DEB5A5F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BD\
F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6BDF7D6BDF7CEB5EFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7CEB5EFC6ADF7D6BD\
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7BDB5F7BDB5F7BDB5
F7BDB5F7DECEF7BDB5F7DECEF7BDB5F7C6ADE7AD9CE79484E78473E78473E77B6BD67363DE6B5A\
DE6B5AD67363DE6B5ADE6B5AE77B6BE77B6BE77B6BE77B6BE78473E77B6BE77B6B
DE6B5ADE6B5ADE7B6BDE7B6BDE7B6BDE7B6BDE7B6BDE7B6BE7847BE7847BD68C7BDE9C84DE9C84\
DE9C8CD6A58CDE9C84D6A58CD69C73D69C84D69C84D6A584D6A584DEA58CDEA58C
DEA58CDEA58CDEAD94DEAD94DEAD94DEA58CDEAD94DEA58CE7A58CDEA58CDEA58CD6A584DE9C84\
D6A58CDEA58CD6A58CDEAD94DEA58CDEAD94DEAD94D6A58CDEB59CDEB5A5F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF9C8C8C
7B635A735A528C7363F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BD\
F7D6BDF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDF7CEB5F7C6ADEFBDA5EFCEB5F7CEB5F7C6ADF7C6ADEFC6ADF7CEB5\
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7BDB5F7BDB5F7BDB5F7BDB5
F7BDB5F7BDB5F7BDB5F7BDB5EFB5A5E79484E79484E78473D67363DE6B5ADE6B5AD66352DE6B5A\
DE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5AD67363DE6B5A
DE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE7B6BDE7B6BDE7B6BE7847BD67B6BD67B6BD68C7BCE8C84\
D69C84DE9C8CD6A58CDE9C84D69C84D69C84D69C73D69C84D6A584D6A584D6A58C
DE9C84DEA58CDEA58CDEA58CDEA58CDEA58CDEAD94DEA58CDEA58CDEAD94DEA58CD6A584DEA58C\
D6A58CD6A58CDEA58CD6A58CDEA58CDEA58CD6A58CDEAD94D6A58CDEB59CE7DEE7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFC6ADBD8C7363
7B635A523129EFCEB5EFD6CEF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BD\
F7D6BDF7CEB5F7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7BDB5F7CEB5EFC6ADEFBDA5EFC6ADF7CEB5EFC6ADF7C6ADEFC6ADF7C6AD\
F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7BDB5F7BDB5F7BDB5F7BDB5F7BDB5F7C6AD
F7BDB5EFB5A5E7AD9CEF948CEF948CE78473E77B6BDE7B6BDE7B6BCE8C84DE9C84CE8C84CE7352\
D68C7BE7847BDE7B6BDE7B6BD67B6BCE5A4AD67B6BD67363DE6B5AD66352DE6B5A
DE6B5AD66352DE6B5AD66352DE6B5ADE6B5AD67363DE7B6BDE7B6BD68C7BD68C7BD67B6BD68C7B\
D68C7BD69C8CDE9C8CD6A584D69C73D69C84D69C73C69C84D69C73D6A584DEA58C
DEA58CDEA58CDEA58CDEA58CDEAD94DEA58CDEA58CE7AD94DEA58CDEA58CDEA58CDEA58CD6A584\
DE9C84DEAD94D6A58CDEAD94DEA58CD6A58CDEAD94DEAD94DEAD94DEB59CEFD6CE
E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E79C8C8C735A52
5A4239523129F7DECEF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BD\
F7D6BDF7D6BDF7CEB5F7D6BDF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7D6BDF7D6BDEFCEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5F7D6BD\
F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7BDB5F7C6ADF7C6ADF7C6ADF7C6ADE7AD9C
EF948CEF948CE79484E7847BE78473DE7B6BD68C7BCE8C84DE9C8CDEB5A5E7AD9CE7AD9CC66B52\
CEB5B5F7BDB5DEB5A5DEB59CDE9C8CB5735AE7AD9CE7AD9CDE9C84D67B6BD67363
D66352D66352CE5A4AD66352D66352DE6B5ADE6B5ADE6B5ADE7B6BDE7B6BD67B6BD67B6BD68C7B\
D68C7BD68C7BDE9C8CD6A58CD69C84D6A584CE947BD69C73D69C84D6A584DE9C84
D6A584D6A584DEA58CDEA58CDEA58CDEA58CE7A58CE7AD94DEA58CDEA58CDEAD94DEA58CDEA58C\
D6A58CD6A58CDEAD94DEA58CDEAD94DEA58CDEA58CDEAD94DEAD94DEAD94DEB5A5
F7E7DEE7DEE7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7DEE79C8C8C8C736B634A42
422921846352F7D6C6F7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5\
F7CEB5F7CEB5F7CEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7CEB5F7D6BDF7CEB5F7C6ADEFBDA5EFBDA5EFBDA5E7B59CEFBDA5EFBDA5EFCEB5F7D6BD\
F7DECEF7D6C6F7DECEF7BDB5F7BDB5F7C6ADEFB5A5EFB5A5E7AD9CEF948CE79484
E7847BE78473D67363D67B6BE7847BCE947BCEB5B5EFD6CED6C6BDEFD6CED6C6C6D6C6BDD69C8C\
DECED6D6C6BDF7BDB5CEB5B5DEB5A5CE8C73CEB5B5CEB5B5DEB5A5DEB5A5CE8C73
A5634AD67363BD846BCE7352CE5A4ADE6B5AD66352D67363DE6B5AD67B6BD67B6BD67B6BD67B6B\
D68C7BD68C7BCE8C84D69C84D69C84D69C73CE947BD69C73D69C84D6A584DE9C84
DE9C84DEA58CDE9C84DEAD94E7AD94DEAD94DEAD94DEAD94DEAD94E7AD94DEAD94DEA58CD6A58C\
DEA58CDEA58CDEA58CDEAD94DEAD94DEA58CDEA58CDEAD94DEAD94D6A58CDEAD94
D6C6B5E7DEE7EFE7E7E7DEEFF7EFEFEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD8C737B6B524A523129
5A3129AD8C84F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BD\
F7C6ADF7C6ADF7CEB5F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7CEB5F7CEB5F7CEB5EFC6ADEFC6ADEFBDA5E7B594E7B594E7B594E7B594EFBDA5F7CEB5F7D6C6\
F7DECEF7D6C6F7BDB5F7C6ADEFB5A5EF948CE7AD94E7AD94EF948CE78473E77B6B
D66352CE5A4AB55239D67363C6ADA5D67B6BE7AD9CD6C6C6D6C6C6EFD6CED6C6C6CEB5B5CEB5B5\
D6C6CECEB5B5CEB5B5EFBDADCEB5B5BDA59CD6C6BDD6C6BDF7BDB5CEB5B5CE8C84
AD6B52C69484D69C8CBD846BA5634A945239CE5A4AD66352D67363D66352D67363D67B6BD67B6B\
D67B6BD68C7BD68C7BD68C7BD6A584D69C84D6A584D69C84D69C73D6A584D6A584
DE9C84D6A584DEA58CDEA58CDEAD94E7B594E7B594DEAD94DEAD94DEAD94DEA58CDEA58CDE9C84\
D6A58CDEA58CDEAD94DEA58CDEAD94DEA58CD6A58CDEAD94DEAD94D6A58CDEAD94
DEB59CE7DEE7E7DEEFF7EFEFE7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E79C8C8C8C7B7363524A523129
6B524ACEB5ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7CEB5\
F7C6ADEFC6ADF7CEB5F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7BDB5EFC6ADF7C6ADEFBDA5EFBDA5E7B594E7B594E7A58CE7A58CEFBDA5F7D6BDF7DECE\
F7DECEF7BDB5E7AD9CE7AD9CEF948CEF948CEF948CEF948CE78473BD5A42BD5A42
CE5A4ACE7352D66352CE7352D67363E79484DE7B6BDE7B6BD68C73E78473D68C73D67B6BD69C84\
D69C8CD6A58CC6ADA5C6ADA5DEB5A5D69C8CCEB5B5D6C6B5CEB5B5D6C6B5D69C8C
BD846BD69C8CC6ADA5C6947BB57B63A54231A54231C66B52D66352D66352D67363D67B6BD67B6B\
D68C7BD67B6BD68C7BCE8C84D69C84D69C84D69C73CE947BD69C73D69C84D6A584
DE9C84DEA58CDEA58CDEAD94DEAD94DEA58CDEAD94E7B594E7B59CE7B594DEAD94DEA58CDE9C84\
DEA58CDEA58CDEAD94DEAD94DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEB59C
DEB59CD6C6C6EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFBDB5BDB59C9C8C7B735A4239523129
C69C84F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7CEB5EFC6AD\
F7C6ADEFBDA5EFC6ADF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6
F7C6ADEFC6ADF7C6ADEFBDA5E7B594E7A58CDE9C84DE9473DE9C84EFBDA5F7D6BDF7D6C6F7BDB5\
E7AD94E7847BE79484E7847BE78473CE8463C66B52842918631810D67B6BEFCEB5
E7AD9CCE8463DE6B5AE79484E79484E79484DE7B6BDE7B6BEFB5A5F7E7DEF7E7E7F7EFEFF7E7DE\
EFD6CEEFD6CEE7AD9CE77B6BD67363E79484D68C7BCE8C73D67363CE735AC66B52
BD8463D69C8CBDA59CBDA59CC69484AD7B6BA56B52AD735AA5634AA55239CE5A4AD66352D66352\
CE735ACE8C73D67B6BCE947BD68C7BD69C84D69C84D69C73C69C84D69C73D6A584
DE9C84DEA58CDEA58CDEAD94DEAD94E7B59CE7B59CE7B594E7B594E7B594E7B594DEAD94DEA58C\
DEA58CDEA58CDEAD94DEAD94DEAD94DEA58CD6A58CDEA58CDEA58CDEAD94DEAD94
DEAD94EFBDADD6C6C6DED6E7F7E7DEF7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6CE9C8C8CB5A5AD7B635A4229216B524A
F7BDB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7C6ADF7C6AD\
F7C6ADF7C6ADEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
EFC6ADF7C6ADEFBDA5E7B59CE7A58CE7A58CDE9C84DE9C84DEA58CEFC6ADF7D6C6F7C6ADE7A58C\
DE7B6BDE7B6BC66B529C5A42CE735ACE8C84DEB59CD6C6BDC68C73EFCEB5F7E7DE
F7E7DEEFBDA5EFBDADF7DECEF7DECEF7BDB5E7AD94E7847BF7E7DEF7EFEFF7EFEFF7E7E7F7E7DE\
F7E7DEEFD6CEF7E7DED6C6C6EFCEB5DECED6EFD6CEF7DECED6C6C6EFBDADD68C7B
D67B6BC66B52BD846BBD9C8CC69484B5846BAD735AAD735AA5735A9C5A42A54231BD5A42CE5A4A\
CE5A4AD67363C66B52D67B6BD68C7BD69C84D69C73D69C84D68C7BD6A584DE9C84
D6A58CDEA58CDEA58CDEAD94E7B594E7B59CEFBDA5E7B59CE7B59CE7B594E7B594DEAD94DEA58C\
DEA58CDEA58CDEAD94DEAD94DEA58CDEAD94DEAD94DEA58CDEA58CD6A58CDEAD94
DEAD94C6ADA5EFCEB5DECED6DED6E7D6C6BDF7E7DEF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7ADA5AD9484849C8C8C5A4239523129B58C73
EFD6CEF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7CEB5F7CEB5F7C6ADEFBDA5\
EFBDA5EFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6BD
F7C6ADEFBDA5E7B59CE7A58CE7A58CDE9C84DE9473D69C73E7A58CEFC6ADEFB5A5DE7B6BDE6B5A\
D663529C392942181094634ADEB59CEFBDADF7E7DEF7DECEF7CEB5F7E7DEF7E7DE
F7E7DEF7E7DEF7EFEFF7EFEFF7EFEFF7EFEFF7E7DEEFBDA5F7E7E7F7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7DECEF7E7DEEFCEB5EFD6CEEFD6CEF7E7DEEFD6CEEFD6CEEFD6CEEFD6CE
D6C6C6E7847BB55239C66B52B5735AA56B5294736BB58C73AD7B6B945239734A39A54231BD5A42\
CE5A4AC66B52D67363D67363D68C7BDE9C84D69C84D69C73C69C84D69C73D6A584
DE9C84DEA58CDEA58CE7B594E7B59CE7B59CE7BDA5EFBDA5E7B59CE7B59CE7B594E7B594DEA58C\
DEA58CDEAD94DEAD94D6A58CDEAD94DEAD94DEA58CDEAD94D6A58CDEAD94DEAD94
DEAD94DEB59CD6C6B5F7E7E7F7F7F7DED6E7D6C6D6DECED6E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD94948C7B73735A524A3131634A42DEB5A5
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7CEB5F7D6BDF7D6BDF7C6ADF7C6ADEFBDA5\
F7C6ADF7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BD
EFC6ADEFBDA5E7B594E7A58CDE9C84DE9473CE8C6BDE9C84DEA58CE7AD94D67363CE5A4AB55239\
9C3929844A39945239DEB59CEFCEB5F7D6C6F7E7DEF7DECEF7D6C6F7E7DEF7E7DE
F7E7DEF7E7E7F7E7E7F7E7E7F7EFEFF7EFEFF7E7DEF7DECEF7E7E7F7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7E7DEF7DECEEFCEB5EFD6CEF7E7DEEFD6CEEFD6CEEFD6CEEFD6CEEFD6CE
EFD6CEDEB59CCE5A4ACE735ACE5A4AAD5A42A56B52AD7B6BAD7B6B734231734A398452429C3929\
BD5A42CE5A4ACE5A4ACE735ACE8C73CE8C84D69C84D69C84D69C73D69C84D69C73
D6A58CDEA58CDEA58CDEAD94E7B594E7B59CE7B59CEFBDA5EFBDA5E7B594E7B594DEAD94DEA58C\
DEA58CDEAD94DEA58CDEAD94DEAD94DEA58CDEA58CDEA58CDEAD94DEAD94DEAD94
DEAD94DEB59CEFBDADDED6E7F7EFEFF7EFEFF7F7F7D6C6D6DECED6F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C7B7363524A634A42523129845242F7D6C6
EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7C6ADEFBDA5\
EFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
F7C6ADEFBDA5E7A58CE7A58CDE9473CE8C6BCE8463D68C7BD68C73D66352B552399C39298C2921\
8C31299C5A42BD846BD6C6BDEFD6CEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7E7F7EFEFF7EFEFF7E7DEF7E7DEF7DECEF7E7E7F7EFEFF7EFEFF7E7E7F7E7DE\
F7E7DEF7E7DEEFD6CEEFCEB5EFD6CEF7E7E7F7E7DEF7E7DEF7E7DEEFD6CEEFD6CE
EFD6CEDEB5A5E7BDA5D6C6BDC6ADA5CE8C84AD5A42A55239945A4A8C31295A3121633931734229\
9C3929BD5A42BD5A42C66B52CE8C73D68C73D69C84D6A584D69C84D69C73D6A584
DE9C84DEA58CDEA58CE7A58CE7B59CE7B594EFBDA5EFBDA5E7B59CEFBDA5E7B59CE7B594E7B594\
DEA58CDEA58CDEAD94DEA58CDEA58CDEAD94D6A58CDEA58CD6A58CDEAD94DEAD94
DEAD94DEAD94DEB5A5EFCEB5DED6E7F7EFEFF7EFEFF7EFEFEFE7E7E7DEEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7F7F7F7EFE7E7F7F7F7EFE7E7F7EFEFF7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF8C736B5242395239315231298C7363F7DECE
F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5EFC6ADF7C6ADF7C6AD\
EFC6ADF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
EFBDA5E7B594E7A58CDE9C84DE9473CE8463CE8C6BCE735AB55239A542318C29218429187B2918\
945239A5735ADEB59CF7D6C6F7D6BDF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7D6C6F7E7DEF7E7DEF7E7E7F7EFEFF7E7DEF7D6C6F7D6C6F7E7DEF7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7DECEEFCEB5EFBDA5EFD6CEF7E7E7EFD6CEF7E7DEEFD6CEF7E7DEEFD6CE
EFD6CEEFC6ADD6C6C6F7D6C6EFD6CEEFD6CEC6ADA59452399C39298C31297321107B2918422921\
4A10089C3929B55239CE5A4AC66B52D67B6BD68C73D69C84D69C84D69C73D69C84
D6A584DEA58CDEA58CDEAD94E7B594EFBDA5E7B59CEFBDA5EFBDA5E7B59CEFBDA5E7B594DEA58C\
DEA58CDEA58CDEA58CDEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDEAD94DEAD94
DEAD94DEAD94DEB59CD6C6B5EFD6CED6C6D6F7EFEFE7DEEFF7EFEFF7EFEFE7DEEFF7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7E7DEEFE7DEEFF7EFEF\
F7F7F7F7EFEFF7F7F7F7F7F7D6C6D694848463524A5A42395A3129C69C84F7DECE
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7CEB5F7C6ADF7C6ADEFBDA5\
F7CEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BDF7D6BD
E7B59CE7B594E7A58CDE9473CE8C6BD67363CE8C6BA542319C39298C29218429187B29187B3121\
945A52B5735AE7AD9CE7B59CEFCEB5F7E7DEF7E7DEF7D6C6F7DECEF7E7E7F7E7DE
F7D6BDF7E7DEF7E7DEF7E7E7F7EFEFF7E7DEF7D6C6F7D6BDF7E7DEF7EFEFF7EFEFF7EFEFF7E7DE\
F7E7DEF7D6C6F7C6ADE7AD9CF7D6C6F7E7E7F7E7DEF7E7DEF7E7DEEFD6CEEFD6CE
F7D6C6EFBDADD6C6C6F7D6C6D6C6C6F7D6C6EFD6CEC69484A55239AD6B52AD7B6B5221184A1008\
1810104A10089C3929B55239C66B52CE5A4ACE8C73D68C7BD69C84D69C84D69C73
D69C84DEA58CDEA58CDEAD94E7B594E7B59CEFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B594\
DEAD94DEAD94DEAD94D6A58CDEAD94DEAD94D6A58CDEA58CDEA58CDEAD94D6A58C
DEA58CDEAD94DEB59CDEB5A5CEBDB5B59C9CCEBDCED6C6CED6C6D6DED6E7F7EFEFE7DEEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEEFD6CEDEAD9C8C7B635A5239315231298C7363F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7CEB5F7D6BDF7D6BDF7CEB5EFC6ADF7C6ADF7C6ADEFCEB5\
F7CEB5EFC6ADF7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7CEB5F7C6AD
E7A58CDE9473DE9C84DE9473CE8463CE8C6BCE94738C2921A54231A542318C3129842918732110\
A54231D68C73DE7B6BE7A58CF7BDB5E7AD94E79484F7C6ADF7DECEF7DECEF7C6AD
F7C6ADF7D6BDF7E7DEF7E7DEF7E7DEF7D6BDEFB5A5EFBDADF7D6BDF7E7E7F7E7E7F7E7E7F7DECE\
F7D6C6F7C6ADEFB5A5E7AD9CE7AD94EFCEB5EFD6CEF7E7DEEFD6CEEFD6CEEFD6CE
E7BDA5DEA58CEFD6CEF7D6C6F7D6C6D6C6C6F7D6C6D6C6BDDEB5A5DEB59CEFCEB5B58C73844A39\
AD7B6B73524A211010421810A55239BD5A42BD5A42CE735AD68C7BDEA58CD69C73
D6A584DEA58CDEA58CE7B594E7B59CEFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B594\
E7AD94E7B594DEAD94DEAD94DEA58CD6A58CD6A58CDEA58CD6A58CDEA58CDEA58C
DEAD94DEAD94DEAD94E7BDA5D6C6B5B59C9C73524A948484B5A5ADCEBDCED6CEDEE7DEE7EFE7E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFFDED6E78C7B736342314A3131523129C6947BF7D6C6EFCEB5
EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7C6ADEFC6ADF7C6ADF7D6BD\
F7C6ADEFBDA5EFBDA5F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7C6AD
E7A58CCE8463DE9C84D68C73C68C63CE8C6BD68C7BBD5A42BD5A42B55239A542318C2921842918\
AD5A42E78473DE7B6BE79484E7A58CDE9473E79484EFBDA5F7D6BDF7D6BDF7BDB5
EFB5A5F7C6ADF7DECEF7E7DEF7E7DEF7C6ADE7AD94F7BDB5F7D6BDF7D6C6F7E7DEF7DECEF7D6BD\
F7C6ADE7AD94EF948CE7AD9CEFB5A5EFBDA5F7D6BDEFD6CEEFD6CEF7D6C6F7D6C6
E7AD94D69C73EFCEB5D6C6C6F7D6C6F7D6BDEFCEB5EFC6ADD6A58CDEB5A5DEB5A5DEB59CBD9C8C\
D6A58CBD9C8C844A397342319C3929A54231B55239C66B52CE8C73D69C84D69C84
D69C84DE9C84DEA58CDEAD94E7B594EFBDA5EFBDA5EFC6ADEFC6ADEFBDA5E7BDA5EFBDA5E7B59C\
DEAD94DEA58CDEAD94DEAD94DEAD94DEA58CD6A58CDE9C84DEA58CDEA58CDEAD94
DEA58CDEAD94DEAD94DEB59CD6C6B5CEB5ADAD9494CEBDB5CEBDB5CEBDB5D6C6BDDECED6DED6E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7DECED6B59C9C63524A422921523129634231DEB5A5F7D6C6F7BDB5
F7D6BDF7BDB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7C6ADF7C6ADF7C6ADEFBDA5F7CEB5EFCEB5\
F7C6ADEFBDA5F7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFBDA5
DE9473CE8463DE9C84D68C73CE8463D68C73DEA58CDE9C84E7847BDE7B6BCE735AA542319C3929\
B55239D67B6BD67B6BDE9473E7847BDE9473E79484E7A58CE7B59CF7D6BDF7BDB5
E7A58CE7AD94F7D6BDF7D6BDF7D6BDE7AD94E7AD9CF7BDB5F7BDB5EFCEB5EFCEB5F7BDB5E7A58C\
E79484E78473E78473E79484EF948CE7AD9CEFBDA5EFC6ADEFCEB5EFCEB5E7BDA5
DE9473DE7B6BE7B59CF7D6BDF7D6BDEFCEB5EFCEB5DEAD94D6A58CDEB5A5DEB5A5DEAD94BD9C8C\
D6A58CDEAD94AD7B6B9C6B527B31219C3929A54231B55239D67363CE947BD6A584
D69C73DEA58CDEA58CDEA58CE7B59CE7BDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59C\
E7B594DEAD94DEA58CD6A58CDEA58CD6A584DEA58CD6A584D6A58CDEA58CDEA58C
DEA58CDEAD94DEB59CDEB59CDEB5A5D6C6C6D6C6D6DECED6D6C6C6D6C6CED6C6BDCEBDB5CEBDC6\
E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DED6E7CEBDCE948484634231392921312121392921734A42EFCEB5D6C6C6F7BDB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5EFC6ADEFBDA5EFBDA5F7D6BDF7CEB5\
EFBDA5EFBDA5EFBDA5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5EFBDA5
E79484CE7352CE8C6BDE9C84DE9473D6A584E7AD94E7BDA5E7AD9CE7AD9CE7AD94EF948CDE7B6B\
D67363DE6B5ADE7B6BE78473E78473E78473E78473DE9473E79484E7AD9CE79484
E79484E77B6BE7A58CE7AD94E7A58CE78473E7A58CE7AD9CEFB5A5F7BDB5F7BDB5E7AD9CD67363\
DE6B5ADE7B6BDE6B5ADE7B6BE78473E79484E7A58CE7A58CE7AD94E7AD94DE9C84
D67363CE735AE7A58CEFCEB5EFCEB5EFCEB5E7B59CD69C73DEB59CDEB5A5DEB5A5DEAD94D6A58C\
C6ADA5BD9C8CB58C73A5735A8C31297B29188C2921A54231BD5A42CE8C73D68C7B
D69C84DE9C84DEA58CDEA58CE7B59CEFBDA5EFBDA5EFC6ADEFC6ADEFBDA5EFBDA5E7B59CE7B59C\
E7B594DEA58CDEAD94DEA58CD6A58CD6A58CD6A584D69C84DE9C84DEA58CDEA58C
DEA58CDEAD94DEB59CDEB59CDEB5A5D6C6BDDED6E7E7DEE7D6C6D6D6C6CECEBDC6D6C6CED6C6CE\
D6C6D6E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFD6C6D6\
B59C9C735A525A42395242394A3131312118312118A5735AEFCEB5F7D6BDEFCEB5
F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7CEB5EFCEB5F7C6ADF7C6ADEFBDA5F7C6ADF7CEB5EFC6AD\
EFBDA5E7B594F7C6ADF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7CEB5EFBDA5
DE9C84CE7352CE8C6BDEA58CDEA58CE7AD94E7B59CF7BDB5EFCEB5F7BDB5EFCEB5EFBDADEFB5A5\
EFB5A5E7AD9CEF948CE7AD9CE7AD9CEF948CEF948CEF948CE7847BE7847BE78473
E7847BE7847BDE7B6BE7847BE7847BE7847BE7847BE7847BE7847BDE9C84E7847BE7847BDE7B6B\
E7847BDE7B6BDE7B6BD67B6BD67363D67363DE7B6BD68C73E78473DE9473DE7B6B
CE8463D67363CE8C6BE7BDA5EFC6ADE7BDA5DEA58CCE8C6BDEAD94DEB59CEFC6ADDEAD94D6A58C\
DEAD94DEAD94C6947BB57B637342317321107B2918842921A54231C66B52D68C73
D69C73D6A58CDE9C84DEA58CE7B594E7BDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B594\
E7AD94E7B594DEAD94D6A58CD6A584DE9C84D6A584D69C84D6A584DEA58CDEA58C
DEAD94DEAD94DEB59CDEB59CDEB59CD6C6BDE7DEEFE7DEEFE7DEEFE7DEEFCEBDC6CEBDC6D6CEDE\
D6C6D6F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFD6C6D68C7363\
634A42422921392921523129523129422118422921C69484F7DECEF7D6C6EFCEB5
F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7C6ADEFBDA5F7C6ADEFBDA5EFC6ADF7BDB5F7C6AD\
EFBDA5E7AD94EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7BDB5F7C6AD
E7A58CCE735ACE8463DEA58CE7B59CE7BDA5EFB5A5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6BD\
F7D6BDF7D6BDF7D6BDF7BDB5F7BDB5EFBDADEFBDADEFB5A5EFB5A5EFB5A5E7AD9C
E7AD9CEF948CEFB5A5EFB5A5E7AD9CEF948CE7AD9CEF948CEF948CEF948CEF948CE7AD9CDE9C8C\
E7847BDE9C84E7847BDE7B6BDE7B6BDE7B6BD67363DE6B5ACE7352CE735ACE735A
D67363D67363D67363DEA58CDEB59CDEA58CCE8C6BCE735AD68C73DEB59CEFC6ADD6A58CCE8C84\
D6A58CD6A58CB58C73AD7B6B7342316318107321107321108C2921A55239CE8463
D68C7BDE9C84D6A584DEA58CE7B594EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B594\
E7B594DEAD94DEA58CDEA58CDE9C84D6A584D6A584D6A58CD69C84D6A584DEA58C
DEAD94D6A58CDEAD94DEB59CDEB59CEFBDADF7F7F7F7F7F7F7EFEFF7EFEFDECED6D6C6D6D6C6D6\
F7E7DEDED6E7E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C8C8C4A3131\
422921312118421810422921523129422921523129DEB59CF7D6C6EFCEB5F7D6BD
F7D6C6F7D6BDF7D6C6F7D6BDF7CEB5F7CEB5F7C6ADF7C6ADEFBDA5EFC6ADF7BDB5EFC6ADEFBDA5\
E7B59CE7B59CF7CEB5F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7D6BDF7CEB5EFC6AD
E7A58CCE8463CE7352DEA58CE7BDA5EFC6ADEFC6ADF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7BDB5F7BDB5F7BDB5
F7BDB5EFBDADF7BDB5F7BDB5F7BDB5EFB5A5EFB5A5EF948CEFBDADEF948CEF948CEF948CEF948C\
EF948CEF948CEF948CE7847BE7847BE7847BD67B6BD67B6BCE735ACE5A4AC66B52
C66B52C66B52CE735AD68C73D69C84D68C73C66B52C66B52CE8C6BDEAD94DEB5A5D6A584C68C63\
D69C84D69C8CAD735AB57B637342316318105210086318107321108C3129AD5A42
D68C7BD69C84DEA58CDEA58CE7A58CE7B59CEFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5E7B594\
E7B594DEAD94DEA58CDEAD94D6A58CD6A584DE9C84D6A584D6A584D6A584DEA58C
D6A58CDEA58CDEAD94DEB59CDEB59CEFBDADD6C6BDF7E7DEF7F7F7F7F7F7DED6E7E7DEEFF7E7DE\
D6CEDED6C6D6F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7E7DEE7D6C6D6523931422921\
211010312118523129633931523129422918A5735AF7D6C6F7D6C6F7BDB5F7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7C6ADEFC6ADEFCEB5F7BDB5EFC6ADEFC6AD\
EFBDA5EFC6ADF7CEB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7C6ADEFBDA5
E7AD94E79484CE8463CE8463E7AD94EFBDA5EFBDADF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECE\
F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECED6C6C6F7BDB5F7D6BDF7BDB5D6C6C6F7BDB5F7BDB5EFBDAD\
EFBDADEFBDADEFBDADEFB5A5E7AD9CE7AD9CEF948CE7847BE7847BDE7B6BD68C7B
E7847BD67B6BD67B6BD67B6BD67363C66B52C66B52C66B52C66B52CE8C6BD69C73CE8C6BC66B52\
BD5A42B5735AAD5A42A542317342314210105210087321108C3129844A398C3129
A55239D69C73D69C84D69C84E7AD94E7B594EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5E7B59C\
E7B594DEA58CDEA58CDEA58CD6A58CD6A58CD69C73D69C84D69C84D6A584D6A58C
DEA58CDEAD94DEA58CDEAD94DEB59CDEB5A5A5847B7B6352B59C9CD6C6C6DED6E7F7E7DEE7DEE7\
DED6E7DECED6E7DEE7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7E7DEE7C6ADBD422921422921\
4229214229215A31296339295A3121522118AD846BF7D6C6F7D6BDF7D6C6EFCEB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7C6ADEFC6ADEFC6ADF7BDB5EFCEB5F7CEB5EFC6AD\
EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7BDB5EFBDA5EFBDA5
E7A58CE7A58CDE9473CE8463DEA58CE7BDA5EFCEB5F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7D6C6\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7C6ADF7CEB5\
F7CEB5F7C6ADEFBDA5EFC6ADF7BDB5EFC6ADE7AD94E7AD94EF948CE79484E7847B
E7847BD68C7BE7847BE7847BD67B6BCE8C73D67363D67363D67363D67363CE8C73BD8463CE634A\
B55239B55239AD5A42A542317B31216318106318107342298C31298C31298C2921
8C3129D68C7BD69C73D69C73DEA58CE7B594E7B59CEFBDA5EFBDA5EFCEB5EFBDA5E7B59CE7B594\
E7AD94DEAD94DEAD94DEA58CDEA58CD6A584D69C84D69C84D69C73D6A584DEA58C
DEA58CDEAD94DEAD94DEAD94DEB59CEFBDADAD9C8C6B524A947B73D6C6C6DED6E7E7DEEFE7DEEF\
F7F7F7E7DEEFE7DEEFEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6BDB5BD9C8C8C422118312118\
5A31295231295A31294229214221185A3121BD9C8CF7D6C6F7D6BDEFCEB5F7D6BD
F7D6BDF7D6C6F7BDB5F7D6BDF7CEB5F7CEB5EFCEB5EFC6ADF7BDB5F7BDB5EFCEB5F7BDB5EFCEB5\
F7BDB5EFCEB5F7CEB5F7D6BDF7D6BDF7BDB5F7D6BDF7BDB5EFCEB5EFC6ADEFBDA5
E7AD94E7A58CDE9C84CE8C6BCE8C6BE7B594EFBDADF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDEFC6ADF7CEB5EFC6ADEFBDA5\
F7C6ADEFBDA5F7C6ADEFBDA5F7C6ADEFC6ADEFBDA5E7B594E7B59CE7B59CE7AD94
E7AD94EF948CDE9C8CDE9C84DE9C84E7847BD68C7BD68C7BE7847BD68C73D67B6BD67B6BD67363\
D67363C66B52C66B52BD5A42AD5A429C39299452399C3929A55239B55239AD5A42
A54231CE8C6BD68C7BD6A584DEA58CE7B594EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5E7B594\
E7B594DEAD94DEAD94DEA58CD6A58CD6A584D69C73D69C84D69C84D69C84D6A58C
DEA58CDEAD94DEA58CDEAD94DEAD94DEB5A5BDA59C7B6352734A39947B73F7E7DEF7F7F7F7EFEF\
F7F7F7EFE7E7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E79C8C8C8C7B73312118422921\
633929634231633931422921422118634231EFBDADF7D6C6EFCEB5F7D6BDF7BDB5
F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5F7CEB5EFC6ADF7BDB5EFCEB5F7D6BDEFCEB5F7D6BDEFCEB5\
F7D6BDF7BDB5F7BDB5F7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7BDB5EFBDAD
E7AD94E7A58CE79484DE9473CE8463DE9C84E7B59CF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7C6ADEFC6ADF7C6ADEFBDA5\
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7AD94
E7AD9CE7AD94E7AD94E7A58CDE9C8CDE9C8CDE9C84DE9C84DE9C84DE9C84DE9C84D68C7BD68C7B\
D68C7BCE8C84D68C7BD68C7BE78473D68C73D67363CE8463D67363C66B52B5735A
C66B52C68C63CE947BD69C84DEA58CE7B594EFBDA5E7B594EFBDA5EFC6ADEFBDA5E7B59CEFBDA5\
E7B594DEA58CDEA58CD6A58CDE9C84D6A584D69C84D69C73D69C73D69C73DEA58C
DEA58CD6A58CDEAD94DEAD94DEAD94DEB5A5C6ADA573524A73524A734A429C8C8CF7E7DEFFFFFF\
EFE7E7F7F7F7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE77B635A5A42395A42399C6B52\
AD847BD69C8CC68C73B5735A7342318C5A4AEFCEB5F7D6C6F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDF7CEB5F7BDB5EFCEB5F7BDB5F7D6BDF7BDB5F7D6BDEFCEB5F7D6BD\
F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDEFCEB5F7C6ADEFCEB5EFBDA5
E7AD94E7A58CE7A58CDE9C84DE9473DE9473E7B59CEFC6ADEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6\
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7C6ADEFC6ADEFBDA5\
EFBDA5EFBDA5EFBDA5E7B59CEFBDA5EFBDA5E7B59CEFBDA5EFBDA5E7B59CE7B594
E7AD94DEAD94E7A58CDEAD94DEA58CDEA58CDE9C84DE9C84D69C84DE9C84DE9C84DE9C84DE9C84\
D69C84DE9C8CDE9C84D69C84CE8C84D68C7BD68C73D68C73D67B6BCE8C6BD67B6B
CE8463BD8463CE8C6BD69C73DE9C84E7B594E7BDA5E7B594EFBDA5EFC6ADEFBDA5E7B59CE7B59C\
E7B594DEA58CDEA58CD6A58CD6A58CDEA58CD6A584D6A584D69C84D69C73D6A584
DE9C84DEAD94DEAD94D6A58CDEAD94DEB5A5C6ADAD8C7B738C7B73A5847B846352B59C9CF7F7F7\
F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E77B635A523129DEB59CF7BDB5\
F7D6BDF7D6BDEFBDA5E7B59CDE9473B58C73F7D6C6F7D6C6D6C6C6F7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7CEB5EFCEB5F7CEB5F7D6BDEFCEB5F7BDB5F7D6BDF7D6BDF7CEB5F7CEB5\
F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7BDB5EFCEB5F7C6ADF7C6AD
E7B59CE7AD94E7A58CE7A58CDE9473CE8C6BDE9C84EFBDADEFC6ADF7D6BDF7D6C6F7D6BDF7D6C6\
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7C6ADEFBDA5EFBDA5\
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59C
E7AD94E7AD94DEA58CDEA58CD69C84D6A584DEA58CDE9C84DEA58CD69C84D69C84D69C84DE9C84\
D69C84D6A584D69C84D69C84D69C84DE9C84D69C84D69C84D68C7BCE947BCE9473
CE947BCE8C73CE9473D69C73D69C73E7B594EFBDA5E7B594EFBDA5EFBDA5EFBDA5EFBDA5E7B59C\
E7B594DEA58CDEA58CD6A584D6A584DE9C84D69C84D69C84D6A584D69C84DE9C84
DEA58CDEA58CDEA58CDEAD94D6A58CDEB59CCEB5AD948484948484AD9494B59C9CAD9494CEBDCE\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7735A52846352F7D6C6F7D6BD\
F7D6BDEFCEB5F7BDB5EFBDA5E7B59CEFBDA5F7D6C6EFCEB5EFCEB5EFCEB5F7D6C6
F7D6BDF7BDB5F7D6BDEFCEB5F7CEB5F7BDB5EFCEB5F7BDB5F7D6BDF7BDB5F7D6BDEFC6ADF7BDB5\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7BDB5F7D6BDF7D6BDEFCEB5EFC6AD
E7B59CE7AD94E7A58CE7A58CDE9C84DE9473DE9473E7BDA5EFC6ADF7BDB5EFCEB5F7D6C6F7D6C6\
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7BDB5F7CEB5EFBDA5EFBDA5EFBDA5\
EFBDA5E7B594E7B59CEFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B59CE7AD94
E7AD94DEAD94DEA58CDE9C84D6A584DEA58CD6A58CDE9C84D69C84D69C73D6A584D69C8CD6A584\
D69C84D69C84D69C84D69C84D69C84D6A584D6A584D69C84D69C73D69C84D69C73
CE8C84D69C73D69C84D6A584D69C73E7A58CE7BDA5E7B594E7B59CEFC6ADEFBDA5EFBDA5E7B594\
DEA58CDEA58CDEA58CDEA58CD6A584D6A584D69C84D6A584D69C84D69C73D6A584
DEA58CDEA58CDEAD94D6A58CDEAD94DEAD94C6ADA5735A527B635AB5A5ADCEBDC6D6C6BDD6C6BD\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7C6ADBD846B5ADEB59CF7D6BDF7D6BD\
F7D6BDF7D6BDF7D6BDF7BDB5EFBDADD6C6B5F7D6C6F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDEFCEB5F7BDB5F7BDB5F7BDB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7BDB5F7D6BD\
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7BDB5EFCEB5
EFB5A5E7B594E7A58CE7A58CE79484DE9C84DE9473E7B594EFC6ADEFCEB5F7D6BDF7D6C6F7D6C6\
F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5F7C6ADEFBDA5E7B594\
EFBDA5E7B594EFB5A5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B594DEA58C
DEA58CDEA58CDEA58CD6A58CD6A584D69C84D69C73C69C84D69C84D69C73CE947BD69C73D69C73\
CE947BD6A584D6A584D69C73D69C73D69C84D69C84D69C84D69C84D6A584D69C84
D69C73D6A584D6A584D69C84D68C73E7B594E7B59CDE9C84EFBDA5EFBDA5EFBDA5E7B59CE7B594\
E7AD94DEA58CD6A584D6A584D6A584D69C8CD6A584D69C84D69C84D69C84DEA58C
DEA58CD6A58CDEA58CDE9C84DEAD94DEB59CC6ADA5735A52735A52AD9494D6C6BDD6C6D6DECED6\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7BDA59CF7BDB5EFCEB5F7D6BDF7D6C6\
F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5F7D6C6D6C6C6EFCEB5EFCEB5F7D6BD
EFCEB5F7D6BDF7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6BD\
F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7C6AD
EFBDA5E7B59CE7B59CE7AD94E7A58CE7A58CDE9C84DE9C84E7B594EFBDA5EFCEB5F7D6BDF7D6BD\
F7D6BDF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6BDF7CEB5F7CEB5EFBDA5EFBDA5EFBDA5\
E7B594E7B594E7B594E7B59CEFBDA5EFBDA5E7B59CE7B594E7B594E7B594E7B594
E7AD94DEA58CDEA58CD69C84D6A584D69C73D69C84CE947BCE947BCE947BCE8C6BCE9473CE947B\
CE9473CE9473CE9473CE947BD69C73CE947BD69C73D68C7BD69C84D69C84D69C84
D69C73D69C73D6A584D69C73DE9C84E7B594E7B594DE9473EFBDA5EFBDA5E7B59CE7B59CDEAD94\
E7B594DE9C84DEA58CD69C84D69C84D69C84D69C84D69C73D69C84D6A584DEA58C
DEA58CDEA58CD6A58CD6A58CD6A58CD6A58CCEB5AD5239313121218C736BCEBDB5E7DEE7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFEFE7E7D6C6CEEFCEB5F7D6BDF7BDB5F7D6BDF7D6C6\
F7D6C6F7D6BDF7D6C6F7DECEF7D6BDEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7BDB5EFCEB5
F7C6ADEFBDA5EFB5A5E7AD94E7A58CE7A58CE7A58CDE9473E7A58CE7B59CEFBDA5EFCEB5F7D6BD\
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5F7C6ADEFC6ADE7B59C\
E7B59CE7B594E7A58CE7B594E7B59CE7B594E7B594E7B594E7A58CDEA58CDEA58C
DEA58CD6A584D69C84D69C84D69C84D69C84CE947BCE947BCE947BCE947BCE9473CE9473CE9473\
CE9473CE8C73CE9473CE9473CE9473D68C73CE9473D69C73D69C73D69C73D69C84
D68C7BD69C84CE947BD69C73E7B594E7B594DE9C84CE8C6BE7B594E7B59CE7B594E7B594E7B594\
DEAD94DEA58CDEA58CD6A584D69C73D69C84D69C73D69C84D69C84D6A584D6A58C
DEA58CDEA58CD6A58CDEA58CD6A58CDEB59CBDA59C5231295231297B635A9C8C8CD6C6CEF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7D6C6B5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6\
F7D6C6F7D6BDF7D6BDF7DECEEFCEB5EFCEB5F7D6C6EFCEB5D6C6C6F7D6BDF7BDB5
EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7BDB5F7CEB5
EFC6ADEFBDADEFBDA5E7B59CE7AD94E7A58CE7A58CE7A58CDE9C84E7A58CEFBDA5EFC6ADEFCEB5\
F7D6BDF7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BD
F7D6C6F7D6BDF7D6BDF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7BDB5EFCEB5EFCEB5EFBDA5\
E7AD94E7A58CDE9C84E7A58CDEA58CE7AD94DEAD94E7B594DEA58CDEA58CDEA58C
D6A584DE9C84D69C84D69C73C69C84D68C73CE947BCE9473CE9473CE8C73CE947BCE8C73CE8C73\
CE9473CE9473CE8C73CE9473CE8C73CE9473CE9473CE8C73CE9473CE9473D68C73
CE9473D69C73D68C7BDE9C84DEAD94DE9C84D69C73E7A58CE7B59CE7B59CE7B594E7AD94E7AD94\
DEA58CDE9C84D6A584D69C84D69C84D69C84D69C73D69C84D6A584D6A584DE9C84
D6A584D6A58CDEAD94DEA58CD6A58CD6A58CBDA59C5239315239317B635A948484D6C6BDE7DEEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7D6C6B5EFCEB5F7D6BDF7D6C6F7D6BDF7D6BD\
F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5F7D6C6F7BDB5F7D6BDF7D6C6F7D6BD
F7D6BDF7CEB5F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7BDB5
F7C6ADF7C6ADE7B59CE7B59CE7B59CE7B594E7A58CDE9C84DE9C84E7B594E7B59CEFBDA5EFC6AD\
EFCEB5F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFC6ADEFB5A5E7B59C\
E7AD9CDEAD94E7AD94DEAD94DEAD94DEA58CDEA58CDE9C84DE9C84D6A584DE9C84
D69C84D69C73D69C84CE947BD68C7BCE947BCE8C73CE9473CE8C73CE9473CE9473CE9473CE947B\
CE947BCE8C73CE9473CE9473CE9473CE947BCE8C73CE9473CE8C73CE9473CE8C6B
CE9473CE9473D69C73DE9C84DE9C84DE9C84DE9C84DEAD94E7AD94E7B594E7AD94E7B594DEA58C\
D6A584D6A584D6A58CD69C73D69C84D69C84D69C84D69C73D69C84D69C84D6A584
DEA58CDEA58CD6A58CDEAD94D69C8CDEB59CC6ADA54A31315231295A5252AD9494C6ADADE7DEE7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6F7BDB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6BD\
F7D6BDF7D6BDF7CEB5F7C6ADE7BDA5EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7BDB5F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7BDB5EFC6ADEFBDA5EFBDA5E7B59CE7A58CE7A58CE7A58CDE9473DE9C84E7B594EFBDA5EFBDA5\
F7BDB5F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6D6C6C6EFCEB5EFCEB5EFBDADE7B59CE7AD94\
DEAD94E7AD9CE7AD9CE7AD9CE7B59CDEAD94DE9C84DE9C84DE9C84DE9C84D69C84
D69C73D69C84D69C73D68C7BCE9473CE8C73CE947BCE8C73CE8C73CE947BCE9473CE8C73CE9473\
CE8C73CE947BCE947BCE947BD68C73CE9473CE9473CE9473CE9473CE8C6BC68C73
CE9473CE8C6BD6A584DE9C84DE9C84DE9C84E7AD94E7AD94DEAD94E7B594DEA58CE7AD94DEA58C\
DEA58CDE9C84D69C73D69C84D6A584D69C84D69C73D69C84D6A584D69C84D6A584
D6A58CD6A58CDEA58CD6A58CD6A58CD6A58CBDA59C422921312118392921634A425A5252948484\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7CEB5F7CEB5\
F7CEB5F7CEB5EFBDA5E7B59CE7B59CEFCEB5F7D6C6F7D6BDF7D6BDEFCEB5F7D6BD
EFCEB5F7D6BDF7BDB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7BDB5
F7CEB5EFC6ADF7C6ADEFBDA5EFBDA5E7B594E7A58CDE9473E7A58CDE9C84E7A58CE7B594EFBDA5\
EFCEB5F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6BDF7D6BDF7CEB5F7D6BDEFCEB5F7D6BDF7BDB5F7D6BDF7BDB5EFCEB5EFBDADEFBDA5E7AD9C\
E7AD94DEB59CDEAD94DEB59CE7AD9CE7AD9CD68C7BD69C73DE9C84DE9C84D69C73
D69C84D68C7BD69C73CE9473CE8C73CE8C73CE9473CE947BCE8C73CE9473CE9473CE9473CE9473\
CE8C73CE947BD69C73CE947BCE9473CE9473CE9473CE9473CE9473CE8C73CE8C6B
CE9473D69C73DE9C84DE9C84DEA58CE7A58CE7AD94E7B594E7AD94E7AD94DEA58CDEAD94DEA58C\
DEA58CDEA58CD69C84D69C84D69C84D6A584D69C84D69C84D69C84D6A584DE9C84
DE9C84DE9C84D6A58CD6A58CDEAD94DEB59CB59C9C422918312121392921523129634A42AD9494\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6C6C6F7CEB5F7CEB5F7D6BDF7D6C6F7D6C6F7BDB5EFC6AD\
F7C6ADF7C6ADE7B594E7B594E7B59CF7D6BDEFCEB5D6C6C6F7D6BDF7D6BDF7BDB5
F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECE\
F7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDF7D6BD
F7BDB5F7C6ADEFC6ADEFBDA5EFBDA5E7B59CE7AD94E7A58CE7A58CDE9C84E7A58CE7B594EFBDA5\
EFCEB5F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BD
F7BDB5EFC6ADF7C6ADF7BDB5EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7C6ADEFBDADE7B59C\
E7AD9CE7AD94DEB59CE7AD94DE9C8CDEAD94D69C84D68C73D68C7BD6A584D69C84
D6A58CD69C84D69C84CE9473CE8C73CE8C73CE8C73CE9473CE9473CE947BCE947BCE9473CE947B\
CE947BD69C73CE947BD69C73CE947BCE9473CE9473CE9473CE9473CE9473CE8C73
CE8C6BDE9C84DE9C84E7A58CE7AD94E7AD94E7B594E7B59CE7AD94DEA58CE7A58CDEA58CDEA58C\
DEA58CD6A58CD6A584D69C84D6A584D69C84D6A584D69C84DE9C8CD6A584DE9C84
D6A58CD6A58CD6A58CDEAD94DEAD94D6A58CBD9C8C4229213121213929214229315A4239CEBDB5\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7DECEF7D6BDF7D6BD\
EFBDA5E7AD94E7B59CDEAD94EFBDADEFCEB5F7D6BDD6C6C6F7BDB5F7D6BDEFCEB5
F7BDB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DE\
F7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6BDF7CEB5F7BDB5F7C6ADEFBDA5E7B59CE7B59CE7A58CE7A58CDE9473E7A58CDE9C84E7A58C\
EFB5A5F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7BDB5EFCEB5
F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7BDB5F7C6ADEFC6ADEFBDAD\
E7B59CEFBDA5E7AD9CDEB59CE7AD94DEB59CDEAD94D69C8CCE947BCE8C73CE8C73
D68C7BCE947BCE9473CE8C6BBD846BCE8C6BCE8C73CE9473D68C7BCE947BCE947BD68C7BCE9473\
CE947BD69C84D69C73D69C73D69C73CE947BD68C73CE9473CE9473D68C73D69C73
DE9C84E7AD94E7AD94E7B59CE7AD9CE7B594E7B59CE7AD94E7A58CDEAD94E7AD94DEA58CDEA58C\
DEA58CDEA58CDEA58CD69C84D69C73D6A584D69C84D69C84DEA58CD69C84D6A58C
D6A58CD69C84DEA58CD6A58CDEAD94DEB59CAD9C8C524239634A42634A425A52529C8CA5D6C6D6\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFE7E7F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7DECEF7D6C6EFCEB5\
EFBDA5E7A58CE7B594DEAD94E7BDA5F7D6BDF7BDB5EFCEB5F7D6BDF7D6BDF7BDB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BD
EFCEB5F7BDB5EFC6ADEFCEB5EFBDA5EFBDA5E7B594E7A58CE7A58CE7A58CDE9C84E7A58CE7A58C\
E7B594EFCEB5F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6EFCEB5F7D6BDEFBDADEFC6AD\
EFBDA5EFBDA5E7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94D69C84CE8C6B
BD846BCE8C73CE8C73CE8C6BCE8C6BCE8C6BCE8C73CE947BCE947BCE9473CE9473CE947BCE947B\
CE9473D69C73C69C84D68C7BCE9473D69C73CE947BCE9473D68C73D69C73DE9C84
DEA58CE7B59CE7B59CE7B59CE7B594E7AD9CE7B594E7AD94DEA58CE7AD94DEA58CDEA58CDEA58C\
DEA58CDEA58CD6A584D69C84D69C84D69C84D69C84D69C84D6A58CD69C73D6A584
DE9C84D6A584D6A58CD69C8CD6A58CC6ADA5A584845231294A3131634A427B737BF7E7DEF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7EFE7E7F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7D6BDEFBDA5\
E7AD94E7B59CE7AD94DEA58CE7BDA5EFCEB5F7D6BDF7D6BDF7D6BDF7BDB5EFCEB5
F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7BDB5EFCEB5F7C6ADEFBDADEFBDA5EFBDA5E7AD9CE7A58CE7A58CE7A58CDE9C84E7A58C\
E7B594F7BDB5F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7BDB5F7D6BDEFC6AD\
EFBDADEFBDA5E7BDA5E7AD9CE7AD94DEAD94DE9C8CD6A58CDEA58CDEAD94D69C8C
CE947BC68C63C68C63CE8C6BBD846BC68C63CE8C6BCE8C73CE8C73CE8C73CE947BCE9473CE9473\
D68C7BCE947BCE947BD69C73D68C7BCE947BD69C73D69C84DE9C84DEA58CE7A58C
E7AD94E7B59CE7B59CE7B59CE7AD9CE7B59CE7B59CE7AD94E7AD94DEAD94DEAD94DEA58CDEA58C\
DEA58CDEA58CDE9C84D69C84D69C84D69C84D6A584D6A58CD69C84D69C84D6A58C
D6A58CD69C84D6A58CD6A58CD6A58CDEB59C947B73422921523129634A428C736BB59C9CB5A5AD\
DED6E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7DECEF7D6BDF7BDB5F7D6BDF7BDB5F7D6C6F7DECEF7DECEEFC6ADE7B59C\
E7B594E7B59CE7A58CDEAD94EFBDADF7BDB5D6C6C6EFCEB5EFCEB5F7D6BDF7D6BD
F7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BD
F7D6BDEFCEB5F7CEB5EFBDADF7C6ADEFC6ADEFBDA5E7B594E7B594E7A58CE7A58CE7A58CE7A58C\
E7A58CEFC6ADF7BDB5F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFBDAD\
EFC6ADEFBDADEFBDA5E7B59CE7AD9CDEB59CDEAD94DEA58CDEA58CDEA58CDEAD94
DEA58CD69C8CCE947BC68C63CE8C73CE8C73BD846BCE8C6BCE8C73CE947BCE9473CE9473CE947B\
CE947BD69C73CE947BD69C84CE947BD68C7BD69C73DE9C84DE9C84DEAD94E7AD94
E7AD94E7B59CE7BDA5E7B594E7B59CE7B59CE7B59CE7B59CDEA58CE7AD94E7AD94DEA58CDEA58C\
DEA58CDEA58CD69C84DEA58CD69C84D6A584DE9C84D69C84D6A58CD69C84DE9C8C
D6A584D6A58CD6A58CD69C8CD6A58CDEB59CAD846B523129422921523129523931523931634A42\
C6ADADE7DEEFE7DEEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7D6BDF7D6BDF7D6BDF7BDB5F7D6BDF7D6C6F7DECEF7D6C6EFBDA5E7B59C\
E7A58CE7B59CDEAD94E7B59CEFC6ADEFCEB5EFCEB5F7D6C6F7BDB5F7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6BDF7BDB5EFBDADEFCEB5F7C6ADEFBDADEFB5A5E7B59CE7AD94E7A58CE7A58CE7A58C\
E7A58CEFBDA5EFC6ADEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7BDB5\
EFBDADEFC6ADEFB5A5E7B59CE7B59CE7AD9CDEAD94DEAD94D6A58CDEAD94D6A58C
DEA58CDEA58CDEAD94D69C84D69C73D6A584CE947BC68C73CE8C6BCE9473CE8C73CE8C73CE947B\
CE9473D68C7BD69C73CE947BD69C73D69C73DE9C84DE9C84E7AD94E7AD94E7B59C
E7B59CE7B59CEFBDA5EFBDA5E7B59CE7B59CE7AD94E7B594E7AD94DEAD94DEA58CDEA58CDEA58C\
DEA58CDE9C84D6A584DEA58CDE9C84D69C84D6A584DEA58CD69C84D69C84D6A584
DE9C84D69C8CDEAD94D6A58CDEAD94C6ADA58C73635A31295A3129523129422921523129523129\
7B635AB59C9CD6C6CEE7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7E7DEEFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7DECEEFCEB5E7B594DE9C84\
DE9C84E7B594DEA58CE7BDA5EFC6ADEFCEB5EFCEB5F7BDB5EFCEB5F7D6BDF7BDB5
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7BDB5EFCEB5F7D6BDF7BDB5EFC6ADF7C6ADEFBDA5EFBDA5EFB5A5E7AD94E7A58CE7A58C\
E7A58CE7B59CEFBDA5F7BDB5F7D6BDF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7E7DEF7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5\
EFBDADEFBDA5EFBDA5E7B59CE7AD9CE7AD9CE7AD94DEAD94DEAD94DEA58CD6A58C
DEA58CD6A58CDEA58CDEA58CD6A58CDEA58CDE9C84D69C73BD846BBD846BC68C73C68C73CE8C6B\
CE9473CE9473CE947BD68C7BD69C73DEA58CDEA58CDEA58CE7AD94E7B59CE7B59C
E7B59CEFBDA5E7B59CE7B594E7B59CE7B59CE7B59CE7B59CE7AD94DEA58CE7A58CDEA58CDEA58C\
DEA58CDE9C84DEA58CDEA58CD6A584D69C84DE9C84D69C84D6A584DE9C84D69C84
D6A584D69C84D6A58CDEAD94DEB59CDEB5A5B58C73845242734A39734A395A3129422921312118\
5A42398C736BAD9494DECED6F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7D6BDF7CEB5F7BDB5F7D6BDF7BDB5F7D6BDF7D6C6F7D6C6E7B59CE7A58CCE8C6B\
E7A58CDE9C84DEA58CE7BDA5D6C6B5EFCEB5F7BDB5EFCEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECE
F7D6BDF7D6BDF7BDB5EFCEB5EFBDADEFC6ADEFBDADEFBDADE7B59CE7B59CE7AD94E7AD94E7A58C\
E7AD94E7B59CEFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7D6C6F7D6BDF7D6BDEFC6AD\
EFBDA5EFBDA5EFBDA5E7AD9CE7B59CE7AD9CDEAD94DEAD94DEA58CDEAD94DEAD94
DEAD94D69C8CDEA58CDEA58CDEA58CDEA58CDE9C84D69C84C68C73CE8C6BCE8C6BCE8C6BC68C73\
CE9473CE9473CE9473D69C73DE9C84E7A58CE7A58CE7AD94E7AD9CE7B594E7B59C
EFB5A5E7B59CEFBDA5EFBDA5E7B59CE7B59CE7B59CE7AD94E7AD94DEAD94DEA58CDEA58CE7AD94\
DE9C8CDEA58CDE9C84DEA58CDE9C8CD6A584DE9C8CD6A584D69C84D6A58CD69C84
DE9C84DEA58CDEAD94D69C8CD6A58CDEB5A5C69C84CE8C6BB57B6394634A94634A734A39523129\
5239317B635A8C7B73B59C9CDECED6F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7DECEEFCEB5F7CEB5F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5E7B594EFC6ADDE9C84CE8C6B\
D68C73D69C8CE7B59CEFCEB5F7BDB5EFCEB5EFCEB5F7BDB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DE\
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BD
F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7BDB5F7C6ADE7B59CE7B59CE7B59CEFBDA5E7B594\
E7B59CEFBDADF7BDB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7CEB5EFCEB5
F7D6BDF7D6BDF7D6C6F7D6BDF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFC6AD\
E7B59CE7AD94E7AD94DEA58CDEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58C
D6A58CDEA58CD69C84D6A58CD69C84DE9C84DE9C8CD6A584D69C73CE8C6BBD846BBD846BCE8C73\
CE9473D68C7BD69C73D69C84DE9C84DEAD94DEAD94E7AD9CE7B59CE7B59CE7B59C
EFBDA5E7B59CEFBDA5E7B59CE7B59CE7BDA5E7BDA5E7B59CDEB59CE7AD94DEAD94E7A58CDEAD94\
DEAD94DEA58CDE9C8CD6A58CDEA58CDEA58CD69C84D6A58CD6A58CDE9C84D6A58C
D6A58CDEA58CD6A58CD6A58CDEB59CE7BDA5D69C73CE8C6BC68C63AD6B52A5634A845239844A39\
5239315A42395A4239634A42735A52AD9494E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFEFCEB5F7BDB5EFCEB5F7D6BDF7D6BDF7D6BDF7BDB5EFBDA5E7B59CEFBDA5D69C84DE9473\
D68C7BDEA58CE7B59CEFBDADD6C6B5F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7BDB5F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5EFBDADE7B59CEFB5A5EFBDA5E7B59CEFBDA5\
EFBDA5EFBDA5F7D6BDF7BDB5F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7BDB5EFC6AD
F7BDB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFC6ADEFC6ADEFBDA5\
E7AD94E7AD94DEA58CDEA58CDEA58CDE9C8CD69C8CDEA58CDEA58CD69C8CD6A58C
D69C8CD6A584D69C8CD69C8CD6A584D6A584D69C73D69C84D68C7BBD846BBD8463BD8463CE8C6B\
CE947BD68C7BD6A584DE9C8CDEAD94E7AD94E7AD94E7B59CE7B59CE7B59CEFBDA5
E7B59CEFB5A5E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7AD9CE7AD94E7AD94DEAD94DE9C8C\
E7AD94DEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CDE9C84D6A58CDE9C84
D6A58CDEA58CD6A58CDEB59CD6A58CC6ADA5D69C84D68C73CE8C73CE8C6BB5735AB5735AA5634A\
633931634231634A42634A427B635AAD9CA5E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7E7EFCEB5F7C6ADF7BDB5F7D6BDF7CEB5F7C6ADE7B59CE7B594EFBDA5DEA58CDE9473DE9C84\
D69C73DEB59CE7BDA5EFCEB5F7BDB5F7BDB5D6C6C6F7D6BDF7D6C6F7D6BDF7D6C6
F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7BDB5EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5\
EFBDA5E7B59CF7D6BDF7D6C6F7DECEF7D6C6F7D6BDF7D6C6EFCEB5EFCEB5F7C6AD
EFC6ADF7BDB5F7D6BDF7D6BDF7D6C6EFCEB5F7D6C6F7D6BDEFCEB5F7D6BDF7BDB5EFBDADEFBDA5\
E7AD94DEAD94DE9C8CDEA58CDE9C84D69C8CD69C8CD69C8CD6A584D69C84D69C84
D6A58CD69C84D69C84D6A584D69C84D69C84D69C84D69C73CE9473BD846BBD8463D67363CE8C6B\
CE9473D69C73DE9C84DEA58CE7AD94E7AD9CE7B59CE7B59CE7B59CE7B59CE7B59C
EFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7B59CDEAD94E7AD9CDEAD94DEAD94E7AD94\
DE9C8CDEAD94DEA58CDEA58CDE9C84DEA58CDE9C84D6A584D6A58CD69C84D6A58C
DEA58CD6A584DEA58CD6A58CDEB59CDEB5A5D69C84D68C7BD69C73CE947BCE8C73CE8C6BBD846B\
9C6B52634A42735A528C7B73C6ADBDE7DEE7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7DEEFC6ADF7C6ADF7CEB5F7C6ADE7B594E7B594E7A58CE79484DE9473DE9473D68C73D69C73\
DEA58CDEB59CEFC6ADF7BDB5EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6C6F7D6BD
F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDEFCEB5F7BDB5F7BDB5EFCEB5EFCEB5F7C6ADEFBDA5EFBDA5EFBDADF7C6AD\
EFBDADEFBDA5EFC6ADF7D6BDF7DECEF7D6C6F7D6C6F7D6BDF7BDB5F7C6ADEFBDAD
EFBDADEFCEB5F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7BDB5EFC6ADEFCEB5EFBDA5E7BDA5\
E7AD9CDEAD94DEA58CD6A58CDEA58CD6A58CD69C73D69C84D69C84D69C84D6A58C
D69C84C69C84D69C84CE947BD69C84D69C84D69C73CE9473CE8C6BBD846BBD8463C68C63CE8C6B\
D68C7BD69C84DE9C8CDEAD94E7AD94E7B59CE7B59CE7B59CE7B594E7B59CEFBDA5
E7B59CE7B59CE7B59CE7B59CE7B59CEFB5A5E7B59CE7B59CE7AD94E7AD94E7AD94DEAD94DEAD94\
DEAD94DEAD94DE9C84DEA58CD6A58CD6A58CD6A58CDEA58CDEA58CD69C84DE9C84
D6A58CD6A58CD69C8CDEB59CDEB59CC6ADA5D69C73D69C84D69C84D69C73CE947BD69C73CE947B\
CE8C7394736B947B73D6C6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7D6C6EFBDA5F7CEB5F7C6ADE7A58CDE9473DE9473CE8463D67363D67B6BD67B6BD68C73D69C84\
DEAD94E7B59CEFBDA5D6C6B5F7BDB5F7D6BDF7BDB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7BDB5F7BDB5EFC6ADEFBDA5EFBDADF7C6ADEFCEB5\
EFBDADF7C6ADEFBDADF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFC6ADF7C6AD
EFBDADF7D6BDEFCEB5F7D6BDF7D6BDF7BDB5F7D6BDEFCEB5F7BDB5EFC6ADEFBDA5EFBDA5E7B594\
E7AD9CE7AD94DEA58CDE9C84D69C84D69C84D69C84D69C84C69C84CE947BCE947B
CE947BCE947BCE947BCE947BD69C73CE947BCE9473CE8C6BBD846BBD846BC68C63CE8C6BCE8C73\
D69C73DE9C8CDEA58CDEAD94E7B59CE7B59CE7B59CE7B59CEFBDA5E7B59CE7B59C
EFBDA5E7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CDEAD94DEAD94E7AD94E7AD94DEA58C\
E7AD94DEA58CD69C8CDEA58CDEA58CDE9C84D69C8CD6A584DE9C8CD6A58CD6A58C
DE9C84D69C84DEB59CD6A58CDEB59CDEB5A5D69C84D69C84D69C84D68C7BD69C84D68C7BD69C84\
CE947BBD9C8CCEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
EFCEB5F7C6ADF7BDB5F7C6ADE7A58CDE9473DE9473DE6B5ACE8C6BCE8C6BCE8C6BCE8C73D69C84\
DEAD94DEB59CEFBDADF7BDB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEDECED6\
F7DECEF7DECEDECED6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6C6
F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDEFCEB5EFC6ADF7C6ADEFBDADEFBDA5EFC6ADEFC6ADF7BDB5\
EFCEB5EFCEB5F7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7BDB5EFCEB5
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFC6ADEFBDADEFC6ADEFBDADE7B59CE7AD9C\
E7AD94DEAD94DEA58CD6A58CD69C84D69C84CE947BCE947BCE8C84CE947BC68C73
C68C73C68C73CE9473CE947BCE947BCE9473C68C73CE8C6BBD846BBD846BCE8C6BCE8C73D69C73\
D69C8CDEA58CDEA58CE7AD94E7AD9CE7B59CEFBDA5E7B59CE7B59CEFBDA5EFBDA5
E7B59CE7B59CE7BDA5E7B59CE7BDA5E7B59CE7AD9CE7B59CE7AD94E7AD94DEB59CDEAD94E7AD94\
DEAD94DEAD94DEA58CDEA58CDE9C84D69C84DEA58CDE9C84D6A58CDE9C8CD69C8C
D6A58CD6A58CD69C8CD6A58CDEB5A5DEB5A5D69C73D69C73D69C73CE947BD69C73D69C73CE8C84\
D69C84DEB59CE7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CE
F7BDB5F7CEB5F7CEB5EFBDA5E79484DE9473E77B6BD67B6BD67B6BD68C73CE8C6BCE947BDEA58C\
DEAD94E7AD9CEFBDADEFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDF7BDB5F7BDB5F7CEB5EFCEB5F7BDB5F7C6ADEFC6ADEFBDADF7C6ADEFC6ADF7BDB5EFCEB5\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5F7BDB5EFC6ADEFC6ADEFBDA5E7BDA5E7B59C\
DEAD94DEAD94DE9C8CD69C84D69C8CC69C84C6947BC68C73C69C84CE947BC68C73
CE9473C68C73C68C73CE947BCE9473CE9473CE8C6BBD846BCE8C6BBD846BCE8C6BCE947BD68C7B\
DE9C84DEA58CDEAD94DEAD94E7B59CE7B59CEFBDA5EFBDA5EFBDA5EFBDA5E7BDA5
E7B59CE7B59CEFB5A5EFB5A5E7B59CE7B59CE7B59CE7B594E7B594DEB59CE7AD94E7A58CDEA58C\
DEAD94DEA58CDEA58CDE9C84DEA58CD6A58CDE9C8CD6A58CD69C84D6A584DEA58C
D6A58CDEA58CDEAD94DEB59CDEB5A5C6ADA5CE9473D68C73CE9473D68C7BD69C73D68C7BD69C73\
D69C84C6ADA5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECE
EFCEB5F7CEB5F7BDB5EFBDA5E7A58CE79484D68C7BD68C73CE8C6BD68C73BD846BD68C73D6A58C\
DEA58CE7BDA5EFC6ADEFCEB5EFCEB5F7D6C6F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6
F7D6BDEFBDADEFCEB5F7BDB5F7C6ADEFCEB5EFCEB5F7C6ADEFBDADEFCEB5F7BDB5EFCEB5F7D6BD\
EFCEB5F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFC6ADEFBDADEFBDA5EFBDA5E7AD94\
E7AD94DEA58CDEA58CD69C84D69C84D69C84CE947BCE947BCE947BCE947BC68C73
BD846BCE8C6BC68C73CE9473C68C73BD846BCE8C6BC68C73CE8C6BCE8C6BD68C7BD69C73D69C84\
DEA58CDEAD94E7AD94E7AD94E7AD9CE7B59CE7B59CEFBDA5E7B59CE7B59CEFBDA5
E7BDA5E7BDA5E7BDA5E7B59CE7B59CE7B59CE7AD9CE7AD94E7AD9CE7AD94DEAD94DEAD94DEA58C\
DEAD94DEA58CDE9C84D69C8CDEA58CDE9C84D69C84DE9C8CD69C84D69C84D69C84
D6A58CD6A58CD6A58CD6A58CDEB59CDEB5A5D68C73CE8C6BCE9473D68C73D68C7BD69C84D69C84\
D69C84DEB59CF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7CEB5
F7BDB5F7CEB5F7C6ADE7B59CE79484E79484DE9473DE9473D67B6BBD846BCE8C73D68C7BD6A58C\
DEB59CEFBDA5EFC6ADEFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6
F7DECEF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7BDB5F7BDB5
F7D6BDF7D6BDF7BDB5EFCEB5EFCEB5EFCEB5EFBDADEFBDADF7C6ADEFCEB5F7BDB5EFC6ADEFCEB5\
F7BDB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5F7C6ADEFBDA5EFBDA5E7B59CE7B59C\
E7A58CDEA58CD6A58CD69C84D69C84CE947BCE947BCE947BCE947BC68C73C68C73
C68C73CE8C6BC68C73C68C73C68C73CE9473CE947BCE9473CE947BD69C84D69C84DEAD94DEAD94\
E7AD94DEAD94E7AD94E7B59CE7B59CE7B59CE7B59CE7BDA5EFBDA5E7BDA5EFBDA5
EFBDA5EFBDA5E7BDA5E7BDA5E7B59CE7AD9CE7AD94E7B59CDEAD94E7AD94DEAD94DEA58CDEA58C\
DEA58CDEA58CD69C73DE9C8CD6A58CDE9C8CD69C84DE9C8CD69C84D69C84D69C8C
D69C84DEA58CD6A58CDEB59CDEB5A5DEB5A5CE8C6BCE8C6BCE8C6BD68C73D69C84D69C84D69C84\
D6A58CDEB59CEFD6CEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7EFC6ADF7BDB5
EFCEB5F7D6C6F7CEB5EFB5A5E7A58CE7A58CE79484DE9473BD846BC68C63CE8C73C69C84DEAD94\
E7B59CEFBDADEFC6ADF7BDB5EFCEB5EFCEB5F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7BDB5EFCEB5EFCEB5F7BDB5EFCEB5F7C6ADF7BDB5EFC6ADEFCEB5EFCEB5F7C6ADEFCEB5F7C6AD\
EFBDADF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5EFCEB5EFB5A5EFBDA5EFBDA5E7AD94\
DEA58CDEA58CDEA58CD69C84D69C84D69C84CE947BCE947BC68C73CE9473C68C73
CE9473C68C73CE9473CE9473CE947BCE947BD68C7BD69C73D69C84DE9C84DEAD94DEAD94DEAD94\
DEAD94DEB59CE7AD94E7AD9CE7BDA5E7BDA5EFB5A5EFBDA5EFBDA5EFB5A5E7BDA5
EFBDA5E7B59CEFBDA5EFBDA5E7B59CE7B59CE7AD94DEB59CDEAD94E7A58CDEAD94DEA58CDEAD94\
DE9C8CDEA58CD69C84D6A584DEA58CD69C84D69C84D69C84D69C84D69C84D69C84
D6A58CD6A584D6A58CDEB59CC6ADA5DEB59CCE9473D68C73CE9473D68C73D69C73D69C84D6A58C\
D6A58CD6A58CD6C6C6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7BDB5F7C6AD
F7CEB5F7D6C6F7BDB5EFB5A5E7A58CE7A58CE79484DE9473CE8C73BD846BCE8C73D69C84DEAD94\
E7B59CEFBDADEFCEB5EFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6BDEFCEB5
EFCEB5F7BDB5F7D6BDEFCEB5F7BDB5EFCEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFCEB5EFBDAD\
EFC6ADF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7C6ADE7B59CE7B59CE7AD94\
DEA58CDEA58CD69C84D69C84D69C84C69C84CE947BCE947BCE947BCE9473C6947B
CE947BCE947BCE947BD69C84CE947BD69C84D6A584D69C84D69C84D6A58CDEA58CDEAD94DEAD94\
E7AD9CE7AD9CDEB59CE7AD9CE7BDA5EFBDA5E7BDA5EFBDA5E7B59CE7B59CE7B59C
EFBDA5EFBDA5E7B59CE7BDA5E7B59CE7B594E7B59CE7B59CE7AD94DEAD94DEA58CDEAD94DEA58C\
DEA58CD6A58CDEA58CD69C8CDEA58CD69C84D69C84D6A58CD69C84D69C84D69C84
D69C84DEA58CD69C8CDEB59CDEB5A5DEB5A5D68C7BD69C73D68C7BD69C73D69C73DE9C8CD6A58C\
D6A58CD69C84DEB5A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7F7D6BDF7C6ADF7C6AD
F7BDB5F7D6C6F7D6BDF7C6ADE7AD9CE7A58CE79484DE9473CE8C6BBD846BCE8C73C69C84DEAD94\
E7BDA5EFBDADF7BDB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5F7BDB5
EFCEB5EFCEB5F7BDB5EFCEB5EFC6ADEFC6ADEFBDADEFBDADEFBDA5EFBDA5EFBDA5EFC6ADEFBDAD\
F7BDB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7CEB5EFBDADEFBDA5E7AD94DEAD94\
E7AD94DEA58CD6A584D68C7BD69C84D69C84CE947BCE947BCE947BCE947BCE947B
CE947BCE947BD68C7BD69C8CD69C84D69C84D69C84DEA58CD69C8CDEA58CDEAD94DEAD94E7AD9C\
DEB59CE7B59CE7B59CE7B59CE7B59CE7BDA5E7BDA5EFBDADEFBDA5EFBDA5E7B59C
EFBDA5E7BDA5E7B59CE7B59CE7B59CE7AD9CE7B594E7AD94DEAD94E7AD94DEAD94DEA58CDEAD94\
DEA58CDE9C8CDE9C84D6A58CDE9C84D69C84D69C84D69C8CD6A58CD69C84D69C84
D69C8CD6A58CD6A58CDEB59CC6ADA5C6ADA5D69C84D69C73D6A584D69C84D69C84D6A58CD6A58C\
D69C8CD69C84DEA58CF7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7CEB5EFBDA5EFBDA5
F7CEB5F7D6C6F7D6C6F7C6ADE7A58CDE9473DE9C84DE9473CE8C6BC68C73C68C73D69C84DEAD94\
E7BDA5EFC6ADEFCEB5F7D6BDF7BDB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDF7D6BDEFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5
F7BDB5F7BDB5EFCEB5EFBDADEFC6ADEFBDADEFC6ADEFBDA5EFBDA5EFBDADEFBDADEFBDA5EFC6AD\
EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6F7BDB5EFBDA5EFBDA5E7AD94E7A58C\
DEAD94DEA58CDE9C8CD69C84D69C84C69C84D69C84CE947BCE947BCE947BCE947B
CE947BD69C73C69C84D69C73C69C84D69C8CD69C84D69C84D6A584DEA58CDEAD94DEAD94DEAD94\
E7AD94E7B59CE7BDA5E7B59CE7BDA5EFBDA5EFBDA5EFBDA5E7B59CE7BDA5EFBDA5
E7B59CEFBDA5E7B59CE7AD94E7AD94E7B594DEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDE9C84\
DEA58CDEA58CD6A58CDE9C84D69C8CD69C84D69C8CD69C84D69C84D69C84D69C8C
D6A584D69C8CD69C8CDEB59CDEB5A5DEB59CD6A58CD6A584DE9C84D6A58CD6A584DEA58CD6A58C\
D69C84D68C7BD69C8CD6C6C6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDF7BDB5E7B594E7B594
F7D6BDF7DECEF7D6C6EFB5A5E7A58CDE9C84E79484D68C7BC68C73BD846BC68C73C69C84DEAD94\
EFBDADEFC6ADEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECE
F7DECEF7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5\
F7DECEF7D6BDF7D6BDF7D6BDEFBDADF7BDB5EFCEB5F7BDB5EFCEB5EFC6ADEFCEB5
EFCEB5EFCEB5EFBDADF7C6ADEFBDADEFBDA5EFBDADEFBDA5EFBDA5EFC6ADEFBDADEFBDADF7BDB5\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFBDADEFBDA5E7B59CE7AD94\
DEA58CDEA58CD6A584D69C84D69C84CE8C84C69C84CE947BCE947BCE9473CE947B
D69C73C69C84D69C84D69C84CE8C84D69C73D6A58CD6A584D69C8CDEA58CDEAD94DEA58CE7AD94\
DEB59CE7AD9CE7BDA5E7B59CEFB5A5E7BDA5EFB5A5E7B59CE7BDA5EFBDA5E7BDA5
EFBDA5E7B59CDEAD94E7AD94DEAD94E7B59CE7AD9CE7B594DEAD94DEA58CDEA58CD6A58CDEA58C\
DEAD94DEA58CD6A58CDE9C8CD6A58CDE9C84D6A584D69C84D69C84D69C84D69C84
D69C8CD69C84D6A58CDEB5A5DEB5A5DEB59CDE9C84DE9C84DEA58CD6A58CDE9C84D6A58CD6A58C\
CE9473D68C7BD69C73F7BDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDF7C6ADE7B594E7B594
F7D6BDF7D6BDE7BDA5E7AD94E7AD9CDE9C84DE9C84DE9473BD846BBD846BC68C73CE947BDEB59C\
EFBDADEFC6ADF7BDB5EFCEB5EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDF7D6BD\
EFCEB5F7D6BDEFCEB5EFCEB5EFC6ADEFCEB5EFCEB5EFCEB5EFBDADEFBDA5EFBDAD
EFCEB5EFBDADEFCEB5EFCEB5EFBDADEFBDA5EFBDA5EFBDADEFBDA5EFBDADEFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFBDADEFBDA5EFB5A5E7AD94\
DEA58CDEA58CDEA58CD69C84D69C84D69C84CE947BC6947BCE947BCE947BCE947B
C69C84D68C7BC69C84D69C73D69C84D69C84D6A58CDEA58CDE9C84DEA58CDEA58CDEAD94E7AD9C\
DEB59CE7B59CE7B59CE7BDA5E7BDA5E7B59CE7B59CE7BDA5EFBDA5E7B59CE7B59C
E7BDA5E7B59CE7B594E7B594E7AD94DEB59CE7AD9CDEAD94E7AD94DEAD94DEA58CDEA58CD6A58C\
D6A58CD69C84DEA58CD6A584D69C84D69C8CD69C8CD69C84D69C84D69C84D69C84
D69C84D69C8CDEB59CC6ADA5E7AD9CC6ADA5CE9473D6A584D6A584DEA58CD6A58CD6A584DEB59C\
D68C73D68C73D68C73DEAD94F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7C6ADE7A58CDE9473E7B59C
E7A58CD69C8CD69C8CD69C849C6B529C6B52B57B63CE8C73CE8C6BBD846BBD846BC69C84E7BDA5\
EFBDADEFCEB5F7BDB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6BDEFCEB5F7BDB5EFCEB5F7BDB5EFC6ADEFC6ADEFCEB5EFBDADEFBDA5EFC6AD
EFBDA5EFBDA5E7BDA5E7BDA5EFC6ADEFBDADEFBDADF7BDB5EFCEB5F7BDB5EFCEB5F7BDB5F7D6BD\
F7D6BDEFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7BDB5F7BDB5EFC6ADE7B59CE7AD9C\
E7AD94DEA58CD69C8CD69C84CE947BC69C84C69C84CE947BCE947BCE947BCE947B
CE947BCE947BC69C84CE947BD69C84D69C84D69C84D69C84DE9C8CD69C8CDE9C8CDEAD94E7B59C\
E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7BDA5E7B59CE7B59CE7BDA5EFBDA5
E7B59CDEAD94E7AD94DEB59CE7AD94DEB59CDEAD94DEAD94E7AD94DEAD94DEAD94DEAD94DE9C8C\
D6A58CDEA58CD6A58CDE9C84D6A58CD69C8CD69C84D69C84D69C84D69C84D69C84
D6A58CD6A58CD6A58CDEB5A5DEB5A5DEB59CC66B52C66B52CE8C6BDEA58CDEAD94DEAD94DEB59C\
D68C7BCE8C6BDE9473D68C7BEFC6ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6BDE7B594DE9473E7A58CE7A58C
CE8C73DEAD94DE9C8CAD735A9C6B52AD735A9C6B52AD735AB57B63B57B63BD846BD69C84E7BDA5\
EFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFCEB5F7CEB5\
EFCEB5F7D6BDEFCEB5EFCEB5EFCEB5EFC6ADEFCEB5EFBDADEFC6ADEFBDADEFBDAD
E7BDA5EFBDA5EFBDADEFBDADEFBDADEFC6ADEFC6ADEFC6ADEFCEB5EFCEB5EFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5F7D6C6F7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFCEB5EFBDADE7B59CE7AD94\
DEA58CDEA58CD69C84D69C84D69C73CE947BCE947BCE947BCE947BCE947BCE947B
CE947BCE947BC69C84D69C84D69C84D69C84D69C84D6A58CD6A58CDE9C8CDEAD94DEB59CE7AD9C\
DEAD94E7BDA5E7B59CE7B59CE7B59CE7AD94E7B59CE7B59CE7B59CE7BDA5E7B59C
E7BDA5E7B59CE7B59CE7AD94E7B59CDEB59CE7AD94DEA58CDEAD94DEAD94DEAD94DEA58CDEAD94\
D69C8CDEA58CD69C84D6A58CD69C84D69C8CD69C84D69C84D69C84D69C84D6A584
D69C8CD6A58CD6A58CDEB5A5DEB5A5C6ADA5AD6B52C66B52CE7352D69C73D6A584D6A58CDEB59C\
D69C84D68C73D68C73D68C73DEA58CEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7CEB5E7A58CDE9473E79484CE8C6B
CE8C73E7A58CB5846B734231945A4AAD735AAD735A94634AA56B52A5735AAD7B6BD6A58CE7B59C\
EFC6ADEFCEB5EFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFC6ADEFCEB5\
EFC6ADEFC6ADEFBDADEFBDA5E7BDA5EFBDADEFBDADEFCEB5EFBDADE7BDA5EFCEB5
EFC6ADD6C6B5EFC6ADEFBDADEFC6ADEFBDADE7BDA5EFBDADEFCEB5EFC6ADEFCEB5EFBDADF7D6BD\
F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7CEB5EFC6ADEFBDA5E7B59CDEAD94\
DEA58CDE9C8CD69C84C69C84CE947BCE947BCE947BCE947BCE947BCE947BCE9473
CE947BCE8C84D69C73D69C84D69C8CC69C84D69C8CDEA58CDE9C8CDEAD94DEAD94E7AD94E7B594\
E7AD9CDEB59CE7B59CE7AD9CE7AD94DEAD94E7AD94E7AD9CDEAD94E7AD9CE7AD9C
DEB59CE7AD9CDEAD94E7AD9CDEAD94E7AD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEA58CD6A58CD6A58CD69C84D69C84D69C73D69C84D69C73D69C84D69C84D69C8C
D6A58CD69C8CDEAD94C6ADA5DEB59CDEB59CB5735AB5735AC66B52CE8463D69C73D6A58CD6A58C\
D6A584D68C7BD68C73DE9473D68C73EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7D6BDF7C6ADE7A58CE79484D68C7BBD846B
CE8C73AD735A8C5A42B5846BAD735A9C6B528C5A4A8C5A4A94634A9C6B529C7363C69C84E7BDA5\
F7BDB5F7D6BDEFCEB5F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5\
EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFCEB5D6C6B5EFC6ADEFBDADEFBDADE7BDA5
E7B59CE7B59CE7BDA5E7B59CE7BDA5EFBDADE7BDA5EFC6ADEFBDADEFCEB5EFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7CEB5F7BDB5EFCEB5EFC6ADEFBDA5E7AD9CE7AD94\
DEA58CD69C73D69C84D69C84D68C7BCE947BC6947BC68C73CE947BCE947BCE947B
CE9473C69C84CE8C84C69C84D69C8CD69C84D69C84DEA58CD6A58CDEAD94DEAD94DEAD94DEAD94\
E7B59CE7AD9CE7AD9CDEB59CE7B59CDEAD94E7AD94E7AD94DEAD94E7AD94DEB59C
E7AD9CDEAD94E7AD94DEAD94E7AD94DEA58CE7AD94DEAD94DEAD94DEA58CD69C8CDEA58CDEAD94\
DEAD94D6A58CDEA58CD69C8CD69C84D69C84D69C84D69C84D69C84D69C8CD69C8C
D6A58CD69C8CD6A58CE7AD9CC6ADA5D6A58CB5735AC66B52C66B52CE8C6BCE947BD6A58CD6A58C\
DEA58CD69C84D69C84D69C73D68C73F7BDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFFEFE7E7F7C6ADEFBDA5DE9473E79484DE9C84AD6B52
8C5A429C5A42BD846BD69C84945A4A8452428C5A4A84524294634A94634AA5735AD69C84E7BDA5\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
EFD6CEF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5
E7BDA5E7BDA5E7B59CE7B59CE7B594E7AD94E7B59CE7AD9CE7BDA5EFBDADEFC6ADEFBDADEFC6AD\
F7BDB5F7D6BDEFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6
F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7BDB5EFCEB5EFBDADEFBDA5EFB5A5E7AD94DEA58C\
DE9C84D69C84D69C84D69C73C69C84CE947BCE947BCE947BC68C73CE9473C6947B
CE947BC69C84D69C84D69C84D69C84D69C84D69C8CD6A58CDEA58CDEA58CDEAD94DEAD94E7AD94\
E7AD94DEAD94E7AD94DEB59CDEB59CE7AD94DEB59CE7AD94DEAD94DEAD94E7AD94
E7AD94E7AD94DEB59CE7AD94DEAD94DEAD94DEA58CDEAD94DEA58CD6A58CDEA58CDEAD94DEAD94\
DEA58CDEA58CD69C84D6A58CD6A58CD69C8CD69C84D69C73D69C84D69C84D69C8C
D6A58CD69C8CDEAD94C6ADA5DEB5A5DEB59CB57B63B5735AC66B52C68C63CE9473D6A584D69C73\
D6A58CDEA58CDEA58CD68C7BD68C7BDEAD94F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEF7C6ADE7B594DE9473E7A58CCE947B945A4A
734229B5735AD69C84BD846B8C5A4A8C6352845242845242734A429C6B52A5735AC69C84E7BDA5\
EFC6ADF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5F7D6C6F7D6C6EFD6CEEFD6CEF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5F7BDB5
EFBDADEFBDADEFBDA5E7B59CE7AD9CE7B59CE7AD9CDEAD94DEAD94DEAD94E7AD9CEFBDADEFC6AD\
D6C6B5EFCEB5EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5EFBDADEFB5A5E7B59CE7AD94DEA58C\
D6A584D68C7BD69C73CE8C84CE947BCE9473CE947BCE9473C68C73CE947BC68C73
C68C73C69C84D69C73D69C84D69C84C69C84D6A58CDEA58CDEAD94D6A58CDEA58CDEAD94DEA58C\
DEAD94DEAD94E7AD94DEAD94E7AD9CE7B59CE7AD9CE7AD9CDEAD94E7AD94DEAD94
DEA58CE7AD94DEAD94E7AD94DEAD94DEAD94DEA58CDEA58CD6A58CDE9C8CDEAD94DEA58CD6A58C\
DEA58CD69C8CDEA58CD6A58CD69C84D6A584D69C84D69C84C69C84D69C84D69C84
D69C8CD6A58CC6ADA5DEB5A5D6A58CD6A58CB57B63B5735AC68C63CE8463CE8C6BCE9473CE9473\
DE9C84DEA58CD6A58CD68C7BDE9473DEA58CF7E7DEF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6EFBDA5E7A58CDE9473EF948CBD846B734A39
734231CE947BBD846BB57B63AD735AC6947B8C73638C5A4A734A42846352A5735AD6A58CE7BDA5\
EFC6ADEFCEB5F7D6BDF7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5EFCEB5F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6D6C6C6
EFCEB5F7BDB5E7BDA5E7BDA5E7BDA5E7B59CE7AD9CE7AD94DEAD94DEAD94DEAD94DEA58CDEB59C\
F7BDB5F7C6ADF7D6BDF7D6C6EFCEB5EFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6EFCEB5F7BDB5F7D6BDEFCEB5F7D6BDEFBDA5E7B59CE7AD9CE7AD94DEA58C\
DE9C84D69C84D69C84D69C73CE947BCE9473C68C73CE9473C68C73C6947BCE947B
C6947BCE947BCE947BC69C84D69C84D69C8CD6A58CD6A58CD6A58CDEAD94DEAD94DEAD94DEAD94\
E7AD9CDEAD94E7AD9CDEAD94DEB59CE7AD9CDEAD94DEAD94E7AD94DEAD94DEAD94
DEA58CDEAD94DEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDEA58CDEAD94DEAD94DEA58CDEA58C\
D6A58CDEA58CD6A58CD69C84D69C84D69C8CD69C8CD69C84D69C84CE947BD69C8C
D6A58CD6A58CD6A58CDEB59CDEB59CD6A58CB57B63AD6B52AD6B52B5735AC66B52C66B52C66B52\
CE8C6BDE9C84DEA58CD69C8CD68C73DE9C84EFD6CEFFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7D6C6E7B594DE9473E79484EFB5A5A5735A734229
B5735AAD735A6342315221188C5A42945A528C6352AD846B846352846352846B5AC69C84E7BDA5\
EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5F7D6C6F7D6C6F7D6BDF7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6C6EFCEB5EFCEB5D6C6B5EFC6ADEFCEB5F7D6BDF7D6C6EFD6CEF7D6C6\
EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFD6CED6C6BDF7D6C6F7D6C6EFCEB5
F7D6C6F7BDB5D6C6B5EFBDADE7BDA5E7BDA5E7BDA5E7A58CDEAD94DEA58CDEA58CDEA58CDEAD94\
DEA58CDEB59CEFBDADEFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFC6ADEFBDA5EFB5A5E7BDA5E7A58CDEA58C\
DE9C8CD69C84CE947BCE947BCE947BCE947BCE8C6BC68C73C68C73C68C73CE947B
CE947BC69C84C69C84C69C84D69C8CD69C84D6A584D6A58CDEA58CDEA58CD6A58CDEA58CDEA58C\
DEAD94DEA58CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94
D69C8CDE9C8CD6A58CDEAD94DEA58CDEAD94DEA58CDEAD94DEAD94DEAD94DEA58CD6A58CD6A58C\
D6A58CD6A58CD6A58CD6A584D69C84D69C84D69C84D6A584D69C84C69C84C69C84
D69C8CD6A58CC6ADA5DEB59CD6A58CD6A58CB57B63A56B52A5634AA55239A55239A55239A54231\
BD5A42CE7352D69C73D69C73D69C8CD68C73EFBDADF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7E7E7F7C6ADE7A58CDE9473E7A58CE7AD9C945A52734A39
B5735A945A4A4218105A3129A5735AAD847B8C5A4A5A4239846352845242A5735AC69C84E7BDA5\
EFCEB5EFCEB5F7D6BDF7D6C6EFCEB5F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
F7D6BDEFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5E7BDA5E7B59CF7D6BDF7D6C6F7D6BD\
F7D6BDD6C6B5EFC6ADEFCEB5F7BDB5DEB5A5DEB5A5DEB59CDEB5A5DEB59CD6A58C
DEB59CDEB59CD6A58CDEB59CE7BDA5E7BDA5E7AD94DEAD94DEAD94E7AD94DEA58CDEA58CDEA58C\
DEA58CDEA58CE7B59CEFC6ADEFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7BDB5EFC6ADEFBDA5EFBDA5E7B59CDEA58CDE9C84\
D6A584D69C73CE947BCE947BCE8C73C68C73BD846BB58C73C68C73CE947BC68C73
CE9473CE947BCE947BD6A584D6A584D6A58CD69C84D6A584D6A584D69C84D69C84D69C84D69C84\
D6A58CD6A58CDEAD94DEAD94DEAD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94
D6A58CD6A58CD6A58CDEAD94DEAD94DEA58CDEAD94DEAD94DEAD94D6A58CD6A58CD6A58CDEA58C\
D69C8CDEA58CD6A584D69C84D69C8CD69C84C69C84D69C84D69C84D69C8CD69C84
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CB5846BA5735AA5634AAD5A429C5A42A55239A55239\
B55239C66B52CE7352D69C73DE9C84D68C73E7BDA5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7E7DEEFBDA5DE9473E77B6BE7AD9CEFBDADAD735A8C5A42
B5735A634231421810845239734A39634231523129634231734A4273524A846352BD9C8CE7BDA5\
EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5EFCEB5EFC6ADDEB59CAD846BC69C84DEAD94DEB59C\
D6A58CD6A584C69C84C6947BCE947BCE8C84C6947BC6947BC69484C69484C69484
C69484C68C73D69C8CC68C73CE8C84DEAD94D69C8CDEAD94DEA58CD6A58CDE9C8CDE9C84DEA58C\
DEA58CDEAD94DEAD94E7BDA5D6C6B5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECE
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6EFCEB5F7D6BDEFC6ADEFBDADE7B594E7B59CE7AD94DEA58C\
D68C7BCE947BCE947BCE9473CE9473CE9473CE8C6BCE8C6BC69C73C68C73C6947B
C6947BCE947BCE947BCE947BCE947BD69C73CE947BCE8C84C69C84CE947BD69C8CD69C84C69C84\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94DEB59CD6A58CDEB59CDEAD94
D6A58CD69C8CDEAD94DEAD94DEAD94DEB59CDEAD94DEB59CDEAD94DEAD94DEAD94D6A58CD6A58C\
DEAD94D6A58CD69C8CD6A58CD69C84D6A584D69C8CD69C84C69C84D69C84D69C8C
D69C8CD6A58CDEB59CBDA59CD6A58CC69C84B5846BA5735AA5634A9C5A42AD5A42A55239A55239\
B55239BD5A42C66B52CE8463DE9C84D68C7BE7AD9CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7DECEE7B594DE9473DE9473E7AD94EFBDADB57B63734231
A5634A422921421810734231422921392921422921523931634231734A427B6352C69C84E7BDA5\
EFC6ADEFCEB5F7D6C6EFCEB5F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7D6C6
F7D6BDF7D6C6EFCEB5EFCEB5EFC6ADE7BDA5E7B594D6A58CC6947BAD846B8C5A4A846352846352\
8C5A4AA5735AA5735AA5735ABD846BAD847BBD846BB58C73C6947BC69484C69484
C69484C6947BD69C8CC6947BBD8463BD8463CE947BDE9C8CCE8C84D69C84D69C84D69C84D69C84\
D69C84E7BDA5EFBDADE7BDA5EFBDADEFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7DECE
F7DECEF7D6C6F7DECEF7D6C6F7D6BDF7D6BDF7D6BDF7CEB5EFBDA5EFBDA5E7B59CDEAD94DEA58C\
D69C84D69C84D69C73CE9473C68C73C68C73BD846BC68C73C6947BC68C73C68C73
C69C73C69C73CE947BCE9473CE947BC69C84C69C84D69C8CD69C8CD69C8CD6A58CD69C8CD6A58C\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEAD94D6A58CDEAD94D6A58CDEAD94
DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEB59CDEAD94DEA58CDEB59CDEAD94D6A58CDEAD94\
D6A58CD6A584D6A58CD6A584D69C84D69C84D69C73D69C84D69C84D69C8CBD9C8C
D6A58CBDA59CD6A58CDEB59CD6A58CD69C8CB58C73AD735AA56B52A5634AA55239A55239AD5A42\
AD5A42BD5A42C66B52CE8463D69C84DE9473DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7D6BDE7B594DE9473E77B6BE7AD9CEFB5A5BD846B844A39
7342314218103121185A3121312118392921422921523931634231634A42734A42C6ADA5EFC6AD\
EFCEB5F7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDEFCEB5
F7D6C6EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADDEB59CD6A584C68C73DEB59CB5846B845242845239\
734A39734A4294634A9C6B52AD735ABD846BCE8C84BD846B9C7363A5735AA5735A
9C73639C6B52A56B52A5735AB5846BBD8463B5735ABD846BC6947BCE947BD68C7BCE947BCE8C73\
CE947BDEAD94E7B59CE7BDA5EFBDA5EFC6ADEFCEB5F7D6BDF7D6BDF7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFBDADEFBDADE7B59CE7A58CDE9C84\
D69C73D69C73C69C84CE947BCE9473CE8C6BC68C73C68C73BD846BC69C73C69C73
BD846BCE8C6BB58C73C69C84C69C84C69C84D69C8CC69C84D69C84C69C84CE947BD69C73C69C84\
D68C7BD69C84CE947BD69C84D69C84C69C84D69C8CD6A58CD6A58CDEAD94DEAD94
DEAD94DEB59CDEB59CDEAD94DEAD94DEB59CE7AD9CDEAD94DEAD94D6A58CD6A58CDEAD94D6A58C\
D69C84D69C8CD6A584D69C84D69C84D6A58CC69C84C69C84D69C84C69C84D69C8C
D6A58CD69C8CD6A58CD6A58CD6A58CC69C84AD846BA5735AA56B52AD5A42AD5A42A55239AD5A42\
B55239BD5A42BD5A42CE8463D68C73DE9C84DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFEFCEB5E7A58CE77B6BDE9473EFB5A5EFB5A5CE947B734A39
5A31212110104218102918183121185231295231294A3131523129734A39734A42D6A58CEFC6AD\
F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6EFCEB5F7D6BDEFCEB5EFCEB5EFCEB5F7D6BD
F7CEB5F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5EFC6ADEFC6ADDEB59CD6A58CDEB5A5C6947B845242\
845242734A39734A39947B73B59C9CCEB5ADCEBDB59484847342296342318C6352
5A31215A31215A31217342297342318C5A4294634AB5735AB5735AC66B52BD8463C68C63B5735A\
CE735ACE8463CE8C6BD69C73DEA58CE7BDA5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDEFCEB5EFBDA5E7B59CE7AD94DE9C84\
D6A584D69C84CE947BCE9473C68C73CE8C6BC68C73BD846BC69C73BD846BBD8463
BD8463C68C73C6947BC69C84C69C84D69C8CD69C84D69C84D69C84D69C84D69C84D69C84D69C84\
D69C73D69C84D69C84D69C84D69C73D69C84D69C73CE947BD69C73C69C84CE947B
D6A58CDEB59CDEB59CDEB59CDEAD94DEAD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94D6A58C\
D6A58CD6A584D69C84D69C84D6A58CC69C84D6A58CD69C84D6A58CC69C84D6A58C
D6A58CD6A58CD6A58CBDA59CD69C8CD69C8CB5846BA5735AAD6B529C5A42AD5A42AD5A42AD5A42\
B55239BD5A42C66B52C66B52D69C73DE9C84DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFEFC6ADDE9473E77B6BDE9473E7AD9CF7BDB5D69C8C633929
4218102110104210103121184229215231295231296342315239316342317B6352BD9C8CEFC6AD\
F7D6BDF7D6C6F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5F7CEB5F7CEB5F7CEB5EFCEB5
F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFC6ADC68C63DEB59CDEAD94C69C84\
9C6B52734A395A4239AD846BB5A5A5CEB5BDBDB5BD7B635A734229AD846BC6ADA5
634A422918182918185A31298452397B31217342299C6B52B57B63B5735AAD6B52A5634AAD5A42\
AD5A42A55239A55239AD5A42C68C63E7B594EFBDA5EFC6ADF7D6C6F7D6C6F7DECE
F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFC6ADEFB5A5E7B59CE7B59CDEA58C\
D6A58CD69C73CE947BCE9473CE9473B58C73BD846BC69C73BD8463BD8463BD846B
BD846BB58C73C69C84D69C8CD6A58CD69C8CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEAD94DEAD94DEA58CDEA58CD6A58CD69C8CD6A58CD69C8CD6A584D69C84D69C84
C69C84CE947BD6A584D6A58CDEAD94DEB59CDEB59CDEB59CDEAD94DEAD94DEAD94D6A58CD6A58C\
D6A58CD6A58CD6A584C69C84D6A584D69C84C69C84C69C84D69C84C69C84BD9C8C
D6A58CD69C8CD6A58CD6A58CD6A58CC69C84B5846B9C7363AD6B52A5634AAD5A42AD5A42AD5A42\
BD5A42BD5A42C66B52CE735AD68C73D69C84DEA58CF7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7E7DEF7C6ADDE9473E77B6BDE7B6BEFB5A5F7BDB5E7AD9C633931
421810211010312118392921523129523129523129523931634231634231734A42D6A58CD6C6B5\
F7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFC6ADF7D6BD
EFCEB5F7D6C6F7D6BDEFCEB5F7D6C6EFCEB5F7D6C6EFCEB5EFCEB5CE947BCE947BDEB5A5DEB59C\
C6ADA5C69C84AD846B634A42846352A5847BAD94945A4239845239C6ADA5CEB5AD
7B737B2918182918185231298452399452399452398C7363BDA59CBD9C8CB58C73B57B639C6B52\
8C5A42A56B52A5735AB57B63C68C63DEA58CEFBDA5F7CEB5EFCEB5F7D6C6F7D6C6
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFC6ADEFBDA5E7BDA5E7AD94DEA58C\
DE9C84D6A584D68C7BC68C73CE8C6BCE8C6BC69C73BD8463B57B63B57B63BD846B
C6947BC6947BD6A58CD6A58CDEB59CDE9C8CDEAD94DEB59CDEB59CE7B59CE7BDA5DEB5A5EFBDAD\
DEB5A5DEB59CDEB59CDEB59CDEAD94DEAD94D6A58CDEAD94D6A58CDEA58CD6A58C
D69C84D6A58CD6A58CD6A58CD6A58CD6A58CDEAD94D6A58CDEAD94D6A58CD6A58CD6A58CD6A58C\
DEA58CD6A58CD6A58CD69C84D69C84D6A584D69C84D6A584D69C8CC69C84D69C8C
BD9C8CD6A58CD6A58CD6A58CD69C8CC6947BAD7B6BA5735AA5634AA5634AA5634AAD5A42AD5A42\
AD5A42AD6B52C66B52CE735AD68C73DE9C84DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
FFFFFFFFFFFFEFD6CEE7B59CDE9473CE7352CE8463E7AD94E7AD9CEFB5A5A5735A
5231294229213929213929214229314A31315231295231296342317B635273524ADEB59CEFCEB5\
EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5F7D6BDEFCEB5F7BDB5EFCEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6EFCEB5EFCEB5EFCEB5E7BDA5D6A58CCE8C6BDEAD94\
D6C6B5C6947BBD9C8CA5847BA5735A5A42396342315A3121735A529484849C8C8C
84739429181829181842313973524A8C5A42845239846B5ABDA59CC6ADA5B59C9C9C73638C5A42\
845239AD5A42CE8463D69C73E7B594EFBDA5EFC6ADEFCEB5F7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5EFBDA5EFBDA5E7B594DEA58C\
DE9C84D69C73CE947BCE8C6BCE8C6BBD846BBD8463B5735AB5735AB5735AB5735A
BD8463CE9473D6A584DEAD94DEB59CDEB59CDEB59CDEB59CDEB59CD69C8CDEB59CDEB5A5DEAD94\
D6A58CD6A58CDEB59CD6A58CDEAD94DEB59CDEB59CDEB59CDEAD94D6A58CDEAD94
D69C8CD6A58CD6A584C69C84D6A58CDEAD94DEAD94DEB59CDEB59CDEB59CDEAD94D6A58CD6A58C\
C69C84D6A584C69C84D6A584C69C84C69C84CE947BD6A584C69C84D6A584C69C84
C69C84D6A58CD6A58CD69C8CC69C84C6947B9C7363A56B5294634AA56B52A5634AAD5A42A5634A\
C66B52C66B52CE735ACE8C6BDE9C84DE9C84DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DECED6AD9C8CDEB59CF7C6ADE77B6BCE7352CE735ADE9C8CE7AD94E7AD9CB5846B
6339313929212918182918184229214A3131392921422921523931734A398C7363DEB59CEFC6AD\
EFCEB5EFCEB5F7D6BDEFCEB5F7D6BDF7BDB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5F7D6BDF7D6BDF7D6BDEFCEB5E7BDA5DEAD94CE947B\
DEAD94F7D6BDEFCEB5DEAD94C69C84C6947B9C7363734A396339296339317B635A
524A5A1810102918184229315A42397342317342318C7363B59C9CA58484B58C739C6B52A5634A\
AD5A42BD8463CE8C6BD6A584E7B594EFC6ADEFC6ADEFCEB5F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEEFCEB5F7D6BDEFC6ADEFBDA5E7B59CE7B594DEA58C\
D69C84D69C73CE9473CE8C6BBD846BBD8463B5735AB5735AB5735AA573528C3129
845239A5634AB5735AD69C84D6A58CDEB59CDEB59CD69C8CD69C8CCE947BCE8C84C6947BCE947B\
B58C73BD846BBD846BC68C73B58C73C69C84D6A58CD6A58CD6A58CD6A58CD6A58C
D6A584D6A58CD6A58CC69C84C6947BD6A584D6A58CD6A58CD6A58CD6A58CD6A58CD6A584D6A584\
D6A58CD6A58CD6A584CE947BC69C84D6A584C69C84CE947BD69C84C69C84D6A584
D69C8CD6A58CD6A58CC69C84CE947BB58C739C6B529C6B529C6B52A56B52A56B52A5634AAD6B52\
B5735ACE735ACE8463CE8C6BD69C84D69C8CDEA58CF7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF\
6B524A734229E7B594F7C6ADCE8463CE7352CE735ADE9C84E7AD9CE7AD94D69C84
734A423121183121214229214229215231295231294229215A3129634231846352DEAD94EFCEB5\
F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BD
F7D6BDF7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6EFCEB5EFC6ADE7BDA5DEAD94\
D6A584DEAD94EFCEB5EFBDADDEB59CDEB59CB58C738463528C5A4A634231634231
5231292918183121184221186339297342296339298463527B635A9C6B52AD6B52AD6B52B5735A\
B5735AC66B52CE8C6BDEA58CE7B594E7B59CEFBDADEFCEB5F7D6C6F7D6BDF7D6C6
F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFBDA5E7B594DEA58C\
D6A584D68C7BCE9473BD846BC68C63BD8463B57B63BD8463B5735AAD6B52734229
7B29187B3121844A39B57B63C68C73C6947BCE947BC68C73C68C63BD846BB57B63B5846BB5846B\
A56B52A56B52AD735A9C6B52A5735AB57B63BD846BC6947BC6947BC69484C69C84
C69C84C69C84D6A584D6A584D6A584CE947BC69C84D6A584D6A58CD6A584D6A58CD6A58CD6A58C\
D6A584C69C84C6947BC6947BCE947BC69C84C69C84C69C84C69C84D69C84C69C84
D69C8CC69C84D69C8CC69C84C6947BB58C739C6B5294634A945A4AA5634AA56B52945A4AAD6B52\
D67363CE8463CE8C6BD68C7BD69C73D68C7BD69C84F7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFB59C9C\
421810734229E7B594EFBDA5E79484CE7352D67363E7B594EFBDA5E7B59CE7B59C
8463522110103121184A3131523129422921422931392921523129634A42846352DEB59CEFCEB5\
EFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFC6ADE7BDA5\
E7B59CD6A584DEAD94F7D6BDEFCEB5C6ADA5B58C73DEAD9494736B84524273524A
845239734A3963423163392973423173422963423194634A8C5A4294634AB5735AB5735AC66B52\
B5735AC68C63DE9C84E7B594DEAD94E7B59CE7BDA5EFCEB5F7D6BDF7D6C6F7D6C6
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6EFCEB5EFCEB5EFBDA5E7BDA5E7B594DEA58C\
D6A584D69C73CE9473CE8C6BBD8463BD8463C69C73BD8463B5735AB5735A9C5A42
7342297B3121845242AD847BB58C73C6947BC69484BD846BAD847BAD735AA5735A9C6B5294634A\
94634A9C6B529C73639C73639C7363A5735A9C6B529C6B52AD735AB57B63B58C73
C69484C6947BC6947BC6947BC69C84CE947BC6947BC69C84C69C84D6A584D6A584CE947BD6A584\
CE947BD6A584C69C84CE947BC6947BC6947BC69C84D6A584C69C84C69C84C69C84
D6A584D69C8CD69C84C6947BC6947BAD846B8C5A4A94634A94634A9C6B5294634A94634A94634A\
C68C63CE8C6BCE8C6BDE9473DE9C84D68C73DE9C84F7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7DEE7947B735A3129\
4218105A3121DE9473F7C6ADEFBDA5E7B59CE7B59CF7C6ADE7B59CE7B59CE7A58C
8452422110103929214A3131523129392921422921523129523129634231846352DEB5A5EFC6AD\
EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5EFCEB5F7CEB5EFCEB5
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5EFCEB5\
E7BDA5E7B59CDEAD94DEAD94EFCEB5DEAD94DEB5A5DEB5A59C7363AD846BB5846B
9C6B529C6B5273524A8C5A4A9C6B52845242845242A57352AD6B52AD846BBD8463B5735AB5735A\
B5735AE7B594E7B594E7B594DEA58CE7B594EFBDA5EFCEB5EFCEB5F7D6BDF7D6C6
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7D6C6F7D6BDEFC6ADEFBDA5EFBDA5E7B59CDEA58C\
D69C84D68C7BCE8C6BCE8C6BBD846BBD8463BD846BBD846BBD8463B5735AAD6B52
A573529452398C5A42AD8C84C6ADADCEBDB5D6C6BDD6C6C6BDB5BD846B5A8452396339297B2918\
633929734229634231845242A5735A9C73639C6B52945A528452398C5A4294634A
B57B63B58C73B5846BB58C73B58C73C69C73B58C73CE8C6BC69C73C68C73C6947BC6947BC6947B\
C69C73C6947BCE947BCE947BCE947BCE947BD6A584C69C84C69C84D69C84D69C8C
D69C8CC69C84C69C84C68C73B58C73B57B638452428C5A428C5A4A8C63528C5A4A8C5A4A9C6B52\
C68C63D68C73D68C7BD69C73D69C84CE8463DE9473EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFEFE7E79C8C8C633929422921\
421810522118D69C73E7B594F7C6ADF7C6ADF7C6ADEFBDA5E7AD94E7B594DE9C8C
8452423121185231294A31315239313929214229214229215A3121634A42846352DEB59CEFCEB5\
F7CEB5F7D6C6EFCEB5F7CEB5EFCEB5EFCEB5EFCEB5EFCEB5E7BDA5EFC6ADEFCEB5
F7D6BDF7D6BDEFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5\
EFCEB5EFC6ADE7B59CDEA58CCE947BD6A584E7BDA5DEB5A5C69C84DEB59CD6A584
B58C73A5735A9C6B52AD735A9C6B5294634A94634AB5735AB5735ABD8463BD8463B5735AB5735A\
D69C73DEA58CE7B594DEA58CE7A58CE7B59CEFC6ADEFCEB5EFCEB5F7D6C6F7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6EFCEB5EFBDA5EFBDA5EFBDA5E7B59CDEA58C\
D69C73CE947BCE9473CE8C6BBD8463BD8463B57B63C69C73BD846BB57B63B5735A
B5735AA5634A844A399C7363C6ADA5D6C6BDD6C6C6CEBDC6AD94946339297B3121633929522118\
5A31217342297342297342296342318452399C6B52A56B52945A4A8C5A4A845242
8C5A429C7363AD846BAD846BAD846BB5846BAD846BAD846BAD846BB5846BBD846BBD846BB58C73\
C68C73C6947BCE947BC69C84D69C84D69C84C69C84D69C84C69C84C69C84D6A58C
D69C8CD6A58CC6947BC68C73B58C739C73638452428463527B63528C5A4A846352845242845242\
BD846BD68C73D69C73DE9C84DE9C84CE8463D68C73F7D6C6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADAD634231422921522118\
4218104A2118C68C63E7A58CE7B594F7C6ADF7C6ADE7B59CE7A58CE7A58CD69C84
8C5A4A5A3129524239634A42423139422921312118422921422921634A428C6352DEB5A5EFCEB5\
EFCEB5EFCEB5F7BDB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDE7BDA5E7B59CEFC6AD
EFCEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6EFD6CEF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5\
EFCEB5EFCEB5EFC6ADE7B59CDEB59CD6A58CDEA58CD6A58CD6A58CDEB59CDEAD94
D6A58CB58C73B58C73C68C73BD8463B57B63B5735ABD8463BD8463B5735AB5735AC68C63D6A584\
DE9C84DE9C84E7AD94E7AD94E7AD94E7BDA5EFBDADEFC6ADEFCEB5F7D6BDF7D6C6
F7DECEF7DECEF7E7DEF7E7DEF7DECEF7D6C6EFCEB5F7CEB5EFC6ADEFC6ADE7BDA5E7B59CDEA58C\
D69C84D69C73CE9473CE8C6BBD8463BD8463B57B63BD846BBD846BBD8463B5735A
AD6B52B5735AA56B528C5A42A5847BC6ADADDECED6BDB5BD7B635A845239A5847B523129211010\
312121423139734A398452427B63526342317B6352846B5A9C6B52945A4A8C5A42
6342318463529C6B52A5735A9C73639C73639C6B5294634AA57352AD735AB57B63BD846BCE8C6B\
C68C73CE947BD6A584C69C84C69C84D6A584C69C84C69C84D6A584C69C84D6A58C
D69C84D6A584C6947BB58C73AD846B9C6B52845242845242734A39846B5A8463528C5A4A845242\
CE8C6BD69C84DE9C84DEA58CCE8C6BCE7352DE7B6BD6C6BDF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C6342314229214A2118422921\
4218104218105A3121C66B52E7A58CE7B594E7B594CE8C6BCE8C6BC68C63A5634A
633931634231524239524239523129392921422921422921523129634A42846352D6C6B5EFCEB5\
EFCEB5EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDE7BDA5D69C84CE947B
DEAD94E7BDA5EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6BDEFD6CEEFD6CEF7D6C6F7D6C6F7D6C6\
F7D6BDF7D6C6EFCEB5EFBDADEFC6ADE7BDA5E7BDA5E7B59CE7B594DEB59CDEAD94
D6A584D6A584CE9473CE9473CE8C6BBD8463CE8C6BD6A584D6A584DE9C84DE9C84DEA58CDEA58C\
DEA58CDEAD94E7B594E7B59CEFBDA5EFC6ADEFCEB5EFCEB5F7D6BDF7D6C6F7D6C6
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEEFCEB5F7BDB5EFC6ADEFC6ADEFBDA5E7BDA5DEAD94\
D6A58CD69C84CE9473CE8C6BBD8463BD8463BD8463BD846BBD846BC69C73BD8463
B5735AAD6B52BD8463B5846BB5735AA5735A94736B8C736B7B6352C6ADA5BDA59C4A394A181010\
3121215242395242396B524A734A42734A39735A529484849C8C8CA5847B7B635A
6B524A634A42524239634A426B524A6B524A7B63528452429C6B52B57B63C6947BD6A584D6A58C\
D6A584D6A584D6A584C69C84D6A584C69C84D6A584C69C84D69C8CC69C84C69C84
D69C84CE947BC6947BAD846BA5735A7B6352734A396B524A73524A8452396339296342318C5A42\
BD846BD6A58CDEA58CD68C73CE634ACE7352CE8463EFCEB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7846B5A5239315A31294A2118422921\
211010421810421810734229C66B52DE9473DE9473B5735AAD6B52A55239734A39
5A42395A42394A3131422931422921392921392921422921523129734A398C7363EFC6ADF7CEB5\
EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDE7BDA5C6947B
C68C73DEAD94EFBDA5EFC6ADEFCEB5F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
EFD6CEF7D6C6F7D6C6EFCEB5EFC6ADEFC6ADEFBDADE7B59CE7B59CE7B59CE7B594
DEAD94DEA58CDEA58CDE9C84D6A584D6A584D6A584DE9C84DE9C84DE9C84DE9C84DE9C84DEA58C\
E7A58CE7B594E7B59CE7BDA5EFC6ADEFC6ADF7BDB5F7D6BDEFCEB5F7D6C6F7DECE
F7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFC6ADEFBDA5E7B59CDEAD94\
DEA58CD69C84D69C73C68C73C68C63BD8463BD846BCE8C6BC69C73BD846BC68C63
BD8463AD6B52B5735AB58C73C68C73BD846BB57B63846352734A42A58484ADA5AD423139181010\
3121215A525263524A734A427342316342317B635AA5847B9484848C7B73735A52
524239634231634231634231734A427342317B63529C6B52B57B63B5846BBD8463BD846BCE9473\
CE947BD6A584D6A58CD6A58CD6A58CD6A58CD6A584D6A58CC69C84D6A584D6A58C
C69C84D6A584C6947BAD846B8C6352734A426B524A734A42734A396B524A523931633929845239\
CE8C6BD6A58CDEA58CCE8C6BBD5A42CE7352DE6B5AD6C6B5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFCEB5B5734A396342316339315A3129422921\
4218102110104218102110105A3121945239AD5A428C5A4A734231734229634A42
523931523931523931422931422921312118392921312118523129734A39846B5ADEB5A5EFCEB5\
EFCEB5EFCEB5F7BDB5EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5E7AD9C
C6947BCE8C73DEAD94DEB59CEFC6ADEFCEB5F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECE\
F7DECEF7DECEF7D6C6EFCEB5EFCEB5EFCEB5EFCEB5E7BDA5E7B59CDEAD94E7B594
E7B594DEAD94DEAD94DE9C84DE9C84DEA58CDE9C84DE9C84DE9C84DEA58CDEA58CDEA58CDEA58C\
DEAD94E7B59CE7BDA5EFC6ADEFBDA5EFCEB5EFCEB5F7D6BDF7BDB5F7D6C6F7DECE
F7E7DEF7DECEF7DECEF7DECEF7DECEF7D6BDF7D6BDEFCEB5EFC6ADEFBDA5E7BDA5E7B59CDEA58C\
DEA58CD6A584CE947BCE8C6BC68C63BD8463BD846BBD8463C69C73CE8C6BC69C73
C68C63C68C63B5735ACE947BCE947BC68C73B58C73B57B63A5735A8452397B635A423139181010\
2918183929395239316342317342295A3121735A52947B738C7363634A424A3131
634231734A397B635284635284523994634AAD735AB5846BBD846BC6947BC6947BCE947BB58C73\
CE8C6BCE9473D6A584D6A58CD6A584C69C84D6A584D69C84C69C84D69C8CD69C84
C69C84C69C84C6947BAD846B8463526B524A6B524A734A398452426B524A523931634231634231\
CE8C73D6A58CDEA58CCE8463CE634ACE634ACE8463F7BDB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFAD94945A3129523129633929523931523129\
2110104218104218104A10082110104A10084218108452425A4239523129634231
422931392921523931523129392921392921392921392921523129634A42A5735ADEB5A5EFCEB5\
EFCEB5F7BDB5EFCEB5EFCEB5F7BDB5EFCEB5F7D6BDF7D6C6EFCEB5EFCEB5EFBDAD
DE9C8CC6947BD6A58CD6A58CDEAD94EFBDADEFCEB5F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7DECEF7D6C6EFCEB5EFCEB5EFCEB5EFBDADEFC6ADE7B59CE7B59C
DEA58CDEA58CDEA58CDEA58CDEAD94DEA58CDEA58CDE9C84DEA58CDEA58CDE9C84DEA58CE7B594\
DEA58CE7B594E7B59CEFBDA5EFC6ADEFC6ADEFCEB5EFC6ADEFCEB5F7D6C6F7DECE
F7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6EFCEB5F7D6BDEFBDADEFC6ADE7B59CE7B59CDEB59C\
DEA58CD6A58CCE9473CE9473CE8C6BCE8C6BBD846BC69C73C68C63C69C73C69C73
CE8C6BC69C73C69C73CE9473D6A58CD6A584B58C73C6947BC68C739C73636B524A5A3129312121\
2918183121185221186339295A312952312973524A73524A5A42395A4239634A42
5A42398463528463528463529C6B52B57B63C69C73BD846BBD846BBD846BC69C73CE947BD6A584\
C6947BCE9473C69C84CE947BD6A584D6A58CD69C8CC69C84D6A58CC69C84D69C84
D6A584C69C84C6947BA5735A734A42634231734A39734A39634231523129523129634231734231\
CE947BDE9C8CD69C8CCE735ABD5A42CE634ACE8463EFCEB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79484845231295231295231296339295A3129\
4218104221184221184221184210104A1008211010634A425A4239523129392931
422931392921392921523129392921392921392921422118523129734A398C7363EFC6ADEFCEB5\
EFC6ADEFCEB5F7D6BDF7D6BDEFCEB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5
E7AD9CDEA58CC68C73DEAD94DEB59CD6A58CE7B59CEFCEB5F7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7E7DEF7DECEF7DECEF7DECEF7D6C6EFCEB5EFCEB5EFCEB5EFBDADDEB5A5E7B59C
E7B594DEAD94DEA58CDEAD94DEA58CDEA58CDEA58CDEA58CD6A584DEA58CD6A584DE9C84DEA58C\
DEA58CE7B594E7B59CE7B59CEFBDA5EFCEB5EFC6ADEFBDADF7D6BDF7D6C6F7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6EFCEB5F7BDB5EFCEB5EFC6ADEFBDA5E7B59CE7B59CE7B59C\
DEB59CDEA58CD69C84CE947BCE8C6BBD846BC69C73C68C73BD846BC69C73CE8C6B
CE9473CE9473CE947BBD8463CE947BD6A58CD6A58CD6A58CCE947BB58C73A5735A8463528C5A4A\
845242734A39634A426342315A3129523931634231422921634231734A39734A42
7B63529C6B528C5A4A9C6B52AD846BB57B63B5846BBD846BB58C73CE8C6BCE8C6BC68C73CE947B\
D6A584CE947BD69C73D69C84CE947BCE947BD6A584D6A58CC69C84D69C84D6A58C
C69C84C6947BB58C738C7363734A39634A426342315A4239634A42634A42523129734229634231\
C69C84DEAD94D69C84C66B52CE634ACE7352CE8463F7D6C6F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7846B5A5A31214229215A3129523931633929\
4218104229214A21185221184218104218104218105A42395239314A3131422921
392921392921312121422921312121392921422921422921422921734A398C7363E7BDA5EFC6AD\
EFC6ADF7CEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6C6EFCEB5
EFCEB5E7AD9CCE947BCE8C84DEAD94DEAD94D69C8CD6A58CEFC6ADEFD6CEEFD6CEF7E7DEF7DECE\
F7E7DEF7DECEF7DECEEFD6CEEFD6CEF7D6C6EFCEB5EFCEB5EFC6ADEFC6ADE7B59C
DEAD94DEAD94DEAD94DEAD94DEB59CDEA58CDEA58CD6A584D69C73D68C7BD68C73CE8C6BD68C73\
DE9C84DEAD94E7B59CE7BDA5EFBDADE7BDA5EFBDADEFCEB5EFCEB5F7D6C6F7DECE
F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFBDA5E7B59CE7B59CE7BDA5DEAD94\
DEAD94D6A58CDEA58CC69C84C68C73CE8C6BB58C73CE8C6BC69C73CE9473CE8C6B
CE947BCE947BCE9473D6A584BD8463CE9473D6A58CDEB59CD6A58CC6947BA5735A9C73639C7363\
A5735A845242846352634A42634A428452397B6352523931634A428C6352A5735A
AD846B94634AAD735AB5846BAD846BBD846BB58C73C69C73C68C73C69C73CE9473C69C73C6947B\
D6A584D6A58CC69C84C69C84D69C84C69C84C69C84C69C84D6A584D69C8CD69C84
C69C84C6947BAD846B846352734A39634231523931634A42634A425239315A3129633929633929\
D69C84D6A58CCE8C6BCE634ABD5A42CE7352D68C73EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6735A525231295A3129523931634231633931\
4229214229215A31294229213121184A21185A31215A42394A31314A3131392921
312121392921312121392921422921392921312118422921523129734A39A5735ADEB5A5EFC6AD\
F7CEB5F7BDB5EFCEB5F7D6BDF7CEB5EFCEB5F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6
F7D6BDEFBDADDE9C84D69C8CD6A58CD69C8CC69484C6947BD6A58CF7BDB5EFCEB5F7D6C6F7DECE\
F7DECEF7DECEF7DECEF7D6C6F7D6BDD6C6B5EFC6ADDEB5A5EFC6ADDEB5A5DEAD94
D6A58CD6A584D6A58CD6A584CE947BCE947BCE947BBD846BC68C63B5735AB5735AB5735AC68C63\
D68C7BD6A58CDEAD94E7B59CE7BDA5EFBDADEFBDADEFCEB5F7D6C6F7D6C6EFD6CE
F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5EFCEB5EFC6ADEFBDA5EFBDA5EFBDADE7B59CDEA58C\
DEAD94D6A58CD6A58CD6A58CCE947BCE8C6BBD846BC69C73BD846BC69C73CE9473
CE9473CE947BCE9473CE9473D6A584CE9473C69C73D6A584DEAD94DEAD94C6947BC69C84B58C73\
AD846BA5735AA5735A84635273524A8C63529C6B52A5735A735A52A5735AAD846B
A5735AAD846BB57B63B5735ABD846BC68C73C69C73C69C73C69C73CE947BCE947BCE947BCE947B\
CE947BCE947BD69C84D6A584D69C84D6A584D69C84C69C84C69C84D6A584C69C84
C69C84C6947BA5735A845242634A425239315231294231395231294221184229215A31215A3129\
D6A584D69C84CE8463BD5A42BD5A42CE7352D69C73F7E7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD94A55239315A31295A31295239315A3129634231\
4229215A31296342315A3129523129523129523129523931422921523931392921
2918183121183121183121215231293929213121184229215A3129734A42846352DEB59CEFC6AD\
EFCEB5F7CEB5EFCEB5F7CEB5EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDEFBDADE7AD9CDEB59CD69C8CAD847BAD847BBD846BAD847BC6947BAD847BC6947B\
AD8C84B58C73B58C73B58C73AD7B6B9C6B528C73639C73638C73638463528C5A4A
8C5A4A8C5A4A94634A945A5294634A8C5A428C5A42A5634AA56B52A56B52AD6B52AD6B52AD6B52\
B5735ACE947BD6A58CDEB59CE7AD9CE7BDA5EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6
F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFCEB5EFC6ADEFBDA5EFBDA5EFC6ADE7B59CE7B59CDEB59C\
DEAD94D6A58CD69C8CCE947BCE947BCE9473CE9473CE8C6BBD846BCE8C6BCE8C6B
C69C73C69C73CE947BD6A584D6A584CE9473CE9473DE9C84D6A58CD6A584D6A584D6A584D6A58C\
D6A584C6947BC6947BC6947BAD846BAD846BB57B63AD735AB57B63AD846BA5735A
AD735AB57B63C69C73C68C73CE947BCE947BCE947BCE947BD69C73D69C84D69C84D69C73C69C84\
D69C84D69C84D6A584D6A584C69C84D6A58CD69C84D6A58CD6A584C69C84C69C84
C69C84AD846B8463526342316342315231295A4239634A425231294229214221184A2118734231\
D69C84BD846BCE735ABD5A42BD5A42CE7352DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD734A395A31295A3121422921422118422921\
4A21184229214229214229215231295231295231295239314229214229214A3131
312121312121291818312121523129422921312121392921523129734A399C6B52D6A58CE7BDA5\
EFC6ADEFCEB5F7CEB5EFCEB5F7BDB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6EFCEB5F7D6BDEFCEB5EFCEB5E7AD9CD69C8CC69484B58C73B5846BB58C73B58C73B58C73\
C6947BAD847BAD847B94736B94736B94736B8C63528C6352945A528C5A4A8C5A4A
945A52945A529C6B52945A4A945A4A9C5A42945A52945A4AA56B5294634A945A52AD735ABD8463\
BD846BCE947BDEA58CDEAD94E7BDA5EFC6ADEFCEB5EFCEB5F7D6C6EFCEB5F7D6C6
F7DECEEFCEB5F7CEB5EFCEB5EFCEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDADE7BDA5E7B59CDEB59C\
DEB59CD6A58CD69C8CC69C84CE947BCE8C73C68C73BD846BCE8C6BC68C63BD846B
CE8C6BCE8C6BC69C73D6A584D6A584D6A584D6A584CE947BD6A584D6A584D6A58CD6A584D6A584\
D6A584C6947BC69C73C69C73AD846BB5846BB5846BB5846BB57B63AD735AAD846B
BD846BCE947BC6947BCE947BC69C84CE947BD69C84D69C84C69C84C69C84D69C84C69C84D69C84\
C69C84D6A584CE947BD69C84D6A58CD69C84C69C84D6A58CD69C84D69C84C69C84
C6947BAD846B7B6352634A42523129523931634A42524239392921422921312118422118845242\
D69C84BD846BC66B52BD5A42BD5A42CE7352DEA58CF7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5A5634A42523129422921422921422118422921\
3121184229215231293929214229214229215231295231293929214229214A3131
3929213121183121182918183121215231295231294229215231296339298C6352D6A58CEFC6AD\
EFC6ADEFCEB5F7CEB5F7D6BDEFCEB5EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFBDADDEB59CD69C8CB58C7394736BAD7B6B947B73\
C6947BAD8C84B58C73AD7B6BAD7B6BAD7B6B9C73639C6B52945A528C63528C6352
A5735A945A52945A52945A52945A4A8C5A4A945239945A52945A4AA5735AB57B63BD846BBD846B\
B58C73D69C84DEAD94E7B59CE7BDA5F7BDB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDEFCEB5F7BDB5EFCEB5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFBDA5E7BDA5DEB59C\
DEB59CDEAD94D69C84CE8C84CE947BC68C73BD846BBD8463B57B63BD8463BD8463
BD8463C69C73C68C73CE9473CE947BD6A584DEAD94D6A58CDEA58CD6A58CD6A584D6A584CE947B\
CE947BCE9473CE9473C69C73B5846BC69C73CE8C6BBD846BC68C73CE9473CE947B
CE947BCE947BD69C84C69C84D69C73C69C84C69C84D6A584D69C8CD6A584C69C84D6A584D69C84\
D6A584C69C84CE947BC69C84D6A58CC69C84D6A584C69C84C69C84D69C84D6A584
B58C739C6B52734A425231294A3131523931423139634A4252423942292142211842181094634A\
CE947BBD846BB5735AAD5A42BD5A42C66B52DEAD94F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD634A425A31295231294A2118422921422921\
4221184229214A2118422921422921422921422921422921392921312118523129
392921312121312121312118312118523129523129523129523931634231845242C69C84E7BDA5\
EFC6ADEFCEB5F7CEB5EFCEB5F7D6BDF7D6BDF7D6BDF7BDB5F7D6BDF7D6BDF7D6BD
F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7D6BDEFCEB5EFCEB5EFBDADAD847BBD846BAD7B6BB5846B\
AD7B6BAD7B6BAD7B6BBD846BAD847BAD8C84C6947B947B73AD7B6B9C7363A5735A
945A52A5735AA5735AA5735AA56B52945A4A945A52A56B52A56B52AD6B52B5735ABD846BBD846B\
CE947BE7AD9CE7AD9CE7BDA5EFBDADEFC6ADF7C6ADEFCEB5F7D6C6F7D6C6F7D6C6
F7D6BDEFCEB5F7CEB5F7D6BDEFCEB5EFC6ADEFBDA5EFBDA5EFC6ADEFC6ADE7BDA5EFBDADE7AD9C\
DEB59CDEAD94C69C84C69C84C68C73B58C73AD735AAD735AA5634AA5634AAD6B52
B5735AB57B63CE8C6BC69C73CE9473CE9473D6A584D6A58CD6A584DEA58CDEA58CD6A58CDEA58C\
D6A58CD6A584D6A584CE947BD6A584CE947BD6A584D6A584D6A584C69C84D69C73
D69C84CE947BD6A584C69C84D69C84D6A584D6A584C69C84D6A584D69C8CD6A584D6A58CC69C84\
C69C84D69C84CE947BC69C84D6A58CD6A584C69C84D69C84D6A584D6A58CC6947B
AD846B8C7363634A42523129523129422921524239634A424A3131312118422118422921B57B63\
CE8C6BD67363B5735ACE634AB55239C66B52DEA58CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD634A426339295231294A2118422921422118\
4229214221184229213929214229214A2118422921422921392921211010422921
422921312121312118312121392921422921523931634A42634A42734A397B6352C69C84DEB59C\
DEB5A5EFC6ADEFCEB5F7CEB5F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6EFCEB5EFBDADD6A58CDE9C8CD69C8C\
C69484D69C8CD69C8CAD8C84C6947BCE8C84D69C8CD69C8CC69484C69484AD847B
C68C73C6947BAD847BC6947BC6947BBD846BBD846BBD8463BD846BCE8C73CE947BD69C84DEA58C\
E7AD94EFBDADEFCEB5EFCEB5EFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6EFCEB5F7CEB5EFCEB5F7BDB5EFCEB5EFBDA5EFBDA5EFC6ADEFBDADE7BDA5EFBDADDEB59C\
DEB59CDEAD94D69C8CCE8C84C68C73BD846BA56B529C5A429452398C5A429C5A42
9C5A42A5634AB5735ABD846BC69C73CE9473CE947BCE947BD6A584D6A584DEA58CD6A584D6A584\
D6A58CDEA58CD6A58CDEA58CDE9C84D6A584D6A58CD6A584D6A58CD6A584D6A58C
C69C84D69C84C69C84D6A584D6A584D69C8CD69C8CD6A584C69C84D6A58CD6A58CD6A58CD69C8C\
D6A584C69C84D69C73C69C84D69C84D69C8CC69C84D6A584D69C8CC69C84C6947B
AD846B734A426342315231293929213929214A3131524239392921392921312118734A39C68C73\
BD8463BD8463B5735AAD5A42BD5A42CE7352C6947BD6C6BDF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFD6BDC673524A5A3129422921422921422921422921\
4229213929214A2118312118312118422921523129422921422921211010392921
422921312118312121312118312118392921523129634A4273524A734A4273524AB58C73DEAD94\
EFBDADEFC6ADEFCEB5F7CEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7BDB5CEB5B5F7BDB5\
E7AD9CDEB59CDEB5A5E7AD9CDEB59CEFB5A5CEB5B5EFBDADDEB5A5E7AD9CDEB5A5
CEB5ADD6A58CE7AD9CDEB59CDEB59CDEB5A5E7AD9CDEB59CE7AD9CEFBDA5EFBDADEFBDADEFBDAD\
EFCEB5EFBDADF7D6BDEFCEB5F7D6BDEFCEB5F7D6C6F7D6C6F7D6C6EFCEB5F7D6BD
EFCEB5F7BDB5EFCEB5F7D6BDEFCEB5F7C6ADEFBDA5EFBDADEFC6ADEFCEB5EFBDADEFBDA5E7BDA5\
E7AD9CDEB59CDEAD94D69C8CCE947BBD846BA5735A945A4A945A4A8C5A428C5A42
8452398C5A4294634AAD735AB57B63C69C73CE9473CE9473D6A584D6A584D6A58CDEA58CD6A58C\
DEAD94D6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A584D6A58CD6A58C
D6A58CD6A58CD6A58CD6A58CD69C84D6A58CD6A584D6A58CD6A58CD6A58CD6A58CD6A58CD6A58C\
D6A584D69C8CC69C84CE947BC69C84D6A58CD69C8CC69C84D6A584D6A584C6947B
8C7363734A395239314229213121215231294A31314229313929215242395231298C5A4ACE8C73\
C68C63BD8463B5735AB55239B55239BD8463CE8C6B947B73FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE846B5A6339315A3121312118422921422921\
4A2118392921422921422921422921523129422921422921422921291818312118
422921312118422921312121312121392921392921422921634A428463528C6352C6947BD6A58C\
DEB59CEFC6ADEFC6ADEFCEB5EFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5\
EFCEB5EFCEB5F7BDB5F7D6C6D6C6C6F7D6C6D6C6C6F7D6C6F7D6C6D6C6BDF7BDB5
F7BDB5F7BDB5D6C6BDEFCEB5F7BDB5F7D6BDD6C6C6F7D6BDF7BDB5D6C6C6F7D6C6EFCEB5EFCEB5\
F7BDB5EFCEB5F7D6BDEFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BD
EFCEB5F7C6ADEFCEB5F7D6BDF7CEB5EFC6ADEFBDADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5E7BDA5\
DEB5A5E7AD9CDEB59CD6A58CD69C8CCE947BAD735A9C6B5294634A845242845239
844A39844A39844A3994634AA5735AB57B63BD846BC68C73CE9473D6A584D6A58CD6A58CD6A58C\
DEAD94DEAD94DEAD94DEA58CDEA58CD6A58CD6A58CD6A58CD69C8CD6A584D6A58C
D6A58CD69C84D69C84D6A58CD6A58CD6A58CD6A58CD6A58CC69C84D6A58CD6A58CC69C84C69C84\
D6A58CD6A584D69C84C69C84D69C8CD6A58CD6A584C69C84CE947BD6A584B58C73
8C6352634A42523129422921392921392921422931392921312121634A425239319C6B52CE9473\
B57B63CE735AAD6B52AD5A42AD5A42C66B52BD846B73524ADED6E7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E78C736B6339316339314229214A2118523129\
4A2118392921422921312118312118422921422921422921422921312118211010
312118422921312118392921422921422921523129523931634A42734A397B6352B58C73BD9C8C\
DEB5A5E7BDA5EFC6ADEFBDA5EFCEB5F7CEB5EFCEB5F7D6BDF7CEB5F7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE
F7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEDECED6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6BDEFCEB5F7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6EFCEB5F7D6C6
EFCEB5EFC6ADF7BDB5EFCEB5EFC6ADEFBDA5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFBDADE7BDA5\
E7BDA5E7BDA5E7AD9CDEB59CE7BDA5DEB59CCE8C84BD846BAD735AA5735A945A4A
845239845242845242734A39734231734A398452428452428C5A4A94634ABD846BCE947BCE947B\
D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A584D6A584C69C84D6A584
D69C84C69C84D6A58CD6A584C69C84D69C84D6A584C69C84D6A58CC69C84CE947BCE947BC69C84\
CE8C84C69C84C69C84D6A58CD69C8CD69C8CD6A584C69C84D69C84CE947B9C7363
6B524A5231294229213929214229214229213929213121214A31315242395A31298C5A4AB57B63\
C68C73AD735AAD6B52A55239AD5A42B5735AA56B52523129AD9494F7E7DEF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF8C7B73734A395A42394229213929214A2118\
422921392921312118422921422118392921422921392921523129312118211010
211010422921422921291818422921422921523129523129634A42734A427B6352AD846BC69C84\
DEAD94E7BDA5EFC6ADEFC6ADEFC6ADF7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6BDF7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7DECEEFCEB5F7D6BDF7D6BD
EFCEB5F7CEB5EFCEB5F7C6ADEFCEB5EFBDA5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7BDA5\
EFBDADEFB5A5E7BDA5E7BDA5E7BDA5EFBDADD6A58CD6A58CCE947BBD846BAD735A
945A528C5A428C5A4A734A39734A39633931633929634231634231734A39845242A5735AB57B63\
C69C73D6A584D6A584D6A58CDEAD94D6A58CD6A58CD6A584D6A58CD6A584C69C84
D6A584D6A584C69C84D6A584C69C84D6A584CE947BC69C84CE947BB58C73C68C73B58C73B58C73\
C6947BCE947BD6A58CD69C8CD6A584D6A58CC69C84D69C84C69C84CE947BA5735A
734A395231293929214229214229214229213121215231295242395231295A3129734A39AD6B52\
CE8C6BBD846BAD6B52A55239AD5A42B57B63945A4A5231299C8C8CDECED6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFEFE7E7A5847B634231734A395A3129422921422921\
422118392921312118312118422921392921422921422921422921422921211010
2110103121184229214229213929215231295231295239315A4239734A4273524AAD846BC69484\
C69C84DEB59CE7BDA5EFCEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DE
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7D6BDEFCEB5F7CEB5EFCEB5F7BDB5EFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFBDADEFBDA5E7BDA5\
E7BDA5E7BDA5E7BDA5EFBDADE7BDA5EFBDADE7BDA5DEB5A5DEB5A5DEA58CCE8C84
C6947BAD735A9C6B528C5A4A845239734A39734A39633931633929633931634231734A39634231\
845239A5735AB58C73C6947BD6A58CD6A58CD6A584D6A584C6947BD6A584D6A584
D6A584D6A584CE947BCE947BCE947BC68C73C68C73C6947B9C7363B57B639C73639C6B52AD735A\
B58C73C6947BD6A58CD69C84C69C84D6A584D69C84C69C84C69C84C6947B8C5A4A
6342314229215231293929213929214229213121215239315239314A313142211873422994634A\
BD8463BD8463BD8463AD6B52B57B63B5846B8452396B524A8C736BB5A5A5DED6E7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7948484633931734A39634231523129523129\
392921422921422921392921422118422921422921422921422921422921291818
211010291818422921422921392921523129523129634231734A3973524A846352B58C73C69C84\
D6A58CDEAD94DEAD94EFBDA5EFCEB5F7CEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DE\
F7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6EFCEB5F7CEB5
F7BDB5EFCEB5F7BDB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDADEFBDA5\
EFBDADE7BDA5EFBDADEFBDADE7BDA5E7BDA5DEB5A5DEB5A5E7BDA5DEB5A5DEB59C
D6A58CD69C8CBD846B9C6B52945A52945A528C5A4A734A39734231634231633929633931634231\
6339297342318452398C5A4AB5846BB58C73C68C73C69C73C68C73C68C73C6947B
CE947BC6947BC6947BC6947BB58C73B5846BB57B639C73639C6B529C6B529C6B529C7363BD846B\
CE8C84D6A58CD69C84D69C84C69C84D69C8CD69C84D69C84CE947BC6947B7B6352
5A3129523129422921291818422921392921422921524239422931422921422118734229844A39\
AD5A42AD6B52B5735ABD8463B57B63A5735A734A39634A428C73639C8C8CEFD6CE
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9494634231734A39634231523129523931\
5231293929213929214A2118392921422921312118422921422921422921312118
2110102110103121183929215231294229214A3131523129634A427B63528463529C7363C6947B\
BD9C8CDEAD94DEB5A5EFC6ADEFCEB5EFCEB5F7D6BDF7CEB5F7CEB5F7D6BDF7D6C6
F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6BDEFCEB5F7CEB5EFCEB5
EFCEB5F7D6BDEFCEB5F7C6ADF7C6ADEFC6ADF7C6ADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5EFC6AD\
EFBDA5EFBDA5EFBDADE7BDA5E7BDA5EFBDADEFBDADEFBDADE7BDA5E7BDA5DEB5A5
DEAD94DEAD94D69C8CC6947BAD7B6BAD735AA5735A9C6B529C6B52845242734A39634231633931\
633931634231734A39734A398C5A4A9C6B529C6B52A5735AAD735AAD846BB57B63
BD846BB57B63A5735AA5735A9C6B529C6B529C6B529C6B529C6B529C6B529C7363BD846BC6947B\
D69C8CD6A58CC69C84C69C84D69C84D69C84C69C84C69C84CE947BB58C736B524A
5231295231293121183929215231293121185231294A31314A31315231294229215A31217B3121\
9C5A42A55239A552399C5A429452398452425A42396B524A8C736BAD9CA5E7DEE7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9494634A42634231734A42634231523931\
4229214229213121184229214A2118392921422921422921422921422921422921
312118211010291818392921422921523129634231634A42634A42734A3984635294736BC6947B\
C69484D6A58CDEB5A5EFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECE
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7D6BDF7D6C6F7D6C6F7D6BDF7DECEF7D6C6EFCEB5F7D6BDF7D6C6EFCEB5EFCEB5
F7D6BDEFCEB5F7D6BDEFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFC6AD\
E7BDA5EFBDADEFBDADEFC6ADEFBDADEFBDADEFC6ADEFBDADE7BDA5E7BDA5E7B59C
DEB5A5DEB59CDEAD94D6A58CD69C8CC6947BAD846BAD7B6B9C7363A5735A8C5A4A845242734A39\
734231634231634231634231734A398452428452428C5A4A8C5A4A9C6B52A57352
846B5A9C6B528C5A4A8C63529C6B529C6B52A5735A945A529C6B52AD735AB5846BCE947BD69C8C\
C69C84D6A58CD69C8CD69C84D69C8CC69C84CE947BCE947BC69C73B58C73734A39
5231293121183121184229214229213121214229313929214A3131392921422118522118522118\
7342298C31297342297B31217342316339296342316B524A846B5AB5A5A5F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD734A39634A42734A42734A39523931\
4A31314A2118312118392921392921523129422921392921422921422921422921
3121182110102918183121183121215231295231295A4239734A427B63527B635294736BB58C73\
C69C84D6A58CDEB59CE7BDA5EFCEB5F7BDB5F7D6BDF7D6BDF7D6C6F7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7BDB5F7D6BD
F7D6BDEFCEB5F7D6BDF7C6ADEFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5EFBDAD\
EFC6ADEFC6ADEFC6ADEFBDADEFC6ADEFBDADE7BDA5EFBDA5E7BDA5E7BDA5E7BDA5
E7B59CE7AD9CDEB59CDEAD94D6A58CD69C8CD69C8CC6947BB58C73B57B639C73639C6B528C5A4A\
845242845242734231734231734A39734A398452428452428C5A4A8C5A4A8C5A4A
9C6B529C6B529C6B528C5A4A9C6B52846B5A9C6B529C7363AD735ABD846BCE8C73C69C84C69C84\
D69C8CD69C84D69C84D69C84C69C84CE947BD69C84CE947BC68C73AD846B634A42
422921312118392921422921392921422921392921422931422921392921312118421810631810\
7B29187B29187321105A3121633929633929734A3973524A948484EFE7E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD734A39634231734A39734A42634231\
523129523129422921422921523129523129523129422921422921422921523129
392921291818211010291818523129523129523129634231634A42734A427B63529C7363B58C73\
AD8C84D6A584DEB59CE7B59CEFBDA5F7CEB5EFCEB5F7D6BDF7CEB5F7D6C6F7D6BD
F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFCEB5F7D6BD
EFCEB5F7CEB5EFCEB5EFCEB5EFC6ADEFC6ADF7C6ADEFC6ADEFC6ADEFC6ADEFBDADEFBDA5EFC6AD\
EFBDADEFBDADEFBDADEFC6ADEFC6ADEFC6ADEFBDADE7BDA5E7BDA5E7B59CE7BDA5
E7BDA5DEB5A5DEB59CDEB59CDEB59CD69C8CD6A58CD69C8CC69C84C6947BBD846BB5846B9C7363\
9C7363945A52845242734A39634231734A39734A39845239734A42845239845242
8452428C5A4A8452428C5A4A945A529C6B52AD735AAD735ABD846BCE947BC69C84D69C84D69C8C\
D69C8CC69C84C69C84C69C84D69C84CE947BC69C84C68C73B58C73AD846B634231
422921392921422921422921392921422931422921523129392921422921312118312118420800\
4218106318105221186339295A31295A4239634A426B524AE7DEE7FFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7B5A5A573524A734A39734A39734A396B524A\
5A3121523931523931392921523129422921422921523129422921523129422921
5239315A42394A3131392921523129523931523129523931734A39734A42846352A5735AB58C73\
C69C84D6A584D6A58CE7BDA5E7B59CEFC6ADF7CEB5F7D6BDEFCEB5F7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7BDB5F7D6BDF7D6BD
EFCEB5EFCEB5F7D6BDEFCEB5F7C6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADEFBDADEFBDADEFBDADEFBDADEFBDADE7BDA5EFBDADE7BDA5E7AD9C
E7BDA5E7AD9CE7B59CE7AD9CDEB59CDEB59CDEAD94D69C8CD6A58CC69C84C69484C6947BC6947B\
C6947BB58C73B5846BB57B639C6B529C6B5294634A8C5A42845242845242734A39
844A39945A4A9C6B52A56B52AD735ABD846BBD846BCE947BC69C84D69C84C69C84D69C8CD69C84\
C69C84D69C8CC69C84D69C84CE947BCE947BC6947BC68C73AD846B8C6352523129
5231294229214229213929215231294229315231294A3131312121392921422921312118312118\
312118422921422921422921523931523931634231735A52D6C6D6E7DEE7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7AD9C8C73524A634A42734A39734A4273524A\
5239315239314A3131392921523129523129422921422921422921422921523129
4229215239314A31315231294A31315242395A42395A4239634A42734A42846352A5735AAD846B\
B58C73BD9C8CD6A58CDEB59CEFC6ADEFBDA5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7DECEF7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5
F7D6BDEFCEB5F7C6ADEFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5\
EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFC6ADE7BDA5EFBDADE7BDA5EFB5A5E7BDA5
E7BDA5DEB5A5E7AD9CE7AD9CDEB59CDEB59CDEB59CDEAD94D6A58CD69C8CD6A58CD69C84C69C84\
D69C8CCE947BC68C73B58C73BD846BB57B639C7363A5735A9C6B529C6B529C6B52
A5735AAD735AAD735AB57B63C68C73C6947BC69C84C69C84C69C84CE947BD69C84D69C84CE8C84\
D69C73C69C84D69C84C69C84CE947BCE947BC68C73B58C73AD846B7B6352523129
5231294229214229214229214229213929215231293121213929214A3131392921211010312118\
3929215231294229215231295239315231295A423963524A8C73639C8C8CD6C6BD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7D6C6CE8C7363846352734A396B524A734A4273524A\
6B524A5239315239315231294229215231294229214229214229215231295A4239
523931523129523129523129523129523129634231523931734A396B524A7B6352846B5A9C7363\
B5846BC69C84D6A58CDEB59CE7BDA5EFC6ADF7CEB5F7D6BDEFCEB5F7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7E7DE\
F7E7DEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECE\
F7DECEF7D6BDF7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6BDEFCEB5F7D6BDF7BDB5
EFCEB5F7CEB5EFBDA5EFC6ADF7CEB5EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDADEFBDA5EFBDA5\
EFBDADEFBDADEFC6ADEFC6ADEFC6ADEFBDA5EFBDADEFC6ADE7BDA5E7BDA5E7BDA5
E7BDA5E7BDA5DEB5A5DEB59CE7AD9CE7AD9CDEB59CDEAD94DEAD94DEAD94D6A58CD69C8CD6A58C\
D6A58CD69C8CC69C84CE947BC6947BB58C73C68C73BD846BBD846BBD846BBD846B
BD846BBD846BC68C73CE947BCE8C84D6A584D69C8CC69C84D69C84CE8C84D69C8CC69C84D69C84\
D69C84CE8C84C69C84D69C73C69C84CE947BB58C73BD846BA5735A734A42523129
5231294229214229214A31314229213929213929213121214A31314A3131312121312118291818\
4229213929213121185231294A31315231294A3131523931634A4273524AAD9C8C
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5B5846B5A734A39734A396B524A634231734A39\
6B524A6342316342315239315231295231295231294229215231294229214A2118
4229215231294229214229214229215231295231295239316342316B524A734A428C63529C7363\
B5846BC6947BD6A58CDEAD94DEB59CEFC6ADEFC6ADF7CEB5F7D6BDF7D6BDF7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DE\
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7DECEF7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6C6
EFCEB5F7BDB5EFC6ADF7CEB5EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFC6ADEFC6ADEFC6ADEFBDAD\
EFC6ADEFCEB5EFC6ADEFBDA5EFBDADEFC6ADEFC6ADEFBDADE7B59CE7B59CE7BDA5
E7B59CE7B59CE7B59CDEB59CDEB59CDEB59CDEB59CDEB59CDEAD94D6A58CD6A58CD6A58CD6A58C\
D69C8CD69C8CD69C8CD69C8CD69C8CCE947BCE947BCE947BCE947BCE8C84CE947B
CE8C73CE947BC69C84D69C8CC69C84D6A58CD69C84D69C84C69C84D69C84D69C84D69C84CE8C84\
C69C84D69C73D68C7BC69C84CE8C84C68C73B58C73AD846B9C6B52734A39523129
5231294229214229214229213929214229213929213929314A3131392921392921312121312121\
3929213121183929214229215231295231295231293929216B524A6B524A9C8C8C
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C7B6352734A39634A42734A39634231634A42\
634A425239316339315A4239523931523129523931422921422921392921312118
4221185231295A31295231295231295231295231295A3129523931634231734A427B63528C6352\
9C7363B5846BD6A584D6A58CDEAD94EFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7DECEF7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDEFCEB5EFCEB5F7D6BD
EFCEB5EFCEB5EFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFBDADEFBDADEFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFC6ADEFBDADE7B59CE7BDA5E7BDA5
E7BDA5E7B59CE7BDA5E7BDA5DEB59CE7AD9CDEB59CE7AD9CDEAD94DEAD94DE9C8CDEAD94D69C8C\
DEB59CD6A58CD6A58CD69C8CD6A58CD69C8CD6A58CD69C8CD6A58CD69C84C69C84
C69C84D69C8CD69C84D6A58CD69C84C69C84D69C8CC69C84D69C84D69C84C69C84D69C8CCE947B\
D69C84D68C7BD69C84C69C84C6947BC68C73B57B63A5735A846352634231523129
523129422921392921392921392921422921312121523129422931392921312121312121312118\
3121213929214A3131422921523129422921312118422921634A42634A428C7363
EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C8C8C73524A734A39734A42734A396B524A634231\
634A425239315239315239315239314A3131634231422921422921422921422921
4A2118422921523931523931523129422921422921523129634231634231634231846352846352\
8C7363AD846BC6947BD6A58CD6A58CEFBDA5EFC6ADEFCEB5F7D6BDF7D6BDF7D6C6
F7D6BDF7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DE\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7E7F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5F7D6C6F7D6C6F7D6BDF7D6BDF7CEB5
F7CEB5EFC6ADF7CEB5EFBDA5EFBDA5EFC6ADEFC6ADEFCEB5EFC6ADEFBDADEFBDA5EFC6ADEFC6AD\
EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7BDA5EFBDADEFBDA5E7B59CE7BDA5E7BDA5
E7B59CEFBDADE7BDA5DEB59CE7AD94DEB59CDEB59CDEAD94DEAD94DEB59CDEB59CDEAD94D6A58C\
DEAD94DEB59CD6A58CDEAD94DEB59CDEAD94D6A58CD6A58CD69C84D6A58CD69C8C
D6A58CD6A58CD69C84C69C84D69C84D69C84D6A584D69C84D69C8CD69C8CD69C84D69C84D69C84\
C69C84D69C84C69C84CE947BC68C73B58C73AD846B94634A734A42523931523129
523129523129392921422921422921312121392921422931523129312121392921312118392921\
312121422921422921422921422921312118291818422921634A426B524A63524A
C6ADADFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7A5847B7B63526B524A6B524A634A42734A39634A42\
6B524A6342315239316342315A4239523129422921422921523129523129312118
4229214229214229214229214229214229214229214221184229216342315A4239734A42846352\
8C6352AD846BB58C73D6A584DEAD94E7BDA5EFC6ADEFCEB5F7CEB5F7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7BDB5EFCEB5F7D6BDEFCEB5F7BDB5
EFCEB5EFC6ADEFC6ADEFBDADEFBDA5EFBDA5EFC6ADEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFC6AD\
EFBDA5EFBDA5EFBDA5E7BDA5EFBDA5EFBDADEFBDA5E7BDA5E7BDA5EFBDA5E7BDA5
E7BDA5E7BDA5E7BDA5E7B59CDEB59CDEB59CE7AD9CDEB59CDEAD94DEAD94DEAD94DEB59CDEAD94\
D6A58CD6A58CDEAD94DEAD94D6A58CD6A58CD6A58CD6A58CD69C8CD6A58CD6A58C
D69C84D69C84C69C84D69C84D6A58CC69C84D69C84D69C84D69C84C69C84D69C84C69C84D69C84\
D69C84C69C84CE947BCE947BC6947BAD846B9C6B52846352634231634231523129
5231293929213929214229213121213929214229314A3131392921523129312121312118312118\
3929214A2118523129422921392921211010211010523129634A426B524A734A39
AD9494F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7846B5A7B6352634231734A426B524A73524A73524A\
634A42634A425239315239315A4239633931523931523129392921422921392921
4229214229214229213121184229214229214229214229215231295231296342316B524A734A39\
7B63528C63529C7363B58C73CE947BE7BDA5E7B59CEFC6ADEFC6ADF7CEB5F7D6BD
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECE\
F7DECEF7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5EFCEB5F7CEB5
EFC6ADEFC6ADEFC6ADEFBDADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFC6ADEFBDADEFC6AD\
EFBDA5EFBDA5EFBDADEFBDA5E7BDA5EFB5A5E7BDA5E7B59CEFBDA5E7B59CE7BDA5
E7BDA5E7B59CE7BDA5DEAD94E7AD9CDEB59CE7B59CE7AD9CDEB59CE7AD9CDEAD94DEAD94DEB59C\
DEAD94DEAD94DEB59CDEAD94DEA58CD6A58CD6A58CD6A58CD6A58CD69C8CD6A58C
D69C84D69C8CD69C8CD6A58CD6A58CD69C8CD6A58CD69C8CD69C8CD69C84C69C84D69C84D69C84\
D69C84C69C84CE947BB58C73AD846BA5735A846352734A39523931523129523129
422921422921392921392921312121392921523931392921291818291818312121312118312121\
39292139292131211842292131211829181831211852393152312963423173524A
AD9C8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7846B5A7B63525A3129734A39634231634A42734A42\
6B524A6B524A5A42395A42395A42395239315239315231294A21184229214A2118
3121184229215231295A3121523129523129422921422921523931634231634231734A42734A42\
734A398452399C6B52AD846BB58C73DEAD94E7B59CEFBDADEFC6ADEFCEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7E7DEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7E7F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7BDB5F7D6BDF7C6ADEFC6AD
F7C6ADEFC6ADEFCEB5EFBDA5EFBDADEFBDA5E7B59CEFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDAD\
EFBDA5EFBDA5EFC6ADE7BDA5EFBDA5E7BDA5EFBDADE7BDA5E7B59CEFBDA5E7B59C
E7B59CE7BDA5E7BDA5DEB59CDEAD94DEAD94DEAD94DEB59CDEAD94DEAD94DEAD94DEAD94DEB59C\
DEB59CD6A58CDEAD94DEA58CD6A58CD6A58CD6A58CD6A58CD6A584D6A58CD69C8C
D69C84D6A58CD6A58CD69C84D6A58CD69C84D69C84D69C84D69C84D69C84D69C84CE8C84D69C84\
D69C84C69C84C6947BB5846B9C7363A5735A7B6352734A39523931523931422921
3929213121183121213121215231294A3131392921291818291818392921312118291818392921\
42292131212139292131211831211829181842292152423952312952393173524A
9C8C8CF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F773524A7B6352634231634A42634A426342316B524A\
734A39634A42634A425239315A42395A4239523931523129422921422921422921
312118422118422921422921422921523129523129523129422921523129634231734A42734A39\
7B6352734A42846352A57352B57B63D6A584E7B594EFC6ADEFC6ADEFCEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDEFCEB5F7D6BDEFCEB5EFC6ADEFCEB5
EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5\
EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59CEFBDA5E7BDA5E7BDA5E7BDA5
E7B59CE7B59CE7B59CE7B59CDEAD94E7AD94DEB59CE7AD94DEAD94DEAD94DEAD94DEAD94DEB59C\
DEAD94DEA58CD6A58CD6A58CD6A58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A584
D6A58CD6A58CD6A58CD6A58CC69C84D69C8CC69C84D69C84C69C84D69C84C69C84D69C84C69C84\
C69C84CE947BBD846BAD846BA5735A7B6352734A395A4239523931523129312118
3121183929213121213929214A3131634231291818291818312121392921291818312121312118\
39292131211839292121101021101031211842292142292152312963423173524A
A5847BDECED6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F75A4239734A39634A426B524A734A39634A42734A42\
634A42634A426B524A634231523931523931523931422921422921422921422921
422921312118422118422118422921422921523129422921523129523129523931734A427B6352\
734A42846352845239845242A5735AD6A584DEAD94EFC6ADEFCEB5EFCEB5F7CEB5
EFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECE\
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7BDB5EFCEB5
F7BDB5EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5\
E7BDA5EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5EFBDADE7BDA5E7B59CE7BDA5E7AD9C
E7B59CE7B59CE7B59CE7AD94E7AD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEB59CD6A58CDEA58CDEAD94D6A58CD6A58CDEAD94D6A58CDEA58CD6A58CD69C84
D69C84D6A58CD6A58CD69C84D69C8CD69C84C69C84D69C84D69C84D69C84D69C84D69C84CE947B\
CE947BC6947BB5846B9C7363A5735A7B6352734A39634231523129392921392921
3929213121183121215231294A3131392921291818291818312121291818312121312118291818\
3121183121183121212110103121183121184229215231294229215A423973524A
94736BCEBDC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7634A42734A39634A42734A396B524A6342316B524A\
634A42734A396B524A634A425239315A42395A4239523129422921422921422921
5231293121183121184229214A21184229214229215231295231295231295231296B524A73524A\
8452428463528463528452429C6B52C6947BD6A58CDEAD94EFC6ADF7CEB5EFCEB5
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7BDB5EFCEB5EFCEB5EFC6AD
EFCEB5EFBDA5EFBDADEFBDA5EFBDA5EFC6ADEFBDA5E7BDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5\
EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7BDA5E7BDA5E7B59CE7B59CE7B59CE7B59C
DEAD94E7AD94E7B594DEB59CDEB59CE7AD94DEB59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEA58CDEAD94D6A58CD6A58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A584D69C8C
D6A58CD6A584D6A58CC69C84D6A584C69C84D69C84D69C8CD6A58CC69C84D69C84C69C84CE947B\
CE947BB58C73AD846BA5735A846352734A39634A42523129422921392921392921
3929213929215231294A3131392921211010312121312121312121312118312118291818312118\
2918183121183121183121182110103929213929215231294229216342316B524A
8C7363D6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E78C736B735A52634231634A426B524A6342316B524A\
6B524A634A426B524A634A425A4239634231634A42523129422921523129422921
5231294229214221184229214229214A2118422921523129523129523129523129634A42845242\
7B635284524284635284524294634AC68C73D6A584DEAD94E7BDA5EFCEB5F7D6BD
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECE\
F7DECEF7DECEEFCEB5F7D6BDF7D6C6EFCEB5F7D6BDF7D6BDF7D6BDF7C6ADF7C6AD
EFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5EFBDA5EFBDAD\
EFBDA5E7B59CEFBDA5EFBDADE7BDA5EFBDADE7B59CE7B594E7B59CDEA58CE7B59C
E7B59CDEAD94DEB59CE7AD94E7AD94DEB59CE7AD94DEAD94DEAD94DEAD94DEAD94DEAD94D6A58C\
DEAD94DEAD94D6A58CD6A58CD6A58CD6A58CD6A58CDE9C84D6A58CD6A58CD6A58C
D6A584D6A58CD69C8CD6A584D69C8CD69C84C69C84D6A584D69C84D69C84C69C84CE947BC6947B\
C68C73B5846B9C73639C6B52846352734A42523931523129422921422921392921
3929215231294A3131523129291818291818312118291818312118312121291818312118291818\
2110103121183121182918183121183929213929215231295231295A3129734A39
8C7363DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7EFE7E77B635273524A734A396342316B524A734A39634A42\
634A426B524A6B524A634A425A4239523931634A42523931523129422921523129
5231294229213121183121184229215231294229214229215239315239315239316342316B524A\
734A427B63528C63528463528C5A4ABD846BCE947BDEAD94E7BDA5EFC6ADEFCEB5
F7CEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFC6AD
EFC6ADEFC6ADEFBDA5EFBDA5EFBDA5E7BDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5\
EFBDA5E7B594EFBDA5E7BDA5EFBDA5EFB5A5E7BDA5E7B59CE7B59CE7B59CE7BDA5
E7B59CE7AD9CDEAD94DEB59CDEAD94E7AD9CDEAD94DEAD94DEAD94DEA58CDEAD94D6A58CDEAD94\
DEA58CDEA58CD6A58CDEAD94D6A58CDEA58CD6A58CD6A58CD6A58CDEA58CD6A58C
D6A58CD6A58CD69C84D69C8CC69C84D69C84C69C84D69C8CD69C84C69C84CE947BC6947BC6947B\
C68C73B5846BA5735A8C63527B6352634231523931523129422921392921422921
5239315A4239523129291818291818291818291818312121312121312121291818291818211010\
3121182918183121183121213121183929214229214229215231295239316B524A
947B73E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7D6C6D66B524A6B524A6342315A42396B524A634A42734A39\
734A396B524A634A4273524A634A425A42396342315A4239523129523129523129
4229215231295A31293121184229214229214229215231293929214229215239315A3129633929\
6B524A8452428463529C6B52945A52B5846BC68C73DEAD94E7B59CE7BDA5EFC6AD
EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7DECEF7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7CEB5EFCEB5EFCEB5
EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5E7B59C\
E7BDA5EFBDA5E7B59CE7BDA5EFBDA5E7B59CE7B59CE7BDA5E7BDA5E7B59CDEB59C
E7AD9CE7AD94DEAD94DEB59CDEAD94E7AD94DEAD94DEAD94DEAD94DEA58CDEA58CDEA58CDEAD94\
D6A58CDEA58CD6A58CD6A58CD6A58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58C
D6A584D6A58CD6A58CD69C84D69C84C69C84D69C84C69C84C69C84C69C84C6947BC68C73C68C73\
B5846BAD846B8C5A4A7B6352634A42634231523931523931523931634231523931
422921312118312118312118312121312121312121312118312118291818291818291818291818\
312118211010312118392921312118392921422921422921523129634231735A52
CEB5BDFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7DECED6734A395A4239634231634A42734A396B524A634A42\
634A42634A42634A426B524A6B524A5A42395A42395A4239523931523129523129
5231294229215231294229214229214229215231295231295231294229214229215A3129634231\
734A39734A428C5A4A846B5A8C6352BD846BC68C73D6A584DEAD94E7BDA5EFC6AD
EFC6ADF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECE\
F7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEEFCEB5F7D6BDF7BDB5F7D6BDF7D6BDEFCEB5F7CEB5EFC6AD
EFBDADEFC6ADEFBDA5E7B59CEFBDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5EFBDA5EFBDA5EFBDA5\
E7BDA5E7B59CEFBDA5EFB5A5E7B59CE7B59CE7B59CE7BDA5E7BDA5E7B59CE7B59C
DEAD94E7AD9CE7AD94E7AD94DEAD94DEAD94DEAD94DEA58CDEA58CDEAD94D6A58CDEAD94DEAD94\
D6A58CDEA58CD6A58CD6A58CD6A58CD6A584DEA58CDEA58CD69C84D69C84D69C84
D6A58CD69C84D69C84C69C84D69C84C69C84D69C84C69C84CE947BC6947BCE9473C68C73B58C73\
AD846B9C7363846352734A42734A39634A425A4239634231523931523129422921
392921312121392921312121312121422921312118312121291818291818291818291818211010\
211010291818392921312118312118392921422921422118523129634231A5847B
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7C6ADBD734A39634A425239315A4239634A42734A42634A42\
734A42734A39734A396B524A6B524A634A42634A425A4239633931523931523129
4229214229215231295231293121184229215231294229215231295A3129422921634A42523931\
634231845242846352A5735A9C6B52BD846BBD846BCE947BD6A584E7B59CEFC6AD
EFCEB5EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DE
F7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5EFCEB5EFCEB5F7BDB5EFC6ADEFC6AD
F7C6ADEFBDADEFBDA5EFBDA5EFB5A5E7B59CEFBDA5E7B59CE7B59CEFBDA5E7B59CE7B59CEFBDA5\
EFBDA5EFBDA5E7BDA5E7B59CE7B59CE7B59CE7BDA5E7B59CE7B59CE7AD94DEAD94
E7AD9CDEB59CDEAD94DEAD94DEAD94E7AD9CDEAD94DEA58CDEA58CDEAD94DEA58CD6A58CDEA58C\
DEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD69C8CD6A58CD6A584D6A584
D69C84D6A584D6A58CD69C8CD6A584D69C84C69C84CE947BC6947BC68C73B58C73BD846BB5846B\
A5735A9C73637B6352734A42734A39634231523931634231523931523931312121
312121312121312121312121392921312121312118291818211010291818291818181010291818\
3121183121183121183121182918184229213121182110105239316B524AAD9494
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5B56B524A734A426B524A634231734A39634A426B524A\
73524A6B524A634A426B524A73524A6B524A634A42634A425A42395A3129523129
523129422921523129523931312118523129523129422921523129523931523931634A42734A39\
634A428452428463529C6B52846B5AAD846BC68C73CE8C6BD69C84E7B59CE7B59C
EFC6ADEFCEB5F7D6BDF7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7DECE\
F7DECEF7D6C6F7D6BDF7D6C6EFCEB5F7D6BDF7BDB5F7D6BDEFCEB5EFBDA5EFBDA5
EFC6ADEFC6ADEFBDA5EFBDA5E7BDA5E7BDA5E7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CEFB5A5\
E7B59CEFBDA5E7B59CE7B59CE7B59CE7AD94E7B59CE7AD94E7AD9CDEAD94E7AD94
E7AD9CDEB59CE7AD9CDE9C8CDEAD94DEA58CDEAD94DEAD94DEAD94DEA58CD6A58CDEA58CDEA58C\
D6A58CD6A58CD6A584D6A58CD6A58CD6A58CD6A584D6A58CD6A584D69C8CD69C84
CE947BD69C8CC69C84D6A58CD69C84C69C84C69C84CE947BC68C73B58C73C68C73B5846B9C7363\
AD846B8C73637B6352734A396342315A42395239315231294A3131422921312121
312118291818312118392921312121312118291818181010291818312121211010211010312118\
312121291818312118312121392921392921312118392921523931735A52CEB5BD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFE7DEEFCEBDC66B524A6B524A6B524A523931634A42634A4273524A\
73524A6B524A734A396B524A6B524A6B524A634A425A4239634A425239314A3131
5231294229215231295231294229215231294229215231295239315A3129523931523931734A39\
6B524A734A428C6352846B5A9C6B52B5846BB58C73C68C73D69C73DEAD94E7B59C
EFC6ADEFCEB5F7CEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7DECEF7E7DEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7D6C6F7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5EFC6ADF7C6ADF7C6ADEFC6AD
EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5EFBDA5EFBDA5E7B59CE7B59C\
E7B59CE7B59CEFBDA5E7B59CE7AD94E7BDA5E7AD9CDEB59CE7AD94DEB59CE7AD94
DEAD94E7AD94DEB59CDEAD94DEAD94DEA58CDEAD94DEA58CD69C8CD6A58CD6A58CD6A584D6A58C\
DEA58CD6A58CD6A58CD69C8CD6A58CD69C84D6A58CD6A58CD69C8CD6A58CD69C84
D69C8CD69C84D6A584C69C84D6A584CE947BCE947BC6947BC68C73B58C73B5846BAD846BAD846B\
A5735AA5735A734A39634A42634231523931523129523931422921312121312121
312118312121312121291818312118312121291818291818291818291818211010312121392921\
29181829181839292139292131211831211831211842292152312973524AC6ADAD
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFD6C6CE734A42734A39634A42523931634A42734A396B524A\
6B524A734A42634A426B524A6B524A735A526B524A5239315A42395A4239523129
5231295231294229215231295231295231295231295239315239315A31296342315A3129634A42\
734A4273524A8C63528C6352846B5AB57B63BD846BC68C73C69C84DEA58CE7B594
EFBDA5EFC6ADEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE\
F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECE
F7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5F7C6ADEFC6ADEFC6ADEFC6ADEFBDA5
EFC6ADEFBDA5EFBDA5EFBDA5E7BDA5EFBDA5E7B59CEFBDA5E7B59CEFBDA5E7BDA5EFBDA5E7B59C\
E7BDA5EFBDA5E7B59CE7B59CE7B59CE7B59CE7AD94DEB59CE7AD9CE7AD94DEAD94
DEA58CDE9C8CDEAD94E7AD94DEAD94DEA58CDEA58CDEAD94DEAD94D6A58CDEA58CD69C8CD69C8C\
DEA58CD6A58CD69C84D69C84D6A584D69C84D6A58CD6A58CD6A58CD69C84D69C84
D6A584C69C84D69C84D69C84C69C84CE947BC69C84C6947BB58C73B5846BAD846BAD846B9C7363\
A5735A8C5A4A634A426342315231295231294A3131422921392921392921312121
392931392921312121312121312121312118291818312121291818211010312121392921291818\
29181831211831212131211831212131211839292152393152393173524AAD9494
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7D6C6CE734A396B524A634A425239316342315A42396B524A\
7B635A6B524A6B524A734A3963524A734A39735A52523931634A425A4239523129
4229215231294229215231295A31295239315231295231295239315239315239315239315A4239\
734A397B6352846352945A52A5735AAD846BBD846BC68C73D69C73D6A58CDEB59C
E7B59CEFBDA5F7C6ADF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7E7DE\
F7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7DECEF7D6BDF7D6C6F7D6BDEFCEB5F7C6ADEFCEB5EFC6ADF7BDB5EFC6ADEFBDA5
EFC6ADEFBDA5EFC6ADEFBDA5EFBDA5EFBDA5E7B59CE7B59CE7B59CEFB5A5E7B59CEFBDA5EFBDA5\
EFBDA5E7B59CE7B59CEFB5A5E7B59CE7BDA5E7AD9CE7AD9CE7AD94DEB59CDEAD94
E7AD94DEAD94E7AD94DEAD94DEAD94DE9C8CDEA58CDEA58CDEA58CD6A58CD69C84D6A58CDEA58C\
D69C84D6A584D6A58CD69C84D6A58CD69C84D6A584D69C84D69C84D69C84D6A584
D69C8CD69C84C69C84D69C84C69C84C69C84CE947BC68C73B58C73BD846BB58C73AD846B8C7363\
9C6B527B63526B524A634231523931523931523129392921422921392921392931
422921392921312121392921392931312121312121291818291818392921392921392921291818\
3121212918183121213121183929213929215231294229215A423973524AC6ADA5
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7EFE7E7CEB5B5634A427B635A634A42523931634231634A42634A42\
6B524A6B524A6B524A6B524A6B524A6B524A73524A634A42634A42634A42523931
4229214229214229215231295239315239315231295231295239315239316342315A42395A4239\
634A42734A398463529C6B52846B5AB57B63B5846BC68C73CE947BD6A58CE7B59C
E7BDA5EFBDA5EFCEB5F7CEB5F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7DECEF7E7DEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7E7DE
F7E7DEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7DECE\
F7D6C6F7D6C6F7D6C6EFCEB5EFC6ADF7BDB5EFC6ADF7CEB5EFCEB5EFBDA5EFC6AD
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B594EFBDA5E7B59CEFBDA5E7BDA5E7BDA5E7B59CE7B59C\
E7B59CE7B594E7B59CE7B59CE7B59CE7B59CDEB5A5E7AD94DEAD94DEB59CE7AD9C
DEB59CDEB59CDEAD94DEAD94DEAD94DEA58CDEA58CD69C8CD69C8CDEA58CD69C8CD69C84D6A58C\
D69C84D6A58CD69C8CD6A58CD6A584D69C8CD69C84D6A58CD69C84D69C84C69C84
D69C84D69C84C69C84D69C8CC69C84CE947BC6947BC6947BB5846BAD846BA5735AA5735AA5735A\
846352734A39634231634231523931523129523129523129392921392921392921
392921392921523129523129392921392921422921422931392921392921312121312121312118\
2918183121213121213929214229214229213929214229215239318C6352D6C6CE
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFDECED6846B5A73524A634A42634231523129634231634A42\
735A5273524A6B524A6B524A73524A6B524A634A42634A42634A42734A39523931
5231294229214229215231295239316339315239315231295231295239315239316B524A734A42\
6B524A734A428463528C7363945A52A5735AAD846BB57B63C68C73CE947BDEAD94
E7B59CE7BDA5EFBDADF7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7DECE\
F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6EFCEB5F7CEB5F7CEB5F7CEB5EFC6ADEFCEB5EFC6ADEFC6ADEFC6ADEFBDA5
EFBDA5EFBDA5E7B59CE7B594E7AD94E7B59CE7B594E7AD94E7B594E7B594E7B59CE7B59CE7B594\
E7B59CEFB5A5E7B59CE7B59CE7AD9CE7B59CE7AD9CDEAD94DEAD94DEB59CE7AD94
DEAD94DEAD94E7AD94DEAD94DEAD94DEA58CDEA58CDEA58CD69C8CDE9C8CD6A58CD69C8CD6A58C\
D69C8CD69C8CD69C84D6A584D6A584C69C84D69C84D6A584C69C84D69C84D6A584
D69C84D69C84C69C84CE947BC6947BC68C73CE8C6BB57B63AD735A9C7363A5735A94634A7B6352\
8452426B524A6342316342314A3131523129523129523129422931422921392921
523129523129422931392921523129422931392921392921392921312121312121312121392921\
523129392921392921312118211010291818392921523129846B5ADECED6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7DECED673524A734A426B524A5A42395A3129523931634A42\
634A4273524A735A526B524A73524A735A52634A426B524A523931634A42634A42
5A31294229214229215231295231295A42395239316339315231295231295239315A4239734A42\
73524A7B6352846352A5735A846B5AA5735AA5735AB57B63BD846BCE9473D6A584
DEAD94E7B59CEFC6ADEFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6\
F7D6BDF7D6C6F7D6BDEFCEB5F7C6ADEFC6ADF7C6ADEFC6ADF7C6ADF7C6ADEFBDA5
EFBDA5E7B59CE7B59CE7B594E7B59CE7B594E7B59CE7B59CE7B59CE7B59CE7B59CEFBDA5E7AD9C\
EFBDA5E7B59CE7B59CE7B59CE7AD9CE7B59CDEB59CE7AD9CDEAD94E7AD9CDEAD94
E7AD94DEAD94DEB59CDEAD94DEAD94DEAD94D69C8CD69C84DEA58CD6A58CDE9C8CD6A58CD6A58C\
D6A58CD6A58CD6A58CC69C84D6A58CD69C84D6A584D69C8CD69C84D69C84C69C84
D69C84C69C84CE947BC6947BC6947BB58C73B58C73B5846BAD846B9C736394634A8452427B6352\
734A39734A396342315A31295239315231295231294229315231294A3131422931
4A3131523931523129312121312121291818291818312121392921392921392921312121312121\
211010291818312118291818211010392921523129422921A58484EFE7E7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7EFE7E7D6C6CE73524A634A42634231634A425A4239523931634A42\
734A3973524A7B635A6B524A6B524A735A526B524A6B524A5A4239634A42634A42
5A42394229214229214229215231296342315A42395239315239315239315239315A4239734A39\
73524A734A42734A428C6352846B5A94634AA5735AAD846BB57B63C68C73D6A584
DEA58CDEB59CEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7E7DE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6BDEFCEB5EFCEB5F7BDB5F7CEB5EFC6ADEFBDA5EFC6ADEFC6ADEFBDA5EFBDA5
EFBDA5E7B594E7B594E7B59CE7B59CE7B59CE7B59CEFBDA5E7B594E7B59CE7B59CE7B59CE7AD9C\
E7B59CE7B59CE7B59CE7B59CE7B59CE7AD9CDEAD94E7AD9CE7AD9CDEB59CE7AD94
E7AD9CDEAD94E7AD94E7AD94DEAD94DE9C8CDEA58CDE9C8CDEA58CDEA58CD6A58CD6A58CD6A58C\
D69C8CD6A584D69C8CD6A58CD69C8CD6A58CD69C84D6A584C69C84D69C84CE947B
D6A584CE947BC69C84C6947BC68C73BD846BB57B63AD735A9C73638C63528452427B6352734A39\
734A39634231634231523931523129523129422921422921422921392921523129
422921422921422931312121291818291818392921392921291818291818211010291818291818\
291818211010312121211010392921523129422921523931BDA59CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7DECED67B635273524A5A4239634A425A4239634231734A39\
6B524A6B524A7B635A634A42734A39735A52735A526B524A634A42634231634A42
634A424229214229214229215239315231295239315A42395A4239633931523931523931634231\
6B524A7B6352734A398C73638C63528452429C6B52A5735AB57B63BD846BCE9473
DEA58CDEAD94EFC6ADEFC6ADEFCEB5F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7E7DEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6EFCEB5\
F7D6BDF7D6BDF7CEB5EFC6ADEFCEB5EFC6ADF7C6ADEFCEB5F7C6ADEFBDA5EFBDA5
EFBDA5E7B59CEFBDA5E7B59CE7B594EFBDA5E7B59CEFB5A5E7B59CE7B59CE7B59CEFBDA5E7B594\
E7B59CE7B59CE7B59CE7B59CE7B59CE7B59CE7AD94E7B59CDEAD94E7AD94DEAD94
DEAD94E7AD94DEAD94DEAD94DEAD94DEA58CDEAD94DEA58CDEA58CD6A58CD6A58CD69C8CD6A58C\
D6A58CD69C8CD6A58CD69C84D6A584C69C84D69C84D69C84D69C84D69C84D69C84
C69C84CE947BC69C84C6947BB58C73BD846BAD846B9C7363A5735A8C5A427B6352845242734A42\
734A395A42395231295231295231294A3131422921392921422921392921392921
312118312118422921523129312121312121312121291818291818291818291818291818181010\
291818211010312118291818422921422921422921634231B5A5A5F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7846B5A7B6352734A39634A42634231523931634A42\
634A42634A4273524A6B524A634A4273524A735A526B524A6B524A5A42395A4239
634A425239313929214229215231295A42395239316342315A4239634A425A4239634231523931\
6342317B6352734A428C63528C63528452428452429C6B52B57B63BD846BCE9473
D6A584DEAD94EFC6ADEFC6ADEFCEB5F7CEB5F7D6BDF7D6BDF7CEB5F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6C6\
F7D6C6F7D6BDEFCEB5F7C6ADF7C6ADEFC6ADEFCEB5F7C6ADEFCEB5EFBDA5EFBDA5
E7B59CEFBDA5E7B59CE7B59CE7B59CE7B59CE7B59CE7B594E7B594E7B594E7B59CE7B59CE7B59C\
E7B594E7B59CE7B59CE7AD94E7AD94E7AD9CDEAD94E7AD9CE7AD94DEAD94E7AD94
DEA58CDEAD94DEAD94DEAD94DEA58CDEA58CDEA58CD69C84DE9C84D69C8CDEA58CD6A58CD6A58C\
D69C84D6A58CD6A58CD69C84D69C8CD69C73C69C84D6A584C69C84D6A584C69C84
D6A584C6947BC6947BC6947BB58C73AD846BAD846BA5735A8C5A42846352845242734A39634231\
634231523931523931523931523129523129523129422921392921312121312118
312118312121392921392921523129392921291818181010211010312118291818211010291818\
211010291818312118312118392921422921523931734A39CEB5ADFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7DECED68C736B73524A634A425A42395A4239523931734A39\
734A39634A426B524A7B63526B524A6B524A73524A6B524A634A42634A425A4239
634A426342315231294229213929215239316342315239315A4239634A42634A42523129523931\
634231734A3973524A73524A7B63527B63528452399C6B52AD735AB57B63CE9473
D69C84DEA58CEFC6ADEFC6ADEFC6ADEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6\
F7D6BDEFCEB5F7CEB5EFCEB5EFC6ADF7CEB5EFC6ADEFC6ADF7C6ADEFBDA5E7B59C
E7B59CEFBDA5E7B59CE7B594E7AD9CE7B594E7B594E7B594E7AD9CE7B59CE7B59CE7B594E7AD94\
E7B59CE7AD94E7B594E7AD9CE7B59CE7B59CE7B59CE7AD94DEAD94E7AD94DEAD94
E7AD94DEAD94E7AD9CDEA58CD69C8CDE9C8CDE9C84DE9C84D69C84DEA58CD6A58CD69C84D69C8C\
D69C84D6A584D69C84D6A584D69C84D69C84D69C84D69C84D69C84D69C84C69C84
CE947BC6947BC68C73BD846BB5846BA5735A9C6B528C63528C5A4A7B6352734A39734A39634A42\
634231634231523129422921422921422921422921422921422921392921392921
392921392921312121392921312121392921291818291818312121181010181010291818211010\
211010291818291818312118422921523129634231734A42DECED6F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7E7DEE79C8C8C7B6352634A426342315A42395239315A4239\
6B524A634A42634A427B63526B524A6B524A6B524A634A42634A426B524A5A4239
5A42395A4239523931422921422921422921523129634231523129634231634A425A42395A3129\
5A4239634A4284524273524A734A428452428452429C6B52AD846BAD735AC68C73
D6A584DEAD94EFC6ADEFC6ADEFCEB5EFC6ADF7C6ADF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6\
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5\
F7D6BDF7D6BDF7BDB5EFC6ADF7BDB5EFC6ADF7C6ADEFC6ADEFBDA5EFBDA5EFBDA5
E7B594E7B59CE7B59CE7B594E7B59CE7AD94E7AD9CE7B594E7B59CE7B59CE7B59CE7AD9CE7B59C\
E7B59CE7B594E7AD9CE7B59CE7B59CE7AD94E7AD9CDEAD94E7AD94DEAD94E7AD94
DEAD94DEAD94DEA58CDE9C8CDEA58CDEA58CD69C8CDEA58CD69C8CDE9C84DE9C8CD6A58CD6A58C\
D6A58CD6A58CD69C8CC69C84D69C84C69C84D69C84C69C84C69C84C69C84CE947B
C6947BC68C73BD846BAD846BAD735AA5735AA5735AA5735A7B6352734231734A39734A39634231\
634231523129523129422921422921422921312118312118392921392921291818
312121312121312121312121312121312121312118312121291818291818291818211010181010\
211010291818312121392921422921523931634A4273524AFFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B737B635273524A5A42395A42395A4239634231\
6B524A5A4239634A426B524A7B6352634A426B524A6B524A634A425A4239634A42
5A42396342316B524A5239315231294229213929215231296342315239315239316B524A634A42\
5A4239634231734A397B6352734A42734A42734A3984524294634AAD846BBD846B
C68C73DEA58CE7B59CEFC6ADEFCEB5EFCEB5EFCEB5F7BDB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6BD\
F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7D6BD
F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDF7D6BD\
F7BDB5F7BDB5F7CEB5EFC6ADF7C6ADEFC6ADF7C6ADEFBDA5EFBDA5EFBDA5E7B59C
E7AD94E7B59CE7B594E7AD94E7AD94E7AD94E7B594E7B594E7AD9CE7B59CE7B59CE7AD94E7B59C\
E7AD9CE7B59CDEAD94E7B59CE7AD94E7B594DEA58CE7A58CDEA58CE7AD94DEAD94
DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEA58CDEA58CDEA58CD6A58CD6A584D69C84D6A58C\
D6A58CD6A58CD6A58CD69C84D69C84C69C84D6A584CE947BCE947BCE947BC6947B
B58C73B57B63AD846BAD846BA5735A9C6B528C5A4A845242734A42734A39634231634231634231\
523931523129422921422921422921392921392921392921312121392921392921
422921422921392921392921312121211010312121312121291818312118211010181010291818\
211010312118312121523129633931734A39734A39B5A5A5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7A5847B846B5A735A52734A39734A39634A42523931\
735A525A42395A4239734A397B635A634A42634A427B635A634A42523931634A42
634A425A4239634A425A4239392921523129422921422921523129634231634231734A426B524A\
5A42396342315A423973524A73524A734A42734A398452398C5A4A9C6B52B57B63
BD846BC69C84DEAD94EFBDA5EFC6ADEFCEB5F7D6BDF7D6BDEFCEB5F7D6BDF7D6BDF7D6BDF7D6BD\
F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6BD
EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BD\
EFCEB5F7C6ADEFC6ADEFC6ADF7C6ADEFC6ADEFBDA5EFBDA5EFBDA5E7B594E7AD94
E7B59CE7AD94E7B594E7AD94E7B594E7AD94E7AD94E7AD94E7B59CE7B594E7AD94E7A58CE7AD94\
E7B594DEAD94E7AD94E7AD94E7AD94E7AD94DEA58CDEA58CDEB59CDEAD94DEA58C
DEA58CDEA58CDEAD94DEA58CDEA58CDEAD94DEA58CD6A58CD6A58CDEA58CD69C8CD6A58CD6A58C\
D6A58CD6A58CD69C8CC69C84C69C84C69C84CE947BC6947BC6947BC6947BC68C73
C68C73AD846BAD846B9C73639C6B528C5A4A846352846352734A396342315A3129634231523129\
523129422921392921312118312118392921392921312118312121312118392921
392921392921392921422921392921392921312121392921291818181010291818291818291818\
3121183929214229216339315A423963423194736BE7DEE7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B738C73637B635A6B524A5A42395A4239634231\
6B524A634A425A42395A423973524A73524A634A427B635A634A42523931634A42
634A42634A425A42396B524A4221185231295231294229214229215239315A4239634A426B524A\
634A42523931634231634A42734A42734A396B524A734A398C5A4A9C6B52AD846B
B57B63C69C73D6A58CDEAD94E7B59CEFBDA5EFC6ADF7CEB5F7D6BDF7CEB5F7D6BDEFCEB5F7D6BD\
F7D6BDEFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDEFCEB5F7CEB5F7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7BDB5\
F7D6BDEFC6ADEFC6ADF7C6ADEFC6ADEFC6ADEFBDA5E7B594EFBDA5E7B594E7AD94
E7AD94E7B59CE7B59CE7B594E7B594DEA58CE7B594E7B594E7B594E7B594E7B594DEAD94DEAD94\
E7B594E7AD94E7AD94DEAD94DEAD94E7A58CE7AD94DEAD94E7A58CDEA58CDEA58C
DEA58CDE9C84DEA58CDE9C8CDE9C84DEA58CD6A58CD6A58CDEA58CD6A58CD6A58CDEA58CD69C8C\
D69C84D6A584D69C8CD6A584CE947BCE947BC68C73C68C73C68C73C68C73B58C73
BD846BA5735AA5735A9C6B528C5A4A846352845242845242634A426342315A3129523129523129\
523129422921392921312118312118312118312118392921312118392921392921
392921392921392921392921392921392921312121312121392921291818291818312121211010\
2918183929215239315A4239634231734A39B59C9CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B73846B5A846B5A73524A5A4239634A425A4239\
6B524A6B524A5A42395A42396B524A73524A634A42735A52735A525A4239523931
5A42395A42395A42395A42395231293929215231295231295231295231295A3129634231734A39\
634A425A42395239315A31296B524A6B524A734A426342318452428C6352A5735A
B5846BC68C73D6A584E7AD94E7B59CEFBDA5EFBDA5EFCEB5EFCEB5F7C6ADF7CEB5F7CEB5F7D6BD\
F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6
F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7BDB5EFCEB5F7BDB5F7D6BDF7D6BDEFC6ADF7C6AD\
EFCEB5F7C6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7B594E7B59CE7AD94
E7B594E7B594E7AD94DEA58CE7A58CDEAD94E7A58CDEA58CDEA58CE7A58CE7A58CE7B594E7B594\
DEAD94E7AD94DEAD94E7AD94E7AD94DEA58CDEA58CDEA58CDEAD94DEA58CDEA58C
DEA58CDEA58CDEAD94D6A584DE9C84D6A58CDEA58CD6A58CD69C84DEA58CD6A58CC69C84D69C84\
C69C84C69C84D69C84C69C84CE947BC6947BC68C73C68C73B58C73C68C73B5846B
9C7363A5735A8C73638C63528C6352845239734A39734A39634231634231634231523129422921\
422921422921312118291818312118312118312121312118392921312121392921
312121312121392921392921392921392921392921392921392921291818211010211010211010\
312118422921633931634231523931846352D6BDC6F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B59C9C846B5A8C736B846B5A634A425A4239634A42\
634A426B524A634A42634A426B524A6B524A634A4273524A735A52634A42523129
6342316B524A5A42395239315A42395231294229215239315239315A42395239315A4239634A42\
735A52634A425A42395A423963423173524A6B524A6B524A734A39846352A5735A
A5735AB57B63CE947BD6A58CD6A584E7B594E7B59CEFC6ADEFCEB5EFC6ADEFC6ADEFCEB5EFCEB5\
F7CEB5EFCEB5F7CEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDF7D6BD
F7D6BDF7D6BDF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDEFCEB5F7CEB5F7C6ADEFCEB5F7D6BD\
F7CEB5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7AD94E7AD94E7B59CE7A58C
E7B594DEA58CE7AD94E7A58CDEA58CDEAD94E7AD94E7AD94DEAD94E7A58CDEA58CDEA58CDEAD94\
E7A58CE7A58CDEAD94E7AD94DEAD94E7A58CDEA58CDEA58CDEA58CDE9C84DEA58C
DEA58CDEA58CDEA58CDEA58CDE9C8CD6A58CDEA58CDEA58CD6A58CD6A58CD69C84D6A58CD6A584\
D69C8CD6A584C69C84CE947BCE947BC69C84C6947BC6947BB58C73B5846BB57B63
AD846BA5735AA5735A9C6B52845242845242734A39734A396342315A3129523129523129422921\
422921422921312118312118312118312118392921312121312118312121392921
422921392921392921312121312121312121291818291818211010211010181010181010291818\
392921523931634231523129734A39846B5ADECED6F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD8C73638C73637B635A735A52634A42634A42\
63423173524A6B524A634A42634A426B524A73524A6B524A735A526B524A5A4239
5A4239634A42634A42523129634A425239313929214229215231295242395A4239734A39634A42\
634A42734A42634A42523931523931734A42734A3973524A845242734A398C5A4A
A5735AAD846BCE9473D6A58CD6A584DEA58CE7B59CE7B59CEFC6ADEFC6ADEFCEB5F7D6BDEFCEB5\
EFCEB5F7CEB5F7D6BDF7D6BDF7D6C6EFCEB5F7CEB5EFCEB5F7D6C6F7D6BDEFCEB5
F7BDB5F7CEB5EFCEB5F7CEB5F7D6BDF7CEB5F7D6BDF7D6BDF7BDB5EFCEB5F7CEB5EFCEB5EFC6AD\
F7C6ADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7AD94E7B59CE7B59CDEA58C
E7A58CDEA58CE7AD94DEA58CDEA58CE7B594E7A58CDEA58CE7AD94DEA58CE7B594E7A58CE7A58C\
DEA58CDEAD94E7AD94DEAD94DEAD94DEA58CDEA58CDEA58CDEA58CDEA58CD69C84
DE9C8CDEA58CDEA58CDEA58CD69C84DEA58CD6A58CD6A584D6A584D6A58CC69C84D69C8CCE947B\
D6A584C69C84CE947BC6947BC6947BC6947BC68C73BD846BBD846BB57B639C7363
AD846B9C6B528C5A4A8C5A4A7B6352734A39734A396342315A3129523129523129523129523129\
422921392921312118312118291818291818312118312118312121312118312121
392921392921291818312121291818291818211010181010181010181010181010181010211010\
422921634231523129523931734A42A5847BF7E7E7FFFFFFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDC6846B5A94736B947B7373524A734A39634231\
5A42396B524A634A42634A425A4239634A42634A4273524A735A527B635A63524A
523931634A426B524A5239315239315A42395239313929215231295231295239315242395A4239\
734A396B524A6B524A634A425239316B524A6B524A634A4273524A7B6352845242
8C5A4AA5735AB58C73D6A584DEA58CDEAD94E7B59CE7B59CE7BDA5EFC6ADEFC6ADEFC6ADEFC6AD\
EFC6ADEFC6ADF7D6BDF7D6BDEFCEB5F7D6BDEFCEB5F7D6BDF7D6BDEFCEB5F7D6C6
F7D6BDEFCEB5F7BDB5F7D6BDEFCEB5F7C6ADEFC6ADF7CEB5EFCEB5F7C6ADEFC6ADF7C6ADEFC6AD\
EFC6ADEFBDADEFBDADEFBDADEFBDA5E7B59CE7AD94E7B59CE7AD94E7AD94E7A58C
E7A58CE7B594E7AD94DEA58CE7A58CE7A58CDE9C84E7B594DEA58CE7B594E7A58CDEA58CDE9C84\
DEA58CE7B594E7AD94DEA58CE7AD94DEA58CDE9C84DEA58CD6A584D6A584DE9C84
D69C73DE9C8CD69C84D6A584D69C8CD6A584D6A58CD69C84D6A58CD69C8CD69C84D69C84D69C84\
CE947BC69C84CE947BC6947BC6947BC6947BB58C73B58C73B5846BAD846BA5735A
9C6B528C63528C5A4A7B6352734A39734A39734A396342315A3129523129523129523129422921\
422921312118312118291818291818291818291818291818291818312121312121
312118312121211010291818211010181010181010181010181010181010181010181010312118\
5231295239315231295A4239734A39B59C9CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFA584847B63527B6352735A52734A42634A42\
5A4239634A426B524A6B524A634A425A42396B524A5A423973524A6B524A6B524A
5A42395A4239634A425A4239422921422921523129523931523931422921523931523931634A42\
5A4239734A39634A427B63527B635A523931523931634A426B524A6B524A734A39
7B63528C63529C7363B57B63C68C73D6A584D6A58CDEAD94DEB59CDEA58CE7B59CE7BDA5EFBDA5\
EFC6ADEFCEB5EFC6ADEFCEB5F7D6BDEFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5
F7D6BDEFCEB5EFCEB5EFCEB5F7CEB5F7CEB5EFCEB5EFCEB5EFC6ADF7CEB5EFC6ADF7CEB5EFC6AD\
EFBDA5EFC6ADEFBDADE7BDA5E7B594DEAD94E7AD94DEA58CDE9C84DE9C84DE9C84
E7A58CDEA58CE7A58CDE9C84DEA58CDEA58CDE9C84DEA58CDEA58CDEA58CDEA58CDE9C84DEA58C\
DE9C84E7A58CDEA58CDE9C84DEA58CDEA58CD69C84DEA58CDEA58CDE9C84DE9C84
D69C84D69C73D69C84D69C84D69C73D69C84D69C73D69C84D69C73C69C84C69C84CE947BC69C84\
C6947BC6947BC68C73C68C73BD846BB57B63B57B63A5735AA5735A9C6B529C6B52
9C6B52845242845242734A39634231634231634231634231523129422921422921422921392921\
312118312121312118291818211010291818291818312121312121312121312121
312121312121291818211010181010181010181010181010181010181010211010291818312118\
5231295231296342315A3129846352DECED6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD8C736384635273524A73524A6B524A\
5A4239634A426B524A6B524A634A425A4239634A42634A426B524A735A5263524A
634A42634231634A425A42394A31313929214A31314A31315239315231294A31315A42395A4239\
634A425A42396B524A6B524A73524A5A4239523931634231734A39734A4273524A
734A397B63529C6B52A5735AAD846BCE8C6BC6947BD6A584D6A58CE7B594E7B59CE7B59CE7B59C\
DEB59CE7BDA5EFC6ADEFC6ADEFC6ADEFCEB5EFCEB5EFC6ADF7CEB5EFCEB5EFCEB5
EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFCEB5EFBDADEFBDA5EFC6AD\
EFBDA5EFC6ADEFBDA5E7BDA5E7AD94DE9C84DEA58CDEA58CDEA58CDE9C84DEA58C
DEA58CDEAD94DEA58CDEA58CDEA58CD6A584DE9C84D6A584DE9C84DEA58CDEA58CDEA58CDEA58C\
DEA58CDE9C84DEA58CDEA58CDEA58CDE9C84DEA58CDEA58CD69C84D69C73D6A584
D69C84D69C84D69C73D69C73D69C84CE947BD69C84CE947BCE947BCE947BC6947BCE947BC6947B\
CE947BC68C73C68C73B58C73AD846BB57B639C7363A5735AA5735AA5735A9C6B52
9C6B52845239734A39734A396342316342315A31295A3129422921422921523129422921392921\
392921312118291818312118291818312118312121291818291818291818291818
291818312121211010211010181010211010181010181010181010181010291818312121523129\
5231295239315A4239633929A5847BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5BD94736B84635273524A73524A6B524A\
634A42634A426B524A6B524A6B524A5A4239634A42634A426B524A735A526B524A
6B524A5239315A4239634A425239315231294229215231294229215231295242395239315A4239\
5A4239634A426B524A6B524A634A427B63525A42395231295A4239634A4273524A
73524A6B524A8463529C6B52A5735A9C7363B57B63BD846BD6A584DEAD94D6A58CD6A58CDEA58C\
DEAD94DEB59CDEB5A5E7BDA5EFC6ADEFC6ADEFC6ADEFC6ADD6C6B5EFCEB5EFC6AD
EFC6ADEFC6ADF7C6ADEFCEB5EFCEB5EFC6ADEFC6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6AD\
EFBDA5E7BDA5EFB5A5E7B59CDEAD94D69C8CD69C84DEAD94DEA58CDE9C84DEA58C
DEA58CDE9C84DEA58CDE9C84D6A584D6A584D6A584DE9C84DE9C84DE9C84DE9C84DE9C84DEAD94\
DEA58CDEA58CDE9C84DE9C84DEA58CD6A584DEA58CD69C73DE9C84D69C84DE9C84
D69C84D69C84D69C84D68C7BCE947BD69C73CE947BCE947BCE947BCE9473CE947BC6947BC6947B\
C68C73B58C73B58C73BD846BB57B63AD846BA5735AA5735AA5735A9C6B529C6B52
8463527B6352734A39734A396342315239315A31295A3129422921422921422921312121392921\
392921312118312118312118312118291818291818291818211010291818291818
181010312121211010181010181010181010181010181010181010211010312118392921523129\
4229215239315239315A4239D6BDC6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECED6948484846B5A7B635273524A6B524A\
634A42734A396B524A73524A6B524A634A42634231634A4A634A42735A526B524A
634A425A4239634231634A425239314229214229214229215231293121215231295A42394A3131\
5A4239634A42634A426B524A6B524A73524A7B6352524239523129523129634A42
734A4273524A734A428452428C5A4A94634AA5735AB57B63B58C73C68C73C68C73CE947BCE947B\
C69C84D6A58CD6A58CDEB5A5DEB5A5DEB59CDEB59CEFC6ADEFC6ADEFC6ADEFC6AD
E7BDA5EFBDA5D6C6B5EFCEB5E7BDA5EFC6ADEFBDA5EFCEB5EFC6ADEFBDA5E7B594EFBDA5EFC6AD\
EFBDA5E7BDA5E7BDA5E7BDA5DEAD94DEAD94DEA58CC69C84D69C84D69C84DE9C84
D69C84D6A584DEA58CD69C84D69C84D69C73D69C84D69C73D69C84DE9C84D6A584DE9C84DE9C84\
D69C84DE9C84DE9C8CDE9C8CDEA58CDE9C84D69C84D69C84D69C73D69C84D69C84
D69C73D69C73D69C73CE947BD68C7BCE947BD68C7BCE947BC69C73C68C73CE947BC68C73C68C73\
C68C73BD846BBD846BB5846B9C7363A5735AA5735AA5735A9C6B528C5A4A845242
845242734A39734A396342316342315A31295A3121422921422921312118392921422921312118\
312121291818291818211010291818291818291818291818291818181010291818
291818211010211010181010181010181010181010181010181010291818312121523129523129\
5239315239314A211894736BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFB5A5A58C73638463527B6352734A42\
5A4239634A42734A396B524A73524A6B524A5A423963524A634A4263524A735A52
63524A63524A5239315A42395239315231293929213929215231295231294229216B524A634A42\
5231295A42395A4239634A426B524A634A4273524A846B5A6B524A5A4239523931
634231734A427B6352734A428452428463528C63529C6B52A5735AA5735AB57B63B57B63C68C73\
C6947BCE947BD6A58CDEAD94DEAD94D6A58CD6A58CDEAD94DEAD94DEB5A5DEB5A5
DEB59CE7BDA5E7BDA5DEB59CE7BDA5E7BDA5E7BDA5EFBDADE7BDA5E7B59CE7B59CE7B59CEFBDA5\
E7BDA5E7BDA5E7B59CDEB59CD6A58CD69C84C68C73CE8C6BC68C73CE9473CE947B
D69C73CE8C84D69C73CE947BCE8C73D68C7BD69C73D69C84D69C73D6A584DE9C84D69C8CD69C84\
D69C73D69C73D69C73D6A584D69C84D69C84D69C84D69C84D69C84D69C73D69C84
D68C7BD68C73D68C7BD69C84CE947BCE947BC69C84CE947BCE947BCE947BC6947BC68C73B58C73\
C68C73B58C73B5846BAD846BB57B63A5735AA5735294634A845242845239845242
845242734A396342316339295A3129523129422921422921422921422921312118312121291818\
421810291818291818312121211010291818291818312121312121291818291818
211010211010211010181010181010181010181010181010211010312121422921523931422921\
5231294229215A3129CEB5B5FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEBDC694736B846B5A7B635A73524A\
634A425A4239634A426B524A73524A634A42634A42634A42634A42634A42735A52
735A52634A425A42395A42396342314A31315231293929215231295231293929215239316B524A\
6B524A5A42395A42395A42395A42396B524A6B524A6B524A846B5A73524A634A42
523931634231734A427B63527B63528463528463528463528463529C6B52AD7B6BAD735AB57B63\
B58C73C6947BB58C73DEAD94D6A58CC6947BD6A58CD6A58CDEAD94DEAD94D6A584
DEB5A5DEAD94DEAD94DEAD94DEB5A5E7B59CDEB59CE7B59CDEB59CE7AD94DEAD94E7BDA5E7BDA5\
E7B59CDEAD94DEAD94D6A58CC69C84CE9473BD846BB5846BB57B63BD846BBD8463
BD846BCE8C6BCE9473C68C73CE8C6BCE9473D68C7BD69C73D69C84D68C7BCE8C6BD69C73D69C84\
D68C7BCE9473CE8C6BD68C73D69C73D68C7BD69C73D69C84D69C73D69C84D68C7B
D69C73CE947BCE947BCE947BCE947BCE947BC68C73C68C73C68C73C6947BC68C73C68C73BD846B\
B5846BB5846BB57B63AD846B9C6B529C6B528C5A4A8C5A4A8452428452427B6352
734231734A39634231523931523129523129422921422118422921312121211010312118312118\
291818291818291818291818291818291818291818291818312121312121291818
211010211010181010181010181010181010181010181010291818392921523931422921422921\
523129422921845242EFE7E7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE947B73846B5A7B635273524A\
634A425A42395A42396B524A6B524A6B524A6B524A634A42634A42634A4A6B524A
735A52634A42634A425A4239524239524239523129392921392921422921523129392921523931\
6B524A7B635A6B524A634A42634A426B524A6B524A634A426B524A73524A73524A
6B524A634A42634231734A39734A4273524A846352846352945A529C7363B57B639C73639C7363\
B58C73B58C73C6947BBD9C8CC6947BC6947BC6947BDEAD94BD9C8CD6A584C69C84
D6A58CBD9C8CC69C84D6A58CDEAD94D6A584DE9C84DEAD94DEB59CDEAD94D6A58CE7B59CDEB59C\
DEB59CDEAD94D69C8CC6947BC6947BAD7B6BB57B63B5846BB57B63AD735AB5846B
BD846BBD8463BD8463BD846BCE8C6BCE8C73CE9473CE9473CE947BD68C73CE8C73CE9473CE947B\
CE9473CE8C73CE8C73CE9473CE9473CE947BD69C84CE947BD68C7BCE947BD69C73
CE947BCE9473CE8C73C68C73C68C73C68C73CE8C6BBD846BC68C73C68C73C68C73B58C73BD846B\
B5846BB57B639C73639C73639C6B528C5A4A8C5A4A8C5A42845242845239734A39
734A39634231634231523129523129422921422921422921312118421010312118312121312118\
312118291818291818291818291818211010211010291818291818291818211010
211010211010181010181010181010181010181010291818392921523129523129422921523129\
422921523931947B73F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFAD94948C63527B635A7B6352\
6B524A5A4239634A42634A426B524A735A526B524A524239634A42634A42634A42
735A52634A42634A425A42395231296342314A3131523129422921392921422921523129422921\
4A31315A4239735A527B635A735A525A42396B524A634A426B524A6B524A6B524A
6B524A6B524A6B524A734A42734A42734A4273524A846352846B5A846B5A8C73639C73639C7363\
9C7363C6947BAD847BC69C84B58C73C68C73B58C73C6947BC6947BB58C73B58C73
D6A584C6947BC69C84C69C84C69C84C69C84C69C84D6A58CDEAD94D69C8CD6A584DEAD94DEB59C\
DEB59CC69C84C6947BC6947BBD846BAD846BA5735AB57B639C73639C6B52AD735A
AD735AB57B63B57B63BD846BB57B63BD846BCE8C6BCE8C73CE8C6BBD846BCE8C6BCE8C73CE8C73\
CE8C73CE9473CE8C73CE9473CE9473CE8C73CE9473CE9473CE947BCE9473C68C73
CE8C6BCE9473C68C73CE8C6BC68C73BD846BCE8C6BC68C73B58C73BD846BB58C73BD846BB57B63\
B57B63AD846BAD846B9C6B5294634A8C5A4A8C5A42845242734A42845239734A39
734A395A31295231295A3121523129523129523129422921392921312118312118312118312121\
312118291818291818291818291818211010211010211010291818291818211010
1810101810101810101810101810101810102110103121214229214A31314229214A3131523129\
422921734A42CEB5ADF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6DEA5847B8C73637B6352\
73524A634A42634231634A42634A426B524A6B524A634A42634A425A42395A4239
634A42735A526B524A634A424A3131422921523931523931523129392921422921523931524239\
5A42395239315A42395239315A4239735A52735A5263524A73524A634A425A4239
634A42735A526B524A73524A735A527B63527B63527B635A8463528463528C5A4A8463528C6352\
A5735AAD846BAD846B94736B9C73639C7363AD846BAD846BB58C73AD846BB57B63
9C73639C7363AD846BAD846B9C7363B5846BB5846BC68C73C6947BD6A58CBD9C8CC6947BC6947B\
C69C84BD846B9C73639C73639C73639C6B52945A529C6B52A5735AA5735A8C7363
A5735AA5735A9C6B52A5735AA5735AB5735ABD8463BD8463BD8463C68C63C68C63BD846BC68C63\
C68C73CE8C6BCE8C6BC68C73CE8C6BCE8C6BC68C73BD846BBD8463B57B63BD846B
BD846BBD8463BD846BBD846BBD846BBD846BBD846BB57B63B5846BB5735AB5846BB57B63A5735A\
A5735A9C6B529C6B52A5735A8463527B6352845239734A42634231634231634231
5A3129523129422921523129422921523129523129392921392921312118291818291818312118\
291818291818291818211010211010211010181010181010181010181010181010
1810101810101810101810101810101810103121215231295231294229214A3131422921422921\
73524AB59C9CF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFAD8C8494736B846B5A\
735A526B524A634A425A4239734A396B524A6B524A634A425A4239634A425A4239
634A427B635A6B524A6B524A5242395231295231295239314A3131392921523129523129634231\
5A4239634A425A4239634A42634A4A6B524A7B635A735A52735A52735A5273524A
6B524A634A427B635A735A52634A42735A52735A527B635A735A527B63527B63528463528C6352\
9C73639C73638C73639C6B52A5735A94736B9C736394736BAD846BA5735A8C7363
8C7363A5735A9C7363AD846BA5735A9C7363A5735AAD846BB58C73C69C84D6A584C69484B58C73\
B58C73AD846BAD846B9C73639C6B529C6B52846B5A9C6B528452428C63528C5A4A
94634A8C5A4A8C635294634AA57352AD735AB5735AAD735AB5735ABD8463BD8463B57B63BD8463\
BD846BBD8463BD846BCE8C6BBD846BBD8463BD8463BD846BBD846BBD846BB57B63
AD735AB57B63B57B63B57B63B5735AB57B63B5846BB57B63B57B63B57B63AD735AAD846B9C7363\
A5735A9C6B528C63528C5A4A8452428452428452397342316342315A3129634231
5A3129422921523129422921422921422118422921422921312118312118312118291818291818\
291818291818291818211010211010211010181010181010181010181010181010
1810101810101810101810101810102110105231295231293929214A3131422921422921523129\
94736BEFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5B5947B738C7363\
73524A6B524A634A42634A42634A426B524A73524A634A42634A4263524A5A4239
5A4239735A52735A52634A425A4239423139392921523129523931523129523129422921523931\
634A425A423963524A5A42396B524A735A5263524A6B524A6B524A6B524A6B524A
6B524A73524A6B524A735A527B635A735A527B635A7B635A846B5A7B6352846352846B5A8C7363\
8C7363846B5AA5735A9C6B52846B5AA5735A8C7363A5735A8C7363A5735A9C6B52
A5735A8C7363A5735A9C7363A5735AA5735A9C6B52AD846BA5735AAD846BB58C73C69C84B58C73\
9C73639C73639C7363AD7B6B9C7363846B5A8C63528C63528C63527B6352845242
8463528C5A4A8C63528452428C5A4AAD735AA5735AAD6B52AD6B52AD735AB57B63B5735AB57B63\
B57B63BD8463BD846BBD8463BD846BBD846BB5846BBD846BB5846BB57B63B57B63
AD735AAD735AA5735AA5735AAD735AA5735AAD735A9C7363A5735A9C7363A5735AA5735AA5735A\
9C6B528C63528C5A42845242845239634231634231634231634231634231634231
5231295A3121523129422921422921392921422921422921312118312121291818291818291818\
312121312118211010181010211010181010211010181010181010181010181010
1810101810101810101810101810102918184A3131422921422921422921392921422921523931\
B5A5A5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE9C8C8C947B73\
735A526B524A734A39634A42634A42634A426B524A6B524A5A423963524A63524A
524239634A427B635263524A5A42395239315231293929215231295A42394A3131523931523931\
5A42396342316B524A735A5263524A6B524A735A527B635A6B524A5A52526B524A
634A4273524A7B635A7B635A846B5A846B5A7B635A735A52735A527B63528C6352846B5AA5735A\
8C63527B6352846B5A846B5A8C73638463528C63528C63528C63528C6352846352
8C63528C63528C5A4A9C6B529C6B529C6B528C5A4AA5735AA5735AA5735AA5735AA5735AAD846B\
9C7363A5735A846B5AA5735A9C7363846B5A8463528463528463528452427B6352
8452427B63528C5A428463528452429C6B5294634A9C6B529C6B52AD735AA57352AD6B52AD735A\
AD735AAD735AB5735AB57B63B5846BB57B63AD846BAD735AAD846BA5735AA5735A
A5735AA5735AA5735AA5735A9C6B52A5735AA5735AA5735A9C6B528C63529C6B529C6B529C6B52\
8C63528452427B6352845242734A39734A396342316342315A31295A31295A3129
523129523129422921422921422118312118392921422921291818312118291818291818211010\
291818291818291818211010211010181010181010181010181010181010181010
1810101810101810101810102918183929214229214229214A31313929213929215A3129633931\
DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFC6ADBDA5847B\
7B635A7B63526B524A634A42634A42634A42634A426B524A634A425A4239634A42
634A42634A426B524A6B524A5A42395A42394A31315231294229315231295A4239523931523931\
634A426B524A6B524A735A52735A52735A526B524A7B635A7B635A7B635A7B635A
5A525263524A7B635A7B63527B635A7B635A7B635A8C736B7B635A846B5A846352846B5A8C7363\
73524A846B5AA5735A8463528463528463527B63527B6352734A427B63528C6352
734A428452428463528463528463528C5A427B63528C635294634A9C6B528C63529C6B529C6B52\
A5735A8C63528C63528463528463528C63527B6352734A427B63528452427B6352
845242734A42734A428C5A4A8452428452428C5A4284524294634A94634AA57352A56B52A5634A\
A57352AD6B52AD735AA57352A57352A57352A5735AA5735A9C6B529C6B529C6B52
A5735A9C6B529C6B529C6B529C6B529C6B529C6B529C6B529C6B529C6B528C5A4A8C5A4A9C6B52\
8C5A42845242845242734A39734A39734A396342316342315A31295A3121523129
5231294229214A2118312118312118392921392921312118291818291818291818291818211010\
211010291818181010181010181010181010181010181010181010181010181010
1810101810101810102918183121215231293929215239314229213929215231295A3129846B5A\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7AD9CA5\
846B5A73524A73524A634A42734A39634A42634A426B524A634A425A4239634A42
63524A634A4263524A735A52634A425A42395239314229213929215242395239315239315A4239\
5A42396B524A6B524A735A527B6352735A527B635A735A526B524A735A52735A52
7B635A735A52634A42735A527B635A8C73638C7363846B5A846B5A8463528C63528C7363846B5A\
846352846B5A8C63527B6352845242734A42734A4273524A734A3973524A8C7363
734A398463527B6352845239734A427B63528452428463528452428463528463528463528C6352\
846352846B5A7B635273524A7B63527B635284635273524A73524A73524A73524A
845242734A42734A426342318452398452428452398452428452428463528C5A428C5A429C6B52\
9C6B529C6B5294634A9C6B529C6B529C6B5294634A94634A8C5A4A8463528C5A4A
9C6B5294634A8C5A428463528C5A428C5A4A94634A8C63528C63528C5A4A8C5A4A845242845242\
8452427B6352734A39734A396342315A31295A31295231295A3121523129523129
523931422921392921312118312118312118312121312118312118211010291818312118291818\
291818181010291818211010181010211010181010181010181010181010181010
181010181010211010291818422921523129523129422921312121422921633931633931AD8C84\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFC6ADAD\
8C736B73524A73524A6B524A634A42634A42634A426B524A6B524A634A425A4239
634A42634A4A634A42735A52634A425A42395239315231295231294231395239315A42395A4239\
5A42395A4239634A42735A527B635A846B5A846B5A7B635A735A52735A526B524A
735A526B524A634A42634A426B524A73524A6B524A6B524A7B63528463528C63528C736373524A\
73524A7B635273524A7B6352846352634A42734A39634A42734A3973524A7B6352
6B524A734A42734A397B63527B63527B6352734A427B6352734A428452427B63528452427B6352\
8463527B63527B63527B6352735A5273524A73524A734A42734A39734A39634A42
734A426B524A734A39734A39634231734A39734A39845242845239845239845242845239845242\
8452428452428C5A428C5A4A846352845242845242845239845242845242846352
8C5A428452427B6352845242734A39734A39734A398452428452398463528452428452427B6352\
734A42845239734A396342316342316342315A31295231295A3129523129422921
523129422118392921392921312118291818312118312118392921291818291818291818211010\
291818211010211010181010181010181010181010181010181010181010181010
1810102110102918183929215231293929215231293121213929216339315A3129633931CEB5B5\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7\
AD94948C736B735A5273524A634A42634A42634A42634A426B524A6B524A634A4A
5A423963524A63524A634A42735A52634A42634A425A423952393142292152393163524A6B524A\
63524A634A42735A527B635A7B635A7B635A735A526B524A73524A846B5A7B6352
735A52735A52634A42634A4273524A735A527B63527B63528463527B6352846B5A73524A7B6352\
8C63527B6352734A3984524273524A734A39734A395A4239634A4273524A6B524A
5A4239734A39634A42734A4273524A73524A63423163392973524A734A42734A39734A427B6352\
7B6352734A39634231634A42734A42735A52634A42634A42634A425231295A4239
6342316342315A4239734A395A4239633929634231634231634231634231634231634231734A39\
734A39734231734A39734231734A39734A39734231734A39734A39734A39734A39
734A395A4239634231634231634231734A39634231633929634231634231634231734A39634231\
6342316342315239316339295A31295A31214229214229214A2118422921422921
392921422921312121312118291818291818291818312118312118312121312121291818291818\
291818291818181010181010211010181010181010181010181010181010181010
291818312121422921392921422921523931312121523129523931633929734A39CEB5B5FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7\
AD9494A5847B7B635A73524A6B524A6B524A634A425A42396B524A6B524A63524A
5A4239634A4263524A634A42735A52735A52634A42634A425A42395242395239316B524A735A52\
7B635A6B524A735A527B635A7B635A7B635A7B635A7B635A735A526B524A735A52
7B635A7B635A735A526B524A634A42734A4273524A73524A7B6352846B5A846B5A6B524A734A42\
7B63526B524A734A396B524A734A395A4239634A426342315A4239634A42634A42
5A42395A4239634231634A426B524A73524A634A425A4239734A397B63526B524A6342316B524A\
734A4273524A634A42523129523931634A42734A39634A425A4239523931523129
5239315239315A31295239316342315231295A31295A31296342315A3129634231734A39634231\
734A396342315A31296342316342316342316342316342315A4239634231634231
634231634231634231633929634231734A395A31296342316342315A31295A3129633929634231\
6342316342315A3129523129523129422921422921422921422921422921312118
422921422921312118291818291818291818291818312121291818312118421810291818291818\
211010211010181010211010181010181010211010181010181010181010291818
3121214229213929214229214A31314229215231295231295A3129633931AD847BF7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7\
C6ADAD9484848C736B73524A73524A634A42734A39634A425A42396B524A6B524A
634A42523931634A4263524A634A426B524A6B524A634A42634A425A42395A42395A42396B524A\
8C73637B635A7B635A735A527B635A846B5A8C736B7B635A7B635A7B635A735A52
6B524A73524A634A425A42396B524A6B524A734A42734A42734A42AD846B846352634A42845242\
6B524A734A396B524A734A396B524A5A4239634231634A425A42395A4239634A42
5239315A4239523931734A39634A426B524A5A423973524A5231296B524A73524A634A42634A42\
6B524A634A42734A39634A425A42395242395A42395A42395A42395A4239523129
5231295239315239315239315239315231295231295231295231295A31295A31295A31295A3129\
6342316342315A3129634231634231634231634231634231633929634231523129
6342316342316339295231295A31295A31296342315A31295A31295A31295239315A3129523129\
6342315A3129634231523129523129523931422921392921422921422921392921
312118422921392921291818291818291818291818312118291818291818291818211010291818\
181010181010211010181010181010181010181010181010181010181010312121
4229314229213929214A31314229213121215A31296B524A634A429C7363D6C6DEF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
D6C6D6AD9494947B737B635A73524A6B524A634A426B524A5A4239634A426B524A
634A4A5A42395A423963524A634A4263524A6B524A6B524A6B524A634A42634A425A4239524239\
73524A7B635A7B635A7B635A735A52735A527B635A846B5A8C736B7B635A73524A
6B524A634A426B524A6B524A73524A73524A6B524A734A427B63528C736373524A734A427B6352\
634A42734A39734A398452426B524A523931634A42634A425A42395A4239634A42
5A4239634A42523129634A42634A426B524A6B524A634A425A42395231296B524A734A39634A42\
634A4273524A5A42395239315239316342315239314A3131523931523129523931
5239314229215231295231295231295231295231295231295231294229215231295231295A3121\
5A3129634A425A3129523129523129634231634231523129523129523129523129
5A31295A31295239315231295231295231295A31295A31295231295231295231295231295A3121\
5231295231295231295231294229214229214A2118422921392921312118392921
392921312118392921312121211010211010211010291818312121211010291818291818291818\
291818211010211010181010181010181010181010181010181010211010392921
42292139292152312952312939292139292152393173524A734A42CEB5ADFFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
DECED6C6ADADAD9C8C947B7373524A6B524A634A426B524A634A42634231634A42
6B524A634A42524239634A4263524A634A42634A425A52527B635A735A526B524A5A52525A4239\
5A42396B524A7B635A8C73637B635A63524A735A527B635A7B635A7B635A7B635A
7B635A8C73637B635A7B635A735A5273524A7B63526B524A73524A846B5A734A39734A396B524A\
6B524A734A39634A4273524A6B524A523931734A39634A42634A42634A42634A42
5242395A42395242395A4239634A426B524A6B524A523931634A425231295239316B524A634A42\
634231634A425A42396342315239315239315239314A31315231295239314A3131
4A31314A3131422921523129422921523129523129523129523129422921422921523129422921\
4229215A3129523931422921523129523129523931523931523129523129523129
5231294229215231295A3129523129523129422921523129523129523129422921523129523129\
523129422921523129523129422921422921312118422921392921392921312118
312118291818392921312121291818211010211010291818291818291818181010211010211010\
291818181010181010181010181010181010181010181010291818312121422921
3929215231295231293121213121215231295A3129734A42AD847BF7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
E7DEE7CEB5B59C8C8C9484847B63526B524A73524A6B524A634A42634A42634A42
634A426B524A634A42634A42735A52634A42634A42634A426B524A7B635A735A52735A527B635A\
6B524A5242395A42396B524A7B635A7B635A735A52735A52735A52735A526B524A
6B524A6B524A6B524A73524A6B524A6B524A6B524A73524A846B5A845242634231634A426B524A\
734A39634A425A4239634A425A42395A42395A42395A42395A4239634A42634A42
6342315A42395A42395231296B524A634231634A42523129634A426342314A3131634A42634A42\
5A42395A42395239314A31315231294A31315231293929215231295239314A3131
422921422921422921392921422921422921523129422921422921523129392921523129422921\
392921422921523129523129422921523129523129523129523129523129523129
422921523129523129422921523129523129523129523129523129422921422921523129422921\
4229214229214A2118422921422921312118422118312118312118312118312118
312121312118291818312118211010211010181010291818291818211010291818181010291818\
211010181010181010211010181010181010181010291818291818392921392921
5231295239313929213121215231294229217B6352AD9494D6C6CEF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
E7DEE7D6C6CEB5A5A5B5A5A58C736B6B524A6B524A634A42734A396B524A634A42
634A42735A5263524A5242396B524A5A5252634A425A4239634A4263524A7B635A7B635A7B635A\
7B635A8C736B6B524A5A4239634A42735A526B524A735A52735A526B524A634A42
5A4239523931523931634A426B524A73524A73524A734A428463526B524A634231734A396B524A\
734A39734A42634A42634A42634A42634A42634A42634A425242395A423963524A
5A4239524239634A424A313173524A5A42395242395A42394A3131634A424A31314A3131524239\
5A42395231294A3131523129523129523129422931523129422931422921422921
422921392921392921422921392921422921422921523129422921422921422921392921523129\
422921392921422921523129392921422921422921422921422921392921523129
422921392921523129422921422921523129422921422921523129523129422921422921422921\
422921312118422921422921422921392921312118312118312118211010291818
312118312121312118312121291818211010181010291818291818312121211010211010181010\
2918182918181810101810101810101810102918182918183929213929214A3131
5239313929213121214229215231294A2118A58484D6C6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7E7DEE7D6C6CE9C8C8C947B738C736373524A634A42634A42634A42734A39
634A425A42396B524A735A52634A4263524A6B524A63524A5A42395A42395A42398C73637B635A\
8C73637B635A7B635A8C7363846B5A634A42523931634A42735A525A5252735A52
7B635A7B635A7B635A735A52634A4A634A42634A42734A427B63525A3129523931634A42634A42\
6342315A4239634231634A42634A425242395A4239634A4A524239634A426B524A
523129524239634A425242395239316B524A5231296342314A31315231295239314A3131524239\
3929214A3131523129312121523129523129392921422931422931392921392921
392921392921392921392921392921392921392921392921422921392921422921422921523129\
422921422921422921422921523129422921523129422921523129392921392921
3121185231293121185231293929213121184A2118523129422921523129312121392921422921\
392921392921392921312118422921422921392921312118291818291818211010
211010291818211010291818291818181010181010211010181010211010291818181010181010\
181010211010181010181010291818291818392921392921312121422921392921
291818422921523931422921422921AD8C84EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFDECED6CEBDC6A5848494736B7B635A6B524A5A4239634A426B524A
6B524A634A42634A42735A525239315A42395A4239634A4263524A5242395239315A5252735A52\
7B635A7B635A7B635A7B635A7B635A7B635A634A4A5242395242395A4239735A52
7B635A8C736B8C73637B635A7B6352634A42634A42734A42734A42422921634231634A425A4239\
5A42395A42395A4239523931634A42523931634A42634A42634A42634A426B524A
523129523931422931634A424229316B524A5242394A31314A3131523129422931392921523129\
4231394229314A3131523129392921422931422921392921392921392921392921
312121392921392921312118312121392921392921392921392921422921392921422921422921\
392921312118422921422921422921422921312118523129422921422931392921
3121183121183929213929213929213121183121184A2118422921422921312121312121422921\
392921312118312121312121312118422921392921312121312121392921312121
291818211010291818291818291818211010211010291818181010181010181010291818181010\
181010181010211010291818312121392921392921392921422921523931312121
4229215231294229216339318C6352DECED6EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEE7DED6E7CEBDC6AD9494947B736B524A634A425A4239634A42
6B524A634A42634A4263524A634A42524239634A42634A426B524A63524A5A42395A4239634A42\
6B524A735A52735A527B635A7B635A7B635A7B635A7B635A735A527B635A735A52
634A425A4239634A42634A425A4239634A42734A396B524A6B524A4229215A31296342315A4239\
634231634A425A4239523931523931523931523931634A42634A425A4239634A42
4229315231295231295A42394A3131634231634A424229313929213929215231294A3131312118\
4A3131523129423139523129392921392921422921392921392921422921392921
392921312121312118392921312118312121312118392921392921312121392921392921392921\
422921312118392921422921422921422921312118392921422921523129392921
312121312118312118421810392921312118312118312118392921392921422921312118312121\
422921312121291818291818312121392921392921312121312118392921312121
312118291818211010291818291818181010211010211010181010181010181010181010291818\
291818181010291818312121392921312121312121422921523931392921523129
5231295231296339318C7363AD9CB5F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7DECED6DED6E7CEBDCE9C8C8C734A42634A42634A42634A42
6B524A6B524A6B524A634A426B524A634A425A4239634A42634A42634A4263524A5A4239524239\
524239634A426B524A735A52735A527B635A7B635A7B635A7B635A735A526B524A
63524A63524A63524A6B524A5A4239634A426B524A73524A734A39523129523931523931523931\
634A42634A42634A425A42394A31314A31315242395A42395A42395A42395A4239
423139523129422931523129524239523129634A425231294A3131392921422931422931523129\
312121392921422931422931523129392921392921392921312121392921392921
392921312121312121312121312118312118312121312118392921392921312121312121392921\
422921312121312118392921392921392921422921312118392921523129392921
291818392921312118291818312118392921312118312118422921392921422921312121312118\
392921312118312121291818291818392921392921312118312121312118312121
312121291818291818181010291818291818291818211010181010181010181010181010291818\
291818312121312121392921312121312121422921523931392921312121422921
5231295A3129845242BDA59CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7EFEFE7DEE7DECED6C6ADAD7B63526B524A5A4239734A39
634A426B524A735A526B524A63524A6B524A52394A5A42395A4239634A42634A4A5A4239735A52\
735A5263524A63524A63524A634A426B524A7B63528C73637B635A735A525A5252
7B635A7B635A735A525A52525A42395A4239634231634A425A4239422921523931523129523931\
5A4239734A39634A425A42394A31315231294A31315A42395239315242395A4239
5A42394A31314A31315231294231394229315A42393929214A3131392921392921422921422931\
3121213929213121215231294A3131523129392921392921392921291818312121
312121312121422918312121312121312118291818291818312121392921392921392921422921\
392921392921291818312118392921392921392921312121312118422921422931
312121291818392921312121312118392921392921312118312118422921422921312118312118\
312121291818291818291818291818291818312121312121291818291818291818
291818291818181010181010181010211010181010181010181010181010181010211010291818\
291818312121392921312121312118422921523931312118392921523129523129
5A4239734A42AD9494F7F7F7F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFDECED6D6C6D6846B5A7B6352634A425A4239
5A42396B524A6B524A634A426B524A735A5263524A5A4239634A42634A4263524A634A4A634A42\
6B524A7B635A735A5263524A634A4A634A425A4239634A42735A527B635A735A52
7B635A7B635A8C736B735A52634A42634A425239315A4239634231523129523129523129523129\
5239315A4239634A425A42394A31315231294A3131634A42423139523931634A42
5A42394A31314231394A31315242394229214A3131392921422921423139392921422921422931\
5231293121213929213121213929214A3131422931392931312121312121291818
312121312121312121312121291818312121291818291818291818392921392921392921392921\
392921312118312118291818312118392921392921392921312121312118523129
392921211010312121312121291818291818392921312121291818392921392921312121312118\
312121291818291818312121312121291818291818211010291818291818291818
181010291818181010211010291818291818181010181010181010181010211010291818291818\
3121183121213121213121214A31315A42394A31314231395A4239523931523931
734A42947B73EFE7E7F7F7F7EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6D6C6CE9C8C8C8C736B6B524A634A42
5A4239634A42634A42634A42634A42735A52735A5263524A634A4A63524A735A52634A4A524239\
524239634A4263524A735A52735A527B635A5A52525A4239524239634A42634A4A
634A4263524A7B635A735A525242395A42395A4239634231523931422921422921523129523129\
5239315239315A42395A42394A31315231294A31315A42395242394A31315A4239
5242393929215231294A31315239314229213929215242393929214A3131422931392921392921\
422921291818312121312121291818392921422921392921392921312121312121
291818312121312121312121312121312118291818291818211010291818312121312118312118\
392921392921312121291818291818291818291818312118312121312121312118
523129291818291818392921312121291818312118392921312118312121312121312121291818\
291818291818291818291818291818291818291818291818291818181010291818
291818291818211010181010291818211010181010181010181010291818312121312118312121\
312121312121291818422921523129392921523129422921422921312118734A39
9C7363DECED6F7F7F7EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFDED6E7A5848494736B7B635273524A
634A425A4239734A39634A42634A42634A42735A527B635A63524A634A42634A42735A52634A4A\
5A42395A423963524A735A527B635A735A52735A52735A5263524A5A42395A4239
634A4A735A527B635A735A525A4239634A425A42395239315239314229215231294A3131422921\
5231295231296342315A42394A31315231294A31315239314A3131523129422931
4A31314229213121184A3131422921422921312121523931422931392921422931392921392921\
312121312121291818312121312121312121392921392921422921392921312121
291818291818312121291818312121291818291818291818291818291818312121312121392921\
312121392921392921291818291818291818291818291818312118312121312121
392921392921291818312121392921291818291818312121312121312118291818312121291818\
291818291818291818211010291818291818291818211010211010211010181010
211010181010181010211010211010181010181010181010291818312121312121312121312121\
2918182918184A3131523129312121422921392921312118392921523129846B5A
CEB5BDF7F7F7F7F7F7EFE7E7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5ADA58484947B737B635A
735A52634A425A42396B524A6B524A634A425A4239634A42735A52634A4A634A42524239634A42\
63524A634A42634A42634A42634A42735A52735A525A525263524A5A4239524239
5A42395242395242394231395231295242396B524A634231523931422921523129392921312118\
4229214229214229215242395239314A31315231294229314A3131523129422931
4A3131524239523129312118392921523931392921392921523129312121312121523129312121\
291818392921392921312121291818312121312121392921312121392921312121
312121291818291818291818291818291818291818291818291818312121291818291818312121\
312121312121312121392921312121211010291818291818291818291818291818
312121312121312121291818291818392921392921291818291818312121291818291818312121\
181010291818211010181010211010291818181010181010181010181010181010
181010181010181010181010291818312121312121312121312121312121291818291818312118\
4229215231293929215231293929213121185231295A42398C5A4A9C6B52D6BDC6
F7F7F7EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7B5A5ADA5847B94736B
846B5A735A52634A425A42396B524A73524A634A42634A426B524A735A5263524A5A4239634A42\
634A42634A42634A42634A4263524A524239634A42634A4263524A6B524A63524A
634A425242395242394A3131523129523931634A42523931523931392921523129422921392921\
4A21184229213121184A31314A31314A31314229214229214A3131422931422921
4A313152393152394A312121312121523129423139312121422921422931312121392921392921\
211010312121392921312121291818312121312121392921392921392921312121
291818291818291818291818291818291818312121312121291818312121291818291818291818\
291818392921392921392921312121291818291818291818291818291818312121
312121312121312121312121291818291818422931392931312121291818312121211010291818\
291818211010211010181010181010211010181010181010181010181010181010
181010181010291818312121312121312121392931392921312121291818291818312121422931\
3929213121215231293929213929215231296342318452429C6B52A5735AEFE7E7
EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDEAD9494947B73
8C736B7B635A6B524A634A426B524A6B524A6B524A634A42524239634A42735A52634A426B524A\
634A4A524239634A42634A42634A42735A526B524A63524A524239524239634A42
523931423139422931392921523129634231734A425A4239523931422921422921392921312121\
3121184229213929215231294A31314A3131422921392921422921422921392921
422931392921634A4A392921312118392921524239291818312121392921392921312118392921\
312121312121392921312118291818291818291818291818392921312121291818
312121291818291818291818291818312121291818291818312121312121291818291818312121\
312121312121392921312121312121312121181010291818181010291818312121
312121291818312121312121312121291818312121423139422931312121291818291818181010\
211010181010181010181010181010211010181010181010181010181010181010
291818312121392921392921392921392921392921291818291818312121392921312121392921\
312121523129422921422921523931734A398452428463529C6B529C7363EFE7E7
E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFCEB5BDA58484
947B73846B5A7B63526B524A5A42396B524A6B524A735A52634A425A423963524A634A4263524A\
6B524A7B635A63524A63524A6B524A6B524A5A5252735A52735A52735A52634A4A
634A4A634A4A524239422931523129634A426B524A523931523931523129422921392921392921\
3121183929213929214229214229214A3131523129392921392921422921392921
4229213929215242394229312918183929214A3131291818291818312118392921291818312121\
392921291818312121312121312121291818312121291818291818312121312121
312121291818291818291818291818291818291818291818312121291818312121291818291818\
312121312121392921523129423139312121312121181010291818291818181010
312121312121312121312121392921392931291818291818312121392931291818211010181010\
181010181010181010181010181010181010181010211010291818291818312121
312121392921422931392921312121312121312121312118312121312121392921523129523129\
5231294229215A3129634231734A39734A398C5A42A5735A9C7363C6ADADF7E7DE
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7ADA5B5
9484848C6352846B5A7B63525A4239634A426B524A6B524A634A425A4239634A42735A52634A4A\
5A42396B524A7B635A735A5263524A73524A6B524A634A42634A42634A4263524A
63524A634A424231394A3131523129634A42634A42634231523129422921422921422921392921\
3121213929213121183121184229214A31314A3131392921392921312121392921
392921392921392921423139291818312121422921312121312118291818312121312121291818\
291818312121291818312121312121312121291818312121181010312121312121
312121312121291818181010181010291818291818312121291818312121312121291818291818\
312121312121392931423139524239423139423139312121291818291818291818
291818312121312121312121312121312121392921312121291818291818392921392921312121\
312121291818291818211010291818312121291818312121312121392921392931
3929214229313121213121212918183929213121213121213929215231294A31314A3131422921\
422921523129634231734A39734A398452428C73639C6B52AD8C84DECED6F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7
C6ADAD9484848C736B7B635A6B524A5A4239634A426B524A6B524A63524A5A423963524A63524A\
634A4A5A42395A423963524A735A525A525263524A63524A634A4A634A42634A4A
5A4239523931524239422931392921634A426B524A634A425231293929214A3131422921312121\
312118392921312118312121392921422921422921422921392921312121392921
312118392921312118422921291818291818312121392921312121312118291818392921312121\
291818291818312121312121312121291818291818312121291818291818312121
312121312121291818291818291818291818291818291818291818291818312121312121291818\
31212131212131212142313952394A423139634A42423139312121291818291818
291818291818312121312121312121312121312121392921392931392921312121392921392921\
422921392931392921392921312121392921392921392921312121312121392921
4229313121213121183121212918183929213121213929214A31314A3131422921312121422921\
5239316342316342316342318452429C6B52A5735A94736BC6ADA5E7DEE7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFE7E7ADA5B5A5847B8C63527B635A6B524A634A426B524A634A426B524A63524A634A4263524A\
63524A6B524A5A52525242395242397B635A7B635A7B635A6B524A635A63735A52
635A63634A4A5A42395231295231296B524A634A42634A42523931422921422921422921392921\
312118312121392921392921312118392921422921392921392921392921312121
312121312118312121312121312121291818312118422931312121312121291818312118312121\
312121312121291818291818312121312121291818291818312121181010291818
312121312121312121181010181010291818291818291818291818312121312121312121291818\
2918183121213929213121215242395A52524231397B635A52394A392921312121
291818312121312121312121291818291818312121312121312121392921392931392921392931\
392921392931392931392931392921392921392921312121523129423139523129
392921312121291818291818392921523931523129523129422921312121312118523129634231\
734A3963423163423184523994634AA56B529C6B52AD8C84D6CEDEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFCEBDCEA5848494736B846B5A735A526B524A63524A634A426B524A634A425A4239\
5A423963524A63524A735A52735A52735A525A5252735A52735A527B635A63524A
735A52735A5263524A5242395242396B524A634A42634A425A42394A3131422921523129422931\
392921312121312121312121312121291818392921422921392921312121312118
312121312118312118312121392921291818291818312121392921312121291818312121312121\
291818291818312121291818312121291818291818291818291818291818181010
291818312121392921312121291818181010181010291818291818291818291818312121392921\
3121213121213121213121213929315242396B636B5A5263423139634A42635A63
5A5252392931312121423139422931392921312121312121291818312121312121291818312121\
312121312121312121392921422931422931392921392921312121312121312121
3121214229215242395242395A4239523129392921392921523931634231634231523931523129\
634231734A397B63528C5A4A9C6B528C7363CEB5B5F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7CEBDC694736B94736B846B5A735A52735A52634A4A63524A63524A6B524A\
634A42634A426B524A63524A634A427B635A7B635A735A5263524A634A42524239
5A42395242395242395231295231296B524A73524A5A42395A4239523931523129422921422921\
422921422921312121312118312118312121312121422921392921312121312118
312118312121312118312118312121392931211010392921392921312121291818291818312121\
312121291818312121312121211010312121291818291818291818312121181010
291818291818312121392931291818291818181010181010181010211010291818312121312121\
4231393929313929213929393121213121215A4A5A7B635A6B636B5A4A5A423139
634A4263524A63524A423139524239422931524239423139423139392931312121312121291818\
3121213121213121213121213121213121213121212918183929215231294A3131
523931523931634231523931312118312121523129523931634231523931523129523129634231\
634231734A398C5A4A9C6B529C7363C6ADADFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEF8C737B94736B947B73846B5A735A52735A526B524A6B524A63524A\
634A425A4239524239634A4252423963524A63524A735A52735A52735A52735A52
735A52735A52634A4A634A4A524239634A42735A526342315A42395A4239523129523129523129\
392921422921392921291818291818312121312118392921422921392921312121
312121312121291818312121312118392921291818291818392921312121312121291818312121\
312121211010291818312121291818312121291818291818291818312121291818
291818291818312121392921291818291818291818291818181010181010291818291818291818\
42293152394A4231394231394A394A3929395242395A5252635A637B635A5A5252
422931523129422931423139423139524239423139423139524239524239422931422931392921\
3929313929213121213121213929213929214229215231294A31315A3129523931
5A42395231294A3131422921523129633931523931634231523129523129634231634231634231\
734A398452429C6B529C6B52AD9494F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7D6C6D6A584848C73638C7363846B5A846B5A7B635A5A525263524A\
634A42634A425A42395242395239315A4239634A4A63524A6B524A63524A63524A
63524A735A527B635A735A526B524A634A426B524A634A425A42395A42395239314A3131523931\
523129422921422921291818291818312118291818312121422921392921392921
312118312118312121312118312121312121312121291818312121392921312121291818291818\
312121291818181010291818312121291818312121291818291818291818312121
291818291818312121312121312121291818181010291818291818181010181010181010291818\
29181831212163524A524239423139634A42423139422931634A42635A637B635A
635A63635A635242394229314229314229315231293929315231294229314A3131423139423139\
4229313929214229214A3131523931523931523931523931523931422921392921
4229215239315231295239315239315239315239315239315239316B524A734A39734A397B6352\
8463528C5A4A945A52AD9494F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFDECED68C737B8C736394736B846B5A7B635A735A52735A52\
735A5263524A634A425A4239524239634A4263524A63524A63524A635A637B635A
7B635A7B635A63524A63524A735A525A5252634A425A4239634231634A425242395A4239523931\
523931422921422921392921291818291818312121312121392921392921392921
291818312121312118291818312118291818392921291818312121312121392921291818291818\
312121312121291818291818291818312121312121312121291818291818291818
291818291818291818312121312121291818291818291818291818291818291818291818291818\
1810101810103121215A52525A525252394A52394A52394A42313942313963524A
7B635A7B635A6B636B735A527B635A735A525A4A5A634A4A634A4A52394A634A4A6B524A735A52\
634A4A634A4A634A4A5A4239524239523129392921392921312118392921523129
5239315A42395239315239315239315A42395A42395A42396B524A734A42734A39734A42845242\
8C5A4A846352AD8C84F7EFEFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDC6A584848C736394736B846B5A735A52735A52\
735A52735A526B524A634A42634A425A4239634A425A5252735A52735A52735A52
735A525A52527B635A6B636B7B635A7B635A6B524A634A425A4239634A425A42395A4239523931\
524239523931422921422931392921291818291818312121312121422921392921
312118291818392921312121312121312118392921291818291818312121312121291818291818\
312121291818312121291818291818291818312121312121291818291818291818
291818291818312121312121312121312121291818291818291818291818291818291818312121\
291818291818291818312121634A4263524A5A525263524A52394A4A394A423139
422931423139634A42524239634A425A52527B635A735A52735A526B524A6B524A6B524A634A42\
634A425A42395239314229314229213929215231295239315A4239734A39634A42
634A42634A42634A42734A39634A42634A42634A426B524A734A39634231734A39734A39845242\
8C5A4A94634ADECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE9C8C9C8C7363846B5A7B635A6B524A\
6B524A63524A6B524A6B524A63524A5A4239524239634A4263524A6B524A5A5252
735A525A52526B636B7B635A7B6B7B6B636B7B635A735A525A42395A42395A4239524239634231\
5239315239314A31315231294A31313121212918183121213121213929214A3131
422921312121312118312118312121312121312118291818291818312121392921392921291818\
291818291818291818291818181010291818312121312121291818291818291818
291818291818291818312121312121312121312121291818181010291818291818291818392921\
3121213121213121212918183121213929315A525252394A634A42634A425A5252
5A525252394A5242394A394A3929313929213121213929213929213929214A3131524239523931\
5239315A42395A42395A42395A42395A42395A42395A4239634A426B524A634A42
634A42634A42634A42634A42634A42734A39634231634231634231634231734A428C5A4A9C6B52\
9C6B52947B73F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFE7E7AD94947B63527B635A\
7B635A735A526B524A634A42634A426B524A6B524A6B524A735A526B524A735A52
5A5252735A527B635A7B635A7B635A8C7B737B6B7B7B635A735A525239315A4239523931523931\
5A42395A42395A42395239315231295239315A4239422921312121392921392921
4A3131422921392921392921312121312121392921422921291818291818312121312121312121\
312121291818291818312121291818291818291818312121392921291818291818
291818312121291818312121312121312121312121312121312121312121291818312121312121\
312121312121392921423139422931422931392931312121422931634A42634A42
634A42634A424A31315239315A423963524A634A426B524A735A525A525263524A6B524A6B524A\
735A5263524A63524A634A42524239524239634A425A4239634A425242395A4239
524239523931523129523129523129634231634231734A398463529C6B528463528C5A4AA5847B\
D6BDC6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F794736B8C6352\
7B6352735A52846B5A7B635A63524A634A4263524A6B524A735A52735A527B635A
7B635A735A527B635A6B636B7B635A7B635A8C736B7B635A7B635A634231523931523931523931\
5A42395239315239315239315231294A31314A3131634A4252394A392921422921
5242394A31314A3131422921422921312121422931392921392921211010291818392921312121\
312121291818291818312121392921312121291818291818312121312121291818
291818312121392921312121392931312121312121312121312121392931312121312121392921\
392931423139312121312121312121422931524239524239422931392939422931
634A425A5252634A4A392931312121392921392921422931392921392921422931392921392921\
5231293929213121213121214A31314A31314A31314229215231295242395A4239
5239315231295231295A3129634231734A398452428452429C6B52846352945A52947B73DECED6\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9CB594736B\
8C7363735A526B524A735A5273524A6B524A63524A634A42634A426B524A5A5252
7B635A7B635A7B635A7B635A8C73638C736B9484849C8C8C9484846B524A523931523931523931\
5239315A42395A42395239314A31315231295231294A3131634A425A42394A3131
5242395242395242395242394A3131422921392921392921423139392921291818392921312121\
392921312121291818291818312121422931312121291818312121392921312121
291818312121422931422921392931392931312121392921392931392931524239392921312121\
3929214229314A394A392931312121312121392921422931423139524239392931
39293139292152423963524A634A4A4231394229313121213929213929213121214229214A3131\
4229315231294A31315239315231294229215231295239315A4239634231523129
5231296342316342317342317B6352734A428452428463528C63528C5A4A947B73DECED6F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD\
947B738C7363735A526B524A634A426B524A6B524A6B524A6B524A63524A63524A
735A525A52527B635A7B635A8C736B8C7B73948484A5847B8C737B6B524A6B524A5A42395A3129\
5239315239315239315239315239315231295231295231294A31315239315A4239
5A42395A42395A42395A42395A42395242394229214A3131422931634A4A392931312121523129\
312121312121312121312121312121312121392921392921312121422931392921
3121212110103121214A313152394A4231393929213121214231393929314229315A5252392921\
422931422931634A425A525252394A423139423139423139423139423139392931
3929313929313929213929215242395242395242395242394A31314A31315A4239524239524239\
524239523931523931523129523931634A425A4239634231523129523129634231
634231734A42734A396B524A734A398452428C5A4A8C6352846352AD9494DECED6F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
D6C6CE9484848C63527B635A735A52634A42634A426B524A6B524A6B524A634A42
634A42735A525A52527B635A7B6B7B8C73638C736B8C7B738C7B737B6B7B7B635A735A525A4239\
5239315239316339315231294A31315239314A31315231294A31314A31314A3131
5A4239634A425A4239524239634A42634A424231395242394229215A5252635A63312121392921\
4229314229312918183121214229315231293929314A3131422931422931392921
42313939292131212129181852423952394A4231394231394229315A52634A394A4229315A4A5A\
4231394A3131422931634A426B636B635A636B524A5A4A5A5A52525A4239524239
4A394A4A31314231394A31314229314229314231395A4239634A4A634A42523931524239523931\
5239315239316342315A4239634A425239315239315A4239634A42734A4273524A
734A42734A398452428452429C6B528C73638C6352846352B5A5A5F7EFEFFFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7D6C6DEAD8C848C73638C73636B524A634A425A42395A4239634A4263524A
6B524A5A52527B635A6B636B8C736B8C736B8C736B8C7B738C7B739484848C736B846B5A7B635A\
634A425242395239315239315231295231295239314A3131523129523129524239
5231295A4239634A42634A42634A42634A4A5A4239524239524239392921735A525A4A5A312121\
4229314229213929212918183121214A31315242394231395242394229314A394A
4231395242394A394A423139524239635A635242395A52524231395242397B737B524A5A6B524A\
7B6B7B635A63422931392931392921634A425A52527B635A7B635A5A5252634A4A
634A4A634A4A634A425A4239634A42634A42634A425A4239634A42634A425A42396342315A4239\
5A4239634A42634A42634A426342316B524A73524A7B635273524A6B524A734A39
634A427B63528452428C6352A5735A8C63528463528C5A4AF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D6CEDEAD94A59484847B635A6B524A6B524A634A425A4239634A42
634A426B524A735A527B635A7B635A8C736B8C736B9484849C8C8C9484848C7B73635A63735A52\
7B635A6B524A634A42634A425A42395239314A3131523129523931524239523931
4229315231295239315A4239634A426B524A6B524A634A4A634A4A52423942293163524A4A394A\
31212142292142313939293129181839292142293152423952423952394A524239
5A525252423963524A5A4A5A52394A6B636B5A525252394A6B524A52423952394A6B636B52394A\
5242398C736B7B6B7B6B524A4A394A4231394A3131524239634A4A634A42634A4A
634A425A42395A4239634A425A42395A42395A42395A4239634A42634A42634A42634A42634A42\
634A42634A42634A426B524A73524A8452427B635273524A734A39734A39734A39
734A398452429C6B528C6352845242734A3973524AB59C9CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7E7DEEFCEBDCE8C7363846B5A7B63526B524A634A42634A42
5242395A42397B635A635A63735A527B635A8C7B849484848C736B9484849C8C8C9484848C736B\
7B635A7B635A735A526B524A6B524A735A526B524A5A42394A31315A42395A4239
5231294A31314A31315A4239735A52634A4A735A52634A4A6B524A735A525A42395231297B635A\
4A394A5239314229215A423942313931212131212152312952394A5A5252634A4A
52394A52394A63524A6B636B6B636B7B737B6B636B5A52525A5252635A63634A4A5242397B6B7B\
5A52525A52526B636B5A52527B635A7B635A5A4A5A5A5252634A4A63524A6B524A
634A4A5A423952394A634A426B524A6B524A6B524A73524A73524A6B524A6B524A735A52735A52\
734A42734A4273524A845242734A39634A42634231734A39734A39734A39845239
8452429C6B52846352734A39734A398C736BCEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6CEDECEB5BD9484948C736B846B5A7B6352
735A5273524A846B5A7B635A735A527B635A7B635A7B635A7B635A8C736B7B737B947B73948484\
9484848C7B737B635A846B5A735A52846B5A8C736B8C73638C736B846B5A7B635A
735A526B524A634A425242395242396B524A6B524A634A4A7B635A7B635A7B635A735A52634A42\
735A526B636B635A635A5252634A4A7B635A52394A3121213121216B636B635A63
634A4263524A5A525263524A5A52526B636B7B635A7B737B6B636B6B636B7B635A5A4A5A634A4A\
634A4A5A4239634A426B524A7B635A735A5263524A634A4A6B524A634A42634A42
6B524A634A42634A426B524A6B524A634A42634A42734A39634A42634A42734A39634231634231\
634A42634A42734A39734A398452428452428452428463528C5A4A94634A8C5A4A
7B63525A42397B6352BDA59CF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFD6C6CEAD94A5947B738C737B
7B635A735A527B635A735A526B524A6B524A735A525A5252735A528C736B8C737B9484847B737B\
8C736B8C7B738C736B8C736B947B738C7B738C736B8C736B8C7B738C736B8C7363
8C7B738C736B7B635A735A52634A4A634A4A6B524A6B524A5A52527B635A7B635A7B6B7B7B6B7B\
735A527B635A6B636B8C7B73635A635A5252736373634A4A4231394229317B635A
5A4A5A52423952394A524239634A4A634A4A5A52527B635A7B6B7B6B636B735A5263524A6B524A\
735A526B524A5A5252634A42634A426B524A73524A735A52735A527B635273524A
73524A73524A73524A734A42734A42734A39634A42634231734A39734A39734A396B524A6B524A\
734A398452427B63528463528C5A4A8C5A4A9C6B52A5735A94634A7B6352845242
734A3994736BCEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFE7DEE7C6ADBDB5A5A5
A58484947B737B635A735A527B6352735A52735A52735A527B635A8C736B8C7B738C7B738C7B73\
8C737B9C8C8C9C8C8C8C736B947B73947B738C736B846B5A8C7B73947B738C7B73
8C736B846B5A8C736B8C7B738C736B8C736B7B635A6B524A6B524A6B524A735A526B636B8C7B73\
7B6B7B7B6B7B7B635A7B6B7B7B737B7B635A7B635A6B636B635A63422931523129
634A42634A425242395242395239315A42395A5252735A527B635A8C7B73635A63634A4A6B524A\
6B524A6B524A73524A6B524A735A526B524A6B524A634A4263524A634A42634A42
634A42634A426342315A4239634231634231634231634231634A426B524A734A4273524A845242\
73524A8463528C5A4A8463528C63529C6B528C6352845242845242734A395A4239
73524AD6C6DEFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6DE
B5A5AD947B736B636B846B5A735A527B635A7B635A735A52735A528C736B8C736B8C7B73948484\
8C736B8C7B738C736B8C736B8C7B738C736B8C736B846B5A846B5A8C736B8C736B
8C7B738C7B738C736B8C7B738C736B8C736B8C736B8C736B635A637B635A7B635A735A52735A52\
8C7B738C736B7B737B6B636B735A527B635A7B737B7B737B6B636B5A4A5A634A4A
52394A52423952394A5A42394231394A31315239315239315A4239634A427B635A8C736B6B524A\
6B524A6B524A634A426B524A734A395A42395A42395A4239634231634231634231
6342315A42396342316342315A4239734A39734A4273524A84524273524A7B63528C5A4A846352\
8463528C5A4A8C63528C5A4AA5735A846352845242734A395A4239734A4294736B
D6C6D6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
E7DEEFBDB5BD9C8C8C8C736B7B6352735A527B6352735A527B635A63524A7B635A8C736B8C736B\
8C736B8C7B738C736B9484848C736B8C736B8C736B8C736B8C736B8C736B8C736B
8C7B738C736B8C736B947B73947B7394736B8C736BA5847B947B738C7B738C736B8C736B735A52\
735A528C7B738C737B8C7B738C7B73635A637B635A8C7B738473846B636B735A52
634A4A6B524A634A4A634A4A5A42395242394A31314229314A31314A3131523931634A42846B5A\
735A52634A42634A42634A42634A42634A425A4239634231634A42734A39634A42
6B524A734A39734A42734A42734A4273524A734A42845242734A428C5A4A8C5A4A8C63528C6352\
8C6352A5735A8C63529C6B52846352734A395A42395A42398463529C8C9CEFE7E7
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7CEBDC6AD94A58C737B7B63527B63526B636B7B635A735A527B635A8C73636B636B\
8C7B738C737B9484849C8C8C8C737B8C7B738C7B739484848C7B738C7B738C7363
8C7B738C7B73846B5A8C736B8C7B73948484947B73947B73948484A5847B8C7B738C737B947B73\
7B6B7B8C7B738C737B8C736B9484849484847B6B7B735A528C736B8C7B737B6B7B
7B635A635A636B524A52394A634A4A634A4A634A4A5A42395A42395A4239524239634A42634A42\
735A527B635A7B635A735A5273524A634A4273524A6B524A734A396B524A734A42
8452427B635273524A73524A8C5A4A73524A7B63528463528C6352846B5A8C7363A5735A9C7363\
8C7363A5735A8C6352845242633931634A428C6352A58484D6C6CEFFFFFFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFFF7EFEFD6C6D6AD94A59484848C7363846B5A846B5A735A52735A527B635A\
7B635A8C736B8C736B8C737B7B737B8C736B8C73637B635A8C737B9C8C8C948484
8C736B94736B8C7B738C7B738C736B8C7B738C7B738C736B947B739C8C8C947B73A5847BA5847B\
947B73947B738C736B8C736B947B739484849484848C737B8C736B8C7B738C736B
7B635A8C736B8C736B846B5A7B635A7B635A7B6352735A52735A52735A52735A52735A526B636B\
7B6352735A5273524A73524A735A527B635273524A7B6352734A4273524A7B6352
73524A73524A8C5A4A846B5A846B5A846B5A9C73639C7363AD7B6B9C736394736B9C7363A5735A\
8C7363845242734A39734A39846352AD9494D6C6DEF7F7F7FFFFFFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF9C8C9C6B636B73524A524252\
735A526B524A6B524A635A637B635A7B737BAD9494AD94949484848C737B948484
9C8C8CA5847B948484A5847B9C8C8C948484947B738C7B738C736B8C736B8C7B73947B73A5847B\
947B73947B73947B73947B73947B73947B73947B738C736394736BA5847B9C8C8C
947B73947B73947B738C736B846B5A846B5A846B5A8C736B8C736B8C63528C73638C63528C6352\
945A52846B5A945A529C6B52846B5A8C63529C6B52846B5A9C736394736B94736B
94736B94736BAD7B6BAD7B6BAD846B947B73AD846B8C73638C7363AD846B73524A734A42634A42\
734A42846352A58484CEBDC6FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6D6AD94A59C8C8C\
6B636B735A52735A52735A52735A528C736B8C736B9C8C8C9C8C8C9484849C8C8C
9C8C8C9C8C8C9C8C8C9C8C8CAD9494AD9494948484947B73947B73947B738C736B8C7B73948484\
947B73947B73947B73947B73948484A58484AD847B9C8C8C94848494736B94736B
947B73947B7394848494736B94736B8C73638C7363846B5A846B5A8C73638C7363846B5A846B5A\
8C7363846B5A846B5A846B5A846B5A8C736394736BAD7B6B947B73AD846BB58C73
B58C73B58C73B58C73A5847BAD846BB58C73AD846BA5735A8C63527B635273524A8463528C6352\
A58484D6BDC6F7EFEFFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7\
BDB5BDAD9CB5AD9CAD8C7B8C8C7B738C7B8C8C7B8CAD9494B59C9CA594A5B59C9C
C6B5C6B5ADBDB59C9CAD9494B59C9CAD9CA5B59C9CA58484A5847B948484A5847BA5847B947B73\
947B737B635A8C7B73947B73947B73A5847BA5847BA58484A5847BA5847B9C8C8C
A5847BA5847BA5847BA5847B947B73947B73947B7394736BA5847B8C736394736B94736B8C7363\
8C736394736B94736B947B73947B73AD7B6BA5847BA5847BA5847BAD846B947B73
8C7363846B5A846B5A8C73638C736373524A73524A73524A73524A8452428C73638C737BCEB5BD\
F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7E7DEEFE7DEE7E7DEEFEFE7E7D6CEDED6CEDEDED6E7D6C6D6
E7DEEFDED6E7C6B5C6B5A5ADCEBDB5BDB5BDAD9CA5ADA5B5B59C9CAD9494AD9494948484948484\
948484A5847B947B73947B738C7B738C736B8C736B8C736B8C736B947B73B58C73
A58484AD8C84AD8C84A5847BA5847BA5847B947B7394736B947B73947B7394736B94736B94736B\
94736B947B73AD7B6B94736B9C73638C736394736B8C73638C7363846B5A8C6352
846B5A8C73638C73637B635273524A73524A73524A73524A8C635294736BDECED6F7EFEFFFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE7DEEFE7DEEF
EFE7E7F7F7F7D6C6D6C6B5C6C6B5C6DECED6BDB5BDE7DEE7C6B5C6B5A5ADAD9494AD9494AD9494\
B59C9CA58484947B73947B73A5847B94736B94736B8C7B738C736B7B6B7B846B5A
8C7B73947B73947B73A5847B947B73A5847BA5847B947B738C736B8C736B94736B8C736B8C736B\
94736B94736B8C73638C73638C736394736B94736B8C7363846B5A846B5A846B5A
846352846B5A846B5A8C5A4A846352846B5A947B73AD94A5AD9CB5D6C6CEFFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
EFE7E7E7DEEFE7DEE7DED6E7D6C6D6D6C6D6DED6E7D6CEDEEFE7E7E7DEEFD6C6D6B5A5ADAD9494\
AD94A5AD9494AD9494AD8C849C8C8CA5847B947B73A5847BA5847B94736B94736B
8C736B947B738C7B738C736B947B73A58484A5847B9C8C8CA5847B947B738C7B73947B73947B73\
94736B8C736394736B947B7394736B94736B8C73638C7363846B5A7B635A735A52
7B635273524A73524A8C736B948494C6ADBDD6C6DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFEFE7E7F7F7F7E7DEEFEFE7E7EFE7E7E7DEEFF7EFEFF7F7F7EFE7E7D6CEDED6C6D6\
D6C6CECEBDC6B5A5AD9C8C9CAD9494AD94A5B5A5A59C8C9CAD8C84948484947B73
947B7394736B947B73A5847B947B738C7B73947B73947B73947B739C8C8CA5847B947B73947B73\
94736B8C736B8C736B8C736B94736B8C73637B635A846352735A52735A52846B5A
846B5A8C737BAD94A5D6C6DEF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFE7DEE7D6C6DED6C6CED6BDC6AD9CB5
B5A5ADB5A5ADB59C9CAD9494AD9494AD8C84948494A58484AD8C848C737B8C737B948484948484\
948484AD94949C8C9CB59C9CAD94A5CEB5B5DECED6D6CEDEF7EFEFE7DEEFF7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFE7DEEFE7DEE7E7DEE7DED6E7CEBDC6CEBDC6D6C6D6DECED6DECED6D6C6DEE7DEE7EFE7E7\
E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -53 0 ]
[.5 1.0125 53 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Generated) show
123.000000 12.812500 moveto
(128) show
141.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(128) show
165.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math1Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
D3D2D1DDDBDADAD8D7D7D6D5D8D8D7D8D8D7D8D8D7D8D7D6D8D7D6D8D7D6D8D8D7D8D8D7D8D9D8\
D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8
D8D9D8D8D9D8D8D9D8D8D8D8D8D8D7D8D8D7D8D7D6D8D7D7D8D8D7D8D9D8D8D9D8D8D9D8D8D9D8\
D8D9D9D8D9D9D8D9D9D9DAD9D9DADAD9DBDBD9DCDED9DCDED8D6D3D7CDC4D7C9BF
D9CBC1D9CDC5D9CEC6D9CFC9D9D1CBD9D0CAD9CEC8D9CEC8D9D1CBD9D2CCD9D2CCD9D2CBDAD2CA\
DAD1CADAD1C9DAD0C9DACFC8DACFC7D9CFC6D8CEC4D6CCC2D5CAC1D4C7BFD3C4BC
D2C1B8D1BFB7D1BFB7D0BFB7CEBEB6CEBEB5CFBFB7D0C0B8D0C1B9D1C1B9D1C1B9D1C1B9D1C1B8\
D1C0B8D1BEB6D0BDB5CEBDB3CCBDB2CCBDB3CCBCB3CBBBAFCAB9ACC8B7ACCBBFB8
D3D1D0DAE0E2DBE1E3DADDDED9DBDCD9DBDBD9DADAD9DADAD9DADAD9DAD9D9D8D7D9D7D7D9D9D8\
D9DADAD9DAD9D8D9D9D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8D8D9D8
D8D8D8D8D8D7D8D8D7D8D8D7D7D8D7DADAD9DDDDDCD3D3D2
DDDBDAEDE6E6EAE3E2E6E3E2E7E6E5E7E7E6E7E6E5E7E3E2E7E2E1E7E3E2E7E6E5E7E7E6E7E7E7\
E7E8E7E7E9E8E7E8E8E7E8E7E7E8E8E7E9E8E7E9E8E7E8E7E7E7E7E7E7E7E7E7E7
E7E7E7E7E7E7E8E7E7E8E7E7E8E7E6E8E4E4E8E3E2E8E3E3E8E6E5E8E8E7E8E8E7E8E8E8E8E8E8\
E8E8E8E8E8E8E8E9E9E8E9EAE8EAEAE8EBECE9EDF0E9EDEFE9E5E2E9DBD1E9D6CA
E9D7CDE9D8CFE9D9CEE8DCD0E8DED5E8DDD6E8DAD3E8DAD3E8DED6E8E1D9E9E1D9EAE0D6EBDED3\
EBDCCFEBDACDEADACCE8DACDE7DACDE7D9CCE6D6CAE3D3C7E0CFC4DDCBC0DBC7BC
DAC4B9DBC2B8DBC3B9DAC2B8D7C1B7D7C1B7DAC5BBDDC9BEDECAC0DECAC0DECAC0DFC9BFDFC7BD\
DFC5BBDFC4BBDEC4BBDBC4B9D8C3B9D7C3B8D7C1B5D6C0B0D3BFAFD0C1B6D4CDC9
E0E2E3EAF2F5ECF3F7EAEFF1E9EDEEE9ECECE9EBEBE8EBEBE8EAEAE8EAEAE8E9E9E8E9E8E8EAE9\
E8EBEAE8EAE9E8E9E8E8E8E8E8E8E7E8E8E7E8E8E7E8E8E7E8E7E7E7E7E7E7E7E6
E7E7E6E7E7E6E7E7E6E7E6E6E6E6E5EAE9E8EDECEBDDDDDC
DAD8D7EAE3E2E6DFDEE3DEDDE3E1E0E3E3E2E3E2E1E3DFDEE3DDDDE4DFDEE4E2E1E4E4E3E4E4E3\
E4E4E3E4E4E3E4E4E3E4E4E3E4E4E3E4E4E3E4E4E3E4E4E3E4E4E3E4E4E3E4E4E3
E4E4E3E4E4E3E4E4E3E4E4E3E4E3E3E4E1E0E4DEDEE4E0DFE4E2E2E4E4E4E4E5E4E4E5E5E4E5E5\
E4E5E5E4E6E6E4E6E7E4E7E7E4E7E9E5E9EBE5EBEEE5EAEDE5E2DFE5D8CDE5D2C5
E5D2C8E5D4CAE5D5C8E5D7CBE5DAD0E5D9D2E5D7D0E5D7D0E5DAD3E5DCD5E6DCD5E6DAD0E6D7CA\
E4D4C5E1D1C2DFD0C1DFD0C2E0CFC2E0CDC0DECABEDBC7BBD7C4B9D4C2B7D2BFB4
D2BDB2D3BDB2D4BDB3D3BDB3D1BBB1D1BCB2D4BFB5D7C3B8D8C4B9D9C4BAD9C4BAD9C3B9D9C0B6\
DABEB4DABEB4D8BEB4D5BEB4D3BEB4D2BDB2D2BBAED1BAAACFBDAECFC7BFD4D7D7
DFE7EBE8F1F6E9F2F6E7EEF1E6EBEDE6EAEBE5E9EAE5E9E9E5E8E9E5E8E8E5E8E8E5E7E7E4E7E7\
E4E6E6E4E6E6E4E6E5E4E5E5E4E5E5E4E5E4E4E5E4E4E4E4E4E4E4E4E4E3E4E4E3
E4E4E3E3E3E3E3E3E2E3E3E2E3E3E2E6E6E5EAE9E8DADAD9
D7D7D6E6E3E2E3DEDDDFDAD9DFDBDADFDDDCDFDEDDDFDDDCE0DCDBE0DDDCE0DFDEE0E0DFE0E0DF\
E0DEDEE0DEDDE0DFDEE0E0DFE0DFDEE0DEDDE0DEDEE0E0DFE0E1E0E0E1E0E0E0E0
E0E0E0E0E0E0E0E0E0E0E0E0E0E0DFE0DEDEE0DDDDE0DEDDE0E0DFE0E1E1E0E1E1E0E1E2E0E2E2\
E0E2E3E0E2E3E0E3E4E1E4E5E1E4E6E1E6E8E1E8ECE1E7EAE0DEDBDFD2C7E0CCBE
E1CDC0E2CFC4E1D0C5E1D2C7E1D4CBE1D5CDE1D5CEE1D5CEE1D5CEE2D6CFE2D6CEE2D4CAE0D0C3\
DACCBDD4C9BBD2C7BAD5C6B8D8C3B6D8BFB3D6BBB1D3BAAFCFBAAECDBAAFCDBBB0
CDBBB0CEBBB0CFBCB1CFBBB1CEBAAFCEB9AECFBAAFD0BBB0D1BCB1D1BCB2D1BDB2D2BCB1D2BAB0\
D2B9AED2B9ACD1B9ACCFB9ADCEB8AECDB7ACCDB5A8CCB4A5CEBCB1D3D0CCDAE3E7
E1EEF4E5F0F6E5EFF3E4ECEFE3E9ECE2E8EAE2E7E8E2E6E7E1E5E6E1E5E6E1E5E6E1E4E4E1E2E2\
E1E1E1E1E1E1E0E2E2E0E2E2E0E2E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0
E0E0DFE0E0DFDFE0DFDFDFDFDFDFDEE3E3E2E6E6E5D7D8D7
D8D8D7E7E7E6E3E1E1DFDBDADFD9D8DFDBDADFDEDDDFDFDEDFDFDEDFDFDEDFDFDFE0E0DFE0DFDF\
E0DDDDE0DCDBE0DDDDE0DFDFE0DEDDE0DCDBE0DDDDE0E0DFE0E1E0E0E1E0E0E0E0
E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E1E0E1E1E0E1E2E0E2E2E0E2E3\
E0E2E3E0E3E4E0E3E5E0E4E6E1E5E7E1E6E9E1E8EDE1E7EADFDCD9DDCFC3DEC9B9
E0CBBCE1CEC2E2D0C6E1D0C8E1D1C9E1D3CBE1D5CEE1D5CEE2D3CCE2D2CBE2D2CAE1D1C6DECEC1\
D7CBBECFC8BDCDC5BAD2C2B6D6BDB2D7B8AFD4B4ACD1B4A9CEB5A9CDB8ACCEBAAE
CEBBB0CFBCB1D0BDB2D0BCB2D0B9AFCFB7ADCDB6ABCCB6ABCCB7ABCDB7ACCDB7ACCDB7ACCEB7AC\
CEB7ABCEB7A8CEB7A8CEB7AACDB6ABCCB4A9CBB1A4CAB1A3CFBEB4DAD9D8E3EFF5
E6F5FCE6F2F7E5EFF3E4ECF0E3EAEDE3E9EBE2E8EAE2E7E8E2E6E7E1E6E7E1E5E6E1E4E4E1E1E1\
E1DFDFE1E0E1E0E2E2E0E3E3E0E2E2E0E2E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0
E0E0DFDFE0DFDFE0DFDFDFDFDFDFDFE3E3E2E7E6E6D8D8D7
D8D9D8E7E9E8E3E3E2DFDBDBDFD9D8DFDBDADFDEDDDFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE0E0DF\
E0DEDDE0DDDDE0DEDEE0DFDFE0DFDEE0DEDDE0DEDEE0E0DFE0E1E0E0E1E0E0E1E0
E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2E0E2E3E0E2E3\
E0E3E4E0E3E5E0E4E6E1E5E7E1E5E8E1E7EAE1E9EDE1E7EAE0DBD8DECDC1DFC7B7
E0CABCE1CEC3E2CFC6E1CFC7E1CFC8E1D1C9E1D3CBE2D3CCE2D2CAE2D1C8E2D1C6E2D0C4DFCFC3\
DBCDC3D6CCC3D4CAC0D6C6BAD9C0B6DBBAB4D9B6B0D4B4ABD1B5A8D0B6A9D1B7AB
D2B8AFD3B9B1D3BAB2D3B8B1D1B4ACCFB1A9CCB2A8CAB3A8CAB4A8CBB4A8CBB4A8CBB4A9CCB5A9\
CCB5A8CCB5A7CCB5A7CEB6A9CEB6AACDB3A7CAAFA2C9AEA1D0BDB4DCDBDBE6F3F9
E8F7FFE6F2F8E5EFF4E4EDF1E4EBEFE3EAEDE3E9EBE2E8EAE2E7E8E2E6E8E1E6E7E1E4E5E1E2E3\
E1E1E1E1E2E2E1E3E3E0E3E3E0E2E2E0E2E2E0E2E1E0E1E1E0E1E1E0E1E0E0E1E0
E0E0E0E0E0DFDFE0DFDFE0DFDFE0DFE3E3E2E7E7E6D8D8D7
D8D9D8E7E9E8E3E3E2DFDCDBDFDAD9DFDCDBDFDFDEDFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE0E0DF\
E0E0DFE0E0DFE0E0DFE0E0E0E0E0E0E0E0DFE0E0E0E0E0E0E0E1E0E0E1E0E0E1E0
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2E0E2E2E0E2E3E0E3E3E0E3E4\
E0E3E5E0E4E5E0E4E6E1E5E7E1E6E8E1E7EAE1E9EDE1E7EAE1DCD8E1CEC1E1C8B8
E1CABDE1CDC3E1CEC5E1CFC6E1CFC7E2D0C8E2D0C8E2D1C9E2D1C9E2D1C7E2D1C4E2D1C5E2D2C8\
E1D2CAE0D2CBDED1C7DCCDC1DDC8BEDFC1BDDEBCB8D9B9B0D5B7AAD5B5A8D6B5AA
D6B6ADD7B7B1D7B7B1D6B4AFD3B0ABD0ADA7CDAFA6CAB1A6CAB1A6CBB2A7CBB3A8CBB4A9CBB4A8\
CBB3A7CBB3A6CDB4A7D0B6A9D0B6A9CDB2A5C9AE9FC9AD9FCFBDB3DCDAD9E6F1F7
E8F6FEE6F2F8E5EFF4E4EDF2E4ECEFE3EAEEE3E9ECE2E8EAE2E7E9E2E7E8E2E6E7E1E5E6E1E4E5\
E1E4E4E1E4E4E1E3E4E1E3E3E0E3E3E0E2E2E0E2E2E0E2E1E0E1E1E0E1E1E0E1E0
E0E0E0E0E0E0E0E0DFDFE0DFE0E0DFE3E3E3E7E7E6D8D8D7
D8D9D8E7E8E7E3E3E3DFDEDDDFDDDCDFDDDDDFDFDEDFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE0E0E0\
E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2E0E2E2E0E2E2E0E2E3E0E3E3E0E3E4E0E3E4\
E0E4E5E0E4E6E1E5E7E1E5E8E1E6E9E1E7EBE1E9EDE1E7EAE1DDD9E2D0C3E2C9B9
E1CABBE1CDBFE1CEC1E1CEC3E2CFC5E2CFC7E2CFC7E2D0C8E2D0C8E2D0C7E2D1C6E3D2C7E3D5CC\
E4D7CFE4D7D0E3D6CDE1D2C9E0CEC4E0C9C1DEC3BCDBBEB5D9BAB0D9B9ADDAB9AD
DABAB0DAB9B1D9B6B1D8B5B0D8B4AED5B2ABD0AFA7CDACA3CDACA4CDAFA8CEB5ADCDB7ADCBB4A9\
CBB1A5CDB1A4CFB2A5D1B3A6D0B2A5CDB0A2C9AD9ECAAFA0D1BFB4DCDBD9E5F0F6
E7F5FCE6F2F8E5EFF4E4EEF2E4ECF0E3EBEEE3EAEDE3E9EBE2E8EAE2E7E9E2E6E8E1E6E7E1E5E6\
E1E5E6E1E4E5E1E4E4E1E3E4E1E3E3E0E2E3E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1
E0E1E0E0E0E0E0E0E0E0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E7E6E3E4E3E0DFDFDFDFDEDFDFDEDFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE0E0DFE0E0E0\
E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1
E0E1E1E0E1E1E0E1E1E0E1E2E0E1E2E0E2E2E0E2E2E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E4E5\
E0E4E6E0E4E6E1E5E7E1E6E8E1E6E9E1E7EBE1E9EDE1E7EAE1DEDAE1D2C5E1CBB9
E1CBB9E1CCBCE1CDBEE2CEC0E2CEC3E2CFC6E2CFC6E2CFC7E2D0C7E2D0C8E2D1C8E3D3CBE3D6CE\
E3D8D1E4D9D1E4D8D0E3D5CEE2D2C9E0CFC4DEC9BFDDC4BBDDC0B7DDBFB4DDBFB3
DDBFB4DCBCB3DAB8B1DAB8B1DBBCB3DABAB0D5B1A9D0A9A3CFA8A3D0AEA8D0B6AFCFB9B1CCB5AB\
CCB1A5CEB0A3D0AFA2D0AFA1CEAEA0CBAD9FCAAE9FCDB4A5D4C5BBDEDEDCE5F0F6
E7F4FBE6F1F7E5EFF4E4EEF2E4ECF0E3EBEFE3EAEDE3E9ECE2E8EAE2E8E9E2E7E8E2E6E8E1E6E7\
E1E5E6E1E4E5E1E4E4E1E3E4E1E3E3E0E3E3E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1
E0E1E1E0E1E0E0E0E0E0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE0E0DFE0E0E0E0E0E0\
E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1
E0E1E1E0E1E1E0E1E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E5E0E4E5\
E0E4E6E1E5E7E1E5E7E1E6E8E1E6E9E1E7EBE1E9EEE2E9ECE2DFDCE1D3C5E1CBB9
E1CBB7E1CCBBE2CDBEE2CDC0E2CEC1E2CEC3E2CFC5E2CFC6E2CFC7E2D1C9E2D3CBE3D5CDE3D5CD\
E3D6CEE3D6CFE4D7D0E4D7D0E3D6CEE1D3C9E0CFC5E0CCC1E0C8BDDFC5B9DEC3B7
DEC2B7DDBFB6DCBCB3DCBCB2DCBEB2DABBB0D7B3ABD3ADA7D1ACA5D0AFA7D0B3ABD0B6AECEB6AD\
CDB4AACDB1A4CDAEA0CDAC9ECBAB9CC9AB9CCBAFA2D1BBB0D9CEC8E1E3E4E6F1F6
E6F3FAE6F1F7E5EFF4E4EEF2E4ECF0E4EBEFE3EAEDE3E9ECE2E9EBE2E8EAE2E7E9E2E7E8E2E6E7\
E1E5E6E1E3E3E1E1E2E1E2E3E1E3E3E1E3E3E0E3E3E0E2E2E0E2E2E0E2E2E0E1E1
E0E1E1E0E1E0E0E1E0E0E0E0E0E0DFE4E4E3E7E7E6D8D8D8
D8D8D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFE0E0DFE0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E0E0\
E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1
E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E5E0E4E5E0E4E6\
E0E4E6E1E5E7E1E5E8E1E6E9E1E7EAE2E8EBE1E7EBE0E4E6E0DBD6E0D0C2E1CBB8
E1CBB8E1CCBCE2CDBFE2CDC0E2CEBFE2CEC0E2CEC3E2CFC6E2D0C7E2D2CAE2D5CCE3D5CDE3D4CC\
E3D3CBE3D4CCE4D6CEE4D8D1E4D8D1E3D6CEE3D4CBE4D3C7E2D0C2E0CBBDDFC6BA
DFC3B9DFC1B8DEC0B5DDBFB3DBBDB0D9BAAED8B5ADD6B2ABD3B2A8D1B1A5D0B0A3D0B1A6CFB5AC\
CDB6ADCBB1A5CAAC9EC9AB9CC8A99AC8A99ACCB1A5D5C3BCDED7D7E3E8EBE6F1F7
E6F2F8E5F0F6E5EFF4E4EEF2E4ECF0E4EBEFE3EAEEE3EAECE3E9EBE2E8EAE2E7E9E2E7E8E2E6E8\
E1E5E6E1E1E3E1E0E1E1E1E2E1E3E4E1E3E4E1E3E3E0E2E2E0E2E2E0E1E1E0E1E0
E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E4E4E3E7E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E0E0E0E0E0\
E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2
E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3E0E2E3E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E0E4E6\
E0E5E6E1E5E7E0E5E8E1E6E9E3E9ECE3E9EDDFE0E2D9D2D0D9CAC2DECABAE1CBB9
E2CBBBE2CCBDE2CCBEE2CDBDE2CDBCE2CEBEE2CEC3E2D0C7E2D1C9E2D3CBE2D4CBE3D4CCE3D4CC\
E3D4CDE3D5CDE3D7CFE4D9D2E4D9D2E4D6CFE5D5CDE5D5CBE4D3C6E2CEC0E1C9BC
E1C5BAE1C3B8E0C2B5DEC0B3DCBEB0DABBAFD9B6AED7B4ABD5B3A8D3B1A3D1AE9FCFAEA0CDB1A5\
CBB2A7C9AFA2C9AB9DC9A99AC9A898C8A899CCB3A7D6C8C4DFDEE1E4ECF1E6F1F7
E6F1F7E5F0F5E5EEF3E4EDF2E4ECF0E4EBEFE3EAEEE3EAECE3E9EBE2E8EAE2E7E9E2E7E9E2E6E8\
E1E5E6E1E3E4E1E1E2E1E2E3E1E3E4E1E3E4E1E3E3E0E3E3E0E2E2E0E0E0E0DEDE
E0DDDDE0DEDDE0DFDEE0E0DFE0E0E0E4E4E3E8E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E1E0\
E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2
E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E5E0E4E5E0E4E6E0E4E6\
E1E5E7E1E5E8E1E6E8E0E6E8DEE5E7DBDFE1D5CFCDD0BDB5D3BBADDCC4B3E1CBBA
E2CCBEE2CCBFE2CCBDE2CCBCE2CDBCE2CDBEE2CEC3E2D1C7E2D3CBE2D4CBE2D2C9E3D2CAE3D5CC\
E3D7CEE3D8CFE3D8D1E4D9D1E4D8D0E4D6CEE4D5CDE5D4CCE5D3C9E4D0C3E4CCBE
E4C8BAE2C4B7E0C1B4DEC0B2DEBFB1DCBCB0DAB7ADD7B3A9D6B2A5D4B0A2D1AD9ECEAC9DCBAC9E\
C9AC9EC8AB9DC9AA9BCBAA9ACBA898CAA999CDB5A9D6CDCADFE3E8E4EEF5E6F1F7
E5F1F6E5EFF4E5EEF3E4EDF1E4ECF0E3EBEFE3EAEEE3EAEDE3E9EBE2E8EAE2E8EAE2E7E9E2E6E8\
E2E5E7E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E4E1E3E3E0E2E2E0DFDFE0DCDC
E0DBDBE0DCDBE0DEDDE0E0DFE0E0E0E4E4E3E8E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E1E0E0E1E0\
E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2
E0E2E2E0E2E2E0E2E3E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E0E4E6E0E5E6\
E0E5E7E1E6E8E3E8EBDFE4E7D0D3D4BFBEBBBDB1A9C8B1A4D5BAA9DEC5B2E2CABA
E2CBBFE2CBBFE2CCBEE2CCBDE2CCBEE2CDC0E2CEC3E2D1C7E2D4CBE2D4CBE2D1C8E3D1C6E3D3C7\
E3D6CAE3D8CEE3D8D0E3D7CFE4D5CEE4D4CDE4D4CCE5D4CAE5D4C8E5D3C5E5CEC0
E3C7BBE1C2B6DFC0B3DEBEB1DEBDB1DDBAAFDAB7AAD7B3A5D4B0A1D2AE9FD0AD9ECEAC9DCCAA9B\
CAA999C8A999C9AA9BCCAC9CCDAC9BCCAC9CCFB8ACD8D2CFE1E8EDE5F1F7E5F1F7
E5F0F5E5EFF4E4EEF2E4EDF1E4ECF0E3EBEFE3EAEEE3EAEDE3E9ECE2E8EBE2E8EAE2E7E9E2E6E8\
E2E6E7E1E5E7E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E3E0E2E2E0E0E0E0DEDE
E0DDDDE0DDDDE0DFDEE0E0E0E0E0E0E4E4E3E8E7E6D8D8D8
D8D9D8E7E7E7E4E4E3E0E0DFE0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0\
E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2
E0E2E2E0E2E2E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E5E0E4E5E0E4E5E0E4E6E1E5E6\
E1E5E7E1E6E9E4E9ECDBDFE2BAB9B99A918B9F8E82C1AA9ADAC1AEE1C9B6E2CBBB
E2CBBFE2CCC1E2CCC1E2CCC1E2CDC2E2CDC2E2CEC4E2D0C7E2D3CAE2D3CBE2D1C8E3D0C5E3D1C4\
E3D4C6E3D6CCE3D6CEE4D4CCE4D2CAE4D1C9E4D1C8E4D1C5E4D1C3E4D1C1E2CCBE
E0C4B9DEBFB4DEBEB1DEBDB0DEBAB0DCB8ADD9B7A7D5B3A1D2AE9DD0AC9CCFAD9ECEAD9ECDAB9B\
CBA898C8A797C8AA9ACAAE9ECCAF9ECDAE9DD1BAAEDBD5D3E3ECF1E6F3F9E5F1F6
E5EFF4E5EEF3E4EDF2E4EDF1E4ECF0E3EBEFE3EAEDE3EAECE3E9ECE2E8EBE2E8EAE2E7E9E2E6E8\
E2E6E7E1E5E7E1E5E6E1E5E5E1E4E5E1E4E4E1E3E4E1E3E3E0E2E2E0E1E2E0E1E1
E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E4E4E3E8E7E6D8D9D8
D8D9D8E7E8E7E4E4E3E0DFDEE0DDDDE0DEDEE0E0DFE0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0\
E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2
E0E2E2E0E2E3E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E0E4E6E0E4E6E1E5E7\
E1E6E7E1E6E8E1E4E9D2D2D7A59E9F7B6B66887368BCA495DEC6B4E4CCBAE2CCBB
E1CDC0E1CDC3E2CDC3E2CDC3E2CFC5E2CFC5E2CEC5E2CFC5E2D1C7E2D2C9E2D2C9E3D2C8E3D3C6\
E3D3C7E3D4CAE3D4CAE4D2C7E4CEC5E4CAC3E3C8C0E2C7BBE0C8B8DEC6B6DDC3B5
DDBFB3DDBDB1DEBDB0DDBDB0DBBBAFD8B8ACD5B5A5D3B19FD2AE9CD1AD9DCFAE9ECDAD9DCBAA98\
C9A795C7A795C7A898C8AB9BC9AB9ACAAB9AD0B9ADDBD6D3E4EEF2E6F3FAE5F0F6
E5EFF3E4EEF2E4EDF1E4ECF0E4ECEFE3EBEEE3EAEDE3EAECE3E9EBE2E8EBE2E8EAE2E7E9E2E6E8\
E2E6E7E1E5E7E1E5E6E1E5E6E1E4E5E1E4E4E1E3E4E1E3E3E1E3E3E0E2E2E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E9E8E4E4E3E0DEDDE0DCDBE0DDDCE0DFDFE0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2
E0E2E3E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E5E0E4E5E0E4E5E0E4E6E0E4E6E1E6E8\
E3E8EAE1E5E8D8D9DDBFBAC0928587715C58876E65BEA699E1C8B8E5CEBCE2CDBD
E1CFC2E1CEC4E2CDC3E2CEC4E2D0C6E2D0C6E2CEC5E2CDC4E2CEC5E2D0C7E2D3C9E3D5CBE3D5CB\
E3D4CBE3D2C9E3D2C6E3D0C3E3CBC0E3C4BDE2BFB8DFBEB3DCBDADD9BBAAD8BAAA
DABBACDCBCADDDBCADDCBCADD9BBADD5B8A9D1B3A3D0AF9ED2AD9DD3AD9DD0AD9DCDAC9AC9A995\
C7A692C7A693C6A695C6A696C6A594C7A695CDB5A9DAD3D0E3EBEFE6F1F7E5EFF5
E4EEF3E4EEF2E4EDF1E4ECF0E3EBEFE3EBEEE3EAEDE3E9ECE3E9EBE2E8EBE2E8EAE2E7E9E2E6E8\
E2E6E8E1E5E7E1E5E6E1E5E6E1E4E5E1E4E4E1E3E4E1E3E3E1E3E3E0E2E3E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E8E7E4E4E3E0DFDEE0DDDCE0DCDCE0DDDCE0DFDEE0E0E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2
E0E2E3E0E2E3E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E5E0E4E5E0E4E5E0E4E6E0E4E6E2E6E8\
E7EDEFE3E8EBC6C5C79D929384726D887067A68C80CCB3A4E1C9B9E4CCBDE2CCBE
E1CDC1E1CDC2E1CCC2E2CDC3E2CFC5E2CFC5E2CEC4E2CDC3E2CDC3E2CFC5E2D1C8E2D4CAE3D6CD\
E3D5CCE3D2C8E2D0C4E1CEC0E0C9BCE0C0B8DFBBB3DDBAAEDAB9A9D7B6A5D6B6A5
D7B8A7D9B9A9DAB9A9D9B9A9D7B9A7D3B7A4D0B1A0CEAD9DD0AB9BD1AB9ACFAA9ACDA998CAA794\
C9A692C9A593C8A594C6A493C5A391C7A594CDB3A6D8CCC7E1E3E5E5ECF1E5EEF3
E4EEF3E4EDF2E4ECF0E4ECF0E3EBEFE3EAEEE3EAEDE3E9ECE3E9EBE2E8EAE2E8EAE2E7E9E2E6E8\
E2E6E8E1E6E7E1E5E6E1E5E6E1E4E5E1E4E5E1E3E4E1E3E3E1E3E3E0E2E3E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E8E7E4E4E3E0E0DFE0DFDEE0DCDCE0DBDBE0DDDDE0E0DFE0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2
E0E2E3E0E2E3E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E0E4E5E1E5E6E0E5E6E0E5E7\
E2E7E9D8DBDCAFAAA883756D877266AF9787CEB5A3DCC3B1E1C8B8E2CABCE2CABE
E1CBC0E1CBC0E1CBC1E2CCC1E2CCC2E2CDC2E2CDC2E2CDC3E2CDC3E2CEC4E2CFC5E2D2C8E3D4CB\
E3D4CBE3D1C8E1CDC1DEC8BADDC1B4DDBAB0DDB6ADDCB5A9D9B3A4D6B0A1D5AFA0
D5B0A0D6B2A2D6B3A3D6B4A2D5B5A0D3B39ECFAF9CCDAB9ACDA897CEA695CDA695CCA694CCA593\
CCA593CBA493CAA492C7A391C6A391C8A694CEAFA1D6C1B9DDD5D3E2E5E7E4EDF2
E4EFF4E4EDF2E4ECF0E3EBEFE3EBEEE3EAEEE3EAEDE3E9ECE2E9EBE2E8EAE2E7EAE2E7E9E2E6E8\
E2E6E8E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E3E4E1E3E3E1E3E3E0E2E2E0E2E2
E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E8E7E4E4E3E0DFDEE0DDDDE0DCDCE0DDDCE0DEDEE0E0E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3
E0E2E3E0E2E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E0E4E5E1E5E7E3E8EADEE3E4\
CACBCBADA9A5968B83928175AA9486CDB5A4E1C8B5E3CAB6E1C9B8E1C9BCE1C9BE
E1CABFE1CABFE1CBC0E2CBBFE2CBBEE2CCBFE2CCC1E2CCC2E2CDC3E2CEC4E2D0C6E2D2C8E3D3C9\
E3D3CAE3D0C6E1C6BDDDB9AFDBAEA6DBA9A2DBA6A0DAA49CD8A197D59F95D49D93
D49E94D5A398D5AB9CD4AF9DD2AF9BD0AD99CEAA98CDA796CCA393CCA190CAA390CAA490CBA492\
CDA493CDA493CBA391C7A38FC6A28EC9A28FCCA696D0B1A4D5C4BDDEDCDCE4EDF1
E5F0F5E4EDF1E3ECEFE3EBEFE3EBEEE3EAEDE3E9ECE3E9ECE2E8EBE2E8EAE2E7E9E2E7E9E2E6E8\
E2E6E7E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E2E3E0E0E1E0DFDF
E0E0E0E0E1E1E0E1E1E0E1E0E0E1E0E4E4E4E8E7E7D8D9D8
D8D9D8E7E9E8E4E4E3E0DEDDE0DCDBE0DDDCE0DFDEE0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3
E0E2E3E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E5E0E4E5E0E4E5E0E4E6E1E6E7E5E9EBDBDEE0\
B4B0AE8A7E768F7D72B5A296D3BDB0DEC6B8E2C9B8E2C9B7E1C9B7E1C9BBE1C9BE
E1C9BFE1CABFE2CABEE2CABCE2CABAE2CBBBE2CBBEE2CBC1E2CCC2E2CFC5E2D1C7E2D1C8E3D0C7\
E3D0C6E3CDC4E1BEB7DEA8A3DC9A96DB9692D9938FD68D89D48A85D48984D48985
D48B86D4938BD4A093D2A797CFA796CDA593CCA493CCA291CB9F8FCA9E8CC8A08CC7A38DCAA390\
CCA392CDA392CBA390C8A28DC7A18AC99E8ACA9D8BC9A291CDB3A7D8D0CBE1E6E8
E4EDF1E4ECF0E3EBEFE3EBEFE3EAEEE3EAEDE3E9ECE3E9EBE2E8EBE2E8EAE2E7E9E2E7E9E2E6E8\
E2E6E7E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E2E2E0DFDFE0DDDE
E0DFDFE0E1E1E0E1E1E0E1E1E0E1E0E4E4E4E8E8E7D8D9D8
D8D9D8E7E9E8E4E4E3E0DEDEE0DDDCE0DEDEE0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E2E3E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E5E0E4E5E0E4E6E1E5E6E0E4E6E0E2E4D5D4D5\
B6AEAB9B8B84A89489CEB8ACE3CCC0E4CCBFE1C8B9E1C8B6E1C8B7E1C9BBE1C9BE
E1C9BEE1C9BDE2C8BAE2C8B7E2C8B6E2C8B6E2C8B9E2C9BCE2CBC0E2CEC4E2D0C6E2CEC5E3C9C1\
E3C7C0E3C4BEE1B6B1DE9F9CDB8F8DD98A86D6847FD37B76D17874D27C79D37F7C
D2807DD28781D39289D1998ECC9A8DC89B8CC89D8DC99F8DC99F8BC79E8AC69F8AC6A08CC9A18F\
CCA291CCA291CBA28FC9A28DC99F8ACA9B88CA9987C89E8BCAAA99D2BEB2DAD2CE
E0E2E3E3EBEEE4ECF0E3EBEFE3EAEDE3EAEDE3E9ECE2E9EBE2E8EBE2E8EAE2E7E9E2E7E9E2E6E8\
E2E6E7E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E2E2E0E0E0E0DFDF
E0DFDFE0E1E1E0E1E1E0E1E1E0E1E0E4E4E4E8E8E7D8D9D8
D8D9D8E7E8E7E4E4E3E0E0DFE0E0DFE0E0DFE0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E2E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E1E5E6E2E6E8DEE2E4D2D2D4C3BEBF\
BBB0AEBFAEA8CCB7ADDBC3B6E2C9BCE3CABCE1C8B8E1C8B6E1C8B7E1C9BBE1C9BE
E1C9BDE1C7BAE1C5B4E1C4B1E1C4B0E1C4B1E2C5B3E2C8B8E2CBBFE3CEC3E3CEC4E3C7BFE3BEB8\
E2B8B4E1B5B1DFABA8DC9A97D88C87D4837CD07C73CD766DCE7770D17E79D2807C
CF7D78CF7D76D1817BD08780CB8B83C69085C59688C59C8AC59F8AC59F89C49D89C69D8AC99F8D\
CBA28FCCA290CBA28FCBA18ECB9F8CCB9B89CB9B88CA9F8DCAA593CDAC9BD3BCB0
DCD5D1E2E8EBE4EDF1E3EBEFE3EAEDE3E9ECE2E9ECE2E8EBE2E8EAE2E7EAE2E7E9E2E7E8E2E6E8\
E1E6E7E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E3E4E1E3E4E1E2E3E0E2E2E0E1E1
E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E4E4E4E8E7E7D8D9D8
D8D9D8E7E7E7E4E4E3E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E2E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E1E5E7E4E9EBDCE0E2BDBDBE9F9796\
A69893C7B4AADDC6B8E1C8B8E1C8B7E1C8B8E1C8B6E1C8B5E1C8B6E1C9BAE1C9BD
E1C9BBE0C6B6DFC2AFDEBEABDFBEAAE0C0ADE1C5B1E2C9B9E2CDC0E4CFC2E5CBBFE4BFB5E1AEA9\
DEA39FDD9E9ADA9B96D5948FCF8880C87C70C5796BC88173CD8C80D19088D18982
CD7B73CA7169CB7069CC766FCA7E76C8877DC58F83C49788C39E8AC49F89C49D85C59B84C69E88\
C9A18CCAA18ECBA18ECBA08ECB9F8DCB9D8BCB9D8ACBA08DCAA28ECAA490CFB1A1
DACDC5E2E4E4E4EBEEE3EBEEE3EAEDE3E9ECE2E9EBE2E8EBE2E8EAE2E7E9E2E7E9E2E6E8E2E6E8\
E1E6E7E1E5E7E1E5E6E1E4E6E1E4E5E1E4E4E1E3E4E1E3E4E1E3E3E0E2E3E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E4E8E7E7D8D9D8
D8D9D8E7E7E7E4E4E3E0E1E0E0E1E0E0E1E0E0E1E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E4E0E4E5E0E4E5E1E5E6E4E7E9D7D9DBAAA7A6807570\
8E7C72C0A999DFC5B2E3C9B6E1C7B4E1C7B4E1C7B3E1C8B4E1C8B7E1C9BBE1C9BB
E1C8B7DFC4B1DCBEAADAB8A4DAB6A2DDBBA8E1C3B1E2C8B8E1C6BADEC1B4DCB8AADBAB9FDA9C94\
D9908BD78B84D48E85D09289C88B81C17E71C0806FC69181CDA091D09F93CD8F85
C7786EC3695EC3675DC56D63C6756CC67D73C5857AC48F82C39988C39E88C39C81C49B7EC59D82\
C6A089C9A18DCBA18ECCA18ECCA08DCB9F8CCB9F8CCB9F8CCA9F8CCAA28ECFAE9D
D8C5BAE0DAD6E3E5E5E3E9EBE3E9ECE3E9ECE2E8EBE2E8EAE2E8EAE2E7E9E2E7E9E2E6E8E2E6E8\
E1E6E7E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E3E1E3E3E0E2E3E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E4E8E7E7D8D9D8
D8D9D8E7E7E7E4E4E3E0E1E0E0E1E0E0E1E0E0E0E0E0DFDEE0DEDEE0DFDFE0E0E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E4E1E4E5E1E5E6E0E3E4DADBDDC8C4C5A2979486736A\
978070C3AA95DEC4B0E3C8B5E0C5B2DFC3AFDFC5B1E0C9B7E1CABBE1C9BCE1C7B8
E1C4B1DEBEA9D9B7A1D5AF99D4AA96D9B1A0E1BDAFE4BEB3DDB0A6CD998EBC8678BC8275CA8B81\
D48D85D4897FD28B80D0968BCD9C91C99B8FC9988BCB988ACC998ACA9788C38C7C
BC7A6AB96F60B97063B97266B77165BA7165C0766BC48276C39081C19983C29A7DC4997AC59B80\
C79E88C9A18DCCA390CDA590CEA48FCCA18DCBA08CCAA08DCAA08DCAA18ECDA895
D3B6A7DAC8BEE0D8D3E3E3E2E3E8E9E3E9ECE2E9EBE2E8EAE2E7EAE2E7E9E2E7E8E2E6E8E1E6E7\
E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E3E1E3E3E0E2E3E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E4E8E7E7D8D9D8
D8D9D8E7E8E7E4E4E3E0E0E0E0E0E0E0E0E0E0E0DFE0DEDDE0DCDCE0DEDDE0E0E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E4E1E5E6E2E7E8DDE0E1CAC8CAB1A6A6A08C86A18779\
B69986D0B5A0E0C6B3E2C7B7DEC2B0DCBEAADDC1AEDFC8B9E1CCBFE1CABDE2C5B6
E1BFACDDB7A1D6AE96D0A48CCD9C88D0A091D8A9A0DCA8A2D49691BB7971A06056A3695EBF8B80\
D39D93D69990D5988FD6A49BD8B6AED9C1BAD8B7AFD49D93CE8D81C68E7FBE8E7C
B68774B48472B38577AD7F73A37063A46456B06457BB6F63BE8272BE917BC1977BC4987BC89980\
CA9C88CBA18FCDA793D0AA93D0A991CEA48ECBA18DCBA18ECAA28ECAA08DCBA18D
CCA794D1B5A6DACAC1E0DCD9E2E5E6E2E8EBE2E8EBE2E8EAE2E7E9E2E7E9E2E6E8E2E6E8E1E6E7\
E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E3E1E3E3E0E2E3E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E4E8E7E7D8D9D8
D8D9D8E7E8E7E4E4E3E0DFDEE0DEDDE0DFDEE0E0DFE0DEDEE0DDDDE0DEDEE0E0E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E0E3E4E1E5E6E4E8E9DADDDEB8B5B5958987968077B39786\
CEB09CDCC0ADE1C7B6E1C6B6DEBFADDBB9A6DBBCABDFC6B8E1CBBFE1C9BDE2C4B6
E1BDAADBB19AD3A48ACC9980C7907BC08678BC8079BF8581C38D89BA8883AC7E77B08981C7A69E\
D8B8B1DBB7B2DBB6B2DCBDBAE0CCC9E2D6D3E0CAC4DBAFA4D49F92CEA295C8A799
C2A697BCA295B49B91A78980956F638D594B925244A05B4CAF705FBB8670C19479C59A7EC99983\
CC9B89CDA291CFAA96D2AD97D2AB94D0A890CEA48ECCA28ECBA18DCA9F8BCA9D89
CAA08BCCAB9CD2C0BBD9D3D7DEDFE3E0E4E7E2E7E9E3E8EAE2E8E9E2E7E9E2E6E8E2E6E8E1E6E7\
E1E5E7E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E3E1E3E3E0E2E2E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E4E8E7E7D8D9D8
D8D9D8E7E9E8E4E4E3E0DEDDE0DCDBE0DDDDE0E0DFE0E0E0E0E0DFE0E0E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3E0E2E3
E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E1E4E5E3E7E8E6EAECD8DADCA8A4A57B6F6B877367B89E8C\
D9BDAAE1C6B5E2C8B7E1C6B3DEBFAADBB8A4DCBAA9DFC3B5E1C9BDE1C8BCE1C4B5
DFBAA7D8AA93CE987EC78D73BF816BAC68599951499C5F5BB28B87C4ABA5CCB6B0D1BDB6D8C7C0\
DECFCBE0D3D2E0D4D4E1D5D5E2D8D7E3DAD6E1D1C9DCC2B5DABDAFDAC3B9D9C8C0
D5C4BDCCBBB4BEADA7AB948E96756C845B4E7B4F408352419C614FB27662BE8C74C4987FC89984\
CC9C89CFA491D2AC98D3AE9AD3AE98D3AC94D0A890CDA38DCB9F8ACA9C89CA9C87
CA9F8ACAA99ACCBAB9CFCAD3D4D4DCDADBDEDEE1E3E0E5E8E1E6E9E1E6E8E2E6E8E1E6E7E1E5E7\
E1E5E6E1E5E6E1E4E5E1E4E5E1E4E5E1E3E4E1E3E4E1E3E3E0E3E3E0E2E2E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E9E8E4E4E3E0DEDEE0DDDCE0DEDDE0E0DFE0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3E0E2E3
E0E3E3E0E3E3E0E3E4E0E3E4E0E3E4E2E5E6E5E9EBE6EAEFD3D4DB9A9599695C597B675BB69E8B\
DCC1AEE3C8B6E2C8B5E0C6B2DFC1ACDDBDA8DEBEADE0C4B6E1C8BCE1C7BBE0C0B1
DBB29FD1A088C58E72BD8064B46E589B4E3F84352C8B4942AE817ACDB1A8DCC7BDE0CBC2E0CBC3\
E0D1CCE2DBDAE3DFDEE3DCD9E3D9D3E3D6CDE0CEC2DBC4B6DBC5B9DDCFC8DFD2CD
DCCAC3D6C1B9CCB9B1BDA69FA98B80957366856757805E4F885A4A9A6251AF7863BF8B75C6947F\
CA9B87CFA591D4AE98D6B29DD6B29DD5AF99D2AB94CDA48FCB9F8BCA9B87CA9985
CA9C88C9A697C7B5B1C7C1C5C9C6C9CDCACCD3D3D7D9DCE3DEE2E7E1E6E8E2E6E8E2E6E7E1E5E7\
E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E4E1E3E3E0E2E3E0E2E2E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E8E7E4E4E3E0E0DFE0DFDFE0E0DFE0E0E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3E0E2E3
E0E3E3E0E3E3E0E3E4E0E3E4E0E3E3DFE2E2DCDFE0D7D8DDC1BDC78E848A6654517D6559B89E8C\
DDC2ADE3C9B4E1C7B2E1C5B0E0C4AEE0C3AEE0C3B1E0C6B7E1C9BCE1C7BADEBBAC
D7A996CB9980BF8B6EB77D60AE68519A4D3D873D30924E44B67B71D3A397DDB7A9DDBAADDCB9AE\
DDC1BADFCFCBE1D6D0E2D1C7E2CDBFE1C9BADDC0B1D8B4A6D6B4AAD9BFB8D9C0B9
D7B6ACD6B4A7D6BAAED0B5AAC1A293B19081A286789075697F5D518153449A5F4EB37562BF8875\
C79985CFA68FD4AF97D8B6A0D8B7A2D6B29DD2AB96CDA591CAA08CC99A86CA9783
CA9985C8A291C6B0A3C4BAB2C3BDB8C4BEBFC9C5CED0D0DCD9DCE4E0E5E7E2E7E8E2E6E7E1E5E7\
E1E5E6E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E4E1E3E3E0E2E3E0E2E2E0E2E2
E0E2E2E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E7E7E4E4E3E0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E3E1E4E4E2E5E6DEE1E1D2D3D1C0BCB9ABA4A5958A8F7D6B6D765C5794786AC3A794\
DEC4AEE3C8B2E1C5AFE1C2ACE1C0AAE1C1ACE1C3B0E1C6B5E1C9B9E0C6B6DCB8A7
D4A491CB9880C39378BE8D73BA826BAF7462A66D5DB07669C78B81D8A095DBAA9DD9AB9DD7AA9D\
D8B0A6DABBB2DCBDB4DEB7ACDDB3A5DAB2A3D5A99BD19B8FD0968DD19A93D19A91
CE9589D09D8ED5AFA0D3B4A4CBA694C09888B69185A2837A8969607C5347854C3E9B594AB27767\
C59481CFA58ED5B097D9B8A1D9B9A4D6B39DD2AA94CDA48FC99F8BC89A86C79884
C89A86C8A18DC7AB98C7B6A7CAC0B8CBC5C6C8C3CECAC7D5D5D6DFE0E4E7E2E7E8E2E6E7E1E5E6\
E1E5E6E1E4E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E3E1E3E3E0E2E3E0E2E2E0E2E2
E0E2E1E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E7E6E4E4E3E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E3E1E4E5E3E6E7DADCDCBCB9B59289826E615B5E4D4A6D5450917167B79586D2B5A1\
E0C5AFE2C6B1E1C1ACE0BCA7E0BAA5E0BBA6E0BFABE1C5B1E1C8B5E0C5B2DBB6A3
D4A38FCE9A84CB9D86CBA28CCCA792CDAA96CDAB98D2AA9CD9AAA0DDABA2DCACA1D8AA9ED6A99C\
D5AA9ED5ADA2D8AAA0DAA39AD89F95D39E92CF988BCD8C7FCD8276CD7D72CB7B6F
C97D70C98B7DCDA090CDA795C99B88C48E7FBD887FB0827B9C736B87594E793F33834134A36355\
C08878CEA08AD4AE95D8B7A0D9B8A2D6B29BD1A991CDA28BC99D88C59A86C59A86
C79D88C8A18CC8A691C9B09FCEC0B7D0C9CBC9C3CEC9C3D1D4D3DCDFE2E5E2E6E8E1E5E7E1E5E6\
E1E5E6E1E4E5E1E4E5E1E4E5E1E3E4E1E3E4E1E3E3E0E3E3E0E2E3E0E2E2E0E2E2
E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E7E6E4E4E3E0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E0E0E0DFDFE0DEDEE0DFDFE0E1E0\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E4E1E4E5E1E2E4D0CED0A09A986359523A2D253A2821684F47A8887CD1B09FDEC1AC\
E1C6AFE1C3AEE1BDAAE0B6A6DFB5A4DEB9A5DEBFA9E0C4AFE1C5B2E0BEAEDCB2A1
D4A390CD9984CA9A84CEA792D7BAA7DEC8B6E2CCBCE3C8BAE1BFB6E0B9B1DEB7ADDBB6AAD9B5A9\
D8B5A9D8B2A6DAAEA2DBA89ED9A499D4A094D09B8DCF9284CF8A7BCE8372CC806F
CA8272C98C7CC99887CA9988CA8E7FC78277C27C74B87870A96E6393574A7D3B2F7C3429954D41\
B27162C5917ED1A892D8B49ED9B6A0D6B198D1A98FCDA189C89B86C49884C39985
C69C87C9A08BC9A38DC3A391BAA398B7A9A7C0B7BDCEC9D1D8D6DDDEDFE2E0E3E5E1E5E6E1E5E6\
E1E5E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E4E1E3E3E0E3E3E0E2E2E0E2E2E0E2E2
E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E1E0E0E0E0E0DEDEE0DCDCE0DEDEE0E0E0\
E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E1E4E4E1E3E4DEDCE0C8C2C79088895048422F241B3C2C23765F55BA9E91DEC1AFE3C7B2\
E1C4AEE1C0ABE1BAA9E0B4A7DEB4A7DCBAA8DDC0ABDFC4AFE1C1B0E0B9ACDCAEA1
D4A391CA9780C49179CA9F89D8B9A8E2CCBEE4D2C4E4CFC2E2C9BEE1C5BAE0C3B8DFC4B8DEC6BA\
DEC5BADEC2B7DFBFB2DFBCAEDDB6A6D9AF9ED7A999D6A695D5A28FD29E88D09A84
CF9985CD9986CB9885CB9282CC887CCC7F76C6786FBD7165B06758A057478F4437893C30924539\
A55F51BB8371CDA18CD6AF9AD8B29CD6AF96D1A88ECDA189C89A85C49682C39682
C69984CB9E89CBA18CB995829A7D6E917C74B0A4A3D3CED1DEDBDFDDDCDEDFE0E2E1E4E6E1E5E6\
E1E4E6E1E4E5E1E4E5E1E4E4E1E3E4E1E3E4E1E3E3E0E2E3E0E2E2E0E2E2E0E2E2
E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E1E0E0E0E0E0DEDEE0DDDDE0DEDEE0E0E0\
E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E1E4E4E0E2E4D9D8DEC5BFC99F9698776A62655246715A4C9A7F71C8AD9DE0C5B2E3C7B2\
E1C3ADE0BFA9E1BBA9E0B8AADEB7AADDB8AADDBDACDFC3AFE1C2B0E0BBADDCB2A3
D4A694C99781C38F77C99B85D6B4A2E0C7B9E2CDC1E2CEC2E1CDC1E1CBBFE1CABEE1CABFE1CDC1\
E1CEC2E2CDC1E2C9BDE1C3B6DFBCADDCB6A5DAB3A0DAB39FD8B19DD5AE97D3AA93
D2A691CFA18DCB9B85C99380CA8B7DCA867AC68173BF7C6AB87361AF6A58A661519F594D9F584E\
A86559B9816DC99A83D2A992D6AE98D5AD94D1A88ECDA189C89B85C49781C39680
C69882CB9D88CB9F8AB48E7B8B6D5E7E695EA29690CDC8C5DDDBDBDEDEDFDFE1E3E1E4E6E1E5E6\
E1E4E5E1E4E5E1E4E5E1E3E4E1E3E4E1E3E3E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2
E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E1E0E0E0E0E0E0DFE0E0DFE0E0E0E0E1E0\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E1E4E4DFE1E3D6D6DDCAC4CEC0B3B4B8A497B49885B79683C4A390D3B6A2DDC2ADE0C5AF\
E0C2ACE0C0AAE0BFABE0BFADE0BBADDFB7ACDFBAADE0C2B0E1C6B2E0C3B0DCB9A7
D4AC98CC9D88C8947FCB9B86D4AE9BDCBEADDFC7B9E1CCBFE1CEC2E1CDC1E1CBBFE1CABFE2CCC0\
E2CEC2E2CFC3E2CAC0E2C0B7E0B8ACDCB4A4DBB3A0DAB39FD8B29DD5AF99D3AB96
D1A792CEA28CC79C85C49680C3917EC48F7DC38F7AC08D77BE8973BB8471B8816FB57C6EB2786D\
B47B6EBC8872C6987CCEA48BD3AB94D4AB93D1A78DCCA088C89A84C49880C3987F
C69981CB9C86C99D88B28D7A8A70627B6A629A8F89C4BDBADAD8D7E0E2E3E1E5E6E1E5E6E1E4E6\
E1E4E5E1E4E5E1E4E4E1E3E4E1E3E4E1E3E3E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2
E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E1E4E4DFE1E2D9D6D8D4C9CAD7C4BEDEC4B5E0C1AEDEBDAADBBCA7D9BCA6DABFA8DCC1AB\
DEC1ABE0C1ABE0C3AEE0C4B1E0C0B1E0BBB0E0BDB2E1C5B5E1C9B7E0C7B4DCBFAC
D6B39ED1A590CD9C87CD9B87D0A490D6B29FDBBFAEDFC9BAE1CEC1E1CFC3E1CDC1E1CBBFE1CABE\
E1CDC1E2CFC3E2CBC0E1C1B7DFB9ACDCB4A3D9B09DD8AC98D6AB96D4AB95D1A992
CEA48DC79F87C09B83BC977FBD937CBE917ABF9179BE927ABE917ABF907ABF8E7ABE8C7ABC897A\
BC8B7AC0917AC69B80CDA48CD2A993D3A992D0A48CCB9D86C69882C3967FC2977E
C49980C89C84C69C85AE8A77846C5F746661958C8CC2BDBFDADADCE1E4E6E2E6E7E1E5E6E1E4E5\
E1E4E5E1E4E5E1E3E4E1E3E4E1E3E4E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E1
E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E3E3E0E3E5DFE0E0DDD6D0DCCABEDFC5B6E3C6B6E4C8B8E2C7B7DEC3B1D9BEAAD8BDA7D9BEA8\
DCC1ABDFC3ADE0C5B1E0C5B5E0C4B6E0C3B6E1C5B9E1C9BCE1CBBCE0C8B9DEC1B0
D9B8A5D5AD98D1A28ECE9B86CD9A86D0A591D7B7A4DDC5B4E0CDBFE1CFC3E1CEC3E1CCC0E1C9BD\
E1CABEE1CDC0E1CCBFE1C7B7DFBFADDCB6A3D8AC99D5A491D3A28DD2A58DCEA58C
C8A087C19B82BA9680B7937CB88F77BA8D74BB8B73BB8C74BC8D74BC8D75BC8B75BC8974BB8A74\
BD8F78C39780C9A089CFA690D2A892D2A690CFA08AC89984C3947FC1927DC1947D
C3977EC69C82C49B83A88572786054675A5790898EC5C2CBDDDEE4E1E5E7E2E6E6E1E5E6E1E4E5\
E1E4E5E1E4E4E1E3E4E1E3E4E0E3E3E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2E0E1E1
E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E2E3
E0E2E3DEE1E3DDDDDDDED3CADFC8B6E0C2ADDFC0ADDEBFADDBBFACD6BDACD2BBACD3BBAAD8BDA9\
DDC0ABDFC4B0E0C6B5E0C8B9E0C8BBE0C9BCE0CBBDE0CCBFE1CDC0E0CABDDFC2B5
DDB8AAD9B09FD5A894D09E8ACD9884CF9F8AD5B09CDBC0AEDFC9BBE1CEC2E1CFC3E1CABFE1C4BA\
E0C2B7DFC6B9DFCAB9E0C9B6DEC2ADDAB6A1D5AA96D3A18DD09C87CD9B84C99B82
C49A81BD9780B8917CB68D77B78B72B98A70B98871BA8871BB8B70BB8C6FBA896EB9866DB9866C\
BD8D72C59881CDA28DD1A691D2A591D0A28DCC9C88C69681C1917DC0907CC1927D
C2967EC59C83C49B84A582706C564C574C4B878085C3BFC7DDDDE2E1E4E6E2E6E6E1E5E6E1E4E5\
E1E4E5E1E3E4E1E3E4E1E3E4E0E3E3E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2E0E1E1
E0E1E1E0E1E1E0E1E0E0E0E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E3E3
DFE2E2DDDEDFDCD7D6DDCFC5DFC6B3DEBFA9DBB9A3D8B39CD4B098CDB1A0CAB5ABCFB9AED9BCAA\
DFBFACE0C3B3E0C7B9E0CABCE0CBBEE0CCBFE0CDBFE0CDC0E0CEC1E0CCBFE0C3B8
DFB8AEDDB1A4D9AC9AD4A48FD19C87D19F89D6AB96DBB9A7DFC4B5E1CCBFE1CEC2E1C8BEE1BEB6\
DFBBB1DDC0B1DDC6B3DFC8B3DDC1ADD8B4A0D4A996D2A28ECE9B86C9927DC4917B
C2957FBE947FBA8D78B88871B8886FB88970B98972BB8A73BD8D71BE8E6FBC8B6EB9886CBA866B\
BF8C72C89881D0A18DD2A48FD0A28DCD9E89C99985C59480C2917DC1907CC1927D
C1967FC69C85C59D86A4827064504848403F756F70B5AFAFD6D4D5E0E3E4E3E7E8E2E5E6E1E4E5\
E1E4E4E1E3E4E1E3E4E0E3E3E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E1E1
E0E1E1E0E1E1E0E1E0E0E0E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E3E4
DFE1E1DEDAD7DCD1CADDCABDDFC4B2DDBCA8D8B39CD2A990CEA58BCAAA97CAB3A7D1B7ADDBB8AA\
E0BCADE1C2B4E0C8BAE0CBBEE0CDBFE0CDBFE0CDC0E0CDC0E0CEC1E0CDC0E1C6BA
E0BDB1DFB6A8DCB29FD8AB95D3A38BD2A089D4A48FD9B19FDEBFB1E1CABEE1CEC2E1C8BEE1BFB7\
DFBCB2DEBFB1DEC5B3DFC7B5DDC0AFD8B4A3D4AB99D2A692CE9D89C8937FC4907C
C39480C1937FBC8A76B9846EB8846DB88770B98973BB8C75BE8F75C09074C08E73BF8C72C08D73\
C5927ACC9C85D1A28DD0A18CCE9D89CB9B86C89883C69581C4937EC2917DC1927C
C1957FC69C84C59C85A48170624E453D34325B5351968E8AC6C2C0E1E1E2E6E8EAE2E5E6E0E4E4\
E1E3E4E1E3E4E0E3E4E0E3E3E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E1E0E1E1
E0E1E1E0E1E1E0E1E0E0E0E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E3E4
E0E1E0DFD7D0DFCCBEDFC6B5DEC2B1DAB8A5D3AC95CEA28ACBA189CCAA94D1B4A3D8B6A9DDB5AA\
E0B8ADE0C1B4E0C8BAE0CCBEE0CDC0E0CDC0E0CDC0E0CDC0E0CEC1E0CDC0E0C9BB
E1C4B3E0BEACDFB8A3DAB099D4A88FD1A188D2A089D7AA97DDBCADE0C9BCE1CDC1E1CBBFE1C6BA\
E0C3B7E0C4B7E0C7B9E0C7B9DEC1B3DAB7A8D6AE9ED2A895CEA18DCA9A85C79782
C69783C3937FBE8B76BA846FB9836DB9866FB98873BB8C76BE8F79C2917AC4917AC7927CCA9781\
CE9D87D0A38DD0A48FCDA08BCB9C87C99A85C89984C79883C59681C3937EC1927C
C1967DC59B81C49B83A683706B544841322C483B36736762ABA3A0D5D2D2E1E2E3E0E3E4E0E4E4\
E1E4E4E0E3E4E0E3E3E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1
E0E1E1E0E1E1E0E1E0E0E0E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E4E5
E0E1E0E0D7CDE0CBB8E0C5B1DDC0ADD4B19CCCA088C99C84CDA48DD3AE99D9B4A2DDB5A7DFB6AA\
E0BBAEE0C2B4E0C8BAE0CBBEE0CEC2E0CFC4E0CFC3E0CEC1E0CDC0E0CDBFE0CBBC
E0C8B6E1C4B0E0BEA9DBB69FD5AC93D0A289D0A087D4A993DAB9A8DEC6B7E0CBBEE1CBBDE1CABB\
E1C9BAE1C9BCE1CABEE1C9BCDFC3B6DBBAABD6B09FD1A894CDA18CCA9C88C89B86
C79985C39581BF8E79BC8873BC876FBB876FBA8870BB8974BE8D79C3917EC89583CD9A88D2A18E\
D4A792D3A893D0A691CCA28DC99E89C89C87C89B86C79A84C59782C29580C1947E
C1967EC49B82C39C84B08C77876855614636543B2F624C43857570ACA4A2CBC9CADDDFE0E2E6E6\
E1E4E5E0E3E4E0E3E3E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1
E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E4E4E3E8E7E7D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E2E0E2E3E0E3E3
E0DFDDE0D4CADFC7B4DEC0A9D8B7A1CDA48CC39278C5987ECFAB94D8B3A2DDB3A6DFB6A8E0BCAC\
E0C1B0E0C4B5E0C7B9E0CBBEE0CFC3E0D1C7E0D1C6E0CEC2E0CDC0E0CDBFE0CBBD
E0C8B9E1C6B5E0C2AEDBBAA4D5AE97D1A68DD1A58BD4AD94D8B9A4DCC3B2DFC7B8E0C8B9E1C8B6\
E1C9B8E1CBBCE1CBBFE1C8BCDFC3B5DBBAA9D5AF9CCFA48FCA9C87C99A85C79A85
C49984C29681C0917CBF8E76BE8C70BC8A6DBA866DBA8671BE8C78C49381CB9A89D1A191D6A896\
D7AC98D4AA96D0A892CBA590C9A38EC8A08BC79D88C59A85C39883C19781C19680
C19780C39B84C49F88BD9881AA836890674D79503C6B483C6D554E857A76B4B1B0DADDDDE5E8E9\
E2E5E5E0E3E3E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1
E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E4E4E3E8E7E6D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E2E2E0E2E3E0E2E2E0DFDE
DFD7D2DEC9BCDBB8A5D6AB95D09E89C69079BF8A71C1987FCBAE99D6B8A7DDB8A9E0BBAAE0C1AD\
E0C4B1E0C5B5E0C7B9E0CBBEE0CEC3E0D1C6E0D0C5E0CEC2E0CDC0E0CDBFE0CBBE
E0C8BAE0C6B6DEC3AFDABCA6D6B29CD3AD96D3AE96D6B59CD9BDA6DDC3AFDFC5B4DFC3B3DFC1AF\
DFC3B1E0C7B7E1C8BAE1C3B7DEBCAFD9B5A2D3AB94CC9E88C89782C69581C49681
C09580BF937DC09279BE8F74BB8B6EB8866AB7836ABA8570BF8E7AC69885CD9F8ED3A695D7AC99\
D7AE99D4AB96D0A893CBA690C9A48EC8A08BC79D87C59A84C39982C19880C1977F
C2967FC59983C69F8AC5A087BF9478B180649D6B548B6152826960918783B8B7B6DADDDEE4E7E8\
E2E4E5E0E3E3E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1
E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E4E4E3E8E7E6D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E2E0E2E2E0E2E2E0E3E3E0E1E1E0D9D5
DFCBC2DBB9A9D5A490CE8F7BC7806DC17D6ABF8872C09B86C6AF9CD0BAA9DBBEACE0C1ADE1C3AE\
E0C4B1E0C5B5E0C7B9E0CBBDE0CDC0E0CEC2E0CEC2E0CDC0E0CDC0E0CCBFE0CABD
E0C7BADEC4B4DCC1ADD9BCA6D7B6A1D6B59FD7B8A1D9BDA6DCC2ACDFC5B1E0C6B2DFC1AFDCBBAB\
DDBCACDFC2B1E1C3B4E1BCB0DDB4A7D7AE99D0A58CCB9A83C6937EC3917DBF907C
BC8E79BC8E76BE8F72BB8C6EB4856AB18068B5816BBC8873C3947FC99E8ACEA491D3A995D7AD99\
D7AE99D4AB96D0A792CBA48EC9A18BC89D88C89A85C79883C59881C3977FC2967C
C4937CC69681C89E89C7A08AC3987FBD8A71B58069B08674B49E95C0BCBAD0D3D4DDE0E1E1E4E5\
E1E3E4E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1
E0E1E1E0E1E0E0E0E0E0E0E0E0E0E0E4E4E3E8E7E6D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E3E0E3E4E0E0E0E0D3CF
DFBFB5DAA99AD29381C97D6CC27060BF7664BF8A75C29F8BC7B19ED1BCAADBC3AFE0C5B2E0C6B3\
E0C5B4E0C5B6E0C7B9E0CABDE0CCBFE0CDBFE0CDBFE0CDC0E0CCBFE0CBBDE0C9BB
E0C7B7DDC4B1DAC0ABD9BBA6DAB9A3DAB9A3D9BDA7DBC1ACDEC4B1E0C7B5E0C8B6DFC3B3DDBDAE\
DDBDAEDFC1B1E1C1B1E0B9ABDCB1A1D5AA95CEA189C89781C4907CBF8D79BB8B77
B88873B78870B9896DB7876BB2826AB1816CB88772C0907BC79B86CCA48FCFA893D3AC97D6AE99\
D7AE99D4AB96D0A791CBA28DC99E89C89B85C89883C89682C79581C5947FC4937C
C4917BC69480C79D89C69F8AC2957FBE8A72BE8972C69C8AD5C1B9E1E0E0E3E7E9E0E3E4E0E2E3\
E0E3E3E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E1E2E0E1E1E0E1E1E0E1E1
E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0E4E4E3E8E7E6D8D9D8
D8D8D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E3E4E0DFDEE1CFCB
DFB7AEDAA093D28C7CC97A6AC17161BE7967C08D78C6A38DCFB49FD7BFABDDC4B2E0C7B7E0C9B9\
E0C8B8E0C6B8E0C7B9E0CABCE0CCBEE0CCBEE0CCBEE0CCBEE0CABDE0C8BAE0C6B7
E0C5B3DDC2AEDABFA9DABBA5DCB8A2DCB9A3DABCA7DBC1ADDEC4B4E0C8B8E0CABBE0C8B9DFC4B6\
DFC2B5E0C3B5E1C1B2E0B9A9DCB19FD5A994CDA08AC69681C08F7ABC8B76B88873
B58570B3836DB3846CB3846CB4856EB88974BF927DC69B86CCA28DCFA792D1AB96D3AE99D6AE9A\
D7AD98D4AA94CFA690CBA28CC89E88C89A84C89682C89381C89181C79180C5907D
C48F7BC49480C69D8BC59E8CC0927CBC866DBE8870C99F8DD9C6BEE6E5E4E5EAECE1E4E5E0E2E3\
E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1E0E1E1
E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0E4E4E3E8E7E6D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E2E0E1E1E0E0DFE0DAD6E1CBC4
E0B7ABDCA394D4907FC97F6DC17865BE806AC2927BCBA790D6B8A1DDC1ADDFC4B4E0C7B9E0CABC\
E0CABCE0C8BAE0C8BAE0C9BBE0C9BCE0C9BCDFC9BADEC8B8DEC7B6DFC5B5E1C3B2
E0BFAFDDBDABDABBA7DAB8A2DCB59FDBB5A0DAB9A4DBBEACDEC3B4E0C7B9E0C9BAE0C9BAE0C8B9\
E0C7B9E0C5B9E1C1B3E0B9AADCAF9ED5A693CD9D88C49480BE8E79BA8A75B78771
B4846FB2846EB1846FB28771B78B74BD917AC49A83C9A18BCEA590D1A994D3AC98D4AE9AD5AD98\
D5AA95D3A791CFA48ECBA18BC89D87C89882C8937FC8907EC88F7FC78E7EC48E7D
C2907BC29680C59E8CC69E8DC2937EBF886FBF8971C59C8AD0BCB4DBD8D8DFE2E4E0E3E4E0E3E3\
E0E3E3E0E2E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1E0E1E1
E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0E4E4E3E8E7E6D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E2E3DFE0E0DFDAD6DFD1C7E0C5B6
DEB7A5D9A592D0937EC5846DBD7E65BD856CC4967FCFAB94DABBA5DFC3AFE0C5B5E0C7B9E0CABC\
E0CBBDE0CABCE0C8BAE0C7B9E0C6B8DFC6B7DDC4B4DBC2AFDCC2AEDEC2AEE0BEAD
DFB7AADDB5A7DAB6A3D9B5A0D9B39DD9B39DD9B6A1DBBCAADEC2B3E0C6B7E0C7B6E0C7B6E0C7B8\
E0C7BAE0C6B9E1C1B5E0B7ACDCAC9ED5A190CC9984C4937DBE8E79BA8A75B88772
B68671B48772B28975B48D77BA9179C0977EC69D85CAA18CCFA590D2A994D5AC97D6AD98D4AB96\
D3A892D1A48ECFA18CCBA08AC89C87C89681C8917DC88F7CC78E7CC48E7BC28F7A
C1927AC29880C49F8CC69E8EC69481C38C75C18D76C29A87C5AEA4CDC4C2D7D6D7DFE1E1E1E4E4\
E0E3E3E0E2E3E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1
E0E1E0E0E0E0E0E0E0E0E0E0E0E0E0E4E4E3E7E7E6D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E2E0E3E3DFDFDEDED3CBDBC3B2D9B6A0
D4A992C99982BC8870B47D64B37C62BA886EC69B84D3AF98DCBEA7E0C4B0E0C5B5E0C6B8E0C8BA\
E0C9BBE0C9BBE0C7B8E0C5B5E0C3B2DFC2B0DDC0ADDABEA9DABDA7DBBBA7DCB7A6
DBB1A4DAAFA1D9B2A0D8B3A0D8B49FD8B59FD9B8A2DBBDA9DEC2B1E0C5B4E0C6B4E0C6B5E0C6B7\
E0C6B9E0C6B9E0C1B5DEB9ADDAAD9FD4A18FCD9883C5927DBE8D78BA8A75B88772
B88772B78974B68D78B8917BBC957DC29981C89D88CCA18DCFA590D2A893D4AB95D5AC96D3AB96\
D1A893D1A58FCFA28CCBA08AC99D87C89883C8947FC6927DC4907BC28F7AC08F79
C0917AC29882C59F8DC69D8CC5907CC38870C38E77C29985C1A092C5ADA6D2C7C5DEDEDEE1E5E5\
E1E3E4E0E2E2E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0
E0E1E0E0E0E0E0E0E0E0E0E0E0E0DFE4E4E3E7E7E6D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0DFE0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E3E0E3E4DFDEDCDBCBC0D4B29CCC9E83
C08D75AE7D669E70599A6B54A3725BB4866FC79F88D5B39DDDBFA9E0C4B1E0C4B4E0C4B6E0C5B7\
E0C6B8E0C6B7E0C5B5E0C4B2E0C2AEE0C0ACDDBEAADABDA8D9BAA6DAB6A4D8B1A1
D6AE9ED6AD9DD7AE9ED8B2A0D8B6A2D7B9A3D8BBA5DABEA9DEC2AEE0C5B2E0C5B5E0C5B6E0C5B7\
E0C6B8E0C5B8DFC3B4DCBCACD8B29FD3A490CC9984C4927DBE8D78BA8974B88772
B88772B98974BB8D78BD917CBF967FC49984CA9D8ACEA08FD0A490D1A691D2A892D2A993D1AA95\
D1A994D0A691CEA38DCBA08AC89D88C79B86C69983C49680C2937DC0907AC08E79
C08F7CC29584C59D8EC59988C18771BF7E64C18C72C39881C19481C59B8DD1BCB5DDDCDBE1E5E6\
E1E3E4E0E2E2E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0
E0E1E0E0E0E0E0E0E0E0E0E0E0E0DFE4E4E3E7E7E6D8D9D8
D8D9D8E7E7E6E4E4E3E0E0DFE0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E3E0E4E5DFDDDBD9C4B7CCA188B78265
A06C538E5F498459458258468D6250A67D6AC39E89D7B6A0DEC0ACE0C4B2E0C4B5E0C4B5E0C4B3\
E0C4B3E0C4B3E0C4B3E0C4B2E1C3B0E0C1AEDFC1ADDDC0ADDCBEADDCB9AAD9B4A4
D6B09FD5AC9BD5AA9BD5AC9BD4B19DD4B6A0D7BAA4DABEA8DCC1ACDEC3B0DFC5B5E0C5B8E0C5B8\
E0C6B7E0C5B6DEC2B1DABCA9D6B19DD0A48FC99784C28E7DBC8977B98772B7866F
B6856FB88772BC8C77C0927CC29782C69A86CB9C8ACE9E8CCEA28ECFA48FD0A490D0A490CFA591\
CEA691CEA48FCCA28CC89E88C59C86C59B85C49B85C29882C0957FC0917BC08E7A
C08D7DC19284C3998AC29581BD8469BA7C5DBE896BC19278C18B75C69181D2B6AEDDDADAE1E6E7\
E0E3E4E0E2E2E0E2E2E0E2E2E0E1E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0
E0E1E0E0E0E0E0E0E0E0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0E0E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E2E3E0E4E5DFDCDAD9BFB2C8967CA66E52
84533A764B36754C3B714B3D765145957162BE9A87D7B6A2DFC1AFE0C4B4E0C4B5DFC3B3DFC3B0\
DFC3AFDFC3AFDFC3B0DFC3B1DFC2B1DFC1B0DEC1B0DDC0B0DDBFB0DCBCAEDAB7A8
D7AFA0D4A899D2A395D0A292CEA591D0AC96D5B49DD8BAA4DABEA8DCC1AEDEC4B4E0C5B8E0C5B8\
E0C6B6E0C5B3DEC0AEDAB7A6D4AC9ACDA08CC59382BE897BBA8576B8856FB6856C
B4836BB6856FBB8A75C0917CC49883C69B86C89A86C99B86CA9D89CBA08CCEA18ECEA08ECC9E8B\
CA9E89CA9F89C89F89C59C86C29983C29983C19982C19881C0957FC0917BC08E7A
C08D7DC19082C19584BE917AB88467B47D5BB68161BA8569BD826BC58E7FD2B5AEDDDAD9E1E6E7\
E0E3E4E0E2E2E0E2E2E0E2E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0
E0E0E0E0E0E0E0E0E0E0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0E0E0E0E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1E0E1E1E0E1E1DFE1E1E0E2E2E0E3E2DFD9D6D9BDB0C8947EA76E54
84523A7348346D463665423769483F8C6A5DBB9885D7B6A2DFC1AFDFC3B2DEC2B1DEC2B0DFC3AF\
E0C4AFDFC3ADDCBFABD9BBA9D8BAA9D7B9A8D6B7A6D3B3A2D2B1A0D2B09FD1AC9C
CFA597CD9E91CB988CC99789C99B88CCA28CD1AA94D5B29CD7B8A3DABEABDEC3B3E0C5B8E0C5B8\
E0C6B6E0C4B3DEBFAEDAB4A5D4A898CC9C8AC3917EBC8777B88371B7826BB58368
B3836AB4846EB88873BD8F79BF947FBF9781BF9680C09680C39983C79D89CBA08DCC9F8CC99B87\
C79984C79B85C69D87C49B85C29983C09781C09781C09680C0957EC0917BC08E7A
C08D7DC09080C09280BA8E76B08063A87454A76F51AC7054B5755EC28C7BD2B6AEDDDAD9E1E5E6\
E0E3E4E0E2E2E0E2E2E0E1E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0
E0E0E0E0E0E0E0E0E0E0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E7E7E4E4E3E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1\
E0E1E1E0E1E1DFE1E1DFE1E1DFE2E2E0E1E1E0DEDCDFD3CDDABBAFCA9A88B07863
915D47774B376440315A3B3063443B89695CBA9784D7B6A0DFC1ABDEC1ADDCBFABDCC0ADDEC2B0\
E0C4B1DFC2ADD9BBA5D2B29DCEAD99CCAB97C6A490BF9B87BB9682BA9581B99382
B99081B98B7FBB877DBF8A7DC3917EC79781C99B84CBA18BCFAA95D5B5A2DBBEAEDFC4B6E0C5B8\
E0C5B7E0C4B5DEBEAFDAB3A5D4A797CB9C89C3927CBC8972B8846BB78266B58267
B3846BB38670B78873B98C76B8907BB7927DB7927DB9937DBE9680C49B86C7A08BC79F8BC49B86\
C39882C59A84C69D87C69D87C49B84C19882BF9680BF967FBF947EBF917BBF8E7A
C08D7CC09080C09380B88C74A8785E9B634997593F9E5940AC674DBE8772D1B5AADDDAD8E1E5E7\
E0E3E4E0E2E2E0E1E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0
E0E0E0E0E0E0E0E0E0E0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E8E7E4E4E3E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1E0E1E1\
E0E1E1DFE1E1DFE1E1E0E2E2DFE2E2DFE0DFDFD8D2DDCABFDAB8A9CB9C8DAC7867
855443663E2E5234274B322859403786685BBA9885D8B6A0DEBFA8DCBFA8DBBDA7DCBEAADFC2AF\
E0C4B1DFC2ADD9BAA3D0AE97C8A58FC19E88B7937CAB866FA17D689B7966967566
947266966F649E6F64AA7769B6826FBA866FB9836CB8826CBC8A75C79C89D4B2A0DDC0B0E0C4B6\
E0C5B7E0C4B6DEBFB0DAB5A5D4A997CC9D89C3927BBC8B6FB88668B58465B38467
B1856BB38770B78A74B98E78B9927DB8947FB8947FBB9580C09781C59A85C59C88C39B87BF9783\
BE9681C29A84C79D87C89E88C69C86C29983BF9680BC947EBB927CBA8F7ABC8E79
BE8F7CC09280C19480B88B74A5735C955A44904D36974D35A75D43BC806AD0B2A6DDD9D7E1E6E7\
E0E3E4E0E2E2E0E1E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0
E0E0E0E0E0E0E0E0E0E0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E8E7E4E4E4E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E0E0E1E1E0E1E1DFE1E1DFE1E1\
DFE1E1DFE1E1DFE1E1E0E2E2E1E4E4E1E0DFDED3CADCC1B1DAB19FC999889A6B5D
633B3044261B3A241B3A27204D3930806658BB9A86D9B8A0DDBEA6DCBDA6DDBCA5DEBEA8DFC2AC\
E0C4AFDFC3ADDCBDA6D4B29CC9A58FBB9781AE8A74A17D6791715E7F6658715B51
6A534A6D50457A54458D614E9F6E5AA6705BA56853A3624DA76954B7826DCCA490DBBCAAE0C4B5\
E0C6B8E0C5B8DEC0B2DAB8A6D4AC98CB9E88C3927ABB8A6EB68768B28665AE8364
AB7E64AD8069B58873BC917BC09780C09982C09983C19882C39680C49581C29482BE9381B9927E\
B9947EC09983C79D87C99E88C79C86C39983BE957FB8917CB48F79B48D78B68E79
BB917CC09480C0957FB78A74A6735C965B45924E38994D37A85A42BC7C67D0AFA5DDD9D7E1E6E7\
E0E3E4E0E1E2E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0
E0E0E0E0E0E0E0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E8E7E4E5E4E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E1E1E0E1E1DFE1E1DFE1E1DFE1E1\
DFE1E1DFE1E1DFE1E1E0E2E2E3E7E8E6E6E4E3D4CADDBCA9DAAB95C59280916356
543229341C152D1C1530201947332B7E6457BB9C88DABAA3DEBFA8DCBDA6DCBCA5DEBEA7DFC1AB\
E0C4ADE0C3ADDFC1ABD9B9A4CDAA95BE9984B48E79AA8672947666755F545A4A42
4C3B344E362C5B3C2D6F4C3A825C4A8F604E965B479B5843A4624DB57E68CBA28CDABBA8DFC5B5\
E0C8BCE0C9BDDEC5B7DABCAAD4AF99CB9F89C19079B8876DB28466AD8362A4785A
9A69519D6A55AC7C67BB8E76C1947BC2967BC0957CBC917AB88B75B78873B98977B98C7BB78F7C\
B8937DBF9880C69C84C79D86C69C85C29983BD947EB68F79B08B75AF8B76B38E79
B9917CBF937FBE927DB48671A2705B945B4793533E9C543EAB5F49BE7E6DD2B1A9DFDBD9E2E7E8\
E1E3E4E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0
E0E0E0E0E0E0E0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8DAD9E7E9E8E4E5E4E0E2E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1DFE1E1DFE1E1DFE1E1DFE1E1\
DFE1E1E0E1E1E0E2E1DFE2E2E1E4E4E3E1DEE1CFC4DEB8A4D9A68FC58E79966758
613E353D26202E1D172E1C17462F287E6355BB9E8ADBBDA6E0C2ABDCBFA8DBBDA6DCBEA7DEC1AA\
DFC3ACE0C3ADE0C3AFDCBEACD2B19EC7A18CC49B87BF9886A685757F65585C483F
49362E472F255134265F42336F5345815C4D935F4CA36751B27861C1907ACFAA94D9BDA9DEC7B7\
E0CCC0E0CEC3DECABDDAC0AED4B19BCB9F89C08F78B4826BAD7E63A87B5D9A694D
88503A894F3D9E6A57B2836AB6886CB28668AC8268A47B659D735E9E745FA87D69AF8672B08A76\
B28E78B99279BF967CC1977EC19680BF957FBC927BB58C76AF8973AE8A74B28D78
B98F7CBD8F7DBA8C78AC7F6A9869558A56448D54409B5B45AD6855C18779D6B8B0E2DEDDE4E8E8\
E1E3E4E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0
E0E0E0E0E0E0E0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E9E8E4E6E5E0E1E0E0E0DFE0E0DFE0E1E0E0E1E1DFE1E1DFE1E1DFE1E1DFE1E1DFE1E1\
DFE1E1E0E2E2E3E6E6DFE1E1CECCCBC0B5B1C7AB9FD7AB96DBA68DC9947DA37361
744F434C332D3423202D1C19432D267B6153BA9E8ADBBEA7E0C3ABDCC0A8DBBEA7DBBFA8DDC1AA\
DDC2AADEC2ACDFC3B0DEC1B0D7B8A6D1AC97D1A893CEA491B99281967665795D4F
694D416445376644346B4C3B7558488664529C6F59B17C65C18E76CDA089D4B19BDABEAADEC7B7\
E0CDC1E0D0C5DECBBEDAC1AED4B19BCB9F88C08E77B48169AC7B61A6755B97624A
844935824838936251A077639D775F8F6B547F5F4C7857467B574686604D936F5B997763977764\
9A7964A38069AC866DB0886FB38970B88B72B98C73B58A73B08972AF8A75B38C78
B98D7ABB8C7AB48772A278638A604E7B4F3E804E3D925B47AB705DC59384D9C0B8E4E1DFE4E8E9\
E1E3E4DFE1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0
E0E0E0E0E0E0E0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D8D7E7E9E8E4E6E5E0E0DFE0DEDDE0DFDEE0E1E0E0E2E1DFE1E1DFE1E1DFE1E1DFE1E1E0E1E1\
DFE1E0E0E1E1E2E4E4D4D4D4A89E9C856C65976E61C18E79D49E86C8967FA77966
7B5548523934352627291C1D3C2B25765F51B89D89DABDA6DEC1AADCBFA8DCBFA8DBBEA8DABDA6\
D9BCA5DABDA7DCC0ADDEC1B1DBBEADD8B8A4D6B19CD2A995C69C88B38C78A4806C
9C7765956E5A8F66508D654D926A529D755DAE8369BE8F75CA9981D1A48ED6B19BDABDA9DDC7B7\
DFCDC0DFCEC1DEC8BADABDAAD3AF99CB9E88C18F77B88369B07C61A8765C9D6851
9159448E594792685A927265856A5C6953464C39304530285B3D317351417D5F4E796150725A49\
74594885655394715C9C745CA3775CAF7E62B6856AB58970B08A74AF8C76B38D77
B98D78B98975AC816C95705B7B57456B46366F4535845443A5715EC69988DBC4BBE5E1E0E4E8E8\
E1E3E3DFE1E1E0E1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0
E0E0E0E0E0DFE0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D7D6E7E9E8E4E6E5E0E0E0E0DEDDE0DFDEE0E1E0DFE2E1DFE1E1DFE1E1DFE1E1DFE1E1E0E2E2\
E1E3E2DCDDDDCFCDCCB0A9A67B696556362F673B2E935F4EAF7B66AE7F6B946B5B
6D4B42493331302526261D1D3A2B25755F52B89D89D9BCA5DCC0A8DCBFA9DDC0ABDAB9A5D5B19C\
D1AD97D3B19BD8B9A6DEC1B1DFC5B4DDC3B0DABCA8D7B29FD1A995CBA08CC69A86
C29680BB8E76B4866CAF8065B08065B6886CC09477C99C81CFA188D4A790D7B09ADABBA7DDC6B5\
DFCCBEDFCCBEDDC5B6D9B9A8D3AC98CBA08AC3937ABB876BB38063AC7C60A6755B
A26E55A06E599E766798796C866C605F4C44332724261916422922614235695043614E42554438\
5943366F524385624F9269529E7055AD7B5EB78468B68970B18A74B08B76B48D77
BA8E77B587719F776282614F6A4C3C5D3E2F613D2E774A3A9E6855C39380DAC0B6E3DFDDE3E7E8\
E1E3E3DFE1E1E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0E0E0E0
E0E0E0E0E0DFE0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D6D6E7E8E7E4E6E5E0E2E1E0E0E0E0E0E0E0E1E1DFE1E1DFE1E1DFE1E1DFE1E1DFE1E1E1E3E3\
E3E6E6D7D7D7B0A8A57D6B66553D3643251D4822185E2F237747388056476E4D43
4F36343627272A201F281D193F2D26796153B99D89D9BCA4DCBFA8DCC0ABDDBFADD8B3A2CFA391\
CA9D89CBA28DD2AE9BDABBAADDC3B3DDC4B4DBC1B0D9BAA9D6B1A0D2A897CDA08D
C89983C3947DC09279BD8E75BE8D73C19176C79A7DCDA186D2A58DD5AA93D7B19BD9BAA7DDC5B4\
DFCBBDDFCBBDDDC3B4D9B6A6D3AB99CBA28EC3977FBB8B70B58566B08464AD8161
AE7C5FB07E64B08570AD87759F7A6A765A4E41312D2A1E1B3D271F573A2E60463B5A463D503E35\
5540346D4F3F86604B976B54A5765CB28366BA8A6EB98A71B48972B28A75B58F77
BA9177AF856D8F6A586D4E415A3F325338295837286E4030955945BC826FD5B5ABE0DBD9E2E6E7\
E0E3E3E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0E0E0E0
E0E0E0E0E0DFE0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D7D6E7E8E7E4E6E5E0E2E2E0E2E1E0E2E1DFE1E1DFE1E1DFE1E1DFE1E1DFE1E1DFE1E1E2E4E3\
E5E7E7D3D2D19B8E8B5D443E42261E40251C3F1E154119114F271D59362C4A322D
332325281D1E291E192F1E17462F267D6154BB9C88DABBA3DDBFA7DCBFAADCBDABD7B2A2D0A394\
CA9C8AC79C87C8A18CCCA895CEAE9DD0B3A2CFB3A2CDAF9EC8A696C19A8BB88E7D
B18471AE816CAF846DB1856EB4846DB7866DBC8C71C3967CCCA18AD3AB95D6B39DD9BBA7DDC4B3\
DFC9BADFC9B9DDC1B0D9B4A3D3AA99CBA490C39B83BB8E73B68769B38765B38764
B58664B8896ABC8F74BE9179B589739771606C53485540385B403568483A6C4C3F674A3F61473C\
684B3E7E5A47966A53A5755CAF8064B68A6EB98F73BA8D73B88B72B68C75B89179
B99278A9836A83604F5E41354D34294B32255232246838278E4B37B57260D0ABA1DDD8D6E1E6E6\
E0E3E3E0E1E1E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0
E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E8E7E4E6E5E0E2E1E0E2E1E0E2E1DFE1E1DFE1E1DFE1E1DFE1E1DFE1E1DFE1E1E2E4E3\
E5E7E7D2D0CF978986593E3741241A43291D42251B3F1F1642231B422A22342420
24191A2419182F1E193620194B30277F6053BB9A86DBB9A1DFBEA6DCBDA6DABCA7D9B9A7D7B3A3\
D1AB9AC9A28EC19983BB917CBA917DBC9682BA9884B49480AC8B79A37F70997264
936958916654936954986D579E6F58A26F58A7745CB3836BC39A83CFAC95D5B6A0DABDA9DDC2B2\
DFC6B6DFC5B3DDBDAAD9B39FD3AA97CBA590C29B85BA8E76B68469B48163B38261
B28663B68C6ABC9273C19579BE9279B188739F7B699271608F6B598D675489604E835A49805947\
885F4D996D58AA7A61B48265B78869B68C70B68F75B99075BC9075BC9178BC937B
B79179A17E68785A49533A2D432C23452C225030246837268B4531AF6957CCA59BDDD7D5E2E6E7\
E0E3E3E0E1E1E0E1E1E0E1E0E0E1E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0
E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D9E7E8E8E4E5E4E0E2E1E0E2E1DFE2E1DFE1E1DFE1E1DFE1E0DFE1E0DFE1E0DFE1E0E2E4E3\
E4E7E7D2D0CF9A8C885D433B42251A40271A3F271D3C251D3A251E36251F2C1F1B
231815261A16301F1A38231D4D342B806154B99783DAB59EE0BCA4DEBCA5DBBDA6DCBFABDDBFAF\
D9BAA9D0AE9BC49F89BA9079B58872B28671AB836FA17E6C9A7868967162916859
8A5F4F885D4A8A604A8E624C93634C99654EA16C55B08069C29B84CFAF99D7BAA5DBBFADDEC2B2\
DFC1B2DFBEAEDDB8A5D9B19DD3AC96CBA58FC29A86BA8B77B27C68AB725AA67054
A57656AA815FB58C6BBE9475C1977BC1967DBF957CBC9179B68B74AF826BA678619E70599C6F58\
A2745EAD7F67B7886DBA8B6DB98C6EB78C73B68D77B89077BB9277BE9479BD947A
B48D769877626B524245322636251C402A2259392C774432904B36AB6855CAA49BDFDAD8E4E8E9\
E1E3E3DFE1E0DFE1E0DFE1E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0E0
E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E4E3E7E7E6D8D8D8
D8D9D8E7E8E7E4E5E4E0E1E0E0E1E0DFE1E0DFE1E0DFE1E0DFE1E0DFE1E0DFE1E0DFE1E0E2E4E3\
E4E7E7D3D1D09D908961463C402317371E1333201730221A30221B2F211A2B1E18
271B15271B152B1F1935261F4E3A327F6456B5937FD5B098DEBAA2DFBDA5DEBFA8DEC1ADDFC3B2\
DDC0B1D9BAAAD1B29ECAA691C29984B98C7AAC83739F7D709E7C70A57C6FA57868
A0715F9C705B9C725C9D715B9E6F58A4725BB07D67BE917ACBA790D4B7A2DABEACDDC2B1DEC2B3\
DFBDB0DFB7AADDB2A3D9B19DD3AE97CBA790C39B88BB8A7BAE77689F6652945C44
915E44996B4EA77E5EB38D6CBA9374BF9579C2977BC4977CC4957CC09078BA8B71B3866BAE836B\
B0856DB78B71BB8F73B98F73B68C74B78B77B88C79B68D78B79077BC9378BB9176
AC866D8B6C585B473934281F291F183E2D246A493B8F5A469B5740A66754C19F95DAD5D3E1E5E5\
DFE2E2DFE0E0E0E1E0DFE0E0DFE0E0DFE0E0DFE0E0E0E0E0E0E0E0E0E0E0E0E0DF
E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E8E8E4E5E4E0E0DFE0DFDFDFE0DFDFE1E0DFE1E0DFE1E0DFE1E0DFE1E0DFE1E0E1E3E3\
E4E7E7D4D2D0A1938C664B3E41221532180E2B1911291D16291F18291E17271B15
251913241913271D173328214E3E357C6356AD8C78CDA891DAB69EDEBDA5DFC0AADFC2AEDFC2B2\
DFC3B4DEC3B4DCC2B1D9BDA9D2B19EC8A291BB978AB19288B39489BD978AC19786
BD9380BA927EB9937EB7917CB68E79BB907BC59A84CEA790D4B39DD9BDA9DCC2B2DEC3B4DDC1B2\
DDBBADDCB4A7DBB1A2D8B29ED3B099CDA993C79F8CC09182B37F71A16C5A905B47
87523E8757418E664C9673569C795DA47E63B0866BBC8E73C4947BC6977EC4977BBE9477B99176\
B89077B99177BA9176B68E75B48A75B48875B48876B48A77B78E78BB9077B68B70
A079617A5C494C3A2E2B221B251F194133297654439D664FA15D459D5F4CA9867BBEB5B2D0D1D1\
DCDEDEE0E2E2E0E1E1DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0E0E0E0E0E0DF
E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E9E8E4E4E4E0DEDEE0DDDCDFDEDDDFE0DFDFE1E0DFE1E0DFE1E0DFE1E0DFE1E0E1E3E3\
E4E6E6D4D2D1A4968F6B504345251934180E2D18102A1C15291F17261D16201712
1B120E1E140F271C163529224E3E36775F52A58471C5A089D6B199DDBBA3DFC0A9DFC2AEDFC2B2\
DFC4B6DFC7B8DFC8B9DEC7B6DBC1B1D6BAABD0B4A7CBB2A6CDB3A7D2B5A7D4B5A6
D3B4A4D2B4A3D1B4A3CFB3A2CFB1A0D1B19FD5B49ED8B7A0D8BAA3DABFABDDC4B4DDC4B4DBC0AE\
D9BBA8D9B7A4D9B5A2D7B39ED4B09ACFAB95CCA692C89F8DC19583B38572A1705E
8C5B4C7E504278513F74543F7355407E5C47946B55AB7D65B98B73BF937AC09579BD9477BB9376\
B89176B58F75B38C74B38871B1856FAC826DAC8370B38776BC8D7ABE8E78B0826B
8F6853664838422E242C221B2C251F47382E745140975D479B563E8F503C855E5291827DB6B3B2\
D8D9D9E3E4E4E1E2E2DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0DFE0E0DF
E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E9E8E4E4E3E0DEDDDFDCDCDFDEDDDFE0DFDFE1E0DFE1E0DFE1E0DFE1E0DFE1E0E1E3E3\
E4E6E6D4D3D1A498916B5348472B1F371D14311C142E1D162B1F17261D161D1611
160F0C1B120D281C153729224E3D34755B4EA07E6BC19B84D3AE96DBBAA2DEC0A9DFC2AEDFC2B2\
DFC5B6DFC8B9DFC9BBDFCABBDECABCDECABDDDCABDDDCABDDDCABDDDCABDDEC9BB
DEC8BADEC8BADDC9BBDDC9BCDDC8BADEC6B6DEC4B0DCC0ABDABEA8DBC0ABDDC4B1DDC4B2DBC0AB\
D8BBA5D7B9A2D7B69FD6B29CD5AF99D2AD97D1AD97D0AC96CEA792C79D89B78B7A
A073678D61567E574A714F40664839694A3A7B55438D645099715CA17A64A67E67A98168A98369\
A7836AA48169A47D66A67A64A77A64A87D68AC826EB78876C08D7AC08B77AA7A66
7F594754382B39261D2F221B33282346352D6441347E473486442F7C3E2B6B413473615AA4A09D\
D5D6D5E4E6E6E1E2E2DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0DFDFE0DF
E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E8E7E4E4E3E0DFDFDFDFDEDFDFDEDFE0DFDFE1E0DFE1E0DFE1E0DFE1E0DFE1E0E1E3E3\
E4E6E6D4D3D1A1989367554D4630273B261D34221A2F1F182C1E17291D16211812
1B140E1F150F2A1D163829224E3C3474594C9F7A67BF9780D2AC94DBB9A1DEBFA9DFC2AEDFC2B2\
DFC5B6DFC8B9DFC9BADFCABCDFCCBFE0CFC4E0D1C7E1D2C7E1D2C8E0D1C7E0CFC3
E0CDC0E0CEC1E0D0C5E0D0C5E0CEC1E0CBBCDFC9B8DEC5B2DDC2ADDDC1ABDDC3ADDEC3AEDCC1AA\
DABDA6D8B8A1D6B39CD6AF99D6AE98D5AF99D5B19AD5B19AD5AF99D2A996C89E8F
B99184AC8377A1766A91695C7E5C4E7252436F4D3D704D3C715140785745835F4C8B66528B6B57\
8B6E598E6D57926B54946A539B6F59A87B68B48674BC8A78C08C78BD8973A37561
734F41472E243320192F211B3326223D2B264B2C245B2C1F682D1D69302061392D6F5D56A39D9A\
D4D5D4E4E6E6E1E3E2DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0DFDFE0DFDFE0DF
DFE0DFE0E0DFE0E0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E8E7E4E4E3E0E0E0DFE0DFDFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0E1E3E2\
E4E6E6D3D3D2A098956758514B38304330283929222F211A2B1E162B1D16271B14
231912251A142D1F1A382A254E3C3472574A9B7762BA937BCEA890D8B79FDDBFA8DFC2ADDFC2B0\
DFC4B3DFC6B7DFC8B9DFC9BBDFCBBEDFCEC3DFD0C7DFD2C9DFD2CADFD2CADFD0C6
DFCEC2DFCEC3DFD0C7DFCFC5DFCCC0DFCABCDFC9BADEC7B7DEC5B2DEC3AEDEC2ACDEC2ABDEC1AA\
DCBDA6D8B7A0D6B19AD6AE97D6AD97D6AF98D6B19AD6B29BD7B09CD6AD9CD2A99A
CBA495C59E8EBF9484B287779F78688C69587C5B4A6F5140684C3B6A4C3B74503F7A56457A5B4A\
7E604D87644F8F664F9268519A6F5BAB7C6BB98677BD8B79BC8C76B687709B715D
6B4A3D412A22301E182D1F192F221E31211E331D173C1A114C1F1357281C5C392F73625BA7A29F\
D6D6D6E4E6E6E1E2E2DFE0E0DFE0E0DFE0E0DFE0E0DFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFE0E0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0DFE0E0E1E3E2\
E4E6E5D4D3D2A299966D5B54553E364E39313F2F282F231B291D162B1D162B1D15
2A1D152C1E1931231F3B2C284D3C356D544692705CB18B74C6A18AD4B29BDCBDA6DFC2ABDFC2AD\
DFC2B0DFC3B3DFC6B7DEC8BADECABCDECCBFDECEC3DED0C8DED2CADED2CADED1C8
DED0C6DED0C7DED0C8DECFC5DECBBFDEC9BBDEC9BADEC8B9DEC7B7DEC5B2DEC3ADDFC2ABDEC1AA\
DCBDA6D9B6A0D6B19BD6AF99D6AE98D6AE97D7AF98D7B19AD7B09CD7AD9CD5AB9B
D1AA98CDA794C9A18DC19884B58D79A8816D9A76638E6D5A85665281604C815C49825B48825D4A\
88634E946A549E715BA17761A67B68B07F71B88376B88877B58A74AC846C926D59
66483B402921301E172D1E182B1F1A281D182619132A170F381C1347261D54393172625BA7A19E\
D5D5D4E4E5E5E1E2E2DFE0E0DFE0E0DFE0E0DFE0E0DFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0E0DFE0E0DFE0E0DFE0E0DFE0E0E1E3E2\
E4E6E5D4D3D1A59995715B535A3F35533B3144322932261E2B1F182C1D162E1C15
2F1D16321F1A3725213F2D294E3A32664E40856753A4816BBE9982D0AD96DABBA3DEC1A9DFC2AB\
DFC1ADDFC2B1DEC4B5DEC7B9DECABCDECBBEDECCC1DECEC4DED0C7DED1C9DED1C9
DED1C9DED2CADED1C9DECFC5DECBBEDEC9BBDEC8BADEC8B9DEC7B7DEC5B3DEC3AFDEC1ACDEBFA9\
DCBBA4D9B49DD6B19AD6B19AD6B099D6AE98D6AE97D6AF98D7AE9AD6AC9AD5AA98
D1A995CEA691CAA38CC79E87C29881BB927BB48D76AD8872A7836DA27C669C745E986F58986E57\
9E725BA87862B0806AB28570B48775B68375B88375B68674B08670A37D65886551
614436402921311E182D1E172C1F18291E17241B14241A122E1D163B261D4B362D6C5A52A09590\
CDC8C7DEDDDDE0E0E0E0E0E0DFE0E0DFE0E0DFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE4E3E3E7E7E6D8D8D8
D8D9D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0E0DFE0E0DFE0E0DFE0E0E1E3E2\
E3E6E6D4D2D1A5989272594D583B2E50372A463328392B2231231C2E1E172F1B13
321A13351E1739241E412C244C372B5D4637765A48967460B58F79CBA68FD6B69FDCBFA7DEC1AA\
DFC1ADDFC1B1DEC4B5DEC7B9DECBBEDECDC1DECDC2DECCC1DECDC2DED0C7DED1C9
DED1CADED2CADED1C9DECEC4DECBBEDEC9BADEC8B9DEC7B7DEC5B3DEC3B0DEC2AFDEC0ADDEBDA8\
DCB7A0D8B19AD6AE98D6B099D6B19AD6B099D6AE98D6AD97D6AC96D6AA96D4A894
D1A690CEA38CCCA089CA9D86C79B83C39881BE957EBC937CBB927BB88F78B38972AF846DAF836C\
B1846DB6856FB98872BB8A77BB8A79BB8877BA8674B78671AD80699970597B5743
593C2F3E271F311F182F1E18312019302119291E17241C15281D1633221A432E24624D42907E78\
BCB0AED5CFCFDEDEDEE0E2E1E0E1E0DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFE0DFDFE0DFE0E0DFE4E3E3E7E7E6D8D8D7
D8D8D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0E0DFE0E0E1E3E2\
E4E6E6D4D2D0A3968F6E55485338284D35274734293F2E253727203220192F1B13
2F1810321B1437211A3C271E452F23523A2C674C3C876450A88069C29B82D2B098DBBCA5DEC1AA\
DFC1ADDFC2B1DEC4B5DEC7B9DECCC0DECFC5DECFC5DECCC1DECCC0DECEC3DED0C6
DED0C8DED0C8DECFC6DECDC1DECABDDEC9BADEC8B9DEC6B5DEC3AFDEC1ADDEC1AEDEBFACDCBAA5\
DAB49DD8AF98D6AD97D6AE98D6B099D6AF99D6AE97D6AB95D6AA94D6A993D4A892
D1A48ECEA089CC9D86CB9B84C89A83C49A83C29881C19780C29780C2967FC0947DBE927BBD917A\
BC9078BB8D76BA8A76BA8A78BA8B79BA8B77B98973B4846EA4786189624D684837
4A312536231C2F1F1930201B32211C30201B291E17231B14221812291A1339251B563E33806861\
AA9895CAC1C0DCDBDBE1E3E2E0E1E1DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFE0DFDFE0DFE0E0DFE4E3E3E7E7E6D8D8D7
D8D8D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0E0E1E3E2\
E4E6E6D3D1CFA0948C69524551382A4E392D49372E4130283B292237231C2F1D15
2919112A1A12301E1634221939261C4730245C4031785540966E54B48D72CDA990DABAA2DEC0A9\
DFC1ADDFC1B1DEC3B4DEC7B9DECCC0DECFC6DED0C7DECFC5DECDC1DECCC0DECDC2
DECFC6DECFC5DECDC1DECABDDEC9BBDEC9BADEC8B9DEC6B4DEC3AEDEC1ABDEC0ABDCBDA8DAB7A1\
D8B29CD7B099D6AE97D6AC96D6AC96D6AC96D6AB95D6AA94D6A993D6A993D4A791
D1A48DCD9F88CA9C85C89A83C69A83C59B84C49C85C39B84C29881C2967FC4957EC4957EC1947D\
BD927BB88E78B58B76B48A76B58B76B58B76B28972A98069956F59735544513A2E
37271E2B1E172D1F1A30211E2D1F1D271B18231A141E171019110D1D110D2E1C154B332A72584F\
9C8681C2B7B4DAD9D8E2E3E3E0E1E1DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFE0DFDFE0DFE0E0DFE4E3E3E7E7E6D8D8D7
D8D8D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE1E3E2\
E4E6E6D3D1CFA0948C68524550392C4F3B324B3A3343332B3F2C253B271F322119
291C14281B132C1D162E1F1833231B412D24553B2E6A4B38835F47A57F65C5A087D8B59DDEBDA7\
DFC0ACDFC1B0DEC3B4DEC6B7DECABDDECDC2DED0C7DED0C8DECEC4DECCC1DECDC2
DECFC5DECEC3DECABEDEC8BADEC8B9DEC8BADEC8B9DEC6B5DEC3AFDDC0ABDCBEA8DABAA4D7B59E\
D6B19AD6AF98D6AD97D6AB95D6A993D6A993D5A993D4A993D4A993D4A892D3A68F
D0A38CCCA088C89C85C69A83C59A83C59B84C59E87C49D86C29982C1957EC3937CC3937CC1937C\
BB917AB48E77B08B75B18A74B38B75B28A74AC856E9D786283635061483B423128
2F231B281E17291E1A2A1E1D241A1B1E16151A141017110C130D0A160D0B261713412C24654C44\
907A73BBB0ACD9D8D7E2E4E3E0E1E1DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFE0DFDFE0DFE0E0DFE4E3E3E7E7E6D8D8D7
D8D8D8E7E7E6E4E4E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE1E3E2\
E4E6E6D3D2D0A2958D6C5447523A2D4E3B324D3C3549383144322B3E2C2438261E
32211A2E1E172D1E162F201936261F433129523D3261483976584498745EBC957ED4AC95DDB9A1\
DFBEAADFC0B0DEC2B3DEC3B4DEC6B8DECABDDECDC2DED0C6DED0C7DECFC5DECFC5
DECFC6DECDC3DECABDDEC8B9DEC8B9DEC8BADEC8B9DEC6B6DEC2B2DCBFACDABCA6D7B8A1D6B49C\
D5B099D5AD96D6AB94D6A993D6A892D6A892D4A992D2A892D1A791D0A58FD0A38D
CFA28BCC9F88C89C85C59A83C59982C59B83C59C85C59B84C49982C2967FC1947CC0927BBF927B\
BA9079B38D76B18A74B48A73B68A73B38770A67F68916D59755646553D313E2B23
33251E2E211C261B192016171D15161A1313150F0E120C0A130D0C19100F2517143C29225E4941\
8A7871B9AFABD9D8D7E2E4E4E0E1E1DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFE0DFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D8E7E7E6E4E3E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE1E3E2\
E4E6E6D4D2D0A497916F584C543B304F3B334F3F374E3D3649383143322A3F2B24
3B261E3320182C1D152F201939282146332B543E3460483B735645926D58B58971CEA289DAB29A\
DEBCA6DEC0AEDEC1B1DEC1B2DEC3B4DEC5B7DEC9BCDECDC2DECFC6DED0C7DED0C8
DED0C8DECEC4DECBBFDEC9BBDEC8BADEC8B9DEC7B9DEC6B7DEC2B3DCBFAED9BCA7D7B8A1D6B49C\
D5AF98D4AB94D3A892D3A791D4A691D5A692D4A792D0A791CEA58ECEA28BCEA089
CE9F89CC9D88C89B85C59A83C59A82C59982C59982C59881C49881C2967FC0947DBE917ABC8F78\
B98D76B58B74B48973B78871B6856FAD806A9C745F84604E69493B4F342A3D2720
35251D2E221C221916191212181112181111140E0D120C0B160F0F1C14122619153F2E27685851\
988B86C2BCB9DBDADAE2E3E3E0E1E1DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFE0DFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D8E7E7E6E4E3E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE1E2E2\
E4E5E5D3D2D1A399936D5A51533E35513E3653413A52413A4E3E37493830443029
3D2720311F18281B132B1E1639261F483128563C30654839795643946951B17F64C7977CD5AC94\
DCB9A3DEBFAADEC1AEDEC1B1DEC1B2DEC2B4DEC5B7DEC9BCDECDC2DED0C7DED1C9
DED0C8DECFC7DECEC4DECBC0DEC9BBDDC8B9DDC7B8DEC5B7DDC2B3DDC0AEDBBDA9D9B9A2D7B49D\
D4AF98D2AA94D0A790D0A48ED2A38ED4A390D3A491D0A38ECEA18ACD9E87CE9C86
CD9B88CB9B87C89A85C59983C59982C59881C5967FC4947DC2947DC0947DBE937CBC9078BA8B74\
B98972B88972B88871B6846DAF7E68A075618C67557653435F40324B2F253B251D
2F2018261C161E171419121217101117100F17100D17110D1913111E1413291A164A3832827570\
B8B1AED4D2D1DEDEDDE0E1E0E0E0E0DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFE0DFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFDFDEE1E0E0\
E3E2E2D2CFCDA09793695A53513F37503F3754433B54433C52413A4D3C3445312A
3A261F2F1F17281C152D1F1839251E462E2554392C6747367E574197674DAE795DC29075D0A78F\
D9B7A0DDBEA8DEC1ADDEC1B0DEC1B2DEC2B3DEC4B5DEC7B9DECBBFDECFC5DED0C8
DED1C9DED1C9DDD0C7DDCDC3DDCABDDDC8B9DDC7B8DDC5B6DCC1B1DCBFACDCBDA8DBB9A2D7B39C\
D4AD96D1AA93D0A790D0A48ED1A28DD2A18FD2A18FCFA18CCE9F87CD9C84CD9A84
CC9A87CA9B87C79A85C49882C39681C3957FC3937CC2927BBF927BBE937BBD927BBC8F78BA8972\
B98670B98771B88770B18069A67761966D59825E4C6C4B3B57392B472C2239231B
2A1D152019121E17131D16141A141219120F1A140E1C150F1D16111F15122C1B1653413B978C89\
D1CFCEE3E4E4E0E1E1DFDFDFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFDFDFDFDEDDE1DDDD\
E1DEDDCFC9C89C928E6557504D3C354E3D3553413A55433C53423B4E3C35423029
36251D31211931231C35261E3A2921412E254D372B6245357D564096664DAB775DBD8D74CCA38B\
D6B49CDCBDA6DEC0ACDEC1B0DEC2B3DEC4B5DEC5B6DEC7B8DECABEDECEC4DED0C8
DDD0C8DDD0C9DDD0C8DDCDC3DDCABDDDC8B9DDC7B8DBC3B3DABEABDABCA6DCBAA4DBB69FD8B099\
D4AA94D3A892D2A791D2A68FD2A48ED1A18DCFA08BCEA08ACE9E87CD9B84CC9A84
CA9C86C79C87C59A84C39681C1927EC0907CC0907BBF917ABE917ABD927ABD917ABD8F78BC8A73\
BA8871B68871B1856EA97D669F735C9369537F5A46664735513527432A2037231B
2A1D16211A13201A14201A151F19141E17121D160F1D170F1E18112217112E1C1656433D9E9390\
D9D8D7E9EAEAE2E3E2DFDFDFDFDFDFDFE0DFDFE0DFDFE0DFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E3E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFDFDFDFDDDDE1DDDC\
E1DDDCCEC8C7998F8B62534C4B39304E3A30523F3654423A53423A4E3D3644332C
3929223727203A2A233C2C253D2D26402F2748362B5D443579564290664FA4745DB68770C79D85\
D3AF97DABAA3DDBFABDEC1B0DEC2B3DEC4B6DEC6B7DEC7B9DECABDDDCDC2DDCEC5
DDCEC5DDCEC5DDCEC4DDCBC0DDC8BADDC5B6DBC3B3D9BFADD7BAA5D7B8A1D9B7A0D9B49DD7AD96\
D5A891D3A68FD3A68ED3A68ED1A48DCFA28ACDA088CDA088CE9E87CD9C85CB9C85
C89D86C59D86C49B84C39580C1907DBF8D7ABE8F7ABD9079BD9079BD9079BD8F78BD8E77BB8B75\
B78973B08771A9826BA17861986D578C624D7853405F40304930243C271D33211A
291D16221B14211A14211A15211A141E17121A140E17130D1A140F2016102F1C1659443D9F928F\
D8D6D5E8E9E9E2E3E2DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFDFDFDFDEDEE1DFDF\
E3E1E0CFCCCB98908C5F50494C362B51382C543D32523F365241395140384B3A33
44332C3F2F273E2E263F2F274031284331284A362A5C453772584686634F976D56AB7D65C0927B\
CFA78FD7B69FDBBDA9DDC0AFDEC1B2DEC3B4DEC4B5DEC7B8DDC8BADDCABDDDCABE
DDCABEDDCBBEDDCABEDDC8BBDDC4B6DCC1B1D9BEABD7BAA4D6B69FD6B59DD7B59ED7B39CD6AC95\
D4A68ED2A48AD0A389D0A38ACFA289CEA186CDA085CDA087CD9F88CD9E87CB9D86
C79C84C49B83C49982C4967FC2917CC08F7ABE8F79BD9079BD8E77BD8C75BD8C75BB8B75B78A74\
B18871A9836CA17C649971598D644E7C554467453752352A40292033231A2A1E17
241B132019121F18131E18141D151318120F120E0B0F0C09130F0C1F141137221C644D46A59793\
D7D5D4E5E7E7E1E2E2DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFDFDFE1E2E1\
E4E5E4D2D1CF9B93906151494E3529533728553C2F523E3552413A53423B504038
4B3A3344332B3F2D26402E264432284734284E392B5B47396C57487A5E4C88614C9E6F58B7866F\
CA9F87D4B29BDABDA8DDC0AEDEC0AFDEC1B0DEC2B2DEC4B5DDC6B6DDC6B6DDC6B5
DDC6B5DDC6B5DDC6B5DDC4B5DDC1B2DBBEADD9BBA6D6B7A0D5B39CD5B29BD5B39BD5AF99D4A892\
D2A38ACFA085CE9E84CD9E87CD9F87CDA085CDA085CDA087CD9F87CD9D86CB9C84
C79A82C49881C49780C4957EC4937BC2917ABF9079BD8F78BD8C75BD8973BC8871B88771B18670\
A8836CA07C6597715B8C654F7D56446A473957382E462C2437231C2C1F17251C14
2119121F17111E16131C1414181111130D0D0D0A090B0808130D0B2A1D1A513D39846F6AB6ABA8\
D9D7D6E3E4E4E0E1E1DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE1E2E2\
E4E5E5D3D2D1A0979469564E51372B513627533B2E53403654433B54433C514038
4A39324331293F2B23422C234732264B362A4E3B2F58473A6552446E54437953428F604CAB7A63\
C3977FD1AF97D9BCA5DDC0AADEC0ABDEC0ACDEC1AEDDC2B1DDC2B1DDC2AFDDC2AD
DDC2ADDDC2ADDDC2ADDDC1AFDDC0AFDCBEADDABCA7D8B8A0D6B39BD5B098D4AD96D3A992D1A28B\
CF9D85CD9B82CD9A83CC9B85CD9C87CD9E86CDA087CDA087CD9D86CD9982CB9780
C79780C4977FC4957EC4937CC4927AC3917ABF9179BD8F78BD8B74BC8871BA856EB4836CAA816A\
A17C6498725B8C654F7B55446A47395B3C304C32263D271E301F18271C15241C14
241B132419132017141B1413161010120C0C0E090A1009091D110E40302C7B6B67B2A7A5D1CCCA\
DDDCDBE0E1E0E0E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE1E2E1\
E3E5E4D4D3D2A79D99735F58563E334E372A4F3A2F53403756433C56433B513E35
49372D432F26402B22432C224731254A362B4D3C325343395A493C60493B6A493B8056459E6F59\
B88D74CBA78ED6B79EDBBDA5DCBFA8DCBFA8DDBFABDDC0ADDDC0ADDDC0ABDDC0A9
DDC0A8DCBFA8DCBEA7DBBEA9DBBEABDCBEABDCBEA8DAB9A2D7B29BD5AC95D3A790D1A28ACF9D85\
CC9980CB977FCB9781CB9884CB9A86CB9C87CB9E87CC9E86CC9A83CB957EC9937C
C6947DC4947DC4927CC4907AC39079C19179BF9178BD8F76BC8A73BB866FB7836CB08169A57C65\
99745D8E67517F57446B4739593B2F4D3327412B1F332218281C14231A14241B15
281C15291B152318151B1413160F0F120B0C100A0A150B0A26151152403A998E8AD3D1D0E4E4E4\
E0E0E0DEDFDEDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE1E2E1\
E3E4E4D5D4D3ADA39F7C6A635C473E4F3B314D3B31503E3655423A58423A543D33
4C362A463126422F26412E25432F2647342B4B3A324E3E354F3E34523F355D44397250418F6550\
AA7E65C0977CCEAB90D6B79ED9BCA4DABCA5DBBDA6DCBEA9DDBFAADDBFA9DDBFA8
DDBFA7DBBDA5D9BBA4D8BAA3D8BAA5DABCA7DBBDA7DAB9A2D7B099D3A690D1A089CF9D84CD9C81\
CB997EC9957DC7947EC79681C79883C79A84C99B84CB9A83CB9780C9937CC6917A
C5917AC4907BC48D7AC38C79C18E79BF9178BD9176BC8D73B9886FB7836CB3816AAB7F67A07961\
926D56835B47714A395F3D2F4D3327402A1F342218291C132118111F1712221915
271B15291B162319151B1313140D0D100909100909170B0A29171357443E9F9591D9D8D7E8EAEA\
E2E2E2DFDFDEDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDFE0E0DFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFE0DFE1E1E1\
E3E4E3D6D5D3B0A7A2817168614E445240374E3C344F3E36544039574139543D33
4E372B4733284231293E2E273E2E2642322A4838304A3A324939314B3A32543F3565493B7E5844\
986D54AF8569C29B80CEAC92D4B39BD6B59ED8B8A0DBBBA3DCBDA5DCBDA6DCBDA6
DCBDA6DABCA4D7B9A2D5B7A0D6B7A0D8B9A1D9BAA3D9B69FD5AD96D1A38CCE9B84CC9980CB9A7F\
C9997DC6947BC4927BC4937CC4957EC4967FC6977FC9977FC9957EC6927BC49078
C38F78C28D77C28A77C08977BD8B76BB8D75BA8D72B78A6EB3846AAF7F67AA7C65A479619A725B\
8A654F76513E623F2F513426422C1F342319291C1421180F1C150E1A14101D1513
2217142418131E151315100F0E0A0A0E0808140B0A1D0F0C2D181257413A9B908BD4D2D1E5E7E7\
E1E2E2DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDFDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFE1E1E1\
E3E4E3D7D5D4B1A9A283736864514756443C514039514038534038533F37523D34
4D392F45332B3E2D283A2B263C2C2640302845352D4A39324C3C344D3B324F3B2F593E2F6A4936\
815C469B745BB18A70C19A82CBA48CD0A992D4AE97D7B39CD9B69ED9B79FD9B8A0
D8B9A2D7BAA2D6B8A1D5B69ED5B49CD6B49CD7B49CD5B19AD2AA93CDA08AC99881C7947CC7947B\
C6947AC49279C38F78C38E77C38F78C3917AC4927BC6937BC6927BC49179C28E77
C08C75BF8A74BF8874BD8773BA8670B7866EB4866DB0846AAA7F66A379619D725B976D558F664F\
805A446A4735533627422A1E3523192B1E16241A121E170F1A130D18110E18100F
1B11101A110F130E0D0C0A0A0706070C08081C110E2C18123A20165D453B9D908AD4D2D0E4E5E5\
E1E2E1DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF
DFDFDFDFDFDFDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFE0E1E0\
E2E3E3D8D7D6B7AFAA8C7C746D59505B484055423B54423A524039503E36503E36
4F3D3548362F3F2C283B28233C2B2441302846352E4B3B334F3E364F3C324E382C4F3628583B2C\
6A4C3B83634F997760AA836CB78C75C1957ECA9F88D1A891D3AC95D3AD95D3AF98
D3B29CD3B49FD3B49ED2B29BD2AF98D3AE97D3AE97D2AC95CDA68FC69B84C09179BD8B73BD8A72\
BF8B72C08B73C18A72C28972C28A74C28C76C28D76C28C75C28C75C28D76C18D74
BF8A71BD886FBC876FB9856EB6826BB27F68AE7E66A97D65A17A6299735B906751895E48815741\
734C385C3D2C462E213623192C1D15251B132019111C160E19120D160F0C150D0C
140C0C110A0A0A08080505050405050D09082215113A241D52382E786157ADA19CD7D5D4E3E4E4\
E0E1E1DFDFDEDFDFDEDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFE0E1E0\
E1E2E1DAD9D9C3BDBCA193927E6B66634D4757423A54423A5140384F3E36514039
54423B4F3C344631283F2A213E29214330284A39314D3C344C3C334E3C324F3B314B362C4B352A\
5741336C54437C624F89695598705CA97B65BA8B74C69A82CAA088C89F88C8A18B
CAA692CBA997CBA997CBA894CBA790CDA790CEA891CCA58EC69D86BB9079B1846CAC7C65AE7B64\
B27D64B78065BB8268BE856DBF8871BF8972BF8770BE846CBE836DBE8770BE896F
BD886BBB8668B88469B58169B17D66AE7A62A97760A4765F9C755D916C56855E497A503D704633\
623C2B4F31233E271C311F17291B132218101D160E19120D160F0C140D0C130B0B
1009090C0607060505040505070606100A09221410433028736058A59690C8C1BEDBDAD9E1E2E1\
E0E0E0DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFE0E0DF\
E0E1E0DDDDDCD2CDD0B9AFB292807F6B564E574239523F364F3E364E3D3652413A
56443C523F354A362A412C213E2821442F284D3A314D3C334A39314D3C34513F374D3B3347362D\
4D3B315A483B6450426C54457B5949906451A4755FB2856EB78C75B48C77B38E7B
B59282B79585BA9685BB9683BD9882C09C84C29D86BF9882B68E77AA806A9F745D9A6D559B6C54\
A16E54A97256AF775BB47D63B68169B7826AB98067BA7C63BA7C64B98068B78268
B58162B37E5FB17B60AF7961AC7760A7745DA2715A9B6E58936B5588624D7A52406D4333603728\
522E2144271D3721192D1C152519111E150E19110C140D0B120B0A110A0A0F0909
0C07070804050404040506060D0A09150D0A22140E4838328D817CC9C2C0DEDBDBDFDEDEDFDFDF\
DFDFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFE0DF\
DFE0DFDFDFDFDCDBDDCBC6C7A396927562585844394D3B324B3A324D3C34513F38
5240384E3D3345362B3D2D253B2823422D264B352B4D392E4C3A314F3F3755443D53423B4D3D36\
4D3C3451413756463B5E4A3F6B50427C58478C624E976C569A725E977464947567
9478699879689E7A67A57E68AA846DAD8972AE8972A8836E9E7865956D598E654F8A5F48895D45\
8E5F459665489E6A4DA46E54A97259AB765CAF785CB4785CB4785DB0785FAA765D
A67257A46F52A46D53A56D55A36D569E6C569669558D6451855D4B7B52406E4534603829532D21\
46261C3A21182F1D152619111F150E1A110C150D0A1109090E07070B0707090606
070505050404030404070706120E0B1D120D291912503F39988E8BD4D2D1E5E5E5E1E1E1DFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF\
DFDFDFE0E1E0E2E2E3D6D4D3B0A7A38071675D4C414C3B324938304D3C344F3E37
4E3E36493C3341362E392D273527233B29224631254C382C503D3454433B5947405A484157463E\
54433B52423A56453D5D4B426650447054457958457E5A467F5D4C7B5E52775E53
755D50795C4C825D4A8B634E926C5697725C96725D8F6C598462527E5B4B7C56447B533E7A513B\
7E533A84573C8B5B40915C449761499C684DA26E51A87153A87055A26D549B6951
96644C946048955F4696604896624C91634F885F4D7E5848764E3F6B43345F3829542F2249281E\
3D221B321E1627191120160E1A130C160F0B120A0A0F07070B0505060404030404
0204040304040706050D0A0917120E24191337251E614D47A29793D5D4D3E4E5E5E1E1E1DFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF\
DFDFDFE0E1E0E3E4E3DAD9D8BAB4B38F82806959545141394B3A324F3E36504039
4D40384B3E36453831392D2730251F34261F4130264D3A3054423A5947405B4A425D4C445E4D45\
5C4B435B4A425D4C436351466855476C56466E55446E54426B5143674E44644B41
63483B6547386A4738724B3C7A5341805947805C4A7959496F5144684B4068493C6B48396E4735\
714833744A32774B337B4C3781513C8A5A429161479464499262488E5F468A5C44
885A4386574084543C83533D8256427F5644795241714A3B6943345D392B502F2346281E40261E\
37231B2B1C1420160E1B140B19120B150E0B120A0A0E06070A0404050303020303
010303060605110C0919110D1C14102A1F1A4D3A337F6963B3A7A3D8D6D5E2E4E3E0E1E0DFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF\
DFDFDFE0E1E0E1E2E1DBDBDAC5C0C3A2979B796A6A5A48424F3C34503E3650413A
4E413A4D40384A3A333E302933282036292142332B4F3E3659473F5D4B445E4C445F4D45604F47\
604F47604E46624F456651456A53456B5444695242654F3F5F493C5B433A573E34
563A2E56392D583A305C3B31623E316844356A493B674A3D5E453B584038573E365A3D335F3C2F\
623C2B623C29623C29633C2C694030714936784F3A7A513B78503A764E37754E37
774F39754C377047326C44316B46356A4537664133613C2E5A37294F312442281E38231B35231B\
2E20192319121A130C18110A18100B150E0B110A0A0D0607080404040303030405
0606070F0B0B1D130F241711241813372A26695753A18F89C7BDBADBDAD9E1E2E1DFE0DFDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF\
DFDFDFE0E0DFE0E1E0DDDDDDD1CED2B7AEB58D7E7F64504B523D354F3D354F3F37
4E3F374E3E364C3B3445362E40322A42342C4A3A3253423B5B49415F4D45604E465F4D455C4B43\
5B4A425B4A425D494061483E66493D6A4B3C674939604536594135523D334C372E
4932294932294C342D4D332B4D3027513329553B31563F35523D354D3A334A37304A332B4B2F26\
4C2E234C2F224B2E224B2D224F2E235532265B38295D3C2B5E3E2B5D3E2A5E3E2B
5F3F2B5D3C2A5835265431245331265231274F2F254C2D22482B2040271D3422192B1E16271C14\
2219121B130E160F0B150E0A150D0B140C0B110A090B0606050403030303070607
110C0F1C12142618152B1B1430211B4E3F3B897C78BFB6B3D8D3D1DEDDDCDFE0DFDFDFDFDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF\
DFDFDFDFE0DFDFE0DFDFDFDFDBD9DCCAC3C8A2949575615C5A453E4F3D364D3C34
4D3C344E3C354D3C344C3B334C3B344F3E3754433B57453D59473F5C4B435F4D455C4A4256443D\
53423A55433B59433B5E42396343386643366341335C3E30543C304D3A3146352D
41302844322A49352E47312B402A233F2A2344322A48372F48362E46332B422F283E2A223A241C\
38221A37241C37241C38221A3B211940221A44261C482B1F482E20482F1F472E1F
472E1F452B1D42261B41221A41221A40221A3D221A3B221A392119341F172A1C142118101D150D\
19120B160E0A130B0A130B0B130B0A110A0A0D08080705050203030303030C090A
1C131629191B2C1B1834221B4A3A33746762ABA5A2D5D3D2E1E1E0DFDFDFDEDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDFDFDFDFDFDFDFDFDFDFDFDFDF\
DFDFDFDFDFDFDFDFDFE0E0E0E0DFE0D5D2D3B6ACAC8D7D7A6A585254423B4B3A32
4C3A324F3D35503F37503E36503F3756443C5B494158463E52413955443C5A494157463E4F3E36\
4D3C345240385A443B61463B63463A6043375A3E34543B304F3A304B393045352D
42322A46342D4C383148332D3C29253727233A2D273E30283F2D253E29223C261F37221B311D16\
2B1B14291C15291C152B1B14301B14361C153A1F183C22193B2319372217352116
342016331F15321C14341C14371D16371D16331C15301C142F1B142B1A132317101C150C19130A\
171009140D0A130A0A120A0A10090A0C0808070606040404030304070506130D0D
251919311F1D331F1945322B746761A8A19DCBC9C8DDDEDDE1E2E2DFE0DFDEDEDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDFDFDFDEE0E0DFE1E1E1DBD9D9C6C0C0A498987C6B685B48414D3A32
4D3B33513F37534139513F384F3E3654433B58484054443C4F3E3652413958473F55443C4C3C34\
493A324F3E365A453A63493C60473A5741374F3C344B39314A383048373044342D
41322B45342E4C383247332F3B292634262336292438292338241F36201B341F18301D162A1A12\
24181021171021170F2417102A1912301C14341E16341E16301C142B1A1126170F
25160F25160F26160F2B1911311C14321C142D1A1228181026171023160F1E140C1B130B19120B\
18100B150D0B120A0A1009090D08080906060605050706050B0908120D0B1D1311
2C1D183A272049342D6A5953A39A96D1CFCEDFE0DFDFDFDFDFDFDEDFDFDEDEDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0DFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFE0DFE0E1E0DDDDDDD1CCCEB6AAAD8C7978644C46523B33
503D3553413A54423A5240384F3D364D3E364D40374E403852423958473E5C4B435748404D4038\
483A334B3A32543E335D4234583F324C392F45352D44352D46362E45352D3F302C
392C2B3B2F2C41332E40302B38282534232135241F35231E311E1D2D1B1A2A1A15271912241810\
1F160E1C140C1C130C1F150E231810271912291A13291A1225181020140D1C110A
190E0A190E0A1C110B22150D2A19112B191125170F1F130C1C110C1A100B1A110A1A120A1A120D\
18110D150D0C1009090B07070906060906060C0908110D0A18130F2219142B1C17
321F1948352D73635DA29996C9C5C4DFDFDEE3E3E3DFE0DFDEDEDEDEDEDEDEDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDFE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0DFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFE0DFE0E0DFDEDEDED9D5D7C4B9BD9B87876F544F573E36
523E3653423A54423A5240394E3D35483A324539314A3E3655453D5C4B435E4D445849414E423A\
463A3245352D4B362B51372A4C3327412E253D2D2540302942322A40312A392B29
322628312728352B2736292533242231201E311E1A2E1B1928181A2316182016131F16101D160F\
1B130D18100A18100A1A130C1D140E1D150F1E150F1D150F1C130D19100A150D08
130A08130B08170F091D130B23160E23150E1D120C170E09120B08110A07130C08150F09150F0C\
140D0D110B0B0D08080906060906060D0908130C0A18110D2017112B1E1737251E
46312A685751A29895D0CECDDFDFDFDFDFDFDFDFDFDFDFDEDEDEDEDEDEDEDEDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0DFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDFDFE0DFDFDFDFDEDDDED0CACBAA9B997D66605F4840
533F3751403853413A5240384E3D354B3B334A3C344D403852453D58494159484054443C4B3D35\
43352D403028422F26442E243F2A2037251D38271F3D2E263F2F283B2B27352626
3023252E22212E221E2E211E2D1E1F2B1B1D2717172113131C1012190F1119111019131019120F\
160F0C140C09140C09160F0C17100D160E0B150E0B160F0C160F0B140C09120A07
120A09140D0B18110B1C130D1D130E1C110D170E0A100A070A06050805040906040B08050B0807\
0A07070906060906070C0909100C0B140E0B170F0B18100C1C110C271710412E27
6D5A559D918DC7C2C0DFDFDEE3E4E3DFDFDFDEDEDDDEDEDEDEDEDEDEDEDEDEDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0DFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE0E0DFE1E2E1D9D7D6BCB4B1948680726058
5B4840514037503F374F3E364D3C344E3E3650413950423B4F433C52453D54443C503F38483831\
41312A3E2C253D2B233B292135251D2F201832231B392921392A24342522302120
2F201F2C1D1A2819152617162516192115191C1214170F0F130B0C130B0B140D0D160F0F160F0E\
140C0C110909110909130C0B130C0B110909130A09170D0C160D0B1008070E0606
110A09160F0C1B130E1C150F1A120F160E0D110A090A0505040202010101020101040302050404\
060505060505090707110C0C1911101D140F1E140D1D130D20110B2D170F543D34
94847EC9C2C0DDDBDADFDFDEDFE0DFDFDFDEDEDEDEDEDEDEDEDEDEDEDEDEDEDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFE0DFE1E1E1DDDDDCD0CECCB8B1AD948782
705F5859463E4D3C344A39314C3B334F3F3750423A4F433B4E433B51443C55453D52413B4B3934\
43302B3D29233B272038272031241C2B1F172B1F1730221A30221C2C1F1A2B1E19
2B1C182718141F120F1A0F0E190E11190F12170F11150E0F130C0C120B0B110A0A130B0C140C0D\
120B0B100808100808120A0B110A0A100708150A091F100D1C0F0C0F0706080404
0E0808170F0D1C140F1D150F19120F130C0C0B06070402020000000000000200000602020A0606\
0D0A090E0A0A100C0C150F0F1D14122618132C1B132F1E143821164D2F2076594B
AF9E97D9D5D3E3E3E3DFE0DFDEDEDDDEDEDDDEDEDDDEDEDEDEDEDEDEDEDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDFDFDFDFDFDFDEDFDFDED5D4D2B9B1AE
91837D6E5C5455433A4B39314B3A324C3D364C40384D423A4F443C54473F594841574540503E3A\
46332F3F2A243C282039292132251F291F19261B16271A15271B14261B14261B14
261913221511190F0D140C0B140C0B150D0D160F0F160F0F150E0E120B0B0F0808100808120A0A\
11090A0F07070F0707110909110909110808180C0923120E22130F140D0D0E0B0D
1410111C15131E15121D131018100E100A0A0805050302020302010503020904030E0706130C0B\
1811101B14131D15141E16142317152E1C1639211944291D5739297655439D8071
C3B4ACDBD9D7E1E2E2DFE0DFDEDEDDDEDEDDDEDEDDDEDEDEDEDEDEDEDEDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFE0DFE2E2E2DFE0DFD2D0CE
B8B0AC92837D6D595157443B4D3E36493C34483B334C3F3753453D5949415B4A435B494255443F\
4B3A344031293D2D253C2D253628232C1F1E241919211614221712241912241812
2116121D14111A120F18110D17100D17100E17100F150E0E130B0C1008090E06060E06060F0707\
0F07070D05050D05050E0606100907140B08190E0A1E110D211515221C21242228
272528292223251B1B1E1213160C0C1009090C07070C08070F0B08120D08150E09160E0B18100E\
1F1614291D1A2F221D2E211C2E1F1A34201940251B523124714F409B8072BFAEA5
D4CDC8DDDCDADFE0DFDEDFDEDEDEDDDEDEDDDEDEDDDEDEDEDEDEDEDEDEDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDFDFE0DFDFE0DFDFE0DF
D5D3D2B9AEAB92807A715E56594A424C3E36493A314D3D3554433B58473F5A49415B4A435A4941\
51423B46393142342B4131283B2A26312122261A1C1F16161F1612231712211511
1B12111912101B14101D160F1C15101A130F170F0E130B0C1008090E06070E06060D05060D0505\
0D04050C04040C04040C04040F0605140C0818100B1B1311231B1F2F2A3439353F
3D393D3C33343528292A1B1D2013141B11111D14122017142219142219122018101E16101E1512\
251A1732251F3C2C253D2C243B28203E261E4C2E236845388F7064B9A8A1D6D2CF
DFDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDEDEDEDEDFDEDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFE0DFE1E2E2
E0E0DFD4D0CEBCB1AE978781725F585B48405241384F3E354E3D3550403853453D594A425D4D44\
5A4A4252433A4C3C31473429412D253726232C1F1D2219171F17131E15121B1210
170F0E160F0D19130D1C150F1B141018110F140C0C1008090E06070E06070F07080F07070D0505\
0C04050D05050D05050C03030C030210070518100D221D1C2C262B362D38403540
4A3E414E413D4A3A3741302E3626263324233729263A2C263729222F231A271D14231A13271B16\
2E211B3828213F2F2745332B4832294F31266544388C6F65B5A19BD1C8C6DEDEDE
E0E2E2DEDFDEDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDEDEDEDEDFDEDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDFDFDFDF
E0E0DFE2E2E1DAD8D6BCB2AE93807A755F56624D445441384C3B324B3C344F423A574A415F4F47\
6150475D4B435643384F3A2D4732263D2B2332241E291F19241C172219171E1615
1A131119110E1A120C1A130D19120F160F0E120A0B0F07080E06070F07081008090F07070C0405\
0D05050F07080F07080D04050A01010C0302160F0E262121302A2D3429313D2E34
4C3B3954433C52413949393441312E402F2C44342F45352E3E2E2632241D281C15261B132E2018\
36261E3B2920412E254D382D593F3469483C86665CB19C97D3CAC9DEDCDBDEDEDE
DEDFDEDEDEDEDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDEDFDEDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDEDFDE
E0E0DFE3E4E4E2E2E2D4D0CEB9AEAA95827A745B505F473C56433951423A52433B584941605047\
6352496250475F4C4259453A4E3A30402F2636271F32251D32251F322722302622
2A211D251C162117101E140E1B130F17100E140D0C110A0B11090A1008090F07070C04040B0303\
0D050711090C120A0D1007080D05040F0603150E0B1F18172720202F24253A2B2A
47353049383040312A362924332621342721372A2336292230231D291C17251912291B13322219\
3A281E3F2B204931245C3F2F7252448C6D64AA928FC9BDBCDDDADAE1E1E1DFDEDE
DEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDEDFDEDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDFE0E0DFE0E0E0E0E0DFD5D2D1B6A9A38F776C745B4F65514659483F53423955443C5D4C44\
63524966544C67564D64534A58473E48372F3D2D24392A223C2C253F30293E302A
382D2632261F2D2018281C152319131D151116100E120B0C11090B1008090E06080D04060D0506\
11080B160E12170F13140C0E150C0A190F0A19100C18100E1F15142D221E3C2E27
43322B3D2C272E211D251A16251B15281D16291E16271D16251A16251A162B1D1632211938271E\
3F2B214931235C3E2C765440937364AF9893C6B9BCD5D0D2DDDCDCDFDFDEDEDEDD
DEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDEDFDEDEDFDEDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E4E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDEDFDEDFDFDFE1E3E2DFDFDECFCAC6B5A8A19583797562565C4A3E4E3D334E3D3457463D\
6250486B59506F5F566D5F5764564D57463E49382F3F2E273C2B253D2C273D2C27
3B2A243B2A223A2A223729212F251E241D18191211110A0B0E07080F080A130B0F150C11160D11\
1A11141F16171F16171C1214201515281C18261A161D121221171636292445352D
46342E3D2C273324202E211B2F221B31231B30221A2E211A2F221C3627213F2F25443328443229\
4A34285C3E2D7957439B7D6DB9A399CBBFBDD6D1D3DBDADBDDDDDDDEDEDDDEDEDD
DEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDFDEDEDFDEDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE4E3E2E7E7E6D8D8D7
D8D8D7E7E7E6E3E3E2E0E0DFDFDFDFDFDFDFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFE0DFDFDFDEDFDEDDD4D2CFB7AEA88F81766F5E535B4A4253423B56443C\
5F4C446A574F705F5770625A6B5E5763554D56473F49393241312B3F2E2B402E2A
422E2844302A46342E42352E3A302A2F2724241D1D1C15171911131C131520171C221820221820\
251B1F2A201F2A2020281E212F2225392926352522281B1B2C1F1F41312C4F3C35
4B373244302C422E28432F27432F26422F263F2E253F2E2645332A4F3B30594436594435533D30\
593F337555449C7C6BBFAAA0D5CCC9DCD9D8DDDBDBDDDDDCDEDDDDDEDEDDDEDEDD
DEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDFDEDEDFDEDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEE0DFDEE3E3E2E7E7E6D8D8D7
D8D8D8E7E7E6E3E3E3E0E0DFDFE0DFDFE0DFDFDFDFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDEDFDEDFDFDFE2E3E2DFE0DFCFCCC9B6AFA99E928E887A7772615E604F48\
5C4941604E4565544B675850675B56665B596256525C4D4758464056453F574640
58464055433D4E3D394539353E37353B35373B343A3C33393D33343A2F2E35282B30232B2D222C\
2E232A332627372A2C3B2F354032384332313D2B2635242038272447352E513C35
4F39334C342E4D322B4F33295034284E34294B352B4D392F564035644A3B6F513E6C4C395F4130\
684D3F91796DBDABA1D5CCC7DFDCDBE0E0DFDFDFDEDEDEDDDEDEDDDEDEDDDEDEDD
DEDEDDDEDEDDDEDEDDDEDEDDDFDEDDDFDEDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE3E3E2E7E7E6D8D8D7
D8D9D8E7E7E6E3E4E3DFE0DFDFE0DFDFE0DFDFDFDFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFE0DFDEDFDEDCDCDBD6D5D4CCC6C7BAAFB29D8F8F7D6E68\
67574F5D4C445B48415C4B445E524F615A5C675F606E615D71605971605970615A
6E615A6457515648454C403F4842424C474C554D565E53596053535749454838373C2D31372A33\
36293139292D3E2E3245373E47393E4433313F2C253D2A22402D2548342C4E382F
52372E54352C56342B583529593728583A2B563D305840356046386E4E3D7C56437C5642745241\
826A5EAEA29BD4D0CDDFDEDDDFDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDEDEDD
DEDEDDDEDEDDDEDEDDDFDEDDDFDEDEDFDEDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE3E3E2E7E7E6D8D8D7
D8D9D8E7E7E6E3E4E3DFE0DFDFE0DFDFE0DFDFE0DFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDEDFDEDFDFDEE0E1E0E1E1E1DDDCDDD4CFD1C3BCBCAAA29F\
8B7E7C6E5D5B5E4B475B4943594E4B5B5659676265776D6B7F716D7E706B7A6E68
766B646E635C6458545E54535E5657625A5E695D616E5F616D5D5A62514B51403B473634433335\
4030333D2B2D3C2A2C3E2D2F3F2E2E3E2C273F2B23422D244530274732294C3329
5534295C362960372A633B2C653F2F67453568493A68493B694737704A3A7E58498C6A5E998076\
AE9F98C9C4C1DCDDDCE0E1E1DEDEDDDEDDDCDEDDDCDEDEDDDEDEDDDEDEDDDEDEDD
DEDEDDDEDEDDDFDEDDDFDEDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE3E3E2E7E7E6D8D8D7
D8D9D8E7E7E6E3E4E3DFE0DFDFE0DFDFE0DFDFE0DFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDFDFE0DFDFDEDEDDDCDCDCDBDAD1CFCE\
B3ACAD8E818379686771625D6C615F6863666F6A6F7C7476837777827675807472
7D726E7A6F6A776B6675696675696875676774636172605B6D5A5564504B59454054403B533F3A\
4E3B374532303E2B293B28233B28203D2921422E2448332A4C372E4D372E51372C
5B382A633A2B683E2D6941316B4636714F3F7B594B7F5D4F7D594B7E5B4F8B6B64A18B87BEB2AF\
D3CFCDDBDAD9DDDDDCDEDEDDDEDEDDDEDDDCDEDEDDDEDEDDDEDEDDDEDEDDDEDEDD
DFDEDDDFDEDDDFDEDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE3E3E2E7E7E6D8D8D7
D8D7D6E7E6E5E3E4E3DFE0DFDFE0DFDFE0DFDFE0DFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDEDEDEDFDFDEE0E0DFE2E3E2DEDFDE\
CDCACBB6AFB1A89F9FA29A989D97969690948B858C82798181767A887A7C8E8182
9285889184868D7F7E89787584726F7F6B6779655F735F596E5A556A555167504D674E4A654D46\
5F484156403B503A355038304F372C4C362A4E382D543E345A433A5E453C61453A
6445366846356A4836684736674638725247896A629D8079A58B84A8938DB09F9CBFB4B3D2CDCD\
DFDEDEE0E0DFDEDDDCDDDDDCDEDDDCDEDEDDDEDEDDDEDEDDDEDEDDDEDEDDDFDEDD
DFDEDDDFDEDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE3E3E2E7E6E5D8D8D7
D8D5D4E7E6E5E3E4E3DFE0DFDFE0DFDFE0DFDFDFDFDFDFDFDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDDDDDD\
DAD9D9D5D4D3D2D1CFD0CFCECECCCCC5C1C5AEA8B0958D978F848A9A8D8FA79A9E
AEA3ABADA1AAA6979C9F8C8C98827F8F797584706D796765725F5E705B5C725A5B725858705550\
695049624B43614941644A4162483C5C43365841345B443962493F694C416A4D3F
684D3D6C5342745C4C765F51745C518067619E8785BAA8A9CBC0BFD2CCCAD4D0CED7D4D2DAD9D8\
DDDCDCDEDEDDDEDDDCDEDDDCDEDEDDDEDEDDDEDEDDDEDEDDDFDEDDDFDEDDDFDEDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE3E2E2E7E6E5D8D8D7
D7D6D5E6E6E5E3E3E2DFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFE0E0DFE0E0DFE0DFDF\
E0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDFE0DFDEDFDFDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDEDEDDDDDDDC\
DEDEDDDFDFDEDFE0DEDFE0DFDFDFDFDAD8DACBC9CCBBB7BCB7B2B5BEB7B8C7C1C2
CBC6CBC8C1CAC0B6BFBCAEB4B9A9AAB09FA1A08F958C7C847A6A7372606A715D67705A5F6C5351\
664E47624B42624B42644B4263493F5F463A5B44385B43385E43376042345F4131
614735735D4D907F73A4958DA79A94AEA19EBFB3B3D0C8C9DBD7D7DFDFDDDFDFDEDEDEDCDDDCDB\
DDDCDBDEDDDCDEDEDCDEDEDDDFDEDDDFDEDDDFDEDDDFDEDEDFDFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDEDFDFDE\
DFDFDEE0DFDEE0DFDEE0DFDEE0DFDEE0DFDEE0DFDEE0DFDEE0DFDEDFDFDEDFDFDE
DFDFDEDFDFDEDFDFDEDFDFDEDFDFDEE3E2E1E6E6E5D7D7D7
DADAD9E9EAE9E6E7E6E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E4E3E2\
E4E3E2E4E3E2E4E3E2E4E3E2E4E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2
E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E2E2E1E2E1E0\
E1E0DFE0DFDEDFDFDDDFDFDDE0E0DEE0E1DFE1E2E1E2E4E2E3E5E3E4E6E4E5E7E5
E4E5E5DEDDE3D9D5E0D9D3DDDCD5DBD6CDD4C5B9C5AB9EAE9084958175867B6F7E786A72746261\
705C556E5A526E59516D59506D58506D584F6C564E69534A674E4364493B634736
6A5240887568B7AAA3D9D1CEE2DEDCE2DFDDE1DFDDE1DFDDE1DFDDE0DEDCE0DEDCE0DFDDE1E0DE\
E2E1E0E2E1E0E2E2E1E3E2E1E3E2E1E3E2E1E3E2E1E3E2E2E3E3E2E3E3E2E3E3E2
E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2\
E3E3E2E3E3E2E3E3E2E3E3E2E4E3E2E4E3E2E3E3E2E3E3E2E3E3E2E3E3E2E3E3E2
E3E3E2E3E3E2E3E3E2E3E2E2E3E2E1E6E6E5E9E9E8DADAD9
DDDEDDEDEDECE9EAE9E6E6E5E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6\
E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6
E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E6E6E5\
E4E3E2E0DFDEDEDDDCDEDCDBDEDEDCE2E3E0EBEEEAF6F9F4FAFEFAF7FCF9F3F8F5
EFF3F0EBEDEEE8E8F0EBEAF3EFEFF5EDEAF1E0DAE5CAC2D1B3ACBBA49EAD9D98A599939A968C8C\
94878394857F92847E91837E91847F93858094858091827C8D7D7489776C887568
917F73AD9F96D7CECAF6F2F2FFFFFFFCFEFCF2F5F1E9EAE6E3E1DDE0DCDAE0DCDBE2DFDEE4E3E2\
E6E5E4E7E6E5E7E6E5E7E6E5E7E6E5E7E6E5E7E6E5E7E6E5E7E6E5E7E6E5E7E7E6
E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6\
E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6E7E7E6
E7E7E6E7E7E6E7E6E5E7E6E5E6E6E5E9E9E8EDECEBDDDDDC
D3D3D3DDDDDCDADAD9D7D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7\
D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7
D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D7D7D7\
D6D6D5D5D5D4D4D4D3D4D4D2D5D5D3D7D8D6DADCD9DEE0DEE0E2E0E0E2E0DEE1DF
DDDFDDDBDDDDDBDCDDDBDCDEDCDDDFDBDBDED6D5D9CFCED3C8C6CCC2C1C6BFBEC2BDBCBEBCB9B9\
BBB7B5BAB4B2BAB3B1B9B5B2B9B6B4BAB6B4BAB6B3BAB5B2B8B3B0B8B2AEB8B3AE
BDB8B3C7C2BFD3D0CFDDDCDBE2E2E1E1E2E1DEDFDDDADAD8D7D6D4D5D4D2D5D4D2D6D5D4D7D6D5\
D7D7D6D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7
D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7\
D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7D8D8D7
D8D8D7D8D8D7D8D8D7D8D8D7D7D7D7DADAD9DDDDDCD3D3D2
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Original) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5F7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECE\
F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFC6ADEFC6ADEFC6AD
E7B59CE7BDA5E7B59CE7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEAD94\
DEAD94DEA58CD6A58CD6A584DE9C84D6A58CD6A58CD6A584C69C84D6A58CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEF7CEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFC6ADEFC6ADE7BDA5E7BDA5E7BDA5
E7BDA5E7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEAD94DEAD94DEA58CDEAD94\
DEA58CD6A58CD6A58CD6A58CD6A58CD6A58CD6A584D6A58CC69C84D6A58CF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEF7D6BDF7D6BD
F7D6C6F7D6BDF7D6BDF7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6BD\
F7D6C6EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADE7BDA5E7BDA5DEB59CE7AD9C
DEAD94DEAD94DEAD94D6A58CD6A58CDEA58CDEAD94DEAD94DEAD94DEA58CDEAD94DEAD94DEA58C\
D6A58CDEA58CDEA58CD6A58CDEA58CD6A58CD6A58CD6A584C69C84D6C6BDF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEF7CEB5F7D6BD
F7D6BDF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5\
F7D6BDEFCEB5EFCEB5D6C6B5D6C6B5E7BDA5E7BDA5DEB5A5DEB59CDEB59CDEB59C
DEB59CDEAD94DEAD94DEAD94DEAD94D6A58CDEA58CD6A58CD6A58CDEA58CDEAD94DEA58CD6A58C\
DEA58CD6A58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A584D69C84F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CEEFCEB5F7D6BD
F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6C6D6C6C6EFCEB5\
D6C6BDD6C6B5E7BDA5E7BDA5E7AD9CE7AD9CDEB59CDEAD94DEB59CDEB59CDEB59C
DEB59CDEB59CDEB59CDEB5A5DEAD94D6A58CD6A58CD6A58CD6A58CD6A58CD6A58CDEA58CD6A58C\
DEA58CD6A584DEAD94D6A58CD6A58CD6A58CD6A58CD6A58CDEB59CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6F7D6BDF7D6BD
F7D6C6F7D6BDF7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDD6C6C6\
F7BDB5F7BDB5F7BDB5EFBDADEFBDADEFBDA5E7B59CE7AD9CE7AD9CDE9C8CDE9C8C
DE9C8CDEAD94DEAD94DEB59CD69C8CC6ADA5D6A58CD6A58CD6A58CD6A58CD6A58CDEAD94DEA58C\
DEA58CD6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD6A58CD6C6BDF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6F7CEB5F7D6BD
F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDEFCEB5F7D6C6\
F7D6BDF7D6C6F7D6BDEFCEB5F7BDB5F7BDB5EFBDADE7B59CE7AD9CE7AD94DE9C8C
E7AD9CEFB5A5E7AD9CDEB59CDE9C8CD6A58CD6A58CDEB5A5D6A58CD6A58CD6A58CD6A584D6A58C\
DE9C84D6A58CD6A58CDEAD94D6A58CD6A58CD6A58CD6A58CF7E7DEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6C6EFCEB5F7D6BDF7BDB5EFBDADEFBDADEFBDA5E7BDA5E7BDA5
E7AD9CEFB5A5EFBDADEFB5A5E7AD9CDE9C8CDEA58CD69C8CD69C8CD6A58CD6A58CDEAD94D6A58C\
D6A58CDEA58CD6A58CDEA58CD6A584D6A58CD6A58CD6A58CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFCEB5F7D6BDF7D6BD
F7D6BDF7D6C6F7D6BDF7D6BDF7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7DECEF7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFC6ADEFBDADEFC6ADEFBDA5E7BDA5
EFBDA5EFB5A5E7AD9CEFB5A5EFBDA5E7AD9CDE9C8CE7AD94DE9C8CD6A58CDEB5A5DEAD94D6A58C\
DEAD94DEA58CDEA58CDEA58CD6A58CD6A58CD6A58CDEB59CF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFCEB5F7D6BDF7D6BD
F7D6BDF7D6BDEFCEB5F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7DECEF7D6C6F7D6C6F7DECEF7DECEF7DECEEFCEB5F7C6ADF7C6ADEFCEB5EFBDAD
EFBDADEFBDADEFB5A5EFB5A5EFB5A5E7AD9CE7AD9CDE9C8CDE9C8CDEAD94DEAD94DEB59CDEB59C\
D6A58CDEAD94DEAD94DEA58CDEAD94D6A58CDEAD94F7BDB5F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5F7D6BDF7D6BD
F7D6BDEFCEB5F7D6C6EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6BDEFC6ADEFCEB5
EFBDADEFBDA5EFBDA5EFB5A5E7B59CE7AD9CE7AD9CE7AD94DEAD94DE9C8CDEA58CDEAD94DEB5A5\
DEAD94D6A58CDEA58CD6A58CD6A58CD6A58CDEAD94EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6F7D6BDF7D6BDF7D6BD
EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7DECEF7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7BDB5
F7BDB5EFBDA5EFBDA5E7B59CEFB5A5E7AD94E7AD94E7AD9CE7AD94DE9C8CDEA58CDE9C8CD6A58C\
D6A58CDEB59CD6A58CD6A58CDEAD94D6A58CDEAD94EFE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7DEB5A5EFCEB5F7D6BDEFCEB5
F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7DECEF7DECE\
F7D6C6F7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6BDF7CEB5EFCEB5
F7C6ADEFC6ADEFBDA5EFBDA5EFBDA5E7AD9CE7AD9CDEA58CE7AD94DEAD94DEA58CDEA58CD6A58C\
DEB59CD6A58CDEB5A5DEA58CDEAD94D6A58CDEAD94EFE7E7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7846B5AEFC6ADF7D6BDEFD6CEF7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6BD
F7C6ADEFC6ADEFBDA5EFB5A5EFB5A5E7AD9CE7AD94E7AD94E7AD94E7AD94DEAD94DEA58CD6A58C\
DEAD94D6A58CD6A58CDEB59CDEAD94DEAD94DEAD94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C7363634A42EFCEB5F7D6C6F7D6BDF7D6C6
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6BD\
F7D6BDF7DECEF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7C6AD
EFBDADEFBDA5EFBDA5EFBDA5EFB5A5E7B59CE7B594E7AD94DEA58CE7AD94DEAD94DEAD94DEA58C\
D6A58CD6A58CDEAD94DEB59CDEB5A5DEAD94DEAD94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F76B524A5231298C6352F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7D6C6\
F7D6C6F7DECEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFCEB5EFCEB5EFC6ADEFC6AD
EFBDA5EFBDA5E7BDA5E7B59CEFBDA5E7B59CE7AD94E7AD94E7AD94E7AD9CDEA58CDEA58CDE9C84\
D6A58CD6A58CD6A58CDEAD94D6A58CEFBDADDEAD94F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7D6C6CE634A425A3129EFD6CEF7D6C6F7D6BDF7D6BDF7D6C6
F7DECEF7DECEF7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECE\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7BDB5EFC6ADEFBDA5EFBDA5E7B59CEFBDA5
EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5E7B59CDEAD94E7AD94E7AD94DEAD94DEAD94DEA58CD6A584\
D6A584D6A58CD6A584D6A58CD6A58CD6A58CD6C6BDF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7EFEF5A4239734A39F7D6C6EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE\
F7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFBDA5EFC6ADEFBDA5EFBDA5E7B59C
EFBDA5E7BDA5EFBDA5E7B59CE7B59CE7AD94DEAD94E7B594E7AD94DEAD94E7A58CDEA58CDEA58C\
D6A58CD6A584D6A584D6A584DEAD94DEAD94DEB59CF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7FFFFFF7B635A634231F7D6C6EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECE\
F7DECEF7D6C6F7D6BDEFCEB5F7C6ADEFBDADEFBDA5EFBDA5E7B59CE7B59CE7B59C
E7B59CE7B59CE7B59CE7B594E7B594E7AD94DEAD94DEAD94DEA58CDEA58CDEA58CDEA58CDEA58C\
D6A584DEA58CD6A58CD6A58CDEA58CDEAD94DEAD94EFD6CEF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7947B73634A42BD9C8CEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7D6C6\
F7D6C6F7D6C6F7D6BDEFCEB5F7BDB5EFB5A5E7AD9CE7AD9CE7AD9CE7AD9CE7AD94
E7AD9CE7AD94E7AD94E7AD94DEA58CDEA58CDEA58CDEA58CDEA58CD6A58CDEA58CDEA58CDEA58C\
D6A584DEA58CDE9C84DE9C84DEA58CDEAD94DEA58CD6A58CEFD6CEF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F76342318C7363F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7D6C6F7D6C6F7DECE
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7D6C6\
F7DECEF7D6C6F7BDB5EF948CF7BDB5EF948CE7847BE7847BE7847BE7847BE7847B
E7847BE79484E7AD94DEAD94DEA58CDEA58CDEA58CD6A58CDE9C84D69C84D6A584DEA58CDEA58C\
D6A58CDEA58CDEA58CD6A584DEA58CDE9C84D6A58CD6A58CD6A58CF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
CEB5B5634231F7DECEF7D6C6F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6F7D6C6
F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6F7DECE\
F7DECEF7BDB5F7BDB5F7BDB5EF948CEF948CE7847BE7847BE7847BEF948CE7847B
E7847BE7847BE7847BE7847BDE9C8CDEA58CD6A58CD6A58CD6A584D6A584D6A58CDEA58CDEA58C\
DEA58CDEA58CDEA58CD6A584DEA58CD6A58CD6A58CD6A58CDEB59CEFBDADF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6C6\
634231EFD6CEF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDF7DECEF7D6C6F7D6C6
F7D6C6F7D6BDF7CEB5F7CEB5F7CEB5F7D6BDF7CEB5F7D6C6F7D6C6F7D6C6F7D6C6F7BDB5F7BDB5\
DECED6F7BDB5F7BDB5EF948CE7847BE78473E77B6BDE6B5ADE6B5AE7847BE77B6B
DE7B6BDE7B6BE7847BE7847BD68C7BE7847BD69C84D6A584D6A584D6A584D69C84DEA58CDEA58C\
DEA58CDEA58CDEAD94DEA58CDEA58CDE9C84D6A58CDEAD94DEA58CDEAD94F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF7B635A\
8C7363EFCEB5F7D6BDF7D6BDF7D6C6F7D6BDF7CEB5F7D6C6F7D6C6F7D6C6F7D6C6
F7D6C6F7D6BDF7CEB5EFBDA5F7CEB5F7C6ADF7CEB5F7D6C6F7DECEF7D6C6F7BDB5F7BDB5F7BDB5\
F7BDB5EFB5A5E79484D67363DE6B5ADE6B5ADE6B5ADE6B5ADE6B5ADE6B5AD67363
DE6B5ADE6B5ADE6B5ADE7B6BE7847BD67B6BCE8C84DE9C8CDE9C84D69C84D69C84D6A584DE9C84\
DEA58CDEA58CDEAD94DEA58CDEA58CDEA58CD6A58CD6A58CDEA58CDEAD94EFBDAD
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F79C8C8C5A4239\
F7DECEEFCEB5F7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6
F7D6BDF7D6BDEFC6ADEFBDA5EFBDA5EFBDA5F7D6BDF7D6C6F7D6C6F7BDB5F7C6ADF7C6ADEF948C\
E79484E78473D68C7BDE9C8CE7AD9CC66B52F7BDB5DEB59CB5735AE7AD9CD67B6B
D66352CE5A4AD66352DE6B5ADE7B6BD67B6BD68C7BD68C7BD6A58CD6A584D69C73D6A584D6A584\
DEA58CDEA58CE7A58CDEA58CDEAD94DEA58CD6A58CDEA58CDEA58CDEAD94DEB59C
F7E7DEF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADBD6B524A5A3129\
F7D6C6F7D6BDF7D6BDF7D6C6F7D6BDF7D6BDF7C6ADF7D6C6F7DECEF7D6C6F7DECE
F7CEB5F7CEB5EFC6ADE7B594E7B594EFBDA5F7D6C6F7D6C6F7C6ADEF948CE7AD94E78473D66352\
B55239C6ADA5E7AD9CD6C6C6D6C6C6CEB5B5CEB5B5EFBDADBDA59CD6C6BDCEB5B5
AD6B52D69C8CA5634ACE5A4AD67363D67363D67B6BD68C7BD68C7BD69C84D69C84D6A584DE9C84\
DEA58CDEAD94E7B594DEAD94DEA58CDE9C84DEA58CDEA58CDEA58CDEAD94D6A58C
DEB59CE7DEEFE7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEFB59C9C5A4239C69C84\
F7D6BDF7D6BDF7D6C6F7D6C6F7D6BDEFC6ADEFBDA5F7DECEF7D6C6F7D6C6F7D6BD
F7C6ADF7C6ADE7B594DE9C84DE9C84F7D6BDF7BDB5E7847BE7847BCE8463842918D67B6BE7AD9C\
DE6B5AE79484DE7B6BEFB5A5F7E7E7F7E7DEEFD6CEE77B6BE79484CE8C73CE735A
BD8463BDA59CC69484A56B52A5634ACE5A4AD66352CE8C73CE947BD69C84D69C73D69C73DE9C84\
DEA58CDEAD94E7B59CE7B594E7B594DEA58CDEA58CDEAD94DEA58CDEA58CDEAD94
DEAD94D6C6C6F7E7DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7ADA5AD9C8C8C523129EFD6CE\
F7D6BDF7D6C6F7D6BDF7D6BDF7CEB5EFBDA5EFBDA5F7D6C6F7D6C6F7D6C6F7D6C6
F7C6ADE7B59CE7A58CDE9473E7A58CEFB5A5DE6B5A9C392994634AEFBDADF7DECEF7E7DEF7E7DE\
F7EFEFF7EFEFF7E7DEF7E7E7F7EFEFF7E7DEF7DECEEFCEB5EFD6CEEFD6CEEFD6CE
D6C6C6B55239B5735A94736BAD7B6B734A39BD5A42C66B52D67363DE9C84D69C73D69C73DE9C84\
DEA58CE7B59CE7BDA5E7B59CE7B594DEA58CDEAD94D6A58CDEAD94DEAD94DEAD94
DEAD94D6C6B5F7F7F7D6C6D6E7DEE7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C7B73634A42845242EFCEB5\
F7D6BDF7D6C6F7D6BDF7D6BDF7CEB5EFBDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6
F7C6ADE7A58CDE9473CE8463D68C73B552398C29219C5A42D6C6BDF7DECEF7E7DEF7E7DEF7E7DE\
F7E7E7F7EFEFF7E7DEF7E7E7F7EFEFF7E7DEF7E7DEEFCEB5F7E7E7F7E7DEEFD6CE
EFD6CEE7BDA5C6ADA5AD5A42945A4A5A3121734229BD5A42C66B52D68C73D6A584D69C73DE9C84\
DEA58CE7B59CEFBDA5E7B59CE7B59CE7B594DEA58CDEA58CDEAD94DEA58CDEAD94
DEAD94DEB5A5DED6E7F7EFEFEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFE7E7F7F7F7F7EFEFF7EFEFE7DEEFF7EFEFF7EFEFF7F7F79484845A4239C69C84F7D6BD\
F7D6C6F7D6C6F7D6BDF7D6BDF7C6ADEFBDA5F7D6BDF7D6C6F7D6C6F7DECEF7D6BD
E7B59CE7A58CCE8C6BCE8C6B9C39298429187B3121B5735AE7B59CF7E7DEF7D6C6F7E7E7F7D6BD\
F7E7DEF7EFEFF7D6C6F7E7DEF7EFEFF7E7DEF7D6C6E7AD9CF7E7E7F7E7DEEFD6CE
F7D6C6D6C6C6D6C6C6EFD6CEA55239AD7B6B4A10084A1008B55239CE5A4AD68C7BD69C84D69C84\
DEA58CE7B594EFBDA5EFBDA5E7B59CE7B594DEAD94D6A58CDEAD94DEA58CDEAD94
DEA58CDEB59CCEBDB5CEBDCED6C6D6F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E7634231523129F7D6C6EFCEB5\
F7D6BDF7D6BDF7D6BDF7D6BDEFC6ADF7D6BDEFBDA5F7D6C6F7D6C6F7D6C6F7D6BD
E7A58CDE9C84C68C63D68C7BBD5A42A54231842918E78473E79484DE9473EFBDA5F7D6BDEFB5A5\
F7DECEF7E7DEE7AD94F7D6BDF7E7DEF7D6BDE7AD94E7AD9CEFBDA5EFD6CEF7D6C6
E7AD94EFCEB5F7D6C6EFCEB5D6A58CDEB5A5BD9C8CBD9C8C734231A54231C66B52D69C84D69C84\
DEA58CE7B594EFBDA5EFC6ADE7BDA5E7B59CDEA58CDEAD94DEA58CDE9C84DEA58C
DEA58CDEAD94D6C6B5AD9494CEBDB5D6C6BDDED6E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEBDCE634231312121734A42D6C6C6F7D6BD\
F7D6BDF7D6BDF7D6BDEFC6ADEFBDA5F7CEB5EFBDA5F7D6C6F7D6C6F7D6C6EFCEB5
E79484CE8C6BDE9473E7AD94E7AD9CE7AD94DE7B6BDE6B5AE78473E78473DE9473E7AD9CE79484\
E7A58CE7A58CE7A58CEFB5A5F7BDB5D67363DE7B6BDE7B6BE79484E7A58CE7AD94
D67363E7A58CEFCEB5E7B59CDEB59CDEB5A5D6A58CBD9C8CA5735A7B2918A54231CE8C73D69C84\
DEA58CE7B59CEFBDA5EFC6ADEFBDA5E7B59CDEA58CDEA58CD6A58CD69C84D6A58C
DEA58CDEB59CDEB5A5DED6E7D6C6D6CEBDC6D6C6CEE7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF8C7363422921523129422118C69484F7D6C6F7D6BD\
F7D6BDF7D6BDF7C6ADF7C6ADEFC6ADF7C6ADE7AD94F7D6BDF7D6C6F7D6BDF7BDB5
E7A58CCE8463E7B59CEFB5A5EFCEB5F7D6C6F7D6BDF7D6BDF7BDB5EFBDADEFB5A5EFB5A5E7AD9C\
EFB5A5E7AD9CE7AD9CEF948CEF948CDE9C8CDE9C84DE7B6BDE7B6BDE6B5ACE735A
D67363D67363DEB59CCE8C6BD68C73EFC6ADCE8C84D6A58CAD7B6B631810732110A55239D68C7B\
D6A584E7B594EFBDA5EFC6ADEFBDA5E7B594DEAD94DEA58CD6A584D6A58CDEA58C
DEAD94DEAD94DEB59CF7F7F7F7EFEFDECED6D6C6D6DED6E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7D6C6D6422921312118633931422918F7D6C6F7BDB5F7D6BD\
F7D6BDF7D6BDEFC6ADEFC6ADF7BDB5EFC6ADEFC6ADF7D6BDF7D6C6F7D6BDF7C6AD
E7AD94CE8463E7AD94EFBDADF7DECEF7D6C6F7DECEF7DECEF7D6C6F7DECEF7D6C6F7DECEF7DECE\
F7DECEF7DECEF7BDB5F7BDB5F7BDB5EFBDADEFBDADEFB5A5E7AD9CE7847BDE7B6B
E7847BD67B6BD67363C66B52C66B52D69C73C66B52B5735AA54231421010732110844A39A55239\
D69C84E7AD94EFBDA5EFBDA5EFBDA5E7B59CDEA58CDEA58CD6A58CD69C84DE9C84
DEA58CDEA58CDEB59CA5847BB59C9CDED6E7E7DEE7DECED6EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7DECED69C8C8C3121185231294229215A3121F7D6C6EFCEB5F7D6BD\
F7BDB5F7CEB5EFCEB5F7BDB5EFCEB5EFCEB5EFCEB5F7D6BDF7BDB5F7BDB5EFC6AD
E7AD94DE9C84CE8C6BEFBDADF7D6C6F7DECEF7DECEF7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE\
F7DECEF7D6C6F7D6C6F7D6BDF7CEB5EFBDA5EFBDA5EFBDA5EFC6ADE7B594E7B59C
E7AD94DE9C8CDE9C84D68C7BE7847BD67B6BD67363C66B52BD5A429C39299C3929B55239A54231\
D68C7BDEA58CEFBDA5EFBDA5EFBDA5E7B594DEAD94DEA58CD6A584D69C84DE9C84
DEA58CDEA58CDEAD94BDA59C734A39F7E7DEF7EFEFEFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7E7DEE75A42399C6B52D69C8CB5735A8C5A4AF7D6C6F7D6BDF7D6BD\
F7D6BDF7CEB5EFCEB5F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5F7D6BDEFCEB5EFCEB5
E7AD94E7A58CDE9473E7B59CEFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7DECE\
F7D6C6F7DECEF7D6C6F7D6BDF7C6ADEFBDA5EFBDA5E7B59CEFBDA5EFBDA5E7B59C
E7AD94E7A58CDEA58CDE9C84D69C84DE9C84DE9C84DE9C8CD69C84D68C7BD68C73CE8C6BCE8463\
CE8C6BDE9C84E7BDA5EFBDA5EFBDA5E7B59CDEA58CD6A58CDEA58CD6A584DEA58C
DE9C84DEAD94DEAD94C6ADAD8C7B73846352F7F7F7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7DED6E7846352F7D6BDEFCEB5EFBDA5EFBDA5EFCEB5EFCEB5F7D6BD\
F7D6BDF7CEB5EFCEB5F7D6BDF7D6BDF7BDB5F7D6C6F7D6BDF7D6BDF7D6BDEFCEB5
E7B59CE7A58CDE9C84DE9473EFC6ADEFCEB5F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6\
F7DECEF7DECEF7D6C6F7BDB5EFBDA5EFBDA5E7B594EFBDA5EFBDA5E7B59CE7B59C
E7AD94DEA58CD6A584D6A58CD69C84D6A584D6A584D69C84D69C84D6A584D69C84D69C84CE8C84\
D69C84D69C73E7BDA5E7B59CEFBDA5E7B594DEA58CDEA58CD6A584D6A584D6A584
DEA58CDEAD94DEAD94C6ADA57B635ACEBDC6D6C6BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFBDA59CEFCEB5F7D6C6F7D6BDF7D6C6EFCEB5D6C6C6EFCEB5EFCEB5\
F7BDB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5
EFBDA5E7B59CE7A58CDE9C84E7B594EFCEB5F7D6BDF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7DECEF7DECEF7CEB5EFBDA5EFBDA5E7B594E7B59CEFBDA5E7B594E7B594
E7AD94DEA58CD6A584D69C84CE947BCE8C6BCE947BCE9473CE947BCE947BD68C7BD69C84D69C73\
D6A584DE9C84E7B594EFBDA5E7B59CDEAD94DE9C84D69C84D69C84D69C73D6A584
DEA58CD6A58CD6A58CCEB5AD312121CEBDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DED6E7F7D6BDF7D6BDF7D6C6F7D6BDF7DECEEFCEB5EFCEB5F7D6BDEFCEB5\
F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6F7BDB5
EFC6ADEFBDA5E7AD94E7A58CDE9C84EFBDA5EFCEB5F7D6C6F7DECEF7D6C6F7DECEF7D6C6F7D6C6\
F7D6BDF7DECEF7D6C6F7D6BDEFCEB5EFBDA5E7A58CE7A58CE7AD94E7B594DEA58C
D6A584D69C84C69C84CE947BCE9473CE947BCE8C73CE9473CE9473CE9473CE8C73CE9473CE9473\
D68C7BDEAD94D69C73E7B59CE7B594E7AD94DE9C84D69C84D69C84D69C84D6A584
D6A584DEAD94D6A58CBDA59C523931948484E7DEEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7DECED6F7D6BDF7D6C6F7D6BDF7D6BDF7C6ADEFCEB5F7D6BDF7D6BDF7BDB5\
F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BD
F7BDB5EFBDA5E7B59CE7A58CDE9473E7B594EFBDA5F7D6C6F7DECEF7DECEF7DECEF7D6C6F7D6C6\
F7D6C6F7D6BDF7D6C6EFCEB5EFBDADE7AD94E7AD9CE7AD9CDEAD94DE9C84DE9C84
D69C73D69C73CE9473CE947BCE8C73CE9473CE9473CE947BCE947BCE9473CE9473CE8C6BCE9473\
D6A584DE9C84E7AD94DEAD94DEA58CDEA58CDE9C84D69C84D69C84D69C84D6A584
D6A58CDEA58CD6A58CBDA59C312118634A42948484F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7EFE7E7F7CEB5F7D6BDF7D6C6EFC6ADF7C6ADE7B594F7D6BDD6C6C6F7D6BDF7CEB5\
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6BD
F7BDB5EFC6ADEFBDA5E7AD94E7A58CE7A58CEFBDA5F7D6C6F7D6C6F7DECEF7DECEF7D6C6F7BDB5\
F7C6ADEFCEB5F7D6BDF7D6BDF7C6ADE7B59CE7AD94E7AD94DEAD94D68C73D6A584
D6A58CD69C84CE8C73CE8C73CE9473CE947BCE947BD69C73D69C73CE9473CE9473CE9473CE8C6B\
DE9C84E7AD94E7B594E7AD94E7A58CDEA58CD6A58CD69C84D69C84D69C84DE9C84
D6A58CD6A58CDEAD94BD9C8C312121422931CEBDB5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D6BDF7D6C6F7D6BDF7DECEEFCEB5E7A58CDEAD94F7D6BDEFCEB5F7D6BDF7D6BD\
F7D6BDF7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6
EFCEB5EFC6ADEFBDA5E7B594E7A58CDE9C84E7A58CEFCEB5F7DECEF7DECEF7D6C6F7D6BDF7D6C6\
F7D6BDF7D6BDF7D6BDF7D6C6F7D6BDEFC6ADEFBDA5E7B59CDEAD94DEAD94D69C84
BD846BCE8C73CE8C6BCE8C73CE947BCE9473CE947BD69C73D68C7BD69C73CE9473D69C73DEA58C\
E7B59CE7B594E7B594DEA58CDEA58CDEA58CDEA58CD69C84D69C84D69C84D6A58C
DE9C84D6A58CD6A58CA584844A31317B737BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7D6BDF7D6BDF7D6C6F7DECEE7B59CE7B59CDEAD94F7BDB5EFCEB5F7D6BDF7BDB5\
F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7CEB5F7C6ADEFBDA5E7B594E7A58CE7A58CEFC6ADF7D6C6F7D6C6F7DECEF7D6C6F7D6C6\
F7DECEF7D6C6F7DECEF7D6C6F7D6BDEFBDADEFBDADE7B59CDEB59CDEA58CDEA58C
DEA58CCE947BCE8C73BD846BCE8C73CE9473CE947BD69C73D69C84D68C7BDE9C84DEAD94E7AD94\
E7BDA5E7B59CE7B59CDEA58CE7AD94DEA58CDEA58CDEA58CD6A584D69C84D6A58C
D6A584D6A58CD6A58CAD846B422921523931634A42E7DEEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7E7DEF7CEB5F7D6BDF7D6C6EFCEB5DE9C84E7B594E7BDA5EFCEB5F7BDB5F7D6BDF7D6BD\
F7D6BDF7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECE
F7D6BDEFCEB5F7BDB5F7C6ADEFBDA5E7AD94E7A58CE7B59CF7BDB5F7D6C6F7DECEF7D6C6F7D6C6\
F7D6C6F7DECEF7E7DEF7DECEF7D6C6EFCEB5EFBDA5E7B59CE7AD9CDEAD94DEA58C
DEA58CDEA58CD6A58CDE9C84BD846BC68C73CE8C6BCE9473D68C7BDEA58CDEA58CE7B59CE7B59C\
E7B59CE7B59CE7B59CE7AD94E7A58CDEA58CDE9C84DEA58CD69C84D69C84D69C84
D6A584D6A58CDEB59CB58C73734A395A31293121188C736BDECED6F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFCEB5F7D6BDF7D6C6EFCEB5EFC6ADCE8C6BD69C8CEFCEB5EFCEB5F7BDB5F7D6BDF7D6BD\
F7D6BDF7D6C6F7DECEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6
F7D6C6EFCEB5F7D6BDF7BDB5E7B59CE7B59CE7B594EFBDADEFCEB5F7D6C6F7D6C6F7CEB5F7D6BD\
F7D6C6F7DECEF7DECEF7D6C6F7D6BDEFC6ADE7AD94DEA58CDEA58CDEA58CD6A58C
D6A58CD69C84D69C84DE9C8CD69C73BD846BCE8C73D68C7BD69C84DEAD94E7AD9CE7B59CEFBDA5\
EFBDA5E7B59CE7BDA5DEB59CDEAD94DEAD94DEA58CD6A58CDEA58CD6A58CD69C84
D6A58CD6A58CDEB59CD69C73C68C63A5634A844A395A4239634A42AD9494F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7E7E7F7C6ADF7D6BDF7C6ADE7B594DEA58CDE9C84DEB59CEFCEB5F7BDB5F7D6BDF7D6BDF7D6BD\
F7D6C6F7D6BDF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6
F7D6BDF7D6BDF7D6BDF7BDB5EFC6ADEFBDA5EFBDA5E7B59CF7D6C6F7D6C6F7D6C6EFCEB5EFC6AD\
F7D6BDF7D6C6F7D6C6EFCEB5F7BDB5EFBDA5DEAD94DEA58CD69C8CD69C8CD69C84
D6A58CD69C84D69C84D69C84CE9473BD8463CE8C6BD69C73DEA58CE7AD9CE7B59CE7B59CEFBDA5\
E7B59CE7B59CE7B59CDEAD94DEAD94E7AD94DEAD94DEA58CDEA58CD6A584DEA58C
DEA58CDEA58CDEB59CD69C84D69C73CE8C73BD846B634A428C7B73E7DEE7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7D6C6F7CEB5E7A58CDE9473D67363D67B6BD69C84E7B59CD6C6B5F7D6BDF7D6BDF7D6BDF7D6BD\
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6
F7D6C6F7D6BDEFCEB5F7BDB5EFC6ADEFBDADEFCEB5F7C6ADF7D6BDF7D6C6F7D6BDEFC6ADEFBDAD\
EFCEB5F7D6BDF7D6BDF7BDB5EFBDA5E7B594E7AD94DE9C84D69C84D69C84CE947B
CE947BCE947BD69C73CE9473BD846BC68C63CE8C73DE9C8CDEAD94E7B59CE7B59CE7B59CEFBDA5\
EFBDA5E7B59CE7B59CDEAD94E7AD94DEA58CDEA58CDEA58CDE9C84D6A584D69C84
DE9C84DEB59CDEB59CD69C84D69C84D69C84D69C84BD9C8CF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7BDB5F7CEB5E79484E77B6BD67B6BCE8C6BDEA58CE7AD9CEFCEB5F7D6BDF7D6C6F7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6
F7D6BDF7BDB5EFCEB5F7C6ADEFBDADEFC6ADEFCEB5F7D6C6F7D6C6F7DECEF7D6C6F7D6BDF7D6C6\
F7D6C6F7D6BDF7BDB5EFC6ADEFBDA5E7B59CDEAD94D69C84C69C84C68C73CE947B
CE9473C68C73CE9473CE8C6BCE8C6BCE8C6BD68C7BDEA58CDEAD94E7B59CEFBDA5EFBDA5E7B59C\
EFB5A5E7B59CE7B59CE7B594E7AD94DEA58CDEA58CDE9C84D6A58CD6A58CD69C84
D6A58CDEAD94DEB5A5CE9473CE9473D69C73D69C73C6ADA5F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFD6CE
F7BDB5F7C6ADE79484DE9473D67B6BCE8C73D6A58CEFBDA5EFCEB5F7D6BDF7D6C6F7D6BDF7DECE\
F7DECEF7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7BDB5
F7D6BDF7BDB5EFCEB5EFBDADF7C6ADF7BDB5EFCEB5F7D6C6F7D6C6F7DECEF7DECEF7DECEF7D6C6\
F7D6C6F7D6C6EFCEB5F7C6ADEFBDA5E7B59CDEA58CD69C84CE947BCE947BC68C73
C68C73C68C73C68C73CE947BCE947BD69C84DEAD94DEAD94E7B59CE7B59CE7BDA5E7BDA5EFBDA5\
E7BDA5E7B59CE7AD94DEAD94DEAD94DEA58CDEA58CDE9C8CDE9C8CDE9C8CD69C84
D69C84D6A58CDEB5A5CE8C6BCE8C6BD69C84D69C84DEB59CFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7BDB5
F7CEB5F7BDB5E7A58CE79484CE8C73CE8C73DEAD94EFBDADEFCEB5F7D6C6F7D6BDF7D6C6F7DECE\
F7D6C6F7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7D6BD
EFCEB5F7D6BDF7BDB5EFC6ADEFBDA5EFBDA5EFBDADF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDEFCEB5E7B59CE7AD94DEA58CD69C84C69C84CE947BCE9473
CE947BCE947BCE947BD6A584D69C84DEA58CDEAD94E7AD9CE7AD9CEFBDA5EFBDA5E7B59CEFBDA5\
E7B59CE7B59CE7B59CE7AD94DEA58CDEA58CD6A58CD69C8CD69C84D6A58CD69C84
D69C84D69C8CDEB5A5D68C7BD68C7BD69C73D6A58CD69C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECEEFBDA5
F7CEB5F7D6C6E7A58CDE9C84CE8C6BC68C73DEAD94EFC6ADF7D6BDF7D6C6F7D6C6F7D6C6F7DECE\
F7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5F7D6BDF7D6BD
F7BDB5EFCEB5EFC6ADEFC6ADEFBDA5EFBDADEFC6ADF7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDF7BDB5EFBDA5E7A58CDEA58CD69C84C69C84CE947BCE947B
CE947BC69C84C69C84D69C84D6A584DEAD94DEAD94E7B59CE7B59CEFBDA5EFBDA5E7BDA5E7B59C\
E7B59CE7AD94DEAD94DEAD94DEA58CDE9C84DEA58CDE9C84D69C84D69C84D69C8C
D6A584D69C8CDEB5A5D6A58CDE9C84D6A584D6A58CD68C7BD6C6C6F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDE7B594
F7D6BDE7BDA5E7AD9CDE9C84BD846BC68C73DEB59CEFC6ADEFCEB5EFCEB5F7D6BDF7D6C6F7DECE\
F7D6C6F7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6BDEFCEB5EFCEB5EFCEB5EFBDA5
EFCEB5EFCEB5EFBDADEFBDA5EFBDA5EFCEB5EFCEB5EFCEB5F7D6C6F7D6BDF7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDEFBDA5E7AD94DEA58CD69C84D69C84C6947BCE947B
C69C84C69C84D69C84D6A58CDE9C84DEA58CE7AD9CE7B59CE7BDA5E7B59CE7BDA5E7B59CE7BDA5\
E7B594E7AD94E7AD9CE7AD94DEA58CD6A58CD69C84D6A584D69C8CD69C84D69C84
D69C84DEB59CE7AD9CCE9473D6A584D6A58CDEB59CD68C73DEAD94F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE7B594E7A58C
CE8C73DE9C8C9C6B529C6B52B57B63BD846BE7BDA5EFCEB5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6\
F7DECEF7D6C6F7D6C6F7D6BDF7D6BDF7CEB5F7D6BDEFCEB5EFC6ADEFBDADEFBDAD
E7BDA5EFBDADEFBDADEFC6ADEFCEB5EFCEB5EFCEB5EFCEB5F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6\
F7D6C6F7D6C6F7D6BDEFCEB5EFBDADE7AD94DEA58CD69C84CE947BCE947BCE947B
CE947BC69C84D69C84D69C84D6A58CDEAD94E7AD9CE7BDA5E7B59CE7AD94E7B59CE7BDA5E7BDA5\
E7B59CE7B59CE7AD94DEAD94DEAD94DEAD94DEA58CD6A58CD69C8CD69C84D69C84
D69C8CD6A58CDEB5A5AD6B52CE7352D6A584DEB59CD68C73D68C73EFE7E7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDE7A58CD68C7B
CE8C738C5A42AD735A8C5A4A94634A9C7363E7BDA5F7D6BDF7D6C6F7D6C6F7D6BDF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDF7D6C6F7D6C6EFCEB5EFCEB5EFC6ADEFCEB5EFC6ADEFBDAD
E7B59CE7BDA5E7BDA5E7BDA5EFBDADEFCEB5EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6BDF7D6BD\
F7D6C6F7D6C6F7CEB5EFCEB5EFBDA5E7AD94D69C73D69C84CE947BC68C73CE947B
CE9473CE8C84D69C8CD69C84D6A58CDEAD94DEAD94E7AD9CDEB59CDEAD94E7AD94E7AD94E7AD9C\
E7AD94E7AD94E7AD94DEAD94D69C8CDEAD94D6A58CD69C8CD69C84D69C84D6A58C
D6A58CD6A58CC6ADA5B5735AC66B52CE947BD6A58CD69C84D69C73F7BDB5F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADDE9473CE947B
734229D69C848C5A4A845242734A42A5735AE7BDA5F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7D6BD\
F7D6C6F7D6BDF7D6C6F7D6C6EFD6CEF7D6C6F7D6C6F7D6C6F7D6C6F7D6C6EFCEB5
EFBDADEFBDA5E7AD9CE7AD9CDEAD94E7AD9CEFC6ADEFCEB5EFCEB5F7D6BDF7D6C6F7D6BDF7D6C6\
F7D6C6F7D6BDF7D6BDEFBDADE7B59CDEA58CD68C7BCE8C84CE9473CE9473CE947B
C68C73D69C73D69C84D6A58CDEAD94DEA58CDEA58CDEAD94DEAD94E7B59CE7AD9CE7AD94DEA58C\
DEAD94DEAD94DEA58CD6A58CDEAD94D6A58CD69C8CD6A58CD6A584D69C84D69C84
D69C8CC6ADA5D6A58CB57B63C68C63CE8C6BCE9473DEA58CD68C7BDEA58CF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFE7B594E79484A5735A
B5735A6342318C5A428C6352846352846B5AE7BDA5F7D6BDF7D6C6EFCEB5F7D6C6F7D6BDEFCEB5\
F7D6BDEFCEB5D6C6B5EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7D6C6D6C6BDF7D6C6
F7D6C6D6C6B5E7BDA5E7BDA5DEAD94DEA58CDEAD94DEB59CEFCEB5EFCEB5F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6BDF7D6BDEFBDA5E7BDA5DEA58CD69C84CE947BCE947BC68C73C68C73
CE947BC69C84D69C8CD6A584DEA58CD6A58CDEA58CDEA58CDEAD94DEAD94DEAD94DEAD94D69C8C\
D6A58CDEA58CDEA58CDEAD94DEA58CD6A58CD6A58CD6A584D69C84D6A584D69C84
D69C8CC6ADA5D6A58CB57B63A5634AA55239A54231CE7352D69C73D68C73F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEDE9473E7AD9CAD735A
B5735A421810734A39523129734A42846352E7BDA5F7D6BDF7D6BDEFCEB5EFCEB5F7D6C6F7D6C6\
F7D6BDF7D6BDEFCEB5DEB59CC69C84DEB59CD6A584C6947BCE8C84C6947BC69484
C69484D69C8CCE8C84D69C8CDEA58CDE9C8CDEA58CDEAD94E7BDA5EFCEB5F7D6C6F7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDEFBDADE7B59CDEA58CCE947BCE9473CE9473CE8C6BC68C73
C6947BCE947BCE947BCE947BC69C84D69C8CC69C84D6A58CD6A58CD6A58CDEB59CDEB59CD6A58C\
DEAD94DEAD94DEAD94DEAD94DEAD94D6A58CD6A58CD6A58CD6A584D69C84C69C84
D69C8CDEB59CD6A58CB5846BA5634AAD5A42A55239BD5A42CE8463D68C7BF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6BDDE9473E7AD9CBD846B
734231312118312118422921634231734A42EFC6ADF7D6C6F7D6BDF7D6BDF7D6BDF7D6BDF7D6C6\
EFCEB5EFC6ADDEB59CC68C73B5846B845239734A429C6B52BD846BBD846BA5735A
9C7363A56B52B5846BB5735AC6947BD68C7BCE8C73DEAD94E7BDA5EFC6ADF7D6BDF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDEFBDADE7B59CDE9C84D69C73CE947BCE8C6BC68C73C69C73
BD846BB58C73C69C84D69C8CD69C84CE947BC69C84D69C84D69C84C69C84D6A58CDEAD94DEAD94\
DEB59CDEAD94E7AD9CDEAD94D6A58CD6A58CD69C8CD69C84D6A58CC69C84C69C84
D6A58CD6A58CD6A58CAD846BA56B52AD5A42AD5A42BD5A42CE8463DE9C84F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFC6ADE77B6BE7AD9CD69C8C
4218104210104229215231295239317B6352EFC6ADF7D6C6EFCEB5F7D6BDF7CEB5F7CEB5F7D6BD\
F7D6BDF7D6BDEFCEB5EFC6ADDEB59CC69C84734A39AD846BCEB5BD7B635AAD846B
634A42291818845239734229B57B63AD6B52AD5A42A55239AD5A42E7B594EFC6ADF7D6C6F7D6C6\
F7D6C6F7D6C6F7D6BDEFC6ADE7B59CDEA58CD69C73CE9473B58C73C69C73BD8463
BD846BC69C84D6A58CDEAD94DEAD94DEAD94DEAD94DEAD94DEA58CD69C8CD69C8CD69C84C69C84\
D6A584DEAD94DEB59CDEAD94DEAD94D6A58CD6A58CC69C84D69C84C69C84D69C84
D6A58CD6A58CD6A58CB5846BAD6B52AD5A42AD5A42BD5A42CE735AD69C84F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFFE7B59CCE7352E7AD94EFB5A5
52312939292142293152312963423173524AEFCEB5F7D6BDF7D6C6EFCEB5EFCEB5EFCEB5F7D6BD\
F7D6C6F7D6BDEFCEB5EFCEB5D6A58CDEAD94C6947BA5847B5A42395A3121948484
84739429181873524A845239BDA59CB59C9C8C5A42AD5A42D69C73EFBDA5EFCEB5F7D6C6F7D6C6\
F7DECEF7DECEF7D6C6EFCEB5EFBDA5DEA58CD69C73CE8C6BBD846BB5735AB5735A
BD8463D6A584DEB59CDEB59CDEB59CDEB59CDEAD94D6A58CD6A58CDEB59CDEB59CD6A58CD69C8C\
D6A584D6A58CDEAD94DEB59CDEAD94D6A58CD6A584D6A584C69C84D6A584C69C84
C69C84D6A58CC69C849C736394634AA5634AA5634AC66B52CE8C6BDE9C84F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7FFFFFF734229F7C6ADCE7352DE9C84E7AD94
734A423121214229215231295A3129846352EFCEB5F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5F7D6BD\
F7D6C6F7D6BDF7D6BDF7D6C6EFC6ADDEAD94DEAD94EFBDADDEB59C846352634231
5231293121186339296339297B635AAD6B52B5735AC66B52DEA58CE7B59CEFCEB5F7D6BDF7DECE\
F7DECEF7E7DEF7D6C6EFCEB5EFBDA5DEA58CD68C7BBD846BBD8463BD8463AD6B52
7B2918844A39C68C73CE947BC68C63B57B63B5846BA56B529C6B52B57B63C6947BC69484C69C84\
D6A584D6A584C69C84D6A58CD6A58CD6A58CC69C84C6947BC69C84C69C84D69C84
D69C8CD69C8CC6947B9C6B52945A4AA56B52AD6B52CE8463D68C7BD68C7BFFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7E7DEE75A31295A3121F7C6ADE7B59CF7C6ADE7B59C
845242392921523129422921523129846352EFC6ADF7D6BDEFCEB5EFCEB5EFCEB5F7CEB5F7D6C6\
F7D6C6F7D6C6F7D6C6F7D6BDF7D6BDEFCEB5E7B59CDEAD94DEAD94DEB5A5AD846B
9C6B5273524A9C6B52845242AD6B52BD8463B5735AE7B594E7B594E7B594EFCEB5F7D6BDF7DECE\
F7E7DEF7E7DEF7D6C6EFC6ADEFBDA5DEA58CD68C7BCE8C6BBD8463BD846BB5735A
A573528C5A42C6ADADD6C6BDBDB5BD8452397B29187342298452429C7363945A528C5A42B57B63\
B5846BB58C73B58C73C69C73C6947BC6947BC6947BCE947BCE947BC69C84D69C84
D69C8CC69C84B58C738452428C5A4A8C5A4A9C6B52D68C73D69C73CE8463F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F76342315221184A2118E7A58CF7C6ADE7B59CE7A58C
8C5A4A5242394231393121184229218C6352EFCEB5EFCEB5EFCEB5F7D6BDF7D6BDE7B59CEFCEB5\
F7D6BDEFCEB5F7D6C6F7D6C6F7D6BDEFCEB5EFCEB5E7B59CD6A58CD6A58CDEB59C
D6A58CB58C73BD8463B5735ABD8463B5735AD6A584DE9C84E7AD94E7BDA5EFC6ADF7D6BDF7DECE\
F7E7DEF7DECEEFCEB5EFC6ADE7BDA5DEA58CD69C73CE8C6BBD8463BD846BBD8463
AD6B52A56B52A5847BDECED67B635AA5847B211010423139845242634231846B5A945A4A634231\
9C6B529C73639C6B52A57352B57B63CE8C6BCE947BC69C84D6A584C69C84C69C84
D69C84C6947BAD846B845242734A39846352845242D69C84DEA58CCE7352FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7846B5A5A3129422921421810734229DE9473B5735AA55239
5A42394A31314229213929215231298C7363F7CEB5F7CEB5F7D6BDEFCEB5F7D6C6E7BDA5C68C73\
EFBDA5EFCEB5F7D6C6F7D6C6F7DECEF7DECEF7D6C6EFCEB5EFC6ADE7B59CE7B59C
DEAD94DEA58CD6A584D6A584DE9C84DE9C84DEA58CE7B594E7BDA5EFC6ADF7D6BDF7D6C6F7DECE\
F7DECEF7DECEF7D6BDEFC6ADEFBDA5DEAD94D69C84C68C73BD8463CE8C6BBD846B
BD8463B5735AC68C73B57B63734A42ADA5AD1810105A5252734A42634231A5847B8C7B73524239\
634231734A427B6352B57B63BD8463CE9473D6A584D6A58CD6A58CD6A58CC69C84
C69C84C6947B8C63526B524A734A39523931845239D6A58CCE8C6BCE7352F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFF5A31296339295231294218104A10084A1008845242523129
422931523931392921392921523129A5735AEFCEB5F7BDB5EFCEB5EFCEB5F7D6C6EFCEB5DE9C8C\
D6A58CDEAD94EFCEB5F7D6C6F7DECEF7DECEF7D6C6F7D6C6EFCEB5EFBDADE7B59C
DEA58CDEA58CDEAD94DEA58CDEA58CDE9C84E7B594E7B594EFBDA5EFC6ADEFC6ADF7D6C6F7DECE\
F7DECEF7DECEEFCEB5EFBDADE7B59CDEB59CD6A58CCE9473CE8C6BC69C73C69C73
CE8C6BC69C73D6A58CB58C73C68C736B524A31212131211863392952312973524A5A42395A4239\
8463529C6B52C69C73BD846BC69C73D6A584CE9473CE947BD6A58CC69C84C69C84
D6A584C6947B734A42734A39634231523129734231DE9C8CCE735ACE634AF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7EFE7E75A31215A31296339294229215221184218105A42394A3131
3929213121213121214229214229218C7363EFC6ADF7CEB5F7D6BDF7D6BDEFCEB5F7D6C6EFCEB5\
CE947BDEAD94D69C8CEFC6ADEFD6CEF7DECEF7DECEEFD6CEF7D6C6EFCEB5EFC6AD
DEAD94DEAD94DEB59CDEA58CD69C73D68C73D68C73DEAD94E7BDA5E7BDA5EFCEB5F7D6C6F7DECE\
F7DECEF7D6C6EFCEB5EFBDA5E7B59CDEAD94D6A58CC69C84CE8C6BCE8C6BCE9473
CE947BCE9473BD8463D6A58CD6A58CA5735A9C7363845242634A428452395239318C6352AD846B\
AD735AAD846BB58C73C68C73CE9473C6947BD6A58CC69C84C69C84C69C84C69C84
C69C84AD846B734A39523931634A425A3129633929D6A58CCE634ACE7352FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7AD94A55A31295239316342315A31295A3129523129523931523931
2918183121185231293121185A3129846352EFC6ADF7CEB5F7CEB5F7D6BDEFCEB5F7D6BDF7D6C6\
EFBDADDEB59CAD847BBD846BC6947BC6947BB58C73B58C739C6B529C7363846352
8C5A4A94634A94634A8C5A42A56B52AD6B52AD6B52CE947BDEB59CE7BDA5EFCEB5F7D6C6F7D6C6\
F7D6BDF7D6BDEFC6ADEFBDA5E7B59CDEB59CD6A58CCE947BCE9473CE8C6BCE8C6B
C69C73CE947BD6A584CE9473D6A58CD6A584D6A58CC6947BC6947BAD846BAD735AAD846BAD735A\
C69C73CE947BCE947BD69C73D69C84C69C84D69C84D6A584D6A58CD6A58CD6A584
C69C848463526342315A4239523129422118734231BD846BBD5A42CE7352F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7B5A5A5523129422921422921422921392921422921523129422921
3929213121183121215231295231298C6352EFC6ADEFCEB5F7D6BDEFCEB5F7D6BDF7D6BDF7D6BD\
F7D6C6EFCEB5EFBDADD69C8C94736B947B73AD8C84AD7B6BAD7B6B9C6B528C6352
A5735A945A52945A4A945239945A4AB57B63BD846BD69C84E7B59CF7BDB5EFCEB5F7D6C6F7D6C6\
EFCEB5EFCEB5EFC6ADEFBDA5EFBDA5DEB59CDEAD94CE8C84C68C73BD8463BD8463
BD8463C68C73CE947BDEAD94DEA58CD6A584CE947BCE9473C69C73C69C73BD846BCE9473CE947B\
D69C84D69C73C69C84D69C8CC69C84D69C84C69C84C69C84C69C84C69C84C69C84
B58C73734A424A313142313952423942211894634ABD846BAD5A42C66B52F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7C6ADBD6339294A21184221184221183929214A2118422921211010
422921312118392921523931634A427B6352DEB59CEFC6ADF7CEB5F7D6BDF7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6F7D6BDEFCEB5D6A58CD69C8CD69C8CAD8C84CE8C84D69C8CC69484
C68C73AD847BC6947BBD846BBD846BCE947BDEA58CEFBDADEFCEB5F7D6BDF7D6C6F7D6C6F7D6C6\
F7CEB5F7BDB5EFBDA5EFC6ADE7BDA5DEB59CDEAD94CE8C84BD846B9C5A428C5A42
9C5A42B5735AC69C73CE947BD6A584DEA58CD6A584DEA58CDEA58CD6A584D6A584D6A584C69C84\
C69C84D6A584D69C8CC69C84D6A58CD69C8CC69C84C69C84D69C8CD6A584C69C84
AD846B6342313929214A3131392921312118C68C73BD8463AD5A42CE7352F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D6CEDE633931312118422921392921422921523129422921291818
422921422921312121392921634A428C6352D6A58CEFC6ADEFCEB5EFCEB5F7D6BDF7D6BDF7D6C6\
F7D6C6F7D6C6F7DECEF7D6C6EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6D6C6BD
F7BDB5D6C6BDF7BDB5D6C6C6F7BDB5F7D6C6EFCEB5EFCEB5EFCEB5F7D6C6F7D6C6F7D6C6EFCEB5\
EFCEB5F7CEB5EFBDADEFC6ADEFBDADE7BDA5E7AD9CD6A58CCE947B9C6B52845242
844A39844A39A5735ABD846BCE9473D6A58CD6A58CDEAD94DEA58CD6A58CD6A58CD6A584D6A58C\
D69C84D6A58CD6A58CC69C84D6A58CC69C84D6A584C69C84D6A58CC69C84D6A584
8C6352523129392921422931312121523931CE9473CE735AAD5A42C66B52948484F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7E7DEEF734A394229214A2118392921422921392921392921312118
211010422921422921523129634A427B6352C69C84E7BDA5EFC6ADF7CEB5F7D6BDF7D6BDF7D6C6\
F7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7DECEF7DECE
F7DECEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5F7D6C6F7DECEF7D6BDEFCEB5\
EFCEB5EFCEB5EFC6ADEFC6ADEFC6ADE7BDA5EFB5A5E7BDA5EFBDADD6A58CBD846B
945A528C5A4A734A39633929634231845242B57B63D6A584D6A58CD6A58CD6A584D6A584D6A584\
C69C84C69C84CE947BCE947BC68C73B58C73CE947BD69C8CD6A58CD69C84B58C73
734A393929214229213121215242395A3129AD6B52BD846BA55239B57B636B524ADECED6F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7633931634231523129422921392921422921422921422921
211010422921392921523129734A39846352C69C84DEAD94EFBDA5F7CEB5F7D6BDF7D6BDF7D6C6\
F7D6C6F7DECEF7D6C6F7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7DECEF7D6C6F7D6C6EFCEB5F7BDB5\
F7BDB5EFCEB5EFC6ADEFBDA5EFC6ADEFBDA5E7BDA5EFBDADE7BDA5DEB5A5DEB5A5
D6A58CBD846B945A528C5A4A7342316339296342317342318C5A4AB58C73C69C73C68C73CE947B\
C6947BB58C73B57B639C6B529C6B52BD846BD6A58CD69C84D69C8CD69C84AD846B
5A3129422921422921422921422931422118844A39AD6B52BD8463A5735A735A529C8C8CF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7634A42734A42523931422921422921392921422921422921
312118291818422921634231634A42846352C6947BD6A58CEFC6ADF7CEB5F7D6BDF7D6BDF7D6C6\
F7D6C6F7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7D6C6F7D6BDF7D6C6F7D6BDEFCEB5F7D6BD\
F7D6BDEFC6ADEFC6ADEFBDA5EFC6ADEFC6ADEFBDADEFC6ADEFBDADEFBDADE7BDA5
DEB5A5DEAD94D69C8CAD846B9C73638C5A4A734A396342316342318452428C5A4A9C6B52846B5A\
8C5A4A9C6B52A5735A9C6B52B5846BD69C8CD6A58CD69C84C69C84CE947BA5735A
5231293121184229214229314A31314221185221188C31297B3121633929735A52B5A5A5F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7734A39734A39634231523129422921523129422921422921
392921211010523129523129634A427B6352B58C73D6A584E7B59CF7CEB5F7D6BDF7D6C6F7D6BD\
F7DECEF7D6C6F7DECEF7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5EFCEB5\
EFCEB5EFC6ADF7C6ADEFC6ADEFBDADEFC6ADEFBDADEFC6ADEFC6ADE7BDA5E7B59C
E7BDA5DEB59CDEB59CD6A58CC69C84BD846B9C7363945A52734A39734A39845239845239845242\
845242945A52AD735ABD846BC69C84D69C8CC69C84C69C84CE947BC68C738C5A4A
4229214229213929214229213929213121184208006318106339295A42397B6352FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7DED6E773524A734A3973524A523931392921523129422921422921
4229214A31314A31315A4239634A42846352AD846BBD9C8CDEB59CEFBDA5F7D6BDF7D6BDF7D6BD\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEF7DECEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DEF7DECEF7D6C6F7DECEF7D6BDF7D6BDF7D6BDF7D6BD\
F7C6ADEFC6ADEFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFC6ADEFC6ADEFBDADEFB5A5
E7BDA5E7AD9CDEB59CDEB59CD6A58CD6A58CC69C84CE947BB58C73B57B63A5735A9C6B52A5735A\
AD735AC68C73C69C84C69C84D69C84CE8C84C69C84C69C84CE947BB58C73634231
523129422921422921523129392921392921312118523129523129523129735A529C8C8CF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7CEB5B5734A396B524A734A39634231523931523129422921422921
422921422921422921523129634231734A429C7363C6947BDEAD94EFC6ADF7CEB5F7D6BDF7D6BD\
F7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7DECEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5\
EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFBDADEFCEB5EFBDA5EFC6ADEFBDADE7B59C
E7B59CE7B59CDEB59CDEB59CDEAD94D6A58CD6A58CD69C8CD69C8CCE947BCE947BCE8C84CE8C73\
C69C84C69C84D69C84C69C84D69C84CE8C84D69C73C69C84C68C73AD846B5A3129
5231294229213929213929214A31313929213121213121184229215231294A31316B524AF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F79C8C8C734A39734A396342315239315239314A3131422921422921
4A2118523931523129422921634231634231846352AD846BD6A58CEFBDA5EFCEB5F7D6BDF7D6BD\
F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7DECEF7DECEF7DECEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6BDEFCEB5F7D6C6F7D6BDF7CEB5\
F7CEB5EFBDA5EFC6ADEFC6ADEFBDA5EFC6ADEFBDA5EFBDA5E7BDA5EFBDA5E7BDA5
E7B59CE7BDA5E7AD94DEB59CDEAD94DEB59CD6A58CDEB59CDEAD94DEAD94D6A58CD6A58CD6A58C\
D69C84D69C84D6A584D69C8CD69C84D69C84D69C84CE947BB58C7394634A523129
5231293929214229213929215231293929213929214229214229213121186342316B524AC6ADAD\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F7846B5A6342316B524A73524A634A42523931633931523129422921
422921422921422921422921523129634231734A398C6352B58C73E7BDA5EFC6ADF7CEB5F7D6C6\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6BDEFCEB5F7D6BDF7D6BDEFCEB5EFC6AD\
EFC6ADEFC6ADEFBDA5EFBDA5EFC6ADEFC6ADEFBDA5EFBDA5EFB5A5E7B59CE7B59C
E7BDA5E7BDA5E7AD9CE7B59CDEB59CDEAD94DEB59CDEAD94DEAD94D6A58CD6A58CD69C8CD69C84\
D69C8CD6A58CD6A58CD69C8CC69C84D69C84C69C84B58C73A5735A734A39523931
4229213929213121215239312918183121213121213929214229212918184A3131634231AD9C8C\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F773524A634231634A426B524A634A425239315A4239523129422921
312118422921422921523129422921634231734A39734A42A57352D6A584EFC6ADEFCEB5F7D6BD\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6BDF7D6BDF7D6BDEFC6ADEFC6AD\
EFBDA5EFC6ADEFBDA5EFBDA5EFBDA5EFBDA5EFC6ADEFBDA5E7B59CEFBDA5E7BDA5
E7B59CE7B59CDEAD94DEB59CDEAD94DEAD94DEB59CDEA58CD6A58CD6A58CDEA58CD6A58CD6A58C\
D6A58CC69C84C69C84C69C84C69C84C69C84CE947BAD846B7B63525A4239422921
3121183121214A3131291818312121291818312118312118211010312118523129634231A5847B\
FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7634A42634A426B524A6B524A734A39634A425A4239523129422921
5231293121184A211842292152312952312973524A846352845242C6947BDEAD94F7CEB5F7D6BD\
F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7BDB5EFCEB5EFCEB5\
EFBDADEFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B59CE7BDA5E7B59CE7B59C
DEAD94E7B594DEB59CDEB59CDEAD94DEAD94DEAD94DEAD94D6A58CD6A58CD6A58CD6A584D6A58C\
D6A58CD6A584D69C84D6A58CD69C84CE947BB58C73A5735A734A39523129422921
3929215231293929213121213121213121183121183121183121183929214229216342318C7363\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F77B6352734A396B524A634A426B524A634A42523931523931422921
5231293121184229214229215239315239316B524A7B6352846352BD846BDEAD94EFC6ADF7CEB5\
F7D6BDF7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7E7DEF7E7DEF7E7DEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5EFCEB5EFC6AD\
EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5EFBDA5E7B594E7BDA5EFB5A5E7B59CE7B59C
E7B59CDEAD94DEAD94DEAD94DEAD94DEAD94DEAD94DEA58CDEAD94DEA58CD6A58CDEA58CD6A58C\
D69C84C69C84C69C84D69C84CE947BC6947BB5846B8C6352634231523129392921
523931523129291818291818312121291818211010291818312121392921422921523931947B73\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7734A39634231734A39634A42634A426B524A5A42395A4239523129
523129523129422921523129523129422921634231734A42846B5ABD846BD6A584E7BDA5EFC6AD\
F7D6BDF7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7E7DEF7E7DEF7E7DEF7DECEF7E7DE
F7E7DEF7E7DEF7DECEF7E7DEF7DECEF7DECEF7D6C6F7D6C6EFCEB5F7BDB5F7D6BDF7CEB5EFBDAD\
EFBDA5EFBDA5E7B59CE7B59CEFBDA5EFBDA5E7B59CEFB5A5E7B59CE7BDA5E7B59C
DEAD94E7AD94DEAD94DEAD94DEA58CD6A58CDEAD94DEA58CD6A58CD6A584DEA58CD69C84D6A58C\
D69C84D69C84D69C84CE947BCE9473B58C739C7363734A42634A42634231523931
392921392921312121312118291818291818211010291818312118392921312118634231EFE7E7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F76B524A6B524A734A396B524A6B524A6B524A6B524A634A425A3129
523129523129312118523129523129523931734A398452429C6B52AD846BCE8C6BE7B59CEFC6AD\
F7D6BDF7D6BDF7DECEF7D6C6F7DECEF7D6C6F7DECEF7DECEF7E7DEF7E7DEF7E7DE
F7E7DEF7DECEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDF7D6BDEFBDA5EFC6AD\
EFBDA5E7BDA5E7B59CE7B59CE7B59CEFB5A5EFBDA5E7B59CE7AD94E7AD94DEAD94
E7AD9CE7AD9CDEAD94DEAD94DEAD94D6A58CDEA58CD6A58CD6A58CD6A58CD6A58CD69C8CCE947B\
C69C84D69C84C69C84C68C73C68C739C73638C7363734A395A4239523129312118
312118312118312121291818291818211010312118291818312121392921523129735A52F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEF734A42634A42634A426B524A734A426B524A735A525239315A4239
523129422921523129523129523931634231634A4273524A8C6352B57B63C68C73DEA58CEFBDA5\
EFCEB5F7D6C6F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7E7DEF7DECEF7DECEF7E7DE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7DECEF7DECEF7D6C6F7D6BDEFCEB5EFC6ADEFC6ADEFC6AD\
EFBDA5E7BDA5E7B59CE7B59CE7BDA5E7B59CEFBDA5E7B59CE7B59CDEB59CE7AD94
DEA58CDEAD94DEAD94DEA58CDEAD94DEA58CD69C8CD6A58CD69C84D69C84D6A58CD69C84D6A584\
D69C84C69C84C69C84B58C73AD846B9C73638C5A4A634231523129422921312121
39293131212131212129181829181831212129181831211831211831211852312973524AF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
F7F7F7EFE7E7634A42634A42634231634A426B524A6B524A6B524A634A42634A42
4229214229215239315231295239316342315A4239734A399C6B52B57B63C68C73D6A58CE7BDA5\
EFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7E7DEF7DECEF7E7DEF7E7DEF7DECE
F7E7DEF7E7DEF7E7DEF7DECEF7DECEF7D6C6F7DECEF7D6C6EFCEB5F7BDB5F7CEB5EFBDA5EFBDA5\
EFBDA5EFBDA5EFBDA5EFBDA5E7BDA5E7B59CE7B594E7B59CE7B59CE7AD94DEB59C
DEB59CDEAD94DEAD94DEA58CD69C8CD69C8CD6A58CD6A58CD6A58CD69C8CD6A58CD69C84D69C84\
C69C84C69C84C6947BB5846BA5735AA5735A734A39634231523129523129392921
3929215231293929214229213929213121213121183121213929214229215231298C6352FFFFFF\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7EFE7E773524A6B524A5A3129634A4273524A6B524A735A526B524A634A42
5A3129422921523129523931523129523931734A427B6352A5735AA5735AB57B63CE9473DEAD94\
EFC6ADEFCEB5F7D6BDF7D6BDF7D6C6F7D6C6F7DECEF7E7DEF7DECEF7E7DEF7DECE
F7DECEF7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6C6F7D6C6EFCEB5EFC6ADEFC6ADF7C6ADEFBDA5\
E7B59CE7B59CE7B59CE7B59CE7B59CE7AD9CE7B59CE7B59CE7B59CE7AD9CE7AD9C
E7AD94DEB59CDEAD94D69C8CDEA58CDE9C8CD6A58CD6A58CC69C84D69C84D69C8CD69C84D69C84\
CE947BC6947BB58C73AD846B94634A7B6352734A395A3129523129422931422921
4A31315231293121212918183929213929213121212918182918183929215A4239EFE7E7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7EFEFF7F7F77B63525A42395A4239734A396B524A634A42735A526B524A634231
634A424229215239315239315A42395239316342317B63528C7363845242A5735ABD846BDEA58C\
EFC6ADEFCEB5EFCEB5F7D6C6F7D6C6F7D6C6F7DECEF7DECEF7DECEF7DECEF7DECE
F7DECEF7DECEF7DECEF7D6C6F7D6C6F7D6BDEFCEB5F7D6BDEFC6ADEFC6ADEFCEB5EFBDA5EFBDA5\
EFBDA5E7B594E7B59CE7B59CE7B59CE7B594E7B59CE7B59CE7B59CE7B59CE7AD94
DEAD94DEAD94DEAD94DEAD94DEA58CD6A58CD6A58CD69C8CD69C84C69C84D69C84D69C84C69C84\
C69C84B58C73AD846BA5735A7B6352734A425A42395231294A3131392921392921
312118422921312121312121291818291818181010211010291818422921734A42F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7EFEF\
F7F7F7F7F7F78C736B634A425A4239734A39634A427B63526B524A6B524A634A42
634A425231293929216342315A4239634A42523931734A3973524A7B63529C6B52B57B63D69C84\
EFC6ADEFC6ADF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7DECEF7D6C6F7DECEF7DECE
F7D6C6F7D6C6F7DECEF7D6BDF7D6C6F7D6C6F7D6C6EFCEB5EFCEB5F7CEB5EFC6ADEFBDA5E7B59C\
E7B59CE7AD9CE7B594E7AD9CE7B59CE7AD94E7AD94E7AD9CE7B59CE7AD94E7AD94
E7AD94E7AD9CD69C8CDE9C84D69C84D6A58CD69C8CD6A584D6A584D69C84D69C84D69C84CE947B\
C68C73B5846B9C6B528C5A4A734A39634A42634231422921422921422921392921
3929213121213121212918183121211810102110102918183121185231298C7363F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7947B7373524A5A42396342315A42396B524A634A426B524A5A4239
5A42396B524A523129392921634231523931634A426342317B6352734A42845242AD846BC68C73\
E7B59CEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6C6F7D6C6F7D6C6F7D6BDF7D6C6
F7D6BDF7D6C6F7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7BDB5EFC6ADEFC6ADEFBDA5EFBDA5E7AD94\
E7B594E7AD94E7B594E7AD9CE7B59CE7B59CE7B59CE7B59CE7B594E7A58CE7AD94
DEAD94DEAD94DEA58CDEA58CDEA58CD6A584D6A58CD6A58CD69C84C69C84CE947BCE947BB58C73\
AD846BA5735A8C5A4A734A42634231634231523129422921392921392921392921
422921392921312121312121291818211010291818312118523129734A39FFFFFFF7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7947B737B635A5A4239634231634A425A423973524A7B635A523931
634A425A42394221185231294229215A42396B524A523931634A42734A39734A399C6B52B57B63\
D6A58CE7B59CEFC6ADF7D6BDF7D6BDF7D6BDEFCEB5F7D6C6F7D6BDF7D6BDF7D6C6
F7D6C6F7D6C6F7D6BDF7CEB5EFCEB5EFCEB5F7BDB5EFC6ADF7C6ADEFC6ADE7B594E7B594E7AD94\
E7B59CE7B594E7B594E7B594E7B594DEAD94E7AD94DEAD94E7A58CDEAD94DEA58C
DEA58CDEA58CDE9C84D6A58CDEA58CD6A58CD69C8CD6A584D6A584CE947BC68C73C68C73BD846B\
A5735A8C5A4A845242634A425A3129523129422921312118312118392921392921
3929213929213929213121213929212918182110103929215A4239734A39F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7B59C9C8C736B634A42634A426B524A634A426B524A73524A634A42
6342315A42395A4239422921523931523931634A42634A425A423973524A6B524A846352A5735A\
CE947BD6A584E7B59CEFCEB5EFC6ADEFCEB5EFCEB5F7D6BDF7D6BDF7D6BDF7D6BD
F7D6BDF7D6BDEFCEB5EFCEB5EFCEB5F7C6ADF7D6BDEFC6ADEFBDA5EFBDA5E7AD94E7B59CE7B594\
E7AD94DEA58CE7AD94DEAD94DEA58CDEAD94E7A58CE7AD94E7A58CDEA58CDE9C84
DEA58CDEA58CDE9C8CDEA58CD6A58CD69C84D6A584D6A584CE947BC69C84C6947BB5846BAD846B\
A5735A845242734A39634231523129422921422921312118312118312121312118
422921392921312121291818211010181010291818523931523129846B5AF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7D6BDC694736B73524A6342316B524A634A42634A4273524A7B635A
5239316B524A5239315239315231295239315A42396B524A634A426B524A634A427B63528C5A4A\
B58C73DEA58CE7B59CE7BDA5EFC6ADEFC6ADEFC6ADF7D6BDF7D6BDF7D6BDEFCEB5
F7D6BDF7BDB5EFCEB5EFC6ADEFCEB5EFC6ADEFC6ADEFBDADEFBDADE7B59CE7B59CE7AD94E7A58C\
E7AD94E7A58CDE9C84DEA58CE7A58CDE9C84E7B594DEA58CDEA58CDEA58CD6A584
D69C73D69C84D69C8CD6A58CD6A58CD69C84D69C84C69C84C6947BC6947BB58C73AD846B9C6B52\
8C5A4A734A39734A395A3129523129422921312118291818291818291818312118
3121182110102110101810101810101810103121185239315A4239B59C9CF7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F78C736373524A6B524A634A426B524A5A4239634A42735A52
634A42634A424A31314A31315239314A31315A42395A42396B524A5A4239634231734A42734A39\
9C6B52AD846BC6947BD6A58CE7B59CE7B59CE7BDA5EFC6ADEFCEB5EFC6ADEFCEB5
EFCEB5EFCEB5EFCEB5EFC6ADEFC6ADEFBDADEFC6ADEFC6ADE7BDA5DE9C84DEA58CDE9C84DEA58C\
DEA58CDEA58CDE9C84DE9C84DEA58CDEA58CDE9C84DEA58CDE9C84DEA58CD69C73
D69C84D69C73D69C84D69C84CE947BC6947BC6947BC68C73B58C73B57B63A5735AA5735A9C6B52\
734A396342315A3129422921523129392921312118312118312118291818291818
291818211010181010181010181010291818523129523931633929F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7FFFFFF9484847B63526B524A734A3973524A634A42634A4A735A52
634A426342315239314229215231295231294A3131634A426B524A73524A524239523129734A42\
734A428C5A4AA5735AB58C73C68C73CE947BD6A58CDEB5A5DEB59CEFC6ADEFC6AD
E7BDA5D6C6B5E7BDA5EFBDA5EFC6ADE7B594EFC6ADE7BDA5E7BDA5DEAD94C69C84D69C84D69C84\
DEA58CD69C84D69C84D69C84D6A584DE9C84DE9C84DE9C8CDE9C84D69C84D69C84
D69C73D69C73D68C7BD68C7BC69C73CE947BC68C73BD846BB5846BA5735AA5735A8C5A4A845242\
734A396342315A3121422921392921312118291818211010291818291818291818
29181821101018101018101018101031212152312952393194736BF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7CEBDC6846B5A73524A5A42396B524A634A42634A42634A42
735A525A42396342315231295231293929216B524A5A42395A42396B524A6B524A73524A523931\
734A427B6352846352846352AD7B6BB57B63C6947BDEAD94C6947BD6A58CDEAD94
DEB5A5DEAD94DEB5A5DEB59CDEB59CDEAD94E7BDA5DEAD94D6A58CCE9473B5846BBD846BBD846B\
CE9473CE8C6BD68C7BD69C84CE8C6BD69C84CE9473D68C73D68C7BD69C84D69C84
D69C73CE947BCE947BC68C73C68C73C68C73BD846BB5846BAD846B9C6B528C5A4A845242734231\
634231523129422921422921211010312118291818291818291818291818291818
211010181010181010181010291818523931422921422921EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7FFFFFF8C73637B635A634A4263423173524A634231634A42
6B524A634A42523129634231523129523129523931523931735A5263524A6B524A634A426B524A\
735A527B6352846B5A8C7363846B5AA5735A947B73B58C73B5846BAD846BB58C73
B58C73B5846BB58C73C6947BD6A584CE8C84D6A58CC6947BAD846BA5735AA5735A9C6B52A5735A\
A5735ABD8463BD846BC68C63BD846BCE8C6BC68C73CE947BCE8C6BCE8C6BC68C73
C68C73C68C73BD846BB58C73BD846BB57B63B57B639C73638C6352845242845242734A39634231\
5A3129422921422921392921291818312118291818211010211010211010181010
1810101810101810102918184A31315231294229218C6352FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7AD8C84846B5A6B524A5A42396B524A634A42634A42
634A426B524A5242395231294A3131523129634231634A42634A426B524A735A52735A526B524A\
7B635A634A42735A52735A527B63528C63529C73639C6B5294736B94736BA5735A
8C73639C7363A5735AA5735AB58C73D6A584B58C73AD846B9C73639C6B529C6B528C635294634A\
8C6352A57352B5735AB5735ABD8463BD8463BD8463CE8C6BBD8463BD846BBD846B
AD735AB57B63B5735AB5846BB57B63AD735A9C73639C6B528C5A4A8452427342315A31295A3129\
523129422921422921312118312118291818291818211010211010181010181010
181010181010181010523129392921422921523129EFD6CEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7D6CEDE947B736B524A634A42634A426B524A63524A
5242397B63525A42395231295231294A3131523931634231735A526B524A7B635A5A5252634A42\
7B635A846B5A7B635A735A528C6352A5735A7B6352846B5A8463528C63528C6352
8C63528C5A4A9C6B528C5A4AA5735AA5735AAD846BA5735AA5735A846B5A846352845242845242\
8C5A4284524294634A9C6B52A57352AD735AAD735AB57B63B57B63AD735AA5735A
A5735AA5735A9C6B52A5735A9C6B529C6B529C6B52845242845242734A396342315A3129523129\
422921422118392921291818291818211010291818211010181010181010181010
1810101810102918184229214A3131392921633931F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7AD9CA573524A634A42634A426B524A5A4239
63524A63524A634A425239313929215239315A42396B524A735A52735A52735A52735A527B635A\
634A427B635A8C7363846B5A8C6352846B5A846B5A7B6352734A4273524A73524A
734A397B6352734A428452428452428463528C6352846B5A73524A7B635273524A73524A845242\
734A428452398452398452428C5A429C6B529C6B529C6B529C6B5294634A846352
9C6B528C5A428C5A4294634A8C63528C5A4A8452427B6352734A395A3129523129523129523931\
392921312118312121312118291818291818181010211010211010181010181010
181010211010422921523129312121633931AD8C84F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DED6E78C736B73524A634A42634A426B524A
5A423963524A735A52634A425239315239316B524A634A427B635A7B635A6B524A846B5A735A52\
634A4273524A7B6352846352846B5A7B63527B6352845242734A395A423973524A
5A4239634A4273524A63423173524A734A397B6352734A39634A42735A52634A42523129634231\
5A42395A4239634231634231634231734A39734231734231734A39734A39734A39
734A396342316342316342316342316342316342316342316339295A3121422921422921392921\
312121291818291818312118312121291818291818181010181010181010181010
291818422921422921312121523931734A39FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE794848473524A634A42634A426B524A
634A42634A42634A426B524A634A425A42396B524A7B635A735A52846B5A7B635A7B635A6B524A\
634A426B524A734A42734A42846352845242734A39734A395A4239634A425A4239
523931523931634A425A423952312973524A634A42634A42634A425242395A42395A4239523129\
5239315239315231295231295A31295A3129634231634231634231634231634231
6342316339295A31296342315A31295239315231295A3129523129523931392921422921312118\
392921291818291818291818291818291818181010181010181010181010211010
4229313929214229215A3129634A42D6C6DEF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7C6ADAD947B736B524A6B524A634231
6B524A52423963524A634A427B635A6B524A5A42396B524A8C736363524A7B635A7B635A7B635A\
7B635A735A527B635273524A734A396B524A734A3973524A523931634A42634A42
524239524239634A426B524A634A42523931634A42634A426342315239314A31315239314A3131\
4229214229215231295231294229214229215A3129422921523129523931523129
523129523129523129422921523129422921523129422921523129422921422921392921312118\
392921291818211010291818181010211010181010181010181010181010392921
3929215231293121215A3129AD847BF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6CEB5A5A56B524A634A426B524A
634A4263524A6B524A634A42634A427B635A7B635A8C736B5A4239735A52735A526B524A5A4239\
5239316B524A73524A8463526342316B524A734A42634A42634A42634A425A4239
5A4239634A4273524A5242394A31314A3131524239523129523129523129523129422921422921\
392921392921422921422921422921523129392921523129422921422921392921
422921523129422921422921523129422921422921312118422921392921312118211010312118\
312118291818181010291818211010181010291818181010181010291818392921
523931312121523129A58484F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFCEBDC694736B6B524A634A42
6B524A634A425239315A423963524A523931735A527B635A7B635A7B635A5242395A42397B635A\
8C73637B6352634A42734A426342315A42395A4239523931523931634A42634A42
5231294229314229315242394A3131422931523129422931523129422931392921392921312121\
392921312121392921392921392921422921312118422921422921523129422931
312118392921392921312118422921312121422921312118312121422921312121392921291818\
291818291818211010181010181010181010181010291818392921392921392921
4229214229218C6352EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6CEBDCE734A42634A42
6B524A6B524A6B524A5A4239634A4263524A524239634A42735A527B635A7B635A735A5263524A\
63524A5A42396B524A734A39523931523931634A425A42394A31315A42395A4239
423139422931524239634A424A3131422931523129392921422931392921392921392921392921\
312121312118312121392921312121392921312121392921392921312118523129
291818312118312118312118422921422921312118312118291818392921312118312118312121\
291818291818291818181010181010291818312121392921312121523931422921
523129845242F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7DECED6846B5A634A42
5A42396B524A6B524A63524A634A4263524A634A427B635A63524A634A42634A427B635A7B635A\
8C736B634A425239316342315231295231295A42395A4239523129634A42523931
5A42394231395242394A31314229213929214229313121213121214A3131392931312121312121\
312121291818291818291818392921392921312118291818392921392921312118
392921312121291818392921291818392921312118291818312121291818211010291818181010\
1810102918181810101810102110102918183121213121215A4239423139523129
734A42EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7947B73846B5A
634A425A42396B524A5A4239634A425242396B524A52423963524A7B635A6B524A634A425A4239\
6B524A523931634A425239315231294229214229215A42395231294A3131523129
4A3131312121422921312121422931523129312121392921291818312121312121422921312121\
291818291818291818312121291818291818392921312121291818291818312121
312121312121392921211010312121291818291818291818181010291818181010181010181010\
1810101810102110103121213121213121183929212918183929214221189C6B52
EFE7E7EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7A5847B
846B5A634A426B524A634A426B524A63524A634A42634A42634A42524239634A426B524A634A42\
524239523129634A425239315231293929214229214A31314A3131422921422931
4A313152394A312121423139422921312121392921312121312121312121392921392921291818\
291818291818312121291818291818291818392921392921291818291818291818
312121312121291818422931312121312121291818211010181010211010181010181010181010\
291818312121392931312121291818422931312121392921523129845242AD9C8C
EFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7CEB5BD
947B737B63525A42396B524A634A4263524A63524A7B635A63524A6B524A735A52735A52634A4A\
5242395231296B524A5239314229213929213929214229214A3131392921422921
4229215242392918184A3131291818392921312121291818312121291818291818312121312121\
291818291818291818312121312121291818312121523129312121181010291818
312121312121392921291818312121291818181010181010181010181010211010291818312121\
422931312121312121312121392921523129422921634231734A39A5735AE7DEE7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
C6ADAD8C736B6B524A634A426B524A5A423963524A5A423963524A5A525263524A634A425A4239\
5242393929216B524A5231294A3131312121392921312121422921422921312121
312118312118291818312121312121291818312121291818312121291818312121291818312121\
291818291818291818291818312121291818312121423139423139423139291818
291818312121312121312121392931312121392921392931392921392921392921312121422931\
3121182918183121214A31314229214229216342316342319C6B5294736BF7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7CEBDCE94736B735A5263524A6B524A5A423963524A735A52735A52735A527B635A735A52\
63524A524239634A425A4239422921422931312121312121291818422921312121
312121312118392921291818392921291818312121291818291818291818291818291818291818\
3929212918181810102918182918183929213121213121215242395A5263634A42
5A5252312121422931312121291818312121312121312121392921422931392921312121312121\
5242395A4239392921523931634231523129734A398C5A4A8C7363F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F78C737B947B73735A526B524A63524A5A4239634A4263524A735A52735A52735A52\
634A4A524239735A525A4239523129523129422921291818312121392921392921
312121291818312118291818392921312121312121211010312121312121291818312121291818\
31212129181829181818101029181829181852394A4231393929395A52527B635A
4229314229314231394231395242394229313929213929213121213929215231295A31295A4239\
4A31315231295239315231296342316342318452429C6B52F7EFEFF7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7FFFFFF8C737B94736B7B635A735A5263524A5A4239634A4263524A635A637B635A\
63524A735A52634A42634231524239523931422921392921291818312121392921
291818312118312118392921312121392921291818312121291818312121312121291818291818\
2918183121212918182918182918182918181810105A525252394A52394A423139
7B635A6B636B7B635A5A4A5A634A4A634A4A735A52634A4A5A4239523129392921392921523931\
5239315239315A42396B524A734A39845242846352F7EFEFF7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F79C8C9C846B5A6B524A63524A6B524A5A4239634A426B524A735A52\
6B636B7B6B7B7B635A5A42395A4239634231523931523129312121312121392921
422921312118312121312118291818392921291818291818291818291818312121291818291818\
29181831212131212118101029181839292131212129181839293152394A634A42
5A52525242393929313121213929214A31315239315A42395A42395A42395A42396B524A634A42\
634A42634A42634231634231734A429C6B52947B73F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F78C6352735A527B635A634A426B524A735A527B635A\
7B635A7B635A8C736B7B635A5239315239315239315239314A3131634A42392921
5242394A3131422921422931392921291818312121291818312121312121291818312121291818\
392921392931312121312121312121392921423139312121422931524239392939
634A42634A4A3121213929213929214229313929213929213121214A3131422921524239523931\
5231296342318452429C6B52945A52DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD8C73636B524A6B524A6B524A63524A735A52\
7B635A8C736B9484848C737B6B524A5A3129523931523931523129523129523931
5A42395A42395A4239422921422931392931523129312121312121312121392921422931312121\
31212152394A3929214231394229313929214229315A5252423139423139423139
3929313929215242395242394A31315A4239524239523931523129634A42634231523129634231\
734A39734A398C5A4A846352DECED6F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6DE8C73636B524A5A4239634A426B524A\
7B635A8C736B8C736B8C7B738C736B7B635A5242395239315231294A3131523129
523129634A42634A425A4239524239735A523121214229212918184A3131423139422931423139\
4A394A5242395242394231397B737B6B524A635A63392931634A427B635A5A5252
634A4A634A42634A42634A42634A425A42395A4239634A42634A426B524A7B63526B524A634A42\
845242A5735A846352F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7948494846B5A735A526B524A\
7B635A8C7B738C7B739C8C8C9484848C7B738C736B73524A7B635A846B5A634A42
5A42394A2118634A42634A42735A525A4A5A634A4263524A5A42393929393121216B636B634A4A\
5A52527B635A7B737B5A4A5A5A4A5A5A52527B635A6B636B635A63735A5263524A
6B524A7B635273524A735A5273524A73524A73524A6B524A5A4239634231734A397B635294634A\
734A42A58484FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7D6C6CE947B737B635A\
7B635A6B524A735A52735A528C737B7B737B8C7B738C736B8C7B738C736B8C736B
8C7B737B635A634A4A6B524A5A52527B635A7B6B7B7B635A8C7B735A5252634A4A4229315A4A5A\
52394A634A4A5A52527B6B7B735A526B524A6B524A634A426B524A735A527B6352
73524A73524A734A42634A42734A39734A396B524A8452428463528C5A4AA5735A7B6352734A39\
CEB5BDF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7B5A5AD\
6B636B735A527B635A735A528C736B9484848C7B738C736B8C736B846B5A8C736B
8C7B738C736B8C736B8C736B635A637B635A735A528C736B6B636B7B635A7B737B5A4A5A52394A\
52394A4231395239315A42397B635A6B524A6B524A6B524A5A42395A4239634231
6342316342315A4239734A428452427B63528463528C5A4A8C5A4A846352734A39734A42D6C6D6\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
CEBDC68C737B7B63527B635A7B635A6B636B8C737B9C8C8C8C7B739484848C7B73
8C7B73846B5A8C7B73947B739484848C7B73947B738C7B738C736B948484735A528C7B737B635A\
6B524A634A4A634A4A5A4239524239634A427B635A735A52634A426B524A6B524A
84524273524A8C5A4A7B63528C63528C73639C7363A5735A845242634A42A58484FFFFFFF7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7E7DEEF6B636B5242526B524A635A637B737BAD94948C737B
9C8C8C9484849C8C8C947B738C736B8C7B73A5847B947B73947B73947B738C7363A5847B947B73\
947B73846B5A846B5A8C736B8C73638C6352846B5A9C6B528C6352846B5A94736B
94736BAD7B6BAD846BAD846B8C736373524A634A42846352CEBDC6F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEE7AD9CB58C7B8C8C7B8CAD9494A594A5
C6B5C6B59C9CB59C9CB59C9CA5847BA5847B947B737B635A947B73A5847BA58484A5847BA5847B\
A5847B947B73947B73A5847B94736B8C736394736B947B73AD7B6BA5847BAD846B
8C7363846B5A8C736373524A73524A8C7363CEB5BDFFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7E7DEEF
EFE7E7D6C6D6C6B5C6BDB5BDC6B5C6AD9494AD9494A58484947B7394736B8C7B737B6B7B8C7B73\
947B73947B73A5847B8C736B94736B8C736B94736B8C736394736B8C7363846B5A
846352846B5A846352947B73AD9CB5FFFFFFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7EFE7E7E7DEEFEFE7E7F7EFEFEFE7E7D6C6D6CEBDC69C8C9CAD94A59C8C9C948484947B73\
947B73947B73947B73947B73A5847B947B738C736B8C736B8C7363846352735A52
846B5AAD94A5F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7EFEFF7F7F7F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7EFEFF7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7EFEF\
E7DEE7DED6E7CEBDC6DECED6D6C6DEEFE7E7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7EFEFF7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7\
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7F7
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[73]:=",
  ImageSize->{450, 450},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720001`R000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo3
0?ooo`007P3oool01@3AdLT0f]SA0=[Hd03He/h0emK>0080emO?00<0f=O@0=SGc`3He/l00P3He/h0
0`3He/l0f=O?0=SGc`020=SGd0/0f=S@2P3Hem020=SGc`80f=K?0P3Hell20=SGd0L0f=S@103Hf=40
3@3HfM80f=[C0=SJe03Hf]<0f=G<0=OCb03Gd<@0f=750=SBa`3Hd/P0f=?80=SCb@3He<X00P3HeL/0
2P3He<X0f=?90=SCb@3HdlX0f=G;0=SEc03He/`0f=G<0=SEb`3IeL/20=WDbP<0fMC90`3He<T02@3H
e<P0f=?80=KBa`3FdLH0eM350=G?a@3DcL<0e<g20=C;`@040=C<`P80d/_100<0dlc20=C=``3Dc/@0
1P3Ec/@00`3Ec/<0eLg30=G<``020=G<`P80dlc10P3Bc<402`3Bbl40d/^o0=;;_P3@bK`0d<Rl0<o9
_`3AcL@0e]O@0=SKe@3Jg]P0f]gG0080fM[C0P3HfM840=SId@070=SHd@3Hf=00f=O@0=SGd03Hf=00
f=SA0=SId@020=SHd@D0f=S@2@3Hem040=OGc`040=WHd03JfM80fMSA0=7AbRX0oooo2@3gmoL00`3g
knl0moOg0?Ogm`060?Ogm`030?O_k`3gmoL0moOg02P0moOg00H0mlje0>o>]@3ge[d0mmJm0?OFaP3g
e[d30?OFaP80mmk>00<0mmK60?ONcP3gg/h02P3gg/h30?OFaP030>o>]@3ge[d0klje0080klje0`3_
aZd0103W_JD0ikFL0>NmY@3N]I`30>NeW0/0gZfD00<0eZF<0=j]U03NYH`00`3FYH`0103NW8@0eZF<
0=JUS03FYH`20=JUQ0030=JLQ03FYH`0mnON01`0moOg00<0mno_0?Ogm`3gmoL00`3gmoL00`3gknl0
moOg0?Ogm`070?Ogmb00oooo000N0?ooo`060=WGd03Yi=`0j>?K0>GQf@3ThMT0i>?K0P3Ui=`01P3U
i=/0iN;J0>GQf@3UhMT0iN;J0>GSf`<0iNCL2`3UiMd;0>GTg0060>GSf`3Uh]X0iN7J0>GSf`3Uhm`0
iNCM1P3UiMd30>GUgP090>GVgP3Ui]l0iNKO0>KWh@3Vj><0i^WT0>KXhP3Vh]P0i]kB0080i][<0P3V
g=020>KMd0040>KOd`3Vh=@0i^3E0>KOe080i]gB00T0i]kC0>KQeP3Vh]L0i^;G0>KReP3WhMD0in3D
0>SOdP3Xgm400P3Xg]020>KNd@0:0>KOd@3Vg]40iMk@0>GMc`3Sf/h0hMW=0>3Gb`3Oe/T0g]?70=kB
aP80g]3500T0gm750=kAaP3MdLD0g=340=_@a03Md/H0g]C80>3FbP3Qe/X00`3QelX00`3Qe/X0hMG9
0>7Db@020>;Cb0030>7Bb03Qd/L0g];600<0gM;600l0gM750=c@`P3Ld<00fLjn0=S=_P3Gd<D0f]K=
0>;Ug`3VjnH0jNoZ0>W^j03Wj^@0inWR0>KXh@3Vin00103Viml20>KVgP80iNGM00<0iNKN0>GWg`3U
iml00P3Ui]h70>GUg@030>GTg@3Ui=`0iNCL00H0iNCL0P3Thm/0103Wi]d0j>OO0>GTg03If=4Z0?oo
o`80moOg0P3gknlD0?Ogm`030?O_k`3gmoL0moOg0280moOg00@0klje0?OF_@3ge[d0mmJm103ge/H4
0?ONcP030?OFaP3gg/h0mmk>0080mmK60P3gg/h00`3ge/H0mmk>0?ONcP030?OFaP030>o>]@3ge/H0
klje00@0klje0`3_aZd01@3W_JD0ikFL0>NeW03W]I`0ikfU00<0gZfD00<0g[FL0=j]U03N[I@00`3N
[I@00`3N]I`0gZF<0=jUS0020=j]U0<0gZF<00D0eZF<0=jUS03FYH`0eZF<0=JUQ0020=JUS080eZF4
00<0aYb40?Ogm`3gmoL0403gmoL00`3gknl0moOg0?Ogm`050?Ogm`030?O_k`3gmoL0mno_00D0moOg
00<0mno_0?Ogm`3gmoL0203gmoLP0?ooo`007P3oool01P3Jf=00kNKN0>gUg@3Yhm/0j>?K0>SVgP80
j>OO00L0j>ON0>WTg03Yhm/0jN?K0>WTg03Yi]h0jNOO0080jNSP00<0jNWP0>WYh@3YjN40203YjN4:
0>WXh0070>WWg`3Yi]h0jN?L0>WSg03YiMd0jNKO0>WXh@030>WYh@<0jNWR0`3Yj^<04`3Yjn@0jN_U
0>W/iP3ZkNP0j^oZ0>[_j`3Zk^P0jnKK0>_Re03[g<`0jm_<0>_Md03ZgM00j]k?0>[Oc`3Zh]<0j^?E
0>[Se`3Zh]H00P3Zgm@02@3ZhMD0j^CH0>[UfP3Zi]X0jnGI0>_Se@3[h]<0jn3>0>_Nc0020>WMb`0F
0>OMc03WgLd0img=0>OLc03Wf//0i]W:0>?Fb03QeLL0g];50=gAa03Lc/40g<g00=g<`03McL00g/g1
0=g>`@3LcL40f/c00=_<`03Md<<0gm;50>;Eb0D0hmK900<0i=?70>CBaP3TdL@00P3Td<D0503Sd<D0
h=740=o@a03Md<<0gLo20=g>`@3Mc;`0g<bj0=W=_03Hcl00f=S?0=cOf@3Vkn/0joCb0>ohm03_m_80
kO;]0>c`j`3[k^P0jnkW0P3ZkNH20>[/i@80j^cT0P3Zjn@0103Yjn@0jNcT0>W[i03Yjn<20>WZhP03
0>WYhP3YjN40jNWQ00<0jNWQ00<0jNSQ0>WXh03Yj>00103Yj>040>SWg`040>_ZhP3]k>@0j>OO0=[I
dRX0oooo2@3gmoL00`3gknl0moOg0?Ogm`040?Ogm`030?O_k`3gmoL0moOg01<0moOg00<0mno_0?Og
m`3gmoL0503gmoL0203_c[D0mmJm0?OF_@3ge/H0mmJm0?OFaP3ge[d0mmK60P3gg/h20?OFaP@0mmk>
00@0mmK60?ONcP3ge/H0mmk>0`3ge/H00`3ge[d0klje0>o>]@020>o>]@030>o6[@3W_JD0klJ]00<0
ikfU00<0g[FU0=jeW03W]I`00`3N]I`30=j]U0030=jUS03N[I@0gZfD00@0gZfD00<0eZF<0=j]U03N
[I@00P3NYH`01`3FYH`0gZF<0=JUS03FYH`0gZF<0=JUQ03FYH`00P3FYH@00`3FW8@0eZF<0=jeW00;
0?Ogm`050?O_k`3gmoL0mno_0?Ogm`3gknl00`3gmoL00`3gknl0moOg0?O_k`0A0?Ogm`030?O_k`3g
moL0moOg00<0moOg803oool001h0oooo00l0fMO?0>_Ug@3[i=`0in3H0>KPf03Uhm/0i^CL0>KUg@3V
i=`0i^;J0>KQf@3Vh=T0i^7J0>KTg03ViMd04P3Vi]h50>OVgP080>OUg@3Whm`0in7J0>OQfP3Whm`0
inCM0>OVg`3Wiml40>OWh0<0inSQ03L0inWR0>OYh`3Wj^@0in[U0>O/j03XkNX0j>kZ0>S/i`3Xi=T0
j=oA0>SIb03Xf<T0j=[<0>SJc@3Xfl`0j=c<0>SOd03Xh=80in3D0>OOe03Xg]80j=kC0>SOd`3XhMH0
j>;G0>SSe`3Xh]H0jN3B0>WOc`3Wg<T0i][70>?HaP3Rf<D0h]S60>;Ha`3SelH0hmK60>;Ca03Qd/<0
g]320=c?`@3IcL00f<bo0=O:_@3Hb[d0fLVm0=W:_@3Jb[h0f/^n0=W:_P3GbKd0elZm0=[<`03Lc/40
g]740080gm;500D0gm;60>3Ba@3Pd/D0h=330>3>`P020>7=`00G0>3=`@3OcL40gLg10=_=`@3Jc<00
f/^n0=[:_03Ib;L0fLRf0=O;^`3Fd<80f=cE0=cSg`3VlNl0j_Gc0>ggm03]m_80jo7]0>[`j`3Yk^P0
jNgW0>S/i@3XjnD00P3Xjn@20>SZh`050>OZh`3Wj^80inWR0>OYhP3WjN400P3Wj>420>OXh0040>OW
h03Wiml0inOO0>OWg`80inKO0P3Wi]h40>KVgP80i^GM00H0iNGM0>KUg@3Yj>00jn[R0>OVg@3If=0Z
0?ooo`h0moOg00<0mno_0?Ogm`3gmoL0203gmoL00`3gknl0moOg0?Ogm`0<0?Ogm`030?O_k`3gmoL0
moOg0180moOg00<0klje0?OF_@3ge[d0103ge[d00`3ge/H0mmk>0?ONcP020?OFaP<0mmk>0P3ge/H2
0?ONcP040?OFaP3ge[d0mmK60?OFaP@0klje0`3_aZd01P3W_JD0g[FU0>NmY@3N]I`0ikfU0=jeW0@0
gZfD00@0eZF<0=j]U03N[I@0gZF<103N[I@01@3NYH`0gZfD0=j]U03N[I@0gZF<0080gZfD0P3NYH`2
0=JUS0040=jUS03FYH`0eZF<0=JUS080eZF400<0eZF<0=K6_@3gmoL0403gmoL00`3gknl0moOg0?Og
m`0I0?Ogmb00oooo000N0?ooo`070=OFcP3XiMd0j>?K0>?NeP3RgMD0hMgE0>;NeP020>;Pf0060>;O
e`3Rg]L0h]kF0>;Oe`3RhMT0h^7J0P3Rh]X0103RhMT0h^3H0>;Pf03RhMT20>;RfP050>;Qf@3Rh=P0
h^3H0>;Qf@3Rh]X00`3Rhm/60>;Rf`030>?Rf`3ShMX0hn7I0080hmoH00@0hn7I0>?QfP3Shm`0hn?L
0`3Si=d20>?TgP80hnGO0P3Si^000`3Sin80hnSS0>CZiP020>C[j0070>CYi03Sgm@0h]W;0>;B`03S
d/00i=C40>CEaP020>CGb0030>CIb`3Tf/d0i=_?00@0i=_@0P3Tg=406@3Ug=40iMc@0>CJb`3Sf<L0
gmC20=_C`03Fd;l0eLno0=O>_@3IcKd0flZk0=c8^P3JaKP0fLBg0=K3]P3D`kH0d/Bg0=;5]`3Aa[P0
d/Ji0=?6^@3DakX0e<Rk0=G8^`3Dak/00P3Da[T01@3Ea[X0eLNj0=K8_03GbK`0elZm00<0f<Zm01`0
f<Rl0=W8^`3IakT0fLNi0=W7^03HakP0e/Ji0=K6^P3EaKT0e<Bg0=C3]@3C`;00dl6a0=G;_@3GdlT0
gNKS0>3^k03Vm_H0j?Of0>Wem03Ym?40j?3/0>O^jP3Vk>L0i^_V0>GZi03UjN@0i>WR0P3Tj>801P3T
j>40i>OQ0>CWh03SiMh0hnCM0>?Sg080hnCM00@0hnGM0>?Tg@3Si=d0hnCL0P3Shm`30>?Sf`80h^;K
0`3Rh]X0203RhMX0h^7I0>7Qf@3RhMX0i^GM0>SWg`3Thm/0emO?:P3ooolm0?Ogm`030>o>]@3gc[D0
mmJm0080mmJm3`3ge/H00`3_c[D0mmJm0?OF_@020>o>]@030=K6]@3_aZd0kkf]00@0ikfU0P3N]I`0
0`3N]JD0g[FL0=jeW0060=j]U0070=JUS03NYH`0eZF<0=j]U03FYH`0gZF<0=JUS0020=jUS080eZF<
00@0gZF<0=JUS03FYH`0gYb40`3FYH`01P3FYH@0eZF<0=JUQ03FYH`0g[FL0?O_kaH0moOg00H0mno_
0?Ogm`3gknl0mno_0?Ogm`3gknl70?Ogm`050?O_k`3gmoL0mno_0?Ogm`3gknl01@3gmoLP0?ooo`00
7P3oool0203Ge/l0j>KN0>SUg@3SgmL0hMcE0>7Le03Qg=D0hMkG1@3QgmL0203Rh=T0h^7I0>;QfP3R
hMT0h]oH0>;Oe`3Rg]L0h]oH0P3RhMT01`3RgmP0h]oG0>;Oe`3Rh=P0h^7I0>;RfP3Rh]/01@3Rh]X3
0>;Rf`80h^7J0P3Rh=T00`3RhMX0h^;K0>;Sg0020>;Sg0040>;Sg@3Ri=d0h^CM0>;TgP80h^GO00D0
h^KP0>;Vh@3Sin80hnSS0>?YiP020>?[j0030>?Xh`3QgM80hMO80080hM2m00P0hm?10>CDa03Te/L0
i=K80>?GbP3Sf</0hmW>0>?Jc`80hm_@0240hm_?0>CJc`3Tf/l0i=[>0>CJc@3Sf<T0h]K60=cC`@3H
dL00d/jo0=7=_P3Dbk/0elZj0=[6^03Ja;H0fL2d0=No/`3D_k80dl2b0=72]03A`kD0dLFg0=;5^03C
a[T0dlNj0=C7^`3Db;/0e<Nj0=C5^@3DaKP0dlBg0=?4^03DaKP00P3Da[T30=G7^P040=K6^@3FaKP0
e/Fg0=K5]P80e/Fe01H0eLBg0=C4]`3C`kH0dl:e0=;0/P3A_Zh0d[n_0=G;_`3Ie/d0hNcZ0>Ccl`3X
nOT0jOSh0>Wem03Xlo40io3]0>O_j`3Vk>P0iN_W0>GZi@3TjN@0i>WS0P3Tj>80203Sj>40hnOP0>?V
g`3Shmd0hn;L0>?Rf`3Shm`0hnCL0P3Ri=d00`3Ri=`0h^?L0>;Sg0020>;Sf`80h^;K0`3Rh]X02P3R
hMX0hN7I0>7Qf@3QhMT0hN3I0>7Qf@3UiMd0j>OO0>CSf`3GellZ0?ooo`H0moOg00@0mno_0?Ogm`3g
moL0mno_2@3gmoL00`3gknl0moOg0?Ogm`0W0?Ogm`80klje00@0mmJm0?OFaP3ge/H0mmJm103ge/H0
0`3gg/h0mmK60?ONcP070?OFaP050>o>]@3Fa/H0klje0>o>]@3Fa[D00P3__Jd30>NmY@80g[FL0`3N
[I@20=jeW00@0=jeY@3FYH`0eZF<0=JUS03N[I@0eZF<0=jUS03FYH`0gZF<0=JUS03NYH`0gZfD0=jU
S03FYH`0gZF<0=j]U080gZF<0P3FYH`30=jUS0060=JUS03NYH`0eZF40=JUS03FYH@0e/Jm5@3gmoL0
0`3gknl0moOg0?Ogm`0F0?Ogmb00oooo000N0?ooo`050=OHd03YjN40j>SP0>?Pf03RgMD00P3Qfm<0
0`3Qg]H0hMoG0>7Qf@050>7Qf@030>;QfP3RhMT0h]oH0080h]kG00@0h]oG0>;Pf@3Rh=T0h]oG0P3R
g]L00`3Rh=P0h^7I0>;Rf`0=0>;Rf`040>;Rg03Rhm`0h^?L0>;Sg@80h^CM0P3Ri=h05`3RiMl0h^GP
0>;Vh03Ri^40hnOR0>?Xh`3Sj>@0hn[W0>?[j@3SjnP0hnSS0>7Kd03PeLH0h<fj0>7=^@3SdKl0hm?2
0>CEa`3TeLP0hmG90>?FbP3Sel/0hmS=0080i=[?01T0i=[>0>CHc03Tf<`0i=S:0>CGbP3Se/L0h]G5
0=cC``3Id/<0dm320=;?`@3Ec;d0elZk0=_4^03K`KL0f[fd0=Rl/P3E_;00dkf_0=:o/03C`;80dl:e
0=C3]`3EaKT0eLJj0080e/Jk00D0e/Fj0=G2]`3E`KD0d/2d0=70/`020=31/`80dL:d0P3B`[@20=;2
]@0T0=;2/`3B`[80dl:a0=?2/P3D`k<0e<:d0=?1/`3B_k40dKf^0<njZP3@_:`0elc00=cId@3Wlo80
j__k0>cmoP3[no/0jOKe0>SdlP3WlNl0io3]0>K^jP3VkNT0iN_W0>G[iP3Tj^@0i>WT0>CYh`3Tj>80
hnOQ0>?Vh03Si=d0hn?L0>?Rg03Shm`0hnCM0P3SiMh20>;Tg@80h^?L0P3Rhm/20>;Rf`<0h^;J00T0
hN7J0>7Qf@3QhMT0hN7I0>;Qf@3ViMd0j>OO0>GTg03Gell0:P3oool00`3gmoL0mno_0?Ogm`040?Og
m`030?O_k`3gmoL0moOg00l0moOg00<0mno_0?Ogm`3gmoL03`3gmoL00`3gknl0moOg0?Ogm`0?0?Og
m`030?O>]@3ge[d0mmJm0080mmJm0`3ge/H00`3gg/h0mmK60?OFaP020?OFaP030?OF_@3ge/H0mmJm
0080klje00D0mmK60>o>]@3g_KD0klje0?Nm]@040>nm[@@0ijfL00L0gZfD0=jLS03NW8`0gZfD0=je
W03N[I@0gYb<0080g[FL00@0eZF<0=jeY@3FYH`0gZF<103FYH`0103NYH`0eZF<0=JUS03FYH`20=j]
U0030=JUS03NYH`0eZF<00@0eZF<00@0eZF40=JUS03FYH`0eZF<5@3gmoL01@3gknl0moOg0?Ogm`3g
moL0mno_0080moOg00<0mno_0?Ogm`3gknl01`3gmoL00`3gknl0moOg0?O_k`060?Ogmb00oooo000N
0?ooo`050=OHd03Yj^40j>SP0>?Qf@3Rg]H00P3Qfm<00`3Qg]H0hMoG0>7Qf@040>7Qf@070>7QfP3R
hMX0h^7I0>;Pf03RgmP0h]oG0>;Pf0020>;Qf@050>;Pf03RgmP0h]oH0>;Pf@3RhMX02`3Rh]/00`3R
h]`0h^?L0>;Sg0020>;Sg080h^?M0`3Ri=h20>;Ug`0<0>;Vh03Ri^40h^OR0>?WhP3Sj>@0hnWU0>?Z
j03Sk>T0hn_X0>?Xh`3Qfll0hMC50P3QcKT0103SdKl0hm;20>CDa`3Te<P20>CEb@030>CFb`3Tel`0
i=W=0080i=W=0P3Tel/07`3TelT0i=O80>CFa`3Re/H0g]C60=cDaP3Gd/H0e]740=S>_`3Ic;d0g<Jj
0=g3^@3M_kL0fkfe0=Jm/03E_Jl0e;j_0=Bo/03E`K@0e/:e0=O3^03Ga;X0elFj0=S4^P3G`[T0e[ne
0=Fm/`3B_K80dKja0<no/@3?`;800P3@`;820=70/`80dL6c00@0dL6b0=71/@3B`K00dl6a0P3D`[<0
5@3C`;40d[j_0=6l[03?^:P0d;Z[0=O;`03MfM40j?Cc0>_ko03/o_l0jo_l0>Wfm@3YmO<0j?;_0>Oa
kP3Vkn/0i^kZ0>G/j03UjnL0iN[U0>CZi0020>CYh`070>CXhP3Tin40hnGN0>?Tg@3Shmd0hnCM0>?T
gP020>?UgP80h^CM00D0h^CL0>;Sg03Rhm`0h^?L0>;Sf`020>;Rf`80h^;J00T0h^7J0>7QfP3QhMT0
hN7I0>;QfP3ViMd0j>OO0>GTg03Gell0:P3oool00`3gknl0moOg0?Ogm`0j0?Ogm`030>o>]@3ge[d0
mmJm00<0mmJm00<0mmK60?ONcP3ge/H01@3ge/H20>o>]@80mmK60P3ge[d00`3Fa/H0mkfe0>o>]@02
0?Nm]@060>nm[@3_c[D0kkFU0>nmY@3W]I`0ikfU0P3W[I`0103NW8`0gZfD0=j]U03NW8`30=j]U004
0=jeW03FYH`0g[FL0<J]Y@L0eZF<00H0gZfD0=jUS03NYH`0gZfD0=JUS03NYH`40=JUS0040=JUQ03F
YH`0eZF<0=JUQ140moOg00<0mno_0?Ogm`3gmoL0603gmoL00`3gknl0moOg0?Ogm`0P0?ooo`007P3o
ool01@3Hf=00jN[Q0>SYh@3Th]X0h]kG0080hMcD00<0hMkG0>7Pf03QhMT00`3QhMT20>7QfP80h^7J
0`3RhMT00`3RhMX0h^;J0>;RfP030>;QfP030>;RfP3Rh]/0h^;K00D0h^;K0P3Rhm/50>;Sg080h^?M
0P3Ri=d20>;TgP80h^GO00h0h^GP0>;Vh03Ri^40h^KQ0>?Wh`3Sj><0hnSU0>?Yi@3SjnP0hncZ0>?[
j03Sj><0hm_?0>?Da@80hlfi00L0hm2o0>CB`P3TdlD0i=C60>CDa`3Te<P0i=G90080i=K:0P3Tel/0
8`3TelX0i=O90>GGa`3UelL0iMS80>CHb@3Sf<`0hmW=0>7Hc@3Pf</0gmG60=oCa03QcL80h/[10>75
_P3O`k/0fl6d0=W0/P3H_jl0fKj`0=Zo/P3J`;@0fl6g0=_1^03K`[T0fl2h0=Zn]`3H^k<0e[Va0=>j
[`3A^Zl0d;b_0<nl[`3@_K00d;ja0080dKnb01/0dKna0=2o/@3A_Zl0dKj_0=:n[`3C_k00eL6a0=K1
/@3D_Zl0d[b/0=2iZ@3>]jH0ckVX0=K:_P3Lf=00j??a0>_jn`3/oOh0jo_k0>WgmP3YmO@0j??`0>Oa
k`3Wkn`0i^o[0>K]j@3Uk>P00P3UjnH01@3Tj^@0i>WT0>CXh`3Tj>80i>OQ0080hnKP0P3Si]l0103S
iMl0hnGN0>?UgP3Si=d20>;Tg@<0h^?L00<0h^?K0>;Rf`3Rh]/00P3Rh]X0203RhMX0hN7J0>7Qf@3R
h]X0i^GM0>WXh03Ui=`0f=O@:P3oool50?Ogm`030?O_k`3gmoL0moOg01T0moOg00<0mno_0?Ogm`3g
moL0603gmoL00`3gknl0klje0?O>]@040?OF_@030?OFaP3ge[d0mmJm00<0mmK600<0mmJm0?OFaP3_
e/h00P3_c[D04@3ge[d0klje0>o>]@3ge/H0mmJm0>o>]@3ge/H0mmJm0>o>]@3ge[d0kkf]0?Nm]@3_
_Jd0kkFU0>NeW03W[I`0ijfD0080gZfD00L0ijfL0>neY@3W[I`0ijfL0=jeW03N[I@0gYb<0080eZF<
00<0gZfD0=jeW03FYH`00`3FYH`00`3FYH@0eZF<0=JUS0040=JUS0030=jUS03FYH`0eZF<00<0eZF<
00<0gZfD0?Ogm`3gmoL03P3gmoL01@3gknl0moOg0?Ogm`3gmoL0mno_0080moOg00<0mno_0?Ogm`3g
moL01@3gmoL00`3gknl0moOg0?Ogm`0=0?Ogmb00oooo000N0?ooo`050=SHd03YjN40j>WP0>CRfP3R
gmL00P3QgMD00`3QgmL0hN3H0>7Qf@020>7Qf@80hN7J00<0h^7J0>;RfP3Rh]X01P3Rh]X80>;Rf`<0
h^?K1P3Rhm`20>;Sg@80h^CM0P3Ri=h20>;Ug`0?0>;Uh03Ri^00h^KP0>;Vh@3Rin80hnOS0>?Xh`3S
jND0hnWV0>?[j03Sk>X0hn_X0>?Xh`3Sg=00hmG50080hlfi00L0i=2o0>CA`@3Tdl@0i=?40>CDaP3T
e<L0i=G80080i=G90`3Te/X01P3Te/T0iMO70>GGa`3Uf<T0iMW;0>GKc`80iM_@00T0i=_>0>;HbP3R
e/P0h]750>?>a03RbL00hLJm0=g3]`3K`K@00P3K`;402`3L`;<0g<6d0=g1]`3M`KP0g<6h0=bo^03K
_[L0f[bd0=Rk/P3D^Zl0dkV^0080d;V]02P0dK^_0=6m/@3A_k<0dL2d0=6o/P3@_k00d;f^0=6m[P3C
_Jh0e;j_0=Jo/03F_jl0dkf]0=:kZP3@^JP0c[NU0<niZ03Gbkh0g=S?0>Obl03Zn_X0k?gm0>_kn`3Y
moH0jOGd0>Scl@3Wl^l0io3]0>K_j`3VkNT0i^gX0>G/i`3UjnH0iN[U0>CZi03TjN<0i>SS0>CXhP3T
in40hnOQ0P3Si^00103Si]l0hnGO0>?UgP3SiMh20>;Tg@<0h^?L00<0h^?K0>;Rf`3Rh]/00`3Rh]X0
1`3RhMX0hN7J0>;RfP3Vi]h0jNSP0>GTg03Hem00:P3oooll0?Ogm`030?O_k`3_c[D0mmJm00@0mmJm
0`3ge/H20?OF_@030?OFaP3ge[d0mmK60080klje00L0mmK60=K6aP3ge[d0mmJm0>o>]@3ge[d0mmK6
0080mmJm00D0mmK60?OF_@3_c[D0klje0>nm[@020>nmY@050>neY@3W[I@0ijfD0>N]U03W[I`00`3W
_JD20>N]W080gYb<0P3FW8`00`3N[I@0g[FL0=JUS0030=JUS0060=j]U03NYH`0gZF<0=j]U03FYH`0
gZF<1P3FYH`00`3N]JD0moOg0?Ogm`0A0?Ogm`030?O_k`3gmoL0moOg01T0moOg803oool001h0oooo
00D0f=S@0>WYh@3Yj>00i>?K0>;Qf@020>7Of0030>7Pf03QhMT0hN7I00<0hN7J00<0h^7J0>;RfP3R
h]X00`3Rh]X50>;Rf`H0h^?K203Rhm`20>;Sg@80h^CM0`3Ri=h20>;Ug`040>;Uh03Ri^00h^KQ0>;V
h@80hnOR01D0hnSS0>?Xi03SjND0hn[V0>?[j@3Sk>X0hn_Y0>?Xi03TgM40i=O70>C?^P3Tc[T0i=2l
0>CA_@3Td/00i=?10>CC``3Te<D0i=C70>CDb03TeLP00P3TeLT07`3Te/T0iMK90>GGb@3UelT0iM[<
0>KKcP3Vg]80i]kC0>OOd`3Wg]80i]c?0>GJcP3Te/X0hmC80>;?``3QcL40glRl0=o6^P3Oa;L0glBf
0>35]`3PaKP0glFi0=o3^@3N`[P0gL2g0=k1^03N`[L0gL6f0=Vl/@3F^Jl00P3C]:/09@3C]jh0e;Za
0=C1]`3C`[P0dL6d0=6o/@3A^j`0d[^[0=BkZ`3E^j/0e[^[0=FkZP3B^JP0dKRW0<ngYP3?^:H0dKb[
0=W>`@3Nfm40io;`0>[in03[o?`0jo[j0>WgmP3YmO@0j??a0>Sbl03Wl>d0io3/0>K^jP3VkNT0iNcX
0>G/i`3UjnH0iN[U0>CYi03TjN<00`3Tj>80103Sin40hnOP0>?Vg`3Si]l20>?UgP040>?TgP3Si=d0
h^CM0>;Tg@80h^?L0P3Rhm/20>;Rf`80h^;J00H0h^7J0>;RfP3Vi]h0jNSP0>GTg03Hem0Z0?ooo`03
0?O_k`3gmoL0moOg01@0moOg00D0mno_0?Ogm`3gknl0moOg0?O_k`030?Ogm`030?O_k`3gmoL0mno_
01X0moOg00<0mnOW0>o>]@3ge[d00`3ge[d20?OFaP80mmJm00<0klje0?OFaP3ge[d00P3ge/H20>o>
]@80mmk>0P3ge/H20?ONcP80mmK60P3ge[d01@3ge/H0mmJm0?OF_@3__JD0kkf]0080klJ]00P0kkf]
0>NeW03__JD0ikfU0>N]W03_]JD0ikFL0>nmY@80ikFL00P0ijfL0=jUS03NYH`0gYb<0=j]U03FYH`0
g[FU0=j]U0<0eZF<00<0gZF<0=JUS03FYH@00P3NYH`01P3FYH`0eZF40=JUS03FYH`0gZfD0=k>eRl0
moOg803oool001h0oooo00D0f=O@0>WYh03Yj>00i>?K0>;Qf@020>7Pf@<0hN7I0`3QhMX60>;RfPD0
h^;K1P3Rhm/70>;Sg080h^?M0P3Ri=d30>;TgP80h^GO0P3RiN030>;Vh@0F0>?WhP3Sin<0hnST0>?X
i03SjND0hn[V0>?[j@3Sk>X0i>cY0>CYi03Tg]80i=S80>C@^P3TckP0i=2j0>CA_03Td[h0i=:o0>CC
`P3Tdl@0i=C60>CDa`80i=G801D0i=G90>GFb@3Ue/T0iMO:0>GHb`3Uf/h0i]c?0>KNdP3Vgm<0imoD
0>OOd`3VgM40i]c@0>GIc03TelT0h];50>7@``3Qbkl0h<Vm0>37^P3PakT00P3Qb;T0<@3Pa[X0h<Fi
0=o3^03N`[P0gl>h0>35^@3Oa;P0fkfc0=Ri[`3E/j/0e;>[0=Bf[P3E^[40eL6g0=C3^03B`KD0dKnb
0=6k[03B^Z/0e;ZZ0=FiZP3E^JT0e;RX0=6gYP3@]ZD0ckJU0=2jZ03B_jh0f]740=oMe03Xl_00j_Wh
0>_ko03Zn_X0jOKe0>Wem03Xlo40j?;`0>OakP3Wl>d0i^k[0>K^jP3Uk>P0iNcW0>G[iP3Uj^D0i>[T
0>CYi03Tj><00P3Tj>800`3Sin00hnKP0>?Vg`020>?Ug`80hnGN00<0hnCN0>;Tg@3Ri=d00`3Rhm`0
0`3Rhm/0h^;K0>;Rf`020>;RfP060>;QfP3Rh]X0i^KN0>WXh03Ui=`0f=O@:P3oool?0?Ogm`030?O_
k`3gmoL0mno_02X0moOg00<0mnOW0?O>]@3ge[d00P3ge[d20?OFaP040?OF_@3ge/H0klje0?OFaP<0
klje00<0mmK60>o>]@3ge/H0103ge/H20?ONcPD0mmK600H0mmJm0>o>]@3_aZd0klJ]0>nmY@3_aZd2
0>nmY@070>nm[@3__JD0kkFU0>NmY@3W[I`0kkFU0>NeW0020>N]W080gYb<00H0gZfD0=jLS03FYH`0
gZfD0=jeY@3N[I@30=JUS080gZF<103FYH`0103FYH@0eZF<0=jeW03gimh_0?Ogmb00oooo000N0?oo
o`050=SGd03Yj>00jNSP0>CSg03Rh]X01`3QhMX60>;RfPH0h^;K0`3Rhm/80>;Sg0030>;Sg@3Ri=d0
h^CM0080h^CM0P3Ri=h0103RiMh0h^GO0>;Ug`3RiMl20>;Vh00I0>;Vh@3Rin40h^OR0>?Wh`3Sj><0
hnST0>?Yi@3SjNH0hn[W0>?[j@3Sk>X0i>cZ0>CZi@3Tgm<0i=W80>C@^P3TckP0i=2i0>C@^`3TdKh0
i=:o0>CB`@3Tdl80i=?30>CDa@020>CDa`0;0>CEb03Ue/T0iMK:0>GHc03UfLd0iM_?0>KKc`3Vg=00
i]gA0>KMdP3Wg]800P3Wg]<0203Vg=00iM_>0>CHbP3Te/P0i=;50>CA``3Sc[l0h/fn0P3Rbk`0=03R
bK`0hLNk0>76^P3PaKT0h<Ji0>37^@3Oa[P0g;nd0=^k/@3H]Zd0e[J]0=Fh[@3E^Zl0eKjc0=G0]03D
`;D0dl2d0=:m/03B^jd0d[RX0=:gY`3A]ZD0dKFT0<ndXP3>]:<0ckJU0=>o[`3Ga[P0gmW?0>?Sg@3Y
m?80j_Sh0>_jnP3ZnOT0jOKe0>Wem03Xlo40j?;`0>OakP3Wl>d0i^o[0>K^jP3VkNT0iNcX0>G[i`3U
jnH0i>[U0>CZi03TjN<0i>SR0>CWhP3TiMl20>?TgP030>?UgP3SiMl0hnGO0080hnGN00<0hnCM0>;T
g@3Ri=d00`3Rhm`00`3Rhm/0h^;K0>;Rf`030>;RfP040>KVgP3Yj>00iNCL0=SGd2X0oooo3P3gmoL0
0`3gknl0moOg0?Ogm`0[0?Ogm`030?OWgP3ge[d0mmJm0080mmJm00L0mmK60?OF_@3_c[D0klje0?OF
aP3_c[D0mmK60080mmJm103ge/H20?ONcP040?OFaP3gg/h0mmk>0?ONcP80mmK600/0mmk>0?OFaP3g
e/H0mmk>0>o>]@3g_KD0klje0?O6[@3_c[D0kkf]0>nmY@020>nm[@030>nmY@3_]JD0kkFU0080ikFL
0`3W[I`01@3W[I@0gYb<0=j]U03NW8`0eZF<0080g[FL0P3FYH`20=j]U0030=jUS03FYH`0gZfD0080
eZF<00<0gZfD0?Nm]@3gmoL0;`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Ti=`0h^;J00H0
hN7J1P3Rh]X60>;Rf`<0h^?K203Rhm`20>;Sg@<0h^CM0`3Ri=h30>;Ug`0G0>;Uh03Ri^00h^KQ0>;V
h@3Rin80hnOR0>?Wh`3Sj><0hnST0>?Yi@3Sj^H0hn[W0>?[j@3Sk>X0hn_X0>?Xh`3Sg]40hmS70>?@
^@3TckL0i=2i0>C@^`3TdKh00P3Td/002`3Tdl40i=?20>CC``3Te<H0i=C70>CEb03Ue/T0iMO:0>GI
c@3Uf/h0iM_?00<0i]_?04D0i]cA0>KMd@3Wg]<0imoD0>KNdP3VgM00iM[<0>GIb`3Ue/L0iMG50>CA
`@3Sckl0h/fn0>;;_P3RbKd0h/Rl0>;8^`3QakT0h<Ni0=o7]`3OaKL0gL2d0=^m/P3I^Jl0ekR^0=Ji
[@3E^Zd0eKb_0=Fm/03D_k<0dl2d0=:n/@3A_:h0d;NX0=2fY@3?]:<0ckBR0<jcX@3>/j80ckJU0=C1
/`3Ib[h0hMgF0>CVhP3YmO@0j_Sh0>[jnP3Zn?P0jOKe0>Wel`3Xlo40j?;`0>OakP3Wl>d0i^o[0>K^
jP3VkNT0iNcX0>G[i`3UjnH0iN[U0>CZi@3TjN<0i>SS0>CWh@3TiMl0i>CN0>?Tg@3Si=h00P3SiMl2
0>?UgP80hnCM00@0h^CM0>;Sg03Rhm`0h^?L0P3Rh]/40>;RfP040>KVgP3Yj>00iNCL0=SGd2X0oooo
00<0mno_0?Ogm`3gmoL01`3gmoL00`3gknl0moOg0?Ogm`060?Ogm`030?O_k`3gmoL0moOg00`0moOg
00<0mno_0?Ogm`3gmoL05`3gmoL0103_e/h0klje0?OF_@3ge[d20?OFaP040?OF_@3_c[D0mmK60>o>
]@80mmJm103ge/H60?ONcP030?OFaP3gg/h0mmK600@0mmk>00H0mmK60?OF_@3ge[d0mkfe0>o>]@3g
aZd20>nm[@030>nmY@3__Jd0kkf]0080kkFU0P3W]I`0103W[I`0ijfD0>N]U03NW8`20=j]U0080=JL
S03FYH`0gZfD0=jeW03FYH`0gZfD0=jUS03N[I@20=JUS0050=j]U03FYH`0eZF<0=j]U03Fa[d0503g
moL00`3gknl0moOg0?O_k`0@0?Ogm`030?O_k`3gmoL0mno_00H0moOg803oool001h0oooo00D0f=O@
0>WXh03Yj>00i>?L0>;RfP040>7QfPP0h^;J1@3Rh]/30>;Sf`L0h^?L0P3Rhmd30>;Tg@<0h^CN00H0
h^GN0>;Ug`3RiMl0h^GO0>;Uh03Ri^020>;Vh@050>;WhP3Sin80hnOR0>?Xh`3Sj>@00P3SjND0303T
jnP0iNcY0>C[j03SjNH0h>7L0=oMeP3PeLL0hM;00>??^@3TckP0i=2j0>C@_080i=6o00d0i=:o0>CB
_P3Tdkl0i=?10>CDa@3Te<L0iMG80>GGbP3Uf</0iM[=0>GKcP3Ufll0i]_>0080i][>03P0i]_@0>KL
d@3Wgm@0in3D0>OOe03Wg]<0imc@0>SLc`3Xfl`0im[:0>GFa@3Tdl80i<no0>C=_`3Tbkh0i<Zm0>?:
_03RbKT0hLRh0=o6]P3Na;D0gL2d0=fn/`3K_;40fKb`0=Nk[03F^ZX0eKRX0=BhZ@3C^jh0dkf`0=6l
[`3?^j`0c[JU0<jdX`3>/Z00cK6O0<baWP3=/Z00c[JU0=K6^P3KdLP0i>GQ0>K/jP3Ym_H0j_Sh0>[i
n03Zn?L0jOKd0>Sel`3Xlo40j?;`0>OakP3Wl>d0i^o/0>K^j`80i^gY00T0iNcW0>G[i`3Uj^H0iN[U
0>CYi03Tj><0i>OR0>CUg`3Ti=h00P3Si=h20>?Vg`060>?Ug`3SiMh0hnGN0>?Tg@3Rhm`0h^;L0P3R
hMX20>;Qf@80h^7J00H0h^;J0>?Rf`3Wi]h0jNSP0>GTg03Hem0Z0?oooc`0moOg00<0kmK>0?OF_@3g
e[d00P3ge[d0103_c[D0mmK60>o>]@3ge/H20?OF_@H0mmK60P3gg/h00`3gimh0mmk>0?OFaP080?ON
cP80mmK600d0mmJm0>o>]@3_c[D0mkfe0>o>]@3g_KD0kkf]0>nmY@3_aZd0kkfU0>NeW03W[I`0ikFL
00<0ijfD00<0ijF<0=jUS03NW8`00P3NYH`0303N]I`0gZfD0=j]U03NYH`0eZF<0=j]U03FYH`0gZF<
0=j]U03FYH`0gZfD0=k>eS00moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>CL0>;RfP020>7Q
fP030>;QfP3Rh]X0h^;J00H0h^;J1P3Rh]/20>;Sf`P0h^?L00@0h^?M0>;Tg@3Ri=d0h^CM103Ri=h4
0>;Ug`80h^KP0P3Ri^401@3Rin80hnOR0>?Wh`3Sj><0hnST0080hnWU00`0i>_X0>G/j@3Tj^L0hNGQ
0=cIdP3KdlX0gLjo0=o>^`3Sc[P0i<ni0>C@^`3Td;d20>CA_P090>CB_P3Td[d0i=>o0>CC`03Te<D0
iMG70>GFb03Uel/0iMS;0080iM[=0340iM[>0>KKcP3Vfll0i]_?0>KLd03VgM40imoD0>OPe@3Wgm@0
imkC0>SMd@3Xg=00j=c>0>SKc03VelH0i]G30>G@`03Uc[l0iLbn0>G;_@3Tb[/0hlVi0>;9^03Pa[H0
glFe0=k1]03M_k<0fkba0=Zl[`3H^j/0ekZY0=FgYP3D]jH0d[VZ0=6j[03?^Z`0c[VZ0<feY03=/j80
c[:P0<jaWP3=/9d0cK:O0<jfY@3Fb;d0fm?<0>CWi@3Wknh0jOOg0080j_Sh00T0jOOf0>Wem03Xm?<0
j??a0>Sbl03WlNh0io3]0>K_k03Vk^/00P3VkNT02`3Uk>L0iN_W0>G[iP3Uj^D0i>WT0>CYh`3Tj>80
i>GP0>CUg`3Si=h0hnGO00<0hnKO00L0hnGO0>?UgP3Si=d0h^?L0>;Rf`3Rh=T0h^3H0080h]oH00P0
h^7I0>;QfP3Rh]X0hn;K0>OVgP3Yj>00iNCL0=SGd2X0oooo>`3gmoL00`3ge/H0mmJm0>o>]@020?OF
_@<0klje00<0mmK60?OF_@3ge[d00P3ge/H00`3gg/h0mmK60?OF_@060?ONcP<0mmK61@3gg/h20?OF
aP<0mmJm0`3_c[D01P3g_KD0kkfU0>nmY@3__JD0ikFL0>neY@H0ijfD00D0gYb<0=jUS03NYH`0gYb<
0=JUS0030=jeW080eZF<00H0gZF<0=j]U03FYH`0eZF<0=j]U03_inL@0?Ogm`030?O_k`3gmoL0moOg
01d0moOg803oool001h0oooo00@0f=O@0>WXh03Yj>00i>CL2`3Rh]X60>;Rf`80h^?K1`3Rhm`20>;S
g@<0h^CM0`3Ri=h0103RiMh0h^GO0>;Ug`3RiMl20>;Uh00E0>;Vh03Ri^40h^KQ0>;WhP3Sin80hnOS
0>?Xh`3Sj>@0hnWT0>?Yi@3RjND0h>ST0=oVhP3JgMP0emG?0=?5^@3C`;80fL>_0=g7/P3Sc[P0i<nk
0080i=2n00T0i=2m0>CA_@3TdK`0i=:l0>CB_`3Td/00i=C50>GEa`3UelT00P3UfL`20>GHb`060>GI
c03Vf/d0i]c?0>KMd03Vg]80i]oB0P3Wh=@0@03Wg]<0imgB0>SLd@3Xg=00j=c?0>SLc@3XfLP0j=O6
0>SC`@3XdL00ilfm0>K<^`3Ub[X0hlRh0>;8]`3RakH0hLFf0=o1/`3M_[80fk^^0=^k[03I^JT0f;RW
0=FfY03C]J@0dKFT0<neY03=]J@0c;BS0<fcX@3=/Z40ck:O0=2aWP3>/9d0c[:O0<ngYP3Gbl40g=SA
0>C/j`3Wl_<0jOOh0>[hn03YmoL0jOKe0>Sel`3Xm?80j??a0>Obl03WlNh0io3]0>K_k03Vkn/0i^gZ
0>K]j@3Uk>P0iNcW0>G[iP3Uj^D0i>[T0>CYi03Tj><0i>OR0>CWh@3Ti^030>?Vh0060>?Vg`3SiMl0
hnGN0>?TgP3Sh]/0h^7J0P3Rg]L02P3RgMH0h]kG0>;Pf03RhMT0h^;J0>?Rf`3Wi]h0jNSP0>GTg03H
em0Z0?ooo`030?Ogm`3gknl0moOg00/0moOg0P3gknlZ0?Ogm`030>ONi`3N]JD0klje0080mmJm00D0
klje0?OFaP3ge[d0mmK60?OF_@020?OFaP040?OF_@3ge/H0mmK60?OF_@<0mmK600D0mmk>0?OFaP3g
g/h0mmK60?ONcP020?OFaP<0mmk>00<0mmK60?ONcP3ge/H00P3gg/h01`3ge/H0mmJm0?O>]@3g_KD0
klJ]0?O6[@3_aZd00`3__JD20>NeW080ijfL00D0ijfD0>N]W03W[I@0gZfD0>NUS0020=jUS080eZF<
00L0_JFL0=JUS03N]JD0aZfU0=JUS03N[I@0eZF<0080gZfD00<0knOW0?Ogm`3gmoL04@3gmoL00`3g
knl0moOg0?O_k`0<0?Ogm`040?O_k`3gmoL0moOg0?O_k`X0moOg803oool001h0oooo00@0f=O@0>WX
h03Yj>00i>CL2P3Rh]X60>;Rf`<0h^?K1`3Rhm`00`3Rhmd0h^CM0>;Tg@020>;Tg@<0h^CN00D0h^GN
0>;Ug`3RiMl0h^GO0>;Uh0020>;Vh00G0>;Vh@3Rin40h^OR0>?WhP3Sin<0hnSS0>?Yi03SjND0hn[V
0>;Yi@3Kh]h0emgH0<o?b03=b;l0cKb^0=2jZP3I`J`0gLJ`0>?>^03Tck/0i=2n0>C@_`3Td;h00`3T
dKd01@3Td[l0i=;10>CDa@3UeLL0iMO90080iM[<00H0iMS;0>GGbP3Uf<X0i]W;0>KLcP3VgLl20>KO
dP80imoC03d0imgB0>OMd@3Xg=00j=c@0>SLcP3Xg<d0jM[90>WHa`3Xe<80j=700>K=_03Ubk/0i<Vi
0>?8]`3SakL0h/Jf0>75]@3O`K80gKj`0=^k[03J^ZX0fKRW0=NgY@3E]J@0dkBS0=2cXP3?/j80cK:Q
0<bbX@3</Z00cK:P0=2cX03@/Yl0ck6N0<ncX03@^:L0f<g30=gJe03Uk^h0ioCd0>Whn03Zn?P0jOOf
0>Wfm@3XmO<0j?Cb0>Scl03Wl_00io7^0>O`k@3Vkn`0i^o[0>K^jP3VkNT0iNcX0>G/i`3UjnH0iN[V
0>CZi03TjN@0i>WS0080i>SR0P3Tin420>?Vh080hnKO00D0hnGN0>?TgP3Sh]`0hn7J0>;Of0030>;N
e`080>;Pf@3RhMT0h^;J0>?Rf`3Wi]h0jNSP0>GTg03Hem0Z0?ooocT0moOg00<0imk_0<J]Y@3W_JD0
0P3ge[d00`3ge/H0klje0>o>]@090?OFaP060?ONcP3ge/H0mmK60?ONcP3ge/H0mmk>103ge/H40?ON
cPD0mmK60P3ge[d01@3gc[D0klJ]0>o6[@3_c[D0klJ]0080kkfU00@0ikFL0>N]W03W[I`0g[FL0P3W
[I@20=j]U0040=jUS03NW8`0gZF<0=JLQ0<0gZfD00L0eZF<0=jeW03FYH`0eZF<0=j]U03FYH`0gZfD
0180moOg00<0mno_0?Ogm`3gmoL0703gmoLP0?ooo`007P3oool0103Hem00jNWP0>WXh03Ti=`90>;R
fPH0h^;K0P3Rhm/70>;Sg080h^?M103Ri=d30>;TgP050>;UgP3RiMl0h^GO0>;Ug`3RiN000P3Ri^02
0>;Vh@80h^OR0180hnOS0>?Xh`3Sj><0hnWU0>CZiP3TjnL0h>OS0<c@b`2o`;X0[ZNM0:nTU`32[Y`0
cKJR0=c4[@3PbK40i<jh0>C?^`3Tckl30>C@_`070>CA_`3TdL00i=;10>CB`P3Ue<D0iMG70>GGb@02
0>GIc00Q0>GHbP3UelT0iMK70>KGa`3Vf/T0i]c<0>KNd03Vg]40imgA0>OLd03Wf/l0im[>0>OJc@3X
f/d0j=[;0>SKbP3Xf/P0j=W60>OC`P3Vd<00i<Zk0>?8^@3SakL0h/Jf0>;5]P3R`kD0hL:d0=o0[`3M
_Z`0f[ZW0=RhY@3F]J<0eKFS0080dkFS01l0dK>Q0=2bX03>/9h0cK2M0<baWP3=/Z00ckFR0=2eXP3@
]:00dKJR0=:kZ@3JdLL0gmkH0>OblP3XmoL0jOSh0>Whm`3Ym_D0jOGd0>SdlP3Xlo80j?;`0>Obk`3W
lNh0io3]0>K_k03Vkn/0i^kZ0>K]j@3Uk>P0iNcW0080iN_V00T0i>[U0>CYi03TjN@0i>WS0>CXh`3T
j>80i>OQ0>?Wh03Si^000P3Si]l20>?UgP040>?Sg@3Sh]`0h^7J0>;PfP80h^3I0P3RhMX01P3Rh]X0
hn;K0>OVgP3Yj>00iNCL0=SGd2X0oooo0`3gmoL0103gknl0moOg0?Ogm`3gknl20?Ogm`030?O_k`3g
moL0moOg00H0moOg00<0mno_0?Ogm`3gmoL0903gmoL0201cDTX0Hd8a0>o6[@3_c[D0mmK60>o>]@3g
e/H0mmJm0`3ge/H01P3gg/h0mmK60?OFaP3ge/H0mmk>0?OFaP@0mmk>00<0mmK60?ONcP3ge/H00`3g
e/H20?ONcP<0mmK600<0mmJm0?OFaP3ge/H00P3ge/H00`3_c[D0mkfe0>o6[@020>o6[@80kkfU00L0
ikfU0>neY@3W]I`0ikFL0>N]W03W[I@0gZF<00<0gZfD0P3NYH`0103FW8@0eZF<0=j]U03N[I@20=JU
S0050=jeY@3FYH`0gZfD0=j]U036[JD04`3gmoL00`3gknl0moOg0?Ogm`0K0?Ogmb00oooo000N0?oo
o`050=SGd03YjN40jNSP0>CTg03Rh]X00P3RhMT60>;RfPH0h^;K0P3Rhm/70>;Sg0030>;Sg@3Ri=d0
h^CM0080h^CM0`3Ri=h20>;UgP<0h^GO00<0h^GP0>;Vh03Ri^000P3Ri^400`3Rin80hnOR0>?Wh`02
0>?Xh`0?0>?Yi@3Tj^H0i>[V0=kTh@33a<00/JnY09^AQP2PTX@0_:RE0<bfX@3Oak00h/^d0>C>^@3T
ck/0i=2o00<0i=300P3TdL40B@3Td/80i=;30>GCa@3UeLL0iMK80>GIb`3UfL`0iMS:0>GGb@3Ue/L0
i]O60>KIb03VflX0i]g?0>KMd03Wg<l0im[>0>OIc@3Wf<`0imS;0>OHbP3Wf<L0imS60>OHa@3Wel@0
i];10>G>_P3Sb;X0h/Nh0>;6]`3RaKD0h/Be0>72]03Q`K<0g[n^0=bnZ`3I^ZD0ekRS0=FdXP3D]:80
dkFS0=:eX`3A/j00d;:O0<j_W03=[i`0c;2M0<bbW`3?]J80d;JR0=2dX03A]Z<0dk^Z0=_Bb03Ph=X0
ioCc0>Whn03Zn?P0jOOg0>Wfm@3XmO@0j?Cb0>Scl@3Wl_00io;_0>OakP3Wl>d0i^o/0>K^j`3Vk^X0
i^gY0>G/j03Uk>L00P3UjnH0203Tj^D0i>WT0>CYi03TjN<0i>SS0>CXhP3Tin40hnOQ0P3Si^001@3S
i]l0hnGO0>?UgP3Si=d0hn?M0080h^;K1@3Rh]X01@3Shm/0inKN0>WXh03Ui=`0f=O@02X0oooo>03g
moL01`3Ne^L0FS4Q06=:@P3_c[D0mmJm0>o>]@3ge[d00`3ge/H0103gg/h0mmK60?OFaP3gg/h30?OF
aP030?ONcP3ge/H0mmK600<0mmK600@0mmk>0?OFaP3ge[d0mmJm2P3ge/H01`3_c[D0mmJm0>o>]@3_
aZd0kkf]0>nmY@3_aZd00P3__JD20>NmY@090>NeW03W]I@0gZfD0=j]U03NYH`0ijfD0>NUS03NYH`0
gZfD0080gZF<00H0gZfD0=JUS03N[I@0eZF<0<je[@3N]JD30=j]U340moOg803oool001h0oooo00D0
f=S@0>WYh@3YjN00i>?K0>;Qf@020>;Of0040>;Qf@3RhMX0h^;J0>;RfPL0h^;K0P3Rhm/70>;Sg003
0>;Sg@3Ri=d0h^CM0080h^CM103Ri=h40>;Ug`030>;Uh03Ri^00h^KP0080h^KQ00<0h^OQ0>;WhP3S
in800P3Sj><0403SjN@0hnWU0>?Xi@3Ohn40e]SG0;2[Z@2HSh/0OVeT08MdI`2dWhd0c;FQ0>?<]@3V
ckP0iM2j0>C@_03TdL030>CA`P090>CB``3Tdl@0i=?50>CCa@3UdlD0iMC60>GEa`3UelT0iMO:0080
iMS:00@0iMS90>KHb03VfLT0i][:0P3Vf/`03P3WfL/0imS90>ODa`3Wd/L0im340>K?`P3Uckh0i<nm
0>??^`3Rc[X0hLZi0>78^03QaKH0hLFe0`3Qa;@08@3O`[<0g/6a0=Zn[03I_:P0e[RS0=JfXP3E]:40
e;BR0=>eX`3B]J80d;>N0<naW03=[YT0c:jI0<^_V`3;/9d0c;:O0<fcW`3=/Id0c[>P0=6iY`3Kd/L0
h>7J0>Sem03ZnOT0j_Sh0>WgmP3XmO@0j?Cc0>SclP3Xlo40io;_0>Oak`020>O`k@060>K_j`3Vk^/0
i^gZ0>K]j@3Uk>P0iNcW0P3UjnH0203Tj^D0i>[T0>CYi03TjN<0i>SS0>CXhP3Tin80hnOQ0P3Si^00
103Si]l0hnGO0>?UgP3SiMh20>?Tg@040>;Tg@3Rhm`0h^?L0>;Sf`80h^;K00D0hn?K0>OVgP3Yj>00
iNCL0=SGd00Z0?ooo`80moOg00<0mno_0?Ogm`3gmoL01@3gmoL0103gknl0moOg0?O_k`3gmoL20?O_
k`040?Ogm`3gknl0moOg0?O_kb<0moOg00H0Je9:06=2<@12:AP0S6=B0?OFaP3ge[d50?OFaP040?ON
cP3ge/H0mmK60?OFaP80mmk>0`3ge/H00`3gg/h0mmK60?ONcP050?OFaP<0mmk>0P3ge/H20>o>]@04
0>o6[@3gaZd0klJ]0>o>]@80klJ]103__JD00`3W_JD0ikFL0>NeW0020>NeW0050>N]U03N[I@0ijfD
0>N]U03W[I`00P3N[I@0103NYH`0gYb40=jLQ03NYH`50=JUS0030>nm[@3N]JD0gZfD0340moOg803o
ool001h0oooo00D0f=S@0>WZh@3YjN40i>?K0>;Pf0020>;Ne`040>;Pf@3RhMT0h^;J0>;RfPH0h^;K
0P3Rhm/70>;Sg080h^?M103Ri=d30>;TgP030>;UgP3RiMl0h^GO0080h^GO0`3Ri^020>;Vh@0F0>;W
h@3Rin80hnOR0>?Xh`3SjN@0i>WU0>?Yi@3Rin@0f]cK0<o?c`2VWid0SX9o07ISF`21K640]9f<0<ff
X`3Uc[L0im2i0>G@^P3TdK`0i=;10>CB`P80i=7200@0i=;40>CCa@3Te<H0i=C60P3UdlD0103Ue<D0
iMG70>GFb03Uf<X20>GIbP80i][:0100i][;0>KIb`3VfL/0i]S80>OGa`3Wd/D0ilo40>K;`03Vb[h0
hlZi0>;:]`3PbKD0glRd0=o6]03OaK@0h<Bd0`3Qa;<04@3Pa;<0gL:b0=c1/03H_JX0ek^W0=FgX`3F
]Z40e[BQ0=FdXP3C]J80d[FQ0<nbW@3>/9X0c:jH0<^]V03:[YX0bZnK0080bk2L00/0c:nJ0<faW@3@
]jD0f]760>3Pf@3Xm?<0j_Sh0>Whm`3Ym_H0j?Gc0>Sdl`020>Scl@0:0>Obk`3WlNl0io3]0>O`k@3V
kn/0i^k[0>K]jP3VkNT0iNcX0>G/i`80iN_V00`0iN[U0>CZi03TjN@0i>WS0>CXh`3Tj>80i>OR0>?W
h@3Sin00hnKP0>?Vg`3SiMl20>?UgP030>?TgP3Si=d0h^CM0080h^?L0P3Rhm/01P3Rh]/0hn?K0>OV
gP3Yj>00iNCL0=SGd2X0oooo203gmoL00`3gknl0moOg0?Ogm`0H0?Ogm`030?O_k`3gmoL0moOg0100
moOg00H0oooo07=:>@1SBT80FS4Y0<je[@3ge[d20?OFaP050?OF_@3ge/H0mmK60?OFaP3gg/h00P3g
e/H00`3gg/h0mmK60?OFaP040?OFaP040?ONcP3ge/H0mmK60?OFaP80mmk>0`3ge/H01@3gg/h0mmK6
0?OFaP3ge[d0mlJ]0080klJ]1P3__JD40>NeW0090>nmY@3W]I`0ikfU0=j]U03W[I@0gZfD0=jUS03N
[I@0ijfL0080gZF<00/0eZF40=JUS03FYH`0gZF<0=JUS03NYH`0gZfD0=JUS03N]JD0e/Je0=jeW00L
0?Ogm`050?O_k`3gmoL0moOg0?Ogm`3gknl00`3gmoL00`3gknl0moOg0?Ogm`0:0?Ogmb00oooo000N
0?ooo`050=SHd03Yj^40jNWQ0>CSf`3Rh=P00P3Rg]H0103RgmL0h^3H0>;Qf@3Rh]X60>;Rf`80h^?K
1`3Rhm`00`3Rhmd0h^CM0>;Tg@020>;Tg@<0h^CN0P3RiMh30>;Ug`030>;Uh03Ri^00h^KP0080h^KQ
01D0h^OQ0>;WhP3Rin80h^OR0>CYi03Uj^H0i^cX0>GZiP3Ohn00b<K50;Nb/@2CQH<0Q7=^07mXGP2>
MVX0_JFD0=:jZ03VckX0im6k0>G@_03TdKd00P3Td/820>CA`P050>CBa03Te<D0i=G60>CDaP3Udl@0
0P3Ud/@05`3UdlD0iMC60>GGb@3Uf<X0iM[<0>GKc@3Vfld0i][<0>KHb@3VelP0iMK40>GE``3Uckl0
iL^n0>C4^P3S`kL0hL>b0=o2/03L`:`0fkn[0=^o[03L`:d0g/:_00<0gl:_0100g/:_0=_1[P3I`:`0
eK^X0=BiY@3C]J40e;BQ0=JcX03E/j00dk>P0=6bWP3>/9X0cJnH0<b]UP3;[9H0bjbH0P3:[9P05039
ZiL0bJ^F0<^^VP3>]:80f<g10=kKd`3Wknd0jOCc0>Wfm@3YmO@0j?Cc0>SdlP3Xlo40io;`0>Oak`3W
lNh0io3]0>K_k03Vkn/0i^k[0P3VkNT02`3Uk>P0iNcW0>G[iP3UjnH0iN[U0>CZi@3TjN@0i>WS0>CX
h`3Tj>80i>OR0080hnOQ0P3Si^020>?Ug`80hnGN00@0hnCM0>;Tg@3Rhm`0h^?L0P3Rhm/01P3Rh]/0
hn?K0>OVgP3Yj>00iNCL0=SGd2X0oooo0`3gmoL00`3gknl0moOg0?Ogm`0_0?Ogm`080>oWi`2DNg<0
Hd8a06=2<@3ge/H0mmJm0?OFaP3ge[d20?OFaP050?ONcP3ge/H0mmK60?OFaP3gg/h0303ge/H40?ON
cP80mmK600D0mmJm0?OFaP3_c[D0klje0>o6[@020>nmY@050>o6[@3W_JD0kkFU0>nmY@3W_JD01P3W
]I`01`3N]I`0ikFD0=j]U03W[I@0gZfD0>N]U03N[I@00P3NYH`01P3FYH`0eZF40=JUS03FYH@0eZF<
0=jUS0<0eZF<00<0g[FL0=jeY@3gmoL06@3gmoL00`3gknl0moOg0?Ogm`0D0?Ogmb00oooo000N0?oo
o`0;0=SHd03YjN40jNWQ0>CSf`3Rh=T0h]kG0>;NeP3Rg]L0h]oG0>;Pf@3RhMT01@3Rh]/30>;Sf`L0
h^?L1@3Ri=d30>;TgP030>;UgP3RiMl0h^GO0080h^GO00<0h^GP0>;Vh03Ri^000P3Ri^405`3Rin40
h^OR0>;WhP3Rin80i>WT0>G[iP3Wk^T0iN_W0=gQg@2k^;D0Yj2M08YjM@25LVX0T7Q[09n7N036[Y/0
e[j[0>G>^P3Vd;/0i=2l0>C@_P3TdL40i=;20080i=7100D0i=;30>CCa03Te<D0i=?50>GBa0020>GB
``0C0>GCa03UdlD0iMK80>GGb@3Uf/`0iM_=0>KKc@3Vf/`0i]O90>GFa`3TeL<0i=?10>?=_@3SbK/0
hl:g0>;1]@3P`K00g/2^0=^nZP020=ZmZ@030=^nZP3M`:`0gL2]0080gL2]00d0g<2/0=[0Z`3H_jT0
e;ZV0=>hY03C]:40dk>P0=FbW`3D/Yl0dk6N0=6`W@3?[iT0cZjG0080c:bF00<0c:^G0<^[U`3:ZYH0
0P39ZYH02P3;[IT0c[BQ0=S:_@3Ne/h0i^_W0>S`kP3Xm?<0j?Gc0>Sdl`3Xm?820>Obl0040>Oak`3W
lNh0io3]0>K_k080i^k[0P3VkNT02`3Uk>P0iNcW0>G[iP3UjnH0iN[U0>CZi@3TjN@0i>WS0>CXh`3T
j>80i>OR0080hnOQ0P3Si^020>?Ug`80hnGN0P3Si=d20>;Sg080h^?K00H0h^;K0>?Sf`3Wi]h0jNSP
0>GTg03Hem0Z0?ooo`80moOg00D0mno_0?Ogm`3gmoL0moOg0?O_k`040?Ogm`030?O_k`3gmoL0moOg
02L0moOg00P0[Ib<05Y2>@1cBST0aYb40?OFaP3_c[D0mmK60?OF_@@0mmK60P3gg/h60?OFaP030?OF
_@3ge/H0mmK600@0mmK60`3gg/h40?OFaP80mmJm00<0klje0>nmY@3__JD0103__JD01@3W]I`0kkfU
0>NmY@3W_JD0kkfU0080ikFL0P3W[I@0103N[I@0gZF<0=j]U03W[I@20=j]U0<0gZF<00H0eZF40=JU
S03FYH@0eZF40=JUS03NYH`30=j]U0030=jeW03gmoL0moOg01/0moOg00<0mno_0?Ogm`3gmoL04@3g
moLP0?ooo`007P3oool01`3Hem00jNWQ0>WXh03Thm`0h^7J0>;Pf03RgmL00P3RgMH01P3RgmP0h^3I
0>;Rf`3Rh]/0h^?K0>;Rf`<0h^?K1`3Rhm`00`3Rhmd0h^CM0>;Tg@020>;Tg@@0h^CN103RiMl0103R
iN00h^KP0>;Vh03Ri^020>;Vh@030>;WhP3Sin80hnSS00<0hnSS0140hnST0=_Nf@3>clT0XY^D08n3
NP27M6L0U7m`0;VQSP37[iX0f/:[0=o7/@3TcKP0i<jj0>C>_@3Tc[h0i<no0>C?`0020>C@`0040>C@
`@3TdL40i=;20>CB`P80iM7302H0iM;30>GBa03Udl@0iMC60>GEa`3Uf<X0iM[<0>KJc@3VfL`0iMK8
0>GDa03Rckh0hLbj0>35]@3P`K<0h;b`0>2k[P3O^ZX0gKVX0=ZgY@3I]Z<0f;FS0=VfX`3J^:D0f[VV
0=ZjY`3J^jL0f[bV0=RkY03G^Z<0e;NQ0=:eX03A/Ih0dJnL0=:]VP3B[IT0dJfI0=2]V080cjbG0P3?
ZiH04`3>ZYH0cJZF0<ZYU039ZI@0bZZE0<b]V03?/Ih0e/6b0=[;_`3Qg]P0i>KR0>Oak`3Xm?80j?Cc
0>SdlP3Wl_00io;_0>OakP3Wl>h00P3Vkn`01P3Vk^/0i^kZ0>K]j@3UkNT0iNcX0>G/i`80iN_V0P3T
j^D00`3TjN@0i>WS0>CXh`020>CXhP040>CWh@3Sin40hnKP0>?Vh080hnGO00@0hnCN0>?Tg@3Si=d0
hn?L0`3Rhm`01`3Rhm/0h^;K0>?Sf`3Wi]l0jNSP0>GTg03Hem00:P3oool80?Ogm`030?O_k`3gmoL0
moOg02P0moOg00@0oooo0>ONi`1J@ST0Hd8a0P3ge/H30?OF_@@0mmK600<0mmk>0?OFaP3ge/H01P3g
e/H00`3ge[d0mmK60?OFaP030?OFaPD0mmk>00H0mmK60?OF_@3_c[D0klje0>o6[@3__Jd30>nmY@<0
ikFL00<0kkfU0>NeW03W]I`00P3W]I`01@3W]I@0gZfD0>N]W03W[I@0gZfD00@0gZF<00L0ikFD0=jU
S03NYH`0gZF<0=jLQ03FYH`0gZF<00<0eZF<00D0gZF<0=j]U03FYH`0gZfD0>oFcP0`0?Ogmb00oooo
000N0?ooo`070=SHd03YjN40jNSP0>CSg03RhMX0h^3H0>;Oe`020>;MeP040>;Of03Rh=T0h^;K0>;R
f`@0h^?K1`3Rhm`20>;Sg@@0h^CM0`3Ri=h00`3RiMh0h^GO0>;Ug`020>;Ug`040>;Uh03Ri^00h^KP
0>;Vh080h^KQ01<0h^OR0>?WhP3Sj><0i>WT0>;WhP3Oi=l0fn3K0<_<aP2m_;D0VY2608eoM02BOVh0
Xhek0<ZbW@3F_ZL0h<Va0>;:/`3Tc;P0i<fj0080i<jm00@0i<jn0>C?_`3Tcl00i<o00P3Td<000`3T
dL00i=710>GA`P020>GA``0Q0>GBa03Udl@0iMC60>GEa`3Uf<T0iMW;0>KJc03VfL/0iMG70>CB``3R
b[X0h<Fe0=nn[`3O^Zd0gkJ[0=neZ@3N/jD0gK:S0=Z`X03I[il0f:jN0=R_WP3I/J00fK>R0=VeX`3I
^:@0f;VS0=NiX@3F^:00dkFN0=:cWP3A[i`0d:fJ0080d:^G103?ZiH0103@ZiH0d:ZF0<nZU@3=ZYD2
0<ZYT`0?0<^YT`3=ZiH0cjjJ0=FjZP3H`kD0g]K>0>7PfP3Vknd0j??b0>Sel`3Xm?80io;`0>Oak`3W
l>h0io3]0080i^o/00H0i^k[0>K^jP3VkNT0iNgY0>G/j03Uk>L20>G[iP80i>[U00<0i>WT0>CYh`3T
j><00P3Tj>80103Tin40hnOQ0>?Vh03Si^020>?Ug`040>?Tg@3Shmd0hn?L0>?Sg0<0h^?L00L0h^?K
0>;Rf`3Shm/0inKO0>WXh03Ui=d0f=O@02X0oooo1P3gmoL00`3gknl0moOg0?Ogm`0Z0?Ogm`040<J]
_@1SBT80DSTa07]SDPH0mmK600<0mmk>0?OFaP3gg/h0103ge/H00`3ge[d0mmK60?OFaP020?OF_@@0
mmK600@0mmk>0?OFaP3gg/h0mmk>103ge/H00`3ge[d0mkfe0>o>]@020>nm[@030>neY@3W[I`0ijfL
0080ijfL1@3W[I@20=j]U0040>N]U03WYH`0gZF<0=j]U0T0gZF<0P3FYH`0103FYH@0eZF<0=JUS03N
YH`20=JUS0030=j]U03N]I`0e/Jm02l0moOg803oool001h0oooo00/0f=S@0>WYh@3YjN40i>?K0>;P
f@3Rg]L0h]kF0>;Ne`3RgmL0h^3I0>;QfP020>;Rf`@0h^?K1P3Rhm`20>;Sg@@0h^CM0`3Ri=h20>;U
gP@0h^GO0`3Ri^020>;Vh@0J0>;Wh@3Sin80hnOR0>CYi@3UjnH0h>GP0=KJe037al40Y9jE09R>Q02F
R7X0Whio0;RTT`36/Ih0gLF`0>;;]03UcKD0i<fe0>?<]`3Sc;T0i<fl0>C=_@3TcKh0i<jn0>C>_`3T
ckh20>C?_@090>C@_@3Td;h0i=310>GA`@3UdL80iM;30>GCa03UeLL0iMK80080iMO90P3VelT02P3U
d/@0i<bo0>6l/03P]:P0gZVP0=jWWP3NY9`0gJ>J0=^OU@3JWI@20=RKT@0Z0=NJT03GVi40f:2D0=RT
U`3HZIX0ek6N0=JcWP3D/Y/0dk2J0=6_V@3@[IT0d:ZG0=2YU@3?YY<0cZNB0<fXT@3<ZI80cZZD0<nZ
U@3@ZYD0d:VE0<nYU03>ZI<0bZR@0<ZXS`3;YXl0cJJ@0<jWTP3@[9T0dK:P0=K6^@3KdlT0i>[V0>Oa
kP3Xm?80j??a0>Oak`3WlNh0io3]0>K`k@3Vkn`0i^o[0P3Vk^X02`3UkNT0iNcX0>G/j03UjnL0iN_V
0>GZiP3Tj^D0i>[T0>CYi03TjN<0i>SS0080i>SR00P0i>OQ0>?Wh@3Si^00hnKP0>?Vg`3SiMl0hn?M
0>?Rf`80hn7J00X0h^;K0>;Sg03Rhm`0h^?K0>;Rf`3Shm/0inKO0>WXh@3Ui=d0f=O@:P3oool00`3g
moL0mno_0?Ogm`0_0?Ogm`060?ooo`1J@ST0HdY20:f<Q03_e/h0mmJm1`3ge/H20?ONcP@0mmK60`3g
e[d0103ge/H0mmJm0?OFaP3ge[d80?OFaP040?ONcP3g_KD0mkfe0?Nm]@80kiB<0P3WU8@01@3NW8@0
ihAk0>nDS03W[I@0kiB<00<0ijfD00<0ijF<0=jUS03NYH`0103NYH`20=JUS0080=JUQ03NYH`0gZF<
0=jUS03FYH`0eZF40=JUS03NYH`20=JUS0050=JUQ03FYH`0eZF<0=JUS03NYH`00P3N]I`00`3_inL0
moOg0?Ogm`0Q0?Ogm`030?O_k`3gmoL0moOg00P0moOg803oool001h0oooo00D0f=S@0>WZhP3YjN40
i>?K0>;Pf0020>;NeP040>;Of03Rh=P0h^7J0>;RfP80h^;K103Rhm/60>;Sg080h^?M103Ri=d30>;T
gP80h^GN103RiMl30>;Vh080h^KQ01L0h^OQ0>?WhP3Sin80iNWU0>K[iP3Oh]h0d]C?0;nm]`2GSH@0
SH1d09b;O02]Vh/0c;RV0=K0[P3QbKD0i<bf0>G=]@3Tc;D0hlbg0>?<^@3TcK`0i<fm0>C=_P020>C>
_P0;0>C>_@3Tc[/0i<nk0>C?^`3Tck`0i=2o0>G@`03Ud<40iM;30>GCa03UeLL00`3Ue/P20>KEa`0:
0>G?`P3Tb;`0hKF[0>2[XP3NX9T0gYjG0=fKU03LV940fI><0=RBRP80ei6901<0ei6:0=NBRP3GUhh0
f9fA0=RSU@3G[9X0eJjJ0=:]V03A[9L0cj^F0<nZUP3?Z9D0cjNC0<jUT03=YI00bjN@0<^XT03=ZI80
cZVD0080d:VE00d0cjVD0<jYTP3;Z8l0bZN>0<bUS@3=Y8d0cZ>>0<jVTP3>ZiP0dkj_0=S<`03RiMl0
iNcY0080io;`00l0io7_0>OakP3Wl>d0i_3]0>K_k03Vk^/0i^kZ0>K]jP3UkNT0iNcX0>G/i`3UjnL0
iN_V0>GZiP3Tj^D00P3TjN@01P3TjN<0i>SS0>CXhP3Tj>80i>OQ0>?Wh@80hnKP00L0hnKO0>?Ug`3S
hm`0hn7K0>?Pf@3Sh=X0h^;K00<0h^?L00H0h^;K0>?Sf`3Wi]l0jNSQ0>GUg@3Hem0Z0?ooo`D0moOg
00<0mno_0?Ogm`3gmoL0:`3gmoL01`1S@S40HdY20>oFcP3gg/h0mmK60?OF_@3ge/H00P3ge[d30?OF
aP030?ONcP3ge/H0mmK600<0mmK61@3ge[d30?OFaP<0mmk>0P3ge/H0103gg/h0mmK60?Nm]@3g_KD2
0>nDS0030>N]W03_U8`0ihAk00@0ihAk00T0kiB<0>N4N`3WQ7/0iiB40>NUS03W[I@0gZfD0=jLS03N
W8@00P3NYH`01P3NW8@0gZF<0=jLQ03FW8@0eZF40=j]U0L0gZF<00@0eZF40=jUS03NW8@0gZfD0P3F
YH`00`3N]I`0klje0?Ogm`0L0?Ogm`040?O_k`3gmoL0mno_0?O_k``0moOg00<0mno_0?ooo`3oool0
7P3oool001h0oooo00D0f=S@0>WZh@3YjN40i>?K0>;Pf@020>;Oe`030>;Pf@3RhMX0h^;K00<0h^;K
103Rhm/60>;Sg0030>;Sg@3Ri=d0h^CM0080h^CM103Ri=h00`3RiMh0h^GO0>;Ug`020>;Ug`060>;U
h03Ri^00h^KP0>;Vh03Ri^40h^OQ0`3Sin804P3Rin80h^GQ0=SIe03=blD0_;J`09nAQ`2KRWh0]:2A
0<NbXP3QbkX0iLnm0>G=^P3Tc;P0hl^e0>?<]@3Sc;L0hlbi0>C=_080i<fm0340i<fl0>C<^P3Tc;T0
i<bg0>C<]P3TcKH0i<fg0>C=^P3Uc[`0iLnn0>GA`P3Udl<0iMG60>GEa`3Ud/D0iM330>K=`@3Vc<40
iLNm0>C0]`3RZj@0h:2J0=jCSP3MTH/0fXb50=V8P@3EPGX0eGmi0=F1O03FPgh0eXF00=J6P@3ERh<0
eXn60=JERP3FWY00e:2A0<nQT@3=XI00c:>A0<bTT@3<YI00c:F?0<^TSP3:Y8d0bJF=0<VVSP3<Yi40
cJNB0080d:RD00l0cjRC0<jXTP3<Yhl0c:J=0<fRR`3=X8X0cIn:0<bQS03<YHl0ck>O0=:m[03Kd/L0
gm_C0>CYi@3Vk^X00P3WlNl03@3Vl>d0i^o/0>K_j`3Vk^/0i^kZ0>K]j@3UkNT0iNcX0>G/i`3UjnL0
iN_V0>GZiP3Tj^D00P3TjN@01P3TjN<0i>SS0>CXhP3Tin80i>OQ0>?Wh@80hnKP00@0hnKO0>?Ug`3S
hmd0hn;K0P3ShMX02P3Rh]/0h^?L0>;Sg03Rhm`0h^;K0>?Sf`3Wi]l0jNSQ0>GUg@3Hem0Z0?ooo`P0
moOg00<0mno_0?Ogm`3gmoL09`3gmoL00`3>]KD0Hd8a0:f<Q0020?OFaP80mmJm0P3ge/H00`3ge[d0
mmK60?OFaP060?OFaP060?OF_@3g_KD0klje0?OF_@3gc[D0mmJm0P3ge/H00`3gg/h0mmK60?OFaP02
0?OFaP80mmk>1@3g_KD20>nDS0@0ihAk00<0kiB<0>N4N`3WQ7/01@3WQ7/00`3>S8@0gYb<0=jUS002
0=JUS0D0eZF42@3NYH`01`3FYH`0gZF<0=JUS03FYH`0gZfD0=JUS03__Jd0403gmoL00`3gknl0moOg
0?Ogm`0J0?Ogmb00oooo000N0?ooo`050=SHd03YjN40jNWQ0>CSf`3RhMT00P3Rh=P00`3RhMT0h^;J
0>;Rf`030>;Rf`<0h^?K1`3Rhm`50>;Tg@@0h^CN00<0h^GN0>;Ug`3RiMl00P3RiMl01`3RiN00h^KP
0>;Vh03Ri^00h^KQ0>?Wh@3Sin800P3Sj><06@3Pi=l0gN3K0=;@c039a;l0_[J_0:jOU@2^W900`jjN
0=6kZ`3TcK`0i/nn0>G=^P3Tc;P0hl^e0>?;]03Sc;L0hlbi0>C=_03TcKd0i<fl0>C<^`3TbkP0i<Zf
0>C:]03Tb[<00P3Tbk@0:P3Tc;L0i<fi0>G>_03UdL40iM;30>GDa@3UdlD0i/k20>K;_`3Vakd0i/Jl
0>G1^03T^[80hJNQ0=nMV03LT8X0fhf60=R7O`3FPgX0dgad0==kM03DOgT0eH9m0=F4OP3DQ7h0e8In
0=F9P@3ESX@0eIF:0=>HS03>VX`0c9^<0<ZOS@3:XHh0bZB?0<ZTSP3:Y8d0bJB<0<RTS039Y8d0bjJ@
0<fVT@80cjRC00l0cjRB0<jWT@3=YXl0cJF>0<fRR`3>X8X0cYn90<fQR`3<Y8h0cZnJ0=2eXP3GakP0
fm750>;Sg@3UjnH00P3WlNl01P3Vl>d0i^o/0>K^j`3Vk^/0i^gZ0>G]j@80iNcX0P3UjnL00`3UjnH0
iN[U0>CZi@020>CYi0060>CYh`3Tj><0i>SR0>CWhP3Tin40hnOQ0P3Si^00103Si]l0hnGO0>?Tg@3S
hm`20>?Rf`<0h^?L00L0h^?K0>;Rf`3Shm/0inKO0>WXh@3UiMd0f=O@02X0oooo1P3gmoL00`3gknl0
moOg0?Ogm`0Y0?Ogm`0609AkL`24JeX0klje0>o>]@3ge[d0mmK60P3ge[d0103ge/H0mmJm0?OF_@3g
g/h30?OFaP<0mmJm0`3gc[D30?OF_@D0mmK60P3gg/h02P3ge/H0mkfe0?Nm]@3g_KD0mnON0?Nm]@3g
aZd0kkFU0>nDS03WQ7<30>N4N`050>nDS03WQ7/0ihAk0>N4N`3NNf/00P3WQ7/0103NNf/0ihAk0=jL
S03NW8`30=jUS080eYb400D0eZF40=JUS03NYH`0eZF<0=j]U0020=jUS0040=j]U03NYH`0eZF40=jU
S080eZF<00<0gZF<0=j]U03FYH`00P3N]I`?0?Ogm`030?O_k`3gmoL0moOg01P0moOg00<0mno_0?Og
m`3gmoL0803oool001h0oooo00@0f=O@0>WYh@3Yj>00i>CL1@3Rh]X20>;Rf`D0h^?K1P3Rhm`00`3R
hmd0h^CM0>;Tg@030>;Tg@<0h^CN0P3RiMh40>;Ug`030>;Uh03Ri^00h^KP0080h^KQ0140hnOQ0>?X
hP3Uj^@0i>WT0=WLf03?d<`0^[F`0;B/Y`2eZZ<0`k:W0<bi[03Ja;80glNe0>?;]`3Tc;P0i<bg0>C;
]P020>?;]0080>?<]P3Sc;P0i<fk0>C=_03Sc;X0hl^h0>?8/`3Sak020>?5[P0c0>?6[`3Tak00i<Zd
0>C<]`3Uc[X0iM;10>KC`P3Wdl<0im310>K6^@3U_kD0i;J^0>>c[03R[jP0hJ^T0=fPV@3KVI80eXb3
0=>7O03?P7<0cWia0<ioL`3@PWH0dhQo0=B:PP3DQgl0dX=k0=1mM@3AOG@0dGif0=:3N`3AQWd0cHb1
0<^@P`38UhL0b9Z90<RQS038Xhd0ajF<0<NUR`37XXX0b:::0<ZSS03;YHh0cZN@0<jWT@3?Yi40cjJA
0<jUT03>YHl0cZ:<0080cZ2;00h0cZ>=0<jUS`3>ZI80cZ^D0=:eX@3E_jh0gmW?0>?TgP3Wl>d0io7^
0>K`k@3Vkn`0i^k[0>K^jP80iNgY0P3Uk>P01@3UjnL0iN_V0>GZiP3Uj^D0i>[U0080i>WT0P3Tj><0
103Tj>80i>OR0>?Wh@3Sin420>?Vh080hnGO00@0hnGN0>?TgP3Si=d0hnCM0`3Rhm`01`3Rhm/0h^;K
0>?Sf`3Wi]l0jNSQ0>GTg@3Hem00:P3oool30?Ogm`030?O_k`3gmoL0moOg02T0moOg00H0oooo09B4
Q02LS8`0FS4Y0?ONcP3_c[D30?OF_@030?OFaP3ge[d0mmK60080mmJm1@3ge/H00`3ge[d0mlje0>o6
[@030?O>]@040>o6[@3ge[d0mmK60?OFaP80mmk>00<0mmK60?Nm]@3g_KD00P3g_KD00`3gg/h0mlJ]
0>N]W0020>N4L`040=IcH`3NJeX0eW=S0=i[FP<0ig][00<0ihAc0>MkJ`3NJeX01@3NNf/01P3WQ7/0
eXak0=jLQ03NW8`0gYb40=JUS080eYb400@0eZF40=jUS03NYH`0gZF<0`3N[I@30=jUS0090=jLQ03F
YH`0gZF<0=j]U03NYH`0gZfD0=JUS03N]JD0mno_02/0moOg803oool001h0oooo00D0f=O@0>WYh@3Y
j>00i>CL0>;Rf`030>;RfP<0h^;K1@3Rhm/60>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0`3Ri=h00`3R
iMh0h^GO0>;Ug`030>;Ug`030>;Uh03Ri^00h^KP0080h^KQ00h0hnOQ0>?Xh`3UjnD0i>WT0=GHe036
a/80Z:>N0:>JU02XVi<0`k6T0=:m[@3PbKD0h/Zf0>?:]@80i<^f00D0i<^e0>?;/`3Sbk<0hlbf0>?<
^0020>C=^`0R0>?<^@3SbkH0h/N`0>75[P3Q`Z/0hL:Z0>;4[03SaZh0i<Zc0>C=]`3UckX0iM;00>KB
`@3Wd<00ilfm0>K0/`3T^:d0hZ^T0>6XX@3OY9d0gZ:J0=ZLT`3GUhh0dHYo0<j4N03:OVl0bWm`0<b7
N03?S7h0di:70=BBR03CRX40dH=j0<iiK`80cWI]01D0cg]b0<mnMP3=QW`0bhYo0<VBQ038UhL0aij;
0<NRS037YH`0ajB;0<NRR037XHL0bJ>90<ZTR`3<YXl0cJN@0<jVT03?YY00cjF@0<nTS`3>XXd00P3>
XH`03P3>Xhd0cZF>0<fWT03=Z900d;6K0=BkZ03NeLX0hn7I0>O^jP3Wl>d0i_3]0>K_k03Vk^/0i^kZ
0P3UkNT20>G/j0040>G[i`3UjnH0iN[V0>CZi@<0i>WT0P3Tj><0103Tj>80i>OR0>?Wh@3Sin420>?V
h080hnGO0P3SiMh20>?Tg@<0h^?L00L0h^?K0>;Rf`3Shm/0inKO0>WXh@3Ui=d0f=O@02X0oooo00<0
moOg0?O_k`3gmoL0;03gmoL01@3gknl0Nf=J07=JDP2<Lf<0klje00<0mmJm00@0mmK60?OF_@3ge[d0
mlje1P3ge/H20?OF_@070?O>]@3gaZd0klje0?O>]@3gaZd0klJ]0?OF_@020?OFaP030?ONcP3ge/H0
mkfe00D0mkfe0P3WU8@00`3FLf<0gV]J0=ISDP0<0=i[FP80gW][0P3FNf/01P3>S8@0eYb40=JUS03N
W8@0eYb40=JLL`80eZF400L0gYb40=jUS03NYH`0gZF<0=j]U03NYH`0gZfD0080gZF<0`3FYH`01@3N
YH`0eZF<0=j]U03N]I`0imkW02/0moOg803oool001h0oooo00D0f=O@0>WYh03Yj>00i>CL0>;Sf`06
0>;RfP<0h^;K00<0h^?K0>;Sg03Rhm`01@3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@<0h^CN00<0h^GN
0>;Ug`3RiMl00P3RiMl0103RiN00h^KP0>;Vh03Ri^020>;Vh@0>0>?Wh@3Sin80iNWT0>;VhP3;c<L0
]K>^08^2N`25NFl0Sgmc0;^VT`3@^J@0i<^c0>G<]03Tb[830>?:/P040>?;/`3Sbk@0hlbg0>?<^@80
i<bi03D0hl^d0>;9/@3O`j/0g/2X0=fkX`3M^Z<0gkjV0>71ZP3TbK<0iL^f0>G<^@3SbKP0h/Nf0=no
[@3N^ZP0gJbN0=fUV@3LVI40g9F=0=ZBR03HThP0e9J:0=:FRP3:SGl0aXMh0<>2L@34QgD0biR50<jN
S@3BXY<0dYnA0<n>P@3<PgL0ag9V0<I^HP36KF40b75V0<QdJP39O740bH1e0<R8N`37SGl0aiN60<JL
R@36XX/0aZ>90<JQP`37X840b:640<RSQP3:YH`0c:J>0<jVT0020<nVT0030<nUS`3?Y8h0cZ>=0080
cZ>=00X0cZB=0<fTS@3=YHh0cjfG0=>eX@3Lc;h0hMS<0>KWg`3Vj^D0i^gY0P3Vk^X02@3VkNX0iNgY
0>G/j@3Uk>P0iNcW0>G[i`3UjnH0iN[U0>CZi@030>CYi080i>SS00@0i>SR0>CWhP3Sin40hnOQ0P3S
i^020>?Ug`80hnGN0P3Si=d02P3Ri=d0h^?L0>;Sg03Rhm/0h^;K0>?Sf`3Wi]l0jNSQ0>GTg@3Hem0Z
0?ooo`80moOg00<0mno_0?Ogm`3gmoL00P3gmoL00`3gknl0moOg0?O_k`0T0?Ogm`060=kFi`2LS8`0
FT8i058a:@3gg/h0klje203ge[d00`3gg/h0mmK60?OFaP020?OFaP80mmJm00<0klJ]0>nmY@3__JD0
0`3__JD01@3ge[d0mmK60?ONcP3ge/H0mkfe0080mlJ]01<0ijfL0>nDS03WU8@0ihAk0=ikJ`3FS7/0
gYb<0=jeY@3W[I`0aV]B0?Nm]@3N]JD0gYb<0;EcFP3W[I`0gYb40=IcH`3FHe80cUY:0080eV=B0P3N
JeX02@3NNf/0eW][0=J<N`3FS7/0gYb<0=JUS03FYH@0cYAk0=JLQ0030=JUQ080gZF<00D0ijF<0>N]
U03NYH`0gZfD0=jUS0020=JUS0030=jUS03N[I@0gZF<0080gZfD00<0g[FU0>ONi`3gknl0:@3gmoLP
0?ooo`007P3oool01`3Hem00jNWQ0>WXh03Ti=`0h^?K0>;RfP3Rh]/00P3Rh]X30>;QfP030>;RfP3R
h]/0h^?K00L0h^?L00<0h^?M0>;Tg@3Ri=d00`3Ri=d30>;TgP030>;UgP3RiMl0h^GO0080h^GO00H0
h^GP0>;Vh03Ri^00h^KP0>?Vh@3Sin420>?WhP0=0>;Uh@3NhM`0aLBo0:nZY027Ng80PW9W08ejJ`2j
Xhh0d;NP0>C:/@3Uc;<0hlZa0>?9/0020>;9/0030>?;/`3Sc;D0hlbh0080i<bi03L0i<^g0>?9/@3Q
aZh0g/2W0=bmX`3J]ih0f[FN0=fiX`3P_ZP0i<Nb0>G8]@3UakH0h;n_0=biZ@3D[9X0dZJE0=>MS`3E
VXh0fI>:0=V@Q`3HSH80eXn30=>ER@3AV8/0biB50<N?P035S7/0aY1n0<bLRP3>XHl0d:>B0=2OS`3;
SWl0ah=d0<=bI032KV40`VeP0<=aI@33LfP0a7U]0<AlK`36PWD0aXIi0<NAPP37UhH0aZ290<JQQ`36
X840aYmo0<NPP@38XXD0bZB;0<^US@3>YY00cjN@0080d:N@00<0cjF>0<nTSP3>Y8d00P3>Y8d03@3=
Y8d0cJF=0<n[U@3B/Yh0f/Jf0=k@`P3Th=L0iNGN0>K[iP3VkNP0i^kZ0>K]jP3UkNT00P3Uk>P00`3U
jnL0iN_V0>G[iP020>CZi@<0i>WT0P3Tj><0103Tj>80i>OR0>?Wh@3Sin420>?Vh080hnGO0P3SiMh2
0>?Tg@0:0>;Tg@3Rhm`0h^?L0>;Sf`3Rh]/0hn?K0>OVg`3Yj>40iNCM0=SGd2X0oooo00<0mno_0?Og
m`3gmoL00P3gmoL00`3gknl0moOg0?Ogm`020?Ogm`030?O_k`3gmoL0moOg00<0moOg00<0mno_0?Og
m`3gknl06P3gmoL01P3oool0W8b<08acJ`12:B40Q6=B0?OFaP80mmJm00@0mmK60?OF_@3ge[d0mmJm
0P3gc[D60?OFaP030?O>]@3ge[d0mlJ]0080kkfU0240ikFL0>nmY@3_c[D0mmk>0?OFaP3gg/h0mkfe
0?O6[@3_]JD0ijfL0>NDQ03WQ7/0eW=S0=IkJ`3>U7/0c[Fe0=K6_@3_e/h0e/Jm0=JLS03Fa[d0mkfe
0=jeY@3>S7<0c[Fe0=jeY@3>S7<0YF=:0;f4J`3>Le80cUY:0=ISDP3FLf<00`3FNf/02`3FS7/0cXb4
0=JLQ03FW7<0cYAk0=JLQ03FYH@0gYb40=jUS03N[I@0ijfD0080gZfD00<0ijfD0=j]U03FYH`00P3N
YH`20=j]U0080=jUS03N[I@0eZF<0=j]U03Wg^L0knOW0?O_k`3_inLW0?Ogmb00oooo000N0?ooo`05
0=SGd03YjN40jNSP0>CTg03Rhm/0103Rh]X01P3Rh=T0h]oH0>;Of03Rh=T0h^;J0>;Rf`H0h^?L0P3R
hmd40>;Tg@<0h^CN0P3RiMh40>;Ug`050>;Uh03Ri^00h^KP0>;Vh03Sin400P3Sin80DP3QiN00emSD
0<o=b@2f[JL0YiZC09B0LP2EOfd0X8Qd0<BZTP3D^Z40hlZa0>C;/`3Rak00hLF^0>34[03PaZd0h/^d
0>?=^03Sc[/0i<fk0>C:]`3Tb;@0h/>[0>30Y`3K^Ih0f;FI0=B/TP3CZI40ejbH0=^bW`3R^j`0hkZ]
0>:fZ@3GXYH0cIB80;MmK`2`MfP0^7ma0<:8N`3CUHT0eiJ:0=NBQ@3FTXD0eIb>0=FRU@3D[9l0djjQ
0=:[W@3BYYP0dIb=0=6IR@3<UhH0bIJ40<6=NP2nQg<0^GeZ0;UkJP2iO6/0^7a^0;IjK02bM6D0/W5S
0;YbI02oMFP0a89c0<B:NP33V880`ib20<FNOP36WG`0bIio0<ZOP`3;XXX0c:B=0<jXT@3@ZY80dZbB
0=:[TP3AZ8l0d:J>0<nUSP3>YHh30<fUSP0@0<jWT03@ZY@0e;JR0=NnZ`3Nd<80hMS=0>GUgP3VjN<0
i^gX0>K]j@3UkNT0iNcX0>G/i`3UjnL0iN_V0>GZiP80i>[U0P3TjN@01@3TjN<0i>SS0>CXhP3Tin80
i>OQ0080hnOQ0P3Si^020>?Ug`80hnGN0P3Si=d02P3Ri=`0h^?L0>;Sg03Rhm/0h^;K0>?Sf`3Wi]l0
jNSQ0>GTg@3Hem0Z0?ooo`X0moOg00<0mno_0?Ogm`3gmoL0803gmoL01P3_inL0S7]c06=BBP1[DTX0
c[F]0>o>]@<0mmJm00H0mmK60?OF_@3ge[d0mlJ]0>o6[@3ge/H20?ONcP<0mmK600/0mkfe0>o6[@3_
_JD0kkfU0>NeU03WYH`0kkfU0?OF_@3gg/h0mkfe0>N]W0030>nDS00K0>N4L`2mFT80cUY:0=ISDP3>
Le80iiB40=ikJ`3FS7<0ihAc0=IkJ`3FW8@0eZF<0<J]Y@3N]JD0eYb<0=K6]@3>]KD0eYb<0;f4J`36
[JD0aYAk0;EkH`2U@S40aV]B0=ISDP3FLf<0eW][0080eXak00L0cXb40=JLQ03FW7<0eYac0=JLQ03N
W8@0gZF<00<0gZfD0P3W]I@0103N[I@0gYb40=jUS03NYH`50=j]U0030=jeW03Fa/H0knOW0240moOg
00<0mno_0?Ogm`3gknl01@3gmoLP0?ooo`007P3oool0103Hem00jNWQ0>WXh03Ti=`40>;RfP070>;Q
fP3Rh=P0h]oG0>;Oe`3RgmP0h^;J0>;Rf`060>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0`3Ri=h20>;U
gP@0h^GO0300h^GP0>;Vh03Ri^00h^KP0>?WhP3Tj>80hnSR0>3TgP3@cl/0a<2l0:fPVP2TThX0WhMg
0:F;M`2`UGl0c;6H0=RnY@3Sb[80i<Zd0>76[`3P`j`0g/:Y0=o4[03Qb[D0h/fi0>??_@3Tc[`0i<Vf
0>C7/P3R`JP0h;fS0=ZdV03G/9<0dJJ;0=2RRP3BXi00eJRF0=b_XP3N[Z<0gJZP0=:FS036R7h0[6iS
0:EYG@2_NF`0_8Qk0=>MT03GWi820=RKSP0j0=RTU`3IZil0f[^^0=Zo/`3I_;00f;>V0=FMS`3CUhP0
c9B30<REPP30TGd0_8eh0;R7L`2gQg@0]hMf0;>4MP2_Og40Yg9S0:M/G@2`JEX0]f]N0;miJP30PW40
`I=l0<:HOP35W7d0aYel0<VNP03;WX<0cJ:;0<fTSP3?ZI<0d:bD0=>^U03C[I<0dZZ@0=2XS`3?YXh0
cZF>0<jVS`3=YXh0cJF>0<jUSP3>Yi00dJjI0=>eX@3Jb;P0g];50>CRfP3Ui^40iN_W0>G/j@3UkNT0
iNcX0>G/i`3UjnL0iN_V0>GZiP80i>[U0P3TjN@01P3TjN<0i>SS0>CXhP3Tin80i>OQ0>?Wh@<0hnKP
0P3SiMl20>?UgP80hnCM0`3Rhm`01`3Rhm/0h^;K0>?Sf`3Wi]l0jNSQ0>GTg@3Hem00:P3oool60?Og
m`030?O_k`3gmoL0moOg02<0moOg00H0imk_0;fe_@2<Ng<0FT8i0<JLQ03ge/H40?OF_@060?OFaP3g
e[d0mlje0?O6[@3__JD0mmk>0`3ge/H0503ge[d0mmK60>o6[@3gaZd0ikFD0>NUS03NU7<0gYb40?OF
_@3ge/H0ijfD0>N4N`3WU8@0ihAc0<j4H`24:AP0HaP@0>o>]@3W[I`0gV]J0P3WU8@03@3NNf/0kkFU
0?OWgP3gknl0mnON0>oFcP3W[I`0eW=S0>NDQ03>S7<0eW=S0<I[DP2mQ6<00P2mYI`02@36U8@0YF]B
0:ecFP2UDST0cUY:0=ISDP3>LeX0eW][0<jDN`020=JLQ0040<JLQ03FW7<0gYb40=jUS080gZfD00@0
ikFL0>NeU03W]I@0ikFD0`3NYH`20=j]U0060=JUS03NYH`0gZfD0=j]U03__Jd0e/K60P3gimhW0?Og
mb00oooo000N0?ooo`050=SHd03YjN40jNWQ0>CSf`3RhMT00P3Rh=P20>;Qf@060>;Pf@3RgmP0h]oH
0>;Pf@3Rh]X0h^;K1P3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@<0h^CN0P3RiMh40>;Ug`0`0>;Uh03R
i^00h^KP0>;Vh03Tj>80iNWT0>CXh`3MhM`0`;nj0:jXY02FQgl0V8Ai0:jDP02mX8X0bJbD0=ZoY`3O
aJd0i<Zd0>?9]03Q`jd0gl2X0=fmY@3N_jP0h<Rd0>;<^@3Sc[d0i<fl0>C9]P3Ta[40h[fT0=ngW@3G
Zhh0e:F70<fJO`3:UWd0aHek0<>:N`32R7l0`hZ30<J=Q`35T8T0`8b40;1oMP2/OW@0]i250<:OT`3G
]ZX0fkV^0P3M]jh0:P3N_;@0gl:j0>;Ab@3Selh0hm;80>77^`3K[9h0f:BE0=:STP3>YYD0b:VG0<FX
U@2oY980_J:B0;VOT@2^TXH0YXMk09M^H02CI5D0UEU:09YIBP2XIED0[fmN0;^5K`2oSWD0aIYl0<NM
OP3:WX80c9j50<nQR`3@Y8l0dJbE0=>_U`3E/IL0eK2F0=B]TP3CZi40dJV?0<nWSP3>YXh0cJF=0<fS
S080cJ::00T0cJJ>0<j[U@3C_Jl0elNn0=gIeP3Ogmd0h^OT0>?Yi@3UjnL00P3Uk>L0103UjnL0iN[V
0>CZi@3Tj^D20>CYi0050>CYh`3Tj><0i>SS0>CXhP3Tin800P3Sin420>?Vh0050>?Vg`3SiMl0hnGO
0>?UgP3Si=h00P3Si=d30>;Sg0070>;Sf`3Rh]/0hn?K0>OVg`3Yj>00iNCM0=SGd00Z0?ooo`<0moOg
00<0mno_0?Ogm`3gmoL02P3gmoL00`3gknl0moOg0?Ogm`0I0?Ogm`050:fU[@2DQ8@0FT8i058a:@3_
e/h00P3ge[d20?OFaP80mmJm00@0mlje0?O6[@3__JD0kkfU1@3ge/H0403ge[d0kkfU0>NeW03WYH`0
gYb40=JLL`3WYH`0kkFU0=ikJ`3FHe80W3TY048H403N]I`0kkf]0?ONcP3gc[D20?OWgP<0mno_00L0
mnON0?OWi`3gknl0mno_0?OWgP3gg/h0mnON00D0kmK>00X0e/K60;EB>@36Je80]G=J09AcJ`2eS7<0
U58i07=:>@2mFT80cUY:0P3FLf<0303NW8@0eYb40<JLQ03FW7<0gYb40=jUS03W]I@0ikFL0>NmY@3_
_JD0ikFL0>NeU080gZF<00@0gZfD0=JUS03N[I@0gZF<0`3N[I@01P3N]I`0e/Je0?Ogm`3Ne^L0g/kF
0>ONibD0moOg803oool001h0oooo00D0f=S@0>WZh@3YjN40i>?K0>;Pf@020>;Oe`030>;Pf@3RhMT0
h^7I0080h^3I00<0h^7I0>;Rf`3Rh]/01P3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@<0h^CN0P3RiMh4
0>;Ug`1X0>;Uh03Ri^00h^KP0>?Vh@3Tj><0iN[T0>CXh`3Lh=/0^KNc0:>MV02:Ng<0T7a`0;6GP`33
Yi00dKBL0=o4[03Rak00i<Zd0>?9/`3P`j/0gknW0=fkX`3N_JL0h<Jb0>;:^03Sc[d0i<fl0>C8]@3T
aK00hK^S0=jdVP3FYHP0dIj10<^DN@37SgH0_H5^0;MhJP2`L6T0/WE_0;IoN@30Th`0`9R@0;^HS`2j
VHl0a:NL0<bbY`3Ja;T0g/Nm0>37_`3Pal00hL[40>;>b03TfM40iMcD0>CGc03RcL40gKRX0=^bX@3G
/Z80eKJV0=2iZP3>^:T0ak>T0<>_XP2nZYh0[iV>0:J<P@2DKf80SF=E08UEAP2<E4@0VUi=0:AWE@2f
OFL0_HQ_0<BHN`36W7l0bYj30<bNQ@3?XH/0d:F?0=>]UP3D/9P0e[:H0=JaU`3E[i@0e:fB0=>[T@3@
Z8h0cjJ>0<fSS03=XX/0cJ690<bQR03<Y8`0cJVC0=6j[@3Ca;d0fMGE0=_Kf`3Phn40hNGR0>CYi@3T
j^H20>G[i`030>CZiP3Tj^D0i>[U0080i>WT00D0i>WS0>CXh`3Tj>80i>SR0>CWhP020>?Wh@80hnKP
00D0hnKO0>?Ug`3SiMl0hnGN0>?TgP020>?Tg@<0h^?L00L0h^?K0>;Rf`3Shm/0inKO0>WXh03Ui=d0
f=O@02X0oooo00<0moOg0?O_k`3gmoL0:@3gmoL01@2]U9@0S7]c04Xa<@1SBT80mmK600<0mmJm00<0
mmK60?O>]@3ge[d0103gaZd20?OFaP0C0?ONcP3ge/H0mmK60?OF_@3__JD0ikFD0=jLQ03NU7<0gYb4
0=jUS03FLf<0cUY:09`i:@24BST0U58i0>o>]@3ge/H0mmk>0?OFaP020?OWgP80mnOW00<0mno_0?OW
gP3ginL00P3gknl20?OWgP030?ONcP3_e/h0mnON00@0kmK>01D0cUY:0<icFP3>FTX0YF]B0:ekJ`1c
@S40LdXi09`i:@2mFT80cUY:0<icFP3>S8@0eYb40=JLL`3FW8@0eZF<0=jUS03N[I@0ikFD0>NeW03_
_JD00P3W]I@20=jUS0<0gZfD0P3NYH`20=j]U0060=jeW03__Jd0mno_0?O_k`3Fa]H0g/kF9@3gmoLP
0?ooo`007P3oool02P3Hf=00jN[R0>WYh@3Thm/0h^3H0>;NeP3Rg]L0h^3I0>;QfP3Rh]X40>;Rf`03
0>;Sf`3Rhm`0h^?L00@0h^?L00<0h^?M0>;Tg@3Ri=d00`3Ri=d30>;TgP80h^GN103RiMl0<P3RiN00
h^KP0>?Vh@3Sin80i^[U0>O/i`3Tj>D0f]cJ0:bYYP2@RXH0MFIM07m/G`2`V8<0b:jG0=RmY@3TbK80
i<Zc0>?:/`3SbK40hLBZ0>30Y`3N_:@0gkjW0>75/@3RbKH0hlbk0>C<^P3Sak@0hl:^0=jfW@3J[I80
ciYm0<^BM034Qf/0_gmV0:aWE02PEdT0T4Q009=AB`2MIEl0^IR?0<F[X@3D`KD0f<Fi0=c;_`3Nc/80
hMC:0>;Hc`3TgML0i=kI0P3Ug]P0=P3VgmH0i]kD0>CHbP3Rd/<0glRf0=k7]03Nc;d0gm330=kBa`3L
cl@0e/Nk0=71]P3:^k00^JNM0:nIS`2KNfl0TFiP085MCP1nFTT0QUY908mNC02VK5P0[gMQ0;f<LP32
U7X0bI^20<^LQ03?XH/0dJJ?0=F_U`3F/YX0ekBL0=NdV`3G/YP0e[6F0=F_U03AZXl0d:N>0<fRRP3=
X8T0cIn70<fOQP3<Xh/0c:NB0<beZP3<_[P0cl_=0=7@d@3Fe]@0f=WF0=gPg@3Ohn40h^SU0>?Yi@80
i>[U0P3TjN@00`3TjN<0i>SS0>CXh`020>CXhP030>CWh@3Sin40hnKQ0080hnKP00L0hnKO0>?Ug`3S
iMl0hnGN0>?TgP3Si=d0h^CM00<0h^?L00L0h^?K0>;Rf`3Shm/0inKO0>WXh03Ui=d0f=O@02X0oooo
00<0moOg0?O_k`3gmoL0803gmoL20>oWi`030?Ogm`3gknl0mno_00@0moOg00L0S7=[0592>@1B<BT0
S7=S0?OF_@3_c[D0mmK600@0mmJm00@0klJ]0?O6[@3_aZd0mmJm1@3ge/H03@3ge[d0ikFD0>NUS03N
U7<0cXAS0<icFP2eDST0S2TQ08@Y602DDST0YG=J0=jeW03ge[d00P3gimh0203gg/h0mnON0?OFaP3g
imh0mnOW0?OWgP3ge/H0mnON0P3gknl01P3gimh0mmk>0>o>]@3_e/h0mnOW0?OWgP<0kmK>01L0e/K6
0?OFaP3_e/h0aZfU09AB>@2<<BT0Lb4@048Y8@1:40P0]E8i0<iJBP3FNf/0eXac0=JLQ03FW7<0eZF4
0=jUS03N[I@0ikFD0>NeW03__JD0ikFL0>nmY@030=jUS080gZfD0P3NYH`30=j]U0070=jeW03_e/h0
e/KF0>ONk`3gknl0imk_0?O_k`0S0?Ogmb00oooo000N0?ooo`090=SHd03Yj^80jNWQ0>CSf`3Rh=T0
h]kG0>;Oe`3Rh=T0h^7J00@0h^;K0P3Rhm/60>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0`3Ri=h20>;U
gPD0h^GO06h0h^KP0>?Wh@3Tj>80i^[U0>O[j03Ri^@0emWH0:JRX@29PGl0KEiE07UVF@2_Uh80bJnH
0=ZoY`3Ub[<0i<Zc0>?:/P3SbK00hLF[0>32Z03O_jL0h<2Y0>76/P3RbKH0i<bk0>C;^P3SaK80hL2[
0=baV03GZ8d0biIg0<J>KP2nP6<0^GMM0:EKB@2HBcd0Qcdd08]7?`2HGED0^YB:0<R[W`3JaKP0g/^m
0>7>`@3Rcl80h]?90>?Hc`3Uh=X0iN;L0>GQf@3Vh=L0i]kB0>KLc`3Te/H0h]2o0=k8]P3Mb;H0gm32
0>3Db03Pe<X0gm760=[8_03Fa;P0d;nd0<:_Y02iXiL0YHMi09]kK029JeX0Q6IE08APC`29GTd0VFAA
0:=/F02fPVX0_X]c0<NFOP39VH80cZ6:0=6VSP3E[iL0ek>J0=RfW@3I]Yd0f;BJ0=NcV03F/9D0dZ^A
0=2WSP3=XXX0cJ280<fMQP3=WHD0c:690<bUT03;/jL0b[^c0<_7a@3<b/P0d<k;0=;AcP3HfMP0fmgM
0=oTh`3QinD0i>WU0>CZi@3Tj^@0i>WT0>CYh`80i>SS00@0i>SR0>CWhP3Sin40hnOQ0`3Si^001`3S
i]l0hnGO0>?UgP3SiMh0hnCN0>?Tg@3Ri=d00`3Rhm`01`3Rhm/0h^;K0>?Sf`3Wi]l0jNSP0>GTg03H
em00:P3oool@0?Ogm`050?O_k`3gmoL0moOg0?Ogm`3gknl03`3gmoL01@3gknl0moOg0?Ogm`3Wg^l0
mno_00<0moOg00@0U8B406=BBP1J<BT0aYb40P3ge[d40?OFaP050?OF_@3gaZd0mlJ]0?O>]@3ge[d0
0P3ge/H20?ONcP80mmJm01H0ikFD0>NUS03>S6/0eW=S0:E2<@2L>BT0Q2TH07/Y602DFU80]G=J0>N]
W03_c[D0mnON0?OFaP3gg/h0mnON0?OF_@3gimh0mnOW0?OWgP3ge/H0mnON0P3gknl01@3gimh0mmK6
0?O6[@3ge/H0mnOW0080mnON00l0kmK>0?OFaP3Fa/H0mmK60=K6aP3_e/h0aYB40:e[DP2]Nf/0BQ08
01P@402L>BT0]E8i0<iJBP3>S7<00`3FW8@00`3NYH`0gZfD0>NeU0030>nmY@0B0>NeW03W]I@0gZfD
0=j]U03FYH`0gZfD0=JUS03NYH`0gZfD0=JUS03N[I@0g[FL0<jm]@2eW9`0e/K>0=K6eP3gknl0imk_
8`3gmoLP0?ooo`007P3oool02@3Hf=00jNWQ0>WYh03Thm`0h^;J0>;Pf@3RhMT0h^7J0>;RfP020>;R
f`@0h^?K1P3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@<0h^CN0P3RiMh40>;Ug`80h^KP06`0h^GO0>7T
gP3Oh]d0g^3L0=?Ce036a<L0V92B07icLP1ZEdh0NF=E0;2GP@3:/9P0fl2W0>G;/@3Ub[40hlV_0>?8
[P3RaZ`0h/F[0>;5[03RaJh0hlRc0>?:]`3Tc;X0hlZh0>71[P3N^JD0eZR?0=2PQ034TG40_hYZ0;Qj
G@2cL5H0XEM309E:>P29@CD0SdXo09eMDP31S7l0cj2B0=jiZ@3P_jd0h<6`0>30/@3PaKT0hL_00>?H
cP3Tfm40iMW;0>GFa`3Ud/00i=2n0>79]P3O`k00f[ZY0=ZjZP3L`[H0gLJl0=g5^@3K`;<0fKZZ0=Vk
Z`3H_Jh0dk^/0<fdY02mWhd0]9F30:F9N02MPg<0SG9S08IWF@23FDX0ReY:0:AZEP2`M600_hQb0<B@
NP3;WhP0cjJ=0=J`U@3H]IT0fkZP0=^kX@3J]il0f;FK0=JaV03BZi80d:R@0<fRR`3<WhP0c9^40<bK
P`3<WXL0c::<0<Z_W@38]JH0aknd0<K1]`37`k`0bLC10<k<cP3AdMD0fMcO0=gQhP3Sj>D0i>[U0>GZ
i03TjN@30>CXh`040>CXhP3Tin80hnOQ0>?Wh@80hnKP0P3Si]l01P3SiMl0hnGN0>?UgP3Si=h0hnCM
0>;Tg@<0h^?L00L0h^?K0>;Rf`3Shm/0inKO0>WXh03Ui=`0f=O@02X0oooo0P3gmoL00`3gknl0moOg
0?Ogm`0J0?Ogm`030?O_k`3gmoL0moOg00P0moOg00L0oooo0=kFi`1S@S40BS4a0<JDN`3ge/H0klje
00H0mmJm00@0klJ]0?O6[@3gaZd0kkfU0P3ge/H0203gg/h0mmK60?OF_@3gaZd0cXAS0=jLQ036S6<0
cXa[0P2mFT805`2U@S40S2TQ0:eJ@P3WQ7<0gW][0>NUS03NU7<0kkfU0?OF_@3g_KD0kkFU0?ONcP3g
imh0mlJ]0>N]U03ge[d0mmK60?ONcP3ge[d0ijfD0>nDS03_]JD0kkfU0080kmK>00L0mmK60>N]U03_
c[D0e/K60?OFaP3_c[D0klJ]0080g[FU00L0_Ib<0=JUS024BST0Ld8a0:E2<@2eDST0cXac0080eYb4
00X0gYb40=j]U03W]I@0kkfU0>o6[@3__JD0ikfU0>NeW03N[I@0gZF<0P3N[I@00`3FYH`0gYb40=jU
S0030=j]U0060=K6]@3>]Jd0c[fe0<jm]@3Fa[d0g/kF4@3gmoL00`3gknl0moOg0?Ogm`0?0?Ogmb00
oooo000N0?ooo`050=SGd03YjN40jNSP0>CTg03Rh]X00P3RhMX20>;RfP80h^;K0`3Rhm/70>;Sg003
0>;Sg@3Ri=d0h^CM00<0h^CM0`3Ri=h20>;UgP<0h^GO0P3Si^00K@3Ri^00h>?L0=gPf@3Fem00dM7<
0<:o`02e/;<0Sh>507]/J`1`FU40P6QJ0;FJQ03</YT0fl6W0>G;/03UbZl0hlR]0>?7[@3SaZ/0hlF[
0>?6[03SaZh0hlRc0>?:]P3Tc;T0hlZg0>30Z`3M]j80eJF<0<nMPP34TW<0_he]0;UoHP2eMU`0YV5=
09eGAP2DDD<0VUU<0:MXF`37SGl0dif>0=fbX03N]Z@0g[NU0=fgYP3M_:h0g/:f0>7>``3RdLD0hljo
0>?;^P3Sak@0h/Jb0=joZ`3L^JH0ejjN0=N]WP3H/jP0fKN/0=ReZ03G/J<0ejjM0=RbX@3I^:L0ekb[
0=>gY@35YI80_Yf:0;6CPP2ZSGh0UGY]08Y]H@1nF4/0PeE709UNC02UIe@0^7iZ0;n:M@3:WXH0cjF<
0=JaU@3H]IT0fk^Q0=blX`3J^J00f;FL0=JaV03BZi80cjR@0<fRR`3<WhP0bi^40<bKP`3<WXH0bj::
0<Z]V038/j00akb]0<No/P38`[/0b<C00<_8c03>c=80e]SL0=_Nh03Sj>@0i>[U0>GZi03TjN@00P3T
j><20>CXhP030>CWhP3Sin40hnOQ0080hnKP00@0hnKO0>?Ug`3SiMl0hnGN0P3Si=h00`3Si=d0h^CM
0>;Sg0020>;Sg0070>;Sf`3Rh]/0hn?K0>OVgP3Yj>00iNCL0=SGd00Z0?ooo`P0moOg00H0mno_0?Og
m`3gmoL0mno_0?Ogm`3gknl60?Ogm`030?O_k`3gmoL0moOg0140moOg00/0mno_0?Ogm`3Nc]H0]IbL
048Y8@1B<BT0g[FU0?OFaP3ge[d0mkfe0?OFaP020?OF_@80mlJ]00@0kkfU0?O>]@3gaZd0kkfU103g
e/H02`3ge[d0kkfU0<j4H`3NW8@0cXAS0=J<L`3NW8@0ihAk0<icFP2U@S40]E8i0080eW][00H0ihAk
0=jDL`3WYH`0ikFL0?Nm]@3WYH`20?OF_@060>N]U03W[I`0mkfe0>o>]@3g_KD0ijF<0P3WQ7<01`3_
U8`0ijfL0>o6[@3_c[D0ikfU0=jDL`3W]I`00P3ge[d03@3_c[D0gZfD0=jeY@3N]JD0_Ib<0=JUS02]
Nf/0W6]B09`i:@2U@S40eW=S0<jDN`3FW7<00P3NYH`00`3W]I`0kkfU0>o6[@020>nmY@040>NeW03W
]I@0gZfD0=JUS080gZF<00`0eZF40=jUS03NYH`0gZfD0=jeW03N]JD0e/K60=k>eP3Fa/H0e/Jm0<jm
]@3Wg^lR0?Ogmb00oooo000N0?ooo`050=SGd03YjN00jNSP0>CTg03Rh]/00`3Rh]X50>;Rf`80h^?K
1P3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@<0h^CN0P3RiMh30>;Ug`0D0>?Vh03Tin80hnKP0=SJd`3>
c/H0]:nV0:JOU`2=PWl0PgMd07UUHP1jHUd0S6iR09eoKP35Z940e;VP0=k4Z@3TbZl0i<V]0>?5ZP3S
`jP20>?1YP170>?2Z@3Sa:/0hlR`0>?:/`3Tc;D0hlZd0=nnY`3L]9d0e:::0=2MP`39VWd0aiYm0<FG
O033U7X0_Xef0;Z:M02iRGD0_H]j0<B@P@3DWY00fZBF0=j/W03M[Yd0fZfL0=V]W03I[j00fK>T0=^j
[03M^Z`0gkFV0=naX`3M[ih0fjjM0=JYU`3DXi80dYJ70=6BQ@3BTHH0dY:60=2@P`3?Sh40ciF40=6N
S03CZ9D0eKBO0=>aW03;Xhh0aib80;jDQ@2hTH@0YH=i09UhKP26H5@0PEE808A:?02<CSl0YVQG0;=i
J038Uh40cj:90=J`T`3H]IP0g;bQ0=bmX`3J^Il0f;FK0=JaUP3AZHl0cjJ=0<^QR@3:WhL00P39W8D0
403:WhL0bj::0<ZYT@39[IH0bkVU0<g0[`3@bL40cl[70<_7c@3;all0d]7G0=SIg03Rin<0i>WT0>GZ
i03TjN@20>CXh`030>CXhP3Tin80hnOQ0080hnOQ0P3Si^00103Si]l0hnGO0>?Ug`3SiMh20>?TgP80
h^CM0P3Rhm`20>;Sf`060>;Rf`3Shm/0inKN0>WXh03Ui=`0f=O@:P3ooolX0?Ogm`040=K6eP2eW9`0
FT8i0592>@80<B4H00@0klje0?OF_@3ge[d0mmJm0P3ge/H01`3gc[D0mlJ]0?O6[@3gaZd0mlje0>nm
Y@3W]I@0103ge/H01`3gc[D0kkfU0<icDP3>S6/0gZF<0>N]U03g_KD00P3_c[D01@3__Jd0kkFU0>N]
W03_U8`0ijfL0080kiB<00@0ihAk0>N4L`3WQ7/0gW][103WQ7/00`3NW8@0ihAk0=ikJ`020=ikJ`80
eW=S01L0eXac0>N4L`3NNf/0cXAS0<j<J`3W_JD0klJ]0=jUS03>S6/0g[FL0>o6[@3FYH`0gZfD0<JD
N`2eNf<0Lb4@07/Y602U@S40aV]B0=JLL`3FYH`0gZF<0>NeU0040>nmY@040>NeU03W[I@0ikFD0=JU
S080eZF400@0eYb40=jUS03NYH`0gZfD0P3N]I`00`3Fa[d0imk_0>ONk`020<jmaP030=K6eP3gimh0
moOg0200moOg803oool001h0oooo00D0f=O@0>WYh03Yj>00i>CL0>;Rf`030>;RfPL0h^;K00<0h^?K
0>;Sg03Rhm`00`3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@<0h^CN0P3RiMh20>;Ug`0E0>?Ug`3Si^00
i>OR0>;Uh03Cdl`0a<:j09jGS@2;PWP0Kf9K06QIE01^F580NV1H09alK@2^SW`0c[2I0=VmY03PaJX0
i<V^0>C8[@3S`ZP0hl2V0080hkjT05X0hl2V0>?2Z@3Sajh0hlVa0>C;/`3SbK40gkbU0=bcW03DXXX0
dIj50<bMPP3;Wh@0c:>90<bTR`3;YHh0bZF>0<^UT@3>YY<0dZNF0=^ZW@3N[9l0gZjP0=f_W`3J[Yd0
fJfL0=R^WP3H/:40fK>T0=^bY03M[9h0gJRK0=^VU`3HYIH0dj6@0=:KR`3@Sh00d8Yl0=26N@3@QGP0
cX=e0<f3M@3<SG`0cYJ40<nPS@3A[IL0d:^E0<^MR038UX<0`Hn10;b<P@2/PgT0XW]a08eTF024ETT0
OT<f0893=@2LG4h0[6mO0<JAO@3=WHD0eJjB0=RdU`3L^j40g;bR0=ZiWP3H]IT0e[2E0=6YSP3?YH/0
bj280<VNQ`38WHD0b9f60<ZPR03;XXX0bZN?0<Z[TP3<]Z40c[f/0=79`@3@b/L0blK;0<_6c@3Bd=D0
f=SJ0>;VhP3TjN@0iNWT0>CYh`3Tj><20>CXhP040>CWhP3Sin40hnOQ0>?Wh@80hnKP00H0hnKO0>?U
g`3SiMh0hnGN0>?TgP3Si=d20>;Tg@80h^?L0P3Rhm/01P3Rh]/0hn?K0>OVgP3Yj>00iNCL0=SGd2X0
oooo9`3gmoL02@3gknl0S7=S06=:@P0i:B40DS4Y048Q6012:B40mmk>0?OFaP050?OF_@060>nmY@3g
aZd0klJ]0?Nm]@3__JD0ijfD0P3ge[d0203ge/H0mmJm0?Nm]@3gaZd0cW=J0<j4H`3W]I`0ikfU0P3_
c[D20?OFaP<0mmJm00@0mkfe0>nm[@3_]JD0kkFU0P3W[I`20>neY@080>nDS03W[I`0kiB<0>nDS03W
[I`0gYb<0=jLQ03WQ7/20=ikJ`030=i[FP3>Le80cW=J0080eW=S0180gZF<0=jeW03>S6/0cW=J0=je
W03_aZd0cXb40=JUS02eS7<0[G][06<H401c8A00S2TQ0:EB>@3FS7/0gYb40=jUS03W]I@40>nmY@80
ikFD0140gZfD0=jUS03NW8@0eZF40=JUS03FYH@0gZF<0=JUS03N[I@0g[FL0>nm[@3gmoL0mno_0=k>
eP3Fa]H0mnON0=kFi`0Q0?Ogmb00oooo000N0?ooo`050=SGd03YjN00jNSP0>CTg03Rh]/00`3Rh]X4
0>;Rf`<0h^;J00<0h^;K0>;Sf`3Rhm`00`3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@<0h^CN0P3RiMh2
0>;Ug`80hnKP01<0i>KQ0>7SgP3;b/@0]kB/08MoM01aIU/0DdDm050o>01WCTH0O61F0:^:NP2nW8T0
e[RP0=g1Y`3QaZ`0i<R]0>C6[03S`:L0hkfU0080h[^R01T0h[jU0>;1Y`3SaZd0hlR_0>C9/@3Sak00
gk^T0=bbV`3DXXX0dIj50<jOQ@3>XXP0dJbC0=>aV03F^J80ekbT0=ZmY`3K_:P0gKVX0>2eZ03P]:P0
gk>U0=jcY03K/J40f[6P0080f;6Q03`0fK6R0=Z_X03MZI/0gJJI0=ZSU@3GXY<0dYf=0=6IR@3@SWh0
d8Uj0=22L`3?P700cGi^0<aoK`3;RGP0c9:00<fKR03>YY00cZ>>0<^FP`39T7h0`hUl0;n6N`2bP7H0
ZWY_09EUF@2:ETT0Ncha07`k;`2DDT@0YFAF0<68M@39UX00djZ?0=NbUP3K^Z00g;^Q0=ZhW03H]9P0
e[2C0=6XS03?Y8X0bin70<VMQP37WHD0aif60<VPR03:XXX0bjJ=0<^XS`3:/9/0b[JT0<_0^03;`[l0
bL?70<_5b`3CdMD0fMWJ0>7Uh@3Sj><20>CYh`040>CXh`3Tj>80i>SR0>?WhP80hnOQ0`3Si^020>?U
g`80hnGN00@0hnCN0>?Tg@3Ri=d0h^CM0P3Rhm`20>;Sf`060>;Rf`3Shm/0inKN0>WXh03Ui=`0f=O@
:P3oool30?Ogm`030?O_k`3gmoL0moOg0280moOg00<0BS4a048Y8@1261000P12:B401P1B<BT0mmK6
0>o>]@3ge/H0mmJm0?OFaP80mlje00@0mlJ]0>nmY@3g_KD0klJ]0P3W]I`0303ge[d0mmK60?OF_@3_
c[D0mlje0>o6[@3>Q6<0cW=B0>NmY@3_aZd0mlje0?OF_@<0mmK600D0mmk>0?OFaP3ge/H0mmK60?OF
_@050?Nm]@80kkFU00<0kkf]0>nDS03_U8`00`3_U8`20>N4N`070=IkJ`3>LeX0aV]B0<I[DP3>LeX0
eXac0=JLQ0020<I[DP0>0=j]U03N]JD0aXaS0=JLQ02]LeX0]G]S06<H401B40P0Lb4@08`a:@3FS7/0
eYb40=jUS03WYH`20>nmY@040>o6[@3__JD0ikFD0>NeU080gZfD00@0eZF<0=jLQ03FYH@0eZF40P3N
YH`02@3N[I@0g[FL0>nm[@3gimh0moOg0=kFi`3Wg^l0e/kN0=K6eP0Q0?Ogmb00oooo000N0?ooo`04
0=SGd03YjN00jNSP0>CTg0D0h^;J0P3Rh]/01P3RhMX0h^3I0>;Of03Rh=P0h^7J0>;Rf`@0h^?L00<0
h^?M0>;Tg@3Ri=d00`3Ri=d30>;TgP80h^GN0P3RiMl20>?Vh01_0>7RgP3LfmL0_;Nd0:2JU@1RFE40
B3he038T6`0g9al0IDi308I[GP32XY00e;BO0>;4Z`3SaZ`0hlN/0>?5ZP3S`jT0hk^V0>>iY03Q]j<0
hKRS0>2nY@3P`JL0h/J/0>?7[P3Ta:l0hl6/0=neXP3L[i/0e::;0=2MQ03;VWl0bif30=:^UP3H^J80
hL^f0>C@^`3Vdkl0i]6n0>K=_03TaKL0hl>d0>;0/@3Q_k00gkn_0=jo[`3M_jl0gKj^0=fkZ`3N^JT0
gkFT0=nbXP3L[I`0fZ^I0=JUT`3EXY00e9b90=BHQ@3BTWd0dHmi0<n=M`3?SGT0cI9n0<fFPP3<VHD0
cI^70<fHQ03=S7d0c8Mi0<QoM034O780^WIZ0;=bI02QH540UEA508<m<@21>2d0ST@h09YAA02cLf40
_XA`0<jQR@3DZi80f[JM0=bhWP3J]YX0f;>F0=J_T@3AYh/0cj>80<ZMQ@38W8@0aYZ30<JKP`39WXH0
bj680<fTR`3;Y8/0_in90;NKR02[V8d0[IjG0;nf]@3:a<@0fMOG0=gLf`3Ph]h0hNCO0>?WhP3Tj>80
i>SS0080i>SR0`3Sin430>?Vh080hnGO0P3SiMh0103Si=h0hnCM0>;Tg@3Ri=d20>;Sg080h^?K00H0
h^;K0>?Sf`3Wi]h0jNSP0>GTg03Hem0Z0?ooo`<0moOg00<0mno_0?Ogm`3gmoL0803gmoL02P3Wg^L0
aZfm048Y8@12:B40FS4Y06<i:@1B8AP0[HA[0?OF_@3ge/H40?OF_@070?O>]@3_aZd0klJ]0>o>]@3g
c[D0klje0?O>]@020?OF_@090>o>]@3ge[d0kkfU0>nmY@3WYH`0gYAc0=jUS03W_JD0mmJm0080mmK6
0P3gg/h60?OFaP80mmk>00h0mmK60?ONcP3ge/H0mmk>0?OFaP3ge[d0mlJ]0?O>]@3gaZd0kkfU0?Nm
]@3_aZd0ijfD0>nDS0@0ihAk00T0eW][0=IcH`3FLf<0eW=S0<j<L`3>HdX0]E8i0:eJ@P2U@S400P1S
610308`a:@0:0=J<N`3FW7<0gZF<0>NeW03__JD0klje0>nmY@3W]I@0ijfD0=j]U080gZF<0P3FW8@0
3@3FYH@0gZF<0=j]U03N[I@0g[FL0>nm[@1[DTX0U7]c0=kFi`3Wg^l0moOg0>ONk`3_inL0803gmoLP
0?ooo`007P3oool0103Hem00jNSP0>WXh03Ti=`50>;RfP80h^;K00H0h^7J0>;Pf@3RgmL0h]oH0>;Q
fP3Rh]/40>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0`3Ri=h20>;UgP1c0>;Ug`3Si]l0hnKP0>?Uh03P
gm`0fMOE0;Na[`2JTi00G5=<04<j<@0b9A`0>b/Q06aFB`2>MFL0bZbI0=ZlY`3Tb:h0i<R]0>C7[03S
a:T0hl6X0>>jYP3S^:D0hKNT0>2hY03O_jH0gl:X0>76[03Sajh0i<:^0>>n[03O]:80g:jK0=>RR`3?
W8<0b9Ik0<RIO@3AZi80ekRQ0>;<^03Ud[h0imG20>OC`@3Vd;l0iLZk0>C8^@3SaKH0h/Fe0>76]P3Q
akH0h<Ng0>36]P3P`k80hL6`0>6n[03Q_:T0g[JR0=bbW`3I[9P0f:ZF0=NVT@3GY8h0eIn70=BLQ03B
VH40dIV20=2JQ03>VhD0cI^60<fIQ03=UH80chYl0<j5N@3:OW80aW]_0;adIP2fKf00YV1?09eFAP2<
@cH0RClb0913>02HCD00[F]J0;QlJ@3;WHD0dZR?0=ZdVP3K]Y`0f[BH0=RbU@3F[Y40dJN:0<nSR03:
WHD0b9^30<JIPP36VX80bIf50<^OQ`3>Y8X0bj>:0;VGP02[S7T0VH=e09b:P02h[ZX0b<:o0=cIe`3O
g]/0h>7L0>7RgP3Si^40hnSR0>CXh`020>CXhP80hnOQ00@0hnKQ0>?Vh03Si^00hnKP0P3SiMl20>?U
gP040>?TgP3Si=d0h^CM0>;Tg@80h^?L00P0h^?K0>;Rf`3Rh]/0hn?K0>OVgP3Yj>00iNCL0=SGd2X0
oooo3@3gmoL00`3gknl0moOg0?Ogm`0F0?Ogm`030;fe_@2LS8`0<B4H0080FS4Y00P0@RTQ05Xa8@2m
W8`0mmJm0>o>]@3ge[d0mmK60?Nm]@80mlje00<0klJ]0?Nm]@3_c[D00P3g_KD03@3_c[D0mmJm0?OF
_@3ge[d0mkfe0>o6[@3__JD0ijF<0=jLQ03>S6/0ikFD0?OF_@3ge/H00`3gg/h30?OFaP040?ONcP3g
e/H0mmK60?OFaP80mmk>0`3ge/H00`3ge[d0klJ]0>o6[@020>nmY@80mlJ]00<0klJ]0>NeU03W]I`0
0P3W[I@00`3NW8`0gYb40=jLQ0020=J<N`0>0=J<L`3FNf/0eW=S0=IcH`36Je80_EY209`i:@2DDST0
YE8i0;EB>@2U@S40cXa[0=JUQ03NYH`20>nmY@080>o6[@3__JD0ikFD0>NeU03N[I@0gZF<0=JUS03F
W7<20=JLQ0080=JUS03N[I@0gZF<0=j]U03N]JD0Nf=B07=:>@3gimh20?Ogm`80knOW803gmoLP0?oo
o`007P3oool0103Hem00jNSP0>WXh03Ti=`50>;RfP80h^;K00H0h^7J0>;Pf@3RgmP0h]oH0>;QfP3R
h]/40>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0`3Ri=h20>;UgP0Y0>;Ug`3Si]l0hnKP0>;Tg`3LfmX0
eM;C0;Ra/P2SVYT0Mf]R06MICP1OC3h0J59408mfIP2YSWd0e;VS0=o4[@3Ub[00i<R]0>C6Z`3S`ZP0
hl2W0>>lY`3S^ZL0hKVW0>2iY`3O_JP0gl2Y0>75[03SaZd0i<>]0>>o[03O]Z<0g;6M0=>TS@3>WH@0
aY=h0<JDN@3?YHd0e[:K0>78]03Sc[/00P3Ud/000`3UdL00i<nn0>C>_@020>C=_0120>C>_P3Tckl0
i=700>CA`03Tckh0i<fl0>C8]`3SaK<0hKjZ0=nkYP3M]Z00gKFO0=beWP3K]9`0f;6G0=N_U03EZi40
eJV@0=>VS@3AXh/0cj280<bHPP3<U800cHem0<f:N`3:Q7D0ah9a0<1lJ02lMf<0/VeI0:eWE@2SGDd0
X5Y;09iFBP2PFDd0[6aL0;EjIP37UWd0cJ670=J^U03H/IL0f;:F0=N`T`3E[Y00dJN:0<nSR03:WH@0
b9^20<JIO`36VH00bIb20<bNQ@3>XXT0bj280;6=M`2NOFT0Pf]L08McI`2[X9L0`;Va0=_HdP3Og]P0
h>7L0>7SgP3Si^40hnOR0P3Tj>800`3Tin80hnOQ0>?Wh@030>?Vh0030>?Vg`3SiMl0hnGO0080hnGN
0P3Si=d01@3Ri=d0h^?M0>;Sg03Rhm`0h^?K0080h^;K00D0hn?K0>OVgP3Yj>00iNCL0=SGd00Z0?oo
o`030?O_k`3gmoL0moOg02<0moOg00P0Nf=J05Y2>@2LJe80[HAk0<J<L`2eLeX0S5Y:0>o>]@D0mmJm
00<0mlje0?Nm]@3g_KD00P3ge[d0103_c[D0mmJm0>o>]@3_c[D20?OF_@80klje00<0kkfU0>NUS03W
YH`00P3NU7<02@3_aZd0klje0?OFaP3ge/H0mmk>0?OFaP3gg/h0mmK60?ONcP030?OFaP030?ONcP3g
e/H0mmK60080mmK600<0mmJm0>o>]@3_aZd01`3__JD01@3W]I@0ijfD0>NUS03N[I@0gZF<00D0gYb4
0180eYb40=jLQ03FW8@0eXak0=J<L`3FNf/0cXa[0<j4H`2mQ6<0eYac0=jLQ03W_JD0ikFD0>o6[@3_
_JD0ikFL0>NeU03NYH`20=JUS080eZF400<0eYac0=JUQ03N[I@00P3N[I@01`3N]JD0S7]c08akL`24
He80]IbL0?Ogm`3_inL08@3gmoLP0?ooo`007P3oool0103Hem00jNSP0>WXh03Ti=`50>;RfP80h^;K
00H0h^7J0>;Qf@3Rh=T0h^3I0>;QfP3Rh]/40>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0`3Ri=h20>;U
gP0[0>;Ug`3Si]l0hnKP0>;Tg`3Kf]X0e=7C0;jf^@2`YZ@0ThAi08UgJ024K5X0Rg1N0:J:MP2hW8L0
ekbT0=o4[03TbJh0i<R]0>?6Z`3S`ZL0hl6W0>>nZ03S_JP0h[^Y0>6jZ03P^jP0h;jY0>;4[03SaZh0
hlF^0>?2[@3O^JD0g;BN0=>VSP3>WhH0b9Ej0<REN`3?Y8`0eK2I0=o4/03Rb[L0i<nn0>C@_`020>CA
`00c0>C@_`3Tckh0i<jm0>C?_P3Td;l0i=;10>GB`P3UdL40iLno0>G9^03TaK@0h[j[0>2kY`3N^:40
gKNP0=bgW`3K]ih0f;BJ0=NbV03F[Y@0eJbC0=>WS`3AY8/0cZ680<ZJPP3:UX00bi1n0<^>O038RgP0
aXUe0<64KP2nPF/0^7UT0;EeH@2^KUd0Zf]K0:QWFP2YIe/0/G=S0;MnJP35UGX0c9n20=B[T03G[i@0
f;2E0=N_TP3E[Hl0dJJ:0<nSR03:WH<0b9^10080aYYo00l0bIb20<bNQ03>XHP0bYn70;2;MP2LO6P0
P6UK08=`I02UVi40^kB[0=SEcP3NgMH0hN?N0>;Uh03Sin800P3Tj>80103Tin80hnOR0>?Wh@3Sin43
0>?Vh0050>?Vg`3SiMl0hnGO0>?UgP3Si=h00P3Si=d01@3Ri=d0h^?L0>;Sg03Rhm`0h^?K0080h^;K
00D0hn?K0>OVgP3Yj>00iNCL0=SGd00Z0?ooo`80moOg00H0mno_0?Ogm`3gknl0mno_0?Ogm`3gknlN
0?Ogm`0;07]SFP1B<BT0mkfe0?OF_@3__JD0ikFL0;F<L`3ge/H0e/K60?OF_@3_c[D00P3ge[d01P3_
c[D0mlje0>o>]@3g_KD0mmJm0?O>]@D0mmJm00/0mkfe0?O6[@3gaZd0ijfD0>NUS03NU7<0cXa[0>nm
[@3_aZd0mmK60?OF_@020?OFaP80mmk>0`3ge/H00`3gg/h0mmK60?OFaP030?OFaP80mmJm1@3__JD0
1@3_aZd0kkfU0>nmY@3W]I`0ijfD0080gZF<00<0eYb40=jUS03NW8@00P3FW8@01`3NW8@0eYb40=JL
Q03FW8@0gYb40=JLQ03FS7/00P3>U7/01@3>S7<0eYac0=JLL`3__JD0ikFD0080kkfU00<0ikFL0>Ne
U03NYH`00P3FYH@30=JLQ0050=jLQ03NYH`0gZF<0=JUS03N]I`00P2DQ8@00`2eW9`0[IBD0?Ogm`0R
0?Ogmb00oooo000N0?ooo`040=SGd03Yj>00jNSP0>CTg0D0h^;J1`3Rh]/00`3Rhm/0h^?L0>;Sg002
0>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM103Ri=h04@3RiMh0h^GO0>?Vg`3RiMl0hN?N0=[If03Ed]80
cL?20<^n^03;]J@0b[6L0<VZTP3:ZI40cjjF0=>cVP3J_Z@0gL:W0080hLJZ05d0h/FZ0>;3Z03S`jP0
hlBZ0>?4Z`3R`:`0h[f[0>:kZ`3R_:`0hlB_0>?7/03Sb[40hlR`0=o0Z03L^j80eJfD0=6US03=Vh80
cIZ20=2SRP3DZY80fkZT0=k1Z`3Qb[H0h/fk0>??_P3Td/00i=;10>C@_`3Tckh0i<jm0>C?_P3TdL00
i=;10>GB`P3Ud<00iLNh0>C1/`3R^ZT0h;RU0=ffX03M]Ih0fkBL0=^cV`3H/YT0ek6G0=F]U03DZi40
d:J<0<fTR@39XHH0a9b10<>IP034UGh0a9Am0<BDN`33U7/0`Y=i0<6AN030SWH0_haf0;f:M@2lR7@0
^HAd0;V3M02kQW@0_H]d0<FGN@3:WWl0dJR<0=B/T@3F[Y<0eZfA0=B[SP3@YHT0cZ670<VLPP37Vh00
aIYn0<FKOP38W840bij30<bPQP38WX@0[H]e09YlJP1nJel0Og5W09jESP2d[:D0dm7:0=cLeP3Si^40
0P3Tj><00`3Tj>80hnOR0>?WhP020>?Wh@040>?Vh@3Si^00hnKP0>?Vg`80hnGO0P3SiMh0103Si=h0
hnCM0>;Tg@3Ri=d30>;Sg0080>;Sf`3Rh]/0h^;K0>?Sf`3Wi]h0jNSP0>GTg03Hem0Z0?ooobD0moOg
00<0imkW08A[FP3N]I`00`3ge[d00`3g_KD0e/Je0?OFaP030?OF_@040>o>]@3g_KD0mkfe0>o>]@<0
mmJm00<0mkfe0?OF_@3ge[d0103ge[d02P3g_KD0klje0>NeU03WYH`0iiB40=jLQ03W]I@0klJ]0?OF
_@3ge/H20?ONcPP0mmK60P3gg/h0103ge/H0mmJm0>o>]@3__JD20>NeU0050>neY@3__JD0kkfU0>nm
Y@3W]I`00`3NYH`02P3FYH`0eZF40=JLL`36W8@0eYac0<jDN`3FW7<0cYAk0=JUQ03FW7<30=JLQ007
0=JUQ03FW7<0eZF40=JLQ03FS7<0ikFL0=jLQ0020>nmY@030>NeU03W[I@0gZF<00<0eZF40P3FW8@0
1@3NYH`0eZF<0=jUS03N[I@0g[FL0080LeYB00<0e/Jm0=K6eP3gmoL0203gmoL00`3gknl0moOg0?Og
m`0G0?Ogmb00oooo000N0?ooo`040=SGd03Yj>00jNSP0>CTg0D0h^;J1@3Rh]/20>;Sf`D0h^?L00<0
h^?M0>;Tg@3Ri=d0103Ri=d30>;TgP0D0>;UgP3RiMl0hnKO0>;Ug`3Qhmh0fmWF0=SCc`3Dal40eLFk
0=_2[`3L`J/0g;bT0=bkXP3K^Z40f[^R0=^oY03L`JH0glBX0>34Z@3Qa:T20>;4Z@0K0>?5[03SaZd0
hl:^0>?0[P3S_Jd0hkn^0>?5/@3SbK<0hl^c0>?:/P3P`j/0gKfU0=J`U`3CZI00cin60<nMQ@3@XHT0
djJ>0=RdW03K^j@0h<Jb0>7;]`3Rc[`0hm;00>CB`@3TdL00i=2o0080i<jm01P0i=2o0>CB`03Ud/80
iM300>C7^03T`[<0hK^Y0>2iY@3M]Ih0g;>L0=Z`V@3I/9L0ejnF0=J_U@3D[980dZZ?0<fTRP39XXL0
aZ250<6LP@30VGl0`9Il0<6EN`32UGX20<6ENP0D0<6DNP31TWT0`I5i0<2@N@30SWT0_H]i0;f:N@2n
SGP0`91h0<JJO03:Wh40dJR<0=>[T03F[I80eJb@0=BZSP3@XhP0cJ260<RKP@36VWl20<FJOP0=0<RL
P03:WH40bj250<JMP`2[RG@0UgYX07YYGP1lKVH0W9B?0;>/Z03Dd/d0g=gH0>?WhP020>CYh`030>CX
hP3Sin80hnOQ0080hnOQ0`3Si^000`3Si]l0hnGO0>?Ug`020>?UgP040>?TgP3Si=d0h^CM0>;Tg@<0
h^?L00P0h^?K0>;Rf`3Rh]/0hn?K0>OVgP3Yj>00iNCL0=SGd2X0oooo903gmoL0103gknl0g]KW0?Nm
]@3_c[D40?OFaP030>o>]@3ge/H0klje0080klje00<0mmJm0?Nm]@3ge[d00P3ge[d30?OFaP040?OF
_@3ge/H0mmJm0?OFaP80mmJm00@0klje0?O6[@3W]I`0ikFL0P3WYH`00`3NW8@0ikFD0>o>]@020?OF
_@H0mmk>0`3ge/H30?ONcP80mlje0P3__JD20>NeU080kkfU0`3W]I@01@3W[I@0gZF<0=JLQ03FYH@0
eYb40080cYAk00@0cXa[0<jDN`3>U7<0cYAc0P3>U7/00`3FW7<0eYb40=JLQ0030=JLL`080=jLQ03W
]I@0gYAc0>nmY@3W]I`0gZfD0>NeU03NW8@30=JLQ0040=JLL`3FYH@0gZF<0=jUS0<0eZF<00@0DSTa
034Q8@3>_KD0imkW8`3gmoLP0?ooo`007P3oool0103Hem00jNSP0>WXh03Ti=`50>;RfP@0h^;K0P3R
hm/60>;Sg080h^?M1@3Ri=d30>;TgP0:0>;UgP3RiMl0h^GO0>;Ug`3Qhm`0gmW?0=kCa`3Nb[P0h<Re
0>C8/`80i/Vc00d0iLVb0>75[@3N`jX0fl2U0=ZoY@3L`JH0gL:W0=k3Z03QaJX0h/J/0>?8[`3Sb;40
hlJc0080hlFc01L0hlJe0>?;^03Sc;T0hlfh0>?<]`3PaJl0gl6Z0=ZfWP3H/IP0e:J>0=:RRP3@WHD0
d9j60=>WS`3E[iL0g<2Y0=k7/@3Qc;L0hm6o0>CC`@3Td/40i=700>C?_P020>C>_@0F0>C?_P3TdL00
i=2o0>C<^03Sb;@0hL2Z0=nkY@3L/i`0fZnG0=NXT@3FYhl0eJV>0=BZSP3@Z8`0cJJ90<JPQ032WX<0
_ib10;^HOP2jUW`0_9=g0;fAMP<0_Y1e0`2oTGH08`2oSgH0_hif0;j=M@2nSWH0`9=i0<>GO039Wh@0
c:B80=:YS`3CZi40eJZA0=BYS`3CYX`0cYn60<ZLP`36Ugl0a9Im0<BFO034Ug`0aY]n0<NMO`38Wh80
`i^00:B3KP2=LF00KEeD071TG`2HTY<0/jj`0=OFeP3Oh=l0i>SS0>CYh`3Tj><0i>SR00<0hnOQ00@0
hnKQ0>?Vh03Si^00hnKP0P3SiMl20>?UgP80hnCN0P3Ri=d40>;Sg0080>;Sf`3Rh]/0h^;K0>?Sf`3W
i]h0jNSP0>GTg03Hem0Z0?ooob@0moOg00@0g]KW0=K6]@3ge[d0mmJm0P3ge/H01`3ge[d0mmk>0>o>
]@3ge/H0e/K60?OF_@3_c[D01@3ge[d50?OFaP090?ONcP3ge/H0mmK60?OFaP3g_KD0mlje0>nm[@3_
_JD0ijfD0080ijF<00D0gYb40>nmY@3_aZd0mmJm0?OFaP020?ONcP060?OFaP3gg/h0mmk>0?OF_@3g
e/H0mmJm0P3gg/h02P3ge/H0mmJm0?Nm]@3_c[D0kkfU0>NUS03NW8@0gZF<0>N]U03W]I@20=jUS00;
0=JUQ03FW8@0eYac0<JLQ03>U7/0cYAc0<j<L`3>U7/0cXac0<jDL`3>S7<01P3>U7<02P3FW7<0gYb4
0=j]U03FW7<0ijF<0>NeW03W]I@0ijfD0=jUS03NW8@20=JLQ0060=JLL`3FW8@0eZF40=jLQ03FYH`0
gZfD0P3FYH`2058i<@0309B4Q03Fa[d0moOg0280moOg803oool001h0oooo00@0f=O@0>WXh03Yj>00
i>CL1@3Rh]X40>;Rf`80h^?K1P3Rhm`20>;Sg@D0h^CM0`3Ri=h0603RiMh0h^GO0>;Ug`3Qi=h0hN;K
0>3Hc03Pd/80hLVc0>76[`3SaZl0i<N`0>?7/@3Rak40g/B]0=c2Z`3I_jH0f;nU0=_0YP3L`JH0g/:X
0>75Z`3Rajd0hlRa0>?9/`80hlRe0300hlRf0>?:^03ScKX0hljk0>?>^P3Sc;T0hLJb0>32[@3L^:40
f[>K0=JYT@3DY8`0d9f50<nLQ03AXh/0e:ZB0=^mY@3Ma:d0h<Zd0>?@_P3Sd/00i=?10>CB`@3Tc[d0
i<bl0>?;^`3Sc;`0hlnm0>?@_03ScKP0hlZd0>72ZP3O_JD0fk:J0=V]U@3FYHd0eJB;0=>URP3BYXX0
cZF80<^SQP34WX80`9b10;fIO`2iUG`0^I=j0;ZAM@2lSg<20;f=LP0W0;f=L`2nSW<0_Y1b0;j?LP2m
S780_H]a0;b;L@2mS740`9=g0<BHO03;XHL0cZF;0=:ZT03DZY40e:V@0=BWSP3BY8/0c9f50<VJPP35
UGd0a9Al0<>EO033UW`0aIYm0<JLO`38Wh80`Y^00:60J`28KE`0IEI>06UMF@2ESi40/Jf`0=OGf03P
hN00i>SS0>CYh`3Tj><0i>SR00<0hnOQ103Si^020>?Ug`80hnGN0P3Si=h20>;Tg@@0h^?L0`3Rh]/0
1@3Shm/0inKN0>WXh03Ui=`0f=O@02X0oooo903gmoL01@3Wg^L0e/Je0?OF_@3ge/H0mmJm00<0mmK6
00H0klje0?OFaP3ge[d0mmK60?OF_@3gc[D30?OF_@H0mmK600L0mmk>0?OFaP3ge/H0mmK60>o>]@3g
_KD0mlJ]0080ikFL00L0ikFD0=jLQ03NW8@0ikFL0>nmY@3_c[D0mmK600@0mmk>203ge/H01`3ge[d0
kkFU0>NeW03N[I@0ijfD0=j]U03NYH`00`3NW8@20=JLQ0030<jDN`3FS7/0cXac00<0cYAc0P3>U7/2
0<jDL`030<jDN`3>S7<0cXac00<0cYAc0`3NW8@0103N[I@0ikFD0>N]U03NYH`20=JUQ00>0=JLL`3F
W8@0eYb40=JLL`3FW8@0eZF40=jUS03FYH`0eYb<0=jeW01:<C40DS4Y0:fDU036[JdH0?Ogm`030?O_
k`3gmoL0moOg00P0moOg803oool001h0oooo00@0f=O@0>WXh03Yj>00i>CL1@3Rh]X40>;Rf`80h^?K
1P3Rhm`20>;Sg@D0h^CM0P3Ri=h20>;UgP1=0>;TgP3Qi=h0h>7K0=oNe`3PeLL0hM2m0>;7[@3Qa:T0
h<2V0=nnY@3M_J<0fkbR0=JkY03C^jH0dK^Y0=>lZ@3J_jL0gL2W0=o2Z03RaZd0h/N`0>?:]@3SbkL0
hlbi0>?<^P3ScK/0hljk0>?@_@3Sd;h0hlnm0>?>_03RakD0hL:a0=nhYP3N]:40fZfG0=NYTP3CX8P0
dIf50=:PQ`3DYXd0f[JN0=fnYP3Oa:h0h/fj0>?@_P3Td/40i=700>C;^`3TakP0hl>d0>;4]03QbKD0
hL^f0>;=]03Rbk80gl:Y0=flX`3H/9P0ej^C0=BSR`3CX8P0cib20<fKP039Vh00aYb00<6JP02oV7h0
_9El0;V?M`2iSW@0^Xea0;^=L02kRg40_8]a0;f<L@2nSW400P2nSfl08`2lS6h0^hY]0;^9J`2lRV`0
`I5d0<JGN`3>XXT0dJF=0=BXT03DZ8l0djF<0=6SRP3?X8P0bYZ20<NGP034Tg`0`i=k0<>DO033UG`0
a9Un0<JLP038X8@0`i^109imJ@21IeL0EdY405Y@CP2:Q8@0ZJBT0=CBd03Mg]/0i>OR0>CYh`3Tj><0
i>SR0080hnOQ00D0hnKQ0>?Vh03Si^00hnKP0>?Vg`020>?Ug`80hnGN00@0hnCN0>?Tg@3Ri=d0h^CM
103Rhm`30>;Rf`050>?Sf`3Wi]h0jNSP0>GTg03Hem00:P3ooolT0?Ogm`80klje00T0mmJm0?OFaP3g
c[D0mlje0>nmY@3W]I`0klje0?OFaP3ge[d00P3_c[D01P3ge[d0mkfe0?OF_@3ge/H0mmJm0?OFaPL0
mmk>00P0mmK60?OF_@3g_KD0klJ]0?O6[@3__JD0ikFD0=jDL`80ijF<00@0ikFD0>o>]@3ge/H0mmK6
1@3gg/h0103ge[d0mlje0?OF_@3ge[d20?Nm]@050>o>]@3__JD0ijfL0=jeW03N[I@00P3W[I`02@3F
W7<0gYb40=JLL`3FW8@0eYac0<jDL`3>S7<0cYAc0<jDN`030<jDL`030<j<L`3FW7<0cYAk00<0cYAc
00P0cXac0<jDL`3FW7<0gYb40=jUS03W[I@0ikFD0>N]U0@0gZF<103FW8@02P3FYH@0gYb40=jLQ03F
YH`0gZfD0=jeW012:AP0<B4Q058a:@1SBT8S0?Ogmb00oooo000N0?ooo`040=SGd03Yj>00jNSP0>CT
g0D0h^;J1@3Rh]/00`3Rhm/0h^?L0>;Sg0050>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0P3Ri=h20>;U
gP0G0>;TgP3Qhmd0gmkH0=kKd`3Odl@0h<jk0>76Z`3Q`ZL0g[fR0=fjW`3I]YX0ekFI0=:eWP3?]Z<0
c[VZ0=6kZP3J_ZP0g/2X0>31Z@3RaJh0hlNb0>?;]`3Sc;T00P3Sc[/20>??_00;0>?@_@3Sd;h0hm2n
0>??_@3Sb;L0h/>b0>6hZ03O]J<0g:nJ0=V/U@3EXhX00P3CX8L0=`3EYH`0f[>K0=bjX`3O`:/0h/^h
0>?>_03Td/00i=700>C9^P3TaKL0h/2b0>71/@3Pa[80h<Vc0>;</`3Rbk40gl:Y0=blX`3H/9P0eZ^C
0=BTS03BX8P0cIV00<^FO@37Ugd0aIQn0<:IP02oUgh0_I=k0;Z=M02jRg80^Xa`0;^<L02kS740_8ab
0;f>LP2nSg40`95_0;n@K`2mSFh0_8]]0;^9J`2lRV`0`i5d0<NGN`3@XXT0dZF=0=BWS`3DYXh0dJ>:
0=2QR03>WXH0bIV10<NGO`34Tg`00P33Tg/03P33UG`0a9Uo0<JLP@39X8D0`ib209emJ@1nIEL0DDE0
059:A`20NgT0X9^H0<k;a`3JfM@0hnKQ0P3UjN<0103Tj>80hnOQ0>?Wh@3Si^430>?Vh0030>?Vg`3S
iMl0hnGO0080hnGN00@0hnCN0>?Tg@3Ri=d0h^CM0`3Rhm`02@3Rhm/0h^;K0>;Rf`3Rh]X0hn?K0>OV
gP3Yj>00iNCL0=SGd00Z0?ooob<0moOg00<0knOW0?O>]@3gc[D00P3ge/H01P3_aZd0mlJ]0>NeU03W
]I@0mmJm0>o>]@80mmJm00<0mlje0?OF_@3ge[d00`3ge/H30?ONcP030?OWgP3gg/h0mmk>00<0mmk>
0P3ge[d0103gaZd0klJ]0>nmY@3W]I`30>NUS0040>NeU03_c[D0mmK60?OFaP@0mmk>00D0mmJm0?Nm
]@3gaZd0mkfe0>o>]@020?OF_@0=0>o>]@3__Jd0ikFL0>N]U03N]I`0gYb<0=j]U03FS7<0eXak0=JL
Q03FYH`0eYb40<jDL`020<j<L`030<jDL`3>U7/0cYAk00<0cYAk00<0eYac0<jDL`3>U7<00P3>U7<0
203>S6/0gYb40>NUS03W[I@0ikFD0>NeW03NYH`0ijF<0P3NYH`01`3FYH`0eYb40=JUQ03FYH@0eYb4
0=JUQ03NW8@00P3FYH`01P3N[I@0eZF<048Y8@0a8B40@RTa05Y2>B<0moOg803oool001h0oooo00@0
f=O@0>WXh03Yj>00i>CL1@3Rh]X50>;Rf`80h^?K1P3Rhm`00`3Rhmd0h^CM0>;Tg@030>;Tg@80h^CN
0P3RiMl0603Rhmd0hN7J0=oIc`3NeLT0gljl0>3:]P3P`j/0gknV0=^gV`3H/YH0djZ=0=6YR`3=[9<0
c;2K0<jgZ03B^JX0fk^X0>2lZ03R_ZT0hlB`0>?7/`3Sc;T0hlfj0>??_0@0hm2m0P3SdKh0EP3Sd;d0
hlZi0>?5]03R_:/0h[VW0=ndWP3M/YX0f:Z@0=JVR`3EXXP0eJB90=V/U03K/Y/0g[VT0>;7]03Sc;X0
i=700>C@_`3TbKX0i<Fg0>:o/@3Q`;00h<B`0>37/@3Rb[<0h/Vb0=o1ZP3L^jD0f;2J0=J]UP3DYhl0
dZ>;0<bHP039UGd0aYAl0<JFOP34Uh00`YEm0<2@N@2lRG40^hM^0;^8KP2kRVl0^hab0;b=M02nT7D0
_i5d0<:CL`32TW<0`I1b0<2?L@31SW40`Xmb0<RFNP3;Vh00dZ>:0=>US03CY8/0dZ::0<nOQP3=WXD0
c9b40<VIP@37V7l0aIEm0<BDO033U7/0`iEl0<BIOP36W840bJ240<BLP@2LO6T0OF=E04Tm>014?3T0
If1L08AmM`2i]:d0c<[30>?TgP3VjN@0i^[T0>GXh`3Sin40hnKQ0`3Si^001`3Si]l0hnGO0>?Ug`3S
iMl0hnGN0>?TgP3Si=d00`3Ri=d30>;Sg0090>;Sf`3Rh]/0h^;K0>;RfP3Shm/0inKN0>WXh03Ui=`0
f=O@02X0oooo8P3gmoL0303_inL0mmJm0?OFaP3ge[d0mmK60?ONcP3_c[D0kkfU0>NeU03N[I@0mmJm
0?Nm]@D0mmJm0`3ge/H60?ONcP070?OWgP3gg/h0mmk>0?OFaP3ge[d0mkfe0>o6[@020>nmY@80ijF<
00D0gYb40>NUS03W]I@0klje0?OFaP020?ONcP060?OFaP3ge[d0mmK60?OFaP3ge[d0mmK60P3ge[d0
1P3ge/H0klje0>nm[@3_aZd0kkfU0>NeW0@0gZfD00<0cXa[0;f4J`3>S7<00P3>S6/03@3>S7<0cYAk
0<jDL`3>U7<0cYAk0<jDL`36W8@0eXak0=JLL`3>U7/0eXac0=JLL`3NYH`00P3W]I`20>NeU080ijfD
103NYH`40=JLQ0030=JLL`3FYH@0eZF40080eZF<00D0aZfU058a:@1:<C40Ng=k0?OWgP0S0?Ogmb00
oooo000N0?ooo`040=SGd03Yj>00jNSP0>CTg0H0h^;J103Rh]/20>;Sf`H0h^?L00<0h^?M0>;Tg@3R
i=d00`3Ri=d20>;TgP80h^GO01P0h^?L0>7Pf03Pel/0gm;30>3;^03QbK<0h<:Z0=jnY@3I]9T0eZjB
0=6VR@3?YHP0cJZA0<f_V@3A]jH0e;VX0=fiZ03P^ZP0h[bY0>?3/03Sa[@0hlbi0>?>^`3Sd;`40>?@
_@80hm6n05D0hm2n0>?;^@3Sb;D0hl2]0>:mZ@3P]j00g[FL0=Z]TP3GZHd0eJB80=FSR03GZ900fZjG
0=ffX03QaK80hl^i0>CA_`3Td;l0i<^k0>C7^03S`[<0h/:b0>76/P3Qb;<0h/Ze0>;9]03O`J`0gKbW
0=RaW03G[YP0e:RA0=:US@3<Vh<0bYMo0<NFOP37Uh00aIN00<>DO@31T7P0_8Q`0;^6KP2kQfh0^hU_
0;^;LP2lSG@0_Y1f0<2AMP32TgH0`i=f0<>BM@34TGD0aI9f0<NDN03;VX00cYj40=:UR`3CYH`0dJ>:
0=2QR03=WXD0c9f40<^LP`39VX40b9V00<JFOP35UGd0`iAk0<>EN`34VGd0aYao0<ROP`33Vh00WGeY
07iTE@19?3D0@CLb05YBC01dJf@0ZjBM0<:n]`3Ph=X0i^OR0>KYh`3Tj>80hnOQ00@0hnKP0`3SiMl2
0>?UgP030>?TgP3Si=d0h^CM0080h^CM0`3Rhm`02@3Rhm/0h^;K0>;Rf`3Rh]X0hn?K0>OVgP3Yj>00
iNCL0=SGd00Z0?ooob80moOg00L0knOW0?OF_@3ge[d0mmJm0?OFaP3gg/h0kkfU0080ijfD00D0gZF<
0>o>]@3ge[d0mmJm0?Nm]@030?OF_@030?OFaP3gg/h0mmk>00<0mmk>0P3gimh50?ONcP060?OFaP3g
_KD0klje0>nm[@3__JD0ijfL0P3WYH`0103NW8@0ikFD0?Nm]@3ge[d20?ONcP80mmK600<0mmJm0?OF
aP3ge/H0103ge/H20?OF_@0=0>o6[@3__JD0ikfU0>N]U03N[I@0eZF<0=jUS03FW8`0cYAk0<J<H`3>
S6/0_HA[0<j<J`020<j<L`0:0<jDN`3>U7<0eXak0<jDN`3FW7<0cYAk0=JLL`3NW8@0gZF<0>N]U080
ikFL00<0ijfL0>NeW03W[I@00P3N[I@30=jUS080eYb400D0eZF40=JUS03FW8@0eZF<0=JLQ0020=JU
S0060=jeW012:B40DS4Y08acJ`2eW9`0g]KW8P3gmoLP0?ooo`007P3oool0103Hem00jNSP0>WXh03T
i=`60>;RfP@0h^;K0P3Rhm/60>;Sg0030>;Sg@3Ri=d0h^CM00<0h^CM0P3Ri=h06`3RiMl0h^GP0>;S
g03RgmD0h]C30>;?^P3Rb;00hLJ^0=joZ03K^J40e:bA0=6VRP3=XXH0cJ>70=2[T@3B/9P0fKRR0=^h
Y03P]jL0hKRX0>:jZP3S`[00hlJd0>?<^@3Sc[/0hm2m0>?@_P020>?A_P<0hm2n03`0hm2m0>?>^P3S
c;L0hlN`0>?4[03R_ZD0hKZQ0=^bUP3H[Y40e:J80=>SQP3EY8X0ejVA0=ZaVP3P`Zh0h/Vf0>??_@3S
d;h0i<fl0>C<^P3SbKP0hlVg0>?:^03SbkT0hlbi0>?:]`3P`k00g[j[0=ZdX03H/9`0e:ZC0=:WS`3=
X8P0c9f50<ZKP`39Vh<0aiR10<FEO@32TGT0_XUa0;f8K`2lQfh0_8Q_0;b:L@2lRg<0_Xmf0;n@N033
TgX0aIAk0<VEO@3:Ugl0cY^30=2OQP3CYH/0djN>0=>XS`3BYhh0cj>:0<fPR03;WXD20<^MQ00F0<ZL
P`39Vh80aiR00<JGO`34UG`0`iEl0<BIO035Vgh0ain20<>KP02TPV/0RVaJ05U4>01;>Bl0CShe05e=
A@2;OgL0YI^D0<c9``3Ge]00h>;M0>;Ug`<0hnOQ00@0hnKP0>?Vg`3SiMl0hnGO0P3SiMh20>?TgP<0
h^CM00D0h^?M0>;Sg03Rhm`0h^?L0>;Sf`020>;Rf`060>;RfP3Sh]/0inKN0>WXh03Ui=`0f=O@:P3o
ool:0?Ogm`030?O_k`3gmoL0moOg01D0moOg0P3ge[d0203g_KD0mmJm0?ONcP3ge/H0ikFL0>NUS03N
[I@0ikFL0P3_c[D0103g_KD0mmJm0?OF_@3ge[d30?OFaPD0mmk>0P3gimh30?ONcP80mmK600H0mmJm
0?Nm]@3_c[D0mlJ]0>neY@3W]I`30>NUS0030>nmY@3_aZd0mmK60080mmK600D0mmk>0?OFaP3ge/H0
mmk>0?OFaP030?ONcP80mmK600H0mkfe0>o6[@3_]JD0ikFL0>N]W03N[I@20=JUS00>0=jUS03N[I@0
eYb40=JLL`3>U7/0aXac0<jDL`3>S7<0cYAk0<jDL`3FW7<0cYAk0=JLL`3NW8@20>N]U080ikFL00D0
kkfU0>NeW03W[I@0ikFD0=j]U0030=jUS0080=jLQ03NYH`0gYb40=JUQ03NYH`0eYb40=JUQ03FW8`2
0=j]U0080<J]Y@1J<BT0FS4Y048Y8@1B<BT0Nf=J0;FLW03Wg^LP0?Ogmb00oooo000N0?ooo`040=SG
d03Yj>00jNSP0>CTg0H0h^;J103Rh]/20>;Sf`H0h^?L00<0h^?M0>;Tg@3Ri=d0103Ri=d0703Ri=h0
h^GO0>;Vh03Rhm`0h]oE0>;D`@3Rc[P0h/R^0>76[03M_JD0fKJL0=2VRP3=XHD0c:640<jTR@3C[I@0
e[:I0=bgX@3N^:@0hKRW0>:iZ03R_:/0hl>a0>?6]03Sc;P0hljj0>?@_P3SdKl20>?B`01G0>?A_`3S
dKh0hm2n0>?@_@3Sc[X0hlfh0>?9/P3Sajl0hl6X0>6nX`3L]IT0f;2C0=>WR@3CY8H0e:B90=JYS`3I
/9P0gl6/0>77/`3Sc[/0hlnl0>C>^`3TcKX0i<bh0>C<^@3TcKX0i<fk0>?=^`3SbkT0hLBb0=no[03J
]J40f;6L0=>ZTP3AYXh0cJ680<bOQP3:WHD0bIb40<NIP@35UWh0`Y9k0;n;L`2nRW40_HU_0;f9KP2l
RW00_8]a0;f=M@2oSgP0`i=l0<JDOP3;V840cIZ30=:PR@3DXh`0eJV@0=FZT@3CZY40dZR?0<jTR`3<
XXT0bin60<^NQP3;WXD0bYf40<VLP`37VH40aYQo0<BFO@33UW`0`iUm0<FLOP37Wh80`ib10:Z7K`2E
MEl0JU0n05]3<`1D?C80G4Hl07a[H`2AQ7`0^;:/0<O4_P3Kg=L0h>?M0080i>SR00<0i>OQ0>?Vh03S
i]l00P3SiMl20>?UgP80hnCN0`3Ri=d30>;Sg080h^?K0P3Rh]/01P3Rh]X0hn;K0>OVgP3Yj>00iNCL
0=SGd2X0oooo00<0moOg0?O_k`3gmoL02@3gmoL00`3gknl0moOg0?Ogm`0C0?Ogm`060>o>]@3gc[D0
mmJm0?OF_@3gg/h0klje0P3NW8@00`3NYH`0ikfU0>o>]@020>o>]@80mmJm00@0mmK60?OF_@3ge/H0
mmK61@3gg/h20?OWgP@0mmk>00D0mmK60?Nm]@3_c[D0mkfe0>o6[@020>nmY@080>N]U03WYH`0ijF<
0>NeW03__JD0mmJm0?OFaP3gg/h50?OFaP060?ONcP3gimh0mmk>0?OFaP3ge[d0klje0P3__JD20>N]
W080gZfD00d0eZF<0=jUS03NYH`0gZF<0=JUS03NW8@0eYac0;f4J`36S7<0cXa[0<jDL`3>U7/0eXak
0080gZF<00D0ijfD0>NeW03W]I`0kkfU0>NeU0030>NeW00:0=jUS03WYH`0gZF<0=jUS03NW8@0gZF<
0=JUQ03NW8@0eYb40=jLQ080eYb400X0eZF<0=jeW03N]JD0Q59207=:>@1J<BT0@RTQ05Y2>@2<Lf/0
g/kF803gmoLP0?ooo`007P3oool0103Hem00jNSP0>WXh03Ti=`60>;RfP@0h^;K0P3Rhm/70>;Sg0H0
h^CM0200h^CN0>;Ug`3RiMl0h^;J0>;NdP3RdKd0h/^d0>33Z03O`:D0ekBI0=:ZS`38VG/0aYIh0<^P
P`3?ZHd0f;>L0=^eW`3P]Z<0hKRT0>:lZ03R_jX0h/6/0>;5/@3Rak@0h/^h0>;=^P3SdKl0hm;10>?D
a03Se<<0hm;00>?A_P80hm2m0180hljk0>?=^@3Sb[D0hlVb0>?6[@3Q`jT0g;VN0=RcU`3DZXd0djN:
0=BYR`3E[I00f;>G0=c0Y`3NaJh0h/Zf0>;;^03Sc;L20>?<]P130>?=^03Tc[`0i<nm0>C=_03SbkT0
hLBa0=o0[03J]Yl0e[2I0=2VS@3>XXX0c9j60<^MQ@39WHD0b9b40<FJPP34V800`iEm0<6@M`30Sg@0
`8i_0;n=KP2mRVd0_8U^0;f;L`2oSGH0a9=m0<NGP@3>WHT0dJ2<0=JXTP3HZi@0fJjE0=N^U@3DZi80
dZZA0<fWSP3<YXd0bj>:0<ZRR@3:X8L0b9j50<NMP`35VX40a9V00<>HO`33V7h0`iYo0<BKP036X8D0
aJ250;ZENP2_RVh0U6iB08MPAP1bCCT0KDTj06eBB01dGeH0TXR10:NRV`3?d</0gMoJ0>KZi03VjN<0
i>OQ0>?Vh0030>?Ug`80hnGN00<0hnCN0>;TgP3Ri=d00P3Ri=d30>;Sg080h^?K0P3Rh]/01P3Rh]X0
hn;K0>OVgP3Yj>00iNCL0=SGd2X0oooo8@3gmoL02P3gg/h0mlje0?OF_@3ge/H0mmJm0>NeU03_aZd0
cXa[0=J<L`3W]I`30>o>]@D0mmJm0P3ge/H20?ONcP030?OWgP3gg/h0mnON0080mmk>00X0mnON0?ON
cP3gg/h0mmK60?OF_@3ge/H0klje0?OF_@3_c[D0mlJ]0P3W]I`01@3__JD0ikFL0>nm[@3g_KD0mmJm
0080mmK600D0mmJm0>o>]@3ge[d0mmK60?OF_@020?ONcP80mmK600@0klje0>o6[@3W[I@0ijfD1@3N
YH`0303FYH`0eYb40=JUS03FW8@0gYb<0=JUQ03>S6/0_HA[0<j<L`3>U7<0eYac0=JLQ080gZfD0P3W
]I`01`3__JD0ikFL0>NeW03W]I`0ikfU0>NeW03W[I@00`3N[I@0503NYH`0eZF<0=jUS03FW8@0eZF<
0=jLQ03FYH`0gZF<0=JUS03N]I`0ikfU0<j<J`36S6<0YF=:08AB>@1B>C40FT8i06=:@P1cFU80imkW
7P3gmoLP0?ooo`007P3oool0103Hem00jNSP0>WXh03Ti=`60>;RfP@0h^;K0P3Rhm/70>;Sg0D0h^CM
0`3Ri=h07P3Ri=d0h]oF0>;Kc`3QcKT0h<N_0=jlX@3L^9d0e:^@0<jRQP34TgD0`i9d0<VQQ03?Zhl0
fKJO0=bgXP3P]j@0h[VU0>:oZ@3R`Z/0h/B]0>;6/@3Rb;@0h/^h0>;=^P3RdKl0hm?20>?Da@3Se<@0
hm;00>?A_P80hm2m05L0hljk0>?=^P3Sb[H0hlVd0>;7[P3Qa:X0g;ZO0=VeVP3D[900djZ>0=F]S`3F
/9<0f;FI0=c0YP3Na:`0hLVd0>;:]@3SbK@0hlVc0>?:/`3SbkD0hljj0>C>_03TbkX0hlVh0>73[`3N
_jT0fKBL0=F^UP3?XhX0cIn70<^LP`3:Vh<0b9^30<JKP`34VH40`iMo0<:FO@31TWL0`I5d0;n?KP2n
SFd0_8U/0;b8K@2mRW80_hef0<FEOP38V8<0cj2;0=>SS`3HZYD0fJfF0=V_U`3H[iH0e:bB0=:ZT@3=
Z8l0c:N>0<^TR`3:XhT0bZ680<RNQ@37WH<0a9^10<BJP033VGl0`iUn0<BIO`35Vh40aj260<NQQ`30
Vgl0^Y=e0:MlG@2LKe80QEU307aC@@1aDdL0Le]B08Z0N@2PViD0cLk80=cOf@3Vj^@0i^WS0>CXh@3S
i]l00`3SiMl20>?UgP050>?TgP3Ri=d0h^CM0>;Tg@3Rhmd00`3Rhm`20>;Sf`80h^;K00H0h^;J0>?R
f`3Wi]h0jNSP0>GTg03Hem0Z0?ooo`040?Ogm`3gknl0moOg0?O_ka`0moOg00<0mno_0>o>]@3_c[D0
0P3ge[d0203g_KD0ikFL0>nmY@3NU7<0eXak0>NeW03__Jd0mkfe0`3ge[d00`3ge/H0mmJm0?OF_@02
0?OF_@D0mmk>0P3gimh30?ONcP80mmK600P0mkfe0?OF_@3_c[D0mkfe0>nm[@3W]I`0kkfU0>NeW080
kkfU00<0mmJm0?OFaP3ge[d00P3ge[d00`3_aZd0mkfe0?OFaP020?OFaP<0mmJm00<0klJ]0>nmY@3W
[I@00P3NYH`0103NW8`0gZF<0=jUS03FYH`30=JLS0090=JUQ03FW7<0eYb40;f4J`2mQ6<0cXa[0<jD
N`3FYH@0gYb<0080ijfD0`3W]I`00`3_]JD0ikFL0>NeW0020>NeW080ijfD00<0gYb<0>N]U03NYH`0
103NYH`00`3FYH`0gYb40=jUS0020=JUS0030<J]Y@3FS7<0cXac0080]G=J00D0HcTa06=2<@1SBT80
Nf=J0>ONi`0N0?Ogmb00oooo000N0?ooo`040=SGd03Yj>00jNSP0>CTg0H0h^;J103Rh]/20>;Sf`L0
h^?L1@3Ri=d20>;TgP0O0>;RfP3Rh=L0h]K:0>7@`03N_jT0g;JM0=JUR`3CWX@0bi5h0<N<L`31Rfl0
`Hmd0<FSR03:[I@0eKVS0=VkYP3P_JL0h[jX0>?3ZP3SaJ/0h/J]0>;7/P3Rb;@0h/^h0>;=^P3Rd;h0
h];00>?C`P3Sd/80hm6o0>?@_P020>?@_@0?0>?>^`3ScKX0h/Zf0>;9]03PaZh0glBZ0=^lXP3I^9h0
ek>H0=JcU`3G]YT0fKVL0=ZlX03N`jP0glJ/0080h/Ra0280hLB^0>73[@3P`jd0hLF_0>?:]@3Sb[H0
i<Je0>?2/P3O^jP0g;RQ0=J_U03CZHh0cIj40<^JP@38Ugl0aiMo0<BFO`32UWh0`IEk0<6DNP31U7P0
`99c0;n@L02jRf/0^8QZ0;R5J@2iQF/0_XYb0<6?M`37VX80bYj70=6US`3DZ980fJjG0P3J/9P07P3H
[iH0e:bB0=6ZT@3=Z8h0c:J=0<^SRP3:XHP0bYn60<VMP`38W880aI^00<BJO`33VWd0`iUm0<FHO@36
VGl0bIn50<VQQ`38XHD0aIeo0;f=KP2fQ6H0YGAJ09i`FP2DM6H0UGib0:BMUP2c/JX0d]G?0=gPfP80
iNSR00@0i>OQ0>?Ug`3SiMl0hnGO0P3SiMh00`3Si=h0h^CN0>;Tg@020>;Tg@@0h^?L00X0h^?K0>;R
f`3Rh]/0h^;K0>;RfP3Sh]/0inKN0>WXh03Ui=`0f=O@:P3ooolP0?Ogm`060?OWgP3_aZd0mlje0?O6
[@3W]I@0ijF<0P3NU7<01@3FW7<0gZF<0>o6[@3g_KD0klje0080mmJm0`3ge/H00`3ge[d0mmK60?OF
aP030?ONcP030?OWgP3gg/h0mmk>00<0mmk>0`3ge/H20?OF_@80mkfe00<0klje0?O6[@3__JD00P3_
_Jd01P3__JD0klJ]0?ONcP3ge/H0mmJm0?Nm]@80kkf]0`3ge[d01P3_c[D0mkfe0>o6[@3__JD0ikfU
0=j]U080gZF<00@0eZF<0=JLQ03FW8@0eZF<0P3FW8@02P3>U7/0eYb40=JLL`3>U7<0_HA[0;f4H`3>
S6/0eXak0=jLS03N[I@20>NeW0030>NeU03W]I`0ikFL00D0ikFL0P3W[I@30=j]U00:0=jUS03FYH`0
eZF<0=jUS03FW8@0gYb40=JUS03FW8`0g[FL0<J]Y@80eYb400D0cYAk0=JLL`3>S7<0U7=[0=K6cP0P
0?Ogmb00oooo000N0?ooo`040=SGd03Yj>00jNSP0>CTg0H0h^;J103Rh]/20>;Sf`L0h^?L02D0h^?M
0>;Tg@3Ri=d0h^CM0>;TgP3RiMh0h^CN0>;Qf@3RgM<0hM720>39]`3L]Il0fJ^C0=:GO`3?SgL0b8A]
0<F2J`31RFl0`I1f0<BTR`38[ID0d[ZT0=RmY`3P`:T0h/:Y0>?5Z`3SaZ`0h/N^0>;7/P3Rb;@0h/^h
0>;=^P3Rd;d0h]6o0>;A`03SdL00hm2n0080hm2m03@0hlnl0>?>^`3Sc;X0h/Vf0>78/`3OaJd0g/>Y
0=^mXP3J^Yl0fKJL0=RgW03I^Yl0f[fQ0=c0Y03OaJ/0hLN]0>;9/03Rb;00hL>]0>30Z`3O`:X0h<:/
0>;7/P3Sb;<0i<:a0>>n[P3N]j@0fkBM0=F/T03BYXX0c9^20<ZHO`37UGd0aIEm0<:CO030Tg/0_i9h
0;nBMP30TW@0_i1`0;f>KP2gR6X0]HEY0;J3J@2iQF`0_had0<:BNP39WHD0c:690=6WT03DZY80f:jG
0P3J/9P07P3H[iH0e:^B0=6ZT03=Yhd0c:F<0<^QR03:X8H0bYj50<VLP`39Vh80aiZ00<FJO`34VG`0
a9Qk0<JFO037Ugh0bIf40<ZQQ`38XHH0aij10<2@L`2lRF`0/WmU0:inJ02[S7`0[IR<0;^f[`35a;h0
f=_E0=oRg080i>OQ00<0i>KP0>?Ug`3SiMl00`3SiMh00`3Si=h0h^CM0>;Tg@020>;Tg@@0h^?L00X0
h^?K0>;Rf`3Rh]/0h^;K0>;RfP3Sh]/0inKN0>WXh03Ui=`0f=O@:P3ooolP0?Ogm`060?OFaP3__JD0
mlJ]0>NUS03NU7<0cXAS0P3FNf/01P3FW8@0gZfD0>nmY@3Fa[D0mmJm0?Nm]@<0mmJm0`3ge/H;0?ON
cP80mmK60P3ge[d02@3_c[D0mmJm0?Nm]@3_aZd0kkf]0?O6[@3__Jd0mlJ]0>nm[@020?OFaP80mmJm
00`0mlJ]0>nm[@3_c[D0mmJm0?Nm]@3ge[d0mkfe0>o6[@3__JD0ikFD0>N]U03NYH`30=JLQ0030<JL
Q03>U7/0cYAk0080cYAk00T0eYac0<jDL`3>S6/0_HA[0<J<H`3>S7<0eYac0=jUS03N[I@00P3W]I`0
0`3__JD0ikFL0>nmY@050>NeW0040=j]U03W[I@0gZF<0>N]U0<0gZF<00D0eYb<0=JUQ03FYH`0eZF<
0=JLQ0020=jeW0070=jeY@3FW8@0eYb40=JLQ03FS7/0cYAk0;fLS00Q0?Ogmb00oooo000N0?ooo`04
0=SGd03Yj>00jNSP0>CTg0H0h^;J103Rh]/20>;Sf`L0h^?L01T0h^?M0>;Tg@3Ri=d0h^CM0>;TgP3R
iMl0h^GN0>;NeP3Reld0hLFe0=njZ03IY8l0eIV30<f3KP39NVH0`g=P0<5gHP31R700`Y=j0<FWS`38
/9P0dKbU0=O1Z@3PaJ`0h/N]0080hlR_00D0h/R`0>;8/P3Rb;@0h/^h0>;<^@020>;?_0130>;@_@3S
d;d0hm2m0>?@_@3Sck`0hljk0>?<^@3SbkP0h/Vc0>77/@3N`j/0g<6X0=bmX`3L_:40g;^Q0=blXP3L
`:H0gL:X0=k4Z`3Qb:l0h/Za0>?;/`3Sb[80hLB_0>31[03O_j/0h<6/0>;5[`3SaK00hkj/0>:jZ03N
/id0fZnG0=>WS03@XXL0bYQo0<REO033TGX0`I1i0;f>M`2lSGD0^X]a0;^<L02lS6h0^h]/0;V9JP2d
Q6T0/h=Z0;N6KP2kRW80`i=k0<NIP03<XhX0cjN>0=:[TP3D[I@0f;2G0=VaV03I/9L0f:nF0=B[T@3A
ZHl0cJF;0<bSR@3:WhD0bYf40<ZLP`020<ZIP@0F0<VHO`38V7h0aYIk0<JENP37U7X0b9El0<VLQ039
WhL0b:270<JLPP31T7D0`8]`0;n;L@32TWX0c:nN0=?1]03Ng]H0hNCN0>;Vh@3Ri^00hnGO0>?Vg`<0
hnGO0P3SiMh20>;TgP@0h^CM103Rhm`02P3Rhm/0h^;K0>;Rf`3Rh]/0h^;J0>?Rf`3Wi]h0jNSP0>GT
g03Hem0Z0?ooob00moOg00h0mkfe0?O>]@3__JD0iiB40>MkJ`3FNf/0eXac0<j<J`3NYH`0gZfD0>nm
[@3_c[D0mmJm0>o>]@80mmJm1@3ge/H20?ONcP030?OWgP3gg/h0mmk>00@0mmk>0`3ge/H20?Nm]@07
0>o>]@3g_KD0klJ]0>nm[@3_aZd0mkfe0?OF_@030?OFaP030?ONcP3ge/H0mmJm00@0mmK60180mmJm
0?Nm]@3_aZd0klJ]0>NmY@3W]I`0gZfD0=jLS03FW8`0aYb40<J<L`36W8@0aXac0<jDL`36S7<0cYAk
0<jDL`3>S6/20;f4J`030<j<J`3FS7/0gYb40080gZfD00@0ikFL0>nmY@3__JD0kkfU0P3W]I`03P3_
]JD0ikFL0>NeW03W]I@0g[FL0>N]U03NYH`0gZfD0=jUS03NW8@0gZF<0=jLS03FYH`0eZF40P3NYH`0
2@3N[I@0g[FU0<J]Y@3FS7<0cYAc0=JLL`3FS7/0eYb40<J]Y@0Q0?Ogmb00oooo000N0?ooo`040=SG
d03Yj>00jNSP0>CTg0H0h^;J103Rh]/20>;Sf`L0h^?L0240h^?M0>;Tg@3Ri=d0h^CM0>;TgP3RiMl0
h^GN0>;Me@3ReL/0hL2a0=ndY03IWXX0e9=n0<anJP38MV<0`W5O0<5fHP31RG80`YAl0<NYT03;/IT0
e;jV0=W2ZP3Pajh0h/R`0>?9/@3SbK80h/Vb0>;8/`3Rb;@0h/^g0>;<^@3Rck/00`3Rck`20>??_009
0>?>^`3ScKX0hl^g0>?:]P3Rb;80h<N_0=g3ZP3L`JL0gKfS0080gKbQ03H0gKfS0=g1Y`3M`jX0g/F/
0>;9/@3Sb[<0hlbe0>?;]@3Qa[80h<>`0>31[P3Q`Zl0h/F`0>?5/03S_ZX0h[ZV0=fbW03J[iH0dZJ;
0<nQQP39V7h0aYAl0<:@N030SgL0^had0;Z:LP2hRFl0^8U^0;V9K02hRF/0]hQZ0;B5J`2eQFd0^XYb
0;j?MP36V800bIf40<jVS03@ZHl0djfD0=B^U@3H/9P0fK6H0=V`U`3H[YD0e:^A0=6XS`3=Y8/0c::9
0<ZNQ@3:W8<0bY^20<^HP@3:Uh020<VFO`0C0<NEO036Tg/0ai=j0<NDO038Vh@0bIn80<NOQ`35VX40
`Hic0;n:KP31SG80aIIm0=>fY@3Kb[`0i^KN0>O[i@3UjN@0hnOQ0>;Ug`040>?Ug`80hnGN0P3Ri=h3
0>;Tg@030>;Sg@3Rhm`0h^?L0080h^?L00X0h^?K0>;Rf`3Rh]/0h^;K0>;RfP3Sh]/0inKN0>WXh03U
i=`0f=O@:P3ooolP0?Ogm`050>o>]@3gc[D0kkfU0>NUS03FS7/00P3FS7<01P2mQ6/0eZF<0=jUS03_
aZd0klje0?OFaP80mmJm0`3ge/H00`3gg/h0mmK60?OFaP080?ONcP@0mmK600L0kkf]0>o>]@3gaZd0
klje0?O6[@3__Jd0mkfe0080klje00<0mmK60?ONcP3gg/h00`3gg/h40?OFaP80mmJm00@0klJ]0>nm
[@3__JD0ijfD0P3NYH`20=JLQ080cYAk00/0aXac0;f4J`36S7<0cYAc0<J<L`3>S6/0aXac0<j<J`3F
S7/0eYb40=jUS0020>N]U0@0ikFL0P3W_JD20>NeW00;0>N]W03W[I@0ijfD0=j]U03NYH`0gZfD0=jU
S03FW8`0gZF<0=JLQ03NW8`00P3FW8@20=JUS0050=jeW03N]JD0cXa[0<jDL`3FS7/00P3FW8@00`3N
]I`0moOg0?Ogm`0O0?Ogmb00oooo000N0?ooo`040=SGd03Yj>00jNSP0>CTg0H0h^;J103Rh]/20>;S
f`L0h^?L00<0h^?M0>;Tg@3Ri=d00`3Ri=d0503Rhm`0hm[@0>?AaP3R^Z`0h:nO0=ZIQ`3ET7`0c7iZ
0<QhI032MV40`7]U0<:=M@35V7l0cJfB0=:eVP3J`:L0gL>/0>77/P3RbK@0h/^f0P3RbkL20>;9]@04
0>;;]`3Rc;P0h/jj0>;>^`80h/jj01<0h/fj0>;=^@3RbkL0h/Zf0>?8/`3Sak80h/F^0>34[03M`JL0
gKnU0=flX@3N^j00gkZP0=jlX@3M`:H0gL:Y0=k4[@3Qb;<0h/Zf0080hlfi01<0h/^g0>;9]P3RakD0
h/Ne0>?7]03SaK80hknZ0>:jY@3M/YX0fZjE0=:US03=X8L0aYIn0<>CN`2oSWH0_Had0;V9L@2gR6l0
]HI]0080]8I/0P2eQfd0:`2hRW00^Xac0<6DN`34VH00bj680<jTR`3AZI00dj^B0=B_UP3E/9L0f;6H
0=VaV03I[YD0ejfD0=>YT03AYhh0cJ>:0<bQR03:WH@0bY^20<ZIP03:UGl0bYAo0<ZBO`3:TWh0b95m
0<NAN`35TWX0aIAl0<NLQ@38WhT0aij80<FIP@30S700_hQ[0<6<L@35UWd0dkJU0=[9^`3Ui=d0i^WS
0>GYh`3Sin40103SiMl20>?UgP80h^CN103Ri=d40>;Sg0040>;Sf`3Rh]/0h^;K0>;Rf`80h^;J00D0
hn;K0>OVgP3Yj>00iNCL0=SGd00Z0?oooah0moOg01<0mnOW0>o6[@3_c[D0mmK60>neY@3WYH`0iiB4
0=jDL`36S6<0cXac0=j]U03W]I`0klJ]0?Nm]@3_c[D0mmK60?OF_@3ge/H0mmk>00<0mmK6203gg/h3
0?OFaP80mmJm0`3_c[D01P3gaZd0klJ]0>o>]@3gaZd0klje0>nm[@@0mmK60P3gg/h40?OFaP80mmJm
00@0klje0>neY@3__JD0ijfD0P3NYH`20=JLQ0030<jDN`36S7<0aXac00<0cYAc00@0cYAk0=J<N`3F
W7<0gYb40`3N[I@03@3W[I@0ijfL0>NmY@3_]JD0kkfU0>neY@3__JD0ikFL0>nmY@3W]I`0ijfD0=je
W03WYH`00P3N[I@0103NW8`0gZF<0=JUQ03NYH`40=JLQ0080=JUQ03FYH`0aZfU0=jeW03FS7<0cYAc
0=JLL`3FW8@20=JUS240moOg803oool001h0oooo00@0f=O@0>WXh03Yj>00i>CL1@3Rh]X50>;Rf`80
h^?K1`3Rhm`00`3Rhmd0h^CM0>;Tg@020>;Tg@0D0>;Sf`3RhMP0hmO<0>??`P3R^Z/0h:nN0=ZKR03F
TGd0c85/0<QkIP31NV<0`7iW0<>@MP36VX00d:nC0=FgW03M`JP0glB]0>;7/P3RbKD30>;<^00O0>;:
]`3Rb[H0h/Zg0>;;^03Rc;T0h/fi0>;<^@3Rc;P0hL^g0>7;]P3Qb[@0h/Vd0>?7/@3SaK00h/:/0>71
ZP3M_jH0gKjT0=fjX03N^Il0g[VN0=jjW`3M_ZD0gL6X0=k3[03Qb;<0h/Zf0>?<^03ScKT0hlbh0>?;
]`020>?9]`0n0>?7]@3SaK<0hkjZ0>:jY@3M/IX0fZbE0=6SRP3=WXH0aIIm0<:BNP2nSGD0_8ad0;R9
L02gQfl0]HI^0;B6K@2cQVh0]8Q_0;F9L02jSG<0_I1f0<>HOP36WH<0c:B:0<nVS@3CZY40e:bC0=F`
UP3F/IP0f;6H0=R`U`3H[I@0ej^B0=>XSP3AYXd0cJ>90<bQQ`3:WH<0bYZ10<ZHO`3:U7h0bY=m0<ZA
OP39TGd0b95l0<JAN`34TgX0a9El0<JMQ@37X8X0aij80<FIPP31SG40`8U/0<6=L@34UG`0ck:Q0=G3
]P3OgMH0h^CN0>?Wh@3Si^040>?Ug`040>?UgP3RiMh0h^CN0>;TgP<0h^CM00<0h^?M0>;Sg03Rhm`0
0P3Rhm`0103Rhm/0h^;K0>;Rf`3Rh]/20>;RfP050>?Rf`3Wi]h0jNSP0>GTg03Hem00:P3ooolN0?Og
m`0<0?ONcP3g_KD0mlje0?OFaP3_]JD0ijF<0>NDQ03NU7<0_HA[0<j<L`3N[I@0ikFL0P3_c[D01@3g
e/H0klje0?OFaP3ge/H0mmk>0080mmK60P3gg/h00`3ge/H0mmk>0?OFaP040?OFaP80mmJm00L0klje
0?OF_@3_c[D0mkfe0?OF_@3g_KD0klje00<0kkfU00T0klje0>o6[@3ge/H0mmK60?OF_@3ge/H0mmk>
0?OFaP3gg/h00`3ge/H01`3_c[D0mmJm0>o>]@3gaZd0ikFL0>N]U03NYH`00P3FW8@01036W8@0cYAk
0<jDN`36U7/20<jDN`0<0=JLQ03>U7/0eZF40=JLQ03FYH`0gZF<0=j]U03W[I`0g[FL0>N]W03__JD0
ikfU0P3W]I`20>nmY@050>NmY@3W]I`0ikFL0>NeW03N[I@00`3NYH`01@3FYH`0eYb<0=jUS03FW8@0
eZF<0080eYb400X0gZF<0=JLS03N]JD0g[FU0=JLL`3FS7/0eYac0=jLS03FYH`0eYb48@3gmoLP0?oo
o`007P3oool0103Hem00jNSP0>WXh03Ti=`50>;RfP@0h^;K0`3Rhm/70>;Sg0@0h^CM01`0h^?K0>;N
e03Rf/h0h]2o0>;9]P3Q^Z@0gk6K0=ROQ`3CUGh0bHI]0<B1I`2oP6@0_hAY0<FEN@39Wh<0eK:G0=Zj
W`3Qa:X0h/F^0>;7/`3RbKD0h/bh0>;=^@3RcKX0h/bi0>;<^03Rb[L0h/Zf0P3RbKH05@3RbKD0hLRc
0=o6[`3NaJh0glJ]0>36[@3R`Z`0h[n[0>6jZ03P^JH0gKVR0=biX@3L]id0g;JL0=bfV`3L]id0g;^R
0=fnYP3N`J/0hLNb0>;9]@030>?;]@110>?;]P3Sb[P0hlZh0>?8]P3SaK@0hkf/0>:hY`3M[IT0fZRB
0=6OQ`3=Vh80aIAl0<:AN@2mSGD0^h]c0;V9L@2hR700]XQ`0;F9L@2dRW80]8ed0;J?M@2mU7P0`9Mj
0<JMP@39X8D0cJF;0=2WSP3CZi40eJbC0=N_UP3H/9L0ejnF0=N^U03EZY40eJR?0=>US03AY8X0cJ:8
0<bPQ`3:Vh80bYQo0<ZFO@3:TW/0bY5k0<V@N`38T7/0aI1j0<BAN@33U7T0`iMl0<FNQ@37XHX0b9n:
0<RJQ035T7H0a8eb0<>@M@33UGd0ajVG0<ZeY`3Cbl@0emC>0=oPf`3Qi=h00P3Si^000`3SiMl0hnGN
0>;UgP020>;TgP@0h^CM1@3Rhm`0103Rhm/0h^;K0>;Rf`3Rh]/20>;RfP050>?Rf`3Wi]h0jNSP0>GT
g03Hem00:P3ooolN0?Ogm`080?O>]@3__JD0mlje0?OFaP3gaZd0ijF<0=jLQ03NU7<20<J<L`060=j]
U03W_JD0klje0?OF_@3ge/H0klje0P3ge/H0103gg/h0mmK60?ONcP3gg/h50?OFaP80mmJm00<0klje
0?OF_@3ge[d00P3ge[d01@3_c[D0mkfe0>o>]@3_aZd0kkf]0080kkfU00<0kkf]0>nmY@3_c[D00`3g
e[d00`3ge/H0mmJm0?OFaP030?OFaP<0mmJm00P0mkfe0>nmY@3W[I@0ijF<0=jUS03NW8`0eYb40<JL
Q0@0cYAk00<0aYb40=JLL`36W8@00P3FW8@01P3NYH`0gZfD0=j]U03W[I@0ikfU0>NeW080kkfU00@0
ikFL0>NmY@3W]I`0kkfU0P3W[I@20=j]U080gZF<00@0gYb40=jUS03NYH`0gYb40P3FW8`20=JLQ0<0
eYb<00X0g[FU0=jeW03FYH@0gYb40=JUQ03NYH`0eYb40=J<N`3Fa/H0oooo7`3gmoLP0?ooo`007P3o
ool0103Hem00jNSP0>WXh03Ti=`50>;RfP@0h^;K0`3Rhm/70>;Sg080h^CM06<0h^CN0>;Tg@3Rh]X0
hM_?0>7Ea`3Qb[H0h<B^0=jfWP3K[iD0dif30<jDNP33QFX0_h5U0;b1I02nQVT0aIMk0<^QQ@3G]9T0
g;bP0>74Z`3RaZh0h/Nc0>;8]@3RbkP0h/bi0>;=^@3Rc;T0h/bh0>;:]P3RbKD0h/Rd0>;7/`3Qa[40
h<F_0=k3Z`3M`jT0g/>Y0=o3ZP3Q_jT0hKbX0>2fY@3O]Z<0gKNQ0=bgW`3K]id0fkJL0=^eV`3K]i`0
g;^Q0=fnY@3N`JX0hLNb0>;8/`3Sb[@0hlZc0>?:]03Sb[D0hlZg0>?:^03Sb;H0hlFd0>>m[@3Q]jL0
gJbI0=VWTP3AWHD0cIV10<FDN`32TGT0_Hee0;^;L`2jRG40^HUa0;R:LP2gRg<0]Xad0;J@M`2hTWP0
_YIj0<6IO037WX80bJ260<jUS03@Yhh0e:ZA0=F/T`3H[iH0f;2F0=N^U@3F[I@0eJZ@0=BXSP3BYH/0
dJB:0<fRR03<X8L0bY^20<ZHO`3:UWd00P3:TWX05038TGX0ai1i0<B@N@33TGP0`YEi0<>HO035WhH0
aj6:0<RNR@38VX@0ai1g0<J>L`34TGH0`iIm0<BTTP36[Il0cL6i0=?;a@3MgML0hN;L0P3Si^000`3S
i]l0hnGN0>;UgP020>;TgP@0h^CM103Rhm`20>;Sf`<0h^;K0P3Rh]X01@3Sh]/0inKN0>WXh03Ui=`0
f=O@02X0oooo3@3gmoL00`3gknl0moOg0?Ogm`0>0?Ogm`0<0?Nm]@3W]I@0mmJm0?ONcP3_]JD0ijF<
0>NDQ03FS7/0_HA[0<J<L`3N[I@0kkf]0P3_c[D20?OF_@80mmK600@0mmk>0?OFaP3gg/h0mmk>1@3g
e/H01`3gg/h0mmJm0?OF_@3__Jd0klje0?Nm]@3_aZd00P3_c[D20>nm[@<0kkfU0P3__Jd20>o>]@03
0?OF_@3ge/H0mmK600<0mmK600<0mmk>0?OFaP3ge/H00P3ge/H0203_c[D0kkf]0>NeW03W[I@0gZF<
0=JUQ03FW8@0cXb40`3>U7/03`3FW7<0eYb40=JLQ03>S8@0eZF<0=JUQ03NYH`0gZfD0>N]U03N]I`0
ikfU0>NeW03W_JD0kkFU0>NmY@020>nmY@050>NeW03W[I@0gZfD0>N]W03W]I@00`3NYH`01@3N[I@0
gZF<0=jLS03FYH`0eZF400@0eYb400X0eZF<0=jeY@3N]I`0gYb40=jUS03NW8@0eZF<0<jDL`3FS7/0
mkfe803gmoLP0?ooo`007P3oool0103Hem00jNSP0>WXh03Ti=`50>;RfP@0h^;K0`3Rhm/70>;Sg080
h^CM01T0h^GN0>;Tg@3QhMP0gmC50=k;^03J^Il0f;:F0=6TR03<W800_H]`0;N4J@2_NUh0[WUL0;B0
HP2iQfX0ai]o0<jVRP3I^9`0g[jS0>;5[03SaZl0h/Nb0>;7]03RbKH0h/Zf0080h/Zg01X0h/Zf0>;8
/`3Rak40h/J^0>;5[@3Q`j/0h<:Y0=g0YP3L_jD0g;jT0=flY03M^:80gKJQ0=bbW`3K/Ih0fk>N0=^d
WP3K]Yh0fkNN0=^iWP3K^Yl0fkfS0=foY@3N`ZT0hLJ_0>;8/@80hlVb0100hlVc0>?9]03SbKH0hlVg
0>?8]P3Ra[@0hKn]0=njZ03K[YX0f:RB0=6MQ@3=VH00aI=k0<:AN02mSGD0^h]c0P2jRW40<02jRg<0
^Xad0;Z>MP2kTWT0_9Aj0<2HO@33VWl0bIj50<bPR03@Y8d0dJJ>0=BYT03EZi40eZfC0=N]U03E[Y@0
eJfD0=B[T@3CZHl0dZJ<0=6TRP3=XXP0c:670<ZMP`3:Vh40bYV00<VFO@38UG`0aI=j0<BBN@32TGP0
`Y5g0<:CNP33UWd0aYj70<NPR`38VhH0aiAn0<F8K`34R6d0a95e0<BFO033W8H0`in<0<V]W`3>^Zl0
fmK>0>3Of@80hnOQ00@0hnKP0>;UgP3Ri=h0h^CN103Ri=d00`3Rhmd0h^?L0>;Sg0020>;Sg080h^?K
0P3Rh]/30>;RfP050>?Rf`3Wi]h0jNSP0>GTg03Hem00:P3ooolM0?Ogm`090>oFcP3WYH`0gYAc0>NU
S03FW8`0eYb409a[DP2eNf<0cXac0080_HA[00D0ikfU0>nm[@3g_KD0klje0?OF_@060?OFaP030?ON
cP3ge/H0mmK600<0mmK600d0mmJm0>o>]@3_c[D0mkfe0>o6[@3_c[D0kkfU0>o6[@3__JD0ikfU0>o6
[@3__Jd0mkfe0080klje00@0mkfe0?OF_@3_c[D0mmJm0P3ge/H00`3ge[d0mmK60?OFaP040?OFaP09
0?OF_@3g_KD0mkfe0>NeW03W[I`0gZF<0=JLS03>U7/0aYb400@0cYAk00<0aYb40<jDN`3FW8@00P3F
W8@00`3FW8`0gYb<0>NeW0040>NeW0070>NmY@3W]I`0ikfU0>NeW03N[I@0g[FL0>N]U0040=j]U005
0=jLS03FYH`0gZF<0=jLQ03FYH`0103FW8@20=JUS0040=jeY@3N]I`0aV]B0<j<J`80gZfD00@0eXak
0<j<J`3FS7/0klJ]7`3gmoLP0?ooo`007P3oool0103Hem00jNSP0>WXh03Ti=`50>;RfP@0h^;K0`3R
hm/70>;Sg00K0>;Tg@3Ri=h0h^GO0>;Tg@3Qh=L0g]300=_5/03E[i<0dJJ80<NFN@30SW80[giS0:Qg
G@2RL5H0Xg5F0:ilH02eQFX0aYf10<jXS@3K^Yh0g[nT0>;5[03SaZl0h/Nb0>;7/`3Rb;@0h/Re0080
h/Ve01h0h/Vd0>;8/@3Rak00hlF]0>?4Z`3Q`ZT0h<6X0=g0YP3L_jD0g;bS0=bjX`3L]Z00fk>O0=Va
W03I/9`0f[6L0=ZbW@3J]Yh0f[NO0=ZjX03J^j40fkjS0=c0YP3N`ZP0hLJ^0>;8/03Sb;80hlRc0>?8
]03Sb;D20>?9]P0<0>?8]@3Ra[@0h<6]0=jlZ03J/9X0ejZB0=2NQP3=VH40aI=k0<:@N02mS7@0^h]c
0P2jRG403`2jRg80^had0;^>MP2mTWT0_YEk0<:IOP34Vh00bYj60<fPR@3AY8d0dZJ>0=>YT03DZY00
eJ^A0=F/TP020=B]T`0O0=>[TP3CZY00dZJ<0=2UR`3=XXP0bj670<ZNQ03:W8<0bI^20<RHO`36Ugh0
a9Ak0<>CN@32TGP0`Y1h0<:BNP33UGh0aYf80<NOR`37VH@0aI5j0<>4J032Q6L0a8mc0<BFNP34V840
`iR30<RTU03>/ZD0fm?:0>3Ne`020>?Wh@040>?Vh03RiMh0h^CN0>;TgP@0h^CM00<0h^?M0>;Sg03R
hm`00P3Rhm`0103Rhm/0h^;K0>;Rf`3Rh]/30>;RfP050>?Rf`3Wi]h0jNSP0>GTg03Hem00:P3ooolL
0?Ogm`070?O_k`3ge[d0gYAc0>NUS03>S7<0gZfD0:ecFP0209a[DP050:ecFP2eNf<0_HA[0>NmY@3_
aZd00P3ge[d60?OFaP040?ONcP3ge/H0mmK60?OFaP80mmJm0P3_c[D0103ge[d0klje0>o>]@3_c[D3
0>nm[@030>nmY@3__Jd0kkf]0080klJ]1@3_c[D40?OFaP80mmJm103ge/H0203ge[d0klje0>o>]@3W
]I`0ijfD0=jUS03FW8@0eYac1@3>U7/02@36W8@0eYb40=JLQ03FW8@0eZF<0=jLS03N[I@0ijfL0=j]
U0020>NeW0030>N]U03W]I`0ikFL0080ikfU00D0ikFL0>N]U03W]I`0ijfD0=jUS0030=j]U0030=JL
S03NYH`0eZF<00@0eYb400X0eZF40=JUS03FYH`0g[FU0<J]Y@36Je80cW=B0=JUQ03FYH`0eYb40P3F
S7<00`3NYH`0moOg0?Ogm`0M0?Ogmb00oooo000N0?ooo`040=SGd03YjN00jNSP0>CTg0D0h^;J103R
h]/30>;Sf`L0h^?L01L0h^CM0>;TgP3RiMl0h^CM0>7OeP3LbKL0ekZR0<RJN`2oRf`0ZWEI0:5]D`2A
HTX0Rem708QMA`2;GdT0VfmI0:QmIP33W880cZV?0=blX@3P`JL0h/J^0>?6/0020>;6/P80h/Ja0P3R
a[00>`3Rak00h/N_0>?7[`3SaJd0hlB[0>;3ZP3Q`ZT0gl:Y0=k1Z@3N_JP0g[^V0=bfXP3J]9l0f;6K
0=N_VP3H[YT0f:jJ0=RaV`3G]9`0ekRN0=RjX03J_Z<0g<2U0=g2Y`3PaJ/0hLJ]0>;8/P3Rb;<0hlRe
0>?8]P3SbKH0hlVe0>;8/`3Qa[40g/6Z0=bmY@3G/IT0eJZB0<jMQP3:V840`i1k0<2=N02lRW<0^hYa
0;V8K`2hR6h0^XU`0;^;LP2mSG@0`I9j0<:EO034VX40aYb30<^NQ`3>WhT0dJ:<0=6TS@3BYXd0dZN>
0080djN?0P3BZI005@3AZI00dJR?0<nVS03>Y8X0bj670<VOQ@38WX@0aij40<NMP`35Vh40a9Z00<:F
O032U7X0`Y5h0<:@N032T7/0`i9o0<FIQ`35W8P0a9Em0<6<LP020;eoG`0=0<6<K@33TW@0`i5f0<B>
M@39VHD0cjVI0=_?a@3PgMD0hnOR0>?Wh@3Si^00h^GN0>;TgP040>;Tg@030>;Sg@3Rhm`0h^?L00<0
h^?L00@0h^?K0>;Rf`3Rh]/0h^;K0`3Rh]X01@3Rh]/0inKN0>WXh03Ui=`0f=O@02X0oooo703gmoL0
203ge[d0mlJ]0>NDQ03FS7/0cXac0:ecFP2eQ6/0[G=J0P2<FTX01@2LJe80W7=S0>NmY@3g_KD0klje
0080mmK60P3ge[d20?OFaP040?OF_@3ge/H0mmK60?OF_@@0mmK60P3_c[D20>o6[@050=K6]@3_aZd0
kkf]0>NmY@3W]I`00P3W_JD00`3__Jd0klJ]0>nm[@040>o>]@0D0?OF_@3ge/H0mmK60?OFaP3_c[D0
mmK60?OF_@3ge/H0mmJm0?OFaP3gc[D0klje0>o6[@3W[I`0ijfD0=JLL`3FW8@0eXak0<jDN`36S7<2
0<jDN`060<jDL`3>S8@0aYb40=JLS03FW8@0gZF<0`3N[I@0203W]I`0ijfL0=jeW03N[I@0ijfD0=j]
U03W[I@0ijfL0P3N[I@20>N]U0030=j]U03NYH`0eYb<0080gZfD00<0eZF<0=JLS03FW8@00P3FW8@3
0=JLS0030=JUS036[JD0eZF<0080aV]B00H0cYAk0=JUS03NYH`0eYb40=JLL`3FS7<O0?Ogmb00oooo
000N0?ooo`040=SGd03YjN00jNSP0>CTg0D0h^;J103Rh]/30>;Sf`L0h^?L01L0h^CM0>;UgP3Ri]l0
h^CM0>7OeP3Ka[@0e[FM0<:@L@2eOf00VfI:091NA@24Ed00P5E007iE@@20Ed@0T6MD09mfHP2oVX40
cJV@0=flX`3P`JP0h/J_0>?6/@020>;6/@80h/J_0`3RaZh01P3RaZl0hlN_0>?6[P3SaJd0h/>/0>;3
Z`80h<>/00H0gl2[0=nmZ@3M^:@0fkJQ0=RaV`3G[YT20=N[U`0;0=F]U`3D[iL0eKBJ0=JgW03J_:40
fknT0=g1YP3Oa:X0h<F/0>77/@3Rb;<00P3Sb;H07@3SbKD0hlVd0>;7/P3Qa[00g[nY0=bkY03F[iL0
djV@0<bLQ@39UX00`Hij0;n;M`2kRG80^XU`0;R8K@2hQfd0^HQ_0;Z9L@2mS7@0`I9j0<>EO036VX80
aib40<^NQ`3=WXP0cj290<nRRP3@YH`0d:F=0080dZF>00P0dJF>0=2VS@3?YX`0cjJ<0<jTRP3<XhT0
bIn50<NNQ0<0aYf301H0a9^10<>JP032UW`0`YAk0<:AN032SgP0`Y1l0<:AO`34V8D0a9V50<:CNP2o
S6l0^gmN0;]oG@2nRFP0`8i^0<:<L033RW40bIJ30<nWU`3Kc/@0h=cE0P3Sin400`3Si^00h^CN0>;T
gP040>;Tg@030>;Sg@3Rhm`0h^?L00<0h^?L00@0h^?K0>;Rf`3Rh]/0h^;K103Rh]X0103Wi]h0jNSP
0>GTg03Hem0Z0?oooa/0moOg0140oooo0?O6[@3__JD0iiB40=jLQ02<FT80W5Y20=JLQ02DFTX0S5Y:
08AB@P2DHdX0YG=J0>NmY@3_c[D0mmJm0>o>]@040?OFaP030>oFcP3ge/H0mmJm00X0mmK600h0mmJm
0?OFaP3_c[D0klje0>NmY@3W]I`0ikFD0>N]U03W[I`0ikfU0>o6[@3__Jd0mkfe0?OF_@80klje00<0
mmK60?OF_@3ge/H00`3ge/H01`3ge[d0klje0?Nm]@3__Jd0kkfU0>N]U03NYH`00P3FW8@01P36W8@0
cYAk0<jDN`36S7<0aYAk0<jDN`<0eYb400@0eYb<0=JUS03NYH`0gZfD0`3W[I@00`3N]I`0ijfD0=je
W0020=j]U0<0ijfD00H0gZfD0=jUS03N[I@0eZF<0=jUS03N[I@20=jUS080eZF<00<0eYb40=JLL`3F
W8@00P3FW8`02@3N[I@0g[FU0=jeW02eLeX0aV]B0<jDL`3FYH@0eZF<0=jUS0020=J<N`030?O_k`3g
moL0moOg01`0moOg803oool001h0oooo00D0f=O@0>WYh03Yj>00i>CL0>;Rf`030>;RfP@0h^;K103R
hm/70>;Sg00K0>;Tg@3RiMh0h^GO0>;Sg03QgM@0fl:`0=F_V02lQ6L0ZW5C08MD>@1kCC@0M4Te07=:
=`1_BCX0KTTl07eIB`2?JeX0^IEo0<ZWS`3M_J@0hL:Z0>;5/03Ra[40h/F`0>;5[`3RaJd0h/F/0080
h/F[01`0hLF[0>74[03Pa:`0h<>]0>32[03O`J`0gl6[0=k0ZP3M_jX0gKjZ0=bmZ@3K^:@0f[FQ0=N]
V@3EZIH0djBA0=:RS`3?XX`0cj><0=2YS`3B[I<0f;JK0=ViWP3K_:40g<2V0=g2Z@3Pa[00hLNc0P3S
b;H0:03SbKD0hlVc0>;7/03Qa:d0g[bV0=^fX@3EZY@0dJB=0<VHPP35TWh0_XUh0;b7M@2jQVl0^HI/
0;N6JP2fQFX0]XI/0;R7K`2kRW80`95h0<:DO035VX40aYb30<NLP`38Vh<0bIb30<ZNQ@3;XHP0cJ::
0=2SS03@XX`0cZ290<fOQ`3;WhD0bj260<ZPQP39X8H0aYf30<FLPP34VX020<>JP00F0<>JO`32VGl0
`YIl0<:DN`32TGP0`Xmi0<:?N`32T7d0`iB00<:EO`2nT7@0^XY/0;AoG02cOET0]7iL0;IoG`2kOf<0
_X5X0<NDP@3>YYL0flk40>3Le080hnOQ00<0hnKP0>;TgP3Ri=d0103Ri=d50>;Sg0030>;Sf`3Rh]/0
h^;K0080h^;K103Rh]X0103Wi]h0jNSP0>GTg03Hem0Z0?oooa`0moOg00l0kkfU0>NUS03_U8`0_HA[
07=2<@3>U7/0]G]S0:ecFP2<Lf<0S5Y:08ASDP2ULeX0ikfU0>o6[@3ge[d0103ge/H00`3gg/h0mmK6
0?OFaP040?OFaP80klje0P3ge[d60?OFaP060=K6aP3g_KD0ikfU0>NmY@3W]I`0ijfD0P3N[I@0103N
YH`0mkfe0?O6[@3ge[d20>o>]@030?OFaP3ge[d0mmK60080mmK600L0klje0?OF_@3_c[D0kkfU0>Ne
W03W[I@0gZF<0080eYb400T0cYAk0<jDL`3>U7<0aXac0<jDN`36U7/0cYAk0<JLQ03FW8@00P3FYH`3
0=j]U080ijfL00H0gZfD0>N]W03N[I@0ijfD0=j]U03NYH`30=j]U080gZF<0P3N[I@00`3NYH`0eZF<
0=jUS0020=JLQ0040=JLS03FW8@0cYAk0=JLS080eZF<00@0g[FL0=JUS02]Je80[F]B0P36Je801P3>
S6/0gYb40=JLS03FS7<0kmK>0?ooo`T0moOg00<0mno_0?Ogm`3gmoL03`3gmoL00`3gknl0moOg0?oo
o`0O0?ooo`007P3oool01@3Hem00jNWP0>WXh03Ti=`0h^;K00<0h^;J0`3Rh]/50>;Sf`L0h^?L0P3R
i=d07P3RiMh0h^;J0>7LdP3K`Jl0eJjH0;b4J02ZLE@0Qe@j07]<=01aAc<0KdLe06U4=P1XACP0MeE8
08YWF02gTgd0bZJ>0=fmY03Q`ZX0h/F_0>75[`3Qa:h0hLB]0>75[03RaJ`0h/J[0>;5ZP3Qa:X0gl:Y
0=g0Z@80g;jX01L0fkfW0=ZlYP3H^J@0ekRS0=NgXP3G]Z40e[>N0=F_V`3CZ9D0dZBB0<nNS@3>W8/0
cIb80<bNR03>Y8/0dJR>0=JaUP3G]IX0fKRM0=^nY03L`:P0h<F_0>76/P020>?8]P0Y0>?9]@3SbK<0
h/J`0>74[@3N^ZD0fkBP0=FXT`3AXh`0b9N00<BAO02mR7H0^hIb0;Z5K02iQFX0]hEX0;J5J@2eQV`0
]hM^0;V9L@2oT7L0`9=j0<:HP033VX40`iV00<BIP035VX00aY^20<VOQP3;XHT0cZ:<0<nRS03=WhP0
bif50<ZMP`39WX@0bIn50<ROQ@36WH<0aIb20<>JP033VGl00P32VGl05@32V7h0`YIl0<:DNP32TGP0
`Xmh0<:?N`32T7d0`Y=o0<6DO@2lSW80]hQZ0:mlF@2/MeD0[GEC0:meE@2eMe/0^W]Q0<JCO`3=YYH0
flk40>3Le0020>?Wh@030>?Vh03Ri=h0h^CM00<0h^CM00<0h^?M0>;Sg03Rhm`00`3Rhm`00`3Rhm/0
h^;K0>;Rf`020>;Rf`@0h^;J00@0inKN0>WXh03Ui=`0f=O@:P3oool00`3gknl0moOg0?Ogm`0H0?Og
m`0C0?O_k`3W]I@0gYAc0>neY@2ULeX0]G=J0:ecFP1B8AP0S5Y208aSDP2]Q6/0Q6=B08A[FP3W_JD0
klje0?OF_@3ge/H0klje0?OFaP020?OF_@030>o>]@3ge[d0mmJm0080klje00<0klJ]0>o>]@3ge/H0
0P3_e/h30?OFaP060>oFcP3Fa[d0mmK60>o>]@3g_KD0e/Je0P3W_JD00`3WYH`0gZfD0=jUS0020=jU
S0040=jeW03__Jd0klje0>o>]@H0mmK600L0klje0?OF_@3__JD0kkFU0>NUS03NYH`0eYb400<0cYAk
0P36S7<20<jDN`80aYb400H0eYb<0=JUQ03FYH`0gZF<0=JUS03NYH`70=j]U0030=JLS03NW8`0gZfD
0080gZF<0P3N[I@01@3NYH`0eZF<0=JUS03FYH`0eZF40080eYb400D0eZF40<JLQ036W8@0eZF<0<J]
Y@020=JUS0090:E[DP2UHdX0YE8i0:EB>@2mFT80cW=B0=JLL`3FW8`0kkf]01h0moOg803oool001h0
oooo00D0f=O@0>WYh@3Yj>00i>CL0>;Sf`020>;RfP@0h^;K1@3Rhm/60>;Sg00k0>;Sg@3Ri=d0h^?L
0>;Sf`3Rg]<0hMO;0=bo[P3F[i/0`H]c0;9jH@2CGTD0QE<l0716<`1X@S40GSd`05hn<`1bDDD0QVEF
0;FBO039YXd0gKfS0>72Z03Qa:X0h<>Z0=k2Z@3O`ZX0hLB/0>;5[@3RaZd0h/FZ0>33Z03J^j40ekNN
0=>cVP3B/YX0d:nG0<f/U037Y8`0a:290<:NQP32WHH0`Ib60<6JQ@30UH@0`9:20<6>O`32SGl0aI5n
0<JDOP3:VX40bif30<jSR03?YX/0dJZ?0=FcV@3G^9l0gL2[0=o4[`3RakD00P3Sb;D05@3Sb;@0h/Ja
0>73[P3N^JD0fk>P0=BWTP3@XH/0aiIn0<>AN@2mRG00^hM]0;V4I`2iQ6H0]XAW0;F5J@2eQfd0]XQ_
0;R9L@2kSG@0_8mg0;bDN`030;^EO0040;jFO@30V7h0aIb30<NOQP80bj::0240bIj60<NLP`36Vh40
aib20<RNQ038WhD0b9j40<NMP`34Vh00`iUo0<:IO`31V7h0`IQm0<6EN`31U7X0`Y1h0<:?N032Sg/0
`Y1l0<:COP31Tg`0^H]`0;:2IP2SKe40WfM909eN@@2OGT40ZVE90;5^D`32SWL0c:BA0=_>``3Pg=@0
0P3Sin400`3Si^00h^CN0>;Tg@020>;Tg@030>;Sg@3Rhm`0h^?L00<0h^?L0P3Rhm/40>;Rf`@0h^;J
00@0inKN0>WXh03Ui=`0f=O@:P3ooolK0?Ogm`0?0?OWgP3NU7<0ig][0>nm[@2]LeX0]G=J06=2<@24
DST0LdXi058a:@1S@S40Le9:08ASDP3W_JD0klje0080mmJm00<0klje0?OF_@3ge/H00`3ge/H20?OF
_@090>o>]@3_aZd0g[FL0<JLQ03N[I@0eZF<0=JUQ036U7/0cYAk0080aYAk0P36U8@00`36S7<0eYb<
0<j<Q0020=j]U0040=jUS03NW8`0gYb40=jUS080gZfD00D0e/Je0>o>]@3ge/H0mmK60?ONcP030?OF
aP060>o>]@3ge[d0kkf]0>NeU03W[I@0gZF<0P3>U7/20<jDL`040<j<J`36W7<0aYAk0<JDN`@0cYAk
00@0cXb40<jDN`3FW8`0aYb4103FYH`01@3N[I@0eZF<0=jeW03FYH`0eYb<00<0gZfD00D0g[FL0=j]
U03N[I@0eZF<0=j]U0020=JUS00B0=JLQ03FW8`0eYb40=JLQ03FW8`0eZF<0=jeW03FYH`0aYb40:Ec
FP2UHdX0[EY20:EB>@2eDST0_EY20<j4H`3NW8@0ijfL7P3gmoLP0?ooo`007P3oool01@3Hem00jNWQ
0>WXh03Ti=`0h^?K0080h^;J0`3Rh]/60>;Sf`H0h^?L05T0h^CM0>;Sg03Rhm/0h^7I0>;Jc`3QdlH0
g;j/0=J_V`32SWL0]7eV09EPB025E3h0K4@a068n;@1H>Bd0FC/`06m@A025I5D0]I9l0<VVS@3M_J40
h<6V0>33Z03O`ZL0g/6W0=k1Z03Pa:`0h/F^0>;6[P3RaJ/0h<:W0=RiWP3D]9X0cjfD0<f[TP39Yhh0
aJ::0;fHO`2iTg/0]Hmg0;B>M`2bSGP0/Hah0;68M`2bQWL0]H=e0;N4M@2nRGL0`Heh0<FDNP36UG/0
b9Qn0<RJP03:WX@0cjR?0=:^UP3J^jD0g/2/0>;6/`3Sak@0hlRe0>?8]03Ra[80hL>_0=jiYP3K/j00
e:NB0=2QR`37Ugh0`i9h0;f:KP2kR6X0^HEV0;R4I@2fQFL0]HIY0;B8KP2fRFl0]hYa0;Z=M02kSgH0
^Y=j0;VDN`2hUG`0^IEl0;bFO@2oUgh0a9^20<NNQ@020<VQR@050<JNQ@35Vh80a9Z00<FKP@38WX@0
0P39WhD06P38WX@0aI^10<>JP032VGl0`IMm0<2GO@30UG/0`9=j0<2@N030SgP0`I1k0<:AO033U7h0
`IAl0;R:K`2`P6D0WfU>09UPA02GECX0VEDj0:EN@@2^J4`0`H]c0<^RSP3KcL80h=cD0P3Sin400`3S
i^00h^CN0>;Tg@020>;Tg@030>;Sg@3Rhm`0h^?L00<0h^?L0P3Rhm/30>;Rf`D0h^;J00@0inKN0>WX
h03Ui=`0f=O@:P3ooolK0?Ogm`080?ONcP3NU7<0gYAc0>nm[@2eNf<0YF=:048Y8@1c@S42048Y8@07
058i<@1cBT80Nf=B0>NmY@3_aZd0mmK60>o>]@020?OFaP0<0>o>]@3ge[d0mmJm0?OFaP3_c[D0klJ]
0>NmY@3FYH`0aYAk08aJBP24He80S5Y:0P2ULeX20;f4J`050;F<L`36U8@0aYB40<JDN`3FW8`00P2m
Q6<00`3NW8`0cXb40=JLQ0020=JLQ0030>NmY@3__Jd0kkf]0080klje00D0mmK60?ONcP3gg/h0mmk>
0?OFaP020?OF_@80kkfU00@0gZfD0=jUS03FW8@0eYac0`36S7<01`36U7/0aXac0<JLL`3>U7/0cYAc
0<jDN`36W8@00P3FW8`60=JUS080gZfD00<0eZF<0=j]U03N[I@00P3N[I@00`3N]I`0gZfD0=jeW002
0=j]U0090=JUS03FYH@0eZF40=JLQ03FW7<0eYb40=JLS02mW8`0_JFL0080eZF<00<0eYb<0:ecFP2U
Je800P2UDST01P2]FT80_EY20<j4H`3FW8@0gZfD0?O_kad0moOg803oool001h0oooo00D0f=O@0>WY
h@3YjN00i>CL0>;Sf`030>;Rf`L0h^?K1P3Rhm`20>;Tg@0k0>;Sg03Rh]T0hMkD0>3B``3Ob[T0g;RT
0=N]V02oSGT0[7UU085B@01_@c80EC<T04d`8P17;b@0Bc<Y06M<@01oHU<0]I=m0<VWSP3M_J00gl2S
0=o0Y03N`:<0g[nT0=o0YP3Q`jX0h/F/0>;6[@3RaJX0h<:W0=ViW@3E/iL0bjR=0<NTR@2mVX00]iAi
0:^6K@2UP6P0VWQR09IeH@2>L5l0RfiN08YZG02;J5/0U6UJ09Y[F`2XMV80[gaV0;J1J@2gP6L0]GaS
0;AkHP2eO6@0^hM_0<6BNP3AZY@0f;JO0>33[`3Ra[800P3Sb;D0?P3Ra[<0hL>`0=jkYP3K]J00e:VB
0=2SR`38Ugd0a99f0;f<K02jRVP0]hMU0;J7I02cQVH0/XEX0;>7K02dR6l0]hYa0;^?MP2mTWT0_IIm
0;fGOP2lV7l0_IQo0<2HO`32VGl0aYZ10<NKP`36W8D0aIb50<2IP@2oV7l0`9Qo0<:JP038WX@0bJ26
0<ZPQP39WhD0aYb20<BJP032VGh0_YIl0;fEN`2kTgT0^Y5h0;^@M`2lT7P0_i5j0<6CO033UWh0`IEl
0;N9K`2^OV@0W6A;09IJ@@2BCCD0UD`d0:9E>P2[H4@0_hE]0<VNR@3Jc<00gm_C0P3Sin400`3Si^00
h^CM0>;Tg@020>;Tg@H0h^?L00<0h^?K0>;Rf`3Rh]/00P3Rh]/50>;RfP040>OVgP3Yj>00iNCL0=SG
d2X0oooo6P3gmoL03`3gknl0klje0>MkJ`3NU7<0kkFU0<jDN`1J<B408A0@02TH600a8AP0DS4Y04Xa
<@1cBST0LdY20>o6[@020?OF_@030?OFaP3_c[D0mmJm0080klje0140mlje0?OF_@3ge/H0mmJm0>o>
]@3_aZd0g[FL0=jeY@36U7/0Q59207=:>@2DNg<0]IbL0<jm]@2DQ8@0Hd8a08aSDP0205Xa8@0?07=2
<@2<FT80]G=J0;EcFP2mQ6<0aXaS0<icFP3>Q6<0cXa[0=jUS03W_JD0klje0?OF_@3ge/H0mmk>00<0
mmK60P3_c[D02@3__JD0ijfD0=jLQ03FW8@0cYAk0<J<L`3>S6/0_HA[0<JLL`020;f4H`030<JDN`36
W8@0aYb400D0eYb400@0eYac0=JLQ03FW8@0eYb40P3FW7<01P36W8@0eZF<0=jeW03N]I`0gZfD0=je
W0<0gZfD0P3FYH`01P3FYH@0eYb40=JUS03FYH`0eYb40<JLQ0<0eZF<0P3FW8`02P2ULeX0[F]B0:eJ
@P2]FT80]E8i0;eJ@P36Je80eYac0=j]U03gknlM0?Ogmb00oooo000N0?ooo`050=SGd03YjN40jNWQ
0>CTg03Rhm/00P3Rh]/80>;Sf`H0h^?L07d0h^CM0>;UgP3Ri=d0h^;I0>;MdP3Pckd0glJb0=beW`3F
ZY@0^hUf0:AcH@1bASL0GCHY04HX70109a`0?RTP04<_9@1RBSh0O65B0;BDO@3:Z8h0gKfP0=o0X`3N
_j<0g[nR0=noX`3P`:D0hL>Y0>;5Z`3RaZ`0h/FZ0>33Y`3K^il0ekFI0<bYSP36XhP0^YIl0;>?M@2V
PVT0WgaT091aG@29K5X0O6=E07QPD`1eFTh0MeQ<085JB`29GTd0Vf]F0:9bF`2/Mel0[GEM0:]^EP2Z
Je@0ZVaD0;5gH02hPf`0c::;0=FaV@3P`Z`0h/Ja0>?8]@3Sb;H0h/Jd0>74/@3N_:L0fkNP0=BZTP3@
Xh/0aiMl0<>BMP2lRf/0^XYX0;J8I@2dR6@0/8AT0:n3I@2`PfT0/XE/0;F9L02lTGL0_YAj0<2HO`30
VH00`9Z00<6JP032VGl0a9Uo0<JIP036V800a9R20<:GP@2nUWl0_9Em0;fGOP30VGl0aij40<VPQ@3:
X8H0bIn50<JLPP34VX00`YQn0;fEN`2jU7X0^95h0;N@M`2hSgL0^Y1g0;jBNP30U7`0`iMn0<6EO02g
RFl0[WiT09eUC02GFT80Tdhf09I==02RE3X0Zei40;n3K03:W8P0f/_00=oKd`020>?Wh@050>?Vh03R
i=d0h^CM0>;Tg@3Rhmd01P3Rhm`00`3Rhm/0h^;K0>;Rf`020>;Rf`D0h^;J00@0i^KN0>WXh03Ui=`0
f=O@:P3ooolJ0?Ogm`0;0?O_k`3_aZd0ig][0=jDL`3g_KD0eYb<048H400Q4100<B4H048Y8@1B<BT0
0P1S@S401`1kHe80klJ]0?OF_@3ge[d0klje0?OF_@3_c[D00P3gc[D0103ge[d0mmK60?OF_@3ge[d2
0>o>]@0;0>o6[@3N]I`0gZfD09a[DP1cBST0[HA[0;FUY@2m]Kd0Nf=J0:f4J`36[JD00P0Y61P01`24
DST0Nc4Q09a[DP2eNf<0[F]B0:ESBP2]FT800P2UDST01@36S6<0ikFD0>o6[@3ge/H0mmk>0080mmK6
00d0mmk>0?OFaP3ge[d0klJ]0>neY@3W]I`0gZF<0=JLL`3>U7/0cYAc0;F<L`36W7<0_HAS0080_HA[
00<0aYb40=JLS03FYH`01P3N[I@20=jUS0080=JLS03FYH`0eZF40=JLQ036W8@0cYAk0=JUS03N[I@2
0=jeW080gZfD0`3FYH`00`36W8@0eZF40<JLQ0020<JLQ0070;fLS03FW8`0eZF<0=JUS036W8@0W7=S
0:e[DP020:eJ@P80_EY200@0cW=J0=J<L`3NYH`0mnOW7@3gmoLP0?ooo`007P3oool0103Hf=00jNWQ
0>WYh@3TiMd;0>;Sf`H0h^?L01d0h^CN0>?Vh03Vj>40i^KM0>GPe03Rc;P0h<6Z0=^^U@3EY8/0]89^
09QYF@1M>2d0AbLN038K4`0_71@0<R4I03TW7`1KACX0N5m?0;BEOP3;Zi00g[nR0>31Y03N_j<0g[jR
0>2oX`3P`:@0hL>W0>;5Z@020>;5ZP1Q0>;4Z@3O_j@0g;^P0=2]T`39YH/0^iIl0;F@M`2ZQVh0XX1Y
08Y_G@1lIEH0He9705Y:@01B?cH0E3db0611<@1YAS@0OEI208INBP2DIE00V6=>09aMAP2MFd@0Wea5
0:UZDP2bN600b9b20=:/T`3N`JX0hLJ`0>?:]`3SbkT0h/Zh0>78]@3N`:X0fk^S0=B]T`3@YH/0aiIl
0<:@M@2iRFX0]XMW0;66H`2^Q640YWYJ0:9dE`2QL5L0YWAM0:alI02jSG<0_i=h0<>HN`34V7`0`iUm
0<:HO02oU7X0_Y9h0;b>M@2mSGH0_Hih0;f?NP2jTGX0^I9j0;^FO02oV7h0aYf10<ROP`3:Wh@0bIj4
0<JLPP34VX00`IQn0;ZCN@2gTGL0/hid0;:=M02dSgH0]Y1g0;bCNP2oU7`0`IEl0;nCNP2dQVd0Zg]R
09]TC@2FFd@0UE<k09QB>P2UF400[V590<64K`3;W8/0g<c20>7Le03Tj>80i>SQ0>?Vg`020>;Tg@03
0>;Sg@3Rhm`0h^?L00@0h^?L00<0h^?K0>;Rf`3Rh]/00P3Rh]/60>;RfP040>KVgP3Yj>00iNCL0=SG
d2X0oooo6@3gmoL02`3oool0kmK>0>NeW03>Le80cXAS0>N]W03_]JD0DS4Y048Y8@0i:B40@RTa0080
DS4Y00/0Nf=B07=BBP3_c[D0klje0?OF_@3ge/H0klje0?OF_@3g_KD0klje0?OF_@020?OFaP0>0?OF
_@3ge/H0klje0>o>]@3FYH`0cXa[0=K6]@36U7/0YHAk0:EcFP1S@S40FS4Q09B4Q02LS8`202TH600?
07=BBP2<FT80Q6]J0;fUW02eW9`0W7=S08AB>@2]FT80cXAS0>NeU03__JD0klje0?OFaP3gg/h0mmK6
00<0mmk>00T0mmK60>o>]@3__JD0ikFD0=jUS03FW7<0cYAk0<j<J`2mQ6/00`2eLeX00`2mQ6<0eZF4
0=j]U0030=jeW0060=JLS03N]I`0gZfD0=JUS03N]I`0eZF<0P3N]I`01`3N[I@0eZF<0=JLS03FYH`0
aYb40=JUS03N[I@00P3N]I`00`3N[I@0eZF<0<JLQ0020=JUQ0050<JLQ03>U7/0eZF40=JUQ036W8@0
0P3FYH`01P36W8@0aYAk0:E[DP2DHdX0YF=:0:eJ@P80aV]B00@0cXa[0=jLQ03NYH`0mno_7@3gmoLP
0?ooo`007P3oool01@3Hf=00jNWQ0>WYh@3TiMd0h^CL00X0h^?K1@3Rhm`0D`3Qhm`0h^CN0>CVh03W
jN80j>ON0>OQe@3SbkL0hKnW0=^[T@3DXHL0/gm[09MXE`1M>Rl0AbTQ030K500]6a@0;ahG03LT7@1K
A3P0N5i>0;FFO`3;[980gl2S0>32Y@3N`:<0g[nS0=noX`3P`:@0hL>W0>;4Z03RaJT0h/JZ0>;5Z@3P
`ZL0g[jT0=>`U`3<Z8l0_iUo0;^DN`2cSGH0ZhMb08mcH@1nIUL0Gde305A3>P19=bh0BS@Z05Dh:@1M
?Rd0L4hl07YFA029Gd`0Sem;09ULAP2MG4D0XEm80:e`E`2fOFD0bYn50=>^U03N`ZX0h<N`0>;;^@3S
cK/0h/bk0>7;^03M`j`0fkfT0=B^U03@YX/0aYIk0<2?M02gQVT0]8EV0:n3H@2[P5h0X75B09YXC@2G
HT/0W6QB0:EbF`2gR6h0_8mc0080`IAe02d0_i=f0;fBMP2hSG80]HU_0;:5K02cQFd0]hUc0;V;M@2h
SgP0]i5i0;ZEN`2mUg`0aIao0<NMP038WX80aif20<FKP@33VGl0`9Mm0;ZBN02fSgD0/Xac0;6<L`2c
SWD0]Hmg0;bBNP2oTg/0`9=k0;fAN02aPfX0Z7QP09QRC02CFT@0U5@m09QE?@2VG4@0[fE>0<>7M03=
Whl0gLk40>;Me@3Uj>80i>SQ0>?Vg`3Ri=d00P3Rhmd60>;Sg0030>;Sf`3Rh]/0h^;K0080h^;K103R
h]X01P3RhMX0h^;J0>KVgP3Yj>00iNCL0=SGd2X0oooo6@3gmoL05@3Nc]H0g[FL0?O6[@3>Le80cW=J
0>N]U03W[I`0HcTa03TY8@0Y61P0@RTQ03TY8@12:B40LdXi08acH`3_aZd0klje0?OF_@3_c[D0mkfe
0>o>]@020?OF_@050>o>]@3ge[d0mmJm0?OFaP3_c[D00P3ge[d0603W_JD0gZfD0=j]U03ge[d0gZfD
0<JLQ02LLf<0LdXi06<i<@1kHeX0610@02TH601J@ST0Ld8a08acH`2eW9`0]Hac09a[DP2]FT80_HAS
0<j<J`3W]I@0klJ]0>o>]@<0mmK60`3gg/h02@3_c[D0klJ]0>nmY@3W]I@0gZF<0=JLL`3>U7<0_HA[
0;f4H`020;EcFP0>08`a:@24DST0]G=J0=JLQ03FYH`0g[FL0=JLS03>U7/0cXb40<jDN`2eS7<0_HA[
0<J<L`36W8@30=JUS0040=JUQ03FYH`0aYb40<JDN`@0eZF<00@0eZF40=JUS03FYH`0cYAk0P36W8@0
0`3>U7/0aYb40=JUQ0020=JUS00<0<jDN`2eS7<0W6]B09a[DP2UJe80YF=:0;EcFP3>LeX0cXa[0=JL
Q03NYH`0mnOW7@3gmoLP0?ooo`007P3oool01@3Hf=00jN[R0>WZhP3TiMd0h^CL00X0h^?K103Rhm`2
0>;Tg@210>7Sg03Ph]`0gmkG0=kJd03NdlL0g/6]0=nhX03KZ8`0e9j20;J1JP2OKU/0K4Lk05Hh;P0i
91d0<AlI02hL5P0e8AX0FT4f07MLC@2dUh00bjjC0>33YP3Ra:L0gl:U0=k0Y03M_j<0g/2T0>33YP3Q
a:L0hLFX0>;5Z@3RaJX0hLB/0>32Z`3H]j00dZnG0<ZSRP3:XHP0aij70<2IP`2QP6h0SG1O06UCA@1L
Ac/0CcP]04de:@1C=RP0FC/[06I9>@1]DD40OUe<08QPC@2LITl0YFaC0:ecF@2mQV`0a99h0=6ZS`3F
]9X0gL>[0>38/@3Rc[/0h]2o0>;A`03Qckd0gLJ`0=_0Y`3D[iD0d:J<0<FEN`2oSG<0/h9W0;1oH`2[
O5d0YgMH09IQAP2<E3`0QDXg08]B?`2FH4/0Zg]R0;22I`2`Q6D0[H9S0:ImH02RNUl0VG9K09I_F02G
KUL0Vg9J0:ImI@2ZPFX0[8M_0:b8L02`S780/hic0;ZCM@2mU7L0_iEi0;nENP30UGX0_iAj0;jCN@2i
SgD0]Xeb0;6:L@2`Rg40/hee0;F>MP2lT7T0_Y1j0;b>M`2hRg<0Z7]T09i`FP2<FdL0R5E108eD?P2D
F440YVA=0;1_F@36TGl0dJRI0>7Cb@3UhMT0i^WS0>GXhP3Si]l0h^CM00L0h^?L0P3Rhm/40>;Rf`@0
h^;J00H0h^7J0>;RfP3Vi]h0jNSP0>GTg03Hem0Z0?ooo`060?Ogm`3gknl0moOg0?O_k`3gmoL0mno_
4@3gmoL04@3gknl0]IbL048H403W]I@0kkfU0<icDP3FLf<0kkfU0>NeW024He808A0@04Xa<@1B<BT0
@RTa03TY8@1SBT80Q6=B00<0klje0P3ge[d20>o>]@040?OF_@3_c[D0mmJm0?OF_@<0mmK60140mmJm
0>o>]@3_aZd0ikFL0=JUQ03ge[d0klje0;F<L`3N[I@0Q59207=BBP1cBST0Hd8a07=2<@1c@RT0U6=:
08aJ@P030;EcFP070<J<H`3NW8@0gZfD0>NeW03_c[D0mmJm0?OFaP040?ONcP070?OFaP3_c[D0kkfU
0>NeU03NYH`0eYac0<jDL`030;f4H`0:0;EcFP2LFT80Ld8Y08AB@P2]Q7/0]Hac0<JDQ02mQ6/0[G=J
0:EcFP80U6=:0P2LLf<01@2ULeX0W6]B0:ecFP2eNf<0aYB40080aYAk00<0aYb40<JDN`36W8@00`3F
YH@01P3>U7/0eZF40<jDN`36U7/0aYb40=JUQ080aYb400@0eYb<0=JLQ036U7/0[HA[102DHdX00`36
S6<0cXa[0=jDL`020=jLQ0030?OWi`3gmoL0moOg01/0moOg803oool001h0oooo00D0f=S@0>WZhP3Y
j^80i>GM0>;Sf`020>;RfPP0h^?K103Rhm`07P3SiMh0i>KO0>3Rf`3LgMH0dLg50<k5^`3>_[40eKBO
0=Z`V03LYhX0eYn30;Z5K@2TM5l0MDm105lo=@0n:B<0=28M02hM600d81/0F3ld07IKC02dUh00bjjD
0>33YP3RaJP0gl:U0=k1Y03M`:<0gL6T0=o3YP80h<BW03h0hLFY0>75ZP3QaJd0h<>/0=ZjX`3F/i`0
d:V?0=2WSP3>Y8d0b9n90:^8M02INFD0Mee<06aB@`1NA3L0G40b05lo;`1R@S40Jddl075D@`21H4h0
RfEA0:5_E`2[MU`0]7iS0<B@MP3:VX00e:jC0=NfW03M`j/0glRb0>;?_03RdL00h];10>7@_P3Ma[00
fl2W0=B_U03@YX/0aIAj0;n=LP2cPFH0[giR0:YiG02VM5L0U5i408]A>P23Ac@0R4ll095LB@2SMUl0
YgaS0:=kGP2MMUX0T6aC08]XD@24HD`0Q5m;08USC@2?J580VgEN09mjH`80X7iW00L0Xh5Y0:R4JP2a
RVh0]8a_0;N=L@2hSW80^hmc0080_8md01X0^Heb0;J<L@2aRW40/8]a0;>=M@2fSWH0_8mi0;f>N@2j
S7D0]HQ`0:=hH02GK5H0QEM4085A?P26DSd0SUM10:=WD02_LUd0b9J40=:/W@3ReL/0i^;J0>KZh`3U
j>80hnKO0>;Sg@L0h^?L0P3Rhm/40>;Rf`@0h^;J00H0h^7J0>;RfP3Vi]h0jNSP0>GTg03Hem0Z0?oo
oaH0moOg00H0oooo09AkL`1J<BT0@QP@0=jDL`3gaZd40>NeW00;08AB@P0Q4100BS4a058a:@12:B40
DS4Y06=2<@24He80klJ]0>o>]@3ge[d00P3_c[D01@3ge[d0klje0?O>]@3ge/H0mmJm0080mmK600T0
mmJm0?OFaP3ge[d0mmJm0>o>]@3W_JD0ikFL0=j]U03_c[D00P3N]JD02@2]Q6/0]HA[09a[DP1cDTX0
W6]B08AB@P2ULe80[F]B0;f4H`020;EcFP80ikFD00H0gZF<0>NeU03_c[D0klje0?OFaP3gg/h20?OW
gP0N0?ONcP3ge/H0klJ]0>nmY@3W]I`0gZF<0=J<N`3>S6/0_HA[0;f4H`2mQ6/0_HAS0:e[DP2ULe80
S5Y20:f<Q036[Jd0e/Jm0=K6aP24JeX0Q58i07/Y601S>BT0Hd8a08AB@P2LLf<0W6]B08AB>@2<FT80
]G]S102eS7<01P3>S6/0aXac0<JDN`36U7/0aYac0<JDN`80cYAk00@0eZF40<JLQ03FW8@0eYb<0P36
W8@00`2eS7<0]G]S08aJ@P0308aJBP060<J<H`3FS7<0eYac0=JLQ03NU7<0kmK>7@3gmoLP0?ooo`00
7P3oool01@3Hf=00jN_R0>W[hP3TiMd0h^?K0080h^3I00<0h^;J0>;Sf`3Rhm`00P3Rhm`30>;Sf`80
h^?L01`0hN?L0>;Sg03Ti]h0i>KO0=WIdP3:al00YIN?09V4N`2IO700]8Qd0<BCN`3FX8@0e9j20;f;
LP2[NfD0OeQ806U8?015;b/0=bLU02/M700_81`0DSdc075IBP2bUWl0bZjC0=o2Y@3Q`jL0gl:U0`3N
`JD20=g0Y01T0=g0X`3M`:D0g/6W0>33[03P`jd0g/2Y0=^lY@3G]I/0ek:H0=B[TP3@YXh0_IEn0;:<
M@2NNfD0UgEP08i[E`2;Ie80Qf1908INAP27HDT0RVE=09I`EP2NMU`0/8=W0;V9K@31T7<0cIb10=6S
R03G/9H0fKNL0=g3Z`3Oak40h/nk0>;A_P3Rd;h0hLjk0=g4[@3K_JD0e:jC0=2URP36UGX0`Heb0;N2
I@2cOV40[7UL0:MdF02JHdX0TeY308aD@02=FDH0TF9@09IbH02EM680QfYG07]PCP1PBS/0ET4d05Dk
;`1M@380LU0n07]IAP23IE40PfQC07iTD01lHDh0PFA?08QYE02GM5d0WGQO0:=kG`2VO5h0[h1R0;B3
I@2gQVP0^8Y]0;J:K`2aS780/Hac0;>>M@2fSWH0^hif0;b<M@2eQfl0[H9Y09I`F029I4h0MDhl0718
=`1fBCL0Oe0l09]VD02[MV00bIf:0=FcXP3Tf<d0in?K0>KYh`3Uj>40hnKO0>;Sg@L0h^?L00<0h^?K
0>;Rf`3Rh]/00`3Rh]/40>;RfP060>;QfP3Rh]X0i^KN0>WXh03Ui=`0f=O@:P3oool0103gknl0moOg
0?O_k`3gmoL20?O_k`030?Ogm`3gknl0moOg00d0moOg00H0aZf]048Y8@1B8AP0@QP@0<J<H`3WYH`2
0?O6[@80ijF<00P0S5Y:05Xa:@1SBT80@S4i034Q6012:B40HdY208aSDP80klje00H0mkfe0>o>]@3g
e[d0klje0>NmY@3W]I`20>o>]@070?OF_@3_c[D0mmK60>oFcP3ge/H0mmJm0?OFaP020>o>]@060>Ne
W03N]I`0gZF<0=JUS03N]I`0gZfD0P2eS7<01P2mQ6<0]G]S0;f4H`2mQ6<0]G=J0<J<H`80gYb40P3W
[I@01@3W_JD0klJ]0>o>]@3ge/H0mmk>0080mnON00P0mmK60>o>]@3_aZd0klJ]0>NeW03NYH`0eYac
0<jDL`80_HAS0P2mQ6/0702eLeX0[F]B0:E[DP2<FT80YHAk0=k>eP2m]Kd0Q58i0:F4N`0Q4100<B4Q
07=:>@24DT80Hd8a07]SDP2LJe80U5Y:06=2<@24He80YG=J09acH`2LJe80U6=:0:ecFP2eNf<0cXa[
0<J<L`3>U7/50<JLQ00?0=JUS03FYH@0aYAk0:f4J`2LJe80Q59207=:>@24He80S5Y:0<j<J`3FW8@0
gZF<0<j<J`3NNf/0e/Jm01d0moOg803oool001h0oooo00D0f=O@0>W[hP3Yjn<0i>GM0>;Rf`020>;P
f0030>;RfP3Rh]/0h^?L0080h^?L0P3Rhm/40>;Sg00J0>7Sg03Qhm/0gn7I0<k<a@2j]:d0S7Ua07eS
F@1mFTh0WFiK0;=oJ03;UGX0c9Ml0;R8L02WNV<0OEM806Q7?014;b`0=RLW02TM7@0]81d0D3db06mI
BP2aUWh0bJfC0=o1Y@3P`jH30=k1Y@1V0=k0Y03K_J40f[bP0=ZkW`3J_:00fkfS0=o2ZP3P`jd0gl:/
0=k1Z@3J^j40fKNM0=J_U@3BZI00aYb40;jEO@2bRW<0[HM_0:MoJ02SNf<0W79H09Y_E02IKU80Vg1D
0:=iG@2ZP680^Ha^0<2BM036UgT0cj240=>UR@3H/9D0f[JL0=g2ZP3Oak00h/jk0>;@_@3Rck`0hLbh
0=g2Z`3K^j<0e:fC0=2URP37UWX0`Xmc0;V4IP2eP680[GYM0:UfFP2OJU00VV=;09EOB@2EHdl0UFUG
09EcI02ALf@0OfIG06mJC01=?3<0@34Y040/901<<RP0J4Lh075A@01gGD/0MEi<06eGA@1ZDd80L5E4
07ULB@2<JUD0TViG09]bE`2OM5L0Zg]L0;5oH02fPf@0^8U/0;J:K`2bS7<0/Hec0;>>M@2fSWD0^hie
0;^<L`2aQ6`0YgiU08iZE021GTT0KDXh06Q4<`1^AC<0Md/i09ISCP2XM5h0bIj90=FcX@3Sf<d0i^?J
0>KYh`3Uj>40hnGO1`3Rhm`00`3Rhm/0h^;K0>;Rf`040>;Rf`@0h^;J00H0h^7J0>;RfP3Vi]h0jNSP
0>GTg03Hem0Z0?ooo`030?Ogm`3gknl0moOg0180moOg00L0]IbL06=2<@1:8AP0@RTQ048H401J<B40
aV]B0080ikFD00H0cXa[0<J<H`1S>C40Hd8a0592>@1B<BT2048Y8@0A06=:@P24He80klje0>o>]@3g
c[D0klje0?OF_@3_c[D0ikfU0=JLQ03N[I@0ikfU0>o>]@3ge[d0klje0?OF_@3_e/h00P3ge/H0303g
e[d0mmK60>nm[@3_aZd0ikfU0>NeW03N]I`0gZfD0=JUQ03>U7<0cXa[0;f4H`80eZF400X0gYb40=jU
S03NYH`0gZfD0>NeU03__JD0klJ]0>o>]@3ge[d0mmK60P3gg/h00`3gimh0mmk>0>o>]@020>o6[@04
0>NmY@3N[I@0eYb40<jDL`80_HAS0P2mQ6/04P2mQ6<0]G=J0;f4H`2eQ6/0]G=J09AcJ`2<Lf/0aZfU
0;fUW00H4100<B4Q0592>@1[DTX0LdXi07=JDP2LS8`0YHAk06]BBP80HdY200H0Je9:07]SDP24DT80
]G]S0<JDN`3FYH`20=JUQ0030<JLQ03FYH@0eZF400<0aYb400h0cYAk0<JDN`2ULeX0Nf=B06]BBP1c
DTX0HcTY06=2<@2mQ6/0eZF<0=J<L`3>HdX0cXAS0>o>]Ad0moOg803oool001h0oooo00D0f=O?0>WZ
hP3Yjn80i>KN0>;Sf`020>;Qf@030>;RfP3Rhm/0h^?L0080h^?L0`3Rhm/0QP3Ri=`0hnCM0>?Ug@3Q
hm/0eMC<0<W6_P2VVi@0SWmh0658@01E=B`0E2lT06lo<022Ccd0Wf]E0:AbG02KKe/0SFED06U9?`1G
?3D0>RXX030T900W7A`0;20L050n<`1_FDX0/IIn0<V]TP3M`:<0g/:U0=k1YP3N`ZL0g[nV0=bkXP3F
/9P0e:bC0=:[T@3C[Y@0eK:H0=^lY03N`JX0hLJa0>77/@3Oa:d0g/6Y0=^iX03I]9`0e:^C0=6WS`3<
X8L0bYf40<FHO@32U7T0^he`0;R:K02eQVL0]XIW0;Z;K02nT700ai]j0<^OO`3?XH<0e:J:0=JXS@3I
/9H0f[FK0=g0Z03OaZl0hLfi0>;?^`3RcKT0hLVe0=fnZ03K^:40e:bC0=2VS037VGh0`i=f0;^8J@2h
QF@0/H5P0:eoG`2YN5X0Z7EH0:IcF@2VMUh0YGUT0:5nK02LO6/0QV]L079KC`13=2h0<2@Q02XK600f
8Q`0EST]0613=@1UCT00HTi005I5>@1C@CD0Fd@f06I<?01oGDT0R6==09E[D@2LKe<0ZgYJ0;:0G`2g
Q6@0^HY/0;R;KP2cRg80/Xac0;B>M02gSgD0^hmd0;V<L@2WOF@0VG9K07]JB01_D3h0Gd4`05/m;01Q
?B`0Jd8`08aH@`2PJE<0aIAo0=:/V@3QdlP0i>3G0>GXhP3Tin40hnGO1P3Rhm`20>;Sf`D0h^;K103R
h]X20>;QfP050>;RfP3Vi]h0jNSP0>GTg03Hem00:P3ooolD0?Ogm`050?ooo`1cBST0Hd8a05Xa:@12
:B400P1261001@0Q4100U58i0:eJ@P1c@S40Ld8Y0080DSTa00H0@RTa048Y8@0i:B40<B4H07=:>@24
JeX20>o>]@0;0?Nm]@3_c[D0mmJm0>o>]@3ge[d0klje0<JDN`3>S7<0gZfD0>o6[@3_c[D00`3ge/H3
0?ONcP<0klje00<0ikfU0=j]U03W]I@00P3N[I@0103NW8@0gZF<0=jLQ03NW8@20=jUS0090=j]U03W
]I`0ikfU0>nmY@3_c[D0mmJm0?Nm]@3gg/h0mnON0080mmk>0P3ge[d01`3_aZd0kkfU0>NeW03NYH`0
eZF40<jDN`36S6<00P2mQ6<20<JLL`0F0<J<H`2eLeX0cYAk0<jDN`2eS7<0]G]S08AB>@1kHeX0610@
02TH601B>C40Hd8a05Xa8@1cFU80S7=S06=:@P1S@S40LdXi08ASDP24DST0[G=J0;F4J`80aYAk00@0
]Hac0<j<J`3>U7<0eZF<0P3FYH@04@3FW8@0eYb<0=JLQ036W8@0aYAk08ASDP1[DTX0LdXi08AB@P1B
>C40Hd8a0<j<L`3FYH`0cXAS0<iSBP3>Q6<0mkfe01d0moOg803oool001h0oooo00D0f=O?0>WZhP3Y
j^80i>KN0>;Tg0020>;RfP040>;Rf`3Rhm/0h^?L0>;Sg0@0h^?K08H0h^CL0>?Ug@3Ti]l0hN?K0<g:
``2k]:d0SWig07MSF`1B>2l0BB/R04PU6`1J;R40JCPZ08=A?`2:FTL0QUe<07YEA`1J?SP0BS<`03<V
900/8B00:1dJ02hQ701B?c@0LEY;0;6FO`39[I80gL2S0=k1Y@3N`JH0gl:X0=jnYP3L^:40e:ZC0=6U
S@3?XhX0cjN=0=6[TP3H^:00g;fW0>35/03Pak40glJ_0=k3[03L_:D0f[RQ0=J_V03DZi@0d:>;0<fO
Q`38VGl0aYMk0<6BMP2oT7<0_He_0;f<KP30T740`iAd0<ZMO@3=XH40d:B50=FXS03GZXl0fK6F0=Zf
V`3M`:P0glF_0>7=^@3Rc[/0h/bh0>78]03M_JP0f[JQ0=B[U03@YXh0aib00<>EN02lRVX0^8MV0;:4
HP2`Pf40[GiN0:elG02^Neh0[WeS0:j1J@2[QG00Yh=_099bH@1oHU<0BcXc03HY9@0[7AT0=B8L058f
:P1K?c80HDTl05i9?@1C@SL0D3ld05U3=@1TBSX0Oe]708URC02HK580Wg5E0:emGP2dPf<0^8QW0;^;
K@2iRfl0]H]a0;>;LP2eSW@0]i1e0;^@M02gS700XGQP091[EP1aDD40ITPi05Pl;@1F>BT0GCTY06Ln
;028DSd0W69;0<6<M`3?YI80gm350>?Ne@3Tj>40i>OQ0>?Ug`H0h^?L0P3Rhm/50>;Rf`@0h^;J0P3R
hMX01@3Rh]X0i^KN0>WXh03Ui=`0f=O@02X0oooo00<0mno_0?Ogm`3gmoL04@3gmoL01`3oool0FS4Y
058a:@1B>C40DS4Y024@401261000P1:40P01P126100FT8i058a:@12:C40>BTQ058a:@<0>BTQ00<0
HdY20:EcFP3_c[D0103_c[D0203ge[d0klje0>o>]@3NW8`0aYAk0=JUS03N[I@0kkf]0P3ge/H30?ON
cP80mmK60P3_c[D00`3__Jd0ikFL0>NeW0020=jUS0050=j]U03NYH`0gYb40=jUS03NW8@00P3NYH`0
0`3W]I@0ikFL0>o6[@020>o6[@030>o>]@3gg/h0mmk>0080mmk>00P0mmK60>o>]@3__Jd0klJ]0>Ne
W03N]I`0eZF<0<jDL`80cXa[0140aYac0<J<H`36W7<0cXa[0<JLL`3>U7<0eZF<0;F<L`36U7/0W7=S
06]BBP0a8B40:APH058Q601S>BT0DS4Y07=BBP0305Y2>@80Q6=B00/0W6]B0<JLL`2mQ6/0_HA[0<JL
L`3FYH@0aYAk0<jDL`3>U7/0eZF40=JLS0020<JLQ00?0=JLQ036W8@0aYAk07=:@P1S@S40LdXi06=2
<@1B<BT0Hd8a0<jDN`3NW8`0cW=J0;eJ@P3>Q6<0klje01d0moOg803oool001h0oooo00D0f=O?0>WZ
hP3Yj^80i>KN0>;Tg0040>;Sf`80h^?L103Rhm/0QP3Ri=d0i>GN0>GWh03Qh]/0a/6j0:jTW@1hIEd0
HT]304P]90139A`0@R4H04/R5`1D9a/0JCX/0754=01`Bcd0IdDk04Xc<00m:bT0;B4P02TO700Y7AP0
<24K05Do=01cFd`0/YIo0<Z]TP3N`:<0gl6T0=k1Y`3N`JP0g[fV0=^fX03CYY40cj2:0<fMQP3<XHP0
cZJ<0=BaVP3H]j40g<2[0=g2[@3L`jd0g<6[0=ZlYP3H^:80eJnI0=:ZU03<X8X0bI^40<BEN`32TgP0
_i5f0;jAM@2nSW80_Xia0<6@LP33TgD0bIal0<bOP03?Xh@0eJR=0=J[T03I/YL0f[JL0=g0Z03OaJh0
hLbh0>;>^P3RbkL0hLNc0=fkY`3J]J00e:^D0=2WS`37WX80`iMk0;b<K02iRFL0/hMS0;:6HP2aPf00
/X5O0;B1HP2eQ6L0]HM/0;B<M02bRW<0X7YV08i[FP1KAC`0AC@^03HV8@0l:B40E3P[05`o<P1RAc/0
GdPl05I2>01D@3D0GDDg06Q<?023GDP0SVE=09i`E@2TMUT0/H9S0;J7J02jS6/0_8e_0;^<K`2gRg00
]H]a0;J?M02hTGH0^Y5d0;J<K`2KM5`0RFA@06Q9>`1M@C<0DcPY058f9`1I=bH0HcXY08A;=P2HFD<0
_XA_0<bNR`3McL40hMcC0>CWh@3Sin00hnGO1P3Rhm`00`3Rhm/0h^;K0>;Rf`030>;Rf`D0h^;J0P3R
hMX01@3Rh]X0i^KN0>WXh03Ui=`0f=O@02X0oooo00D0moOg0?O_k`3gmoL0moOg0?O_k`0@0?Ogm`80
DS4Y00<0HcTY05Xa:@1261000P128AP01`1:40P08A0@05Y2>@1B<BT0@RTa03TY8@1B<BT00P0i:B40
1@128AP0LdXi08acH`3_c[D0klJ]0080mmJm00`0klje0?OF_@3ge[d0mmJm0>N]W03NYH`0aXac0=je
W03FYH`0klje0?OFaP3gg/h20?OWgP80mmk>00H0mmK60>o>]@3_c[D0g[FU0>NeW03N[I@40=jUS080
eZF400P0gYb40=jUS03W]I@0ikFL0>nmY@3_c[D0kkf]0?OF_@@0mmk>00@0klje0?Nm]@3_aZd0kkfU
0P3W]I`02`3NYH`0eYb40<j<J`2mQ6/0aXac0;f4J`3>S6/0cYAc0<jDN`2mQ6<0cYAk0080eZF<00L0
]Hac0:EcFP2<FTX0Q59206=:@P1S@S40DSTa0080Hd8a00L0LdXi07]SDP2LJe80W6]B0:f4J`2eQ6/0
_HA[0080cXa[01L0cYAk0=JUQ03>U7/0eYb40<jDN`3FYH@0eZF<0=JLQ03FYH`0aYAk0;F<L`1cBST0
HdY205Y2>@1SBT80DS4Y07=2:@36W8@0gZfD0<I[DP3>HdX0cXAS0?OFaP0K0?Ogm`030?O_k`3gmoL0
oooo01l0oooo000N0?ooo`050=SGd03Yj^40jN[R0>CVgP3RiMd00P3Ri=`00`3Rhm`0h^?K0>;Sf`05
0>;Sf`080>?Tg@3Ti]l0i^SP0>3QfP2l]Zh0WY::0699@@1><RT2040T6@1l040S600o71<0@1/A04XT
6@1?:b00CC4X04D]9`0a8B40:QdN02LK6@0Y71P0<1hG03LS6`1K@3@0Me];0;BEOP3;Zi40gknR0>30
Y03O`:D0g/2V0=blY@3K]j40eJZF0=:UT03?XX`0bYn60<VPQP38XHP0bJ>;0<^XT@3<Zi@0cJjH0<b_
V03:ZiD0ajRB0<2MR@2lUh@0]8Yg0;25L@2ZOFL0ZGaU0:UnI@2[OfH0[X1W0;20IP2cPFH0]H=W0;^:
K@2oT7<0a9Mj0<nURP3CZi00f;BI0=VhWP3M`:P0glB^0>7:]@3RbkH0hLVc0>35[`3M^J<0f[>M0=B[
U03?Z900aj250<>JOP2lSVl0^HYZ0;J7I02fR6<0]HQR0;J8H`2iRVL0^he[0;f@L030U7L0`9=g0;F9
L02YP6T0QFIE07EJC01UC400IT/m06m??P1bD3l0Le51075@@@1ZC3h0JT`m07AC@P1nFTH0UFYA09i`
EP2/Ned0/81Q0;J9J@2hSFd0^Xm`0;b@LP2lSg40^hia0;Z>L`2jTGH0^i=g0;VAM@2aRVh0TFeG07aK
B01J?S40D3HZ04X`901:<2<0E38R05hd901n@B`0TTdg0;MfHP36TX00f/Nl0=oId@3Sin40hnOP0>?U
g`D0h^?L00<0h^?K0>;Rf`3Rh]/0103Rh]/40>;RfP<0h^7J00D0h^;J0>KVgP3Yj>00iNCL0=SGd00Z
0?ooo`80moOg00<0mno_0?Ogm`3gmoL03`3gmoL02P3Nc]H0DS4Y05Xa:@1S@S40HcTa048Y8@1J<BT0
@RTQ04XQ601J<B4204Xa<@0I034Q8@0i:B40>BTQ048Y8@0a8AP0@RTQ07=:>@2ULeX0klJ]0?O>]@3_
c[D0mmJm0>o>]@3ge/H0mmJm0?OFaP3ge[d0kkf]0=jLQ03FYH`0eYb<0<JDN`3FYH`0klje0?OFaP02
0?ONcP030?OFaP3ge[d0klJ]0080g[FU00<0gZfD0=JUQ03FYH`00P3>U7/0302mQ6/0aXaS0;EcFP2e
LeX0eXak0=JUS03N[I@0ikfU0>nm[@3_c[D0mmK60>oFcP80mmK600<0mmJm0>o>]@3_c[D00P3__JD0
203W]I`0gZF<0=JUS03FYH`0cYAk0<j<J`36W7<0_HA[103>U7<0303FYH@0aYac0=JUQ03N[I@0aYAk
0;F<L`2]Q6/0YG=J08ASDP2<He80W6]B07=JDP80YG=J00<0[HA[0;EcFP2mQ6/00P36W7<50<jDN`0@
0=JUQ03FW8@0eYb40<JLQ03FYH@0aYb40<JDN`2ULeX0HdY2058i<@12<CT0DS4Y048Y8@1J<B40eZF4
0=JLQ080_EY200<0eYac0?OWi`3gmoL0703gmoLP0?ooo`007P3oool01@3Hf=00jN[R0>WZhP3Ti]h0
h^GM0080h^CL00<0h^?L0>;Sf`3Rhm/01@3Rhm/02@3Si=d0i>KO0>GXh03PhMX0^kB]09b?Q`1OASh0
C30V040T6002044U6@1G03lO5@0o7A@0@b8I04HW7@12:R80>RLQ02TL6`0T6AT09aXG02/L5`0c7aP0
>b@K05a0=@1hFT/0]IAm0<^ZT03P_Z40hL2S0=noY03N_j@0g;bT0=^iX`3H/I`0eZfH0=>YT`3<XhX0
b:260<>JP@31VH00`IZ20<:LQ@33X8T0`Z690;jNQP2kVX<0/Y1l0:j:M`2UOF/0X7MU09]_F`2JKUT0
Vg5I09ebFP2RME`0Y7EL0:QfG02[Med0/GmS0;N6JP2mSg<0bj>70=2ZS`3G]Y/0fKZO0=g1Z@3Oa:d0
hLRc0>;9]03Qak00h<>/0=fhX@3J/i`0dj^C0<nXS`37X8H0`iYo0;^=L02iRF/0]XET0;J5HP2eQV40
]HMR0;R<I`2jSV/0_I5_0<6EMP32UGL0^hmd0;>8L02KMf<0T6mM08=TD`22HU00Q61<08AOB`21FdP0
OUQ60080NEE30280Pee908aTCP2PLUT0Z7QL0;>1H@2fQF@0^8][0;R>K`2hSg40^i5c0;b@LP2mT7<0
_I5d0;bCM`2mU7P0]i5e0:j9KP2<Je@0MeQ505Dj;@1;<RL0ARdR04L^8@1C<B80GC@S07do:P2@BS@0
]79N0<B?O@3Ia[/0gmW@0>CWh@3Sin40hnGO1@3Rhm`00`3Rhm/0h^;K0>;Rf`040>;Rf`@0h^;J0`3R
hMX01@3Rh]X0i^KN0>WXh03Ui=`0f=O@02X0oooo0`3gmoL0103gknl0moOg0?Ogm`3gknl=0?Ogm`08
0:fDY@1J<BT0FS4Y05Xa:@1S@S40@RTQ06=2<@1J<BT2058a:@0;048Y8@1B>C40:APH034Q600a8B40
DS4Y034Q6012:B40LdY208ASDP3_aZd00P3_c[D00`3gc[D0mmJm0?OF_@020?OF_@0:0?OFaP3ge[d0
kkf]0=jeW03FW8`0[HAk0;f4J`36U7/0[HAk0:f<Q080]Hac00@0[G][08acH`2LLf<0Q6=B0P2<FTX2
09ASBP0308aJ@P2UHdX0YF]B0080[F]B00D0]G=J0<jDN`3FYH`0ijfL0>NmY@020>o>]@80mmK60140
mmJm0>o>]@3_c[D0klJ]0>nmY@3_aZd0ikFL0=jeW03FYH`0eYb<0<jDN`3>U7<0cXa[0;f4J`3>S6/0
aYac0<jDN`020=JUQ0060<jDL`3NW8@0eZF40=JUQ03FYH`0eZF40P36U7/01`2]Q6/0]G]S0;EkH`2]
Q6/0[G=J0;EkH`36S7<00`3>U7/20=JLQ0070<JLQ03FW8@0eYb40=JUQ036W8@0eYb40=JUS0020<JL
Q00:0:f4J`24He80Hd8a058a:@1SBT80DS4Y048Q601:8AP0eYb40;f4J`80_EY200<0gZF<0?O_k`3g
moL0703gmoLP0?ooo`007P3oool01@3Hf=00jN[R0>WZh@3TiMd0h^CL0080h^?L203Rhm/0QP3Si=d0
i>KO0>GWh03PhMT0_;F]09j@R01RBCl0Cc<X040T5`109QP0@BLJ03lU6P0n91X0?2@L03/U7@0d8ad0
;R0K02<H5@0R5a@0:A/F02hM600g8QX0?bLO05m3=`1jFd`0]99j0<ZWS@3P^ih0h[jQ0>2nX@3N_Z80
gKjT0=foYP3N_jT0gKfW0=ZjY03B[iL0c:R?0<6IO`2lTWP0]h]a0;J:L@2dRW80/HUb0:V5K`2UPVd0
WW]W09YgI02DK5/0T6MF08]PC@2:Gd/0S65:08iSB`2CID`0UFI=09]WCP2NJDl0Yg9I0:ilHP2gR6h0
b::70<n/T@3G^Il0f[fS0=k2Z`3Pa:h0h/F`0>;4/03Q`JX0h;jV0=ffW@3J/YT0djbB0<nYS`37X8H0
`YV00;Z:LP2gPfX0/GYN0:mhFP2[N5L0Zg]H0:j4G`2aR6@0]XeY0;jELP31UgH0`YMi0<2FN@2kTWL0
^I1f0;>;L@2aQfh0Zh1W0:MkHP2OLUT0VfiE09MZDP2GJe<0Wg9I0:EgGP2bPfH0]hMX0;^;J@2kS6X0
^He^0;R>L@2gSW<0^I1e0;^BM02nU7D0_iAf0;nEN02nUGP0/heb0:N4JP21I4l0Je4o04Pc9P0n:b00
?BPN04</8@1I=bP0Ic`[08=4;`2BC3H0/FmK0<2<N`3Ia[/0h=[B0>GYhP3Tj>40hnKO103Rhm`00`3R
hm/0h^;K0>;Rf`050>;Rf`@0h^;J0`3RhMX01@3Rh]X0i^KN0>WXh03Ui=`0f=O@02X0oooo503gmoL0
502eYJD0DS4Y048Y8@128AP0@RTQ034Q601B<BT0>BTQ048Y8@1B<BT0>BTQ048Y8@0i:B40<B4H02TH
600a8B40DS4Y048Y8@1S>BT0S6=B0P3_aZd01@3gc[D0mmJm0>o>]@3gc[D0klje00<0mmJm00T0mmK6
0>o>]@3_c[D0g[FL0=JLS02DLf/0[G][0<JDN`2]S8@00P2]Nf/0102LLf<0W6]B08aSDP2<He8209AJ
DP0<09AJBP2<FTX0U5YB09AJBP2eNf<0_HA[0;F<L`3FW8@0gZfD0>NmY@3g_KD0klje0`3ge/H03P3_
c[D0mkfe0>o6[@3_aZd0kkfU0>o6[@3W_JD0g[FL0=j]U03FW8@0cYAk0<J<L`2mQ6<0]G]S0P2mQ6<0
1036S7<0cYAc0<jDN`3N[I@20=JUS0040=JUQ03>U7/0cYAk0<jDL`80aYac00<0cXa[0<J<L`3>U7<0
0P3>U7/00`36W8@0eYac0<JLQ0020=JUQ0030<JLQ03FW8@0eZF40080aYb401<0eZF<0=JUQ036W8@0
eYb40=JUQ02LJe80LdY204Xa<@1B>C40HdY20592>@128AP0@QP@0<jDN`2mQ6/0[EY20;eJ@P3N[I@0
mno_0100moOg00<0mno_0?Ogm`3gknl02P3gmoLP0?ooo`007P3oool01@3Hf=00jN[Q0>WYh@3TiMd0
h^CL00X0h^?K08H0hnCM0>CVgP3Uin00h>7I0;be[@2OTXT0I4]0050c:00o8aH0?B<F03dT600k91X0
>B@J03LT700f91`0<24K02`N6@0T6A@08aPD02TK5P0]7QL0=b<L03lY8@1PACT0NUe=0;:@N@39YHX0
gkVM0>:mX03Q_Z40gkjR0=k0Y@3O`JP0h<:/0=o1[03M_jT0e[FN0=6^UP36X8H0`IUn0;Z>M@2hRg80
/hI_0:j4KP2SOf/0WgeY09]hIP2KMF<0UfiL09AYE`2?HTl0SV9<08mSC02@ID`0TfI=09IVC@2KJ4h0
WfYA0:YfG02bP6H0^Xab0<ZVR`3@/9D0fKbR0=^oYP3O`jd0h<B_0>;3/03R`Zh0hKfX0>2jY03M]I`0
f[:I0=>]TP3?ZXl0aj270<>IP@2jR7<0]H1Z0:acFP2XKe@0XVe?0:9`C`2VNUL0Zh5M0;27H`2kTfl0
_iIc0<:IN@33VGX0`iQk0<:HNP30U7P0_I5f0;N:K`2dQV/0ZgeR0:MiGP2SME/0XgIL0:UkH@2^P6D0
^8U[0;^<K@2lSVd0^hi]0;V>L@2iSW<0^8ie0;V@M@2jTGD0_IAe0;jDMP2oUGL0_IAf0;2:K`2SP6H0
NUm;06=<>`0o;R80=RLL03TV7@13;B80HCh_0755<`2;C3D0UU0j0:m_F`2nRgX0f<Jl0>3KdP3UjN80
i>SQ0>?Ug`@0h^?L00<0h^?K0>;Rf`3Rh]/0103Rh]/50>;RfP<0h^7J00D0h^;J0>KVgP3Yj>00iNCL
0=SGd00Z0?ooo`P0moOg00<0mno_0?Ogm`3gmoL01@3gmoL01`3gknl0moOg0?Ogm`3gmoL0]JF]05Xa
:@1B<BT00P12:B400`128AP0BR4H048Y8@02048Y8@0403TY8@0a8AP0>BTQ034Q8@80<B4H0P1B<BT0
1P1S@S40Q5920>NmY@3_aZd0mlje0>o>]@@0mmJm00P0mmK60?OF_@3ge/H0mmk>0?OF_@3_c[D0kkf]
0;f4J`<0[G][00D0_HA[0:f4N`36U7/0U7]c09acH`030:EcFP070:E[DP2DFTX0YF]B0:E[DP2eLeX0
_HA[0<jDN`020>N]W0030>nm[@3_aZd0klje0080mmK600D0mmJm0?O>]@3ge[d0klJ]0>nmY@020>o6
[@0?0>nm[@3W[I`0gZfD0<JLQ036S7<0]Hac0:ecFP2UHdX0[F]B0;EcFP3>S6/0aYac0<jDL`3FYH@0
eZF<00<0gZF<00@0eZF<0=JUQ03>U7/0cYAk0P3FYH@02@36W8@0eYb40<jDN`36W8@0eYb40=JUQ036
W8@0eYb<0=JUQ0020<JLQ00D0=JLQ036W8@0eZF<0<JLQ03FW8@0eZF<0<JDN`2<Lf<0HdY2058a:@12
:B40HdY204Xa<@128AP0@RTQ0<j<J`3FLf<0cV=:0;EB>@3NYH`N0?Ogmb00oooo000N0?ooo`050=SH
d03YjN40jNWQ0>CUg@3Rhm/00P3Rh]/80>;Sf`0=0>?Tg@3Ti]h0iNOP0>3Qf@2n]jh0XYF:06Q>@@1A
=2L0>QhA03DK400b7140;ahE02hO5`0202dP601G02/N5`0Z7AH09aXD02HJ4`0W6a@0:AdF03<U7P0m
;BD0H4Xn07UOD02]SGD0`Yn50=ZeV03O^I`0hKjQ0>70X`3P`ZL0hL>Y0>74[P3Qa:l0h<>^0=foZP3K
_:H0e;FL0=6`UP3:XhX0aYb40;^?NP2cRWL0YX=c0:>2L`2WPg<0ZhAc0:j1KP2/OVX0YgUS0:EiH@2U
NV40YG]R0:AiH02UN5h0ZWUP0:mmI02kRg40`YAi0<RNP`3B/IH0e[RN0=c1Z@3N`j`0h<F`0>75/03Q
`Jh0hKj[0>6gY@3P]J80g;BM0=ZcVP3C/9@0d:bA0<RQR@34VX@0^hQg0;EoK@2TK5P0WFA>099K@P2@
Fd40U6=709U/C@2OME@0[8IR0;6;J02hT6l0^Y5a0;nDM@31UGH0a9Mh0<FGN@35UGP0`i=f0;f?L02j
SFh0]8U/0;:9K02dRfh0]he`0080_95b01h0^I1b0;R>LP2hSG@0^Hae0;V<MP2hSGH0^8ie0;ZAM@2l
TgD0_I9c0;Z@L@2WPFH0UgEL06YC@01C@C80<2DL02PP600c9Qd0A38V079>?026FD<0Ve]209mJ@@2Y
K5P0]8Ac0<fl/@3Gd<P0h>;L0>7Sg@3Qhm`30>;Sg0030>;Sf`3Rh]/0h^;K00D0h^;K1@3Rh]X30>;Q
fP050>;RfP3Vi]h0jNSP0>GTg03Hem00:P3ooolC0?Ogm`030?O_k`3F_LH0FS4Y00@0@RTQ00L0BR4H
034Q6012:B40DS4Y048Y8@0Q4100@RTQ00<0<B4H00P0DS4Y06=:@P1cBT80Le9:0=j]U03__Jd0klje
0?O>]@D0mmJm1P3ge/H0403g_KD0c[Fe0>N]W03N]I`0ijfL0=jeW03>]KD0kkf]0>N]W03N]JD0eZF<
0>N]W03N]I`0g[FU0=jeW03W[I`20>nm[@050>o>]@3__Jd0mmJm0?OF_@3_c[D00P3ge/H03P3ge[d0
klje0>o>]@3ge[d0mlJ]0>nmY@3_aZd0klje0>nmY@3W_JD0g[FL0=j]U03>U7/0_HA[0P2DFTX01@2<
FT80Q58i09ASBP2]LeX0]G]S0080cYAc00D0eZF40=JUS03FYH`0gZfD0=jUS0020=JUS0030=jUS03F
YH@0eZF<00<0eZF<00<0eYb40=JUQ03FYH`00`3FYH`04P3FYH@0eYb<0<jDN`36W8@0eYb<0<JLQ03F
YH@0aYAk07=:>@1B>C40<B4Q058a:@12:C40>BTQ058a:@2<FTX0aXaS0;f4H`80]E8i00<0cXa[09Ak
L`3gmoL0703gmoLP0?ooo`007P3oool01@3Hf=00jNWQ0>WYh@3Ti=`0h^;K00<0h^;J00<0h^;K0>;S
f`3Rhm/0103Rhm/0=03Si=d0i>KN0>GWh03PhMT0_kR_0:BFR`1ZD480DcDW03TL400c60h0;aP?02/K
4`0Z7A@0:AhF02XN5P0Y71D0:1/D02HI4`0U6A809AXD02LL5P0b9Qh0?2hV05m;?`1hGe00ZXYc0;jK
PP3G/ID0g;NJ0>6nX@3Q`:<0hL>X0>74ZP3Qa:h0hLB_0>74/03P`jh0g/:/0=^nYP3H^j80dZnF0<fW
T032VHD0^i>20:j>OP2/SGh0/Xn00;NAP02lT7`0^hii0;J:L`2dRW820;>;LP1@0;68L02aQfh0]HQ_
0;Z<LP35V7h0bZ250<nXS03F]Y/0fKbR0=k3[03Oa:l0h<Fa0>35/03P`:`0h;bY0>2fY03O]:40g;BM
0=ZdV`3D/ID0d:fB0<ZSRP36W8H0_Xaj0;N3LP2VKe`0WFIA08mI@P2<ESl0S5Y108mQAP2DJD`0WWYH
0:9nG@2YQ6@0[8IV0;F;K02iSVl0`I=e0<BEN037UgX0aYMi0<:EMP2oU7@0^Y1b0;R?LP2hT7<0^Y5c
0;bBL`2kTW<0^8mc0;N=L`2fRg<0]hYd0;R:M@2gRgD0]hee0;V@M@2lTWD0^i1b0;N<KP2PNUl0SfeE
069;>P1<>Rd0:b<J02DO5`0c:1l0ASDY07QD@@2=GTP0X5m60:5L@`2SJ5<0ZW]Z0<2]XP3:`[T0f=WC
0=cNf03OhMX30>;Sg0030>;Sf`3Rh]/0h^;K00@0h^;K1P3Rh]X30>;QfP050>;RfP3Vi]h0jNSP0>GT
g03Hem00:P3oool80?Ogm`030?O_k`3gmoL0moOg00T0moOg00<0e/kN06<i<@1J<B400P12:B40101:
8AP0@RTQ048Y8@1B<BT2048Y8@0302TH6012:B40<B4H0080<B4Q00L0>BTQ048Y8@24He80S6=B0=JU
S03N]I`0klJ]0080klje0`3ge[d70?OFaP@0klje00D0mmK60=K6aP3Fa/H0mmK60=K6_@020?Nm]@0;
0=K6_@3g_KD0mmJm0?OF_@3g_KD0mmK60>o>]@3g_KD0klje0?OF_@3_c[D00`3ge/H01P3ge[d0klje
0>o>]@3ge[d0klJ]0>nm[@80klJ]0P3W_JD01`3W[I`0g[FL0=JLS03>U7/0W6]B09ASBP24DST00P24
BST01@2DHdX0YG=J0;f4J`36S7<0eZF40080eZF<0P3N[I@01`3NYH`0eZF<0=JUS03FW8`0eZF40=JU
S03FW8@01P3FYH`02`36W8@0eZF<0=JUQ036W8@0eYb<0=JUQ036W8@0eZF40;F<L`1SBT80DS4Y00<0
>BTQ00D0<B4Q058i<@2LJe80]G]S0<icFP020:eJ@P030;f4J`1cDTX0moOg00l0moOg00<0mno_0?Og
m`3gmoL02@3gmoL00`3gknl0oooo0?ooo`0N0?ooo`007P3oool02@3Hf=00jN[R0>WYh@3Thm/0h^7I
0>;Oe`3RgmP0h^7I0>;RfP040>;Sf`80hN?K03@0hnCL0>CUgP3Uin00h>7I0<6j/02WVXh0KeA605Pj
:`0k7100=1L=02lF3@0Z6A40:A/C02PM5@0W7AD091XC024G4@0M4`l07A<>024G4@0U6a@0<bLO03d`
9`1NBcl0M5e=0::3K02fTgX0d:^>0=NbU@3O_9l0h;nS0>;3Z03Ra:X0h/B^0>;5/03Ra[40h/Rd0>;9
]03Qb;80h<N`0=c0ZP3I_:H0d[:O0<j_W@37[9/0aZbK0<Z^W03>[id0dZnK0=6_VP3?[IL0cZfF0P3=
[IH0=@3;ZiD0bjZD0<fZT`3?[9<0eK6F0=NdV03H]i/0f[fQ0=c0YP3OaJl0h<Na0>36/03Oa:h0gKnX
0=flY@3M^:80g;NP0=^eW@3I]I/0eK6F0=:_U03>Z8l0c:B=0<JJQ@32U7l0]8A^0:akI@2IIU80T5e:
08AC@@20Dd00OeE007iL@`1mGT@0P65708ETB`2GL5D0XWML0;F6JP2kS700`iEh0<BGN@33V7P0`IMf
0;jEM@2mU7D0^Y=e0;VBM02gT7<0]hmb0;J;L@2dRG00/HI^0080/8E^01T0/hQb0;J:M02mSgL0_i1g
0;V;K`2`PfL0T6UA07aJA@1C?2d0@C0T02/R6P0X8AX0>2hT04/j;@1jE400SEa509iL@P2MF3h0U5M2
095PCP2GP7@0XYF<0<6o^03@d<T0fmcE0080i>GN00<0h^?L0>;Sf`3Rh]/01@3Rh]/50>;RfP<0h^7J
00H0h^7I0>;RfP3Vi]h0jNSP0>GTg03Hem0Z0?ooo`@0moOg0P3gknl00`3gmoL0mno_0?Ogm`0;0?Og
m`0@0>ONk`1cBST0FT8i03TY8@1:8AP0@RTQ034Q6012:B40>BTQ048Y8@1B<BT0<B4H024@4012:B40
:APH048Y8@80DS4Y00@0LdY207]SDP36W8@0gZfD0P3_aZd20?O>]@80mmJm0P3ge/H?0?ONcP030?OW
gP3gg/h0mmk>00<0mmk>0`3ge/H01`3ge[d0mmK60?OFaP3ge/H0mmk>0>o>]@3ge[d00P3_c[D00`3g
aZd0kkfU0>o6[@030>o6[@0:0>NmY@3_]JD0ikfU0>NmY@3__Jd0eZF<0<jDN`2]LeX0U5YB08aJBP80
LdXi00L0HcTY06=2<@1cBST0Q5920;EkH`36W7<0eZF400@0eZF<103FYH@04036W8@0cYAk0<JLQ02e
S7<0aXac0;F<L`36U7/0cYAk0=JLS03FYH@0aYb40=JLQ03>U7/0YG=J058a:@0i:B42048Y8@0;058a
:@1B@ST0FS4Y07=:>@3>S6/0_HA[0:EB>@2]FT80U5Y:058a:@3Nc]H0703gmoLP0?ooo`007P3oool0
2@3Hf=00jN[R0>WYh@3Thm/0h^3I0>;Ne`3RgmL0h^7I0>;RfP040>;Sf`80hN?K02`0h^CL0>CUgP3U
iml0h>7I0<:k/@2XVhl0L5M805Tl;P0m7Q80=AT>034G3P0/6A40:Q/C02PM5@0W7AD08QTB01hF400I
40d06A0<020E400U6Q@0=2LO03h`9`1MBSh0LU];09moJ@2bSgH0cJN;0=F`T`3N^ih0h;nR0>73Z03R
a:X0h/B^0>;5/03Ra[80h/Ve0>;:]@3QbkD0hLZd0=o6/@3Ma:l0fKj[0=NmZP80dk^Y00`0eKbZ0=Nl
ZP3I_JT0fKbX0=RlYP3G^jH0ekbV0=JkYP3E^jD0eKZU0=JiXP3H^J420=^kX01:0=^lX03K_Z<0g<6W
0=o6[`3Pak40glJ_0=k4[03L_ZH0fkbS0=^iX@3K^:00f[JL0=VeVP3F/IH0e:nD0=2[T@3?ZI00bj>;
0<RNQ`2nTWX0]XUa0:=cG`2HIeH0QUM8081C@`1kDT40M58n075B?01`DSd0M5Do08QRB`2EJe80ZWaR
0;63J@2jSG80_91d0;bBL`2lTW80^Y9a0;VAL@2fT780]Hma0;:<L02bRVl0/XI/0;:5J`2^PfX0[H9Z
0:b3J`2bQg40]hUd0;n>N031SgL0^8Q^0:anI027HD/0LU0m04`e9`0m:b00;B8J02`S700k<2H0C3X^
07E??027ECl0UeDl09IB>@2:CCP0Q54o08=ZGP2>OgD0][>[0<[9`P3If]<20>GVg`030>;Sg03Rhm/0
h^;K00D0h^;K1@3Rh]X30>;QfP060>;Qf@3Rh]X0i^KN0>WXh03Ui=`0f=O@:P3ooolC0?Ogm`040?O_
k`3_inL0Hd8a07=:>@80@RTQ00@0@R4H034Q600a8AP0>BTQ0`12:B403P0Q4100<B4H048Y8@0i:B40
DS4Y058i<@1cBT80Le9:0<JDQ036W8@0ikfU0>o>]@3ge[d0klje0P3ge[d20?OFaPT0mmk>00@0mnON
0?ONcP3gimh0mmk>0P3gimh00`3gg/h0mnON0?OWgP040?ONcPD0mmK600<0mmJm0?OFaP3ge/H00P3g
e[d01@3gc[D0klje0>o6[@3__JD0klJ]0080kkfU103W_JD02@3__Jd0g[FU0=jeY@3>S8@0aYAk09a[
DP2<FTX0Q58i07=:>@0206<i<@80Hd8a00H0Q58i0;F<L`36U7/0eZF<0=JUQ036U7/30=JUQ080cYAk
0140aXac0<JDN`2eNf<0W7=S0:ecFP2eS7<0aYAk0=JLQ036W8@0eYb40<JLQ036U7/0S5Y:048Y8@1B
<BT0>BTQ048Y8@02058i<@0:048Q601c@RT0_HAS0;f4H`2]Je80]G]S08AB>@1[DTX0]JFU0=kFia/0
moOg803oool001h0oooo00D0f=S@0>WZhP3YjN40i>?K0>;Pf@020>;Oe`040>;Qf@3Rh]X0h^;K0>;R
f`@0hN;K02X0h^CL0>CUgP3Ui]l0h>7I0<6k/P2WW940KeY=05U0<`0o91T0>1lE03@M4`0_71@0;Q`D
02/M5@0Y7AD08QTB01dF400G40/05`l;020E3`0V6Q<0=BLO03l_9`1LB3`0L5M809]jI02_RW40bZ>7
0=>]T03M^Yd0gkjQ0>73Y`3Q`jX0hLB^0>75/03Qa[80hLZe0>7;]P3Qc;L0hLbh0>7=^@3QcKX60>7>
_01F0>7=^P3QcKT0hLbh0>7<^@3QcKX0hLfk0>7=^P3QcKT0hL^e0>7:/`3Pajh0h<F[0=o3Z03N`ZH0
g/:W0=o5[03Pajh0glF/0=k3ZP3L_j@0fkfR0=ZjW`3J^Id0fKFJ0=VcV03G/IH0e[2F0=F`U@3D/9D0
e:nD0=>]TP3>YH`0bIn70;R<N@2^PW40VViP099WF@2;HE<0OEQ807EC@`1ZC3/0JT/j07AA?P1lET80
RF5<08iWD@2FL5T0VWAL0:5iG`2SNf00Y7iS0:>0I02ROf@0XGiT0:1kH@2QNF00Y7MN0:EhGP2XO6<0
ZWmW0:f2JP2fR780^hYd0<>>M`33SGH0]H9Z0:AeGP1gDT00HD4b040Z7`0g91/0;b8K030T7P0l;RL0
Ac<Z064l;P1^?bh0OCl[07ln:@1g>bP0Kc`[06a@A01hIUd0ZJBM0<?1^P3Fe/l20>GWh0030>?Sg03R
hm/0h^;K00@0h^;K1@3Rh]X40>;QfP060>;Qf@3Rh]X0i^KN0>WXh03Ui=`0f=O@:P3ooolE0?Ogm`09
06=2<@1cBST0DS4Y058i<@1B<BT0>BTQ04XQ6012:B40<B4H0080@RTQ0P0Q41004@0i:B40DS4Y04Xa
<@1B<BT0Nf=B08ASDP36U7/0_Ib<0=jeY@3_aZd0klje0?OF_@3gc[D0mmJm0?OFaP3ge[d0mmK600L0
mmk>00<0mnON0?ONcP3gimh00P3gimh00`3gg/h0mnON0?OWgP020?OWgP80mmk>00<0mnON0?ONcP3g
g/h0103ge/H00`3gg/h0mmJm0>o>]@030>o>]@030?O6[@3_aZd0mlJ]0080klJ]00D0ikfU0>o6[@3_
_JD0kkf]0>NmY@020>nm[@0:0>NmY@3N]JD0gZfD0=JLS036U7/0[G][0:EcFP2LJe80Q59207=:>@80
HcTa0P1cBST209a[DP050:ecFP2]Q6/0_HA[0;EkH`2ULeX0102LJe801P2LLf<0aYAk0=JLS03FYH`0
aYb40=JLQ080aYb400H0]Hac06]BBP1B<BT0<B4H058a:@0a8AP204Xa<@0:048Y8@1J<B40W5Y20:EB
>@2LFT80U58i05Y2>@1[DTX0[IbU0>ONia/0moOg803oool001h0oooo00D0f=S@0>WYh@3YjN40i>?K
0>;Qf@020>;Pf0040>;Qf@3Rh]X0h^;K0>;Rf`@0hN;K0380h^CL0>CUgP3Ui]l0h>7I0<2k/`2VW980
KU]?05Q2=P10:1d0>R<I03HP5`0a7QH0;ahE02/M5@0Z7AD091TB01lG400I4P`06A4<024F400W6Q<0
=RLO03l_9`1LAc/0L5I709]hHP2^R6l0bJ:60=:[S`3L^I`0gkjQ0>72Y`3Q`jT0hLB^0>75/03Qa[80
hLVe0>7;]P3Qc;L0hLbh0>;>^P3Rck`0h]700>;B`@3Sd/80hm?20>?B`@3Rd/40h]6o0>;@_@80h/nl
00T0h]6o0>;A`03SdKl0hm2m0>?>^@3Rc;L0hLVb0>78[`3PaZ`00P3O`jP0303PaJ/0h<J/0>35Z`3O
a:T0gL2T0=bnXP3J^Yh0fKNL0=VcV03I/YL0f;6F0=NaUP<0e[:G03P0e[2F0=>[TP3?YXl0`YN40;V?
OP2YOg00XWQY09abHP2=IEH0QEm?07EDA01`DD00LDlm07A@?@1iED40O5Q4089OBP26Hdd0T6YC09=]
E@2ELUT0U7AK09AeG02EM5/0Ug9H09Q`E`2KKeH0WW5H0:IiH@2[OVL0/8=/0;V9L`2mRgD0`hif0<:=
M02bP6P0X79L075>?@1J?2h0?2HL03@Q6@0_8A/0<2@N03X[9@11;RL0E34V05hb901]<b40LC<P06dc
8P1X=RH0JDa107ITFP2XXi/0`/2i0=KFc`80iNOP00<0hn?L0>;Sf`3Rh]/0103Rh]/50>;RfP@0h^7J
00H0h^7I0>;RfP3Vi]h0jNSP0>GTg03Hem0Z0?ooo`<0moOg00<0mno_0?Ogm`3gmoL03`3gmoL0201S
BT80Hd8a06=2<@1B>C40@RTQ034Q6012:B40>BTQ0`12:B403@0a8AP08A0@03TY8@12:B40Hd8a06=:
@P1cBST0Q6=B0<JDN`36U8@0g[FU0>o6[@3gc[D00`3ge[d30?OFaPL0mmk>1P3gimh02P3gg/h0mnON
0?ONcP3gimh0mmk>0?OWgP3gg/h0mnON0?ONcP3ge[d20?OFaP050?ONcP3ge/H0mmJm0?OFaP3_c[D0
0P3ge[d01`3_c[D0klJ]0>o6[@3__JD0klJ]0>nmY@3_aZd01@3__Jd0303W_JD0ikFL0=jeY@3N[I@0
eZF<0=JLS02]Q6/0[G][0:EcFP2<FTX0LdXi07=2<@80Hd8a0P24DT803`2<FTX0W6]B08A[FP2LJe80
S6=B09a[DP2ULeX0U5YB0:ecFP2eQ6/0eYb<0<JLQ03FYH`0eYb40=JLS0020<jDN`0A0;F<L`1cBST0
<B4H034Q6012:B40<B4Q03TY8@1:<C40@R4H058Q601c@RT0S34Y07/a8@1c@S40Hd8a06]BBP2eYJD0
703gmoLP0?ooo`007P3oool01@3Hem00jNWQ0>WXh03Ti=`0h^;J0080h^7J0`3Rh]X00`3Qh]X0hN;K
0>7Rf`020>7Rf`0A0>;Sg03TiMh0iNKO0>3Qf@30^k<0YIfD06eMD`1HAS`0A30W040/8`0l:B40<b<K
02lP600[7AD0:Q`D02LK4`0U6A800P0P5a006P0U6Q<0:QdG03HX8@0o<2P0FdHj06iEA@2HM5h0ZhAZ
0<JNPP3?Z8`0f[NK0=flX03Q`ZH0hL>Y0>;4[@3QaJh0hLJ`0>78/`3QbKD0hL^f0>7;]`3Qc[X0hLnm
0>;B`P3Rdl<0h]C50P3ReLH0403Re<H0h]?30>;A`03Rd;h0h]2o0>;B`P3Rdl<0h]700>;@_P3RcKT0
h/fh0>7;]P3Qb[@0hLVa0>76[03QaJ/30>75Z@060>34Z03O`JD0gKjR0=ZhW03I]IX0fK6F0P3I/9D0
?03I/IH0fK>G0=VdV03I]9T0fK>I0=R_V03F[IL0d:NC0<bTT@33W8T0`9N40;bBO`2`QG80Z7i[09A_
G02:IeD0NeY807IE@P1]CS/0JT`i06]=>P1_Cc`0NEE107eHA01oGTX0Of5<089UC`26ITl0SVM>091W
C@2CJE00UfaD0:IhHP2_OVX0]XAa0;j;MP2oS7H0_hec0;f;L@2[O6@0V6eH06Q7>@1B=RX0=R8J030O
5`0^7aT0;R4L038S7`0d8ah0>QlH03lN5@1>81<0E28E05/Z7@1L<B@0J4i407UWGP2[YYh0a<:k0=OG
d080iNOP00<0hn?L0>;Rf`3Rh]/00`3Rh]/60>;RfP@0h^7J00H0h^7I0>;RfP3Vi]h0jNSP0>GTg03H
em0Z0?oooaD0moOg00D0LdXi06=2<@1cBT80Hd8a058a:@02048Y8@80DS4Y0P12:B400`0i:B40:APH
02TH6002058a:@0?06=2<@1cBT80Nf=B0;F<L`2]S8@0g[FL0>NeW03gc[D0klje0?O>]@3ge/H0mmJm
0?OFaP3gg/h0mmK60080mmk>00D0mmK60?ONcP3gimh0mnON0?ONcP0:0?OWgPD0mmk>103ge/H00`3_
c[D0mmJm0?OF_@030>o>]@060>o6[@3gaZd0klJ]0>o6[@3__JD0klJ]0P3__Jd20>o6[@@0ikfU0`3N
]I`0103FYH`0eYb<0<JDN`2mQ6/209acH`0708AB@P1cBST0LdXi07=:>@1cBT80Q58i08AB@P0208aJ
BP0509AJDP2]LeX0[G=J0<jDN`36W8@00P3FW8`20<JLQ00;0=JLQ036W8@0aXac0:f4J`1S@S40>BTQ
048Y8@0i:B40@RTa058a:@0i:B400P0a8AP01`126100HaP@06<i:@1J<BT0HdY206]BBP3oool0703g
moLP0?ooo`007P3oool01@3Hem00jNWP0>WXh03Ti=`0h^;K00@0h^;J0`3Qh]X30>7Rf`0b0>;Sg03T
iMd0iNKO0>3Qf@30_;@0YIfE06iNE@1KB3l0BC@[04Da:010;RD0=BDM02lQ6@0Z7AD0:Q`D02TK4`0W
6a8091TA02@I4P0X71H0;1lI03LY8`10<2T0FTHj06eCA02ELU`0Yh5X0<:KO`3<YHT0f;JI0=bkW`3Q
`ZH0hL>X0>;4[03QaJd0hLF_0>77/P3Qb;<0hLZe0>7;]P3QcKX0hLjl0>7A`03Qd/80hMC50>;DaP3Q
eLL0hMC60>7C``3Qd/820>7A`080hM?300/0hM700>7?_@3QcKT0hLbh0>7;]`3QbkD0hLZc0>78[`3Q
ajd0hLFZ0>75Z@020>74Z0050=o1Y@3N_Z80fkRL0=ZeV@3I/IH00`3I/9D0?P3I/YL0fK>G0=VdV@3I
/iT0fK2J0=R^V@3DZiL0dJVE0<^TS`38XH`0aIb70;bAO02dRWD0XW]W09UdH028IU80PEm<07EF@`1a
Dd00Ke4m075A?@1hE400NeI207aJA`1mGDT0PV9<08MTC@2AJ4l0TfU@09M]E02JL5P0Z7YU0;1oK02g
Q780_HYf0;f;M@2lS780^HY`0:MkHP2DK5H0IDHg04le:@0e8AT0;ahG02dN600]81X0;R0L02hO6P0`
6a@0=1TA044K40187Q<0DbPL05La9@1WCdD0NFUP0:bWW`35`k`0emS@0>KWh03Uin00h^?L1@3Rh]/6
0>;RfP<0h^7J0P3RhMT01@3Rh]X0i^KN0>WXh03Ui=`0f=O@02X0oooo503gmoL0203_inL0Le9:07=:
>@1cBST0Je9:05Xa8@1B>C40>BTQ0`12:B40101B<BT0DSTa05Y2>@0i:B42058a:@0;058i<@1cBT80
Q6=B0;F<L`36W8@0eZF<0>NmY@3_aZd0mlje0>o>]@3ge[d00`3ge/H01`3gg/h0mmK60?ONcP3ge/H0
mmk>0?OWgP3gg/h01`3gimh0103gg/h0mnON0?OWgP3gimh50?ONcP0:0?OFaP3ge[d0mmJm0?OF_@3g
e/H0mkfe0?OF_@3_c[D0mmJm0>o>]@L0klJ]0`3__Jd02`3W_JD0kkf]0>N]W03W_JD0ikFL0>N]W03N
]I`0gZfD0=JLS036W8@0aYB40080aYAk00@0]HA[0;EkH`2LJe80U6=:0P24DT804@24BST0U5Y:0:E[
DP2]LeX0_HA[0<jDN`3FW8@0aYb40=JLQ036W8@0eYb<0=JLQ03>U7/0aYAk0<J<L`2<He80DS4Y0080
@RTQ00D0DS4Y048Y<@1:<C40<B4Q048Y8@02034Q6080@RTQ00@0DSTa06=2<@1cFU80imkW703gmoLP
0?ooo`007P3oool0103Hem00jNWP0>WXh03Ti=`50>;RfP@0hN;J0P3Qh]/0;P3Rhm`0i>GM0>GVg`3P
h=T0`Kbd0:NNU@1dHEP0HTa3058k<@1?>2l0BCD[03PZ8@0`91/0:AdE02TL500[71@0:a`C02XL500[
71D0;QlJ034R7P0j:bH0@S4[05Q4>01XD440S6aE09ejH@2hTgL0`ij20=>`U03I^9/0h<6T0>73Y`3R
a:T0hLBZ0>74Z`3QaJl0hLJa0>78]03Qb[D0hLbh0>7=^@3Qc[`0hM2n0>7B``3Qdl@20>7DaP0;0>7C
a@3Qdl@0hM?40>7Ca03QdlD0hM?40>7@`03Qckd0hLbh0>7<]`3QbkL00P3QbkH02P3QbK<0hLRa0>76
[03QaJX0hLBX0>73Y`3O`:@0g[fQ0=^gV`3J]IT20=VbU`0m0=VaUP3I/9D0fK2E0=VaUP3I/iP0fK>I
0=V`V@3I[iT0ejfG0=F/UP3AZY80cjR@0<fVS@36WXD0`YV00;R?MP2bRW40YX1X0:1lI02EM5`0TG1I
08]ZDP2:Ie00R69;08QQBP27HDX0R69;091XD02FK5<0XG=J0:AgG@2WO6<0ZGiW0;20K@2ePG00^8=b
0;Z7M02hRG<0]8Y`0;27K02MMeh0RfMB0613=@1=<bP0=B4I02lN5`0/7QL0:ahG02PM5`0W71H09APA
02HG3`0`6A00=adC04@W7@1;;bD0Hdi407MWGP2[Y9`0`l2h0=GDc@020>CUgP030>;Sg03Rh]/0h^;K
0080h^;K1P3Rh]X40>;QfP80h^7I00D0h^;J0>KVgP3Yj>00iNCL0=SGd00Z0?ooo`l0moOg00<0mno_
0?Ogm`3gknl00P3gmoL01`3Fa/h0Q6=B07=:>@1cBT80Le9:06]BBP1B>C400P1B<BT2048Y8@03058a
:@1B>C40DS4Y0080DS4Y00/0Hd8a058i<@1[DTX0Nf=B09acH`2eQ6/0eZF<0=jeW03_aZd0mlje0>o>
]@020?OF_@<0mmK6103gg/h00`3ge/H0mnON0?ONcP0;0?OWgP@0mmk>00T0mmJm0?OFaP3ge/H0klje
0?OF_@3_c[D0mkfe0>o>]@3__JD00`3_aZd01@3__JD0klJ]0>nmY@3__JD0kkf]0080klJ]00<0kkfU
0>o6[@3W_JD00P3W_JD0103N]JD0g[FL0>N]W03N]I`20=j]U0<0eZF<00@0aYb40<jDN`2eS7<0aXac
102mQ6/01P3>U7/0cXb40=JLS036W8@0cXb40=JLS080eYb400L0cXb40=JLL`36W8@0]Hac0;f4J`1c
BT80DS4Y00<0@RTQ00P0>BTQ034Q8@1:<C40<B4Q034Q6012:B40>BTQ058a:@80BS4a00<0DSTa07=B
BP2]W8`06`3gmoLP0?ooo`007P3oool0103Hem00jNWP0>WXh03Ti=`40>;RfPH0hN;J0300hN;K0>;S
g03TiMd0iNKO0>3Pf@31_;<0Z9jE07IQE`1UCD80EC`a054i;`1<=R`0>R/R038U7@0Z7QH0:AdE02/L
500/71<0;A`D02hL5@0a81/0=2<N03`[9P13<B/0Ed8f06E>?P26Ie40UWEL0;>>L`2oVWh0dJjA0=Ne
V@3O`:<0h<:V0>74Z03Qa:T0hLBZ0>74[P3QaK00hLRc0>79]@3Qc;P0hLbi0>7>^`3Qckd0hM710>7B
``3QdlD60>7Da@040>7Ca03Qd;l0hLjl0>7<^080hL^g0P3QbkH02P3QbK<0hLRa0>76[03QaJX0hLBX
0>73Y`3O_j<0g[bP0=^fVP3J]9T20=VcU`100=VaUP3I/ID0fK2E0=V`U@3I/YL0fK:H0=V_V03I[YP0
ejbF0=F/U03AZY00cjR>0<fVS039X8H0aYf30;nEN`2kTGP0/X]a0:f7KP2UPVT0XWmV09ahG`2IM5`0
UFeE09=[DP2BJE40TfYB09]_EP2PLeX0ZW]Q0:enI@2`Q6/0/HE^0;F4L@2gPg80^H=b0;V6L`2gR780
/HQ]0:b4J@2GLUX0QfA>05i1<`1<<RL0=B4I030N5`0/7AH0:ahG02TN5P0W71D08aTB02<H400[6Q80
<AdD03lW7@16;R@0Gd]107ASF@2WWYH0_kVb0=7>a`3RhMX0hn?L0>;Sf`@0h^;K1P3Rh]X40>;QfP80
h^7I00D0h^;J0>KVgP3Yj>00iNCL0=SGd00Z0?oooa@0moOg00P0c[Fe07=:>@1cBST0Hd8a07=:>@1[
DTX0Hd8a058i<@<0DS4Y0P12:B402`1B<BT0@RTQ048Y8@1B<BT0DSTa06]BBP1cBT80W7=S0;F4J`3F
YH`0gZfD0080klJ]0`3ge[d20?OFaPD0mmk>00<0mnON0?ONcP3gg/h02`3gimh40?ONcP0;0?OFaP3g
g/h0mmK60?OF_@3_c[D0mmJm0?OFaP3_c[D0klJ]0?O>]@3_aZd00P3__JD20>o6[@080>nm[@3_c[D0
klJ]0>nm[@3_aZd0kkf]0>NeW03W_JD20>NeW0@0g[FL0`3FYH`30=JLS0<0cYAk00D0cXb40<j<L`3>
U7/0eYb<0<JLQ0040=JLQ0090<j<Q036W8@0eYac0<JLQ03>S8@0]Hac0:f4J`1cBST0DS4Y0080@RTQ
00T0>BTQ048Y8@0i:C40BS4a03TY8@0a8B40>BTQ034Q6012:B400P1B<BT00`0i:B40Je9:09b<S00K
0?Ogmb00oooo000N0?ooo`040=SGd03Yj>00jNSP0>CTg0@0h^;J1`3Qh]X0:`3Rhm`0i>GM0>GVg`3P
h=T0`[^b0:VMT`1gGe<0IT/m05Di:`1A=bT0C3DX03l^8`0h:B00;b8J02dO5`0]71@0;Q/B030J4P0b
6a@0=QlI03PS7@0o:b<0A30W05@n<01NASH0N5a708MXDP2WPfX0]Y1f0<bWR`3C/9@0g;fP0=k0X`3Q
`jH0hL>W0>73Z@3Q`jd0hLB_0>77/`3QbKD0hLbi0>7=^`3Qckd00P3Qckh0103Qd;h0hM710>7B``3Q
e<D40>7DaP0C0>7Ca03Qd;l0hLjl0>7<^03QbkL0hL^f0>7:]@3Qb[<0hLR`0>77[`3QaJd0hLB/0>72
Z@3Q`JH0gkbP0=jiW@3J/iP0fK:F0=VbU`020=VcU`030=VbU`3I/ID0fK2E0080fJnE03d0fJfE0=R]
U03FZi80eJZ@0=6WS03@YHX0cjB80<bPQ@3;Wh<0ai^00<FIOP30UW/0_IAj0;ZBM`2iTGH0]Xec0;>:
L02]Q6T0Zh5V0:YnI02ZOf@0[h1V0;:2J02hQV`0^HQ_0;^;M02kRgD0^hUe0;b8M02lQg<0^XMa0;N6
K`2]PFL0YG]P08aVCP1kF4<0F3/]04T_900e8AT0<1hG02hN5P0^7aL0;R0G02`O5`0V71@091/C02HK
500Z7AD0=R<J03hZ7`1G@SH0JUI:09Z:P@2aY9`0`kZc0=[Ec`3Ng=H0h^?K0>;Sg03Rhm/0h^;K00H0
h^;J103RhMX30>;Qf@050>;RfP3Vi]h0jNSP0>GTg03Hem00:P3ooolD0?Ogm`0609b<S01cBST0LdY2
06]BBP1S@S40HdY20P1B>C402P1:<C40Hd8a048Y8@12:B40BR4H048Y8@1B>C40DS4Y048Y8@1B<BT2
06=2<@0608ASDP2<Lf<0aYAk0=JUS03__JD0klJ]103ge[d40?OFaP80mmk>00H0mnON0?ONcP3gg/h0
mmk>0?OWgP3gg/h60?OWgP030?ONcP3ginL0mmk>00@0mmk>00D0mmK60?OF_@3_c[D0mmK60?OF_@03
0?O>]@050>nmY@3_aZd0klJ]0>o6[@3__Jd00P3_aZd30>nmY@0:0>NmY@3__JD0ikFL0>NmY@3W]I`0
ikfU0=jeW03W[I@0g[FL0=j]U080g[FL00<0eZF<0=j]U03FYH`00P3N[I@00`3FYH`0eYb40=JUS002
0=JUS0050<JLQ03FW8@0eZF40=JLQ03FW8`00P3FW8@01`36W8@0eYb40<jDN`36S7<0[HA[09ASBP1B
>C400P1B<BT0200i:B40@RTQ034Q8@12:C40DS4Y03TY8@0a8AP0<B4Q0`12:B401@0Y61P0@RTQ06]B
BP1SDTX0oooo01X0moOg803oool001h0oooo00L0f=O@0>WXh03Yj>00i>CL0>;RfP3RhMX0h^;J00P0
hN;J02X0h^?L0>CUg@3Ui]l0h>3I0<:k/@2YW940MUi@06A9>P1C=bL0CcDV04/d9P11;b@0>b/Q038T
700_8AT0;Q`D02hJ4P0a6A40<QXB03HN5`0h8Q/0?bXQ04@^8`1A>R/0FD8a071E@P1oHD`0X7aT0;2:
L039XhH0d:f@0=ZkWP3M_j80h<>V0>73Y`3Q`jT0hL>]0>74[`3Qak<0hLVe0>7=^P3Qc[`20>7@_`80
hLnm00@0hM300>7A`P3QdlD0hMC50P3Qe<H02`3QdlD0hM?40>7@_P3Qc[`0hLbh0>7;]`3Qb[D0hLZd
0>79/P3Qajh0hLJ]0080hLB/00P0hL6Y0>70YP3O^Yl0gKNK0=ZbUP3I/ID0fK6F0=VbU`80fK>G01L0
fK6F0=V`U@3I[Y@0fJjC0=V]T`3H[9<0eZZ@0=BYSP3AYHX0d:B80<nRQ`3>Wh@0c9j30<VLP@37Vh00
`YQm0<6GO02oUW/0_iEj0;fDN@2lTGH0]haa0;F:K`020;B8K@0X0;J8K@2hR6h0^hU`0;b:LP2mS7D0
_Haf0;f;MP2mRW@0_HUc0;Z8L02gQVd0ZWeS0:1eF`24GTL0M54l05<g:P15;B80=24I030N5`0_7QL0
<1lH034P6@0_81P0:1dE02DL500U6a<0:1`D038Q5`0i9Q/0DC`_06A>@P2AOW@0Z9N?0;^^Y`3Ec/P0
g=WB0>;Rf`3Si=`0h^?K0>;Rf`H0h^;J103RhMX30>;Qf@050>;RfP3Vi]h0jNSP0>GTg03Hem00:P3o
oolD0?Ogm`0:0:F4N`1[DTX0Je9:07=:>@1SBT80Je9:058i<@1S@S40DS4Y048Y8@80DS4Y1@12:B40
2`128AP0Hd8a05Y2>@24He80S6=B0;F<L`3FYH@0ikfU0>o6[@3gc[D0mmJm00@0mmK60`3gg/h0103g
imh0mmk>0?ONcP3gg/h30?OWgP030?ONcP3gimh0mnON00@0mnON0P3gg/h0103gimh0mmk>0?ONcP3g
e/H30?OF_@070>o>]@3ge[d0mkfe0>o>]@3_aZd0kkf]0>nmY@020>o6[@030>nmY@3_aZd0klJ]00<0
kkfU00<0kkf]0>NmY@3W_JD00`3W_JD0103W]I`0g[FL0>N]W03N]I`30=j]U0030=JUS03N[I@0gZfD
0080eZF<00<0eYb<0=JUS03FW8@00P3FW8@0103FYH`0eYb40=JLQ036W8@30=JLQ0070<JLQ03>U7/0
aYAk09a[DP24He80Hd8a058a:@0203TY8@0>034Q8@0i:B40BS4a03TY8@0a8B40<B4H03TY8@1:8AP0
@RTQ03TY8@0Q4100DS4Y06]BBP1cBSTK0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSg03R
h]X00P3RhMX80>7RfP0Z0>;Sg03TiMd0iNKO0>3Pf@30^[00YiZ>079JB`1PACD0CcDU04de9P1;=BL0
@c4V03l^900h9ah0=B<K030M5@0^6a80;AL?02hH3`0a71@0=1lG03XU6`0m:1d0Ac0S04hg:01SAcH0
LE8n095/D`2RNUl0_YIi0<VSQ@3G]YT0g;bO0>32YP3Q`jL0hL>Y0>74[@3Qa:l0hLNb0>79]@3Qc[/0
hM2n0P3Qd/801P3Qd;l0hLnm0>7?_@3Qd;h0hM710>7B``80hM?400@0hM;20>7A`03Qc[`0hLfj0P3Q
bkL01@3Qb[D0hLVc0>78/03QaJX0hLBZ0080hL>Z00H0h<2V0=nmX`3M^9`0g;FI0=ZaU@3I/9@20=V`
U@80fK6F00<0fK2E0=V_U03I[I800P3I[940303HZi40eZV>0=BWS03AXhP0d:660<nPQ03=WH80c9b1
0<VLP@38W840aI^00<BKO`80a9Yo02h0a9Um0<BHO033UGX0`YEi0<6DN@30TgP0_Y5f0;f@M@2kSG<0
^had0;Z<M@2kS7H0^hae0;^<M02jRg80]XM]0;63J@2OM5/0TFUA071?>`1P@S40@bdQ03TV700_7aP0
;QlI030O6P0`81X0;alJ02dN600W71D091/C020G400P5Q009aPA02hM5016<2@0F40d085YG`2GP7L0
ZiR@0<_2^`3Fd/X0h^;K0>?Tg@3Rhm`0h^;K1@3Rh]X50>;QfP<0h^7I00D0h^;J0>KVgP3Yj>00iNCL
0=SGd00Z0?oooa@0moOg00H0Q6]J05Xa:@1cBST0HdY207=:@P1[DTX205Y2>@80DSTa00H0BR4H048Y
8@0a8AP0@RTQ05Xa8@1B<BT2048Y8@80Hd8a00T0LdY207=:>@2LJe80[HA[0=j]U03W]I`0klJ]0>o>
]@3ge[d0103ge/H00`3gg/h0mmK60?OWgP020?ONcP<0mnON00@0mmk>0?OWgP3gimh0mmk>0`3gimh0
0`3ginL0mnON0?ONcP020?ONcP80mmK60P3ge[d01P3ge/H0mkfe0?OF_@3_aZd0mlJ]0>o>]@80kkfU
00P0ikFL0>nmY@3__JD0klJ]0>nm[@3__JD0klJ]0>nmY@80ikfU0`3W]I`01@3W_JD0g[FL0=j]U03N
[I@0g[FL0080gZfD0P3N]I`02P3N[I@0gZF<0=JUS03FYH`0eZF40=JUS03FW8@0eZF<0=JLQ03FYH`6
0=JLQ00;0<JLQ02eQ6/0W7=S07]SDP1cBST0DSTa048Y8@0a8AP0<B4Q058a:@1:<C400P0Y61P0100a
8AP0:APH048Y8@0a8B42034Q6005048Y8@1B@ST0DSTa07=BBP3gknl06P3gmoLP0?ooo`007P3oool0
1@3Hem00jNSP0>WXh03Thm`0h^;J0080h^7J00<0hN7J0>7RfP3Qh]X01@3Qh]X04@3Rhm`0i>GM0>GV
g`3Ph=P0`;V_0:FIS@1`FDX0GT@d04lf9`1==RP0BcHZ04Db:010;bD0>RPO03LU700b7aH0;a`C0080
:QP?01L0;Q/C034N5@0e8QP0>2@J044/7`18<B@0GD4`06];>029HdX0VG5E0;N>L033WGl0e[>F0=^k
WP3P`ZD0hL>W0>73Z@3Qa:d0hLB_0>77/P3QbKD0hLfk0>7@_P020>7B``060>7A`@3Qd;l0hLnm0>7?
_@3Qd;l0hM710P3Qd/<0103Qd<00hLnn0>7=^P3Qc;T20>7;]`0=0>7:]@3QbK80hLN_0>75ZP3Qa:T0
hL>Y0>32Z@3O_ZD0g[bQ0=bfV`3K]9P0fK6F0=V`U@050=V_U00D0=V^T`3I[940fJbA0=V[T@3HZi00
eZV>0=BWS03AXhP0cj660<jOQ03<WH40bib10<VLP@38W840aYf20<FMP@35W800a9^00<FIO@35V7d2
0<FFN`0Z0<BFNP32UGX0_i=h0;bAMP2iSG@0^8ac0;R<M02hS7D0^8ad0;R<L`2gRg40/XI[0:b1IP2G
KeL0Qf=<06E8=`1E?2d0>bPN03<R6@0]7QP0;AlI02lP700_7a`0;1dI02TL5`0T6Q@08ATB01`D3P0K
4`d08A@>02PH4@11:b00DST^07YPEP2?Mfh0Y9270<Nm]@3DclL0h^;K0>?Tg@3Shm`0h^;K1@3Rh]X5
0>;QfP<0h^7I00D0h^;J0>KVgP3Yj>00iNCL0=SGd00Z0?oooa@0moOg00X0Le9:06=2<@1SBT80Hd8a
06]BBP1cBST0HdY2058i<@1J@ST0DSTa0P12:B40100a8AP0@R4H048Y8@12:B43058a:@0:06=2<@1c
BST0Nf=B08ASDP2ULe80eZF40>NeU03_aZd0klje0?OF_@D0mmK6103gg/h20?OWgP030?ONcP3gimh0
mmk>00@0mnON1`3gg/h30?OFaP80mmJm0P3_c[D00`3_aZd0kkfU0>nmY@060>nmY@050>o6[@3__JD0
kkfU0>NeW03__JD00P3W_JD30>NeW0030=j]U03N]I`0ijfD0080gZfD00<0g[FL0=j]U03FYH`0203F
YH`20<JLQ080eYb40`36W8@04@3>U7/0[HA[0:EcFP1cBST0FT8i058a:@0a8AP0>BTQ034Q8@1:<C40
Hd8a02TH600a8B40:APH034Q8@0i:B40<B4H00808A0@0P12:B40101S@S40Le9:0=k>eP3ooolI0?Og
mb00oooo000N0?ooo`070=SGd03Yj>00jNSP0>CSf`3Rh]X0h^7I0>;QfP020>7QfPH0hN;J02/0h^?L
0>CUg@3Ui]l0h>3H0;nh[P2TV8`0KUQ905a4=@1?>2X0CST]04dj;`17=B`0@c8Y03h[8P0l:1l0=R8J
034O5P0Y6Q809aTA02TK4P0[71@0;ahF030P5`0i9Q`0@2`Q05Dj:`1P@S40NEDm08MQAP2WOf80]i1b
0=6]T03I]YT0h;nS0>71YP3Q`ZP0hL>/0>74[P3Qa[80hLRd0>7<^@3Qc[`0hM710080hM;300T0hM;2
0>7@_`3Qckd0hLnn0>7@_`3Qd/80hM710>7>_03QcKX0103QbkL03`3Qb[D0hLVc0>77/03Pa:X0h<>Y
0>32YP3O`JD0gKbQ0=biWP3J]IT0fK>G0=VaUP3I/ID0fJjC0=V]TP020=V/T@80f:bA03l0f:^A0=R[
T03GZi00ejZ?0=FXS@3DYX/0d:>70<jQQ@3<Wh@0bIb10<VLP038W840b9f10<ROP`37Wh@0aYj20<FL
P@34V7`0a9Ik0<FENP36UGX0a9Ej0<:ENP2mTWP0^I5f0;B=L`2cS780]8ab0;B<L`2eS780]8]a0;69
K`2XPFH0WgUP08ETCP1dEd@0DS`_04<a9P0_8QX0:QhG02TM600Z7QX0:ahL02PL6`0R61L07aLD01`D
400J4`h05@l:01@=2@0H3P/0818>03PS7017<2L0KE=9089ZG`2HPgP0`KJ]0=3:`P3Qh]X0i>GM0>?T
g03Rhm/0103Rh]X60>;QfP<0h^7I00D0h^;J0>KVgP3Yj>00iNCL0=SGd00Z0?ooo``0moOg00@0mno_
0?Ogm`3gknl0mno_0`3gmoL02@3_inL0HdY206=:@P1cBST0Hd8a06]BBP1SBT80Je9:06=:@P0205Y2
>@80@RTQ00D0DS4Y034Q6012:B40BR4H048Y8@03058a:@0807=BBP24DT80Q6=B08AB@P36U7/0eZF<
0>o6[@3gc[D20?OF_@@0mmK6103gg/h20?OWgP80mmk>1@3gimh00`3gg/h0mnON0?ONcP060?ONcP09
0?OF_@3ge/H0mkfe0>o>]@3_aZd0klje0>nm[@3__JD0klJ]0080kkfU00<0klJ]0>nmY@3__JD00`3_
_JD01P3W_JD0ikFL0>NeW03W]I`0gZfD0>NeU0<0g[FL103N[I@03`3NYH`0eZF<0=JUS03FYH`0gZF<
0=JUS03FYH@0eZF<0=JUQ036W8@0eZF40=JLQ03FW8`0aYb40=JLQ0020<jDN`050;F<L`2ULeX0Q6=B
06=:@P1B<BT00`0i:B400`1B<BT0>BTQ024@4002034Q8@03034Q600Y61P0:APH0080<B4H00H08A0@
03TY8@1B<BT0Hd8a06]BBP3Fa[dJ0?Ogmb00oooo000N0?ooo`070=SGd03Yj>00jNSP0>CSf`3Rh]X0
h^7I0>7Qf@020>7QfPH0hN;J02l0h^?L0>CUg@3Ui]l0h>3H0;ni[P2TV8`0KeU:05e5=@1?>2/0CSX^
04dk<018=bh0AC@[040]900n:R40>2@L03<Q6@0[71@0:A/C02XK4`0[71@0;QhF030P600h9Qd0?b`R
058i;01L@C00LU4k07mL@`2ONEd0/HY^0<jXS03G/YH0h;fQ0>70Y03Q`JL0hL>/0>73[P3QaK40hLNc
0>7;]`3QcKX0hM2o0>7A`P3Qdl@0hM;30>7@`0020>7@_`0_0>7@`03QdL80hM710>7>^`3Qc;T0hL^f
0>7:]P3QbkH0hL^g0>7:]@3QbK<0hLNa0>34Z`3P`jT0gl6V0=k0Y03L^il0f[RL0=VdV03I/iL0fK6E
0=V`U03I[I80fJbB0=V[T@3IZi00f:^@0=N[T@3GZi00eZ^@0=JZS`3FZHh0e:N<0=>VRP3@XhL0cZ65
0<bOQ039W840b9b00<RLP@38WH40b9n30<ROQ036WX<0aIb10<BHO@34UW/00P35UGX0:P33UGX0`YAi
0;bBM`2hT7H0/hec0;:<LP2dS780]Hab0;F<L@2cRW00/8Q]0:=mH`2IM5`0OEe906a@?`1<=b`0?bhT
02lR6P0[7aP0:1dH02PL6@0V6aX091XI01hF5P0L5A<0618>01H@300C3@X04P`901L=2`0N4@h0=24J
04<]9@1WCd@0O6EJ09=nM02n/jX0clW10>7RfP3TiMh0hnCL0>;Sf`@0h^;J1@3RhMX40>;Qf@050>;R
fP3Vi]h0jNSP0>GTg03Hem00:P3ooolC0?Ogm`050>oWi`2<Lf/0Hd8a06=:@P1S@S400`1[DTX0101S
BT80Hd8a06=:@P12:B42058a:@@0@RTQ0`1B<BT02024DT80Nf=B08ASDP24DT80aXac0=JUQ03W_JD0
klje0`3ge[d20?OFaPD0mmk>0P3gimh00`3gg/h0mnON0?OWgP030?OWgP<0mmk>00<0mnON0?ONcP3g
g/h00`3gg/h00`3_c[D0mmK60>o>]@020?OF_@040?O6[@3_aZd0klJ]0>o6[@<0kkfU00P0klJ]0>nm
Y@3__Jd0ikFL0>nmY@3W_JD0kkf]0>NeU0<0ikFL00@0g[FL0>N]U03W[I@0ijfD0`3N[I@00`3FYH`0
gZfD0=JUS0050=JUS00C0=JUQ03FYH`0eZF40=JLS036W8@0eZF40=JLQ036W8@0aYAk0<J<L`2eQ6/0
W6]B08ASDP1B>C40DS4Y048Y8@0i:B40DS4Y04Xa<@0302TH600<034Q600Y61P0<B4H024@400a8AP0
:APH034Q600i:B40DS4Y05Xa:@1cBST0g/kF6P3gmoLP0?ooo`007P3oool01`3Hem00jNSP0>WXh03T
hm/0h^;J0>;Qf@3QhMT0103QhMX40>7RfP0]0>;Sf`3TiMd0iNKO0>3Pf031^Jl0YiZ>079KC01PASP0
CcP/04hi;P1=>c40Bc/b04Xi<015<bX0@S0W03`Y8@0i9Qh0=28I038P5`0^7AD0;AdE02hO5`0a8QX0
>bXQ044_9P1@>c00F44d06Q=>`1cET40TfmG0:IoI@37WX80dZV<0=fgV`3P_:00hKnT0>72Z`3Q`jd0
hLB_0>75/03Qak<0hLVe0>7<^P3Qc[d0hM710080hM;30P3Qd/801@3Qd/<0hM;20>7A`@3QcK/0hLbh
0080h<Zf0P3PbkH03`3Qb[D0hLVd0>77/P3Pa:d0gl:[0=foY@3L_Z80f[VM0=VgV`3H/iL0f;6E0=R^
T`3H[I80f:^A0=R[T0020=RZT0060=NZT03FZi00e:Z@0=>ZS`3CYh`0dZJ;0P3BY8T01`3?XXH0cJ25
0<^OQ038W840b9b00<NLP038W8400P38WH80<037W840aY^00<FIOP34V7`0`iEj0<:DN@31U7P0`9=h
0;^AMP2hSgD0/hab0;B;L@2gRg40^8]`0;J9KP2bQV`0[89X09UcF`2<J5<0Ke0o05m4=@15<2H0?BXQ
03<T7@0`8a`0:1dH02@I5P0M5A@071@D01TC4`0H4Q4050d<018<2P0B2`X04`d;01X@3P0O4a00<B4J
03l/901SCdD0NFIK0960M@2m]J`0cl[20>;RfP3TiMh0hn?L0>;Rf`<0hN;J00<0hN7J0>;QfP3RhMX0
0`3RhMX40>;Qf@050>;RfP3Vi]h0jNSP0>GTg03Hem00:P3oool@0?Ogm`080?O_k`3gmoL0moOg0=K6
eP1[DTX0Hd8a05Y2>@1SBT8207=:>@0406=:@P1cDTX0FT8i06=2<@80DS4Y00<0@RTQ058a:@0a8AP0
0P12:B403@1B<BT0@RTQ058i<@1S>BT0Je9:08ASDP2LJe80]HA[0<J<L`3W]I`0ikfU0>o>]@3ge[d0
0`3ge/H00`3ge[d0mmK60?ONcP030?ONcPP0mnON00<0mmk>0?OWgP3gg/h00P3gg/h20?OFaP080?ON
cP3ge[d0mmJm0?OF_@3_c[D0mlje0>o>]@3_aZd40>nmY@080>NeW03__JD0kkfU0>NeW03__JD0ikFL
0>nmY@3W]I`20>NmY@040=jeW03W[I`0gZfD0=jeW0<0gZfD0P3NYH`00`3N[I@0eZF<0=JUS0020=JU
S0050=jUS03FYH`0eZF<0=JUQ03FYH`00`3FW8@20<JLQ0060<JDN`36S7<0]HA[0:f4J`1kHe80HdY2
0P1B>C40101S@S40DSTa034Q600a8AP2034Q8@80<B4H0P0Y61P0100a8AP08A0@03TY8@0a8AP2048Y
8@0306=2<@1cFU80oooo01X0moOg803oool001h0oooo00L0f=O@0>WXh03Yj>00i>?K0>;RfP3RhMT0
hN7I00@0hN7J103Qh]X0;P3Rhm/0i>GM0>GVg`3Ph=P0`KZ`0:RKS`1dGDh0HDPj050i;@1>>Rl0CS/b
04dl<`1<>c80AcH]04@c:P0o;2<0?2TQ03PT700e8AT0;adE02dM5@0^7aL0<R8J03d[8`13<BP0DC`a
05Q2=@1WCC`0LUE2091/E@2RNf40`iQk0<nSQP3L]9L0gkVM0>2mX`3Q`JX0hL:/0>73[P3Qa:l0hLFa
0>77/P3Qb[L0hLbj0>7@_`3QdL420>7B``80hM?400D0hM;30>7A`@3Pc[`0h<fj0>3;]`030>3;]P0=
0>7:]@3QbK@0hLNc0>34[P3O`Z`0gKnU0=^mXP3I^Id0fKNK0=RcU`3H/9D0ejfB0=N/T@020=NZS`80
f:V?00h0ejZ@0=JZT03CZHl0dZR>0=6VR`3AY8T0dJ>80=6RQ`3?XHH0cJ250<^NP`38W840b9b00<NL
P080b9b00340b9^00<NKP037VWl0aIUn0<BHO@32UGX0`IAi0<2CM`2oTWL0^i1e0;R>M02eS740]X]a
0;R:L02iRFl0]HI/0:n2J@2XOF@0TfeF08IRC@1YBSX0Fcla04@]8`0m:1l0=B@M034S700W71P08APE
01XB4P0H4A80614A01L@400C3@/04@/:018<2`0E3Pd06a8@020E4P0b8Q`0@2lW06QFC01oKV@0UXQn
0<6j/@3AcLD0h^;K0>CUg@3Shm`0h^;K0080hN;J0P3QhMX40>;QfPD0h^7I00D0h^;J0>KVgP3Yj>00
iNCL0=SGd00Z0?ooo`h0moOg00X0mno_0?Ogm`3gmoL0moOg0?O_k`3Nc]H0LdXi06=2<@1SBT80Je9:
0`1SBT80101[DTX0FT8i05Y2>@1B>C42058a:@<0@RTQ0P1B<BT2048Y8@0;06=2<@1cBST0S5Y:08A[
FP2mQ6/0aXac0=j]U03W_JD0klJ]0?O>]@3ge[d01@3ge/H20?ONcP80mnON00<0mmk>0?OWgP3gg/h0
103gimh00`3gg/h0mnON0?OWgP020?ONcP<0mmK600X0mmk>0?OF_@3g_KD0mmJm0>o>]@3_aZd0kkf]
0>nmY@3W]I`0kkfU0P3W]I`30>nmY@040>NeW03__JD0ikFL0>NeW080ikfU00@0ikFL0=j]U03W[I@0
ijfD0P3N[I@0103NYH`0gZfD0=JUS03N[I@30=JUS0070=JUQ03NYH`0eYb40=JLQ03FYH`0eYb40<JL
Q0020=JLQ00A0<JLQ036U7/0cYAc0;F<L`2]Q6/0W7=S07=:@P1cBST0FT8i06=2<@1B<BT0@RTQ034Q
8@0i:B40<B4Q048Y8@0a8B400`0Y61P0200Q4100:APH034Q600a8AP0@RTQ048Q601S@S40YHAk6`3g
moLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00<0hN7I1@3QhMX20>7RfP0`0>;Sf`3T
i=d0iNKN0>3Pf031^k80YifB07=OD`1QBcl0DC``050l<P1@?S@0DD0g054o=P1=?3<0BST`04Db:@13
;RH0?BLN03PS6`0]7A@0:Q/C02/M5@0`8AP0?RXQ04H`9P1D>bl0Fd4c06]=>`1eE400T6Q?0:1cF02m
S6h0b9Qj0=N]S`3K]IP0g[ZO0>31Y`3Q`ZT0hL>/0>73[@3Q`jl0hLB_0>77/P3Qb;@0hLbj0>7>_03Q
dL40hM;30P3PdlD07`3Pdl@0h=;30>3@`03Pckh0h<fj0>3<^03PbkH0h<Zf0>39]@3Pb;@0h<Nc0>34
[`3P`jd0g/2W0=fnY03K^Yh0f[RK0=RbUP3F/9@0eJb@0=BZS`3DZ8d0e:N<0=JWS@3GYXh0eZN?0=FW
SP3BYX`0dJF:0=2RQ`3@XHD00P3@WhD02@3?WXH0cIj50<^MP`38W840b9b00<NKP037Vgl0b9Un0<NH
O@020<JGO00^0<BGO033Ug/0`9Ei0;nCN02mSg@0_8ic0;^<L@2jRg40^HY`0;V9K`2hQV`0]X=Y0:]l
I02SMf00VW5K08AOB`1hED80Gd0a05@g:P11:Al0>RDL030Q6@0/7aP08QTD01hF4`0H4A405a0@01H?
3`0F3`h05@h;01@>2`0F3`d0614?01dC4@0R5Q80>2LQ04/j<P1nL6P0VHj50;2XW`3@cLD0fMS@0>;R
f`3Shm`0h^?K0>;Rf`80hN;J103QhMX20>;QfPD0h^7I00D0h^;J0>KVgP3Yj>00iNCL0=SGd00Z0?oo
o`h0moOg00<0mno_0?Ogm`3gmoL00P3gmoL0203>]KD0Je9:06]BBP1S@S40HdY206]BBP1cDTX0HdY2
0P1[DTX02@1SBT80FT8i05Xa:@1B<BT0@RTQ058i<@0a8AP0DS4Y048Y8@02058i<@0:07=:>@1SBT80
Q6=B09a[DP2]Q6/0aXac0=JLQ03W]I`0klJ]0>o>]@80mmJm0`3ge/H50?ONcPH0mnON00@0mmk>0?OW
gP3gg/h0mnON0P3gg/h01@3ge/H0mmk>0?OFaP3ge[d0klje0080mmJm00<0klje0>nmY@3_aZd00P3_
_JD00`3W_JD0ikFL0>NeW0020>NeW0040>neY@3__JD0ikFL0>NeW080ijfD00D0ijfL0>N]U03W[I`0
ijfL0=jLS0030=j]U0050=jUS03FYH`0gZF<0=JUS03FYH@00P3FYH`20=JUQ00H0=JLS03>U7/0eYb<
0=JUS03FW8@0aYb40<jDN`2eS7<0aXac09acH`2]Q6/0S7=S07=:>@1S@S40DSTa058a:@12:B40<B4Q
02TH600a8AP0<B4Q034Q600H4100:APH0P0Q4100200a8B40:APH034Q8@0i:B40<B4H03TY8@1cFU80
c[Fm6`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00@0hN7I1P3QhMX0<03Rhm/0
i>CL0>CUgP3PgmP0`;^b0:JMT`1bH5D0H4a1054m<P1@?C<0DCle05=1>01B@CP0Cche04dl<P17=B`0
A30W03dW7`0g8aX0;1`D02PJ4P0Z71@0<20G03hY8016;R@0ECX]05a0<@1^CCX0NEDo099VC02PL5@0
^XMX0<FCM03DZX`0fK:F0=fiW@3P`:D0hL:X0>73Z`3Q`jd0hL>^0>73[`3QaK40hLNc0>7;]`3QcKX0
h=2o0>3A`P80h=?50380h=?40>3Ba03PdL80h=300>3>^`3Pc;T0h<^f0>3:]P3PbKD0h<Rd0>37/`3P
a:l0h<>/0=o0Y`3N_j@0g;^N0=ZhV`3G/YH0eZnD0=B[T03CZXl0djN<0=>VR`3EYH`0eZF=0=JUSP3E
YHd0dZB:0=6SR@3@XHD0d9n40=2MQ03@WHD0cif50<fMQ@3;W8<0b9^10<NKP037Vgl0aiYo0<NHO@37
Ug`0aYIk0<FFNP32UW/0`IIj0<2DN@2oTWL0_Hic0;b<L@<0^hY_02H0^XQ^0;J4J@2bP6H0YGQP09eb
G02CJeH0OEU6075??@1K?2d0DC@W040X7P0h8a/0;1hF02PL5@0P61<07AHB01TB4@0G4A405Pl?01H?
3@0F40`05a0<01PB3P0I4Pl07Q<A02<F4P0l:R<0DT0i08aoM`2XWiL0_kZb0=WGd03Ng]H0h^;K0>;S
f`3Rh]/0h^;J0>7RfPH0hN7J00<0h^7J0>;Qf@3RhMT00`3RhMT01@3Rh]X0i^KM0>WXh03Ui=`0f=O@
02X0oooo4P3gmoL01P3gknl0c[g606]BBP1[DTX0DSTa06=:@P80Le9:00<0LdXi06]BBP1[DTX00P1S
BT80101B>C40DS4Y048Y8@1B<BT2048Y8@0@058a:@1J<BT0DSTa07=:>@1[DTX0S6=B08A[FP2eQ6/0
]Hac0=JLL`3N[I@0klJ]0>o>]@3gc[D0mmK60?OF_@80mmK6103gg/h01@3gimh0mmk>0?OWgP3gimh0
mmk>00<0mnON00D0mmk>0?OWgP3gg/h0mnON0?OFaP020?ONcP80mmK60P3ge[d0103_aZd0mlJ]0>o6
[@3_aZd20>nmY@040>NeW03__JD0kkfU0>nmY@<0ikFL00@0kkfU0>N]U03W_JD0g[FL0P3W[I@00`3N
[I@0g[FL0=j]U0020=j]U00D0=jUS03FYH`0eZF<0=JUS03NYH`0eZF<0=JLS03FW8@0eZF<0=JLS03F
YH`0eYb<0=JLQ036W8@0eZF40<jDN`36U7/0]Hac0;F4J`2]Q6/20:EcFP0406=:@P1S@S40DS4Y058i
<@@0<B4Q00H0<B4H034Q8@0Y61P0:APH024@400a8B4202TH600603TY8@0a8AP0<B4H048Y8@1cDTX0
aZf]6`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00@0hN7I1@3QhMX0<P3QhMT0
h^7I0>?RfP3Sh]X0g]cD0;fg[`2SVY80KUmF05a;@P1??C<0Ccdd0550=P1D@ST0E4<i0591>01@?cD0
BCL^04@a:00j9Qh0=28I02`M5@0Z7A@0;AlG034Q6@0m:1l0@b`R054g:@1J?Bh0L4`h07aE?@2EIDT0
XFe@0;N1H`30SFl0d:F70=F_TP3J]YX0gknS0>31YP3Q`jX0hL>/0>73[P3Qa:l0hLFa0>36/P3PbKD0
h<^g0>3?_@3Pd<00h=?40`3PdlD0:P3Pdl@0h=;30>3?_P3PcK/0h<^g0>3:]P3PbK@0h<Rc0=o6/@3O
`Z/0gl6Y0=o0Y@3O_Z<0gKVM0=^fVP3H/9D0eZjC0=B[T03CZXl0djN<0=>VR`3DY8/0eJB<0=BSS03D
Xh/0dJ:80=6QQP3@WX<0d9f20<nLP`3?W8@0cIf50<^MQ03:W8<0ai^00<JIO`35Ugh0aIIm0<FDN`35
U7X0`iAh0<:DN080`9Ai02T0_i=h0;nBM`2mSG80_8Y_0;^8KP2kRFh0^XU^0;R7K02`P6D0Zg]Q09ea
F@2DJe@0RVA>07AB?P1YB3H0ECLX04``8`0n9Q`0=R8I02PL500S6A807QLB01dG4P0L5Q<06aDB01XC
3`0I4Ph06Q<=01/D3@0L5@l071D@020E400U5a80@BhW05]9@@2NU8`0_KR`0=CBbP3Vi]l0iNKO0>;R
f`030>7RfPP0hN7J1@3RhMT01@3Rh]X0i^KM0>WXh03Ui=`0f=O@02X0oooo303gmoL00`3gknl0moOg
0?Ogm`040?Ogm`080=K6cP1cBST0HdY2058i<@1J@ST0Je9:07]SFP1[DTX207=:>@0407=JDP1SBT80
FT8i048Y8@80DS4Y00<0FS4Y058a:@1B<BT00P1B>C40301J@ST0LdXi08ASDP2DFU80[HA[0;f4J`3F
W7<0eZF<0>NeW03__JD0mlJ]0?OF_@80mmK600<0mmJm0?OFaP3gg/h00`3gg/h00`3gimh0mmk>0?OW
gP020?ONcP030?OWgP3gg/h0mmk>00H0mmk>00L0mmJm0?OFaP3_c[D0mlJ]0>o6[@3g_KD0kkfU0080
klJ]0P3__JD20>NeW0030>neY@3__JD0kkfU00<0ikFL00@0ikfU0>N]W03W[I@0gZfD0P3W[I@20=j]
U080gZF<00D0eZF<0=JLQ03NYH`0eYb40=JUS0020=JLQ0040=JUQ03FW8@0eYb40=JLS080eYb400/0
aYb40<jDN`36S7<0_HA[0;F<L`2<Lf<0W6]B07]SDP1S@S40DSTa058a:@0203TY8@0503TY<@0i:B40
<B4Q03TY<@0a8B400P0Y61P203TY8@08034Q8@0Y61P0<B4H03TY8@1B<BT0@RTQ07=BBP36[JDK0?Og
mb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X0103QhMT40>7QfP80hN7I0340h^3H0>?P
f@3SgmP0gMWB0;be[@2QV8l0K5eE05Y:@@1=?380CS`c050o=@1D@ST0E4<i05=1>01A?cH0BCL^04@a
:00h9Ad0<b8I02hO5`0]81L0<B8J03@T700m:B00@B`S04hf:@1G?2d0KT`g07]D?@2EIDT0X6e@0;F0
HP2nS6h0cZ>60=>]T03H]IP0g[jR0>31Y@3Q`jX0hL>/0>74[`3Qa;00h<Ja0>37/P3PbK@0h<^f0>3>
_@3Pd<00h=?400<0h=?502X0h=?40>3B``3Pckh0h<fk0>3;]`3Pb[H0h<Vd0=o7/P3NaJl0gL6Y0=k0
YP3O_Z<0gkfQ0=fhW03K]IT0f:nC0=J]TP3EZi00e:Z?0=BXS@3DYh`0e:F;0=BTR`3CXhX0dZ>:0=6R
Q`3AXHH0d9j20=2MP@3?W880cYf40<^NQ@3:WX@0bIf30<NJP036V7l0a9El0<BCN`33TgX0`i=i0<:C
N031TgP20<2DN00F0;nCN02oTWL0_Xeb0;f;L02kRFh0^XU_0;N8KP2dQV/0[7iS0:MiG`2KKeH0TVUA
08URB`1bCc`0ITHc054e9P1:;b80?BDL03HR6@0X71@08aXB01lH4P807QPC01807QLC01`E4@0L5@l0
71D>01`E3@0M5Pl07AH@024F400V6140@RlX05e;@`2RV900`[be0=SGc`3XjN80inSQ0>;Sf`3Qh]X9
0>7QfP80hN7I103RhMT01@3Rh]X0i^KM0>WXh03Ui=`0f=O@02X0oooo403gmoL0103gknl0moOg0?Og
m`3>]KD206=:@P03058i<@1SBT80HdY200@0Je9:00<0Le9:06=:@P1SBT800P12:B404P1B<BT0DSTa
058a:@1B<BT0DSTa06=2<@1J@ST0HdY208ASDP2LJe80]G]S0;F4J`3>U7/0eZF<0>NmY@3__JD0klje
0?OF_@D0mmK600T0mmk>0?OWgP3gg/h0mnON0?ONcP3gimh0mmk>0?OWgP3gg/h00`3gimh20?ONcPD0
mmK600D0klJ]0?Nm]@3gc[D0klje0>o6[@030>nmY@040>NeU03__JD0kkfU0>NmY@80ikFL00P0ikFD
0>NeW03W]I`0ikFL0>N]U03N[I@0ijfL0=jeW0<0gZfD00T0gZF<0=JLS03NYH`0eYb<0=JUS03FW8@0
eYb<0=JUS03FW8`01@3FW8@01@3FW8`0aYb40<JDN`36U7/0[HA[0080YG=J00@0Q6=B07=:>@1S@S40
DSTa0P1B<BT303TY8@05058a:@0i:B40>BTQ048Y<@0i:B400P0a8B40200Y61P0<B4Q03TY8@12:B40
>BTQ048Y8@2<He80e/K>6`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00D0hN7I
0P3QhMX05@3Qh]X0hN7I0>;Pf@3RgmL0hmoG0>;MeP3Le/l0^K6Y09jDS01YFU00EdHm04/h;P1=>Bl0
Cc`b05=0=P1D@CP0Dd4h054o=P19>2l0@c8Y03PW7`0203DU700M03HW7P0i:B40>RXR03d/8`0o;R@0
B3DY054k;@1YBcP0Me@n095TBP2KK540[geR0;R8K039WH40cjN;0=F`T`3L_9l0gknS0>32ZP3Q`j`0
hLB_0>35/@3Pak<0h<Rc0>3:]@3PbkH0h<jk0>3?_P3PdL800`3Pd/<04@3PdL80h=710>3>_03Pc;T0
h<Ve0>39]03Oa[00gLB]0=c2ZP3K_J<0fkbP0=fkW`3M^Yh0g;FI0=^bUP3H[940ejZ?0080eZV=01L0
eZR=0=FXS03DYXX0djF90=6SQ`3AXXL0d::60=2QQ@3@WX<0d9j20<fNP`3<WX<0bIn40<ROQ038WX80
aYUo0<FFO@33TGX0`Y1i0<6@N030TGP0`99g0<2CM`030;nBM`0D0;nAMP2nSW<0_Hab0;Z:L02gRVl0
/8M/0:b3J@2TNEl0WgAJ09EYD@2=Hd`0Q5a606a:=P1O@2l0BS4S04<[7`0h91X0<b4H02PM5@0T6a@2
020J4`0C020J500P6A<07aPB01dG400J50d06A@=01XD3@0L5@h08AH?02LH4@14<2P0Gda40:BIT@33
_KD0f]O@0>WZhP3Wj>40h^?K0>7RfP080>7QfP@0hN7I0`3RhMT01@3Rh]X0i^KM0>WXh03Ui=`0f=O@
02X0oooo303gmoL00`3gknl0moOg0?Ogm`040?Ogm`050=k>eP1cDTX0Je9:05Y2>@1B>C400P1SBT80
201cFU80Je9:07=JDP1SBT80DSTa06=:@P1J<BT0@RTQ0P1B<BT01`1B>C40HcTa058a:@1B>C40LdY2
07=BBP24He800`2ULeX01P2mQ6/0cYAc0=j]U03W]I`0klJ]0>o>]@<0mmJm0P3ge/H20?ONcP@0mnON
00<0mmk>0?OWgP3gg/h0103gg/h20?OFaP80mmJm00<0mmK60?OF_@3gaZd00P3_aZd0103gaZd0kkfU
0>nmY@3W]I`20>NeU0<0ikFL00L0kkfU0>N]W03W]I`0ikFL0>N]W03W]I`0ijfL0080gZfD00P0ijfD
0=jeW03N[I@0gZfD0=JLS03FW8@0eZF<0=jLS0<0eZF<00<0aYb40=JLQ03FYH@00`3FW8@02036W8@0
aYAk0<JDN`2eS7<0]HA[09acH`2DHdX0Nf=B0P1cBST02`1J<BT0DSTa058a:@12:C40BS4a048Y<@1B
>C40DS4Y034Q8@0Y61P0<B4Q0080>BTQ00P0<B4Q024@400Y61P0:APH024@401B<BT0@RTQ0>oWia`0
moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP050>7Qf@<0hN7J0380hN7I0>7Pf@3R
gmP0hmoH0>;NeP3Lem00^K6Z09fCR`1WF4l0ET@j04/g;01=>2d0D3/`05<o=@1C@3H0DT4g054o=P1;
>C00ASD/03`[8`0i:B00>BPP03XZ8@0l;2<0?BdT03h^9@10;bD0B3DY050j;@1WBcT0ME@o08eTB`2G
Je40ZWYO0;B4J@36VGh0cJ>70=>/T03K^Yd0gKjR0>32Z@3P`Z/0h<B_0>35/@3Pak<0h<Rc0>39]@3P
b[H0h<fj0>3>_@D0h=300100h<no0>3<^P3Pb[L0h<Rc0=o7/@3Ma:d0g<:Z0=^oYP3J^j00f[ZN0=^j
W@3L^I`0fkBH0=ZaU@3HZhl0ejV=0P3FZ8/05@3EZ8/0eJN;0=>UR@3BY8P0d:>60=2RQ@3@XXH0d:65
0=2OQ03?Wh<0cIj30<^OP`38Wh<0aij30<NMPP36VGl0aIIm0<>ANP32T7T0`91h0<2AM`020;nBM`80
_i5f0P2oT7D0502nSW<0_8ab0;N:L02dRFl0[8EZ0:R1IP2PMe`0Vg5G08mUC@28GTP0OUM206I5<`1J
?2`0ARhQ03lY7@0e8QT0<20G02HL500S6a<081TB0`0P6A<04@0M5a4071D@01LB300F4@/05Q8<01PC
3@0P5@h0:1PA04La:@1QCDD0YIVA0<>m]@3Iell0j>WR0>OXh@3Rhm/0hN;J00P0hN7J103QhMT30>;Q
f@050>;RfP3Vi]d0jNSP0>GTg03Hem00:P3oool80?Ogm`030?O_k`3gmoL0mno_00D0moOg0140mno_
0?Ogm`3gmoL0e/K>07=BBP1S@S40HdY2058i<@1SBT80LdXi07]SFP1[DTX0LeYB06]BBP1J@ST0HdY2
05Y2>@02048Y8@03058a:@1J@ST0DSTa0080DSTa00`0LdXi07=BBP1cBT80S6=B09ASBP2ULeX0]G]S
0<J<L`3NYH`0g[FL0>o6[@3gc[D20?OF_@<0mmK61P3gg/h20?OWgPD0mmk>0`3ge/H0103ge[d0klje
0>o>]@3gc[D30>o6[@80kkfU00D0ikFD0>NeW03W]I`0ikFL0>NeU0020>NeW0040>N]W03W]I`0ikFL
0>NeW0<0ijfL00P0ijfD0>N]W03W[I@0ijfD0=j]U03NYH`0gYb<0=jUS080eZF<0P3FW8`20=JUS00;
0=JLQ036W8@0eYb40=JUQ03>U7/0aYAk0<J<L`2eNf<0[G=J08aSDP24DT800P1cBST00`1S@S40DSTa
058a:@02048Y8@0403TY8@1B<BT0@RTQ048Y<@80:APH00<0>BTQ02TH600Q41000P0Y61P2024@4003
03TY8@12:B40DSTa01d0moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP060>7Qf@80
hN7J0P3QhMT0<03RhMT0hn;J0>CRfP3Nfm@0^[F]09fES@1VET`0ED8g04de:01@=RT0DcT/05<m<@1B
?S<0DD0f0550=`1??SD0C3/b04He;013<RT0?bhU03h]900n;RD0?blV044a9P13<BH0BSHX054k;01T
CC/0KeE2089RC02;ITl0WG1G0:QiGP2nSW<0aiUn0<jTR03H]IP0fkZO0=k0Z03O`Z/0h<>^0>74[`3P
aK00h<Ja0>38/`3PbKD0h<^g0>3;^0D0h<bi00X0h<^h0>39]@3Pak<0glB^0=k2Z`3K_jD0f[bR0=Vj
W`3H]i/0fKNJ0P3I]i/01P3I/iL0fJnD0=NYS@3FYhX0e:F60=>TQP80dZB700@0dJB60=6SQ@3@XX<0
d::30P3@XXD01@3@XHD0cj250<fOP`3;WX80b9f10080aib003@0aYUn0<JGO035TgT0a95h0<6AM`30
TGL0_i5f0;n@M@2oSW<0_hec0;n=LP2nS780^Xaa0;N;L@2`R6d0[8E[0:=nI02PNEl0UfiD095WC`21
F4@0Me0n06e8>@1H>B`0CS8V03dW7@0f91X0;1lF02PM500R6Q4081PA01hG4@0N5a807AHC01`E4P0H
4Pl05A0=00l<2@0=2`P03``901<>2`0R5Q40;QdG05@m=@1_FE00[9nG0<Jo]`3Ie/l0i^OP0>KWg`3R
hm/0hN;J203QhMX50>7Qf@80h^7I00D0h^;J0>KUg@3Yj>00iNCL0=SGd00Z0?ooo`h0moOg00<0mno_
0?Ogm`3gmoL00P3gmoL01@3Wg^L0Q6]J07=:>@1SBT80DSTa0080HdY20180Le9:06]BBP1cDTX0LeYB
06]BBP1J@ST0HdY2058i<@12:B40DS4Y058i<@1S@S40HdY205Y2>@1B>C40Hd8a07=:@P2<He8208AB
@P090;EkH`2mQ6/0eZF40=j]U03_aZd0klje0?O>]@3ge[d0mlje00H0mmK6203gg/h30?OFaP090?OF
_@3ge/H0mmJm0>o>]@3gaZd0klJ]0?O6[@3_c[D0kkfU00D0ikFL0P3W]I@40>NeW0030>N]U03W[I`0
ijfL0080ijfD00<0gZF<0=j]U03N[I@00P3NYH`0203FW8@0eYb<0=jUS03FYH`0eYb40=JUS03FW8@0
eYac0P36W8@20=JUQ080aYAk00D0]Hac0:f4J`2ULeX0Q6=B08AB@P0206=2<@80DSTa0P1B<BT02P12
:B40<B4Q034Q600a8B40>BTQ058a:@0i:B40610@024@400Y61P2024@400602TH600a8AP0>BTQ058i
<@1cBST0oooo703gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00H0hN7I0P3QhMX2
0>7Qf@0X0>;RfP3Thm/0i>CL0=oNeP2k]jl0WYN>06IGC@1F@SH0CS@V054f9`1D>BX0Dc``058m<P1A
@3H0DT0g0550=P1??SD0BCP_04He;010;bH0?bdU03l^9010;bD0A38W04Db9P1<=bT0DS`]06==?01/
ED<0OEm;08ARC02FJU40XG9H0;V8K@33U7P0c9n30=JbUP3I^Id0g/2W0=o2ZP80hL>]00D0hLB^0>35
/03Pak80h<Rc0>39]@060>3:]@080>39]@3Pak80h<Fa0=o2[03M`JT0fkfR0=ZkW`3I^Id20=RfV@08
0=RfVP3H]YT0f;6F0=R^TP3FZ8/0eJF80=:SQ03AXX<30=6RQ@100=2RQ03@XX<0d::30=2RQ@3@XHD0
d:250<nPQ03=WX80bif10<RKP037Vgl0aiYo0<NHO@37Ug`0aYAi0<FCN032TWL0`I9g0;n@MP2oSg@0
_hab0;n;L@2nRg00_HY`0;N:L02dRFl0[8E[0:R2J02ONUl0VgAJ091XC`2:HDX0N54o06i9>@1T@C@0
D3<X04P]8`0h91/0<R4I02PM5@0U71<08AT@01lH400N5Q407AHB01/D4P0J4a405Pl>01<=300=2PP0
2`P700d:200C3@/0:1XG03LV801RBd@0OFMO0;BXW`3:a;`0f]S@0>GVg`3Ui]h0h^;K0>7RfPL0hN7J
1P3QhMT20>;Qf@050>;RfP3ViMd0jNSP0>GTg03Hem00:P3oool<0?Ogm`050?O_k`3gmoL0moOg0?Og
m`3gknl00P3gmoL01@3Nc]H0S7=[06=:@P1J@ST0DSTa0080LdXi00@0Je9:07]SDP1[DTX0Le9:0`1S
BT801@1S@S40@RTQ03TY8@1S@S40DSTa0080HdY200X0DSTa06=2<@1cDTX0Le9:07]SDP24DST0[G=J
0;EkH`3FW8@0gZF<0P3_aZd00`3_c[D0mmJm0?OF_@040?OFaPD0mmk>0`3ge/H20?ONcP@0mmK600L0
mmJm0>o>]@3gc[D0klJ]0?O>]@3_aZd0mlJ]00<0ikFL0`3W]I@00`3W[I`0ikFL0>NeU0020>N]U004
0>NeU03W]I`0ikFL0>N]U080gZfD00@0ijfD0>N]W03NYH`0eYb<0P3NW8@00`3NYH`0eZF<0=JLS002
0=JLQ0030=JUQ03FW8@0eYb40080eYb400T0cYAk0<JDN`2mQ6/0]HA[09a[DP2<He80Nf=B07=:>@1S
BT800P1S@S44048Y8@<0>BTQ0P0a8B402`0i:B40:APH034Q8@0H4100:APH024@400Y61P0<B4H048Y
8@1S@S40LdY201d0moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP080>7Qf@80hN7J
02P0h^?K0>CTg@3Ui]h0h>3H0;jj/P2SVY80K5Y@05]4>@1?=2D0DCDU058g:01C?2l0Dchc05=1>01C
@ST0DT4h0550=P1;>S00AcH]044^9@0o;2<0@2`R04<^8`17<bH0BC@W04hi:`1B?S00Gd`l06IB@@1a
Ed@0MeM308MLAP2BI4`0[G]Q0;Z9KP34Ug/0djjB0=RgV`3N`:D0gl6W0P3Q`ZT01P3Q`j/0h<>/0>35
[`3PaK00h<J_0>36[PD0h<J]01H0h<F]0>34[@3P`jd0gl6Z0=k0Z03L_J80fk^O0=ZhW03H]9P0f;>G
0=RbUP3G/ID0eZ^@0=FXS@3CXXH0dZ230=2NP03@WX40d9j30=2NQ03@Wh@0d:240P3@XX@0?03@XXD0
d:640=2NPP3?W840cI]o0<^JO`38VGh0aiUm0<NHO@37UW/0aiEj0<NDN036TgP0`i=g0<6BM`2oT7D0
_hid0;n;L02oRFl0_8M]0;V6K02aQFX0[H=Y0:AnH`2ONUl0UFmE08mXD020FDD0Me4o06M4=@1N?S00
ESP[04D/8P0n9ah0<B0H02`N5P0U71@08a/C028I4@0R614081HB01hE4P0J4Q80614@01<=3@0A2`/0
3@P800`71`0B2PT06a4>03d^:@1FACl0SGee0:JHT03:`k/0e];:0=gLe@3Si=`0hn?L0>;RfPL0hN7J
203QhMT01P3RhMT0h^;J0>KUg@3Yj>00iNCL0=SGd2X0oooo3P3gmoL00`3gknl0moOg0?Ogm`030?Og
m`0;09AkL`1cDTX0FT8i05Y2>@1S@S40Je9:06=:@P1[DTX0HdY206]BBP1SBT800P1J@ST01@1S@S40
DSTa058a:@0i:B40DS4Y0080DSTa00/0HdY205Y2>@1cBST0Nf=B07=:@P1cBST0U6=:0:f4J`36S7<0
gZF<0>NeW0020>o>]@050?Nm]@3ge[d0mmJm0?OFaP3ge[d00`3ge/H20?OF_@080?OFaP3ge[d0mmJm
0?OFaP3ge[d0mmK60?OF_@3ge/H20?OF_@80mkfe00<0mlje0?O6[@3_aZd00P3__JD00`3W]I`0ijfD
0>NeU0020>N]U0040>NeU03W[I`0ikFL0>N]U080ikFL00D0gZfD0>N]U03W]I@0ijF<0=jUS0040=j]
U0<0gZF<00<0eZF<0=JUQ03FYH`00P3FYH`00`3FW8@0aYb40=JUQ0020<jDN`070;F<L`2eNf<0[HA[
0:EcFP2<FTX0Q59207=:>@0206=2<@04058i<@1B<BT0@RTQ048Y8@@0>BTQ00h0@RTQ03TY8@0a8B40
8A0@034Q8@0Y61P08A0@01P@400Q4100<B4H058a:@1S>C40LdXi0;FUYAd0moOg803oool001h0oooo
00D0f=O@0>WXh03Yj>00i>?K0>;RfP080>7Qf@80hN7J0340h^?K0>CTg@3Ui]h0h>3H0<2k/`2VW9@0
L5eC05i7?01@=BH0D3DU054g9`1B?2l0Dclc05A2>01D@cT0Dd4h050o=@1:>Bl0AcD[044]900o:b40
@B/P04@^8P19<bD0BSDW04hj;@1A?c40G4Xk069??`1[DT00L58o07mF@@2;GDL0YgEL0;B4J@30TWL0
dJb?0=JeV@3M_j<0gl6V0>32Y`3P`ZP0h<:Y0>33ZP3P`jd0h<B^0>34[@3Pa:`0h<BZ00@0h<BY03`0
h<>Z0>33Z`3P`Z/0gl6Z0=o0Z03M_Z80g;bO0=^iW03I]9L0f;:F0=N_T`3G[I80eJR<0=BUR@3BWh<0
dIj10=2LO`3?W800cib20<nLQ03?WXD0cin40<nQQ03?XXD0d:640=2PQ03@W800ciYn0<bHO@3;V7d0
b9Um0<NHO@37Ug`0aiEj0<NDN@37TgP0aY=h0<>CM`31TWL0_i1e0;n>L`2oRW00_XQ^0;^6J`2hQFX0
[h9X0:V1IP2PNUl0VgEK091YD029HDX0Me4o06i:>P1N?S00EcT/050d9`11:Ql0>BDK02dN5P0Y71D2
02@K4`0802@J4P0T6A808QLC01lF4`0J4Q805a0@01<<300A2P/200h8200901L<2P0Q5100BSTc06MG
D02SUhl0^k:Z0=KBbP3Lf]80h=oG0080h^;K00<0h^;J0>7QfP3QhMX01@3QhMX80>7Qf@060>;Qf@3R
h]X0i^GM0>WXh03Ui=`0f=O@:P3oool<0?Ogm`0@0?O_k`3gmoL0moOg0?Ogm`3gknl0moOg0?O_k`3g
moL0YHAk07=JDP1cBST0HdY2058i<@1cFU80FT8i07=:>@<0HdY200D0DSTa06=:@P1J@ST0FT8i03TY
8@02048Y8@80Hd8a00l0Je9:05Y2>@1J@ST0Le9:07=:@P1cBST0S5Y:09a[DP2mQ6/0aYb40=j]U03_
aZd0klje0?OF_@3_c[D0103ge[d00`3ge/H0mmJm0?OF_@050?OF_@80mmK60`3ge[d20>o>]@040?O6
[@3_aZd0mlJ]0>o6[@80kkfU00<0ijfD0>NeW03W]I@00`3W[I@01@3W]I`0ikFD0>NUS03W[I@0gZfD
00<0ijfD00D0gZF<0=jeW03NYH`0gZF<0=j]U0030=jUS0030=JUS03NYH`0eYb<0080eZF<00@0eYb<
0<JLQ036W8@0cYAk0P36U7/01036S7<0[HA[09acH`2LJe8208ASDP0506=2<@1J<BT0DS4Y058a:@12
:B400P0a8AP00`0i:B40<B4H034Q600603TY8@<0:APH00H0<B4H03TY8@1S>C40FT8i09AcJ`3Wg^LM
0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X0203QhMT20>7QfP0a0>;Rf`3Si=`0
i>GN0>3Pf034_[H0[::I07YVG01WD4D0DSX]04lg:@1>>2X0D3``058n=01E@ST0ET<i05A0=P1A?S<0
BSL/04Lc:012;B<0@B/Q048/8014;B40B38U04Te:01=>Rl0Cchc05E4=`1HAST0GTLh0697>01`C3/0
O5=109U[D`2WNEl0]8M[0<VRQ03@[8h0f[ZL0=bmX03N`:<0gl6T0=o1Y@3O`JH0h<:Y0>32ZP3P`ZT0
h<:X0>32YP020>32Y@100=o1Y03N`:@0g/2T0=foYP3M`:L0g/2X0=o1Y`3N_j@0g[fQ0=bjW@3I/YH0
f:nC0=JYS@3EYh/0dj:60=:PP`3@W7l0ci]n0<fIO@3=VGh0cIV10<fJPP3=W8@0cIj40<jOQ03>X8@0
cin30<nMP@3>V7d0cIIk0<^EN@39UGX0aiIk0<NEN`37U7X0aY5h0<JAM`35TWL0a9=g0<:CMP31TWD0
_hmc0;j=L@2mRFh0_8M/0;N4J@2dPfP0ZWmT0:AlH@2HLUP0TV]B08ALA@1kDcl0Id@d05hn<01@=2L0
BC0S04</7`0f91P0<20F02HJ4`0T6A808QXC02@J5080:1/D01409ATD028G500J4Q405a0?018;2`0@
2@X040P90189200M3``0:QTD05]9@P1mKVH0`;Vb0=KCb`3Vi]h0iNGN0>?Sg0080>7QfPX0hN7I00H0
h^7I0>;RfP3ViMd0jNSP0>GTg03Hem0Z0?oooa@0moOg00H0U7]c08A[FP1cDTX0HdY205Y2>@1[DTX2
05Y2>@0307=BBP1SBT80LeYB00@0FT8i101B<BT03P1J<BT0LdXi06=:@P1B>C40FS4Y06]BBP1cBT80
Q59208aSDP2eQ6/0aXac0=JUQ03W]I`0kkfU0P3_c[D30?O>]@H0mmJm103ge/H01`3ge[d0klje0?Nm
]@3ge[d0klJ]0>o>]@3gaZd00`3__JD02P3W]I`0ikFD0>N]U03W]I@0ijfD0=jUS03N[I@0ijF<0=jU
S03WYH`20>NeU0030>N]U03N[I@0ijfD0080gZF<01@0gZfD0=jUS03NYH`0gZfD0=JUQ03NW8@0gZF<
0=JUS03NYH`0eZF<0=JLQ036W8@0eYb40<JLQ036U7/0aXac0;F<L`36S7<0W7=S0:EcFP80S6=B0P1c
BST206=2<@<0@RTQ00L0:APH034Q600a8B40<B4H034Q8@0i:B40<B4Q00D0>BTQ0P0Q41001@0a8AP0
@RTQ06=2<@1B>C40e[g601h0moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP090>7Q
f@0E0>7QfP3Rh]/0hnCL0>CUg@3Ph=P0aL2h0:nUW01nJf40JeE:05@m<@1@>Rd0CST/04lk<01A?S<0
ED4h05I2>@1E@3H0Dcdb04/f:P18<bL0@bhS0080@RdR01X0@bhR04Ha9@17=2P0BcX_04dl<P1A@3D0
DT4e05M2=@1K@cD0JDTj07E@?`2AITl0X7=I0:f1I033VW`0bjF60=NeUP3J^Y`0gKnQ0=foXP3M`:<0
g/2T0=o1Y`3P`JP0h<:W0>32YP80h<:U02@0h<6T0=o0X`3M_j80gKjR0=bnX`3L_Z@0gKnV0=k0YP3N
_j<0g[fQ0=biW@3I/9@0ejbA0=FVRP3DXhP0dZ230=6OP@3?W7h0cYYl0<bHO03;Ug`0biQo0<^IP@3;
Vh80bib30<bNP`3=WX<0cYf10<jLP03=Ug/0c9Ej0<ZDN039U7T0aiAj0<NCN@37TWT20<J@M`0^0<BA
M`33TWL0`I=e0<2BM02nSg40_Ha_0;^7K02jQV/0]H=Y0;:2I`2WOV<0XGYO09A^E02=ITh0OUE007A=
>P1Q?c00F3T[04T`8`13;1l0?BPL030P5@0[7A<08aPA024H4@0Q61<08aTD02PK500Y6a@09QTD028G
500J4Q405Pl?014:2P0@2@T040P80189200O40`0;1XE05i<A021LVX0a;jg0=[Hd03XjN80inOP0>CT
g@P0hN7J2P3QhMT01P3RhMT0h^;J0>KUg@3Yj>00iNCL0=SGd2X0oooo303gmoL00`3gknl0moOg0?Og
m`050?Ogm`040;FLW02<Lf/0Q6]J05Y2>@@0HdY200h0Je9:06=:@P1cFU80HdY206=2<@1[DTX0DSTa
05Y2>@12:B40DSTa05Y2>@1B>C40HdY207=JDP80FT8i00l0Le9:06]BBP1cBST0Q6=B0:EcFP2eNf<0
cYAk0=JUQ03W]I@0klJ]0>o>]@3_aZd0klje0?O>]@3_c[D0203ge[d0203_c[D0mmJm0?OF_@3_c[D0
mlJ]0>o>]@3gc[D0klJ]0`3__JD20>N]U00;0>NUS03W]I@0ijfD0>NUS03N[I@0ijfD0=j]U03WYH`0
gZF<0=j]U03WYH`00P3N[I@00`3WYH`0gZF<0=jUS0040=jUS00A0=jLS03NYH`0gZF<0=JUS03FW8@0
eZF40=JLS036W8@0cYAk0<JLQ036U7/0]Hac0;F4J`2]Q6/0YG=J09a[DP24DT800P1cBST00`1J<BT0
DS4Y048Y8@02048Y8@80<B4H00<0>BTQ034Q8@0a8B400`0i:B42034Q8@0902TH600Q4100610@01P@
400i:B40DSTa058a:@1cBST0g/kF01h0moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;R
fP0:0>7Qf@0K0>;Rf`3Shm`0i>CM0>3Pf037`[X0/ZVP08AdJ@1aGU<0F4@i058o=01??340CC/a04lm
<`1D@3H0ET4g05Lo=01E?C40CSLY04Xd9`15<BD0@S0V03l^9@0o;B@0@BlV04<a:018=bh0BST`0080
BcX`01T0CC/a050m<P1MA3L0J4Xk085KA@2?ID`0W75E0;B9JP2nU7@0cJR90=:_T@3H^9X0fKVL0=Zj
WP3K^il0g[jR0=noX`3O`:@0h<2T0>30X`3O`J<0gl2S0=joXP3K_J00f[bO0080fKZN04h0fkbP0=bm
X@3M_J40gK^N0=bgV`3H[I80eZR=0=:PQ@3AWX80d9eo0<nMOP3=W7`0c9Yk0<VFN@38UGT0b9Ik0<RG
O038V7h0b9Un0<VJO`3:VWl0cIYn0<fIO@3;UGX0bIAh0<NBM`36TWL0aY1g0<J?MP36SWH0aHaf0<>=
MP31SgD0_i1d0;jALP2mT740^ha]0;V9J`2ePfP0/h9W0:moI02[OV<0XWUN09]dFP2<IDd0PUa506m9
=P1V@C00E3HW04`b8`0m:1`0=R@I030P5P0V6Q408QP?01dE3P0K50l07ADA01lF4P0T61<09APC028G
4`0O5A805Pl?018<300>20P03PL70189200F2`T08a4<02lK5@1OBd<0P75X0<6l/`3GeLh0inSQ0>KW
h03TiMd70>7QfP/0hN7I00H0h^7I0>;RfP3ViMd0jNSP0>GTg03Hem0Z0?oooa@0moOg00H0e[g609Ac
J`2DNg<0LdXi06=2<@1J@ST406=:@P0407=JDP1kHeX0DSTa06=:@P<0DSTa00L0>BTQ058a:@1B>C40
FT8i07=:>@1[DTX0HdY20080Je9:00T0Le9:07]SDP2<FTX0YG=J0;F<L`3NYH`0gZfD0>NeW03W_JD0
103_aZd03`3ge[d0klje0>o>]@3ge[d0klje0?OFaP3_c[D0mkfe0>o>]@3gaZd0mlje0>o>]@3_aZd0
mlJ]0>o6[@020>nm[@040>nmY@3W]I`0ikFL0>N]U080ijF<00T0ijfD0=jUS03WYH`0gYb40=jUS03W
]I@0gZF<0=jLQ03W]I@00P3W[I@20=jUS0090=JUQ03NW8@0eYac0=JLQ03FYH@0eYb<0=JUS03FW8@0
eYb<0080eYb40P3>U7/20<JDN`060;F<L`2eQ6/0[HA[09a[DP2<He80Nf=B0P1cBST00`1S@S40DS4Y
058a:@02048Y8@03034Q600Y61P0:APH0080:APH0`0a8B42024@40D0610@00@0DS4Y058i<@1J@ST0
LdXi7`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00X0hN7I01/0h^;K0>?Sg03T
i=d0h>3H0<S3^P2cZj00QWIZ079PE01JAc/0E44f050n=01>?3<0Ccdd05<o=P1E@3H0ESld05@m<@1>
=bX0BSDX04@a9P11;bH0?RdU03d/900o;RD0@C0W04Lf;019>2h00P1:>C004`1;>S00CS`a05U1=01Q
ASH0N5@o08EMA@2BJ4h0ZX1Q0;F<K037X840cJR:0=FbU@3F]9L0f;JJ0=ZhV`3L^il0gKfP0=jnX@3O
_Z400P3N_j80103M_j80gKjQ0=ZlW`3I^ih20=RiW01>0=ZjW@3K^ih0g;^N0=biW03J]IT0ejb@0=BW
S03AWh<0cib00<jKO@3>Vg`0c9]k0<^INP38UGT0aiAh0<NDN@37U7X0aiIk0<NGO038V7`0bIQm0<^H
O03;Ug`0bYEi0<RCN036TGH0aI5f0<F?M@35SGD0a8ae0<>;M032Rg@0_hec0;f>LP2lSW00^hi^0;R:
J`2eQfT0/H5U0:ioI02YNf40YWYO09edF@2GL5D0Qf5907eG@@1XA380GS`[04da8`15;Al0=bDJ034Q
5`0/7Q@08aP@01lG3P0K50d06Q<>01/C400L4a408ADB028F4@0N51406a8@018=300?2PX030L700d7
1`0E2`X06Pd;02LC3@0c71D0GdY0081_I@30^[40e]C<0>KWh03Viml0i>CM1P3QhMX<0>7Qf@060>;Q
f@3Rh]X0i^GM0>WXh03Ui=`0f=O@:P3oool?0?Ogm`030?O_k`3gmoL0moOg0080moOg00H0imk_07]S
DP1kHe80LdY206=:@P1J@ST206]BBP0405Y2>@1[DTX0Le9:06]BBP<0FT8i00T0@RTQ058a:@1B>C40
@RTQ058i<@1SBT80FT8i06=:@P1kHe800P1B>C4206]BBP0:07]SDP2<He80W7=S0<J<L`3FYH@0gZfD
0=jeW03W]I`0ikfU0>o6[@80klje00<0mmJm0>o>]@3_c[D0103_c[D20?O>]@0:0>o>]@3_aZd0klJ]
0?O>]@3__JD0klJ]0>nm[@3W]I@0gZfD0=jUS080gYb40P3WYH`00`3NW8@0gZF<0=jLQ0020=jUS003
0=jLQ03NYH`0ijF<00D0gZF<00@0gYb40=JLQ03FW8@0eYb40P3FW7<01@3FW8@0aYb40<JLQ036W8@0
aYAk0080aXac0P2eNf<01@2ULeX0W6]B09a[DP24DT80LdXi00<0Hd8a0P12:B401P0i:B40<B4H034Q
8@0Y61P08A0@02TH60@0<B4Q00<0:APH01P@400H41000P0H41001`0Q4100:APH058a:@1B<BT0FS4Y
08ASDP3oool07P3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00X0hN7I00`0h^;J
0>?Sg03Ti=d0h>3I0<W4^`2e[J80R7U[07ITEP1NBcl0F4Dj05A2>01A?cH2058o=P0T05<o=@1B?S<0
DCdb04di;P1:=R`0@S0X03h]9P0j:R@0>RXS03d]900o;bH0A3@Z04Lf;@1;>S40C3/b04dk<01>>Rl0
DSX/05Hl;01UAC80L4dh07aG@02EKe@0XGYN0;J>LP2nUWT0bJ640<fTR03BZXh0e:fA0=RcUP3I]IP0
fkNJ0=^gV`3K^I`0fkVM0P3J^ih04`3H^Yh0f;VM0=NgVP3G]YT0f;FI0=VeV@3I]IP0f;>G0=NaU@3C
ZHh0d:B90<bKO`3:Ug`0bIEh0<REN038UGL0aiAg0<JBMP36TGD00P36Sg@0>P36T7D0aY9f0<NCN037
U7P0b9Ah0<RCN037TWL0aY9f0<B@M033SW<0`Xab0<6;L@31RW40`8U`0;j8K`2kQfd0^HM/0;J7JP2e
QVT0/8AW0:f2I@2VNf00XWQM09aaEP2IKE<0TVM=08eSBP1lESl0LDdg05Tj:@1?<b<0?RPK03PT6@0]
7aD0:AdD02DK4P0O5`l07AH=01TB300H4@`05`l=01L?3P0I3`h060l=01@=300@30X02@L700L61P08
1PH03PT801hA3P0W5Q40=QdD040V6`1XD4D0QW=X0<6k/P3Fdl/20>GVg`030>?Tg03QhMX0hN7J0080
hN7J3P3QhMT01P3RhMT0h^;J0>KUg@3Yj>00iNCL0=SGd2X0oooo2`3gmoL00`3gknl0moOg0?Ogm`07
0?Ogm`0509AcJ`24He80Le9:06]BBP1SBT800P1[DTX02@1J@ST0HdY206]BBP1cFU80Je9:058i<@1S
BT80DSTa048Y8@02058a:@030592>@1J@ST0FT8i0080Je9:00/0Nf=B05Y2>@1J@ST0HdY207=BBP1[
DTX0Q6=B0:EcFP2LLf<0_HA[0=JUQ0020=JUS0030=j]U03N]I`0ikfU00<0klJ]00D0klje0>o6[@3_
aZd0mlJ]0>o>]@030>o6[@<0kkfU00D0ikfU0>neY@3N[I@0eYb<0=j]U0040=jUS0030=jLQ03FYH@0
eZF400<0gYb400H0gZfD0=jUS03NW8@0gZF<0=JUQ03FW7<20=jLQ080eYb400/0eXak0<jDN`3>U7/0
cYAk0<jDL`3>U7/0aYAk0<J<L`2eS7<0_HA[0:f4J`020:EcFP0509a[DP24He80Nf=B07=:>@1S@S40
0P1J<BT2048Y8@80>BTQ0`0a8AP402TH6003034Q8@0Q4100610@00<0610@00H0<B4H03TY8@12:B40
DSTa05Y2>@3F_LHO0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X02P3QhMT03`3R
h]X0hn?L0>CTg@3Qh=T0blJm0;N_Y02<OG00NVQK065>@P1KAcd0ET<j05=1=`1C@3L0DT0f054o=@02
050m<`0W04hk<@1;>2l0@S0Y03h/9P0j:B<0>RTR03d/9010;RD0A3@Z04Lg;@1<>c80CSdc04ll<@1>
>bh0D3PY058h:@1M?bd0IDHc071?>P29ITh0UG9H0:Z4J@2bRg00_iEj0<BIOP3<XHD0d:F90=F]T03G
/9<0f;:F0=RcUP3H]9P0f;FI0=RhW03H^9d0ekRL0=NgW03F]IT0e[BG0080ek>F00L0ek:F0=JaU@3E
[Y<0d:N<0<fRQ`38V7`0aYAh00@0a91d0P35Sg<20<F=LP030<F>L`35Sg@0aY5f0080aY5f02<0aY5e
0<J@M@36T7D0a8mc0<:=LP30Rfl0`8Y_0;n9K`2nR6h0_8M]0;V5JP2gQ6T0]8=W0;:3I`2/PFD0ZGmS
0:5iGP2MM5X0UF]A095WC@2;H4H0QUa307E?>@1ZAc80DSHV04P_800h91T0<R0F02TL500V6a<08aXB
01hG3`0L5@d0614<01L@2`0301D=300B01@<2`0?2PT02`P800D51@0410@020H500h9200R5100;AXD
040V701<<BD0Lea@08mmLP35_kH0emG=0>GVgP3UiMh0hnCL103QhMX>0>7Qf@060>;Qf@3Rh]X0i^GM
0>WXh03Ui=`0f=O@:P3oool00`3gmoL0mno_0?Ogm`0A0?Ogm`0@0?ooo`2DQ8@0Q6]J07=BBP1[DTX0
HdY206]BBP1cDTX0HdY206=2<@1SBT80LeYB06=:@P1J@ST0HdY2058i<@80@RTQ00P0<B4Q058a:@1:
<C40FT8i06=:@P1[DTX0Le9:07]SDP80DS4Y00/0LdY207=BBP1cBT80S5Y:09ASBP2eNf<0]Hac0<J<
L`3>U7/0aYb40=JUS0020=jeY@0;0=jeW03_aZd0klJ]0>o6[@3__JD0e/Je0>NmY@3_aZd0klje0>o6
[@3W]I@00P3__JD20>NmY@80gZfD00L0aYb40=JLQ03NW8@0eYb40=jUS03FW8@0eYac0080eYb4103N
W8@01P3NW8`0gZF<0=jLQ03FW8@0eYac0=JLQ080eYac00H0cYAk0=J<N`3FS7/0cYAk0<J<L`3>U7/2
0<J<L`080;f4J`2eQ6/0YG=J0:EcFP2LJe80S5Y:08AB@P1cBST206=2<@0805Xa8@12:B40<B4H03TY
8@0a8AP0<B4Q02TH600Q410302TH600401P@400Y61P08A0@024@40@0610@00D0<B4Q058a:@1B>C40
DSTa09AcJ`0P0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X02P3QhMT06`3Rh]X0
h^?K0>?Tg03QhMT0d<c40<6j/P2MSXH0RgU`06eHC`1RCD@0FdHm05E1>01D@CL0DT0f050n=@1??S@0
D3le054o=P1@?C@0B3D/04@`9`0n:B00?BPO03l[8P11;RD0AcH]04Xi<00204dl<P0A04hl<@1>>bl0
CSP[04df:@1?=RT0E3//05a2<P1bEd<0O61;08e^EP2DLUX0XgYQ0:YoI@2iRW00`95f0<^OP`3>XhL0
0P3@YhX07@3?Z8`0d:Z?0=6^U@3A[iL0dK2G0=6_U`3A[I<0dJfB0=:/T03C[I00djb@0=:[S`3@Z8`0
bIn40<BJOP2kSG80^8Q]0;F3J02fPfP0^HAX0;^5J02nQVT0`8MZ0<:8K032RFh0`h]a0<><LP33S740
`h]`0080`XQ^02P0`hY_0<><L032S6l0`Ha]0;n:JP2nRFT0_HQY0;Z5J@2hPfP0]H1U0;=nH`2_O640
[7]P0:IjG`2RNEh0VG=I09A]E029H4P0Q5U307]?>@1fBcD0IT0]05`j:017;B00?bPL034O5P0/71@0
9ATA028H400O5`l06a@=01TB300F3`/05@h;01<;2P0B2PX040P900h720091@D01P@40P0310@03P0:
1`H040X802@F4@0c8AX0Ed4f06aFB`2IQg`0[Z6G0=7<a03Lf]80hnCM0>?Tg03Rhm/0hN7J4@3QhMT0
1P3RhMT0h^;J0>KUg@3Yj>00iNCL0=SGd2X0oooo5@3gmoL0103>_LH0U7=[07]SFP1cDTX206=:@P03
06]BBP1SBT80HdY20080HdY200P0LeYB06=:@P1J@ST0Hd8a058a:@0i:B40DS4Y03TY8@80Je9:0P1J
@ST206]BBP0608A[FP1cDTX0DSTa06=2<@1cBT80Nf=B0`24He801@2]Nf/0[G=J0;F<L`36U7/0gZfD
00<0eZF<00D0gZfD0=JUQ03N[I@0gZfD0=jeY@020>NeW0040=jeW03N[I@0ikfU0>NeW080gZfD01H0
aYb40<jDL`2eQ6/0]G]S0;f4H`2mQ6/0cYAc0<J<L`3>U7<0eXak0=JLQ03FS7/0eYac0=JLQ03>U7<0
cXa[0=JLL`3FS7/0eYb40=JLL`3FS7/0eYac0`3>U7/20<J<L`080<JDN`36S7<0_HA[0;F4J`2eNf<0
[HA[09a[DP2<FTX208AB@P0907=2<@1cBST0DSTa058a:@12:B40@R4H034Q8@0Q4100<B4H00H0:APH
00<0<B4Q02TH600Q4100100H41001`0Y61P0DSTa048Y8@1B<BT0@RTQ0>oWi`3oool07`3gmoLP0?oo
o`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00X0hN7I00h0h^;J0>;Rf`3Shm/0hN7I0=C@b@38
`K/0Z9ZD09J5O`1dGeL0Ie5805i8?P1E@CL0E40f054o=@80D3he01h0DD0f05=1>01B@3H0C3P]04Pb
:010:R00?RPO040[8P13;RD0BCL^04`j<@1<?380C3/a04dk<01>>c00CSX^04`g;01:=BT0CCP[05@n
<01WD3h0L5Q507iRC@24IU00TfaF09]aF@2^OV@0]XI/0<BFNP38Vh020<VOP`0M0<RPQ@38XXP0bZN?
0<^XT@3;ZI80bjVA0<bWSP3<Yhd0cJR<0<jXS03?Z8d0cZN;0<bTR034VWh0_Y=h0;>6J`2_PFH0[7]Q
0:ekH02aO600]7iQ0;V0HP2kPV@0_XEY0;n7J`30RFl0`HY_0<69KP30Qf`00P30Q6T0=030Qf`0`8Q]
0;n:K02oRVT0_HQV0;b7IP2kQFH0^89V0;J1IP2bOF<0/7]Q0:aiGP2YN5d0XgML09mfF`2EKeH0T6UA
08=JA01mDch0LdPd06e3;`1N>BL0EC<T04<Y7@0k9AX0;ahE02/K4`0S610081L?01dE3P0I4P`05a0;
01D=2`0D30/04PX:01492@0>1`L030H600L4100510@00`@400D51@0<1`L04PX802@F4@0d8a`0HTm5
07eZH02^X9H0`;J]0=SDc03NgMD20>;Sf`030>;Rf`3QhMX0hN7I0100hN7I00H0h^7I0>;RfP3ViMd0
jNSP0>GTg03Hem0Z0?oooaD0moOg00H0e/kN09AkL`1kHe80Le9:06=:@P1J@ST306]BBP0;06=:@P1S
BTX0LeYB06=:@P1J@ST0DT8i058a:@0i:B40@RTQ058a:@1B>C400P1[DTX03P1SBT80Je9:06]BBP1[
DTX0Le9:06]BBP1SBT80Hd8a07=:@P1cDTX0Q6=B09AJDP2eNf<0W7=S0P2eS7<07`2mW8`0aYAk0<JD
N`3N[I@0eZF40<JLQ02mW8`0aYb40=j]U03FYH@0gZfD0=jeW03FYH`0ikFL0=jeW03N[I@0eYb<0<JD
N`2]Nf/0]HA[0;EkH`2eQ6/0_HA[0;f4H`2mQ6/0cXac0<jDL`3>U7/0eXac0<jDL`3>U7/00P3>S7<0
1`3>U7<0cYAk0<jDN`3FS7/0eYac0<jDN`3>S7<00P36S7<01P3>S6/0_HA[0<J<L`36S7<0_HA[0;F4
J`80W7=S0P2<FTX01024DT80Q58i07=:>@1S@S42058a:@80@RTQ00@0@Q0@034Q600a8AP0<B4H0`0Y
61P00`0Q4100:APH02TH6002024@40<0610@00<0:APH03TY8@1B<BT00P12:B400`1B>C40mno_0?Og
m`0O0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X02P3QhMT0C@3RhMX0h^;J0>;R
fP3QhMX0fmWC0=GAc02n/k00[9jJ08=`I`1aFe40Hde105@o=01A?S<0CSdc04hl<`1??S@0DD0f05A2
>01D@CL0CS/^04Xf:@12;240?bTO03lZ8@13;BD0BcL]04dj;`1<>Rl0BcT_04`k<@1??C@0DCle04hm
<`19=bh0BCL]04`j;`1GACL0GDXk06I@@01ZDT80N5Q5085LB02EJE40Wg5H0:j0IP2cQV/0]8Y`0;>:
L@2aRgD0/Heh0;>AO@2eTgh0^9An0;VDOP2lUWd0_IMm0<2JO`31W800`I^00;nIOP2lU7X0/XU_0:f2
J@2QMU`0WG5G09Y/DP2JJe40WfeA0:=_D@2ZLe@0[WIF0;=kGP2eOV40^85V0;R2IP2jPFD0^X1S0080
_7eQ03@0^h1T0;Z1I@2gPV<0]X5P0;AnG02cOE`0/WaL0;1jGP2_NEh0[7IL0:YeF`2TLUT0XG5H09Y^
E@2FK5@0S6A=08ENB01hCS/0LDLd06@j:@1M=BD0Cb`O04PX700j8QT0=1lG02/K4`0W6A4081D>01`C
300I4@/05@d:01<<2@0@2PT040T900h8200=1`L02PD500P410040`<00`<300D51@091`H04P/901H<
2@0V5a40=bLP079TG02ERH40c<Jn0=[FcP3Rh=T0h^7J0`3QhMXB0>7Qf@060>;Qf@3Rh]X0i^GM0>WX
h03Ui=`0f=O@:P3ooolF0?Ogm`060=K6gP2<Lf<0Nf=B07=BBP1S@S40HdY20P1[DTX01P1SBT80FT8i
06=:@P1cFU80HdY204Xa<@80DSTa00<0>BTQ048Y8@1B@ST00P1J@ST0101B>C40LeYB07=JDP1cDTX2
06=:@P0<07=JDP1[DTX0LeYB07]SDP1kHeX0Q6=B08aJBP24He80YG=J0:f4J`2DLf/0W7=S0`2]Q6/0
2`2eNf<0W7=S0:f4J`2LLf<0]HA[0<J<L`36U7/0_Ib<0<JDN`36W8@0_HA[0080W7=S0P2LJe801P2U
LeX0S7=S0:EcFP2LJe80YG=J0;EcFP80_HAS00<0aXaS0;f4J`36S6<0103>S6/00`2mQ6/0_HAS0;f4
J`050;f4J`030;EkH`2eLeX0]HA[0080YG=J00@0W6]B0:EcFP1kHe80Q58i0P1S@S402@1J<BT0DS4Y
058a:@12:B40DS4Y03TY8@0a8AP0:APH034Q600202TH60808A0@200H4102058a:@0404Xa<@12:B40
Le9:0;FLW240moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP0:0>7Qf@0=0>7QfP3R
h]X0h^;J0>7QfP3NgML0f]OB0<No^`2fZZD0RWQ_07IREP1UD4@0Dclc04ll<@0204`k<@1704lm=01A
?cD0Dd4g0590=@1<>Rh0B3HY040]8P0m:R40?RTR048/901:=BX0CCP]04`i;P1;>Bl0CS`c050o=P1C
@CP0DD0g04`k<@1;>S00C3/`05=2=@1GACP0GT/m069=?P1_DT80N5I408YQB`2CIe00XGAK0:EiH02V
OFH0YGiX0:9oK02RPFh0XhAa0:F5L@2ZQW00[HM`0;6:L@2cSG<0]Y5f0;RCM`2gTWL0]Hmd0;6:L@2W
OfH0XWUP09Q^E@2EJU00TVE;099TB@2FIDT0VFM:0:5]C@2UKe00[7AG0:ifFP2aNUh0/WaO0;EmG`2f
O5h0^G]M0;UkGP2gO600]GeQ0;5lGP2_NU/0[GMF0:afEP2/MEH00P2[LeP0:`2XLUP0YW5H09m^EP2K
KED0TfQB08mUC`25GDL0OeI20758=@1Z@Bl0GC@U05H_8@19:1`0@RDJ03HO5`0`7AD0:1TA02@G400M
50d06Q8<01L?2P0C2`T04@X800h81`0=1`L02`L700X61P0810@01P<400<20`030`<01PH500/91`0E
3PX06Pl:02TJ4`0k:R80MfYR09^AR@3CclL0h=gF0>CTg03Shm/00`3QhMXB0>7Qf@060>;Qf@3Rh]X0
i^GM0>WXh03Ui=`0f=O@:P3ooolF0?Ogm`060?O_k`2DLf/0Q6]J07=JDP1SBT80FT8i0P1[DTX02`1J
@ST0HdY206=:@P1kHeX0Je9:0592>@1B<BT0DSTa03TY8@1B<BT0Hd8a0080FT8i00<0HdY206]BBP1k
HeX00P1cFU802@1[DTX0HdY207]SFP1SBT80LeYB07]SFP1cFU80Nf=B08ASDP0209acH`0?09a[DP2U
LeX0W7=S09AcJ`2ULeX0S7=S0:EcFP2LLf<0YG=J09acH`2]Q6/0]Hac0=JUQ036U8@0]Hac0080[HA[
0`2LJe801P24DT80S5Y:09ASBP2<He80U6=:0:ecFP80]G=J00@0_HAS0;EkH`2mQ6<0_HAS0P2mQ6/0
1@2mQ6<0_HA[0;f4J`2eNf<0[G=J0080]G]S00`0]G=J0;F4J`2eNf<0]G]S0:ecFP2LLf<0YG=J08aS
DP2<FTX0Q59208AB>@1S@S4205Xa:@D0@RTQ0P0a8AP302TH60808A0@1`0H41000`0Q4100DS4Y03TY
8@02048Y8@0309AcJ`3_e/h0moOg0200moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;R
fP0;0>7Qf@1d0>7QfP3Rh]X0h^;J0>7PfP3NgML0c/W30;je[P2APGL0NfUL06UEA`1C?c<0CS/`04/i
;`1;>S00CS`c050n=01A?cD0D3hd04Tj;P15=RX0?BdT03/Z8P0l:280@2/S04Pc9`1;=RX0C3T]04`j
;`1??SD0DT4h05E4>`1D@cX0D3lf04hm=01>?C<0DD0e05=2=`1IAc/0GTXm06U?@01aDd80PE]608UP
B@2DJE40UfeD09QaF`2FLUh0TW=R095dH`2BMV@0U7IS09]gH@2ON640YGiU0:R1I`2/Qf`0[HQ]0:b7
K02YQ6X0Y7mW09YdGP2FKeP0SfI>08eSBP2:GTD0REe308aN@`2@H4<0V6I709aXB@2SK4l0YViB0:Yb
EP2[MEP0[gQI0;5hF@2eNET0]GUJ0;9hG02_N5`0ZWEH0:McE@2TKe00Y6i@0:A]D02UKE40YFeB0:=]
E02PKE@0VFYC09AXDP2;HTh0Qem:07iE@@1hCc/0Jd4`06@k:P1G<280D2/O04<T6P0m8QP0<AdE02`K
4`0T60l08AH>01/B300H40/05@h:014:200?20L030H600X61P081@D01`D500D410040`<200<30`0=
00P71P0=2`P0614<01dB300^7AH0@2hV07a_I`2PUXh0e]?<0>;QfP3UiMh0hn?L0>7QfP0D0>7Qf@06
0>;Qf@3Rh]X0i^GM0>WXh03Ui=`0f=O@:P3ooolG0?Ogm`0309AkL`2<Lf<0Le9:0080HdY200T0Je9:
07=BBP1SBT80He9:05Y2>@1cFU80HdY205Y2>@0i:B400`1B<BT01P1B>C40HdY206=BBP1J@ST0LeYB
06=BBP<0Je9:00d0Le9:06]BBP1kHeX0LeYB07]SFP24JeX0Q6=B08A[FP2<Lf<0Q6]J09a[DP24JeX0
S7=S0080YG=J00<0W6]B08acH`2ULeX00P2ULeX0102]Q6/0YG=J0;F<L`36W8@409acH`0>08A[FP2<
He80S6=B08AB@P24He80S6=B08AB@P2]LeX0YG=J0:e[DP2]LeX0]G=J0;EkH`2mQ6<40;f4J`030;F4
J`2eNf<0[G=J0080YG=J0P2]LeX209acH`80YG=J00<0W6]B08aJ@P24DT80101S@S400`1B<BT0FS4Q
048Y8@03048Y8@06034Q8@0Y61P0:APH034Q8@0a8AP0610@0P0Q410601P@400602TH6012:B40@RTQ
03TY8@12:B40]JFU8P3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00`0hN7I01d0
hN7J0>;RfP3Si=`0hn?L0=SEcP39a;`0WY:708MhK01bHED0ET@i04lm<P1:>2l0BcT`04hm<`1??S@0
CShd04`m<`16>Bl0@SH/03X]9P0f:B<0=RHP03TW8013;b<0B3<V04hj;P1@?C80E48i05I5?00205Y8
?`1S05U7?@1GAS`0ET@k05A3>@1EA3X0FTPm05e;?`1VD480Je=307AF@`1hF4<0OEY407iKA@1mG4/0
Nee=07MLC`1eG4h0ME]:07MKB@1oFdL0Pee708aTC@2@J500UFmG09IaF02DL5P0T6eF08]YE021Gdd0
OU]:07]F@`1kED00NU8l07]A>P1mDSP0Oe@i08IH>`29FC`0Se]0099M@P2HHTL0VfI:0:5]CP2TKdl0
Z75A0:Q`D@2SKU40X6a@09YXC@2GIT/0UF5709APA@2DGd@0UEm509IPA`2DHdX0TV=;08]PB`26GDX0
OEI307QA?`1_ASD0JD4`05`f9P1F<B<0C2XN04HW7@0k8QT0=AlG02XJ4P0U60l07QD<01/C2`0G3`X0
5@d:01<;2@0?1`L03@H600T410070`<00`<300830`010`<00P<300D510081PD03P/801<>2`0N5Q00
9QXC03h[8`1B?SD0Rgac0:ZOU`3He/h0h^;J0>GVgP3Shm`0hN7J01@0hN7I00H0h^7I0>;RfP3ViMd0
jNSP0>GTg03Hem0Z0?oooaL0moOg00@0aZfm0:F4N`1kHeX0Je9:101SBT801P1J@ST0HdY206=:@P1[
DTX0FT8i04Xa<@80DS4Y00@0FT8i058i<@1SBT80Je9:0P1cFU801@1[DTX0Nf=J07]SFP1JDU80He9:
00<0Nf=J00H0S7=[07]SFP24He80Q6]J07=BBP24JeX208ASDP<0Nf=B00X0S6=B08AB@P24He80Q6=B
08aJ@P2<He80U6=:08aSDP2LJe80YG=J0P2<He800`24He80S6=B07=:@P0207]SDP0508AB@P1cBT80
S5Y:08AB@P2<FT800P2DHdX0102UJe80YF=:0:e[DP2]LeX20:EcDP040:EcFP2LJe80W6]B0:EcFPH0
W6]B00@0S5Y:09a[DP2<FT80Q5920P1cBST01@1S@S40FS4Y05Xa8@1B<BT0@RTQ0080<B4H00@0>BTQ
034Q600Y61P0:APH0P0Q41000`0Y61P0610@01P@400601P@4007034Q8@1B<BT0DSTa048Y8@1B<BT0
FS4Y0?O_k`0R0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X03@3QhMT07@3Rh]X0
i>CM0>CTg@3Jf=40c<W10:BJT@2=P7L0NFUP05Y9?`1A@3H0BcT_04/j<01??C@0Ccle04ho=@1<?S@0
AcX`04<g;P0j;RH0=BTR038T7P0f9Qh0@BhS04Lc9P1?>c00DSld05M5>`1IAcd0FdU00080G4Y00640
FdY005Y8?`1HAcd0FDLm05e;@01PCT80Ie=406YDA01`ET<0LUI307AF@@1dET80LUE5071DA`1]DdH0
Je9506]@@01]Cch0Le0m07MA?P1oEd<0Pe]608USC02;IDh0RFE?08ERCP20Gd`0MUI607=CA01aCcl0
LDhm07=<>@1dC3L0Md`e07U>=01mDCD0P58f08AC>P27E3`0SE]1095OA02HIdP0VfU:09i[C02NJT`0
VFM;09MUBP2BHTL0T61608iM@`2=Fd40SEY008aI@02<FT40Ree508UMA`23FTH0OeM407I??@1bBcT0
Id4`064k:`1E<B<0CbdP04HX7@129Q`0>24I034N5P0V6A008QL>01`D2`0J4PX05Pl:01@=2P0B2`T0
3`L700d51@080`<01P<300820`010P800@<200830`091`D03@T701<>2P0G40`08ALB02XN5`19=Bd0
GdY109J6O@2bYih0fMO?0>;RfP3TiMd0hn?L01D0hN7I00H0h^7I0>;RfP3ViMd0jNSP0>GTg03Hem0Z
0?oooaL0moOg00@0imkW0:fLY@24JeX0Le9:101SBT802@1J@ST0He9:06=:@P1cFU80HdY2058i<@12
:B40DT8i058i<@0205Y2>@0;06]BBP1cFU80LeYB07]SFP1[DTX0LeYB07]SFP1cFU80HdY207]SFP2<
Lf<00P24JeX01`2<He80S7=S08ASDP24JeX0Nf=B08AB@P1cBT800P1cDTX01`2<Lf<0Q6=B07]SDP1c
BT80Nf=B08ASDP24DT800`24He801024JeX0Nf=B07]SDP1kHe8307=BBP0808AB@P1cBT80Hd8a08AB
@P24DST0Q59208ASDP2<FT8209a[DP0409ASBP2LJe80W6]B09ASBP80S5Y:00H0W6]B08aJ@P24He80
S5Y209ASBP2<He8208aJBP80Q5920P1cBST205Xa:@0405Xa8@1B<BT0DSTa048Y8@80<B4H00<0<B4Q
034Q600Q41000`0Y61P00`0H41008A0@01P@400501P@4005024@4012:B40DS4Y048Y8@0a8B400P1S
>C4S0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X03@3QhMT0703Rh]X0hnCL0>CT
g03Lfm@0d/o90;:YYP2NTi00RWai06IEC`1JB400CS`b04hk<@1@?cD0D40f04i0=`1=@3H0Bc`c04Pi
<00m;bL0=bXR034U7@0c9ah0?blU04He:`1B@3D0ET@j05]9?`1LBT0205i<@P80H4i402h0Gdi405m=
@`1OCT<0He1306EB@`1YE4@0JeE406aE@`1/E480JE8o06M@?P1SBcd0HDPl05e4>01L@SD0G3la05`o
<01O?c40HD0b06M3=01[ACD0LD/i07=>?01cDT00LE5006a>?`1SB3`0H4Hk05i3>01O@cL0Hd8d06E1
<P1Y@Bh0JT8]06]2:`1/@R`0KD<^06m4<01fBSH0Ndlh089F?@24FCh0QUXo08EI?`22ESd0P5Dl0P1o
EC`0<01oDcX0OE4h07]>=P1gBcD0MT`f07E>>P1dCS/0LDXi06i7=P1W@C40Hch^05Tg:01C<R@0ARTN
044V700k91/0>2@K030P600Z71@07aD=01`C2`0I4PX0614:01H>2P0D30X04PX900h61`0<1@D01`<3
00D20P020P<00@<300<410071PH04P`:01P@300O4`h07a@?02TM6@0f:B@0I55907mZHP2`XIL0`kV`
0=cJdP3QhMX0hnCL0>;RfaD0hN7I00H0h^7I0>;RfP3ViMd0jNSP0>GTg03Hem0Z0?oooaL0moOg00D0
mno_0=kFi`2]U9@0LeYB07=BBP0206=:@P80Je9:00/0FT8i06=BBP1SBT80LeYB06=:@P1J@ST0@RTQ
058i<@1[DTX0He9:07=JDP0207]SFP0307=JDP1cDTX0Q6]J0080LeYB0140HdY207=BBP1cFU80Nf=B
08ASDP24JeX0Le9:08aSDP1kHe80Q59207=BBP1cBST0FT8i07=BBP1[DTX0LdXi06=:@P0207=BBP09
06<i:@1cDTX0LdXi07=:@P1kHe80LdXi06=2<@1cBT80LeYB0080HdY200D0FT8i06=2<@1J@ST0LdXi
06<i:@0406=2<@0307=:>@1c@S40LdXi00H0LdXi101S@S400`1S>BT0Hd8a06=2<@0206=2<@09058i
<@1S>BT0FS4Q048Y8@1:8AP0@RTQ03TY8@12:B40<B4H0080:APH00<0<B4H034Q8@0a8B400`0Y61P0
0`0H41008A0@01P@400301P@4008034Q8@12:B40@RTQ058i<@1B<BT0DSTa07=:>@3>]KDS0?Ogmb00
oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X03@3QhMT0703Rh]X0hn?K0>?Sf`3Mg=D0eM;=
0;Zb/02XWI`0U8J506eLE`1OC4D0D3`c04lk<@1@?cD0D40f04i0=`1>@3H0C3dd04Xj<@10<BT0>RdT
03@X800f:R40@C8X04Pg;P1D@SP0F4Hl05e;@@1NC48205m=@`80H4i40280Gdi405m>@`1PCT<0Hdm2
06E@@P1YDT80Je9206]B@01ZDSl0IThl06=<>`1NAcT0Fd@h05Lo<`1F?300ECT/05Di:`1G>Bh0F3X_
05dk;`1P?2l0ID4b06M4=01YBCX0IdXk06A8>`1L@cT0FD4g05Lo=@1G?S@0FS``05`l;P1P>bX0HC/Y
0P1Q>bP02@1Q>bT0Hc`[06U1;`1]AC80MD`f07M>=`1hD3P0Me0g07E>=P0207A==@0a07E>=P1dC3D0
LdXc0717<@1/@bl0Jd<`06U4<`1YA3@0IT4a06@n;`1N>R/0FcPY058b901;;R40?bHL03XS6P0d8QT0
<R8I02/N5P0V6Q<071<<01TA2P0G40T05a0:01D>2P0D30X04PX900h71`0;1@D01P<300@20P020`<0
0`<400L61`0;2@T0610=01hC3`0S5Q0091HA02lR7@0o<B`0Lf9J08mnM@2m/:L0c<Bk0=kLe03QhMX0
hn?K0>;Rf`0E0>7Qf@060>;Qf@3Rh]X0i^GM0>WXh03Ui=`0f=O@:P3ooolH0?Ogm`060>oWi`2]U9@0
Nf=J07=BBP1[DTX0HdY20P1[DTX0101J@ST0HdY206=:@P1cFU8206=:@P050592>@1B>C40LeYB07]S
FP1cFU800`1kHeX0301cFU80Je9:07]SFP1kHeX0LeYB06=:@P1cBT80Le9:07]SDP24JeX0Je9:07]S
DP80Je9:00<0LdXi06=:@P1S@S400P1SBT80301J@ST0Hd8a06]BBP1cDTX0FT8i07=:>@1[DTX0Hd8a
07=:@P1cDTX0HdY2058i<@80HdY200X0FT8i058a:@1B>C40FS4Y058i<@1B<BT0FS4Y06=2<@1J<BT0
LdXi0P1S@S401@1J<BT0Hd8a06=2<@1S@S40FT8i00<0Hd8a00@0HcTY06=2<@1J<BT0Hd8a0P1J<BT2
06=2<@0305Xa:@1B<BT0@RTQ00D0@RTQ0`0Y61P0100a8B40<B4H048H400Y61P3024@400=01P@400Q
4100610@01P@400Y61P0@RTQ03TY8@1:<C40@RTQ058a:@1J<BT0[HAk0?O_k`0S0?Ogmb00oooo000N
0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X03@3QhMT03@3QhMX0h^;J0>;RfP3Og]P0fmWD0<[4``2l
/k<0ZIfM07i/I`1[ETl0E3le050l<P1??C<00P1>?S@0<`1=?S@0CC`c04`k<@17=Rd0A3@[044c:@13
=2/0BSX`04hm=01GAC/0FTPn05i<@P1PCT<0H4i405m=@`1LBd40FdY005Y9?`1KBCl0G4Tn05m8?01Q
B3`0ITPj06Q9>P1ZBST0J4Tg0695=01N@c<0Ed0b05@n<P1=>2h0BcD[04Pb9`19<RL0C3@[04de;01=
<RT0CC4W04lb9`1A=BX0EC`a05Dn<`1D?S@0DC`c04hk<P1;=bl0BSH]04Xa:01:;bD0BbdR04/]8@02
04X^8@0l04X]8@1;;B40CbhR058`8`1H=BH0FSPW05`l:@1M?BT0G3dY05`m:01M?BT0GChY05`l:01J
>BL0F3HU05@a8`1C<2<0DS0T054`901?;b<0CRhR04//8019:al0@RPM03dU6`0a81L0;AhE02LL4`0U
6Q8081L?01dD3P0G3`/05@d:01@=2@0D3@X050`:01<;2P0A2PT030H600P51@030P800P8200@41008
1PL04``?01T@4P0S5A@09aPD02`K500_7aL0A3D]05U;A02CQh00[jFM0=?=a03Kell0hN3H0>7QfP3R
h]X0hN7J5@3QhMT01P3RhMT0h^7J0>KUg@3Yj>00iNCL0=SGd2X0oooo603gmoL0303gknl0e/KF09Ak
L`1kHeX0Je9:06=:@P1J@ST0HdY206=:BP1J@ST0He9:06=:@P80Je9:0P1SBT802`1B@ST0Le9:07]S
FP1kHeX0LeYB07]SFP2<Lf/0Nf=J06]BBP1SBT80Je9:0080Le9:00P0LdY207]SDP1cDTX0LdY206=:
@P1cBST0Q59206]BBP80HdY20100FT8i06=:@P1SBT80DS4Y06=:@P1[DTX0HdY205Y2>@1[DTX0LdXi
06=:@P1cDTX0FT8i058i<@1S@S40BS4a0`1B>C45058a:@07048Y8@1B<BT0FS4Q06=:@P1J<BT0DS4Y
06=2<@03058a:@0405Xa:@1B>C40DS4Y058a:@80FS4Y0P1B<BT02`1J<B40DS4Y058a:@1B<BT0@RTQ
04XQ600i:B40<B4H03TY8@0a8AP0<B4Q00808A0@00<0:APH024@400Y61P00P0Y61P00`0Q4100610@
01P@400201P@4004024@400i:B40>BTQ058a:@80>BTQ00<0Le9:07=:@P3oool0903gmoLP0?ooo`00
7P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J00h0hN7I0P3Rh]X02P3Ph=T0g]cG0=;<b`35_K`0]:RW
08MfL@1cGUL0F4<i058n=01>?3<304dl<`0304dl<P1<>c80BST_0080B3P^00H0BST`04ln=@1B@CL0
EdDl05U7?P1MBd4205m=@`0S05i<@P1IB3h0F4Hl05M5?01GAC/0FDDk05a5>P1OA3T0I4Dh06I5=`1X
ASH0ITDd0611<@1L@300ECd`054k<01:=bd0Ac@Z04@`9`15<BL0BC@[04Xe;018<2P0ARdU04H]9018
<2H0C3L]04hj<01>>S40C3T_04Xg;P17=2/0AC8Y04</8`12:R400P109ad02@10:Ah0?bTN040W7@11
9a`0A2LM04LX7@1<;200CRlQ054c8`05054e8`05050c8P1><B40CBhO04XY7@19:1d00P18:1h09@15
9ah0A2LM048V70109A/0>b<J03LR600/7AD09a/C028H400P5`l071<<01TA2`0E3@X050`:01<;2@0C
2`X04P/:014:2@0?2@P02PH600L410020P800@8200D51@0;20T06A0B01lD5P0W61H0:QTE034P600h
9al0E4Dl06]NEP2TVi<0_KN_0=_Hd03Pg]H00P3QhMT00`3QhMX0hN7I0>7Qf@0D0>7Qf@060>;Qf@3R
hMX0i^GM0>WXh03Ui=`0f=O@:P3ooolI0?Ogm`040=k>eP2]W8`0U7]c06]BBP80HdY200T0Hd8a06]B
BP1SBT80HdY206=BBP1SBT80FU9B07=JDP1[DTX00P1J@ST0101kHeX0S7=S06=BBP1cFU8307]SFP06
08acH`1kHeX0LeYB07=BBP1[DTX0Le9:0P1cBST01@1[DTX0LdXi07=BBP1[DTX0LdXi00<0HdY200/0
FT8i0592>@1SBT80Je9:058i<@1SBT80DSTa06]BBP1S@S40HdY205Y2>@02058i<@0504Xa<@1B<BT0
BS4a04Xa<@12:B40101B<BT01@12:B40DS4Y048Y8@1J<BT0DSTa0080DS4Y00<0DSTa058a:@1B<BT0
0P1B<BT00`1J<BT0DS4Y048Y8@02058a:@03048Y8@1B<BT0DS4Y0080DS4Y00T0@RTQ034Q600i:B40
>BTQ034Q600Y61P0<B4Q02TH600Q41000P0Y61P00`0H41008A0@02TH600501P@4008034Q8@12:B40
DS4Y058a:@0a8B40DS4Y07=:@P2]Q7/U0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3R
h]X03`3QhMT0@03QhMX0h^7J0>7QfP3KfM@0dlk:0<Fm^@2MSXT0R7I`06ICBP1KB3l0Ccdc04`j<@1<
>S00CC/a04hm<`1??C<0CSdc04hl<`1@?SD0Dd4g05Q6?01HAc`0ETDk05E4>P1GAS`0FTPn05a:@01J
B3h0Dd4h050o=@1??SD0DT0g05I2>01LA3T0Gd@i06=4=`1TA3L0HT8d05m0<P1I?Bl0ES/^050j;`1=
>Bl0AcH]04@c:P12<BP0A3<Y04Xg;P1;=bh0AC0Y040[9@0k:280>bXS040a:@12<bX0@c<Z04<`9`12
;bD0@2/R03hY8@0i91`0=R8I038O5`0`7aL202lP600A030N5P0b7QH0=QdF03TN5P0n8AP0?b<I044W
6`11:1/0?bPJ03hW6P0l9aT0?2HI03/U600j8aL0>B4G03TO5P0j7QH00P0k7aL03@0h7aL0=QhF03@N
5P0c7QD0<1dD02dL4`0T610081L>01/D2`0J4`X05`l901D>2@0C2`T00P0B2PX05`0A2@T03`P800d8
1`0:1`H01@@400<30`010P800P<300X71`0B30`08aLG02XK6P0_6aP0<AdH048_9`1C@SX0PGE/09V@
Q`33`;P0dm790>;Rf`3Si=`0h^;J01P0hN7I00H0h^7I0>;QfP3ViMd0jNSP0>GTg03Hem0Z0?oooaT0
moOg00<0imkW0;FUY@2eYJD00P1[DTX02@1cBST0Je9:06=:@P1cFU80DT8i06]BBP1SBT80FT8i06=B
BP0307]SFP0706]BBP1J@ST0LeYB06]BBP1cFU80Je9:05Y2>@02058i<@0506]BBP1cDTX0LdY208AS
DP1S@S400P1cBST00`1cBT80HdY206=:@P0206=:@P0505Y2>@1SDTX0DT8i06=:@P1cDTX00P1J@ST3
04Xa<@0305Y2>@1B<BT0BS4a00<0DS4Y00@0@RTa048Y8@12:B40>BTQ1@12:B401@0i:B40DS4Y03TY
8@12:B40>BTQ00<0@RTQ00<0DS4Y048Y8@1B<BT01012:B400`1B<BT0@RTQ048Y8@03048Y8@0503TY
8@0a8AP0<B4H024@400a8AP00P0a8B401P0Y61P0610@02TH600a8B408A0@01P@4080:APH0P0H4102
02TH600703TY8@1:<C40>BTQ034Q8@1B<BT0BR4H0=K6cP0V0?Ogmb00oooo000N0?ooo`050=SGd03Y
j>00jNSP0>CSf`3Rh]X0403QhMT0?`3Rh]X0h^;K0=kLe`3Ge<h0blG00:RKUP2DQ7h0KeeE065?AP1@
?S@0C3Xa04`j<01=>c40D3dd050n=@1@?S@0Ccdd0590=P1D@ST0FTPm05Y8?P1EA3X0Dd8g05A3>@1G
AC/0FTPn05Q6?01@?cD0CC`c04dl<P1A?cD0ED4g05e5>@1QAcX0HdHi0695>01M@CD0FSlc05@l<01B
>Rl0CST_04`i;`17=Rd0A3@[04<b:@15=2/0C3P_04dh;`15<2X0?b/V03PW8P0h:B<0?2hW03h`9`0o
;bH0?b/S03lZ8@0l9ah0>bDM03DQ6@0b7aL0;A`D02/L500202TL500E02/K500/6a<0<Q/D03DL5@0i
7aL0>b4H03`S600k8aP0>28G03HR5P0d8AD0<b0E03<O500b7Q@0<QdD03<L500d71@0=adE03PN5P0d
7AD0<Q`D0080;a/C0100;1XB02TI4@0Q5Ph07QD<01XC2P0I4PT05Pl901D=2@0B2`T04PX901492@0@
2@T03@L700X61P081@D010@40P030`<0400510@03PT901H>3P0W6QP0;QhK03<O6P0g8Q`0Ccde06IF
C@2JTHP0/JZR0=3?a`3JfM80h^?K0>?Sg03Rh]XH0>7Qf@060>;Qf@3RhMX0i^GM0>WXh03Ui=`0f=O@
:P3ooolJ0?Ogm`040=K6cP2LS8`0S7=S07=BBP<0HdY200D0FT8i07=JDP1SBT80Je9:06=BBP0205Y2
>@0807]SFP2<Lf<0Nf=J08acH`1SBT80DSTa07=JDP1JDU8307]SFP0806=:BP1SBT80LdY207]SDP1B
>C40HdY206=2<@1J@ST206=:@P0>05Y2>@1SBTX0HdY206]BBP1B@ST0HdY2058i<@1[DTX0Hd8a04Xa
<@1B>C40BS4a03TY8@1:<C43058a:@80@RTa1P0i:B401012:B40>BTQ048Y8@1B<BT2048Y8@05058a
:@12:B40@RTQ058a:@0i:B400P0a8AP00`1B<BT0>BTQ04XQ6002058a:@07034Q8@12:B40>BTQ03TY
8@0a8AP0@RTQ03TY8@0202TH6005024@400Y61P0:APH02TH600H41000P0Q41001P0Y61P0610@01P@
400Q4100610@02TH6080>BTQ00H0@RTQ03TY8@12:B40DSTa048Y8@2]S8@W0?Ogmb00oooo000N0?oo
o`050=SGd03Yj>00jNSP0>CSf`3Rh]X0403QhMT0?`3Rh]X0hn?K0>7Pf@3Mfm@0eM;;0;^b[@2YWIP0
PW1Z06mLE@1E@3L0CcXa04dj<01??3<0DT0f0590=`1A?cD0D3he050o=@1B@CL0ETHk05I6?01B@SL0
D3le05=1=`1FA3X0FDLm05I5>`1>?S@0BS/a04Tj<01>?C<0Dd0e05e6>01QB3P0HDLh05e4=P1C?S<0
Cc`b04/i;`1;>2l0BSP^04Th;P15=B`0@S<[044a:`13<b`0BSL_04/g<013<2/0?B/W03HV8P0e9b80
>2XR03TZ8P0i:240=b<M03LQ6`0e7aP0<alG02hL500[6a<09QP@02<H4002020G3`0<02<G3`0V6100
:aXB02hK4`0b7AD0<ahF03<N5@0a7A@0;1XB02TI400V5`l09AH>0P0T5@h03@0U5Ph0:AP@02`I4@0a
71<0<Q`D02hK4P0[6A409aL?02HF3`0S5@h08QD=01dC2`0K4`X00P0I4PX06@0G40X05Ph:018:2@0A
2@T03PP800d71`091PH020D500L51@061PD020L500`:200@30X06Q4>020D4@0^7AP0=B<L04Ha:@1A
?SD0N6QP09:6OP34_kP0e=;:0>7Qf@3Rh]X00P3QhMXI0>7Qf@060>;Qf@3RhMX0i^GM0>WXg`3Ui=`0
f=O@:P3oool80?Ogm`030?O_k`3gmoL0moOg00l0moOg00T0imkW0=kFi`2]U9@0U7]c06=:@P1J@ST0
Je9:06=:@P1SDTX00`1SBT801@1SDTX0FT8i06=:@P1[DTX0LeYB00<0Nf=J00L0LeYB07]SFP1SBT80
FT8i06=:@P1J@ST0HdY20080Je9:00@0FS4Y06=2<@1S@S40HdY20`1B>C400`1SBT80FT8i06=:@P02
058a:@0504Xa<@1S@S40@RTa03TY8@1B<BT00P1:<C400`1B<BT0@S4i03TY8@0503TY8@06034Q600i
:B40<B4Q034Q600i:B40<B4Q0P0i:B402`0a8AP0>BTQ048Y8@12:B40>BTQ048Y8@0i:B40<B4Q034Q
60126100>BTQ0080<B4H00@0>BTQ048Y8@0a8B40@RTQ0P0Y61P203TY8@03034Q600i:B40<B4H00<0
:APH0P0Q410201P@4080:APH00H0610@034Q8@0i:B40<B4Q048Y8@0i:B42058a:@0306<i<@2]W;D0
moOg02L0moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP0@0>7Qf@0=0>;RfP3Rhm/0
hN7J0=kMeP3He/l0`kZf0;>WX`2:N7<0MV5K05Q1>@1A>c40Cc/a050m=00205=1=`0H058o=P1@?SD0
Cchd04lo=@1A@SP0DD<h0511=P1A@3H0ED<i05Q6?01JBCh0EdLm04ho=P1:?380BCXa04`k<@1@?C80
Fd<e05m5=@1MA3@0FD4c04hj<01:>2l0AcL^0P18=bd02@17=Rd0@c</040a:`0m;bX0?c4/04De;P16
=Bh0@BlZ03`[9P0203DU8@0;03LW800g9R00=bDO03@P700b7QX0<1dG02hL5@0Z6a<0:1XA02<G3`0P
5Ph00P0N5@d08`0P5Ph08aL?02PI4@0Z6Q80;A`D02hL500]71<0:a/B02HH3`0T5Ph081<<01lB300N
4@`07Q8<01lC300T5Ph0:1L?02dJ4P0^6a80:QTA02LH3`0R5@d08A@=01lC300N4P`06a8:01XB2P0J
4P/06A8;01L@2`0F3P/04PX90109200<1`L02`H6008020D5014020H500X81P0=2PP04`l;01PA3P0Q
5Q809QPC034O600j9Qh0E44i06IEC02BQWh0ZJ6I0=7>a`3Mg=@0i>CM0>?Sg00K0>7Qf@060>;Qf@3R
hMX0i^GM0>WXg`3Ui=`0f=O@:P3ooolK0?Ogm`030=k>eP3>_Lh0W8b<0080HdY20P1[DTX00`1SBT80
Je9:05Y2>@0206=:@P0506=BBP1B@ST0DT8i06]BBP1cFU800`1kHeX0201cFU80He9:06=BBP1SDTX0
FT8i06=:@P1cDTX0LdXi0P1B>C4206=:@P0305Y2>@1:<C40DT8i00<0FT8i00<0DS4Y048Y<@1B@ST0
0P1B<BT01`1:<C40@RTa048Y<@0a8B40>BTQ048Y<@1B<BT00P0i:B400`0a8B40>BTQ03TY8@02034Q
8@08034Q600a8B40>BTQ03TY8@0a8B40>BTQ034Q8@0a8AP203TY8@06034Q600i:B40>BTQ02TH600a
8AP0:APH0`0a8AP01P0i:B40@RTQ034Q600i:B40<B4Q02TH6080>BTQ00D0<B4Q034Q600a8B40:APH
01P@400202TH6003024@400H4100610@0080:APH00T0<B4Q03TY8@0a8B40@RTQ058i<@0a8B40@RTQ
05Xa:@24DT80:@3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J0100hN7I0`3Rh]X0
?03Ph=P0gM_E0<o7``31][<0VXJ208=/IP1PASd0Echd058m<`1B?cD0Dd8h05A2>01B@3H0DChe04`l
<P1:>c40B3/a04Tl<P1?@3H0Dd<i05Y9?P1LBd00G4]105U9?`1@@SP0Bche04Pk<@17=bd0BSL/058j
;01E>b`0DcTZ04hf:@13<BL0@C0W044b:@13<bX0A3@Z04<c:P0m;bT0>R`Y03DY:00e:RT0>BhY03/^
:00i:bH0=RLS03<R7`0c8Ah0=20K038O6`0`7Q/0:aXJ02TI6@0U61D091PC028H400Q5a007QD>01`D
30806A8:03H071@<01hE3@0Q5`l08AL@028H400S61008QL@024F3`0M4``06a8:01L>2@0F3@T05@`9
01H=2@0H3`T07A<;024E300V5`l09aL?02<E3@0O50`06A0:01L>2@0E30T05@d801H>200F3`T05a0;
01L@300E3P`050`;01092@0=20L02@D500P51@091PD02`L600h91`0C3@X05Q0<01hF400T6A<0;alH
03<Q6P10:b<0CCT`07][H`2FRX80`kjf0=7>aP3Og]L0h^;J0>?Sf`3Rh]/K0>7Qf@060>;Qf@3RhMX0
i^GM0>WXg`3Ui=`0f=O@:P3oool00`3gknl0moOg0?Ogm`0I0?Ogm`0C0=k>eP3Fa]H0Nf=B06=:@P1J
@ST0Je9:06=:@P1[DTX0He9:05Y2>@1SBT80He9:06=:@P1[DTX0LeYB06=BBP1SBT80FT8i07=JDP03
07]SFP0508acJ`1SBT80HdY205Y2>@1S@S400P1B<BT00`1B>C40FT8i05Y2>@0204Xa<@0=06=:@P1B
>C40HdY204Xa<@12<CT0DT8i048Y8@0i:B40@RTQ03TY8@12:B40DS4Y034Q8@0203TY8@0404Xa<@0i
:C40<B4Q02TH60@0<B4Q0P0Y61P303TY8@<0<B4H0P0i:B400`0a8B40DS4Y03TY8@02034Q8@0302TH
600i:B40<B4Q0080>BTQ00@0<B4H034Q8@0Y61P0<B4Q100Y61P0100H4100:APH024@400Y61P301P@
4003024@400Y61P0<B4H0080<B4Q0P1:<C401012<CT0DSTa058i<@2DNg<30>oWibL0moOg803oool0
01h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP0@0>7Qf@0o0>7QfP3Rh]X0h^;J0>7Pf@3OgML0e<g9
0<Rm^P2QSXT0RW=]06E:@@1J@CL0Dcdc058o=@1C@CL0Dd4h0590=P1A?SD0C3/b04Tj<016>Bl0Ac/a
04i0=P1CA3X0FdXo05e;@@1KBd00F4Tn04m2>01;?S@0AcX`04De:`16=2X0CCDY04lf:01<<bH0B30T
03h/8P0m;2<0?blV044a:012<RT0@C4Y03//:00g:BL0<RHW038W9P0e:RD0=RXT03DW8`0d9B80<B0N
034O700`7AT0;Q/H02`J600V5aP08aHG020F500P5Q807QH@01hF3`0L50d06Q8<00805a0900<06Q8<
01/C3@0M5@h00P0M5@h0300M5@l07A@>01`D3@0J4@/0610901D<200D2`P04`/901D<2@0F3PT0718;
01hD30808aH>00h07a<<01`A2`0E3@P04P/701091`0@2PL04P`701<=200C3PX04`h;018<2`0@2`X0
3@P800/71`802@H600l02`P600h91`0@2PP05@l;01PA300P5Q009ATB038R6P0j9al0CcXb05m<A02A
Q7`0[:>K0=?Ab@3Mg=@00`3Rh]X00`3QhMX0hN7I0>7Qf@0I0>7Qf@060>;Qf@3RhMX0i^GM0>WXg`3U
i=`0f=O@:P3ooolL0?Ogm`050=k>eP3Fa/h0S7=[06]BBP1J@ST00`1SBT80101cFU80He9:06=BBP1c
FU820592>@0506=BBP1cFU80Nf=J05YBDP1B@ST00P1SBT80201SDTX0Nf=J0592>@1J@ST0Hd8a058i
<@12:B40DS4Y0P1B>C404P1J@ST0BS4a04Xa<@1J@ST0BS4a05Y2>@0i:B40DS4Y058i<@12:B40DT8i
03TY8@12:C40>BTQ048Y8@0Y61P0<B4Q02TH60<0>BTQ00P0<B4Q02TH600a8B40<B4Q034Q600Y61P0
8A0@02TH6080<B4H00d0>BTQ034Q8@0Y61P0:APH034Q600a8B40<B4H058a:@0Y61P0>BTQ034Q8@0a
8AP0>BTQ0080<B4Q1`0Y61P01@0H4100:APH02TH600H4100:APH0080610@00<0:APH034Q8@0a8B40
0P0a8B402@12:B40DS4Y058a:@12:B40<B4H07=:>@3Nc]H0moOg0>oWi`0X0?Ogmb00oooo000N0?oo
o`050=SGd03Yj>00jNSP0>CSf`3Rh]X04P3QhMT30>;QfP080=cHd`3Cc<L0/::K09Z8P01bFe40I4e3
05E0=P1B?cD20590=P0`058o=P1@?S@0CC/b04/k<@1:?380Bcdc04m1>01AA3X0ETLm05Q8?P1GAS`0
E4@j04`m<`18>Bl0A3H/040`9`10;bD0@bhT04<^8`0o:Ql0>bLM03HT6`0g9Qd0?2`S03h^9@0n;RH0
?2/U03HV900c92@0;b8R02lR8@0^8Ad0;R4L02hO7@0]7Qd0:a/L02TI6P0U5QD08Q@C01lB4P0K4140
6@lA01TA400I4Q006Q<@01TB3`0G40d05Pl;0P0D30T02P0F3P/05`l<01L@300F3``05Ph;01H?2`0G
40`05`l<01@=2@0C30P2018:200;01@<2P0F3P/0610;01/C300M50d07A<>01`B3P0H3`/05@d900l8
1P0;1`D00P0710<06`081P@02@L400X81P0:1`H02@H600P61P081PD02@H600d92@0?2`X04`d:01D>
2P0F3`X05a0;01P@2`0M4@/08Q<=03LT7019=B`0MfEM0921N@2l]:`0cLS00>7Pf@3Ti=d0hn?L0>;R
fP050>7PfAP0hN7I00H0h^7I0>;QfP3ViMd0jNSO0>GTg03Hem0Z0?oooah0moOg00@0YHB409AkL`1c
FU80HdY20P1[DTX00`1J@ST0HdY206=:BP0206=:@P0306=BBP1SBT80HdY20080LeYB00<0He9:05Y2
>@1J@ST00P1B@ST01P1B<BT0DT8i06=2<@1B>C40DS4Y03TY8@80@RTQ00l0DT8i058i<@1B<BT0@RTa
058a:@12:C40DT8i058a:@0i:B40DSTa03TY8@1B<BT0<B4Q058a:@0Y61P00P0i:B400`0Y61P0<B4Q
03TY8@03034Q8@D0:APH00<0<B4Q02TH600a8B400`0a8B40100Q4100:APH02TH600Y61P2034Q8@80
:APH00T0>BTQ02TH600a8B40:APH034Q8@0H41008A0@01P@400Y61P01P0H41001`0Y61P0<B4Q034Q
8@0a8B40:APH034Q6012:B400P1B<BT01@0i:B40DS4Y05Y2>@2LJe80e[g60080knOW:@3gmoLP0?oo
o`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J0180hN7I00/0hN7J0>;RfP3Rh]/0gmgF0=OCc@2h
[ZH0Y9F=07aXGP1]F4h0FDDk05A1=`02054o=@0X050n=@1??C@0CC`b04dl<P1>?S@0CSle04m2>01@
@cX0DdDl05E6?01EA3X0DT8h04/k<@17=bd0@c<Z03l^9@0n;B<0?b`R03l[8@0j9ad0=R@K038R6@0d
8aX0>RXQ03`/8`0k:b@0>2PS03<T8P0a8R40;b0O02hP7@0[7AT0:QdH02TK6@0Y6QX09QPJ02@G6@0O
4a<0714A01X@3`805Pd>00H05Ph>01L@3`0H4@l0614?01H?3@0D3@/2018;2@0601@=2`0E3P`05@d<
01@<2`0D30X05@d;0P0F3P`0;00C2`T04@X801091`0A2PP05@d;01L?300I4Pd071@=01`D3P0K4Ph0
6A4>01D=2`0B2`T030H500P510040P800`8200@30P0510<01PD400L510061@D01PD400L51@091`L0
3`/:01<=300G40`06A4<01TA2`0J4@/06Q0;01h@2P0S4P/0?BLN05<n=@2<O7<0YiZB0<g7_`3He<d0
h^;J0>?Sg03Rh]/0hN7J1@3Qh=TH0>7Qf@80h^7I00@0i^GM0>WXg`3Ui=`0f=O@:P3ooolN0?Ogm`06
0;FU[@2UQ7/0Q6]J07=JDP1J@ST0Je9:0P1SBT800`1cFU80He9:06=:@P0306=:@P050592>@1SBT80
He9:06]BBP1SBT800P1B@ST0201B<BT0DSTa058i<@1B>C40DS4Y048Y8@1:8AP0@RTQ0P1:<C42048Y
8@0?048Y<@12:B40DSTa058iBP0a8B40DS4Y034Q8@12:B40<B4Q03TY8@0Q4100<B4Q03TY8@0Y61P0
<B4Q0080>BTQ00<0<B4Q02TH600Y61P00P0Y61P00`0a8B40:APH034Q8@0202TH6080>BTQ00@0<B4Q
02TH600Y61P0:APH100a8B401@0Y61P0@RTa03TY<@0Y61P0<B4Q0080:APH00<08A0@01P@400Q4100
1@0H4102034Q8@0703TY<@0i:B40:APH02TH6012:C40>BTQ034Q8@0203TY8@0306=2<@24DT80YG=J
0080knOW:P3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J0180hN7I02P0hN7J0>;R
fP3Shm/0hN7J0=gLe@3;a[h0_KF/09^>Q029NW00JUQ>05m<@P1B?cD0Ccdc04`j<@1<>S00CC`b04hm
=01@@CL0D48h04m3>@1>@cT0D4@j0594>P1D@cT0DT0h04/i<@17=Bh0@c4Y03h[8`0m:B00>bPO03TX
7`0d91`0<28I02`N5@0]7aH0<b@K03DU7@0c91h0<28M0P0]7a/04`0/7AT0:Q/G02@F4P0Q51407a8B
01hB4`0M4A@06a4D01P@4@0F3`l05@h>01<<300B2`/04`/;01<<300E3@d05@h>01@=300C2`/00P0@
2@T03`0B2`/04``;018:2P0A2@T04`X901H<2P0L40d06`l<01<:200>1`D02`H500h81`0E3P`0614=
01/C3P0201dE3`0601TA3P0F3`d03`T900`71`050`<00`410P0000006@0100000`4100H410081@D0
2@L600T71`0;20P03@X:01@>3P0H4@l081D@028F400T5a009QP@02PH400^6Q00=QhC05Hk;@1`EdT0
[9fB0<Fl/`3PgMH0hn;K0>;RfP3QhMX00P3QhMT60>7PfAL0hN7I0P3RhMT0103ViMd0jNSO0>GTg03H
em0Z0?oooah0moOg00T0mno_0<je_@2DNg<0Q6]J06]BBP1J@ST0Je9:07=JDP1J@ST00P1SDTX01@1[
DTX0He9:06=BBP1[DTX0FU9B0080LeYB0P1SBTX00`1B@ST0DS4Y06=:@P02058i<@04048Y8@0i:B40
<B4H03TY8@80@RTQ00<0DS4Y03TY8@12:B400P0i:B400`1B@ST0:APH03TY8@0202TH600403TY8@0Y
61P0>BTQ02TH6080<B4Q0`0Y61P2034Q8@@0:APH00/0<B4Q02TH600Y61P0:APH034Q8@0i:B40@S4i
034Q8@0H4100:APH01P@4003034Q8@0503TY8@0Y61P0:APH03TY<@0Y61P01P0H410202TH6003034Q
8@0i:B40>BTQ0080<B4Q00<0<B4H034Q8@0i:B400P1B<BT01`12:B40Hd8a07=:>@2<FT80YG=J0<J]
[@3gimh0:`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J01<0hN7I00`0h^;J0>;R
f`3Rh]X0gmoG0=CAb@3:aKd0[JBK09^?Q@1hIU`0JEI<05E2>01??C<204/i;`0404dk<P1>?C@0Cd4g
04m2>080CT<i02P0DD@j05=5>`1EA3/0Dd8i04`j=018=S00A34[03hZ8P0l:200>RLO03TW7P0c91`0
;b4I02XM5@0Z7QD0;b0H030Q6@0^81X0;1lI02XM600[7AP0:Q/F02PI500P4a007A4>01X>3P0I3Pl0
6@lA01P?4@0G3a005Pl?01D>3P0C30`04P/;018:2P0B2P/04``<01@<3@0C30`04PX;0P0@20P05`0B
2PX04P/;014:2P0A2@T050X901T<2P0P4@h07a4=01@;200>1`H02PH600d8200F3`d06A4>01`D3`0M
5@l071D?01PA3P0E3Pd03@P800T51P030P800@410080000001T00`0000D10@091@D02`L700h:2@0>
2PX040/;014<300G40l06a8@02<F4P0W6180:aXB02lM4`0b7a@0?BDG04L[701YBSX0PVIF0;NXW03=
a;/0h^7J0>CTg@3Rh]X0hN7I00T0hN3I5P3QhMT20>;Qf@040>KUg@3Yj=l0iNCL0=SGd2X0oooo7`3g
moL01@3Wg^L0U8B408aSDP1kHe80FT8i0080Je9:00P0FT8i06=:@P1SBTX0FT8i07]SFP1cFU80Le9:
06]BBP80HdY200L0He9:06=:@P12<CT0DS4Y06=:@P1S@S40DS4Y0080@RTQ00L0<B4Q03TY8@0a8AP0
@RTQ04Xa<@0i:B40<B4Q00<0>BTQ00@0:APH034Q8@0a8B40<B4H0P0a8B400`0Y61P0<B4Q02TH6003
034Q8@0501P@400a8B40<B4Q02TH600H41000`0Y61P0200a8B40:APH02TH600a8B40>BTa0592>@12
<CT0<B4Q0`0Y61P3034Q8@0403TY8@0a8B40:APH03TY8@80<B4Q00D0:APH024@400a8B40:APH034Q
8@0203TY8@03048Y<@0a8B40:APH0080<B4Q00D0DS4Y04Xa<@12:B40@RTQ058a:@0207=:>@0308ac
H`2LJe80g/kF02`0moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP0G0>7Qf@0S0>3P
f03MgMD0cLW00;jg[P2IS880QWM/06IDB@1JAcd0CC/a04/i;`1;>c40Bc`c04/n=@1<@3H0CT8h04m3
>@1DAS`0EdLm05U7?P1HASh0DCli04dj=@18=Bl0@2`T03dY8@0k:1l0>RPP03@V7P0_8a`09a`G02HK
5@0V6Q@09aXD02LJ4`0V6a<00P0V6Q<0200U61808aHA01/A3P0H3``05@d;01@<2`0E3@d05Ph>0`0F
3`l0200D3@d04`/;01092@0@20P04@T9014:2P0B2PX04@T90P0?1`L0<P0@2@T04@X:014:2@0B2PT0
5``901`>2`0T4`l091@@01XA400D3`l04Q0A01DB4`0L5QD07QLE01lG500N5A4071<?01H>3@0C30/0
2`L700L510040`800`<200D40P0710802PD300`6100A2PT050d;01TA400K4a407QDC01hF500P5Q@0
8QLD02XJ5@0`71H0=AlF040V6@17:ad0GCh/06e<>@2BLf00YXaj0<Vl/03FclD0h^;K0>?Tg@3Rh]X0
hN7I2P3Qh=TE0>7Qf@80h^7I00@0i^GM0>WXg`3Ui=`0f=O@:P3ooolP0?Ogm`050>oWi`2]YKD0S6=B
07]SFP1SBT800P1[DTX306=BBP0505YBDP1B@ST0Nf=J07]SFP1[DTX00P1SFV<01P1SBTX0FT8i058a
:@1[DTX0HdY2058i<@80@RTQ00D0<B4H034Q8@0i:B40<B4H048Y8@0203TY8@09034Q8@0a8AP0<B4Q
034Q8@0Y61P0@RTa034Q8@0Y61P0<B4H0080<B4Q00H0:APH034Q8@0a8B40:APH034Q8@0Y61P2034Q
8@0401P@400Y61P0:APH02TH6080<B4Q00T0:APH034Q8@0i:B40DT8i05YBDP1kHeX0DSU:034Q8@0Y
61P00P0a8B40100Y61P0<B4Q034Q8@0i:B4203TY<@0303TY8@0i:C40>BTa0080>BTQ00H0DS4Y048a
>@0i:B40<B4Q02TH600i:B42058a:@09034Q8@0a8AP0Hd8a07=:>@1S@S40Q58i09ASBP2LJe80[Hb4
02d0moOg803oool001h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP0F0>7Qf@0S0>;QfP3Shm/0hN;J
0=KDc03;akh0[:6H09V<PP1eHeP0IU9805<o=@1>?380Bc`b04Xl<P19?3<0BSdd04i1=`1A@cX0ETLm
05U8?P1KBCl0FTLo05A2>`1@?CL0BSPb044_9`0n;2<0?2XQ03/Z8@0f9b00<B@N02PL6@0U6QH08aLC
02@G4`0T61800`0U6A804`0R5a4081D@01/A3P0H40d05Pl<01H>2`0F3``05Pl=01L?3`0F3`l05@h>
01<<300B2`/03`P800l71`0?20P040P901092@0@20P00P0>1PH0<P0?20P040T8018:2@0C2`T060d:
01`?2`0R4`l08aDB01hF5`0L5aT06aXM01hL7P0S7Ad08a`K02<J600O5A<0718@01H=300B2`X030L7
00T61@081@@020H400/81@0<20D040T6014:1`0E3@/05`l=01dD4P0P5aD09Q/H02LL600W6aL0:1/F
02hL5P0c7QL0>B4H04HY701?<240K4/i07iNB`2URgT0]j6A0=77^`3IeL/0h^;J0>;Sf`3QhMX0hN7I
2P3Qh=TE0>7Qf@80h^7I00@0i^GM0>WXg`3Ui=`0f=O@:P3ooolQ0?Ogm`070?O_k`2UQ8@0U7=[07=J
DP1[DTX0HdY206]BBP0205Y2>@0606=BBP1cFU80LeYB05YBDP1cFU80Nf=J0P1cFU80201SDTX0DT8i
06]BBP1SBT80FT8i048Y8@1B<BT0>BTQ0`0a8B400`0i:B40@RTQ034Q8@03034Q600603TY8@0Y61P0
<B4Q03TY8@0Y61P0<B4Q0P0Y61P2034Q8@<0:APH00@0610@02TH600i:B40<B4Q0P0H410202TH600=
034Q8@0i:B40<B4Q034Q8@0i:C40DT8i05YBH`12<CT0HeYS05YBDP0a8B40@S4i048Y<@07034Q8@03
03TY8@12:C40>BTQ00<0<B4Q00<0@RTQ0592>@1J@ST00P0i:B4206=2<@06058a:@1S@S40LdXi08aJ
BP2LJe80c[Fe;P3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J01H0hN7I01<0h^7J
0>?Sf`3Shm/0h>3H0=cKd`3<b;l0_kN^09Z:P027M6T0J5A:05e;@@1?@CL0Bcdc04Pj<019>S00Cd0f
05=3>@1HAcd0FTTo0080FdU000h0FDLn05E4>`1@@3L0ACH]044c:@0o<2H0?blU03XZ900f9R80:adM
02HJ6P0P5QD07aDC024F4@808aLA00@08AHA01dC400L4a006a<?0`0K50h0200J4`h06A8>01H?3P0E
3Pd04``<01492@0@20P03PL70P0>1PH00`0>1PL03PH600h61P0300d51@0F00h61P0B2PL050`801T@
2`0K4@`07Q@A024G5`0X8RL0;2P_03<`=P0d<CD0=Bl_03<[:P0`9RD0:1XK02<F5P0J3`l05`h=01D>
3@0F3Pd0614>01TB3P806a@=0P0K4`d04`0K4Pl071<@02@I5P0Z7QX0=2HO03LX800f9Ql0=BDM03LS
6`0k8a/0@BHL05Dc9P1S@340RFUI09j4M034]ZT0dLRl0=gJd@3OgMD00`3QhMT00`3Qh=T0hN3H0>7P
f@080>7PfAD0hN7I0P3RhMT0103ViMd0jNSO0>GTg03Hem0Z0?ooob80moOg00X0mno_08acN`2DNg<0
Q6]J07=JDP1[DTX0He9:06=:@P1B@ST0HdY20P1SDTX407=JDP0506=:BP1B@ST0HdY206=2<@1J@ST0
0P1B<BT01@0i:B40@RTQ02TH600Y61P0<B4H0080>BTQ0P0a8B402@0Y61P0<B4H03TY8@0Y61P0>BTQ
034Q8@0Y61P0<B4Q024@400202TH6003034Q8@0Y61P0:APH0080:APH00@0<B4Q03TY8@0Y61P0:APH
0P0H410202TH6007058iBP12<CT0BSU:03TY>@1JDU80HeYS05YBDP02048Y<@@0@S4i00@0DT8i048Y
<@0i:B40>BTa0P0a8B402`0i:B40@RTQ04Xa<@1J<BT0FT8i058a:@12:B40DS4Y058i<@1S@S40DS4Y
0080Hd8a00@0LdXi08AB@P2LJe80[IBD;`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0
h^;J01L0hN7I0`3Rh]X09@3QhMT0emG=0<g7_`2]WiH0VXUo07QUF`1ZF4h0ETHl04m0=P1:>S00BcX`
04ln=01B@CL0EdHk05Q7?@1JBCl0FdU005]9?`1HAcd0E4<j04Tk<@15=bd0@S<X044a9`0m:b@0>2LS
02hO7`0X6a`081HF01lE4`0P5Q408AHA024E400N51006Q8?01TB3`0J4`l00`0L5@l01P0J4`l06A8?
01H>3@0D30`04P/;010820803`L700@03PL700h61P0>1PH03PH61@0=1@D0:`0A20H04`/701P@2`0J
4Pd07aLE02<K700]9bh0<bdf03`g?@0n>Cd0?cLf03dc<P0j;Rd0<B8R02/L7@0R5AD07a@C01lE4`0P
5aD08aXE02@K5@0T6Q<08aXA020H400O5`l07QD@01lF4P0X71P0;R4K03TZ8P0l;2<0?2/S03`Z8@0m
9ad0@BLM04P[801P?S40LDm009UmKP2^UhX0clJl0=WEb`3Qh=L00P3Qh=P30>7Pf@030>7Pf03Qh=T0
hN3I00P0hN3I503QhMT20>;Qf@040>KUg@3Yj=l0iNCL0=SGd2X0oooo8`3gmoL0303Fa]H0S7=S08ac
H`24JeX0Nf=J06=BBP1SBT80FT8i0592>@1J@ST0HdY:06]BBP80He9:00<0LeYB07]SFP1[DTX00P1S
BT801@1J@ST0DSTa04Xa<@1B<BT0@RTQ00<0:APH00@0<B4Q03TY8@0i:B40<B4H0`0a8B40200Y61P0
<B4Q034Q8@0Y61P0<B4Q02TH600H4100<B4Q0`0Y61P01`0a8B40:APH034Q8@0a8B40:APH01P@400Y
61P00P0H41002P0Y61P0<B4Q06=BBP12<CT0HdY2048Y<@1SBT80Nf=J06=JH`1B@ST2048Y<@08058a
:@0i:C40@RTa04Xa<@12<CT0@RTa048Y8@1:<C43058i<@80@RTQ1@1B>C401`1[DTX0LdXi07]SDP24
He80S5Y:0:fDU03gknl0;`3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0h^;J01T0hN7I
02<0h^;K0>?Sg03QhMT0g]cD0<k7_P31]jh0WXn508]jL01[Edd0H4a205A2>01B?cD0Ccdc04hm<`1?
?cD0DD4g05E6?01HBCl0GDa205e<@@1KBd00E4@j0511=@1;>Bd0BCDY048^900n:b<0=2@P02hP7@0T
6QL08APD01lF4P0O5A4071<@01XA3`0201H?3@0;01TB300J4`d071D>01/D3`0I4Pl05a0>01<<2`0A
2PX040P800h71`0?1`L00P0@20P0=P0?1`L03PH600d51@0>1PH03`L700h61P0=1@D03@@400d50`0?
1`@05Pl<01/E4@0V8B00:bHW03@/=00i;cT0@cPn04Pm?`1?@Sd0Cd4k04dn>015=300@2l/03HW9@0d
9B<0=bPU03T[9P0k;2D0>B/S038U700^8QP09Q`C02@J4P0U6a@0:1`F030R6`0e9Ah0?B`S044_9P16
<bT0B3<Y04hb9P1D=BT0GSd`085RE02FNVd0_:ZO0<Zn]03LfM40hN3H0>;Sg03Rh]X0hN3H0>3Pf0@0
hN3H2P3Qh=TC0>7Qf@80h^7I00@0i^GM0>WXg`3Ui=`0f=O@:P3ooolT0?Ogm`040=JmaP2UQ8@0U7=[
08A[FP80LeYB00@0Je9:06=:@P1J@ST0HdY20`1cFU801@1JDU80Nf=J07]SFP1kHeX0HdY200<0FT8i
00`0DT8i058i<@12:C40>BTQ02TH600a8B40@RTQ03TY8@0Y61P0>BTQ034Q8@0a8AP202TH6005034Q
8@0Y61P0<B4Q02TH600a8B400P0Y61P0100a8B40:APH02TH600Y61P3034Q8@@0:APH00@0<B4Q02TH
600Y61P0HdY20P1SDTX0201B>DX0@S4i048Y<@1SBT80DT8i06=:@P1kHeX0LeYB0P1[DTX206=:@P06
058i<@12:C40>BTQ058a:@1J@ST0LdXi0P1SBT802@1cBST0HdY206=:@P1[DTX0Hd8a07=:>@24DT80
S5Y:09ASBP0a0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X06@3QhMT0=P3Rh]X0
h^;K0>;RfP3Qh=P0fMK=0=7:`P2aYI/0WHf307UTFP1/Ed`0G4Pm05M3>@1@?C<0CC`a04dm<`1>?cD0
DdDk05M9?P1NCD<0Gdi305i=@`1IB3h0ETDj050l;`1=>2/0AC0T044]8`0g9R00<B<M02LM5`0T6aD0
8APC020G4`0M51806a8A01L@3P0G40d06A8<01XC300K50h06Q<>01PA3P0F3`d04P/:01092@0?20P0
3`L700l7200@2@T04@T900l71`0>1PH03@D600h61P8040P803003PH600d4100<10803@D301D>2`0K
5A<0:B@S02hY:P0e;3<0>Bdf04<e>P19>c`0Dd<m05A4?01C@SX0BcXd04He<00n;BX0?2`Y03l_:P11
<B/0@S8Y03l_9P0f9ah0<2<J02LL4`0U6a80:AdE02dO5`0d91`0=bHN03h/8P12;bD0BcH[04lh;@1I
>bh0HD0c06e;?P2CMVX0ZI660<^n]@3EcLD0gmgF0>7Qf@3Rh]/0hN7J0>7Pf03Ph=P40>7Pf0X0hN3I
503QhMT01@3RhMT0i^GM0>WXg`3Ui=`0f=O@02X0oooo9@3gmoL00`3Fc]h0S7=S08A[FP0406]BBP0:
05Y2>@1B@ST0He9:06]BBP1cFU80FU9B06]SJ`1kJg/0Jf=[07=JDP80FT8i00/0DT8i058i<@1B>C40
DS4Y04Xa<@0Y61P0<B4Q03TY8@1:<C40<B4Q034Q6002034Q8@80:APH0P0i:B4302TH600301P@400Y
61P0<B4Q00@0:APH0`0a8B40100H4100:APH02TH600i:B43034Q8@0303TY<@1B>DX0HdY20080FU9B
00@0DT8i04XiBP0i:C40<B4Q0P0i:B400`1:<C40DSTa058i<@0405Y2>@0306=:@P1[DTX0HdY200<0
HdY20`1S@S40101cBT80W6]B09a[DP2DNg<a0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CS
f`3Rh]X06`3QhMT07@3Rh]X0hn?L0>GTg@3Qh=P0c/No0;ndZ`2LRX00RgI[06mGB`1TCD00ET4e058o
<`1??c@0Cd0f05=5>`1GB3h0Gdi4065@A@1RDDH0HDi305m<@01IACP0ET4c04dh:P17<bL0>bXQ03HW
7P0_8QX0;B4J0080:b4K00d0:AlK02HM6P0R6AD081PC01hE3P0M50d071<=01/C3P0H40h05Pl=01<;
2`0A2PX04@T900<040T900D040P800h61P0=1@D03@D600l72002018:300I01082@0?1`L03@D300h5
0`0D3@X06Q<A02HQ7`0[9BD0<BLZ03DX:`11<300AcHc050n=@1??SD0C3`c04<d;@0o<BX0>b`W03//
9P0n;bP0?c0X03d^9P0j:b<0<B<L02`O600202HJ4P0A02dO5P0b8QT0>BLM03`X7P12;B40B34T05Pm
;P1QA3D0MEE7085QE02@LFH0]9nF0<Ff[P3Mem00hMkG0>;Qf@3QhMT00P3Qh=T70>7Pf0T0hN3I503Q
hMT01@3RhMT0i^GM0>WXg`3Ui=`0f=O@02X0oooo:03gmoL01P2<He80Nf=B08A[FP1kHeX0HdY206=B
BP80LeYB00<0Nf=J07=JDP1kHeX0101kHeX2058i<@0805Y2>@1B>C40DSTa058a:@1:<C40HdY203TY
8@12:B4204Xa<@07048Y8@0a8B40>BTQ03TY8@0Y61P0>BTQ034Q8@0202TH600403TY8@0a8B40:APH
034Q8@80:APH00<0>BTQ034Q8@0a8B400P0a8B40100i:C40<B4Q03TY8@12<CT2034Q8@0>048Y<@1B
@ST0@RTa048Y<@1SBT80HdY:03TY<@0a8B40>BTQ048Y<@0i:B40@RTa03TY8@1B<BT2034Q8@80BS4a
00H0DS4Y0592>@1B>C40DS4Y05Xa:@1S@S4208AB@P0408ASDP2DFU80g/kF0?oooc80moOg803oool0
01h0oooo00D0f=O@0>WXh03Yj>00i>?K0>;RfP0K0>7Qf@1R0>;RfP3Shm`0iNGN0>CSf`3Gdl/0c<Fm
0:jPU@2LRWh0NV9D06eDAP1LAST0F4<g05=2=`1A@SP0E4@j05M7?@1OCT<0HU1506=AAP1SD4D0HTm3
05i:?@1KAcX0DCd`04Xg:`0m;280>2PO03<U700b9A`0<bHO03<W800a9R40;bDP02TP6`0W7QL08aTA
024G3`0O5@h07A@?01TB3P0G40h050`<018;2`0B2P/04@X:01492P0@20P03`L700d51@0<10D03PH7
01082P0C2`h050`?018:2`0A20T040L501081@0E3@X06A8?028L6P0V7ah0;R@T03<W9P0o<2`0AS@_
04/i<018=bl0A3@/03T[9@0e:2<0<bHP03@W800f:B40=bXQ03DX800b9Ah0:alH02PL5P0W6A80:1XB
030P5`0d8aX0>bPN03hZ7P17;b40CS@U0693<P1]CC`0QVIH09=fJP2RQgh0`;2Y0<k3_03Pg=D0hn7J
0>;RfP3QhMT20>3Pf0L0hN3H2@3Qh=TD0>7Qf@050>;Qf@3ViMd0jNSO0>GTg03Hem00:P3ooolX0?Og
m`0809AcJ`2<Lf<0Je9:07=JDP1[DTX0He9:06=:@P1[DTX307]SFP0408acH`2<Lf/0W8b<09B4Q0<0
DSTa00L0FT8i058i<@1:<C40DS4Y04Xa<@1J@ST0BS4a0080DT8i00D0BS4a048Y8@0i:B40@S4i02TH
600203TY8@05034Q8@0Y61P0<B4Q048Y<@0Y61P00P0a8B401@0Y61P0@RTa048Y8@0i:C40<B4Q0080
>BTa00@0>BTQ034Q8@12:C40BSU:0P0a8B406`12:C40@S4i03TY<@0i:C40DT8i06=BBP1SBTX0@RTa
034Q8@0i:B40<B4Q04Xa<@12:C40BS4a058i<@12:B40DS4Y05Y2>@1S@S40DS4Y06=2<@1c@S40Nf=B
08AB@P24He80S5Y:09AkL`0d0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X0703Q
hMT04`3Rh]X0h^;K0>;Rf`3QhMT0g]gE0<c5_02l/:D0Uh9d08M_H01`FDX0J59505Y8?01FA3T0DT4f
05A3>01LBSl0H4i306=AAP1VE4T00P1WEDX01@1UE4P0FdXo05A3=`15=2X0@2lU0080>RXQ01L0?2`T
03d^9P0m;bL0>bhV03HZ8P0d9al0;b4I02dO5`0Y7AD09Q/D01lG4P0L5A005Pl=01@<300B2`/04@T:
01092P0@20T03`L900l6200?1`P04PX;01D<3P0201TA500Y01L?4@0F3Ph060l<01XA3@0L4`h071<?
01`C4@0O5Q@0;24M03@X8P11<RX0A3@[048a:@0m;2H0=RLQ02XN6@0X7AP0:AhG02XO5`0/81L0:b0G
02TN5`0X7AL09a`G02TL5P0^7aL0<B4H03LV7@0k:Ah0@RdQ04L`8P1G>RP0Hd<_07iLA`2=JeP0ZHj2
0;JPU`31/:/0dl[60=WDcP3PgmL00P3QhMT00`3Qh=T0h>3H0>3Pf0070>7Pf0T0hN3I503QhMT01@3R
hMT0i^GM0>WXg`3Ui=`0f=O@02X0oooo:@3gmoL00`3Fa/h0S6=B07]SFP0206=:@P80Je9:00D0HdY2
07=JDP1JDU80Nf]k08acH`0208akL`0507]SFP1cFU80DSTa058i<@1B<BT00P1:<C401@1B<BT0BS4a
04Xa<@1SBT80FT8i0080HdY200@0DT8i048Y8@1SFV<0<B4Q0P12:C407@0Y61P0@RTa058a:@1:<C40
@RTa03TY8@12<CT0<B4Q02TH601B>DX0@S4i048Y<@1JDV<0@RTa05Y:FP1:<C40@RTa06]SJ`1SFV<0
FTYJ05YBDP1B@ST0BSU:048a>@1:<C40@RTa048a>@1J@ST0HdY200<0DSTa00D0Hd8a05Y2>@1B>C40
DSTa06=:@P0207=:@P0707=:>@24DT80W6]B08aSDP24He80mno_0?ooo`0d0?Ogmb00oooo000N0?oo
o`050=SGd03Yj>00jNSP0>CSf`3Rh]X07P3QhMT0A@3Rh]X0hn?L0>;RfP3EdLP0bL2f0:VHRP2IQ7H0
OFMI075LCP1MBSd0ET@h050n<`1A?c@0FDLl05i;@@1RD4D0J5I;06YHC@1/Fe00JUY?065AAP1JBSl0
BcX`04Dd:P0n;B<0?2/S03d/900n;BH0?RhW03d]9P0i:b80>2TP03HV7@0d9A`0;b<J02`Q6@0S6aD0
7aLC01H?3P0C30`04@X:01082@0@20X04@T<018:300B2Pd04`X=01H=400I41807ADF01dE5`0K4Q@0
6Q4B01hD4@0Q5a808aPC024F4P0M4a807aDD02hS7P0g:b@0A3D/04He;@11<2T0?2/U03DV8@0/7aX0
:QhH02`P600202dQ600I02`P5`0[7aL0:QhH02`P6P0_8Q/0=bLN03XY7`0n;280@2hS04Pa901>=2D0
Hd<`075@>`2@L5/0X85_0;VTV034/j/0c<2k0=SCcP3LfM<0h=oH0>7Pf@3QhMT0hN3H0>3Pf0090>7P
f0P0hN3I503QhMT01@3RhMT0i^GM0>WXg`3Ui=`0f=O@02X0oooo:P3gmoL02@2]S8@0S7=S06]BBP1S
BT80FT8i06=:@P1[DTX0FU9B07]SFP0208acJ`80S7]c00/0S7=[08A[FP1SBT80DT8i058i<@1B<BT0
DSTa04Xa<@1B<BT0DT8i05Y2>@0206=:@P0J06=:BP1B@ST0DT8i07=JDP1JBUX0@RTa048Y8@0i:B40
<B4Q04Xa<@12<CT0DT8i04XiBP12<CT0BSU:048a>@1SFV<0DT8i048a>@1B@ST0DTYJ06]BBP1SFV<0
@RTa03TY8@1SBT8207]SFP80HdY:00H0HdY205Y2>@1SBT80HdY205Y2>@1SBT8305Y2>@80HdY200X0
Je9:07=BBP1cDTX0Je9:06=:@P1kHe80S6=B0:EcFP24He80S5Y:=P3gmoLP0?ooo`007P3oool01@3H
em00jNSP0>WXh03Thm/0h^;J01l0hN7I0P3Rhm/0603Og]H0fmS@0<_3^@2m/jP0Vhan08QhJ@1YEdT0
GT`o0590=@1@?c@0ED<i05Y7?@1OC480JEM<06eKD01aHED0L65F06YLD@1VEd`0FTTo05=2>016=B`0
@S4X03h]9P80?R`W01@0?R`V03l/9010;B@0@C0W044`:00l;bL0>2dU02dU7`0W81`07AHE01TB4P0F
3`l05@d>01H>3`0J4AD071<H01hD6P0N5AX08ALK02<J6`80:1hM00l09A`M02DK7@0]81l0<B@Q03<T
7`0^81`09ATH02HK6P0h:RH0@S</04dk<P1<>S80AC8/044_:@0n;2H00P0k:R8203/[8@0E03XZ800i
:Al0>BTP03XZ8P11<2L0AS@Y04hk;@1@?Bh0CCX/04dh;01F?2h0HD@b085NB@2CLUd0]If=0<>`X`3D
bL40f=7:0=_Fd03Ng=H0gmkG0080h>3H303Qh=P70>7PfAD0hN7I00D0h^7I0>KUg@3Yj=l0iNCL0=SG
d00Z0?ooob/0moOg00h0imk_08acH`24JeX0Je9:06=:@P1B@ST0FT8i07]SFP1cFU80Nf=J09B4Q02<
Lf/0W8b<09B4Q080Nf=J0`1[DTX305Y2>@80BS4a01T0LeYB06=:BP1SBTX0Je9:05Y2>@1B<BT0BSU:
058i<@12:B40@S4i034Q8@1B<BT0DSU:06=:BP1B>DX0He9:06]SJ`1kLg/0Jf=[05YBDP1SFV<0DT8i
07][N`1JDU80Jf=[0080Nf=J00H0FU9B06=:BP1[DTX0HdY:058iBP1SBT8206]BBP0907=BBP1[DTX0
Je9:07=JDP1cBT80Le9:08AB@P1SBT80Hd8a0080LdXi00D0Q59209a[DP1cBST0LdXi0<je_@0g0?Og
mb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CSf`3Rh]X07`3QhMT20>;RfP0Z0>7Qf@3PgmL0e]?:
0<c6_02ZWi80V8Yl07MWF@1[FTh0FdY105M6?@1GA3/0FDLm05e:@01WE4T0JeU>06mOE01_H5D0K5iD
06UKD@1PD4L0FDY004dl<`18=bl0@c8[048a:`12<2/0@c0Z04Da:@16<RX0Ac@/04He;@10=2`0?38[
038[9P0]9R<091dN024J6`0O61T07QHF01lF5`0S6A`091XO0P0T6R40500V7B40:AlQ02dS8@0^9280
;28T02dR9@0e9bP0>BXX03XZ9@0d9B40:ahL02`O7P0m;RT0AcL_050m=@1?>c@0B3@^04Ha;015<2X0
A2lW0P14<2H05P14<2D0@BlT040_9011<2H0A38X04di;@1C?S00FdDd05a5=01E?bl0E3`^05m4=01/
Ccd0TG5M0:B7M035/Z@0dL>h0=cFcP3Nf]<0gmcE0>3Oe`3PgmP30>3Pf0/0hN3H1`3Qh=TE0>7Qf@05
0>;Qf@3ViMd0jNSO0>GTg03Hem00:P3oool00`3gknl0moOg0?Ogm`0Y0?Ogm`080=K>gP3>]Kd0S7=[
08A[FP1cFU80Le9:08A[FP1cFU8307]SFP0?07]cN`2DNg<0U8B408akL`24JeX0LeYB08acJ`2<Lf<0
Q6]J07]SFP1[DTX0HdY20592>@1[DTX0HdY:0080Nf=J0P1cFU80101[Hf/0HeYS06=:BP1kHeX2034Q
8@0606=JH`1SBT80FU9B06=BBP1[Hf/0Nf=J0P1[Hf/02`1JBUX0HdY:05Y2>@1SBT80Nf=J07=JDP1S
BTX0Je9:06=:@P1[DTX0HdY20080Je9:00H0HdY207=:>@1SBT80LdXi06=2<@1SBT8207=:>@80Q592
00H0S5Y:09ASBP1kHe80FT8i0;fUW03gknlh0?Ogmb00oooo000N0?ooo`050=SGd03Yj>00jNSP0>CS
f`3Rh]X08@3QhMT0E`3Rh]/0hn?L0>7Qf@3Kf]80b<>h0;bdZ@2TVHl0VHb408=cK@1hIf40IE=;061=
@`1NBd00H4e2069@A@1UE4T0IUI<06MJDP1WFe@0IEYD06=GD@1NCdL0G4]305U7?`1HASh0FDLo05U8
?`1IAcl0EdDm050o>@1<?CL0ACXe044i=00n>3L0?CLh03hf>`0o=SX0@3Li040e=00n<c40>Bd]03HY
;00a9B`0<2D]030U;00b9b/0=bXZ03T/;00m<C@0?c<h04@e=`15=C@0@S0Z03h/9P0g9b80>BPS04Dc
;01<>C40Dche05<l=01?=c00CcD^04le;01A=BX0DCDY054e:01@=RP0CCHZ04dg:`1?>bl0Dcha0617
=`1WC3X0LE8l071@>P1UAC80HD<b075FA`25K5`0/Yf>0<>cY@3Id<H0g]W@0>;Qf@3RhMX0h^7I0>7P
f0040>3Pf0X0hN3H1`3Qh=TF0>7Qf@050>;Qf@3ViMd0jNSO0>GTg03Hem00:P3oool^0?Ogm`060>ON
i`36[Kd0YHB409AkL`1kHeX0Nf=B0P1cFU80301kHeX0S7]c08akL`2<Lg/0W8b<08acJ`2DNg<0S7=[
08A[FP2DNg<0S7]c08A[FP<0S7=[0P1[DTX02`1cFU80Jf=[07][N`1kJg/0Nf=J07]cN`1kHeX0Jf=[
06=JH`1B<BT0HdY20080DT8i00D0FT8i05YBDP1kHeX0S7]c06=:BP0206]BBP0507=BBP1cFU80Je9:
06=:@P1SDTX00P1SBT800`1S@S40FT8i06=2<@0206=2<@0<06]BBP1cBT80Q59207=BBP2<FTX0Q6=B
09a[DP2<He80Q59207=:>@1cDTX0e/KN>P3gmoLP0?ooo`007P3oool01@3Hem00jNSP0>WXh03Thm/0
h^;J01l0hN7I01/0hN3I0>7Qf@3Rh]X0hn?K0>7QfP3Ng]H0dm770<c8_P2k/j/0/JNQ09^=R02=OWT0
Lf9J06UGCP1SDDH0GTa105i<@P1PCT@0HE16069ECP1SF5<0I5aI06EKF01VF540IeI>06IDB`1VE4X0
0P1VED`0?01SE4/0H51805I6@01@@C`0B3di04Dm>P15@400Ad5304a4B@1?ATX0DDM90556@P1>@Sh0
A3Hd03la<@0h:S00=RTa03DY<00f:Rh0>R`]03d^;`13=CT0ACPm04Pi>`18=cH0A34Z040^9P0m:R<0
?R`U04Ld;01=>C00Dc`c05<k<P1C>2l0DcH]05@f;01F=RX0ESHY05Lg:01F>2T0DcX/058k;P1E?c80
FT8d06I:>@1^Cc`0N5Do07QD?P1^BcL0Jd/i07iTE@2COVl0`;:V0<o5^P3NfM00hMkE0>;Qf@3RhMX0
hN7I0>7Pf0<0h>3H2`3Qh=P70>7PfA40hN7I103Qh=T01P3QhMT0h^7I0>KUg@3Yj=l0iNCL0=SGd2X0
oooo<03gmoL01@2eYJd0U7]c06]SJ`1cFU80Nf=J0080LeYB00P0S7=[08akL`2<Lf/0S7]c08acJ`2<
Ng<0S7=[08A[FP80S7=[00<0S7]c08acJ`2<Lf/00P2<Lf/02`1SFV<0Nf=J07=JDP2<Ng<0S7=[07]c
N`1cFU80Nf=J07]cN`1[Hf/0HdY:0080DSU:00H0FT8i04Xa<@1B>C40FT8i06=:@P2<Lf/206]BBP04
06=:@P1cBST0FT8i05Y2>@D0Hd8a00D0FT8i07=:@P1cDTX0Le9:07]SDP0208ASDP0708aSDP2<FTX0
Q6=B08AB@P1J@ST0LdY20=K6eP0k0?Ogmb00oooo000N0?ooo`050=SGd03YjN00jNSP0>CSf`3Rh]X0
9@3QhMT02`3Ph=P0gmkG0=WFd03Dc/X0`[Ve0;J/Y`2JSXH0Rgif07i_I`1XEe00HDm70080FdPo0480
Fdi805]ACP1PFUX0IUmN079WH@1gJF80NVYQ07YZH01hJEl0MVUO075UF`1]H5L0HEA=05a?BP1FC4T0
EDe;05UBD`1LEEL0IEUL06QKG@1ZGE`0J5UD06=DC@1D@cd0C3`h04<d=011<cD0?c4e03h_<P0n;Rl0
@2l`04@d=P16=ST0ASHf04Dd<@13<2P0@RlU04@`9P15<BL0BCD[04`g;@1B>2d0ECP]05Xh;01L>2/0
GCP[060i:`1Q>R/0HSh]0690;P1RA3<0HTDe06=6=P1TASH0KDXh07=>>`20FDH0Q5i;08MWE@2;KUh0
XHn20;:VV`3Dd<L0gM_C0>;RfP3RhMT30>7Pf080h>3H303Qh=P60>7PfA40hN7I103Qh=T20>7Pf006
0>7Pf@3RhMT0i^GM0>WWg`3Ui=`0f=O@:P3ooolb0?Ogm`040<jmaP2<Lg/0Nf=B06]SJ`80Nf=J01@0
S7=S08akL`2<Lg/0W8b<08acN`2<Ng<0U8B408akL`2<Lf<0S7]c08A[FP2<Ng<0U8B409AkL`2DQ8@0
S7]c08acN`1kJg/0S7]c08acN`80U8B400H0LeYB08acJ`1kJg/0Nf=J06]BBP1B>DX206=:BP80FT8i
0P1SBT8207]SFP0607=BBP1SBT80Je9:07=:>@1cBT80Q5920P1cDTX03@2<FTX0Nf=B08ASDP24JeX0
S7=S09acH`2<Lf<0S6=B08AB@P1SBT80S6=B0=K6cP3oool0?03gmoLP0?ooo`007P3oool01@3Hf=00
jNWP0>WXh03Ti=/0h^;J0280hN7I00<0hN3I0>7Qf@3QhMT00P3Rh]/0C@3OgML0g=SC0=3:a037`;X0
/:NP0:6GT02BQWl0M6AO06YGDP1OC4@0GD]305a?B@1KDTh0H5]K06IPH01eJfL0O6mY081aJ@1oL6P0
O6mV07Y^I01eJUl0LFIL06ULE01UF580HEMC061HE@1TFe/0IeeM06ePG`1_H5l0L65M06eLE@1WETh0
F4I0054o>P19>CH0B3Pg04De=P13<c<0@2h_040^;P11<300@S8a048b;P12<2/0@RlV04<_9P17<RP0
B3@Y04Xf:`1<=R`0DSL/05Hh:`1M>2X0H3T[068j:`1U?2d0ISh]06Q2<01YAC<0JTXi06]<>`1[BcX0
JdXi071;>@1eCcd0Pee=08YWE`2GNfd0WhQj0;FXW@32^[00fMO?0=oOe`3Rh]/0hN7I00D0h>3H303Q
h=P60>7PfA40hN7I0`3Qh=T40>7Pf0050>;Qf@3ViMd0jNOO0>GTg03Hell0:P3ooolb0?Ogm`050?oo
o`3Fa]H0[IBU08acH`24JeX00P1cFU803@1kHeX0S7=[08acN`1kLg/0S7=S07]SFP2LS8`0U8B409Ac
J`2<Ng<0S7=[08akL`2<Lf/00P2DNg<01`2UQ7/0U7]c09AkL`2<Lf/0U7]c09B4Q02<Lg/00P2<Lf/0
1@1kHeX0S7=[08A[FP1kHeX0Nf=B00<0LeYB00@0Jf=[07=JDP1cDTX0LeYB0P1kHe80101cBT80Nf=B
07=BBP2<FTX208A[FP<0W7=S00<0U7=[0:EcFP2<Lf<00P1cBST00`2]U9@0e/KN0?ooo`0m0?Ogmb00
oooo000N0?ooo`050=SGd03YjN00j>SP0>?Tg03Rh]X08@3QhMT20>7Pf@80hN7I0P3RhMX06@3Qh=T0
h=oH0=kMe@3Mfm@0dm390<S4_@2i/Zd0UXV708QiMP1iJF<0MVIO075VG`1^IV80KFQY075[K@1kLg80
P7Ec08AgL`24Mg80PWI`089fK`1oLf`0OW9Z07Y^IP1iK6@00P1gJVD02@1gJFD0MfQS07IUGP1eHe`0
M65I06mKD`1ZEdh0H4a405a8@00205Q4?@0U05A1>`1A?CP0BCDb04Db;`12;bX0@RlX048_9P13;bD0
AS8W04Td:@1>>Bh0D3/`058l<@1C?340F3`_05`l;P1T?Bd0Icl]06U0;P1[@S40Jd@b06e8=`1`C3/0
NUQ707iLC022H500PUm?089OD025HeD0TgE[09f3NP2fYYh0`kR_0=GAb@3Jf<l0gmkF0>3Of0020>7P
f0<0h>3H3@3Qh=P50>7PfA<0hN7I0P3Qh=T50>7Pf0050>;Qf@3ViMd0j>OO0>GTg03Hell0:P3ooolg
0?Ogm`030=K6eP2]U:D0Jf=[00<0LeYB00<0S7=[09b<S02DQ8@00`2LS8`20:fDU080U7]c00<0S7=[
08akL`2DNg<00P2DNg<0202DQ8@0YHB409b<S02DQ8@0U7=[09AkL`2DQ8@0U7=[0P2<Lf<00`24JeX0
S7=S08A[FP0408A[FP0308acH`2]Nf/0U7]c00<0]Hac00X0YHAk0:f4J`2]Q6/0YG=J07]SDP1cDTX0
S6=B0:F4Q03gknl0oooo@03gmoLP0?ooo`007P3oool01@3Hell0jNSP0>SXh03Si=`0h^;J0240hN7I
0P3Qh=T80>7Qf@0@0=cKd`3DdL/0al:m0:VOW02MTHh0Sh9l08b0N027OGL0Q7ah07miNP1nN7X0OgMh
085gM`24MgD0QGQe08QkM`80RGah0380R7]f08EhL@23MFh0PG9[081`JP1nK6L0O6YT07QUG@1fHeX0
MF5H071KD`1/F500IU1906==AP1RBd<0HD]305e8?`1IA3d0D3`f04di<`1:=Bh0BS@[04Td:@19=2P0
BcH[04hi;@1D?S<0ET4f05U2=`1K@SL0Gd8d0692<`1X@c40JT@a06]5<P1/AS<0JdHd06a9>01`CSh0
Oei@08MVF@2ALF<0Tg=U09EgJ@2GNfl0Xh^30:bHT@33^;40clS00=kLd`<0h=oG1@3Ph=P<0>7Pf0D0
hN3I4`3QhMT20>7Pf@H0hN3H00D0h^7I0>KUg@3Ximl0iNCL0=SGc`0Z0?ooo`030?O_k`3gmoL0moOg
03H0moOg00T0_KFm0:fL]@2<Nh`0S7]c08akS02]U9@0YIBU0;FLW02e[Kd00P2eW9`00`2]W:D0YHB4
0:F4N`020:F4N`0809AkL`1kHeX0S7]c09AkL`2UQ7/0YHB40:F4N`2LS8`30:F4N`80U7]c00@0YHAk
08acH`2DLf/0S7=S0P2DLf/01`2DNg<0[G][0:F4N`2UQ7/0U7]c08acH`24JeX00P2<Lf<207=BBP03
08AB@P2<Lf<0c[Fm04<0moOg803oool001h0oooo00D0emK>0>WXg`3Xj=l0hnCL0>;RfP0S0>7Qf@80
hN3I0P3Qh=P20>7Qf@180>;RfP3Shm/0hN7I0=gLe@3He]00blO10<G0^`2o^K80_KR`0;Ze[P2g/Jd0
ZjFU0::KW@2?Qh/0RH2308]nOP2@PX00VXb:09jAT02RUYL0XYFF09f?S02JRXH0UH5k099mMP2;MVh0
Qg9Z07mZH`1kIel0N6AL07=OF01bGEL0LEYF075IE@1aF540LEM?06]CB@1WD4H0H4Y105m8?`1OAcd0
H4Lk05e4=`1K@cD0F48d05U3=@1NB3/0HTXn06M=@@1YCT40Jddn06]=?@1/Cc`0Ke4n075D@@1bET<0
LEA3075DAP1fFDd0SG5X09^0N@2bVY<0^:BL0;n`Y`32]J/0akfe0<_3^`3FdLX0fmSA0>7Pf@3RhMT0
hN3H0`3PgmL>0>7Pf0@0hN3I5P3QhMT00`3Qh=T0hN3H0>7Pf0040>7Pf0050>;Qf@3ViMd0j>OO0>GT
g03Gell0:P3ooolo0?Ogm`80imk_00H0moOg0=K6eP36]LH0g/kF0>ONi`36]LH20:fDU00:0;FLW02U
Q8@0U7]c0:F4N`2DLf/0S7]c08acJ`24JeX0S7]c09AkL`<0YHAk102<Lf/01@2DLf/0S7=S08acH`2D
Lf/0S7=S0080Q6]J00P0Q6=B08A[FP2<FTX0Q6=B09AkL`2]U:D0e/K>0?oood@0moOg803oool001h0
oooo00D0emK>0>SWg`3Ximl0hnCL0>7RfP0S0>7Qf@80hN3I0P3Qh=P0B03Qh=T0hN7I0>7Qf@3QhMT0
h>3H0=kNeP3Lfm@0emC=0=CBb`3Ac/L0d<g60<k;a03;b<<0_kZi0;B^[`2LUIP0UHb@09J:RP2KSX`0
Z9^H0:fPW`2aYZP0/:BW0:^LW02WUiD0XHf809j9PP2FP7T0TGae08IbK020KFP0O6UT07ERGP1dH5d0
MEiL07EMG01eFeL0M5YC06mEC01[DdT0IDi406A=@`1WCT<0Ide206A;?@1QBCX0GDHg05e7>01QBSd0
I4/o06Y>@P1/Cd40K4lo06]??P1^E440LUU607MOC01mIE@0O6EE07eTF022JEh0VH9k0:RAS030[jT0
b;Zc0=38`03Bc<<0eM380=OBbP3Kf=40gM_D0>3Of080hN3H00<0h>3H0>3Oe`3Ph=P03@3Qh=P40>7P
fAL0hN7I00<0hN3I0>7Pf03Qh=P0103Qh=P01@3QhMT0iNCL0>SWg`3Thm/0emO?02X0oooo@@3gmoL0
2@3Wg^l0imkW0=K6eP3Fa]H0e/kN0>oWi`3Fa]H0]JF]0:fDY@020:fDU00909b<S02UQ7/0YHAk0:F4
N`2DLf/0S7=[08akL`2<Lf/0YHB40080YHAk0`2DNg<0302<Lf<0U7=[09AcJ`2DLf/0S7=S08A[FP1c
FU80Nf=B07=BBP2<Lf/0U8BD0=K6gTL0moOg803oool001h0oooo00P0emK?0>SXg`3Xj=l0hnCL0>;R
fP3Qh]X0h^;J0>;QfPP0h^;J203RhMXF0>;Qf@80hN7I00<0h>3H0>3Of03PgmP0103Ph=P07`3PgmP0
gmgG0=ODd03@cLT0`;bk0;^g]@2k]K80_kVd0<S1_03;aL40cLO70<_4aP35^[d0`[Jh0;n`[`2m[ZX0
]jJR0;6PW@2PSi00UXF808alP01mK780NFQ^07MTJP1gHfP0MEmO07=LF01_Edd0K5E:06UCA`1YDTL0
0P1[DdL06@1ZD4@0Idm106=<?P1RBch0Hd/n06A:?@1VBCX0ITTh06E8=P1VBSL0LU]807mZF02>NfX0
YIJ80:^LS`2]X9H0/:>J0;jaZ`36^kD0e/g80=_EcP3Pg]H0hN3G0>7Pf03Qh=L00P3PgmL00`3QgmL0
hN3H0>7Pf0020>7Pf0030>7Qf@3RhMT0h^7I02`0h^7I00H0hN3I0>;Qf@3ViMd0j>OO0>CSf`3GellZ
0?ooodd0moOg00/0imk_0=K6gP3Fa/h0[Ibe0;FU[@2eW9`0[IBD0:f<Q02DQ9@0[Hb408acN`0209B4
Q0050:fDU02LS9`0[IBU0<je]@3Fc]h00P3gknm<0?Ogmb00oooo000N0?ooo`050=SGd03YjN40jNWQ
0>GUg@3Si=/0103Shm/R0>CSf`<0hn?K0P3Sh]X90>;Qf@0M0=kMeP3KfM<0dm7<0=7?bP3AclP0dm7:
0=SFcP3Jem40f]OD0=OCd`3Ab/d0clK:0<o4a03?`l40b[fj0<Bf]@2aXZL0YIJM09V;TP25Mh00Og5j
07]/M@1jJW80N6EV07IRG`1bG5<0L5Y@06iIC@1^F4d00P1_F4d05P1^Ed/0KEI906YDA`1YDdH0J514
06M?@P1WBc`0IdXi06E9=P1WCCT0NF=A08YgIP2NSGh0_[:V0<Jk/@3;`[T0c<Bk0=;;``3Fd<P0gMWA
0>3Le@3Rh=P20>?Qf@050>;Qf@3RhMP0h^7H0>;Qf@3ShMT01`3Sh]X00`3ShmX0hn?K0>CSf`0U0>CS
f`030>?Sf`3Sh]X0hn;J0080hn;J00@0inKN0>WXh03Ui=`0f=O?:P3oool01@3gknl0moOg0?O_k`3g
moL0mno_0440moOg0P3gknl90?Ogm`030?O_k`3Wg^L0imkW0080c[g60P3Nc]H00`3Wg^L0knOW0?Og
m`1B0?Ogmb00oooo000N0?ooo`040=[JdP3]kN@0kNgT0>WYh0<0j>OO0P3Xj=lU0>WXg`070>SXg`3X
iml0j>OO0>OVgP3ViMd0i>;J0>?Qf@020>7Pe`0O0>;Qf03Rh]T0i^KM0>WZh03`lNH0l_CY0??fj`3c
mN/0lOCY0?3bj03/k^D0j^[T0>GSi03Uh^@0jNGV0>_WiP3Yi>80i=gN0=;9c`36_<D0^Zni0:>IY02K
TYd0U8^E09:9T@2?Q8D0SH1n08YkLP29NFl0RGQ^08UhK@0208MgK00L08QgK@29Mfd0RGM]08QfK025
LVL0PfmS07mYFP1mIUH0O6ID081ZF02FQ7@0Zi^=0<6dZ03Xh=L0l^gU0?SgkP3gm^d0lO7W0>k^i03X
imd0i^CJ0>?Pe`3SgmL0hn3H0>CQf@3Vi=/0inGM0>SVgP`0j>OO1@3YimlL0>WXg`80jNOO103Ximl0
1P3Ximh0j>OO0>_ZhP3]k><0j>OO0=[IdBX0oooo[@3gmoLP0?ooo`007P3oool01P3Jfm<0kNgT0>g/
i03YjN40j>SP0>SXgbX0jNSP04@0jNSO0>SWg`3WiMd0i>;J0>;Pf@3QgmL0hMoF0>7Pe`3RhMP0i^OM
0>_/h@3dm^X0n?[^0?Wll@3gno00m?S]0?;fj`3_lNL0kNkW0>[Yi`3Zj>T0k^c/0?3^k@3`kN/0k>SW
0=gGf`3Cc=80b<780;F^]P2^Z;00Yj:Y0:JPY@2RVi/0XIRE09nDR`2OTXT0Wi6709jAQ`2MT8H0W926
09fAQ`2NTHP0Wi6809jAQ`2KSH<0VHYo09F5M`2DPW<0Th9b09N6MP2[W8h0_;2S0=35^P3ajn<0n_O_
0?oom`3nooH0m_S]0?;cj03ZjMl0inGK0>?PeP3RgmH0hmoG0>CQf@3Vi=`0inKM0>WWgc40jNSP0P3Y
j=l20>SWg`040>_ZhP3]k><0jNSO0=[JdRX0oooo[@3gmoLP0?ooo`007P3oool0103AdLX0f][B0=[I
dP3Hem030=OGcbT0f=O@0P3Gell00`3Ge/h0eMG=0=GDc@020=CCc0060=CDc03EeLd0emO?0=WId03L
gM@0g]kE0P3NgmH05@3Lg]D0g=gD0=[Kd`3Jf]<0fMWC0=WIe03Jf]D0fm_F0=_Ke@3JfM@0e]C@0=?A
cP3@c//0b/S60<S6a035a<40aL?00<?2_@33`K/0`l2h0<:o]`030<:n]P030<6n]P32_kL0`[ng0080
`kng01X0`[je0<6m]030^k80_kZa0<2k/@31_;80al>j0<c9`03BclL0g=[C0=oNeP3QhMT0h>7I0=gN
e@3Kg=<0f=S?0=OFcP3Ee<`0eM?<0=GDc03Ee<d0e]K>0=OFc`3Gell0f=O?0=SGd0X0f=O?8`3Hem02
0=SGc`@0emO?00@0fMS@0=[Id@3If=40dM7::P3oool20?Ogm`030?O_k`3gmoL0moOg0:P0moOg803o
ool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3o
ool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0ooooAP3oool2@00007/0oooo
003o0?ooodP0oooo00=000000?ooo`3oool0N03oool004<0oooo0T0000030?ooo`90000000<0oooo
@000040000000P3oool00d000000oooo0?ooo`02@0000080oooo0d0000020?ooo`A000000P3oool2
@00000<0oooo0T0000030?ooo`=00000403oool3@00000<0oooo00A000000?ooo`3oool0oooo0T00
00060?ooo`06@000003oool0oooo0?oood000000oooo0d0000030?ooo`04@000003oool0oooo0?oo
o`900000U03oool2@0000080oooo0d0000020?ooo`=000000`3oool3@00000050?oood0000100000
@000003oool00T0000020?ooo`03@000003ooom0000000=0000000@0oooo@000040000100000I`3o
ool00480oooo00=000000?oood0000000P3oool00d000000oooo0?ooo`020?ooo`06@000003oool0
oooo@000003ooom000001@3oool014000000oooo0?ooo`3oool3@0000080oooo00I000000?ooo`3o
oom000000?oood0000040?ooo`04@000003oool0oooo@0000100oooo00=000000?ooo`3oool00P3o
ool00d000000oooo@00000020?ooo`03@000003ooom0000000H0oooo00=000000?oood0000000P3o
ool00d000000oooo0?ooo`020?ooo`03@000003ooom000000080oooo00=000000?oood000000TP3o
ool014000000oooo0?oood0000020?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0
oooo@00000020?ooo`04@000003oool0oooo@00000<0oooo00E000000?ooo`3ooom000000?ooo`03
@00000<0oooo00=000000?ooo`3oool0IP3oool00480oooo00E000000?oood00001000000?ooo`03
@0000080oooo00E000000?ooo`3ooom000000?ooo`03@00000<0oooo00=000000?ooo`3oool00`3o
ool014000000oooo0?oood0000040?ooo`=000000P3oool014000000oooo0?oood00000A0?ooo`03
@000003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oood0000070?ooo`03@000003oool0
oooo0080oooo00=000000?ooo`3oool00`3oool01T000000oooo0?oood000000oooo@0000980oooo
00A000000?ooo`3ooom000000P3oool00d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oo
od0000000P3oool014000000oooo0?oood0000030?ooo`04@000003oool0oooo@00000<0oooo00E0
00000?ooo`3oool0oooo@000001X0?ooo`00@P3oool00d000000oooo0?ooo`020?ooo`=0000000<0
oooo@000040000000T0000020?ooo`=000000P3oool4@0000080oooo0T0000000`3ooom00000@000
0002@0000080oooo0d0000030?ooo`=000004@3oool014000000oooo0?ooo`3oool2@00000<0oooo
0T0000070?ooo`03@000003ooom0000000<0oooo00A000000?ooo`3oool0oooo0T0000030?ooo`90
0000T`3oool01D000000oooo0?oood000000oooo00A0000000<0oooo@00004000000103oool3@000
00030?oood00001000000080oooo140000030?ooo`9000000`3oool00d000000oooo0?ooo`1V0?oo
o`00@P3oool00d000000oooo0?ooo`0K0?ooo`03@000003oool0oooo00X0oooo00=000000?ooo`3o
ool03P3oool00d000000oooo@00000020?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool01@3oool02D000000oooo0?ooo`3ooom000000?oood000000oooo@00000020?ooo`03@000003o
ool0oooo0080oooo00=000000?ooo`3oool0TP3oool014000000oooo0?oood00000P0?ooo`03@000
003oool0oooo06H0oooo00120?ooo`=000009`3oool2@0000140oooo00A000000?ooo`3oool0oooo
0d0000030?ooo`900000303oool014000000oooo0?ooo`3oool3@00000<0oooo0T00002C0?ooo`90
0000203oool00d000000oooo0?ooo`070?ooo`03@000003oool0oooo00/0oooo0T00001X0?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`007P3oool01@3Cd]40gM_J0=gKfP3Jf=L0emKE00@0f=SG1@3H
emH20=SHea@0f=WH0P3Hf=P30=SHe`040=SGeP3HemL0f=SG0=SHe`D0f=WH103HfMT0103If]T0fM[J
0=WJfP3Ifm/30=WLgP050=SFd`3GcL@0elg40=O9_`3Ibl400P3IcLD01@3Ic/H0fLo90=WAb`3IdL/0
fM3:00<0fLk800H0fM7;0=WBc03Id/`0fM;<0=WBb`3Jd/X20=[AbP050=[Ab@3Jd<T0f]390=[?b03J
clL00P3IclH01P3Hc/@0e/c20=G:`@3Eb/40e<No0=?4_080d/6h0P3A_kL20=2o]`060<jn]P3>_[D0
ckng0<no]`3@`;P0d<6i1@3A`KT01P3A`KP0dL2h0=6n]P3A_[H0d;fe0<jm/`80c;fb00H0c;fc0<bl
/`3;^jl0bk^_0<Zi[038]j`20<^o^0050=?Ad03Jh>80fn7S0=_Qh`3JgMh00P3Ifm`00`3Ifm/0fM[J
0=WJfP020=WJfP050=WJf@3If=L0fMSG0=WGe`3IfMP00P3If]X00`3If]T0f=WI0=SIf00:0=SIf080
f=SH103Hf=L01@3Gf=L0f][I0=gMg03MgM`0dm?B02X0oooo2@3gmoL20?O_kc80moOg00<0kmK>0>o>
]@3_c[D0103ge[d20?OFaP<0mmk>00<0mmK60?ONcP3gg/h02@3gg/h40?OFaP80mmJm0P3_c[D40>o6
[@80ikFL00@0ikfU0>NeW03W]I`0ikFL3@3N[I@20=jUS0040=JUS03FYH@0gYb40=jLQ080eZF<0P3F
YH@00`36W8@0eZF<0?Ogm`0>0?Ogm`80mno_4`3gmoL00`3gknl0moOg0?Ogm`060?Ogmb00oooo000N
0?ooo`050=gKfP3]i^H0kNKV0>[ShP3Vhn800P3Wi^D01@3WinH0inKU0>OShP3Whn80in;Q0080in?R
00H0inKU0>OWiP3WinL0inOW0>OXi`3WjNP20>OXj0030>OXi`3Wj>P0inWX0080inWX00<0inSW0>OW
i`3WinL01@3WinL30>SWi`050>SWiP3Xi>@0j>CT0>SShP3Xhn<00P3Xi^D20>SXi`H0j>SX00H0j>WY
0>SYjP3Xj^X0j>[Z0>S[k03YkO020>W]k`050>WUhP3Yfm40jM_A0>WFbP3Yeld00P3Yf<l01@3YfLh0
j=c@0>SNe@3Xg]D0j=gF00<0j=[C00H0j=kF0>SQf@3YhMT0jN7I0>[PeP3[g]<20>_Lc`050>_Jc@3Z
f/`0j][<0>SJc@3Wf/d00P3WfL`01P3Ve/X0hm?70>3?a03Pcl@0gL_00=_7_080f/Bi00@0fl:h0=_3
^@3J`[P0f/:h0P3G`KL20=[5^`030=g9_P3Nb/00g/[00080g/[00P3ObKl01P3Oakd0glFk0=o4^`3O
a;/0g/Bk0=_4^@80f<>i00H0el>h0=O1]@3F`;00e/2`0=>o[`3@`KH20=C=b@050>3Rh`3Zl_D0k??g
0>ccm`3Zko400P3YkNh0103Yk>`0jN_[0>S[j`3Xjn/20>SZjP80j>WY00H0j>WX0>SZj@3XjnX0j>_Z
0>SZj@3XjNP20>SXj0D0j>SW00<0j>OW0>OWi`3WinL01@3WinH20>OViP050>KVi@3ZjNP0kNc[0>g/
j`3MgM`0:P3oool00`3gknl0moOg0?Ogm`020?Ogm`80mno_403gmoL00`3gknl0moOg0?Ogm`0S0?Og
m`030?OWgP3gc[D0mlje0080mmJm1P3ge/H00`3gg/h0mmK60?ONcP030?ONcP80mmK6103gg/h40?OF
aP<0klje0P3_aZd60>NmY@030>NeW03N[I@0gZfD00D0gZfD00<0gZF<0=j]U03N[I@00P3N[I@20=jU
S0030=j]U03NYH`0eZF<00H0eZF<00D0eZF40=JUS03FYH`0aYb40=JUS00:0?Ogm`030?O_k`3gmoL0
moOg0200moOg803oool001h0oooo00D0gM_J0>gViP3]i^H0j^?R0>KShP020>OVi@050>OWiP3Wi^D0
in?R0>OShP3Wh^400P3Whn801P3Wi^D0inOV0>OWi`3WinL0inSW0>OYj080inSX00<0inSW0>OXj03W
jNP00P3WjNP00`3Wj>L0inOW0>OWi`050>OWi`<0j>OW00D0j>OV0>STi03Xi>@0j>?R0>SSh`020>SV
i@80j>SW1P3Xj>P01P3XjNT0j>WZ0>SZjP3Xj^X0j>_/0>W]l080jNg_00D0jNGR0>WKd@3Yfm40jMK:
0>WGc@020>WHc`050>WIcP3Xg=00j=kE0>SNe@3XgMH00`3Xf]<01P3Xg]H0j>7I0>WQf@3YhMT0j^3F
0>_Nd`80jmc?00D0jm[=0>[Jc03Zf/`0j=[=0>OJc@020>OIc0060>KFbP3SdlL0h<o40>3?a03Mbl00
flNl0P3Ja;T0103K`[P0fl>i0=[2^03J`[P20=O1]`80f/Fk00<0gLVn0=k:`03Nb/000P3Nb/020=o9
_`060=o7_@3OaK/0glBk0=o4^`3Na;/0flBi0P3H`kT01P3G`kP0el6e0=K0/03F`;00dkn_0=31]P80
e<g900D0h>;S0>[bm@3/loL0k??g0>[_l@020>W]kP040>W/k03Yjn/0j>_[0>S[j`80j>[Z0P3XjNT0
1P3XjNP0j>[Y0>S[jP3XjnX0j>[Y0>SYj080j>SX1@3Xj>L00`3XinL0inOW0>OWi`050>OWiP80inKV
00D0i^KU0>[Yj03]k>/0kNc[0=gMg00Z0?ooo`030?O_k`3gmoL0moOg0080moOg0P3gknl@0?Ogm`03
0?O_k`3gmoL0moOg02<0moOg00<0mnON0?O>]@3gc[D00P3ge[d60?OFaP030?ONcP3ge/H0mmk>00<0
mmk>0P3ge/H40?ONcP@0mmK60`3_c[D20>o6[@H0ikfU00<0ikFL0=j]U03N[I@01@3N[I@00`3NYH`0
gZfD0=j]U0020=j]U080gZF<00<0gZfD0=jUS03FYH`01P3FYH`01@3FYH@0eZF<0=JUS036W8@0eZF<
00X0moOg00<0mno_0?Ogm`3gmoL0803gmoLP0?ooo`007P3oool01@3Jf=L0j^?R0>[ShP3Vgmh0hmkM
0080hn7P00D0hn?R0>?Rh@3Sgmh0hmoN0>?Mg@020>COgP030>CRh@3Ti><0i>CS01D0i>CS00D0i>?S
0>CQh03ThN00i=kN0>CPg`020>CRhP030>CTi03TiN@0i>GU00<0i>GU0P3Ti^H01P3Ti^L0i>OW0>CW
j@3TinT0iNW[0>G[kP80iN[]00D0iN;O0>GHc@3Uf<d0iM;50>GBb0020>GDbP050>GEb03Uel/0iM[@
0>GJd03UfM800`3Uem001P3Uf]<0iMcE0>KLe@3Vg=D0i][@0>KGbP80i=C500D0hM720=o@`@3Od<40
gm320>3?`P020>3=`0060=k:_P3Kak/0elBi0=O4^@3D`[L0d[nd0P3B_K801P3C_K80e;fc0=>m/`3C
_K<0dK^a0=6l/P80e;ne00<0el>h0=S4^@3Ia;X00P3Ia;X20=W3^@060=W0]P3J_[@0f[jd0=Zn]03H
_[@0eKjd0P3C_[@01P3B_K80d[^^0=6jZP3A^ZX0ckf^0<o7_`80e=OG00D0gnO[0>SamP3Yl_H0jO;f
0>O^l@020>K[k@050>KZj`3UjNX0iNWY0>GYj@3Uj>T00`3Uj>P00`3UinL0i>OW0>CViP020>CViP04
0>CVi@3TiND0i>GU0>CUi@<0i>GT0P3Ti>@50>CTh`030>?Sh`3Shn80hn?R0080hn?R00@0i^KU0>[Y
j03ZjNP0f][I:P3oool30?Ogm`030?O_k`3gmoL0moOg00D0moOg00D0mno_0?Ogm`3gmoL0moOg0?O_
k`0I0?Ogm`030?O_k`3gmoL0moOg0140moOg00D0mnON0?OF_@3ge[d0mmJm0?OFaP030?OF_@<0mmk>
0P3ge/H30?ONcP050?OFaP3gg/h0mmk>0?OFaP3ge[d00P3ge/H40>o>]@@0klJ]0`3W_JD00`3N]I`0
ijfL0=j]U0030=j]U0<0eZF<00<0gZF<0=j]U03N[I@00P3N[I@20=jUS0<0gZfD00<0gZF<0=JUS03N
YH`00P3NYH`00`3FYH`0gZF<0=jUS0020=JUS080eZF400<0aYb40=K6_@3gmoL0;03gmoLP0?ooo`00
7P3oool01@3GemH0i^?R0>KShP3Sg]d0gm[I0080gm_J00D0gmgL0=oNg@3OgM`0gmgL0>3Lf`020>3M
g0060>3OgP3Ph=l0h>3O0>3Pg`3Pg]h0h=kM0P3Pgmh01P3Ph=l0h=oN0>3Ng@3Pg]d0h=kN0>3Pg`<0
h>7P1`3Ph>001@3Ph=l0h=kN0>3NgP3PgMd0h=kM0080h>3O0P3PhN420>3QhP060>3RhP3Ph^<0h>;S
0>3Rh`3Phn@0hNCU0P3Qi>H01@3Qi^P0hNS/0>7WjP3QinX0h=kK0080gm;700H0h<bn0>7=`03Rcl@0
h/o40>7@a@3Qd/L20>7Db`030>7Ec@3QeLh0hMG>0080hMG>00D0h]K?0>;FcP3Re/h0h]C:0>3@``02
0=[<_@050=C9^`3BakX0d/Nj0=G6^03H`kH00P3H_k<01@3F^k40dkZ_0<nj[P3?^Zh0cKZ_00<0cK^`
00H0c[^`0<nl/@3?^k40ck^a0<jj[`3>^Jh20<nj[`050=2k/03A_;40dKbb0=6l/P3A_K800P3B_;40
1P3B^[00d[V^0=:i[03B^J`0dKV/0<ni[@80c[R^00H0cKN/0<feZ03<]:D0c;BU0<jl/@3Cd<`20=[S
i`050>7^m03Ul?H0iNoc0>G_l`3Tk>l00P3SjN`0103Rj>X0h^OX0>;Vi`3Ri^L40>7UiP030>7Ti03Q
h^80hN7Q0080hN7Q0`3Ph^80103Ph^40h>7Q0>3Qh@3PhN420>3Qh0<0h>3P0`3Ph=l01@3Oh=l0gmoO
0=oOg`3Ogmh0hn?R0080i^KU00<0emSG0?ooo`3oool0:03ooolm0?Ogm`030?ONcP3gc[D0mlje0080
mmJm0`3ge/H01@3gg/h0mmK60?OFaP3ge/H0mmk>00H0mmK600@0mmJm0>o>]@3ge[d0mmJm0`3_c[D2
0=K6]@<0ikfU00<0g[FU0=jeW03N]I`0103N]I`50=j]U0030=JUS03NYH`0gZF<0080eZF<0P3NYH`0
1@3N[I@0gZF<0=jUS03FYH`0gZF<00<0eZF<00<0gZF<0=JUS03FYH`00P3FYH`20=JUQ0030=JLQ03g
knl0moOg0140moOg00D0mno_0?Ogm`3gmoL0moOg0?O_k`040?Ogm`80mno_1`3gmoL01@3gknl0moOg
0?Ogm`3gmoL0mno_00@0moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0hn7Q0=oKfP020=oIf003
0=oKfP3Og]d0gmoN00@0gmoN00H0gmoO0>3Pg`3Pgml0h=oO0>3Mg@3Pg=/20>3Mg@060>3Og`3Pg]d0
h=cK0>3Lf`3PgMd0h>3O0`3PhN0<0>3Ph080h>3Q00@0h>7Q0>3QhP3Ph^80h>;R0P3Ph^<20>3Si006
0>3Si@3Pi>H0hNGW0>7Ui`3Qi^T0hNS]0P3QinX01@3Og=T0gLo30=g?``3NbKT0h<^l0080hLk200D0
h]360>7@b03QdLT0hM790>7Cb`030>7EcP060>;Cc03Rd//0h];:0>;BbP3QdLH0g/k10P3Gbkh01@3?
b;d0cLFj0<g5^P3B`[H0e[fb0080ekR_00H0e;B/0=6dZ@3>]JT0c[FY0<fh[03>^Zh20<jk/0060<nl
/@3@_K80d;bb0=2l/P3@^Jl0ckN]0P3=]Z/00`3<]Z/0c;N[0<fg[0040<fg[0030<jg[03>]j/0c[NX
0080c[NX00D0c[NZ0<ffZ`3=]Z/0c;BY0<^aY0020<ZaX`060<nn]03JfMP0hnoe0>?_m@3VmO`0i_;g
0P3Uko<01@3Tk?00hn[]0>?Zk@3SjN/0h^SZ0080h^OX00H0h^KW0>7Vi`3QiNH0hNGV0>7Ti03QhN42
0>7Og`060>7Ph@3Ph^80h>?S0>3Sh`3Ph^80h>;Q0`3PhN430>3Qh0030>3Ph03Ph=l0h>3O0080gn3O
0`3Ogml0103Shn80inKV0>OViP3Hf=LZ0?ooo`@0moOg0`3gknl<0?Ogm`<0mno_0P3gmoL20?O_ka00
moOg00<0mno_0?Ogm`3gmoL0403gmoL00`3_e/h0klje0>o>]@040?OF_@D0mmK600<0mmk>0?OF_@3g
e[d0103ge/H01@3Fa/H0klje0=K6_@3Fa[d0e/Je00<0ikfU0`3W[I`00`3N]I`0gZfD0=jeW0070=je
W080g[FU00<0gZfD0=JUS03FYH`01P3FYH`20=jUS0050=JUS03NYH`0eZF40=JUQ03N[I@01`3FYH`0
0`3N]I`0moOg0?Ogm`0@0?Ogm`80mno_6P3gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3ShN40
gm_J0080gmWH00<0gm_J0=oNg@3Ogmh0103Ogmh01P3Ogml0h>3O0>3Og`3Pgml0h=gM0>3Lf`80h=gM
00H0h=oO0>3Ng@3Pg=/0h=cK0>3Mg@3Ph=l30>3Qh0`0h>3P0P3Ph>40103PhN40h>7R0>3RhP3Ph^82
0>3Rh`80h>?T00H0h>?U0>3TiP3QiNL0hNGW0>7Vj@3Qj>d20>7WjP050=oLf@3Mcl<0gLo30=k9^@3P
bk`00P3Qc/801@3Rd<H0hM380>7Ab@3QdLT0hM?;00<0hMG>00H0h]?<0>;Bb`3Rd/X0h];:0>7AaP3N
c/420=O;_P050<o8_@3=aKX0cLFj0=;2]P3F_K800P3G^:l01P3D]:`0dKBY0<jeZ@3>]JT0cKR/0<jj
[P80c[^`00H0ckba0=2m/P3@_;80d;bb0=2i[`3?]jd20<ffZ`030<bfZ`3<]j/0cKN/00@0cKN/00<0
c[N/0<jgZ`3>]jP00P3>]jP01@3>]jX0cKJ[0<ffZ`3<]:T0bk6T0080b[6S00H0ckjd0=[If03SkoD0
hnoe0>Keo03Vl_L20>G_l`050>C/l03Sj^d0hn[]0>?Yj`3Rj>X00P3RinP01P3Ri^L0hNKW0>7UiP3Q
iNH0hNCT0>7Qh@80hMoO00H0hN3Q0>3RhP3Phn<0h>?S0>3RhP3Ph^430>3Qh@<0h>7P00<0h>3P0>3P
g`3Ph=l00P3Oh=l30=oOg`040>?ShP3Wi^H0inKV0=SHebX0oooo103gmoL30?O_k``0moOg0`3gknl2
0?Ogm`80mno_403gmoL00`3gknl0moOg0?Ogm`0@0?Ogm`030>oFcP3_c[D0klje00@0mmJm1@3ge/H0
0`3gg/h0mmJm0?OF_@040?OFaP050=K6aP3_c[D0e/Jm0=K6_@3Fa[D00`3W_JD30>N]W0030=jeW03N
[I@0g[FL00L0g[FL0P3N]JD00`3N[I@0eZF<0=JUS0060=JUS080gZF<00D0eZF<0=jUS03FYH@0eZF4
0=j]U0070=JUS0030=jeW03gmoL0moOg0100moOg0P3gknlJ0?Ogmb00oooo000N0?ooo`050=SIf03W
jNP0inWX0>?ShP3Ofm/00P3OfMP00`3OfmX0gmkM0=oPg`040=oPg`@0h>3O00H0h=kM0>3Mg@3Pg]h0
h=kN0>3Og`3Pgmh20>3Ng@030>3NgP3Ph=l0h>7P00T0h>7P1`3PhN400`3PhN80h>;R0>3Rh`020>3R
h`050>3Si03PhnD0h>?U0>3TiP3QiNL00P3QiNP01@3QinX0hNW]0>7WjP3QinX0h=_H0080g/g100H0
glNg0>3:_03Qc/<0hLk30>;?aP3QclL20>7?b0060>7Ab@3Qdl/0h]?<0>;Cc03Rd/X0h]780P3RdLH0
1@3Rd<@0glo30=_=``3KcL<0e/c30080e<[000H0e/Jj0=W0]P3K^[@0fkZd0=Vf/03D]:/20=6eZ006
0=2fZ@3A]j/0d[R_0=:h[`3C^K40dkZb0P3C^;401P3A]:`0ck6Y0<bbZ03</ZP0b[>X0<ZdZ0<0bkBX
0P3;]:T00`3<]JT0c;FX0<beY`020<beY`050<jfZ@3>]ZX0c[JZ0<fcY`3:[j800P39[Z401P3@_K@0
g=_K0>Kcn@3VloT0j?Oo0>Kbn080iNod00D0i>ga0>C[k`3Tjnl0hn[]0>?Yj`020>;XjP060>;Wj03R
i^P0hNKW0>7Vi`3Qi>D0hN;S0P3QhN40103Qh^80hN?S0>3Sh`3Phn<20>3RhP80h>;Q0P3PhN430>3Q
h080h>3P00<0h>3O0=oPg`3Oh=l00P3Oh=l0103Shn80inOV0>OWiP3Hf=LZ0?ooo`030?O_k`3gmoL0
moOg03X0moOg00D0mmK60?OF_@3ge[d0mmJm0?OFaP020?OF_@030?OFaP3gg/h0mmK600T0mmK600<0
mmJm0=K6aP3g_KD0103g_KD20>nm[@80kkfU00@0ikFL0>N]W03W[I`0ijfL103NW8`20=j]U080g[FL
00<0eYb<0<J]Y@3FYH`01P3FYH`20=j]U080gZF<0P3FYH`00`3NYH`0eZF<0=JUS0050=JUS0030=K6
_@3gmoL0moOg02T0moOg0P3gknl00`3gmoL0oooo0?ooo`0N0?ooo`007P3oool01@3HfMP0inWX0>OY
j03Shn80gmcK0080gm[I00<0gmcK0=oOgP3Oh=l0103Oh=l80>3Pg`80h>3P0P3Ph=l20>3Ph0@0h>7P
2P3PhN401@3PhN80h>;R0>3RhP3Ph^80h>;S0080h>?S00H0h>?T0>3Si@3Pi>D0h>CU0>3TiP3QiNL2
0>7Vj0050>7WjP3QjNd0hNOZ0>7WjP3Qg=P00P3Qc/401P3Qb;P0hLZm0>7=``3QcL<0hLk50>7?aP80
hLo70P3Rd<P30>;Ab@050>;Aa`3RdL@0h]740>;Aa@3Rd/P00P3Qd/X01@3Pd//0g]770=kAa`3LcL40
gLRn0080gl6m00H0g[bh0=Vi/03E]jX0eKNZ0=FeZ03F]JX20=Jf[@80ekNa0P3F]:l0103C/:/0d:fW
0<f_YP3=[jH20<ZaYP80bk:W00D0bk>X0<^dZ@3;]:T0bkBX0<^cY`020<^cYP060<fdY`3@]ZT0d;JY
0=2fZ@3=/ZD0bJjO0P39[Il01P3?_K<0g=[I0>Kam`3VlOL0j?Kn0>Kbn080iNod00D0i>gb0>C/k`3T
k>l0hn[^0>?Yk0020>;XjP060>;Wj@3RinP0h^KW0>;Vi`3QiNH0hNCU0`3Qi>@0103Qhn@0hN?S0>7S
h`3Phn<30>3RhP050>3Rh@3PhN40h>7Q0>3Qh@3PhN000`3Ph>001@3Ph=l0gn3O0=oPg`3Ph=l0hn?S
0080inOV00<0f=SG0?ooo`3oool0:03oool50?Ogm`80mno_=P3gmoL01@3ge/H0mlje0?O>]@3ge[d0
mmK60080mmJm2@3ge/H01@3_c[D0mmJm0?OF_@3_c[D0mmK60080mmJm00@0mmK60?OF_@3ge[d0klje
0`3g_KD01P3__Jd0ikFL0>N]W03W[I`0ijfD0=jLS080ijfL00D0kkFU0>N]W03N]I`0g[FL0=jLS003
0=JUS0030=jeY@3FYH`0eZF<0080eZF<0P3FYH@00`3FYH`0gYb40=JUS0020=JUS0030=j]U03FYH`0
eZF<00@0eZF<00<0mnON0?Ogm`3gmoL0;03gmoLP0?ooo`007P3oool01@3HfMP0inSW0>OXi`3Shn<0
gmkM0080gmgL00<0gmgM0=oOgP3Oh=l0103Oh=l20>3Pg`<0h>3P2@3PhN0;0>3Qh@80h>7R103Ph^80
0`3Ph^<0h>?S0>3Si0020>3Si0050>3Ti@3Pi>H0h>CV0>7Ui`3QiNP00P3Qi^T01@3Qin/0hNW]0>7W
jP3QinX0hMgI0080h]3300H0h/Vi0>7:^`3QcKl0hLfo0>7>`@3Qc/<20>;?a@80h/o70`3Rd<P01@3R
d<L0h]760>;AaP3Sd/L0hmG<0080i=O?00D0i=O@0>?Fc@3Se/d0hM;90>3>a0020>39`@060=k3_03K
_[D0fKZ`0=Vj/03I^Jd0f[V]0P3J^[001P3J^K40fKJa0=Re/03H]K00f;B^0=FbZ`80d:nW00D0cJbS
0<f/Y03=[jP0cJnX0<je[@020<fg[@060<^dZ@3;/JD0cK6T0<faY03?/ZD0dK>V0P3@/ZD01P3=/:80
bJfN0<Z_X03:[j00dKnd0=cKf@80iO3f00D0ioGl0>Kbn03Uko@0iNod0>C^lP020>C/l0060>?[kP3S
j^d0hnW[0>?Yj`3Rj>X0h^OY0P3Ri^P01P3Qi^L0hNGV0>7UiP3QiNH0hNCU0>7Ti080hN?T00<0hN?S
0>3Rh`3Ph^800P3Ph^840>3Qh@80h>7P0P3Ph>030>3Pg`040>CSh`3WinH0inOV0=SHf2X0oooo203g
moL00`3gknl0moOg0?Ogm`0b0?Ogm`<0mmJm1P3ge/H20>o>]@040?OF_@3ge/H0mmK60?OFaP@0klje
1`3ge/H0103_c[D0mmJm0?Nm]@3g_KD20>nm[@80kkfU0P3W_JD20>N]W0060>neY@3__Jd0kkFU0>ne
Y@3W[I`0gYb<0P3NYH`20=JLS0<0eZF<0P3N[I@20=JUS080gZF<00@0eZF<0=jUS03FYH@0eZF4103F
YH`_0?Ogmb00oooo000N0?ooo`050=SIf03Wj>L0inSW0>?Sh`3Og]d00P3OgM`00`3OgMd0gmoN0=oP
g`040=oPg`80h>3O0`3Ph>090>3Qh0/0h>7Q0P3PhN840>3RhP030>3Rh`3Phn<0h>?T0080h>?T00D0
h>CU0>3TiP3Pi>H0hNGW0>7Uj0020>7Vj@050>7Wj`3QjNd0hNOZ0>7WjP3QgMT00P3Rd<<01P3RbKT0
hLZk0>7=_`3QcKl0hLk10>7>``80h/o50P3RclL30>;@b0050>;@a`3RdLH0h]760>?Ba`3SeL`00P3T
ell01@3Tem00hmK=0>?Fc@3Qd/T0h<k40080h<W100H0g/>l0=^n]@3I^[00fKZ`0=Vi[@3J^Jd20=Zj
/0060=Zi/@3I][40f;F`0=Re/03H]:h0eK:[0P3@[jL01@3=[:<0cJbT0<f_Z03=[jP0c[F]0080cKN]
00H0bkBY0<^aY@3=/J@0cK6T0<nbY@3A/jH20=2bY@060<f`XP39[Ih0bZnP0<Z_X03A_k@0g=_I0P3U
l?H01@3WmO`0i_;h0>G_m03Uko@0i>kb0080i>c`00H0hn_^0>?Zk@3SjN/0hnW[0>;XjP3RinT20>;V
j0060>7Vi`3QiNH0hNGV0>7UiP3Qi>D0hNCT0P3Qhn@00`3Qhn<0h>;S0>3RhP020>3RhP@0h>7Q0P3P
hN020>3Ph0<0h>3O00@0i>?S0>OWiP3WinH0f=SH:P3oool80?Ogm`030?O_k`3gmoL0moOg0380moOg
0`3ge[d60?OFaP80klje00@0mmJm0?OFaP3ge/H0mmK6103_c[D70?OFaP040>o>]@3ge[d0mkfe0?Nm
]@80kkf]0P3__JD20>NmY@80ijfL00H0kkFU0>nm[@3_]JD0kkFU0>N]W03NW8`20=jUS080eYb<0`3F
YH`20=j]U080eZF<0P3NYH`0103FYH`0gZF<0=JUQ03FYH@40=JUS2l0moOg803oool001h0oooo00D0
f=WH0>OWiP3WinH0hnCS0>3Og`030=oOgP@0gn3O103Ph=l30>3Ph0L0h>7P2P3PhN430>3QhP<0h>;R
0`3Ph^<01@3Phn<0h>?T0>3Si03Phn@0h>CU00<0h>CV00H0hNGW0>7Vj03Qi^T0hNKY0>7Wj`3QjNd2
0>7WjP030>7NfP3Qd/D0hM;50080hL^i0P3Qc;`0103QcKh0h/k00>;>``3Rc/<20>;?aP80h/o700H0
h]370>;@b03RdLP0h]780>?Cb`3Se/h20>?Hd@050>CId@3Tf=00i=S@0>?EcP3Rd/T00P3Pcl@01P3N
bKl0gLBk0=g0]`3M`;L0gKnd0=fo/`80gKnd00H0g;bc0=Zh/@3J^;40f[Ra0=^l/`3J^[020=FaZ@05
0=2YX`3?Z:<0d:jX0=2^Z03@]Zl00P3?^K401P3<]J/0c;6U0<j`X`3>/:<0d:nR0=2_X@80cZjP00H0
bjfO0<Z^W`3=]:D0cKBU0=C5^`3Ng]`20>G`mP050>Odn`3VlOL0iNod0>G_m03Tk_800P3Tk?001P3S
jnl0hn[]0>?Yk03SjN`0h^SZ0>;Xj@80h^OX00H0h^KX0>7Vi`3QiNH0hNGV0>7Ti@3Qi>@20>7Si003
0>7Sh`3Phn<0h>;R00<0h>;R1@3PhN400`3PhN00h>3P0>3Pg`020>3Pg`040>CTh`3WinH0inOV0=SH
f2X0oooo4P3gmoL00`3gknl0moOg0?Ogm`0X0?Ogm`030>o>]@3ge[d0mmJm0080mmJm0P3ge/H20?OF
_@80mmK600<0klje0?OFaP3ge/H01P3ge/H40?ONcP@0mmK60P3_c[D01P3_aZd0kkf]0>o6[@3_aZd0
kkfU0>NmY@80kkfU00H0kkFU0>N]W03_]JD0kkFU0>nmY@3W[I`20=jLS0050>N]U03NW8`0eZF<0=JU
S03N]JD00P3N[I@00`3FYH`0gZfD0=jUS0030=jUS0@0eZF<0P3N]I`_0?Ogmb00oooo000N0?ooo`05
0=SIf03WinH0inOV0>CTh`3Ph=l01P3Oh=l40>3Pg`@0h>3P1@3PhN0;0>3Qh@030>3QhP3Ph^80h>;R
00<0h>;R0P3Ph^<20>3Sh`80h>?T0P3PhnD00`3Pi>D0h>CV0>7Ui`020>7Ui`050>7Vj03Qi^T0hNKY
0>7Wj`3QjNh00P3RjN`01@3Rgm`0hM?50>7Ca@3QbkT0hL^g0080hLbk00H0h/fn0>;=`03Rc/40h/k1
0>;>``3RclD20>;?aP040>;?a`3RdLT0h]?;0>;Cb`80hmG=0P3Se/h01@3Se/l0i=O@0>CGd03Tem00
hmK>0080hM?900H0h<o50>3<`@3Pb;d0h<Rm0=o5^@3N`kL20=k2]`060=fo]P3L_;<0g;bb0=bl/P3L
_[80f[^`0P3G/j/01@3C[JL0dJbU0=2_Y`3@[jL0d;>[0080d;J^00H0c[J]0<fdZP3=/J@0cK6T0<f^
X03=[9h20<^[W0060<V[W03;[j80dK^`0=6k/03Ic/P0hN?T0P3VlOH01@3VloX0i_7g0>G_m03Uko@0
i>kb0080i>c`00H0i>__0>?Zk@3SjN`0hnW/0>;Yj`3Rj>X20>;Wj@060>;Wj03Ri^L0hNGV0>7UiP3Q
hn<0hN7R0P3Qh^<20>7Sh`80h>?S103Ph^830>3Qh@80h>7P0P3Ph>001@3Ph=l0i>CS0>OWiP3WinH0
f=SH02X0oooo?@3gmoL00`3_c[D0mmJm0?OF_@040?OF_@040>o>]@3ge/H0klje0>o>]@H0mmK61P3g
g/h30?OFaP@0mmk>00D0klje0?O6[@3gaZd0mlJ]0>o>]@040>nm[@@0kkFU0`3W[I`20=jLS0<0gZfD
0`3N]I`01@3FYH`0gZfD0=j]U03N[I@0gZF<0080gZfD00@0eZF<0=j]U03g_KD0mkfe403gmoL00`3g
knl0moOg0?Ogm`0L0?Ogmb00oooo000N0?ooo`050=SHf03WinH0inOV0>CTh`3Ph=l00`3Oh=l40>3P
g`L0h>3P103PhN0;0>3Qh@D0h>;R0`3Ph^<01@3Phn<0h>?T0>3Si03Phn@0h>?U0080h>CU0P3Pi>H2
0>7Ui`060>7Uj03Qi^T0hNOZ0>7WjP3Rj>/0hNO[0P3Pi>H00`3PfmH0h=320>3@`P020>7;^080hLbl
00H0h/fo0>;=`03Rc[l0h/jo0>;>`03Rc/<20>;?aP060>;@a`3Rd/X0h]G<0>;Ec03SeLd0hmC<0P3S
dl/00`3Se<`0i=K>0>CFcP020>CHd@80hmK>00H0hmC;0>CCa`3Rd<80h]320>3;_@3Oa[X20=o3^@06
0=o1^03N`;D0gKnc0=fo/`3K_K00fKZ^0P3H]Jd01@3F/Z/0dk:X0=6aY@3A/JD0d;2S0080d;6V00H0
ckF/0<ff[@3;/JD0bk6U0<Z/WP39Zi`30<RYVP050<baY@3E`k`0eL>l0=kGe`3Sj>/00P3VlOL01@3V
l_P0iO3f0>G_m03Uko@0i>kb0080i>c`00H0i>__0>?ZkP3Sj^`0hn[/0>?Yj`3Rj>X20>;Wj@060>;W
j03Ri^P0hNGV0>7UiP3QhN<0hN3Q0P3QhN820>7Si080hN?S0P3Ph^820>3Qh@030>3Qh03Ph>00h>3P
00D0h>3P00@0i>CS0>OWiP3WinH0f=SH:P3ooolm0?Ogm`030?O>]@3ge[d0mmJm0080mmJm0P3_c[D0
103ge/H0klje0?OF_@3ge[d50?OFaP@0mmk>103ge/H40?ONcP<0mmK60`3ge[d0103_aZd0klje0>nm
[@3__Jd20>nmY@80kkFU00H0ikFL0>N]W03W[I`0ijfL0>N]U03N[I@20=jLS0050=jUS03N[I@0gZfD
0=jeY@3N[I@00P3FYH`00`3NYH`0eZF<0=JUS0020=JUS0030=j]U03_e/h0kmK>01L0moOg00<0mno_
0?Ogm`3gmoL05@3gmoLP0?ooo`007P3oool01@3Hf=P0inOV0>OWiP3Ti><0h>3O00<0gn3O103Ph=l7
0>3Ph0@0h>7P2`3PhN450>3RhP<0h>;S00D0h>?S0>3Si03Phn@0h>?T0>3Si@020>3Ti@80h>CV0P3Q
iNL01P3QiNP0hNKY0>7WjP3QinX0h^S[0>7Wj`80h>CV00<0h=_F0>3@`P3Pd<800P3QbkP20>7<_006
0>;=_`3RcL00h/jo0>;>_`3Rc/00h/k30P3RclH01P3Rd<L0h];:0>;Ec03ReL`0hmG=0>?Dc080hm?;
00<0hmC<0>CFcP3Te/h00P3Tf=420>?FcP060>?Db`3TdlL0h]320>;@`P3Pbkd0glJj0P3O`kT01P3O
`KP0g/2e0=fo/`3M_k<0fkf`0=Vj[P80f;F]00D0e[:[0=>bZ03A/JD0dK6U0=2`X`020=2aYP060<ne
[03=]Zd0bk6U0<^aY@3:[9h0bJ^L0`38ZIX01@3</JD0eL>l0=G3_03NemL0hnS[0080i_7g00D0i_;h
0>G`mP3Uko@0iNod0>C^lP020>C/l0060>C[k`3Sj^h0hn[/0>?Zk03SjN/0h^SZ0P3RinT01P3RinP0
h^KX0>7UiP3QiNH0hN7S0>7Ph@80hN7R0P3Qhn@20>7Sh`80h>;R0P3PhN400`3PhN00h>3P0>3Ph005
0>3Ph0040>CTh`3WinH0inOV0=SHf2X0oooo?@3gmoL00`3gc[D0mmJm0?OF_@020?OF_@80klje00@0
mmK60>o>]@3ge[d0mmJm1@3ge/H40?ONcP@0mmK6103gg/h30?OFaP<0mmJm00@0klJ]0>o>]@3__Jd0
kkf]0P3__JD20>neY@060>NeW03W[I`0ijfL0>N]W03W[I@0gZfD0P3NW8`01@3NYH`0gZfD0=j]U03N
]JD0gZfD0080eZF<00<0gZF<0=JUS03FYH`00P3FYH`00`3N[I@0kmK>0>oFcP0G0?Ogm`030?O_k`3g
moL0moOg01D0moOg803oool001h0oooo00@0f=WH0>OWiP3WinH0i>CS1`3Ph=l70>3Ph0D0h>7P203P
hN400`3PhN80h>;R0>3RhP040>3RhP@0h>;S103Phn@30>3Ti@060>3TiP3PiNH0hNGW0>7Ui`3PiNP0
hNKY0P3SjN`01@3SjNd0gn3R0=WBd03Id]00fL[20080g/Zj00H0hL^i0>;;^`3Rc;d0h/bm0>;<_P3R
cKd20>;=_0060>;>_P3Rc/<0h]370>;@a`3RdLT0h]?;0P3Re</20>?Dc080hmC=00<0hmG=0>?Gc`3S
ell00P3TfM820>CFc`060>GEc@3UeL/0i=?60>CCaP3Rc/00hLVl0P3QaKX01P3Q`kP0h<:e0=k0/`3N
`;<0g;j`0=Zk[`80fKJ^00D0ekB[0=FcZ03C/J<0dk6S0=6^W`020<n^X0060<faY@3;/ZL0bJnR0<V_
XP39Zid0bJVJ0P39Z9P01P38Z9T0c;>W0=K8a03Fb<@0gmkQ0>C/l@<0i_7g00@0iO3e0>G^l`3Uk_<0
i>gb0P3Tk?001P3Tjnl0hn[^0>?Zk03Sj^`0hnW[0>;XjP<0h^OY00D0h^KX0>7UiP3QiNH0hN?T0>7Q
hP020>7Rh`80hN?T0P3Qhn<01@3Phn<0h>;R0>3Ph03Ph>00h=kN0080h=gM00H0h=kM0>3OgP3Ph=l0
h>3O0>3Ph03Ti><20>SWiP030=SHf03oool0oooo02P0oooo0`3gmoL00`3gknl0moOg0?Ogm`0e0?Og
m`80mmK6103ge[d30>o>]@H0mmK60P3ge[d50?ONcP<0mmK61@3gg/h40?OFaP80mmJm00@0klje0?Nm
]@3g_KD0mkfe0P3__JD20>NeW0060>neY@3W[I@0ijfD0>N]U03W[I`0ijfD0P3NW8`00`3NYH`0gYb<
0=jLS0020=JUS080g[FL0P3FYH`20=j]U0040=JUS03N[I@0knOW0>oWi``0moOg00<0mno_0?Ogm`3g
moL0803gmoLP0?ooo`007P3oool0103HfMP0inOV0>OWiP3Ti><50>3Pg`L0h>3P1P3PhN080>3Qh@03
0>3QhP3Ph^80h>;R00<0h>;R1@3Ph^<01P3Phn<0h>?T0>3Si03Phn@0h>?U0>3Ti@<0h>CV00D0hNGW
0>7Uj03QiNP0hNKX0>3Vj0020=kUi`050=_Oh@3Ecld0d;fe0=2m]@3C^jd00P3La;<01P3QbkX0h/bn
0>;<_`3Rc;l0h/bm0>;<_080h/fl00H0h/fn0>;>``3RdLL0h]770>;Cb`3Re</20>;Bb@050>?BbP3S
eL`0hmO>0>?GcP3Sf<l00P3Sf=401P3TfM40i=S@0>CFcP3Te/h0i=G=0>GDc080iM?900H0i=330>C<
_P3Tb;X0i<Rj0>;4]`3P`K@20=k0/P060=jo/@3L_;00f[N]0=Zg[@3G/jT0e[:U0P3D/:801@3A[Ih0
cZbM0<j/W@3;[9h0bJbN0080b:^M00H0bJZK0<^ZVP3;Z9P0bjRH0<ZYV@3=]JT20=K=bP060=oSj03T
k_D0i_7g0>Kam`3UlOH0iNod0P3Uk_<01@3TkO40i>c`0>C/l03Sjnl0hn[^0080hn[]00H0hnW[0>;X
jP3Rj>X0h^SZ0>;Wj@3Ri^P20>;Ui`050>7UiP3Qi>D0hNCU0>7Ti@3Qi>@00`3Qhn@01@3Qhn<0h>;R
0>3Og`3Pgml0h=cL0080h=_K00H0h=cK0>3Ng@3Ph=l0h>3O0>3Ph03Ti><20>SWiP030=SHf03oool0
oooo02P0oooo00<0moOg0?O_k`3gknl0103gmoL00`3gknl0moOg0?Ogm`0`0?Ogm`040>ONi`3N]JD0
g[FU0>o>]@80mmJm00H0klje0?OFaP3ge/H0mmK60?OF_@3ge/H20?OF_@@0mmK60P3gg/h20?OFaP80
mmk>0P3ge/H50?ONcP80mmK600H0mmk>0?OFaP3ge[d0mmJm0?O>]@3_c[D20?O6[@030>o6[@3__JD0
kkfU0080kkfU0`3W[I`0103NYH`0ijfD0=j]U03N[I@30=jUS0060=JUS03N]I`0eZF<0=JUS03N]JD0
gZF<0P3N[I@0103FYH`0gZfD0>oWi`3_inLC0?Ogm`030?O_k`3gmoL0moOg00/0moOg0P3gknl00`3g
moL0mno_0?O_k`090?Ogmb00oooo000N0?ooo`040=SIf03WinH0inOV0>CTh`/0h>3P1@3PhN0:0>3Q
h@D0h>;R103Ph^<20>3Sh`@0h>?T0P3Pi>D20>3TiP060>3UiP3PiNL0hNKX0>7Vj03Sj>/0gnCW0P3@
dm@01@2o_[/0_K6Y0<RaY038/J@0eKZY0080g/Fb00H0h/Zj0>;;_`3Rbkl0h/^o0>;<_P3Rc;d20>;<
_P040>;=`03Rc/<0h]770>;Aa`80h]C;0P3RdLP01@3SdLH0hm?70>?FbP3Se/X0hmS>0080hmS@00H0
hmO?0>CEcP3Te<d0i=C=0>CDc03Ue<X20>GDb0060>GCa@3Uc/00hlNk0>?7^`3Q`[H0gl2c0P3N_[40
1P3N_K40gKZ_0=ZgZP3J]jX0ek>U0=B`X@80dZjO00D0d:fN0<j/W@3>[9d0c:ZK0<ZYV@020<RYV@06
0<VZV`3<[9`0cJbK0<f/V`3<[9`0ckR/0P3Hd/l01P3Qj>d0iO7g0>Gam`3UlOL0iO3e0>G_m080i>kb
00D0i>ga0>C/l03Tk?00hn__0>?ZkP020>?Zk@060>?Yk03Rj>/0h^SZ0>;XjP3RinT0h^KX0P3Ri^L0
0`3QiNL0hNGV0>7Ti@020>7Ti@050>7Ti03Qhn@0hN?T0>7Sh`3Ph^800P3Ph>001@3Pg]h0h=gM0>3M
g@3PgMd0h=oN00<0h>3P00@0i>CS0>SWiP3XinH0f=SH:P3oool00`3gmoL0mno_0?O_k`0g0?Ogm`04
08A[FP3_aZd0klJ]0?OF_@80kmK>3@3ge/H00`3gg/h0mmK60?OFaP050?OFaP80mmk>00@0mmK60?ON
cP3ge[d0mmJm103ge/H20?OF_@80mlJ]00<0klJ]0>nmY@3_]JD00P3_]JD00`3W[I`0ijfD0>N]U004
0>N]U0050=j]U03NYH`0gZF<0=JUS03N[I@00`3FYH`00`3N]I`0gZfD0=j]U0020=j]U140moOg00<0
mno_0?Ogm`3gmoL07@3gmoLP0?ooo`007P3oool0103HfMP0inOV0>OWiP3Ti><;0>3Ph0D0h>7P2P3P
hN450>3RhP@0h>;S0P3Phn<40>3Si080h>CU0P3Pi>H01P3PiNH0h>GW0>7Vj03Qi^P0hnS[0=oTi`80
d=?D00D0_kjk0;faZ@38/J@0b;6T0=FjZ@020=k5/P060>;:^P3Rbkl0h/^o0>;;_`3Rc;h0h/bm0P3R
c;h0103RcL00h/k30>;Aa`3RdLL20>;Db`80h]7800D0hm760>?Ca`3Se/X0hmK:0>?HcP020>?Hd006
0>?Gc`3TeLh0i=C=0>CDc@3Te<`0iMC:0P3Ue<P01P3UdlD0iLk00>?7^`3Sak/0hL:f0=o0/`80g[ja
00H0g[fa0=fj[`3J]jX0f[NZ0=NcY@3D/:420=:^W`050=2]WP3>[9d0cZbM0<bZV`3:ZIT00P38ZIT0
1P39ZY/0c:bL0<f/V`3=[9/0c:bL0<nh[080f=;?00H0hNS]0>Gam`3UlOL0iO7g0>G`m@3Uko@20>C^
lP050>C]l@3Tk?00i>c`0>?[k`3Sj^h00P3Sj^d01P3SjN`0h^S[0>;XjP3Rj>X0h^OY0>;Vj080h^KW
00<0hNGW0>7UiP3Qi>D00P3Qi>D01@3Qi>@0hN?T0>7Si03Qhn<0h>;R0080h>3P00D0h=kN0>3Mg@3P
gMd0h=gM0>3OgP030>3Ph0040>CTh`3XinH0j>OV0=SHf2X0oooo00<0moOg0?O_k`3gknl0=`3gmoL0
1024JeX0klJ]0>o6[@3ge[d20>oFcPd0mmK600<0mmk>0?OFaP3ge/H01@3ge/H20?ONcP040?OFaP3g
g/h0mmJm0?OF_@@0mmK60P3ge[d20?O6[@030>o6[@3__JD0kkFU0080kkFU00<0ijfL0>N]U03W[I@0
103W[I@01@3N[I@0gZF<0=jUS03FYH`0gZfD00<0eZF<00<0g[FL0=j]U03N[I@00P3N[I@A0?Ogm`03
0?O_k`3gmoL0moOg01d0moOg803oool001h0oooo00@0f=WH0>OWi`3WinL0i>CS103Ph=l60>3Ph0D0
h>7P2@3PhN470>3RhP<0h>;S00<0h>?S0>3Si03Phn@00P3Phn@20>3Si@80h>CU0P3Pi>H01P3QiNH0
hNGW0>7Vj@3Qi^T0i>W/0=_OhP80^[Vi00D0VY6;09n>PP31ZYX0`JZJ0=[1[P020>79]P030>;;^`3R
bkl0h/c100<0h/c10`3RcL801@3Rc/@0h]370>;@a`3RdlX0h]?;0080h]7800D0hm350>?Aa03Se<H0
hmC60>?Fc0020>?FcP060>CDc03Td/X0i=790>CAb@3TdLP0i=750P3TdL<01P3TdL40h/bn0>34^@3P
a;T0g[nd0=jn/@80g[f`00H0g[Z`0=bh[@3I]jL0fKNW0=FcX@3B[Yd20=2/W0050<n]WP3>[Ih0cZfN
0<f[V`3;Z9P00P38YiL01P38ZYX0bZjN0<b_WP3<[ih0cJjM0=6j[P80fmGC00H0hnca0>Kcn@3UlOH0
iO7f0>G_m03Uk_<20>C]lP050>C]l@3Tk?00i>c`0>?[k`3Sj^d00P3Sj^`01P3SjN`0h^S[0>;XjP3R
j>X0h^OY0>;Vj080h^KW00H0hNGW0>7UiP3QiND0hNGU0>7Ti@3Qi>@20>7Si0050>7Sh`3Ph^80h>7R
0>3QhP3PhN401`3Ph>00103Ti><0j>OV0>SWiP3HfMPZ0?ooocT0moOg00D0S7=S06=:@P3_c[D0klje
0?OFaP020?OF_@80mmK60P3gg/h80?OFaP030?ONcP3ge/H0mmK60080mmK60`3ge[d01@3gg/h0mmK6
0?OFaP3ge/H0mmJm00<0mmK600D0mmJm0>o>]@3_c[D0mmJm0?O6[@020>nm[@@0kkfU00H0kkFU0>Ne
W03W]I@0ikFD0>N]U03NYH`20>N]U0<0gZfD00H0gZF<0=JUS03FYH`0eZF<0=j]U03N]I`20=jeY@80
gZfD<@3gmoLP0?ooo`007P3oool01@3HfMP0inSW0>OXi`3Ti><0h=oN0080h=gM00<0h=kN0>3Pg`3P
hN002@3PhN080>3Qh@L0h>;R103Ph^<00`3Phn<0h>?T0>3Si0020>3Si0<0h>CU0`3Pi>H01P3QiNL0
hNKW0>7Vj03Qi^P0hNCY0=;Be`80YIjO00D0Nf]V08QcJ02lY9D0_:BE0=k6]0020>C<^P040>;<^`3Q
cL00hLg30>7=``80h/g30`3RclD0103Rc/D0h/o50>;?a@3RdLL30>;Bb@040>?Bb03SdlH0hm?70>?C
a`<0hmC:00H0i=;70>C>a@3Tb/<0i<[30>?8`03Rak/20>38^0060=k6]P3M`kD0gKnc0=fo/`3M_K40
g[f`0P3M_K001P3K^jl0f;R/0=FeY@3E]JD0dk6O0=:^W080dJfM00D0cjjN0<f]W@3=[Id0bjZH0<VW
U@020<NWU@060<NXV038Zi/0bJ^J0<V[VP3:ZiX0d;V]0P3Ke]<01P3Tk_80i_?j0>G`mP3Ul?H0iNoc
0>C^lP80i>ga00D0i>c`0>C/k`3Tk>l0hn_^0>?Zk@020>?Zk0060>?Yj`3Rj>/0h^SZ0>;XjP3RinT0
h^KX0P3Ri^L01P3QiNL0hNGV0>7UiP3QiNH0hNCU0>7Ti080hN?T0P3Qhn<50>3RhP80h>7Q0P3PhN00
1@3Ph>00i>CS0>SWi`3XinL0f=WH02X0oooo303gmoL20?O_k`@0moOg00<0mno_0?Ogm`3gmoL08P3g
moL206]BBP03058a:@2<He80mmK600H0mmK60P3gg/h00`3ge/H0mmk>0?ONcP020?ONcP@0mmK600<0
mmk>0?OFaP3ge/H0103ge/H30?ONcP050?OFaP3ge[d0klje0>o>]@3_aZd00`3_c[D20>o6[@<0kkfU
00D0ikfU0>NeW03W]I`0kkfU0>NeW0040>N]U080ijfL0`3NYH`00`3NW8@0eZF<0=JUS0020=JUS005
0=j]U03FYH`0eZF<0>nm[@3N[I@0<@3gmoLP0?ooo`007P3oool01@3HfMP0inSW0>OXi`3Ti><0h=oN
0080h=gM00<0h=kN0>3Pg`3PhN002@3PhN080>3Qh@L0h>;R103Ph^<00`3Phn<0h>?T0>3Si0020>3S
i0<0h>CU0`3Pi>H01P3QiNL0hNKW0>7Vj03Qi^P0hNCY0=;Be`80YIjO00D0Nf]V08QcJ02lY9D0_:BE
0=k6]0020>C<^P040>;<^`3QcL00hLg30>7=``80h/g30`3RclD0103Rc/D0h/o50>;?a@3RdLL30>;B
b@040>?Bb03SdlH0hm?70>?Ca`<0hmC:00H0i=;70>C>a@3Tb/<0i<[30>?8`03Rak/20>38^0060=k6
]P3M`kD0gKnc0=fo/`3M_K40g[f`0P3M_K001P3K^jl0f;R/0=FeY@3E]JD0dk6O0=:^W080dJfM00D0
cjjN0<f]W@3=[Id0bjZH0<VWU@020<NWU@060<NXV038Zi/0bJ^J0<V[VP3:ZiX0d;V]0P3Ke]<01P3T
k_80i_?j0>G`mP3Ul?H0iNoc0>C^lP80i>ga00D0i>c`0>C/k`3Tk>l0hn_^0>?Zk@020>?Zk0060>?Y
j`3Rj>/0h^SZ0>;XjP3RinT0h^KX0P3Ri^L01P3QiNL0hNGV0>7UiP3QiNH0hNCU0>7Ti080hN?T0P3Q
hn<50>3RhP80h>7Q0P3PhN001@3Ph>00i>CS0>SWi`3XinL0f=WH02X0oooo303gmoL20?O_k`@0moOg
00<0mno_0?Ogm`3gmoL08P3gmoL206]BBP03058a:@2<He80mmK600H0mmK60P3gg/h00`3ge/H0mmk>
0?ONcP020?ONcP@0mmK600<0mmk>0?OFaP3ge/H0103ge/H30?ONcP050?OFaP3ge[d0klje0>o>]@3_
aZd00`3_c[D20>o6[@<0kkfU00D0ikfU0>NeW03W]I`0kkfU0>NeW0040>N]U080ijfL0`3NYH`00`3N
W8@0eZF<0=JUS0020=JUS0050=j]U03FYH`0eZF<0>nm[@3N[I@0<@3gmoLP0?ooo`007P3oool01@3H
fMP0inWX0>OYj03Ti><0h=kM0080h=cK00<0h=gL0>3Og`3Ph>000P3Ph>060>3Qh0T0h>7Q1@3Ph^84
0>3Rh`80h>?S103Phn@0103PhnD0h>CU0>3Ti@3Pi>D30>3TiP060>7Vj03Sj>X0hNGX0>7Uj03HfMd0
_k[00P2BQHL01@1aG5P0QfiU0;jVV@2nYYT0hLRh0080iLjl00H0h/fm0>7?`P3Qc/@0hLk40>;=``3R
c/@30>;@aP050>;>a@3RcL@0h/g40>;>a@3Rd<L00P3RdlT20>?Eb`80hmC;00D0hm;90>?BaP3Sd/H0
hm330>?;`0020>?4_@060>:o^03O_[<0g;f]0=bm[@3I^jX0f;ZZ0P3J^j`01P3L_:d0gKb]0=bl[@3L
_:d0fK^]0=FhZ@80dK>S00D0d:nN0=:]W@3C[Id0djfM0=2]W@020<f/VP060<VYU@37YY80ajJC0<NV
T`36YYD0aZJF0P36YI@01P37YYD0cKFY0=[Cd03Jdm00hn__0>Kam`80iNoe00D0i>kc0>C^lP3TkO40
i>ga0>C/l0020>?[k`060>?[kP3Sj^d0hnW/0>?Yk03SjN/0h^S[0P3Rj>X01@3RinT0h^KX0>;Vj03R
i^P0hNGW00<0hNGV00@0hNCU0>7Ti03Qhn@0hN?T0P3Qhn<20>3Rh`<0h>;R0P3PhN430>3Qh0040>CT
h`3XinL0j>OW0=SIf2X0oooo00@0moOg0?O_k`3gknl0moOg0`3gknl20?Ogm`80mno_:`3gmoL01@3F
a/h0HdY206=:@P1J<BT0kmK>0080mmK60`3ge[d0103ge/H0mmk>0?ONcP3gg/h20?OFaP<0mmk>1@3g
e/H40?ONcPD0mmK60P3ge[d20?Nm]@050>o6[@3__JD0kkfU0>nmY@3W]I`01`3__JD0103W_JD0ikFL
0=j]U03N[I@20>N]U0<0gZfD0P3NYH`20=JUQ080eZF<00<0eZF40=JUS03FYH`00P3FYH`00`3Fa[d0
moOg0?Ogm`0_0?Ogmb00oooo000N0?ooo`050=SIf03Wj>L0inSW0>CTh`3Pgmh00P3PgM`01@3Pg=`0
h=gL0>3OgP3Pgmh0h>3P00@0h>7P2P3PhN460>3RhP<0h>;S0`3Phn<40>3Si0040>3Si@3Pi>D0h>CU
0>3Ti@<0h>CV00H0h^KX0>O]k`3Sj>/0hnS[0<K5a`2MTY<208AbK@0508Q`I`2VS800c;>T0<bcY03Q
bKT00P3Tc;d01P3Rc;h0hLg10>7=`P3QcL80hLc20>;=``<0h/o500D0h/k40>;=``3RcL<0h/g30>;?
a@020>;Ab0050>;DbP3Se/d0hmG<0>?Ec03Sd/P00P3Rd<@01P3Qc/00h<Vl0>30^03P`;P0gk^c0=fj
[P80f[VY00H0ekJU0=JfY@3G^:L0ekRW0=ViZ@3J^JT20=ViZ@060=NiY`3C]j@0d;6P0=2aX03>[Id0
d:^K0P3AZiX01@3?ZYX0cJVH0<fYV03:Yi@0bJJB0080bJFC00H0b:FD0<JTT`35Xi40aJ>A0<NUU03=
/jH20=S<a`060>7Si@3Uk?40iNkc0>G^l`3Tk_<0i>gb0`3Tk?020>?[k`050>?ZkP3Sj^d0hnW/0>?Y
k03SjN/00`3Rj>X01@3RinT0h^KX0>;Vj03Ri^P0hNKW00<0hNGV0P3Qi>D20>7Si080hN?S0P3Ph^<3
0>3RhP80h>7Q0`3PhN00103Ti><0j>OW0>SWi`3HfMPZ0?ooocD0moOg00H0mno_05Y2>@1cBST0LdXi
0?OFaP3_c[D70?OFaP80mmk>303ge/H50?ONcP<0mmK600D0mmJm0>o>]@3_c[D0kkfU0>o6[@030>nm
Y@050>NeW03__JD0kkfU0>NmY@3__JD00`3W]I`01@3W[I@0gZfD0=j]U03W]I@0ijfD0080gZfD00D0
ijF<0=jUS03NYH`0gZF<0=JUS0040=JUQ0<0gZfD00<0g[FL0?Ogm`3gmoL0;`3gmoLP0?ooo`007P3o
ool01@3HfMP0inSW0>OXi`3Ti><0h>3O0080h=oN00D0h=cL0>3Kf`3PgMd0h=gM0>3Pg`040>3Qh0X0
h>7Q1P3Ph^830>3Rh`<0h>?S103Phn@40>3Ti@050>7UiP3PiNH0h>GV0>3Ui`3RinT00P3Hfm`01P2_
ZZP0PgE]08MbIP27LVH0[iN70<jeX`80g<>a00@0hLRh0>;:_03Rb[`0h/Zn0`3Qbl00103Qbl40h/c1
0>;<`P3Rc<820>;=`P<0h/g300@0h/k40>;?a@3RclD0h];80`3Se</01@3SdLP0hLg10>7=`@3Nb;X0
gL6d0080gKZ`00H0gKJ]0=beZ@3I/j@0fK>T0=J`X@3E[j020=F`X0060=JbXP3F/j<0e[BR0=JdXP3E
]J00dk>N0P3?[i`01@3=ZiX0cJRG0<jVU@3>YYD0cJJE0080c:JD0P3<YI<20<^TT`060<ZTTP37Xi40
aZ>A0<JST@38YY@0cZnQ0P3F`KT01P3MeM<0h^GW0>C]lP3TkO80i>od0>C]lP80i>c`00D0hn__0>?[
kP3Sjnh0hn[^0>?Zk@020>?Yk0050>;Yj`3Rj>X0h^OZ0>;WjP3RinT00`3Ri^P0103QiNL0hNGV0>7U
iP3QiNH20>7Ti@80hN?T0P3Qhn<30>3RhP@0h>7Q0`3PhN00103Ti><0j>OW0>SWi`3HfMPZ0?ooo`L0
moOg0P3gknlZ0?Ogm`80oooo00D0Nf=J06=2<@3ge/H0mmK60>o>]@030?OF_A<0mmK6103gg/h01@3g
e/H0mmJm0?OF_@3_c[D0mlJ]0080kkf]0P3__JD80>NeW0<0ikFD00@0ijfD0=j]U03N[I@0gZfD1`3N
YH`00`3FYH@0gZF<0=jUS0020=JUS080gZF<0P3N[I@20>oFcRl0moOg803oool001h0oooo00D0f=WH
0>OXi`3Wj>L0i>CS0>3Pg`020>3OgP050>3Lg03Pfm/0h=gM0>3Mg@3Ph=l0103PhN0:0>3Qh@H0h>;R
0`3Ph^<30>3Sh`@0h>?T103Pi>D01@3QiNH0h>GV0>3UiP3PiNL0h^OY0080f=_L00H0[jZX08=eK@27
LVH0Qg9V0:nGQ`3>]J<20=c3/@040>78^03Rb[`0h/Zl0>;:_P<0hL_000@0hL_10>;<`@3Rc<80h/c2
0P3RcL830>;=``040>;>a03RclD0h/o50>;Bb0<0hmC;00D0hm780>7=`@3QcL40g/Rj0=g1]0020=fj
/0060=ff[@3L]JT0fK>T0=VcY03F/:40eJnP0P3E/:001P3F/Z80e[>S0=JdXP3F]:80eKFP0=>cWP80
cjnL00D0cJ^J0<fXU`3>YYD0cZJE0<fVU@020<bVU080c:FC0P3;Y9<01P3:Y980aj>A0<JST@36Xi40
b:JD0<j_X@80e/6i00H0gMGC0>;Ui`3TkO80i>gb0>C_m03TkO820>C/l0050>?[k`3Sjnh0hn_^0>?Z
kP3Sj^d00P3SjN`01@3RjN/0h^SZ0>;WjP3RinX0h^OY00<0h^KX00@0hNGW0>7UiP3QiNH0hNGV0P3Q
i>D20>7Si080hN?S0`3Ph^840>3Qh@<0h>7P00@0i>CS0>SWi`3XinL0f=WH:P3oool70?Ogm`80mno_
:P3gmoL20?ooo`0507]SFP1S@S40mmK60?OFaP3_c[D00`3ge[dC0?OFaP@0mmk>00D0mmK60?OF_@3g
e[d0klje0?O6[@020>nm[@80kkfU203W]I`30>NeU0040>N]U03N[I@0gZfD0=j]U0L0gZF<00<0eZF4
0=jUS03NYH`00P3FYH`20=jUS080gZfD0P3_e/h_0?Ogmb00oooo000N0?ooo`050=SIf03Wj>L0inSW
0>CTh`3Pgmh00P3PgMd01@3Pg=`0h=gL0>3NgP3Pg]h0h>3P00<0h>7P2@3PhN470>3RhP@0h>;S00<0
h>?S0>3Si03Phn@0103Phn@40>3Ti@050>7Ui`3Sj>X0hnSZ0=kSi03:bl/00P2]ZJD01P2FRh<0TX5e
0:ZDQP2ZU8H0cKFT0>78]@80hlZf00@0hLVh0>79_03QbK`0hLVn0`3Qb[l01P3Qbl00h/^o0>;;_P3R
bkh0h/bo0>;<`@80h/c200H0h/g30>;>a03Rd<H0h]360>;Bb03SdlT20>?CbP050>?@aP3Qa[d0hLJm
0=fi[`3K[ZH00P3KZJ801P3KYZ00fZBL0=RQU`3HXIL0eInE0=BMT`80e9jD00H0eJ>H0=F[W03D[id0
e:nM0=:_V`3@[IT20<jZV0050<fWUP3<Xi<0c:6@0<bQT03:Xi000P3:Y9001P3;Y980cJBC0<fTT`3=
Y9<0bj>A0<NSS`80aZ:>00H0bJ:?0<bVUP3@/J@0d;6T0=G4_@3Ng=`20>C]l@050>G`m@3TkO40hnc_
0>?/k`3Sjnl00P3Sjnh01P3Sj^d0hnW/0>?Yk03SjN`0h^S[0>;XjP<0h^OY00@0h^KX0>;Vi`3Ri^L0
hNGW0`3QiNH20>7Ti@80hNCT00D0hN?T0>7Rh`3Ph>40h>3Q0>3Og`020>3Ph080h>7Q0`3PhN00103T
i>@0j>OW0>SWi`3HfMPZ0?ooo`T0moOg0P3gknl00`3gmoL0mno_0?O_k`0U0?Ogm`80U7]c00@0HdY2
0;fLS03_c[D0klje303ge/H40?OF_@030?OFaP3ge[d0mmJm0080mmK60`3gg/h40?OFaP80mmJm00@0
klje0?Nm]@3_]JD0kkFU1@3W[I`00`3W[I@0ijfL0>N]W0040>N]U0H0gZF<0P3FYH`40=jUS0030=JU
Q03NYH`0gZF<0080gYb40P3NYH`01@3N[I@0gZF<0=JUS03FYH`0kmK>02h0moOg803oool001h0oooo
00D0f=WH0>OYj03WjNP0i>CS0>3Ng@020>3Lf`040>3Mg03Pgmh0h>3P0>3Ph0@0h>7P2@3PhN470>3R
hP<0h>;S0P3Phn<50>3Si0060>3Si@3Pi>D0h>CU0>3Ti@3Pi>H0hNKW0P3UjN/01P3Kg^00];2^08Yn
MP2:OWH0Sgeb0;FRUP80dkf`00D0g/Jh0>;9^03RbKL0h/Vg0>79]`020>79^`060>79_P3QbKl0hLZo
0>7:_`3Rb[h0h/Zl0P3Rb[X01P3Rbk/0h/^n0>;;`@3Rbl40h/c20>;?a@80h]7700D0h]780>?@a`3S
d<H0hm360>?=a0020>6n]`060=jXX`3LVYH0fiJB0=^FTP3IThl0eXf90P3DRXD01P3DRH@0e8V50=B;
QP3DRhH0e9>;0=BPT`80dZNG00H0cjNF0<fUT`3<Y9<0c:BC0<bRT@3;Whl20<ZNS0050<RPS037Xhd0
aj>=0<ZST03<Xi800P3=Xi801P3;Xi00b::=0<NQRP37XHX0bIj:0<ZMR`80bJ:A00H0cK>W0=S@b`3Q
i^P0hNKX0>C]l@3Tk?030>?[k`80hn[^00H0hn[]0>?Yk03SjN/0hnW[0>;Xj`3Rj>X30>;Wj@040>;V
j03Ri^L0h^KW0>7Ui`<0hNGV0P3Qi>D20>7Ti0050>7Si03Qh^80h=oO0>3Og`3PgMh00P3Pgml40>3Q
h@050>3Qh03Ti>@0j>SW0>SXi`3HfMP0:P3oool50?Ogm`80mno_;03gmoL206=2<@0308acH`3gg/h0
mmK60080mmK60`3ge[d30?OFaP030?ONcP3ge/H0mmK60080mmK6103ge[d40?OFaP<0mmk>0P3ge/H2
0?ONcP050?OFaP3g_KD0mkfe0>nDS03g_KD00P3_U8`80>N4N`040>NDQ03W[I@0gZfD0=j]U0@0gZF<
00D0eZF<0=jLQ03FW8@0eYb40=JUQ0030=jUS0050=JUS03NYH`0gZF<0=jUS03FYH@00P3NYH`00`3N
W8@0eZF<0=JUS0020=JUS200moOg0P3gknl<0?Ogmb00oooo000N0?ooo`050=SIf03WjNP0inWX0>CT
h`3Pg]h00P3PgM`00`3Pg]h0h>3P0>3Qh0050>3Qh0P0h>7Q1`3Ph^840>3Rh`80h>?S1@3Phn@01P3P
hnD0h>CU0>3TiP3Pi>H0hNGV0>3TiP80h>;T00H0eMCE0;J^Z`2KRh@0Vh^40:RDR@3>^:`20>?<`005
0>C<_`3Qb;T0hLRf0>78]P3Qb;L00P3QbK/20>79_P80hLVm00<0h/Rj0>;8]`3Rb;H00P3Rb;H01@3R
b;T0h/Vl0>;9_03Rbl00h/k40080h]3600D0h/k50>?9`@3Sal00hlO00>?4_P020>6f/@060=jOW03K
Shd0fHZ60=V:QP3FQ7l0dg]f0P3AN7@01P3BO7T0dgml0=:0O@3BP7d0dXN10=>BR@80dIV>00H0c9Z=
0<RKS038WHd0b9f=0<VOS@39Wh/20<NNRP040<JORP36X8`0aZ2<0<VQS`<0c::A00H0bj:?0<VRS@39
WhX0bIn:0<ZKR03:VHL20<RNR`060<ZZV@3B_[80f];>0=[BcP3Ph^<0hn_^0P3Tk?001@3Sjnl0hn[]
0>?Zk@3Sj^d0hnW/0080h^W[00<0h^S[0>;XjP3RinT00P3RinT0103Ri^P0h^KW0>;Vi`3QiNL30>7U
iP80hNCU0P3Qi>@0103Qhn@0hN;R0>3Ph03Ph>030>3Og`@0h>7Q00D0h>7P0>CTi03Xj>L0j>SW0=SI
f00Z0?ooo`P0moOg00<0mno_0?Ogm`3gmoL09`3gmoL01@3>]KD0Hd8a06=2<@3gg/h0mmK60080mmJm
0P3ge/H20?OF_@P0mmK600<0mmJm0>o>]@3_c[D00P3ge[d70?OFaP<0mmk>103g_KD30>nDS0@0ihAk
00<0kiB<0>N4N`3WQ7/01@3WQ7/00`3NW8`0gZF<0=JUS0020=JUS0<0eZF400<0eZF<0=jUS03NYH`0
1@3NYH`00`3FYH@0gZF<0=jUS0040=JUS0030=jeW03__Jd0moOg0100moOg00<0mno_0?Ogm`3gmoL0
6@3gmoLP0?ooo`007P3oool01@3HfMP0inWX0>OYj03Ti><0h=kN0080h=gL00<0h=kN0>3Ph03PhN00
1@3PhN080>3Qh@L0h>;R103Ph^<20>3Sh`D0h>?T00H0h>?U0>3Ti@3Pi>H0h>CV0>7UiP3Pi>H20>3R
i0060=GDe@2f[Z/0Vh^409^;Q02XU8T0c[R/0P3Sc<001@3Tc;l0hLRi0>78]P3Qb;H0hLRg0080hLVk
0P3QbKh20>79_@030>;8^P3Rb;L0h/Rf0080h/Rf00D0h/Ri0>;9_03RbK`0h/_00>;>a0020>;@aP05
0>;>a@3SbL40hlO00>?7`03Sa;h00P3Q][401P3NWi`0fhn=0=V:QP3IRXH0eXAo0==kMP80dGQd00H0
dWai0==oO03BP7d0dX1m0=:7P@3CTXT20=6ISP060<bJS@38Vh`0b9f=0<RMS@39Whd0bIn;0P37WXX0
1036WhX0aZ2<0<JPS039XHl30<bRT@060<^RS`39XXd0bIn:0<VORP3:VhP0bYV70P38WX/01P3:ZYT0
d[jb0=[BcP3Jd/h0h>;S0>?[kP80i>c`00D0hn__0>?Zk@3Sj^d0hn[]0>?Yk0020>;Yj`030>;Xj`3R
j>X0h^OY0080h^OY00@0h^KX0>;Vi`3Ri^L0hNGW0`3QiNH20>7Ti@80hNCT00@0hN?T0>7RhP3Ph>00
h>3P0`3Pgml40>3Qh@050>3Qh03Ti>@0j>SW0>SXi`3HfMP0:P3oool80?Ogm`030?O_k`3gmoL0moOg
02L0moOg00D0c[Fe06=2<@1S@S40mmk>0?OFaP020?OF_@80mmK60P3ge[d80?OFaP030?OF_@3_c[D0
klje0080mmJm1`3ge/H30?ONcP@0mkfe0`3_U8`40>N4N`030>nDS03WQ7/0ihAk00D0ihAk00<0gYb<
0=jUS03FYH`00P3FYH`30=JUQ0030=JUS03NYH`0gZF<00D0gZF<00<0eZF40=jUS03NYH`0103FYH`0
0`3N]I`0kkf]0?Ogm`0@0?Ogm`030?O_k`3gmoL0moOg01T0moOg803oool001h0oooo00@0f=WH0>OX
i`3Wj>L0i>CS103Ph=l60>3Qh0T0h>7Q1`3Ph^840>3Rh`030>3Sh`3Phn@0h>?T00@0h>?T0P3Pi>D2
0>7UiP060>;Vj03Nh^@0d];D0=;Be033_[l0^k2^0P2o[ZP01P3<]jd0fl>f0>;9_03RbK`0hlZl0>78
^080hLRf00D0hLRg0>79^`3QbK/0hLVn0>79_@020>77^P060>75]03Qa;40hLB`0>74/03Qa;40h/Fc
0P3Rb;P01P3Rbkl0hlk30>?>a03Sc/@0hlNo0>>n^080h[Rd00D0hKFa0=n[Z03OZjP0g9ZG0=R<Q`02
0=B3O0060=1lL`3=MVd0cWM`0<igL03AOWT0dX1l0P3?OGP01P3?OGH0dH5k0=27P03@Qh00bh^30<J@
Q@80aIJ800D0aIb:0<FORP35WhT0aIn90<BMR@020<JMRP060<VOS@3;XXl0c::@0<bRT03;XXl0bj6>
0P3;Wh`01P3;VhT0bi^80<ZOS@3:Whd0bZFC0<f/V`80dkb`00D0g=GA0>;Xj`3TkO40i>ga0>?[k`02
0>?Zk@060>?Yk03RjN`0h^S[0>;Xj`3Rj>X0h^OZ0P3RinT01@3RinP0h^KX0>7Vi`3Qi^L0hNGW00<0
hNGV0P3Qi>D30>7Si0030>7Rh`3Ph^80h>;R00D0h>7Q0`3PhN00103Ti>@0j>OW0>SWi`3HfMPZ0?oo
oc40moOg00D0e/K606=2<@3_e/h0kmK>0?OF_@050?OFaP80mmJm00<0mmk>0?OFaP3ge/H00P3ge/H2
0?OF_@@0mlje00<0mmJm0?O>]@3ge/H01@3ge/H20?Nm]@80g/kF0`3g_KD01@3_U8`0ihAk0>N4L`3W
Q7<0ig][00<0gV]J00<0ihAk0>MkJ`3NNf/00P3NNf/30>N4N`040=J<N`3WQ7/0eYb40=JLQ0@0eZF4
00<0eYb40=jUS03NYH`0103NYH`01P3N[I@0gZF<0=jUS03NYH`0gYb40=JUS080gZfD00@0gZF<0=j]
U03gknl0mno_:`3gmoLP0?ooo`007P3oool0103HfMP0inOW0>OWi`3Ti><70>3Qh0`0h>7Q1`3Ph^84
0>3Rh`030>3Sh`3Phn@0h>?T00@0h>?T0P3Pi>D20>7Ui`060>CYj`3Lh>80_Kfn0;fm_P2OUiH0YYRC
0P37]:X01P3Ma[P0hLRh0>78]`3Qb;L0hLRh0>78]P80hLRe00D0hLRf0>79^P3QbKX0hLVm0>79^`02
0>36]P060=o2[`3N_Z/0gkjZ0=nnZP3P`:d0hLFa0P3RbKT01P3RcL00i<o20>G;_`3Ubkl0i;ne0>6^
Z@80gZ>O00D0gIjJ0=ZKUP3JViH0eIB?0<n8P0020<QlL0060<EiJ`38PG<0cHb00<f<P03AT8P0dHV2
0P3=Ng<01P3:LFT0bg1Y0<afK`3<MVl0bWif0<R7O@80aHn300D0a9N80<>NRP34WhT0a9n90<BMQ@02
0<FKQ0060<JNR039XH`0bZ6>0<ZQSP3;XHh0bj2>0P3;Whd01P3;WH/0bif:0<^PS@3;X8d0bZ:>0<ZT
T080ck6Q00D0f/g50>;Ti03Tjnh0i>_^0>?[kP020>?Zk@050>?Yk03RjN/0h^S[0>;Xj`3Rj>X00`3R
inT20>;Vj080hNKW00H0hNGW0>7UiP3Qi>H0hNCV0>7Ti@3Qi>@30>7Si0030>7Sh`3Ph^<0h>;S00<0
h>;R0P3PhN430>3Qh0040>CTi03XinL0j>OW0=SIf2X0oooo00<0moOg0?O_k`3gknl0103gmoL00`3g
knl0moOg0?Ogm`0U0?Ogm`80mno_00@0Nf=J08acH`3_c[D0klje0P3ge[d20?OFaP030?OF_@3gc[D0
mmK600H0mmK60P3ge[d01P3gc[D0kkfU0?O>]@3gc[D0mlJ]0?O>]@80mmK600<0mmk>0?OFaP3g_KD0
1@3g_KD0103_]JD0iiB40>NDQ03FLf<80=i[FP030=IcH`3NJeX0gV]J0080gV]J0P3NNf/01P3WQ7/0
eW][0<j<Q03>S8@0gYb<0=jLQ0<0eYb40P3FYH@01@3NW8@0gZF<0=jUS03NYH`0gZfD00@0gZF<0`3F
YH`01@3NYH`0gZfD0>nm[@3__Jd0mno_02X0moOg803oool001h0oooo00@0f=WH0>OWi`3WinL0i>CS
1@3PhN030>3Ph0<0h>7P203PhN470>3RhP80h>;S0`3Phn<60>3Si080h>CU0P3QiNH01P3TinT0emWK
0:ZWYP2ZYjH0P7E`08ilLP80`:VI00<0glFb0>?9]P3Qak@00P3Qak@0103Qak<0hLRd0>78]03Qb;L3
0>79^`050>78]`3Oa;40glBa0=bnZP3J^:@00P3J]Z801P3M^jP0hL>a0>;8^03Rb;P0hLJj0=k1]080
g;RZ00D0fj^O0=ZLU03IT8/0fI2;0=N;Q0020=B>Q@060=2BR@38Rh40`Gia0<5nL@30P6l0aY610P3=
X9401P3@Wi<0cHn50<MhKP37N6h0`fUN0<=WG@80aFeS00H0aWE/0<ImL`35QGX0aHEj0<B?PP33VHP2
0<>NR0050<>LP@34Vgh0a9]n0<FMPP36X8T00P39XHd0103;XHh0c:6>0<bPS@3<X8d40<^OS0060<ZO
S03:XXh0cjjM0<n^W@3HaKX0h=[F0P3SiND01@3SjN/0hnW/0>?Yk03SjN`0h^S[00<0h^SZ0`3RinT2
0>;Vj080hNKW0P3QiNH30>7Ti@030>7Ti03Qhn@0hN?T0080hN?S0P3Ph^<30>3RhP80h>7Q0`3PhN00
103Ti>@0j>OW0>SWi`3HfMPZ0?ooo`T0moOg0P3gknlT0?Ogm`80W8b<00@0FT8i0?ONcP3_c[D0klje
203ge[d40?OFaP<0mmJm00<0klJ]0>nmY@3__JD00P3__JD01@3ge[d0mmK60?OFaP3ge/H0mkfe00<0
mlJ]00@0kiB<0>NDQ03WU8@0ihAc0P3FS7/01P3NW8`0ijfL0<I[DP36Je80mkfe0=jeW080]G=J00H0
ijfL0=IkJ`3FHe80eV=B0<iJBP3FHe820=i[FP030=ikJ`3FNf/0eXak0080eXak00@0eZF<0=JUQ03F
YH@0eYac0`3FYH@30=jUS0060>NUS03NYH`0gZfD0=j]U03NYH`0eZF<0`3NYH`01@3N[I@0g[FL0=je
W03gimh0mno_02T0moOg803oool001h0oooo00@0f=WH0>OWi`3WinL0i>CS1@3PhN030>3Ph0<0h>7P
203PhN470>3RhP80h>;S0`3Phn<60>3Si080h>CU0P3QiNH01P3TinT0emWK0:ZWYP2ZYjH0P7E`08il
LP80`:VI00<0glFb0>?9]P3Qak@00P3Qak@0103Qak<0hLRd0>78]03Qb;L30>79^`050>78]`3Oa;40
glBa0=bnZP3J^:@00P3J]Z801P3M^jP0hL>a0>;8^03Rb;P0hLJj0=k1]080g;RZ00D0fj^O0=ZLU03I
T8/0fI2;0=N;Q0020=B>Q@060=2BR@38Rh40`Gia0<5nL@30P6l0aY610P3=X9401P3@Wi<0cHn50<Mh
KP37N6h0`fUN0<=WG@80aFeS00H0aWE/0<ImL`35QGX0aHEj0<B?PP33VHP20<>NR0050<>LP@34Vgh0
a9]n0<FMPP36X8T00P39XHd0103;XHh0c:6>0<bPS@3<X8d40<^OS0060<ZOS03:XXh0cjjM0<n^W@3H
aKX0h=[F0P3SiND01@3SjN/0hnW/0>?Yk03SjN`0h^S[00<0h^SZ0`3RinT20>;Vj080hNKW0P3QiNH3
0>7Ti@030>7Ti03Qhn@0hN?T0080hN?S0P3Ph^<30>3RhP80h>7Q0`3PhN00103Ti>@0j>OW0>SWi`3H
fMPZ0?ooo`T0moOg0P3gknlT0?Ogm`80W8b<00@0FT8i0?ONcP3_c[D0klje203ge[d40?OFaP<0mmJm
00<0klJ]0>nmY@3__JD00P3__JD01@3ge[d0mmK60?OFaP3ge/H0mkfe00<0mlJ]00@0kiB<0>NDQ03W
U8@0ihAc0P3FS7/01P3NW8`0ijfL0<I[DP36Je80mkfe0=jeW080]G=J00H0ijfL0=IkJ`3FHe80eV=B
0<iJBP3FHe820=i[FP030=ikJ`3FNf/0eXak0080eXak00@0eZF<0=JUQ03FYH@0eYac0`3FYH@30=jU
S0060>NUS03NYH`0gZfD0=j]U03NYH`0eZF<0`3NYH`01@3N[I@0g[FL0=jeW03gimh0mno_02T0moOg
803oool001h0oooo00@0f=WH0>OWi`3WinL0i>CS103PhN00103Ph>00h=oN0>3OgP3Pg]h20>3Og`03
0>3Ph03PhN40h>7Q00D0h>7Q203Ph^820>3Rh`<0h>?S1P3Phn@01P3Qi>D0hNGV0>3Si03Phn@0f]_M
0<S4a@80XYND00H0QW=Z09N0L033ZYD0`jZE0=k4/03Sb;D20>35/P050=o3[`3OaK40h<Vg0>39]`3Q
b[/00P3QbK`01P3QakP0hLBa0=jnZ@3N_ZT0fKNQ0=F_V@80e:ZF00H0fK6P0>6m[`3T_[<0i;jc0=f`
YP3=VHh20;b6N0050;b2M@3:Rh40e8f50=B=Q@3DRGl00P3BRh001P3@UX/0cIbA0<VKS`39Vhl0bIR;
0<^HRP80c9V:00H0bYN80<><O02lNVX0_7YZ0;U_H02iL6<20;UbIP060;MaI@2jLFD0`7I[0<1fJ`34
PWH0`i210P31VH<01@32VWd0a9Uj0<BINP35Vh00aij80080bJ6=00H0c:>@0<fUT03>Y8l0cZB?0<bQ
S@3;X8`30<ZPS@050<ZQSP3=Z9D0cJRE0=>fY`3Jb;h00P3Pf=<01@3Shn80hnSY0>?Xj@3SjN`0h^W[
0080h^SZ00H0h^OZ0>;Wj@3RinP0h^OX0>;Vj03Qi^L20>7Ui`80hNGV0`3Qi>D00`3Qi>@0hN?T0>7S
i0020>7Sh`80h>;S0`3Ph^820>3Qh@<0h>7P00@0i>CT0>SWi`3XinL0f=WH:P3oool70?Ogm`030?O_
k`3gmoL0moOg02@0moOg00D0aZfm06]BBP1[DTX0FS4Y0?OFaP030?OF_@050?OFaP3ge[d0mmJm0?OF
_@3gaZd00P3ge/H0103gg/h0mmK60?OFaP3gg/h30?O>]@050>o6[@3W]I@0ikFD0>NeU03__JD00`3g
e/H01P3gaZd0kiB<0>N]U03W[I@0ihAc0=ISDP80]E8i00<0aZfU0>N]W03W[I`00P3Fa/H30<je]@05
0>nm[@2mYI`0_JFL0=K6_@3>]KD00P2]Je80103FW8`0YF=:0<iJBP3>FTX20=IcH`80eW][0P3FS7/3
0=JLQ080eZF400H0gYb40=jUS03N[I@0gZfD0>NeU03N[I@20=jUS0030=jLQ03NYH`0gZF<0080gZF<
00@0gZfD0=JUS03FYH`0g[FL0`3Wg^lW0?Ogmb00oooo000N0?ooo`040=SIf03Wj>L0inSW0>CTh`@0
h>3P00@0h>3O0>3Ng@3Pg]d0h=cL0P3Pg]d00`3Ph>00h>7Q0>3Qh@050>3Qh@P0h>;R0P3Ph^<30>3S
h`H0h>?T00H0hNGV0>;Wj03Mh>40gN3Q0<[8bP2aYZH20:2<QP060:67N@2fVHH0d;FP0=2eX03Pa[<0
h/Ng0P3N`[001@3L_ZX0gL6^0=o8^@3Ob;T0hLbo0080hLZm00H0h/Ff0>6o[03M]j40gKNQ0=J^UP3@
Y8`20<fLR0060=2PT@3HZJ00g:RR0=bXXP3DUY40^gUa0P2PH5H01@2SJEh0_h^00=>MT`3CWI<0eYV@
0080eIR?00H0eZBK0=Rf[P3I`KX0fL6j0=Rg[`3DWI<20<j=P@060<J>O`2nSW`0]XMd0;J7M02dQ780
/hEg0P2]Og<01P2SL6<0Y6AF0;1TE`2`I5L0^fmS0;j2LP80_Y5k00D0`IMk0<BHN`34V7/0b9V00<ZL
R0020<^QS`060<fWT`3@ZY<0d:VA0=2YT@3>Y8h0bj6=0P3;XHh01P3:XXh0bZ2=0<^QS@3;XHd0c:ND
0=6eYP80f/[100<0h=cI0>;UiP3RiNH00P3Rj>/20>;XjP80h^OY0`3Ri^P00`3Qi^L0hNGW0>7Ui`02
0>7UiP<0hNCU00<0hNCT0>7Si03Qhn@00P3Qhn<20>3Rh`<0h>;R0P3PhN430>3Qh0040>CTi03XinL0
j>OW0=SIf2X0oooo2`3gmoL00`3gknl0moOg0?Ogm`0O0?Ogm`050>ONk`2eW9`0FT8i05Y2>@36W8@0
0`3ge[d20?OFaP80mmJm00@0klJ]0>nmY@3gg/h0mmk>0`3ge/H01@3ge[d0mlJ]0?O6[@3gaZd0ikFD
00<0gYb400<0mmJm0?Nm]@3WQ7/00P3WQ7/01@3>Q6<0Q2TH08@Y603FNf/0ijfL0080gV]J00D0iiB4
0=ikJ`3NNf/0kkFU0?OWi`020?OWgP060>oFcP3WNf/0iiB40>NDQ03>S7<0cW=J0P2mQ6<01P2mYI`0
aYB40:E[DP2UJe80YF=:0<iJBP80eV=B00@0cXac0<jDN`3FW8@0eYb40`3FW7<01@3NW8@0gZF<0=j]
U03N[I@0ikFL00<0ikFD0P3NYH`20=j]U080gZF<0`3N[I@00`3Fa/H0mnON0?OWgP0W0?Ogmb00oooo
000N0?ooo`050=SIf03Wj>L0inSW0>CTh`3Pgmh00P3Pg]d01@3Pgmh0h>3O0>3NgP3Pg]h0h=gM0080
h=kN00<0h>3P0>3Qh@3PhN401@3PhN480>3RhP80h>;S0`3Phn<60>3Si0060>7UiP3Tj>T0f]gN0=[M
gP2h]KD0UHV70P2FP7L01P2cUhH0c[2L0=c0[@3L`:d0hLNf0>76]P80g[n]00D0fkVV0=^lZ`3Oa[P0
glJh0>7;_`020>79_@060>;4]P3Q_JX0fk6J0=^aVP3CY8X0c9V00P37T7/01P30QWP0_81i0;n5P@2o
QH40`hf90;Z8P`80[7ig00D0/8V10<NVWP3H^;40f;Ra0=^g/P020=^f/P060=bm^P3Pc<T0h]KC0>;F
d`3Pb/@0fjnT0P3DWi801P3>XYD0b:NI0<:VU`32YYL0_::E0;BKT@80YhV000H0UFmS08eIB`2BDT@0
TU940:1KC02_L5l20;^6L0050<6DN@35VWh0aIYn0<VIP`3<VhT00P3=XY401P3?ZYH0dZfG0=:[U03B
Zi@0d:R@0<jTSP80c::>00H0bj6=0<ZOR`3:WHT0bYf90<ZPR`3<Zi`20=;0^`050=WCe`3Ngn<0g]oS
0>3Ti`3RinT00P3Sj>X00`3Rj>T0h^OY0>;Vj0020>;Vj0030>7Vi`3QiNL0hNGW0080hNGV0`3Qi>D0
0`3Qi>@0hN?T0>7Si0020>7Sh`D0h>;R0P3PhN430>3Qh0040>CTi03XinL0j>OW0=SIf2X0oooo403g
moL20?O_ka/0moOg00H0[JF]09b<S01B<BT0DS4Y0>oFcP3ge[d20?OFaP80mmJm0P3gc[D20>nmY@H0
mmK600D0mlJ]0>NeW03W]I`0ijF<0=jDL`020>NUS0060>neY@3NJeX0W3TY09`i:@2DHdX0kkf]0P3g
g/h20?OWgP<0mno_0P3gimh01P3ginL0mno_0?OWgP3gimh0mmk>0>o>]@@0kmK>0P3Fa/H01P2eDST0
]G=J09AcJ`2DLf/0[G][07=:>@80_EY200@0aV]B0=IcH`3NW8@0gYb40`3FW7<01P3NW8@0gZF<0>Ne
W03W]I`0ikfU0>NeW080ikFD00@0gZF<0=j]U03FYH`0eZF<1@3N[I@0103Fa[D0moOg0?Ogm`3Fa]H2
0>ONib@0moOg803oool001h0oooo00D0f=WH0>OXi`3Wj>L0i>CS0>3OgP020>3Ng@050>3OgP3Ph=l0
h=kN0>3NgP3PgMd00P3Pg]h00`3Ph>00h>7Q0>3Qh@050>3Qh@P0h>;R0P3Ph^<30>3Sh`H0h>?T00H0
hNGV0>CXj@3JgMh0f]gN0;Re]@2ERHL209J0M`060;>GQP3>/9`0g<2]0=c0[@3QakH0hLJf0P3N_jd0
1@3K^JH0fkb[0=o6^03Oa[P0hL^o0080hLVm00H0h/Bf0>6mZP3K/IX0fk6J0=>TRP3<VH020<N@N`06
0<26N02lP7T0_hF10;n5P@33SHT0^XR30P2/OWL01@2`RH40ajJN0=Rh/@3H^;40fkNb0080fkJb00H0
g;fj0>3<b@3Re]<0h]KC0>3:a03K[j@20=BOTP060<jRU@38YiT0`ZJG0<:VU`2lXYD0]9^A0P2WRH00
1P2EKf<0SEU;099BA02BDT@0X5]<0:m`G`80^hI`00D0`IAi0<FJOP35VWh0bIV30<bKR@020<fRT@06
0<nZUP3B[IL0dZ^D0=:[U03@Z900cZB>0P3<XXh01P3;XHd0bYn;0<ZMR@3:WHT0bZ2;0<b[W080d/2k
00D0fM?G0=kOh`3Ngn<0h>CW0>;Wj@020>?XjP030>;Xj@3RinT0h^KX0080h^KX00<0hNKW0>7Ui`3Q
iNL00P3QiNH30>7Ti@030>7Ti03Qhn@0hN?T0080hN?S1@3Ph^820>3Qh@<0h>7P00@0i>CT0>SWi`3X
inL0f=WH:P3oool@0?Ogm`80mno_6`3gmoL01P2]YJd0W8b<058a:@1B<BT0kmK>0?OF_@80mmK60P3g
e[d20?O>]@80kkfU1P3ge/H01@3gaZd0ikFL0>NeW03WYH`0gYAc0080ijF<00H0kkFU0=i[FP2L>BT0
W3TY09ASBP3__Jd20?ONcP80mnON0`3gknl20?OWgP060?OWi`3gknl0mnON0?OWgP3gg/h0klje103_
e/h20=K6aP060;EB>@2eLeX0U7=[09AcJ`2]Nf/0LdXi0P2mFT801036Je80eW=S0=jLQ03NW8@30=JL
L`060=jLQ03NYH`0ikFL0>NeW03W_JD0ikFL0P3W]I@0103NYH`0gZfD0=JUS03FYH`50=j]U0040=K6
]@3gmoL0moOg0=K6eP80imkW903gmoLP0?ooo`007P3oool01@3HfMP0inWX0>OYj03Ti><0h=kM0080
h=cK00D0h=gM0>3Pg`3Ph>00h>3P0>3Pg`020>3Ph0030>3Qh03PhN40h>7Q00D0h>7Q1P3Ph^840>3R
h`<0h>?S103Phn@20>7Ti@060>?Wj03Vj^`0f=[L0=SJg02XY:D0Nfm[0P27LfL01P2hWX`0fKfZ0>76
]@3Qa[D0h/Rg0>76/`80g[nZ00D0fkRT0=bjZ@3O`kD0gl>e0>79_@020>78_0060>74]@3O^ZL0f:ZC
0=RZT`3>V7h0ahec0P2oPF/01P2/J5T0VE5909aOF`2LGe/0/X^70<B[Y@80c;J`00D0dKff0=S7`03N
cl/0g/o;0>3CdP020>3De0060>7Ee@3Rf=L0hm[F0>?JeP3QdLT0g<:e0P3J_Jl01P3J`kT0fLS00=G4
_@3Ea;d0c;^d0;j]Y`80ZiB>00H0UWE/08AKCP1kCd00Ndm008=B@@2LHDl20;9fHP050;j<M034V7l0
a9Qo0<RIQ03<W8T00P3?Y9401P3B[9P0djjJ0=>^V03C[YP0djbD0=2XT080cJ>=00H0bin:0<ZLR@3:
W8L0bYb70<ZORP3:ZIX20<bj^@050<o:d`3De=`0e=CL0=[KgP3NhN<00P3PiNP01P3Qi^T0hNKX0>;V
j03Ri^P0hNKW0>7Ui`<0hNGV103Qi>D30>7Si0030>7Sh`3Phn<0h>;R00@0h>;R0P3PhN430>3Qh004
0>CTh`3XinL0j>OW0=SIf2X0oooo103gmoL30?O_k`80moOg0P3gknl00`3gmoL0mno_0?O_k`0O0?Og
m`0608akL`1SBT80Q59208AB@P3_c[D0mmJm0P3ge/H20?OF_@80mlje00<0kkfU0?OF_@3ge/H01@3g
e/H01@3gaZd0ijF<0>NUS03NU7<0cXAS0080eXac00H0]E8i08`Y8@2LFT80W5Y20=K6_@3gg/h40?OW
gP80mnOW00D0mno_0?OWgP3gimh0mnOW0?O_k`030?OWgP040>o>]@3ginL0mnOW0?OWgP<0kmK>00H0
ikfU0<J]Y@2]FT80[EY209AJBP1J<B4207=2:@050;eJ@P36Je80eXac0=J<L`3FYH@00P3FW7<01@3N
W8@0gZF<0>NeW03W]I`0kkfU00<0ikFL00H0ikFD0=jUS03NYH`0gZF<0=j]U03NYH`30=j]U0040=je
Y@3Ne^L0g]KW0?O_k`80knOW903gmoLP0?ooo`007P3oool01@3HfMP0inWX0>OYj03Ti><0h=kN0080
h=gL00<0h=kM0>3Pg`3PhN00103PhN080>3Qh@H0h>;R103Ph^<30>3Sh`@0h>?T0P3RiNH01P3UjN/0
i^[_0=?Df`3Ce=/0VYFI06ULF@80NfMK00H0]Yj;0=c1[P3Sb;H0hlRf0>;8]@3Pa[820=o1[0050=fm
Z03N_Zd0h<Bf0>34]P3Qb;`00P3Qak/01P3P`;40fk:O0=6PR03AX8P0aHib0;f0I080]6iH00H0Vdho
08@e;02;BD80RdU20:j1NP3=/JP20=c7_@050>3;`P3Pbl<0h=7<0>3Ac03RfmX00P3Sgmh01P3Sg=T0
hmWC0>?Fc@3Se/d0h<k20=_4]P80flFi00H0gLo80=oBc@3Lb/<0g<[30=K1^@3<^K420;fVW`060:V;
P02ELfH0QFMG08EWE`20GTl0R5Y:0P2JHU401@2_N6<0_h]e0;n;M@36U7l0bY^70080cjFA00H0e:jH
0=JbW@3F/Yd0e[:M0=F_V@3BZi@20<fTS`060<^OR`3:VhL0bYV50<ZIQ@3:W8P0bJJG0P37]K401@37
`LD0bLK90<W6b@3=b/`0dm?G0080fMcS00H0g^;W0>7Vj03Ri^P0h^KX0>;Vi`3QiNL30>7UiP<0hNCU
00H0hNCT0>7Si03Qhn@0hN?T0>7Sh`3Ph^<50>3RhP80h>7Q0`3PhN00103Ti><0j>OW0>SWi`3HfMPZ
0?oooa00moOg0P3gknl0103gmoL0mno_0?O_k`3gknl<0?Ogm`030>oWi`3gmoL0mno_0080mno_0P3W
g^l20?O_k`80moOg00D0U8B405Y2>@36W8@0aYb40?OF_@030?OFaP80mmJm0P3gaZd00`3__JD0mmJm
0?OFaP020?OFaP80mmk>00@0mmJm0>NeW03WYH`0ijF<0P3>S6/209`i:@0608@Y601k<B40]G=J0;Ec
FP3W]I`0mnON0P3ge/H01@3ginL0mmJm0?OWgP3gimh0mno_0080mmK600H0mnON0?O_k`3gimh0mnON
0?OFaP3W[I`20?OWi`040?OWgP3_e/h0mmK60?OFaP80e/K60P3_e/h00`2UDST0[G][04X@200204X@
20040;EB>@3>FTX0cUY:0=J<N`<0eYb400<0gZF<0>NeU03W]I@00P3__JD20>NeW0060>NeU03N[I@0
eZF<0=JUS03N[I@0gZF<0P3N[I@01@3NYH`0g[FL0<jm]@3>_KD0c[g>0080e/KF00<0mno_0?Ogm`3g
moL08@3gmoLP0?ooo`007P3oool01@3HfMP0inSW0>OXi`3Ti><0h>3O0080h=oO00<0h>3O0>3Ph03P
hN000P3PhN0:0>3Qh@H0h>;R103Ph^<30>3Sh`<0h>?T00D0h>?S0=oRhP3Oh^80g=oP0=OHg@020<6m
a`0608j4RP1VE540OFEI07eUF@2hWX`0gL:]0P3SbK@01P3Qak80hLF`0>34[P3Pa:h0h<>^0>33/@80
h<Jg00D0hLVl0>77^P3QakX0g[^/0=NYUP020<^IP0060;n;KP2gOF00[VQA0:iXD@2JCCd0Qcd`0P2B
CT@01P2fNg40dj>G0=fgZ@3M]jT0gKZ]0=bi[P80gL6j00D0glo;0>7Fd03Qe]00h]770>;=_`020>79
^P060=g0/@3H]:H0e[BZ0=JdZP3I_kP0fL2i0P3G]Z`01P3F]:L0e[Z^0=2eZP3@]JX0`J:C0;6@P@80
XXIh00D0T7EY07mMD@21Dd@0PE=409YOCP020;=eHP060;n8M@37VHD0cjJ?0<nVS`3D[iL0f;JP0P3H
]j801P3F/Yd0dZ^F0<fUT@3=YI40bZ2<0<VJQP80bYN300D0bYV50<RRT@36/:<0a[2S0<Bj/P020<>m
^0060<Bn_`39aLh0d=3L0=3@g03Ig>@0h>GW0P3RinP00`3Ri^L0hNGW0>7UiP020>7UiP<0hNCU00H0
hNCT0>7Si03Qhn@0hN?T0>7Sh`3Ph^<50>3RhP80h>7Q0`3PhN00103Ti><0j>OW0>SWi`3HfMPZ0?oo
oal0moOg00<0mno_0?Ogm`3gmoL02@3gmoL20=kFi`0506=2<@1B<BT0mmK60?OFaP3_c[D01@3ge[d2
0>o6[@030?OF_@3__JD0mmK600@0mmK600H0mmJm0>NUS03NW8@0gYb40<J<H`3FS7/20;eJ@P060:E2
<@24:AP0ihAc0>N4L`3WU8@0gYAc0P3__JD01@3ge[d0kkFU0?ONcP3gg/h0mnON0080ijfD00H0mmJm
0?OWgP3ge[d0mmJm0>N]U03W[I`20>nmY@060>oFcP3ge/H0ijfD0>N]U03_c[D0mmK60P3_c[D00`3F
YH`0g[FU0;fLS0020;fLS00407=2<@2U@S40YD8a0<I[DP<0eYb400D0gZF<0>NeU03W]I@0kkfU0>o6
[@020>NmY@060>NeW03NYH`0gZfD0=j]U03NYH`0gYb40`3NYH`0103N[I@0e/Je0=K6]@2]U9@20<jm
]@030=K6_@3Ne^L0moOg00l0moOg0P3gknl@0?Ogmb00oooo000N0?ooo`050=SIf03Wj>L0inSW0>CT
h`3Ph=l00P3Pgml00`3Ph=l0h>3P0>3Qh0020>3Qh0X0h>7Q1P3Ph^840>3Rh`<0h>?S0`3Phn@01@3P
hn<0gn;R0=oRhP3Lgn00emSM0080`Kg700H0SXB:06IDD@1mIET0OFEI0;RNS03M`Zd20>?9]0060>77
/P3QaK00h<B^0>34[P3P`jh0h<>a0P3Pa[L01@3QbK`0hLNj0>77^P3N^j`0ejVF0080biV000H0_h]^
0;MmH02^J540[VQA09Y=?@27?C02099>A0060;IkL@3CXiL0gKNY0=fgZ@3M^Zd0g;V^0P3M`KX01@3O
cl/0hMK@0>7Fd03RdLL0h/fo0080hLVj00H0gL2a0=RdYP3F]:X0e[BZ0=Vo^03I`;T20=Nf[0060=Jd
Y`3F^Zh0d;FZ0=2eZP31XY<0/I210P2RQWP01@2@MFT0OeeA085CA021Dd@0VUm>0080/gER00H0_hQe
0<NIQ@3?YXl0cjJ?0=B_U`3H]Z020=RgXP060=JbW@3BZiH0cJFA0<fUT@3:X8`0bIZ60P3:Uh<01@3:
VHD0b::A0<J`X`36/:<0a;Zb0080`kfh00H0a;jo0<W5cP3@d=`0d=3L0=WLi03PiNL20>;Wj0030>;V
i`3QiNL0hNGV0080hNGV0`3Qi>D01P3Qi>@0hN?T0>7Si03Qhn@0hN?S0>3Rh`D0h>;R0P3PhN430>3Q
h0040>CTh`3XinL0j>OW0=SIf2X0oooo7`3gmoL00`3gknl0moOg0?Ogm`090?Ogm`80g]KW00D0Hd8a
058a:@3ge/H0mmK60>o>]@050?OF_@80klJ]00<0mmJm0>nmY@3ge/H0103ge/H01P3ge[d0ijF<0=jL
Q03NW8@0aXaS0=J<N`80_EY200H0YD8a08@Y603WQ7<0ihAc0>NDQ03NU7<20>nmY@050?OF_@3_]JD0
mmk>0?ONcP3gimh00P3W[I@01P3ge[d0mnON0?OF_@3ge[d0ijfD0>N]W080kkfU00H0kmK>0?OFaP3W
[I@0ijfD0>o>]@3ge/H20>o>]@030=JUS03N]JD0_Ib<0080_Ib<00@0Ld8a0:E2<@2U@S40aV]B0`3F
W8@01@3NYH`0ikFD0>NeU03__JD0klJ]0080ikfU00H0ikFL0=jUS03N[I@0gZfD0=jUS03NW8@30=jU
S0040=j]U03Fa[D0e/Je0:fDU080c[fe00<0e/Jm0=kFi`3gmoL03`3gmoL20?O_ka00moOg803oool0
01h0oooo00@0f=WH0>OWi`3WinL0i>CS103Ph>040>3Qh0X0h>7Q203Ph^820>3Rh`<0h>?S00@0hNCT
0>;UiP3RiNH0g^7Q0P3Bdm401P30_;T0ZjBU09F:S`2ERXl0OF]]07ILE`80U7QZ00H0`jND0=k4[P3S
b;80hlRb0>75[`3Q`Z`20>70ZP050>71[03Q`k00hLJe0>76]@3QbKT00P3Pa[H01P3L^:L0e:BA0<^H
P03;V800`i=h0;j=L`80^X9[00H0[gAR0:I]G@2`MVT0/7IY0<N;P@3HX9D20=^ZW@050=V[W@3GZYd0
f;2V0=R`YP3J^k800P3L_K@01P3N]j`0gK>U0=ZbX`3J/Z<0eJVK0=6KS`80d9J=00H0dIZC0=6JT@3>
UHT0cYF90=2MSP3E[j020=>dY0060<^VU030V8P0]Y650;JAQ@2RPgX0RFUP0P1lDdL01@25C3h0VeU:
09]IBP2bMfL0aIB10080cjF>00H0eK2G0=VhX@3I^J@0fKVT0=JcW@3BZY@20<fTS`060<VOR`38VXH0
aiR40<NHQ038VXH0b:6=0P37ZiP01@37]ZL0b/2h0<[0^03;aLH0b<?>0080b/OE00D0eMKO0>3Ti`3R
inP0h^OX0>;Vi`030>7UiP060>7TiP3Qi>D0hNCU0>7Ti@3Qi>@0hN?T0`3Qhn<0103Ph^<0h>;R0>3R
hP3Ph^820>3Rh@80h>7Q0`3PhN00103Ti><0j>OW0>SWi`3HfMPZ0?ooo`030?Ogm`3gknl0mno_02L0
moOg00D0c[g>06=2<@1S@S40<B4Q07=:@P020=K6aPD0mmJm00D0klJ]0>nmY@3__JD0mlje0>nmY@05
0?OFaP060>o>]@3WU8@0cXa[0<j<J`3NU7<0ijfD0P3W[I`0103W[I@0gW][0=i[FP3NJeX20>N4L`80
gYAc00<0ijfL0>NDQ03WYH`0103WYH`0103_]JD0mkfe0=IcH`3FLf<20=ikJ`80iiB400H0ijF<0>N]
U03FLf<0eW=S0>NUS03_c[D20>NeW0060=jeW03N]JD0eZF<0=JUS02mW8`0YG=J0P1k:AP01@2U@S40
cXac0<j<L`3FW8@0gZF<0080ikFL00D0kkfU0>o6[@3__JD0kkfU0>NeW0030=jUS0060=JUS03FW8@0
eZF<0=JUS03NYH`0g[FL0P3N]JD01@3Ne^L0e/KF0=K6eP3>_LH0e/K>0080imk_803gmoLP0?ooo`00
7P3oool0103HfMP0inOV0>OWiP3Ti><30>3Ph0T0h>7P1P3PhN480>3RhP80h>;S0`3Phn<0103Qi>D0
hnKW0>?Vi`3Jg=`20;bi]@0609:9PP1^HE/0GTe:05i=BP1]E500TG5W0P2gUHH01P3B]J40h<F_0>;6
/@3Ra[40hL6/0>2lY`80h;ZU00D0h;^V0>2oZ`3QaK40hLFa0>78]@020>35/P060=^fX`3DXhl0cYZ4
0<jJQ03;WHH0bj:<0P3<Yi801P3=ZYH0cJ^H0=:ZW03BZY`0fJZP0=f[XP80g:bQ00D0f:ZN0=JYW03E
ZYh0eJZN0=F]XP020=RZX0060=ZSVP3HWiD0dijB0=>NTP3?V8/0cHao0P3=PWH01P3=OG80bg]_0<Um
L039OG00bH]m0<fPT080cJNE00H0bI^80<B>O`2mR7l0_HQo0;22N`2LLf/208MICP0507To<`23@C@0
Pd4d0:=SE@30R7P00P3>X8X01P3D[YD0f;NP0=VhXP3I^:80e[:K0=6YT@80cJ:;00H0bIf80<FJQP35
VXH0aIZ60<NMR038XH`20<RVT@050<V`W`3>`;L0c/2g0=39b`39`lh00P39`m401@3Ddm`0gn;U0>;V
j03Ri^P0hNGW00<0hNGV103Qi>D20>7Si080hN?S00<0h>?S0>3Rh`3Ph^800P3Ph^840>3Qh@<0h>7P
00@0i>CS0>SWi`3XinL0f=WH:P3ooolW0?Ogm`80mno_00H0S7=S048Y8@1B<BT0DS4Y048Q6036U8@2
0?OFaP@0mmJm0P3gaZd20>o6[@050?O6[@3W[I@0mmJm0?OF_@3ge/H00P3ge[d01P3g_KD0ijF<0<j4
H`3>Q6<0ikFL0>neY@80klje00H0mmK60?OF_@3ge[d0mmJm0?Nm]@3__Jd30>neY@030>N]W03_]JD0
kkFU00<0ijfL0P3_U8`20=jLS0060=jLQ03NNf/0gW][0=ikJ`3NJeX0cW=J0`3FLf<01@3N]I`0cXa[
0<j<J`3FS7<0klJ]0080cXb400D0eZF<0:ekJ`1S6100HaP@07<Q40020:EB>@060=J<N`3FYH@0ikFD
0>NeU03__JD0klJ]0P3__JD01P3W]I@0gZfD0=jUS03NYH`0eZF40=JUS080gZF<0P3N[I@20=jeW005
0?Ogm`3gknl0mno_0=k>eP3Fa]H00P3Ne^LP0?Ogmb00oooo000N0?ooo`040=SIf03WinH0inOV0>CT
h`@0h>3P0`3PhN001@3Ph>00h=oO0>3Og`3Pg]h0h=oO0080h>7P103PhN480>3RhP80h>;S0P3Phn<0
1@3Phn@0hNCU0>7Ri03Qh^@0d<k@0080X9ZH00H0HeUB03X]9@0j:240>RPQ06Q?A`2XR7`20=6`W`06
0=k1[03QaZl0hL>^0>73[P3Q_JX0h;JV0P3O]J@01@3N^JD0g[nY0>34[`3Pa:l0hLFb0080h;j^00H0
g;:Q0=BST03=VH@0cIV40<ZJQ03>Yi820=NjY`060=k8]P3Rc;`0hlRj0>?8^P3Q_kH0h;Va0P3N]jd0
1@3K]ZX0fKFY0=ReZ@3H]JT0f;:V0080fZjR00H0fjRN0=VTV@3DX9@0e:2D0=2KS@3?TX@20<n:N`06
0<j3LP3<P6l0bX9b0<Z2LP39S7`0bIR70P3:VHP01P3:SWl0ah9g0<9lM032O7@0^7Q`0:U^H`80TeM:
00D0OC/_07`d:@1l=2T0UDe10;9aHP020<FAOP060=6XTP3H]9h0fKJP0=VfX03F/IP0dJV?0P3=XHT0
1P38VhH0a9R40<>IQ@33VHD0aYb70<VPR`80bJ>=00D0`j>A0;ZSV02jXiP0]jVW0<2g_@020<k9d@04
0=SFg@3Ngn80h>?U0>3Si@@0hNGV0P3Qi>D20>7Ti080hN?T0P3Qhn<00`3Phn<0h>;R0>3RhP020>3R
hP@0h>7Q0`3PhN00103Ti><0j>OW0>SWi`3HfMPZ0?ooo`h0moOg00<0mno_0?Ogm`3gmoL05@3gmoL0
1@3Wg^L0e/KF0=K6eP12:B40<B4H0080HcTa00@0@RTH0?OFaP3g_KD0mkfe103ge[d20>o6[@80mkfe
0P3_aZd20?OF_@050?OFaP3ge[d0mmJm0?O6[@3W[I@00P3>Q6<01@3W[I@0kkf]0?ONcP3gg/h0mmK6
00<0mmk>00@0mmK60?ONcP3ge/H0mmK61@3gg/h40?Nm]@<0kkf]00D0kkFU0>N]W03W[I`0ihAk0=ik
J`020>N4N`030=IkJ`3FLf<0aV]B0080aV]B00D0eYac0<I[DP36Je80]G=J0:E2<@02048@400507<Q
4024BST0Q4Xi0:EB>@3FW8@00P3W[I@40>nmY@060>NeW03NYH`0gZF<0=jUS03FYH`0eYb40P3NW8@2
0=jUS080g[FL00D0YHAk0;FLW02eW9`0g]KW0>ONi`020=k>eP030>oWi`3gmoL0moOg01d0moOg803o
ool001h0oooo00@0f=WH0>OWiP3WinH0i>CS103Ph>030>3Qh0050>3Ph03Pgml0h=oO0>3NgP3Pgml0
0P3PhN040>3Qh@P0h>;R0P3Ph^<20>3Sh`050>3Si03Qi>D0hN;T0>7Ri03@c]000P2PVYP01P1SFE80
>RdU03XX8@0j:240J4m70:R8O080dK2O00H0g/6/0>76[`3Q`jh0hL>^0>6mZP3P]ZH20=neY0050=ji
Y@3N_jT0h<B_0>34[`3QaK800P3P_Zh01P3L/Z40e:>@0<fIQ03=VH@0bYZ40<jWTP80ekZW00H0g/Rf
0>;<_03Sb;X0hlRj0>6o]P3P^K420=jg[@050=^fZP3I]JT0f;FY0=ReZ@3H/ZH00P3J[Z801P3KZ9h0
fJBI0=BPU03DX9@0d9^=0<nBQ080chYk00H0cX=b0<b0K`3:PW80bX9b0<V<O039V8L20<ZIR0060<Z>
O`37PWL0`Wad0<9lM02hN700ZFiS0P2CEdX01@1m>bl0O3@Y07`d:@2ECD40/W5R0080aI5n00H0dJRB
0=RdWP3I]Z00fKJP0=JaV03AZHl20<fQR@060<RKQP34V8@0`iV50<>IQ@36W8L0bJ2;0P39Xhd01@33
Xi40^Z>H0;ZSV02gZJL0`;Nm0080c/WA00@0f=KM0=kOhP3PhnD0h>?U103QiNH20>7Ti@80hNCT0P3Q
hn@20>7Sh`030>3Sh`3Ph^80h>;R0080h>;R103PhN430>3Qh0040>CTh`3XinL0j>OW0=SIf2X0oooo
3P3gmoL00`3gknl0moOg0?Ogm`0E0?Ogm`050>ONi`3Fa]H0e/KF048Y8@0a8AP00P1S>C401012:AP0
mmK60?Nm]@3g_KD40?OF_@80klJ]0P3g_KD20>o6[@80mmJm00D0mmK60?OF_@3ge[d0mlJ]0>N]U002
0<j4H`050>N]U03__Jd0mmk>0?ONcP3ge/H00`3gg/h0103ge/H0mmk>0?OFaP3ge/H50?ONcP@0mkfe
0`3__Jd01@3_]JD0ijfL0>N]W03WQ7/0gW][0080ihAk00<0eW][0=IcH`36Je800P36Je801@3FW7<0
aV]B0<I[DP2eLeX0YD8a0080@Q0@00D0Lb4@08A:>@24BST0YE8i0=JLQ0020>N]U0@0kkfU00H0ikFL
0=jUS03NYH`0gZF<0=JUS03FW8@20=jLQ080gZF<0P3N]I`01@2UQ7/0]IbL0;FLW03Ne^L0imkW0080
g/kF00<0knOW0?Ogm`3gmoL07@3gmoLP0?ooo`007P3oool0103HfMP0inOV0>OWiP3Ti><30>3Pg`80
h>3P0P3PhN001@3Ph>00h=kN0>3NgP3Pg=`0h=kN0080h>3P103PhN480>3RhP80h>;S0P3Phn<01@3Q
i>@0hN?T0=kLh03Ng>00b<;70080T8R900H0D4Q202lT6`0l;2<0?2`S07IOE@2jWY420=k1[`060>?7
/P3Qa:h0hL2[0>70Z`3Q^ZT0h;BW0P3N]:L01@3L^ZP0gL2[0=o4[`3Oa:l0hL6`0080h;V/00H0g:jQ
0=BST@3:Uh00bYN00<BAN@3:WhT20=RiZ0060>;<_P3Td/@0i<o20>C?`P3RbKh0hLFj0P3P`kP01@3O
a;P0g/Jj0=k5^P3NaKX0g/:g0080gknb00H0gkb^0=ffYP3I[ih0fJnN0=NYV@3FYYD20=FRS`060=:N
R03@VX@0ciV50<nIQ@3=VHH0biR50P3;TX801P3<R7`0c7mf0<IhK`36N6l0_G5U0;1WF080X5M700D0
Sd@g08Tl<029?300TTDi0:EOD@020;^3L@060<fQS03F[iX0f;:L0=RbW03F[iH0dJR>0P3=XHT01P38
VXD0a9J20<>FPP33UX80aYV40<^NR@80bj6<00D0^IF209YmKP2JOFh0TGad0;2TX`020=?>d@060=kK
g`3Mg=h0gn3R0=oPhP3Qi>H0hNGV0P3Qi>H20>7Ti@80hNCT0P3Qhn@20>7Sh`030>3Rh`3Ph^80h>;R
0080h>;R103PhN430>3Qh0040>CTh`3XinL0j>OW0=SIf2X0oooo3P3gmoL00`3gknl0moOg0?Ogm`0E
0?Ogm`050=k>eP2LS8`0W8b<034Q601B<BT00P12:B401P1J<B40mmK60>o>]@3_c[D0mmJm0?Nm]@80
mlje00<0klje0?Nm]@3_c[D00`3_c[D20?OF_@<0mkfe00H0klJ]0>N]U03NW8@0gYb40<j<J`3__Jd2
0?OFaP80mmk>0`3ge/H0103gg/h0mmK60?OFaP3ge/H30?ONcP<0mmK600<0mmJm0?O>]@3__JD00`3_
_JD20>o6[@060>NeU03W]I`0ijfD0>N]U03NW8`0gYb40P3FS7/01P3WQ7/0eW][0=IcH`3FLf<0aV]B
0;eJ@P<0W3TY0P2eDST0102U@S40eXak0=jUS03NYH`40>nmY@060>NeU03N[I@0gZF<0=jUS03FYH@0
eYb40P3NW8@20=jUS080gZfD00D0_JFL07=:>@1cBST0mnON0?O_k`030>oWial0moOg803oool001h0
oooo00@0f=WH0>OWiP3WinH0i>CS0`3Ph=l20>3Ph080h>7P00D0h>3P0>3NgP3Pg]h0h=gM0>3NgP02
0>3Ph0@0h>7Q00<0h>7R0>3RhP3Ph^801@3Ph^820>3Rh`80h>?S00D0hNCT0>3Ri03If=h0fMSN0<Fo
b@0209nFV00607MZHP1UDTH0LEY<075JC02JOg40b:fM0P3PaK801P3Sak80hL>]0>2oZ@3P_jT0hK^Y
0>2hZP80g[NZ00D0gKRZ0=fm[03O`jl0gl>_0>72/0020>2k[@060=bbX`3DYY@0bIN10<VGP@33SgL0
bI^50P3F]:801P3PakT0h/g10>;>`P3Rc/80hLg10>7;_`80hLZn00D0hLZo0>7=`@3Qc/80hLk20>;=
`@020>;9_@060>73]P3O_:d0g;JU0=bfY@3J/j00f[>O0P3H/Id01P3E[YL0djZC0=:VT@3BYY40cj6=
0<^KQ@80bI>000H0bX]m0<Z6NP36PG<0aX5c0;mlJP2hLf420:mZF0050:IQD@2OFDd0WeU=09mHCP2X
IET00P2iPFd01P39VX<0dZVB0=J^V03F[YP0eJfD0=6XSP80cJ6900H0b9^50<BGP@33UX00`iJ00<JH
PP3;WHP20<^ORP050;B>N`2;KEh0RfeN07iYGP2RUY000P3=b<D01P3Mfm/0g]kO0=oQh`3OhN<0hNCV
0>7UiP@0hNCU0`3Qhn@0103Qhn<0h>?S0>3Sh`3Ph^<40>3RhP@0h>7Q0`3PhN00103Ti><0j>OW0>SW
i`3HfMPZ0?ooo`030?O_k`3gmoL0moOg02<0moOg00D0imkW05Y2>@1J@ST0W6]B0=JLS0020;EcFP03
08aJBP3ge/H0mmJm00<0mmJm0P3gc[D00`3_c[D0mmJm0?OF_@020?OF_@<0klje00D0mmJm0>o>]@3_
c[D0klje0>N]U0020>NUS0040=jDL`3W]I`0klje0>o>]@D0mmK600D0mmk>0?OFaP3ge/H0mmK60?ON
cP020?OFaP050?ONcP3ge/H0mmK60?OF_@3gaZd00`3__JD01@3W]I`0kkfU0>nmY@3__JD0ikFL0080
ijfD00D0ijF<0=jUS03NW8@0gYb40=JLQ0030=jLQ0050=jLS03FW8@0eXak0=J<N`3FS7<00P3>S6/0
1@3>Q6<0cXa[0=jLQ03NW8@0ikfU00<0kkfU00H0ikFL0=jUS03FYH`0eZF<0=jUS03FYH@20=jUS005
0=jLQ03N[I@0gZfD0=j]U036[Jd00P2<Ng<01024He80moOg0>oWi`3_inLP0?Ogmb00oooo000N0?oo
o`040=SIf03WinH0inOV0>CTh`<0h>3O0P3Ph>020>3Qh0050>3Ph03Ph=l0h>3O0>3Pg`3Ph>000P3P
hN050>3Qh@L0h>;R0P3Ph^<20>3Sh`050>7Ti03OhN<0e]KM0=KFg@3:a<h00P30/k@01P2hY9L0]9R5
0;NFP`2gUX<0a:>@0=>fXP80gL:]00H0h<F_0>32[03P`:X0h<2Z0>2oZ`3P_jd20>2k[@050=ng[03O
^Zd0h<:`0>32/03Qa[800P3P`k001P3L^JL0e:bH0<bMR03<WHP0b9Ao0<^KQP80e:jK00H0g;j]0=o7
^@3Qc;l0hLbo0>7>`P3QcL420>7;_`050>7:_`3Rc<00h/k20>;>`P3Rcl<00P3Rb/001P3R`;L0h;R/
0=bdY03L]:@0fk>P0=ZcW`80f;:M00H0eJnI0=>[UP3AYi80dJNB0<jRS037W8D20<BFP0060<>AOP34
Sgd0`hmj0<>?NP30SGL0_XUc0P2kQ7401@2hPFl0]Ga^0;ElKP2bN6d0]7]^0080_8Qb00H0aYQl0<jT
R`3CZi@0dj^D0=B[T`3AYhd20<bPR0060<RJQ034V800`iQo0<>HO`36VH40bib60P39WHP01@2bSGX0
RW1R08Y`HP1kJV80VXn90080a;fj00<0f]SG0>3Rh`3QiNH00P3QiNH01@3Qi>H0hNCU0>7Ti@3Qi>D0
hNCT00<0hN?T00@0hN?S0>3Sh`3Phn<0h>;S103Ph^830>3Qh@<0h>7P00D0h>3P0>CTh`3XinL0j>OW
0=SIf00Z0?ooobH0moOg00D0g]KW08ASDP24He80mmJm0>o>]@030>nmY@<0klje0P3ge[d20?O>]@06
0>o>]@3ge[d0mmJm0?OF_@3g_KD0mmK61@3ge[d01P3_c[D0ikFL0>NUS03WYH`0gYb40=jDL`80klJ]
00<0klje0?OFaP3gg/h00`3gg/h40?OFaP<0mmk>0P3ge/H01@3g_KD0kkfU0>nmY@3__JD0ikFD00<0
kkfU0P3W]I`20>N]U0050=jUS03FYH@0eZF<0=JUS03FW8@00`3FYH@20=JLQ080eZF40`3FW8@01P3>
S8@0eYb40=JLL`3FW7<0ikfU0>NeW080kkfU00@0ikFD0=jUS03NYH`0gZF<103FYH@01@3NYH`0gZfD
0=j]U03N[I@0aZfU0080Nf=J00<0c[g60=K6_@3gmoL08@3gmoLP0?ooo`007P3oool0103HfMP0inOV
0>OWiP3Ti><30>3Pg`80h>3P0P3PhN001@3Ph>00h>3O0>3Pg`3Ph=l0h>3P0080h>7P1@3PhN470>3R
hP80h>;S0P3Phn<01@3Qi>@0gn7S0=KFg@3Fe]d0b/C>0080`;>d00H0^:BG0;BHQ@2gUX<0]iJ30<BS
T03C]Z820=g2[@060>35[`3P`Z`0h<2Z0>30ZP3P_j/0h;n]0P3P^jd01@3O]j`0gkZ]0>32/03P`[00
hLJb0080h<>`00H0g;VW0=B/V03<WHP0c9f80<RDO`3;VhH20=B^V`060=bn[@3OakT0hLbo0>7<_`3Q
c/80hLg10P3Qbkl01@3Qb[l0h/c00>;>`P3Rc/80h/o30080h/[000H0h/2g0>2h[03L]:@0g;BT0=^c
X03J/il20=RbW@060=F_V@3CZiH0dJNB0=6WTP3>XX`0aib50P34UX001P33TGh0a8mm0<>?NP33SgX0
`8eg0;j9L`80^hAa00D0^85_0;ElKP2eO6h0/WQ]0;AkKP020;b8LP060<JHO03>Y8/0dj^D0=>[U03D
Zi<0dJN=0P3<X8P01P38VX@0a9R00<>HO`33V7l0aYV10<^LQP80bIf800D0/Xej08Y`HP2:L680NfYR
09Z?R@020<Bm^P030=[He`3Ph^<0hNGV0080hNGV00D0hNCV0>7Ti@3Qi>D0hNCU0>7Ti0030>7Si004
0>7Sh`3Phn<0h>?S0>3Rh`@0h>;R0`3PhN430>3Qh0050>3Ph03Ti><0j>OW0>SWi`3HfMP0:P3ooolV
0?Ogm`050=kFi`24He80Q6=B0?OF_@3_c[D00`3__JD30>o>]@80mmJm0P3gc[D01P3_c[D0mmJm0?OF
_@3ge[d0mkfe0?OFaPD0mmJm00H0klje0>NeW03WYH`0ijF<0=jLQ03NU7<20>o6[@030>o>]@3ge/H0
mmk>00<0mmk>103ge/H30?ONcP80mmK600D0mkfe0>nmY@3__JD0kkfU0>NeU0030>nmY@80ikFL0P3W
[I@01@3NYH`0eZF40=JUS03FYH`0eYb400<0eZF40P3FW8@20=JUQ0<0eYb400H0cXb40=JLQ03FW7<0
eYac0>NmY@3W]I`20>nmY@040>NeU03NYH`0gZF<0=jUS0@0eZF400D0gZF<0=j]U03N[I@0gZfD0<J]
Y@0207]SFP030<jmaP3Fa[d0moOg0240moOg803oool001h0oooo00@0f=WH0>OWiP3WinH0i>CS0`3P
h=l40>3Ph0<0h>7P2@3PhN470>3RhP80h>;S0P3Phn<01@3Qi>@0gn7R0=WFf03Ie]P0e<W:0080elBn
00H0g/Be0>31[P3N_JX0g[fZ0=^lY`3I_:H20=ZoZ0060=c1Z`3N`J/0h<6[0>31Z`3P`jh0h<Ba0P3P
`;401@3P^k00h;fb0>75]@3QaKD0hLVg0080h<Nd00H0g;n/0=JcWP3AYI00dJF@0<fLQ`3=VhL20=2T
T0060=JbW`3K_jh0glVj0=o9^P3Qc/40hLo30P3QcL401@3Qbkl0hLZn0>7=`@3QcL40h/o30080h/_0
00H0hL6g0=ni[03L]:<0g;BS0=V`W@3H[9P20=J[UP060=B[U@3AZI80cZB=0<jTS@37WhL0`9^30P2l
Ugl01P2mTg`0_Y5j0;nAN@2oTGT0_Y9j0;jANP80_i1j00D0_hij0;j<NP2nS7X0_8Uj0;b;NP020<2A
NP060<JKP03=Y8`0dZVC0=:YT`3CZI80d:B<0P3;WHH01P36V880`iIo0<:GOP32Ugh0a9V00<RLQ080
aYb500D0[XYg08A/G`24K5l0M6IQ09F<S0020<:m_`050=[Jg03Qi>H0h^KW0>;Vi`3QiNH0103Qi>D4
0>7Si0030>3Sh`3Ph^<0h>;S00@0h>;R00@0h>;Q0>3Qh@3PhN40h>7Q0`3PhN001@3Ph>00i>CS0>SW
i`3XinL0f=WH02X0oooo903gmoL20?O_k`050;fUW03_c[D0klje0?OFaP3ge[d00P3ge/H00`3_c[D0
e/K60>o>]@020>o>]@030?Nm]@3ge[d0mmJm00@0mmK600<0mmJm0?OFaP3ge[d0103ge[d01P3_c[D0
kkfU0>NeW03W]I`0ijF<0=jLQ080ikFD00<0klje0?OF_@3gg/h01@3gg/h40?OFaP<0mmk>00H0mlje
0>nmY@3__JD0kkfU0>NeU03W]I`20>nmY@80ikFD0P3W[I@01P3NYH`0eZF40=JLQ03FW8@0cYAk0<j<
J`80cYAk00D0cYAc0<jDN`3>U7/0cYAk0=J<N`020=JLQ0060=JLL`3FYH@0gYb40=jLQ03W]I@0kkfU
0P3W]I`00`3N[I@0gYb40=JLQ0020=JLQ0040=JLL`3FYH@0eZF40=jUS0<0eZF<00@0c[F]034Q8@0a
8B40c[fe8`3gmoLP0?ooo`007P3oool0103Hf=P0inOV0>OWiP3Ti><30>3Pg`@0h>3P0`3PhN090>3Q
h@L0h>;R0P3Ph^<20>3Sh`050>3Si@3Oh>00gMK@0=gFd03Lb[h00P3OaKH01P3Sa[H0i<Rh0>;7]`3R
akL0g/>a0=VnZP80f;fW00H0fKjX0=c1Z`3O`jd0gl>]0>35/@3PaKD20>34]P050>33]P3QaKT0hLVl
0>79_03Qbk`00P3Pb;T01P3N`K00fKRU0=F]V03E[IP0dJ:>0<jKQP80cIZ600H0d:FA0=NgY03MaK@0
gLFd0>3=_`3Qcl<20>7>``050>7<`03QbKd0hLZn0>7:_P3QcL000P3Qc;l01P3QakL0gkn]0=bfX`3L
]Z<0f:bI0=FTT@80dj:=00H0dZF=0<jUS038X8L0b:270<6KPP2jUX020;NCO0060;R?M`2jSG@0^h]c
0;^;L`2kS7@0_8ed0P2lSGD01@2lRgD0_8Ud0;b9M02kRW@0_Hmh0080`iN000H0bJ290<nVT03BZ980
dZRB0=:VT03?X8X20<RIQ0060<>DO`31TWd0`IAm0<6DO@33Ugh0aYb20P34Vh<01@2XQG80N61D07QP
E01WFUL0T8V>0080aL;;00D0gMkT0>7Ui`3Ri^H0h^KV0>7UiP030>7Ti@040>7Ti03Qhn@0hN?T0>7S
i080h>?S0P3Ph^<40>3RhP@0h>7Q0`3PhN001@3Ph>00i>CS0>SWi`3XinL0f=WH02X0oooo903gmoL2
0=kFi`<0mmJm00@0mmK60?OF_@3gg/h0mmk>0P3_c[D20?OF_@030>o>]@3ge[d0mmJm0080mmJm1@3g
e/H20?ONcP<0mmK600H0mkfe0>o6[@3__JD0kkfU0>N]U03WYH`20=jLQ0060>nmY@3_c[D0mmK60?OF
aP3gg/h0mmK60P3gg/h20?OFaP80mmJm00D0mmk>0?OFaP3ge/H0mmJm0>o>]@020>nmY@80ijF<0P3W
[I@01P3W]I@0gZF<0=JUQ03FYH@0eYb40<JLQ080cYAk00@0cYAc0<jDN`3>S7<0cXac103>U7<01@3>
S7<0cYAc0<jDL`3>U7<0eXak0080gZfD00H0eYac0>NeW03W]I@0ikFD0>N]U03NW8@40=JLQ0<0eZF4
00@0gZfD0=JUS03FYH`0_JFL0P1B>C400`2DQ8@0imk_0?Ogm`0Q0?Ogmb00oooo000N0?ooo`040=SH
f03WinH0inOV0>CTh`<0h>3O103Ph>040>3Qh0P0h>7Q1`3Ph^840>3Rh`050=kQh`3MgMd0g]?:0=kC
bP3Ob;H00P3P`Zd01P3O`:d0g[n]0=^o[03K_j`0e[f/0=:k[080dk^Z00H0f;fY0=g0Z`3Oa;00glB`
0>36]@3Pb;T20>38^`050>39_03Pbkd0h<bo0>3<_`3QcL000P3Pb[d01P3O`[D0gKRZ0=V`W`3I/9l0
eJRD0=2NRP80cIR400H0cin:0=F`W03K`:h0fl2^0=o9^`3Qc/820>7?``050>7:_`3Qa;X0h<:g0>32
]`3Oa[T00P3Ob[T01P3PbKH0g/:]0=ZfX@3J]Z40eJZF0=>QS@80d9b700H0cI^40<VKPP34VX40a9Z1
0;fGP02hTG`20;J=M`060;N;LP2iRW00^HQa0;V8L@2jR740^h]`0P2kS6l01@2jRFh0^HI]0;V6K@2i
QV`0_Heb0080aIR100H0cJ:=0=6VT@3BYI40dZFA0=2RS@3<W8P20<JFP@060<6AO@30T7`0`I9m0<6B
O@32UWh0aIb30P34Vh@01@2UPW00K5I<06aFC01GC4/0Qh250080`ko700D0gMgR0>7TiP3Ri^H0h^KV
0>7UiP030>7Ti@@0hN?T0P3Phn<20>3Rh`@0h>;R103PhN401@3PhN00h>3P0>3Ph03Ph>00i>CS0080
j>OW00<0f=WH0?ooo`3oool0:03ooolT0?Ogm`80g/kF00<0mmJm0?OFaP3ge/H00P3ge[d20?O6[@05
0>o>]@3ge[d0mmJm0?OF_@3g_KD00`3ge[d20?OFaPL0mmk>0P3ge/H01P3ge[d0mkfe0>nmY@3__JD0
ikFL0>NUS080gYAc00@0ikFD0>nmY@3ge/H0mmK6103gg/h40?OFaP050?OF_@3ge/H0mmK60>o>]@3_
_Jd00P3W[I@20>N]W080gZfD0P3NW8@30=JLL`040<jDL`3>U7/0cYAk0<j<L`<0cYAc0P3>U7/30<jD
L`80cXa[00H0cYAc0=JUQ03NW8@0gYb40>N]U03N[I@30=jUS0030=jLQ03FW8@0eYb40080eYb40P3F
YH@01@3FYH`0gZF<0=JUS03FYH`0_JFL0080<B4H00<0HdY209B4Q03gmoL08@3gmoLP0?ooo`007P3o
ool0103Hf=P0inOV0>OWiP3Ti><30>3Pg`@0h>3P103PhN080>3Qh@L0h>;R103Ph^<01@3NhN<0gMgM
0=kCbP3NdlX0glRf0080h<:]00H0gl2]0=jo[@3K_j`0fkn/0=Jm[03B^j`20=>kZP060=RmZ@3M`:/0
glB`0=o4/03Pa[D0h<Ri0P3Pb;/01@3PbK`0h<^m0>3<_`3Pc;l0hLg00080h<Zm00H0gl:e0=fhZP3I
/9l0fK2O0=FXU03@WXX20<fHQ0060<nORP3E/9`0fl2^0=_0[P3ObK/0hLk20P3Qcl<01@3Qb[l0hLBj
0>32]`3P`[L0glJi0080glZi00H0h<Vf0=k2[@3J]Z40f[JQ0=FZUP3CXHd20=2LQ`060<fKQ039Vh80
a9Z10<BJP@2mUh00^95l0P2fSGL01P2gRg80^HY`0;V8L@2iR740^XQa0;^;L080^ha_00D0^XU^0;V6
K@2iQVd0^HI/0;f=LP020<FHP@060<fRS@3AYY40dZFA0=:UT@3@XXd0c9b80P36UX401P31TGd0`91l
0<6BO@31TWd0`YIn0<FLP`80a9^400D0YH9`06aFC01/ET`0Eda;08N0Q@020<>oa`050=gMhP3Qi>H0
h^KV0>;ViP3QiNH00`3Qi>D40>7Si080h>?S0P3Ph^<40>3RhP@0h>7Q00D0h>7P0>3Ph03Ph>00h>3P
0>CTh`020>SWi`030=SIf03oool0oooo02P0oooo903gmoL20=k>eP030?OF_@3ge/H0mmK60080mmJm
0P3gaZd01@3_c[D0mmJm0?OF_@3ge[d0mkfe00<0mmJm0P3ge/H70?ONcP80mmK600H0mmJm0?Nm]@3_
_JD0kkfU0>NeW03WYH`20=jDL`040>NeU03__JD0mmK60?OFaP@0mmk>103ge/H01@3ge[d0mmK60?OF
aP3_c[D0kkf]0080ijfD0P3W[I`20=j]U080gYb40`3FW7<0103>U7<0cYAk0<jDN`3>S7<30<jDL`80
cYAk0`3>U7<20<j<J`060<jDL`3FYH@0gYb40=jLQ03W[I@0gZfD0`3NYH`00`3NW8@0eYb40=JLQ002
0=JLQ080eZF400D0eZF<0=jUS03FYH`0eZF<0;fUW002034Q600306=:@P2DQ8@0moOg0240moOg803o
ool001h0oooo00@0f=SH0>OWiP3WinH0i>CS0`3Ph=l40>3Ph0@0h>7P203PhN470>3RhP060>3Rh`3P
hn<0gn;R0=oRhP3Mg]l0g=OF0P3MclD01@3Oa[<0g[nY0=joZ@3K^J<0f;>L0080e;2H00H0cK6P0<Ze
Z`3?^Jh0ckV^0=VlZP3O_j`20>33/`060>37^@3Pb[`0h<^n0>3;_P3Pc;l0h<fo0P3PcL001@3Pc/40
h<bo0>3<_`3P`kP0gkR^0080gK6T00H0fJbJ0=BTS`3AW8L0dIb70=6OR@3FZiH20=^iY`060=o4]@3Q
c;l0hLk20>7>`P3Qb;h0hKjf0P3O^k401@3M`;40gLJc0=g6/`3Ob;<0gL6]0080f;BP00H0e:VF0=:R
SP3>VhH0cY^60<VBO@34TG/20<:EO`060;jDO`2jSGP0^8Qa0;R8L@2hR6l0^8U`0P2iRG801@2kRW<0
_Hea0;j>K`2nSVl0_8]^0080^HQ/00H0^XI[0;n<LP38V840b9R10=2QS@3BY8l20=2RS@060<fNR@39
VHD0aIB00<FDP032TGd0`I1l0P31TWd01@31UWl0aYb50<FMQP35WHH0Y89`0080I51800H0B40o07E_
L02e[jl0]Jn_0=KDe@3Phn@20>?Wj0040>;UiP3Qi>D0hNCT0>7Ti080hN?T0`3Phn<30>3Rh`@0h>;R
103PhN401@3PhN00h>3P0>3Ph03Ph>00i>CS0080j>OW00<0f=WH0?ooo`3oool0:03ooolS0?Ogm`04
0>oWi`3gc[D0mlje0?OF_@80mmK600H0klJ]0?O6[@3W]I@0ikFD0?OF_@3Fa/H20?OF_@030?O>]@3g
e[d0mmK60080mmK62P3gg/h01P3ge[d0mkfe0>o6[@3_aZd0kkfU0>N]U0<0ijF<00@0kkfU0?OFaP3g
e/H0mmK60`3gg/h01@3ge/H0mkfe0?O6[@3gaZd0klje00<0mmJm00<0mlJ]0>NeW03W]I`00P3W[I@2
0=j]U0050=J<L`3FYH@0eZF<0=JUS03FW8@00`3>S7<0103>U7<0cYAk0<jDN`3>U7/20=JLL`D0cYAc
00H0cXa[0=jLQ03W[I@0ijfD0>NeU03W[I@20>NUS0030=jUS03FYH`0eYb400<0eYb40P3NW8@20=JU
S080gZfD00D0_Ib<034Q8@0a8B40@RTa0<jm]@0R0?Ogmb00oooo000N0?ooo`040=SHf03WinH0inOV
0>CTh`<0h>3O103Ph>040>3Qh0P0h>7Q00<0h>7R0>3RhP3Ph^80103Ph^801P3Ph^<0h>?T0=oQh@3O
hN40g][G0=cAbP80gLZm00D0glBb0=flZ03M_:P0f;>L0=:YT0020<jUR`060<ZZU`3:/jL0dKN]0=6g
[@3K^:X0h;b]0P3Q`[@00`3Pb;X0h<^n0>3=_`020>3=_`<0h<g000D0h<k10>3=`03PcL00hLJj0>2m
/@020=nfZ0060=bbW`3HZiD0dj>;0=>SR`3BX8T0e:B?0P3I/Il01P3N_k40hLZn0>7>`P3Qc/80hLRn
0>6o]`80gkbb00D0g[na0=k5/`3NaK<0glNe0=g0[`020=RdX`060=B[V@3BYY80cYf90<jMR@38Tgl0
a91l0P33U8001P31Tgl0_8Yf0;V4KP2iQ6h0^8A]0;R7L080^HUc00D0^hae0;j?M@30T7@0`91d0<2>
L`020;n<LP060<2=L`35TWX0c9b50<bLQ@3AXXd0d:6<0P3>WHT01P3;VhH0b9R30<JEP@36UH40a9=n
0<:AO@80`I9l00D0`IEo0<JLQ035W8D0aIb50:B1L002069>A@0603dd<P1KDe40UXj:09J>RP36`/00
hN7R0P3Vj>X00`3RiNH0h>CT0>7Si0020>7Si0050>3Si03Phn<0h>?S0>3Sh`3Ph^<0103Ph^820>3R
h@@0h>7Q00D0h>7P0>3Ph03Ph>00h>3P0>CTh`020>SWi`030=SIf03oool0oooo02P0oooo8`3gmoL0
103ge[d0mmK60?OFaP3ge[d20?ONcP060>o>]@3WYH`0gZfD0=j]U03ge[d0klje103ge[d30?OFaPX0
mmk>00H0mmK60>o>]@3_aZd0klJ]0>nmY@3W]I@20>NUS0040=jLQ03WYH`0klje0>o>]@80mmk>0P3g
e/H00`3ge[d0mmK60?OF_@040?OF_@060?OFaP3ge[d0klJ]0>o6[@3__JD0ikFL0`3N[I@01@3FW8@0
_HA[0;f4J`3>S7<0cXa[0080cXac00H0cYAk0<jDL`3>U7/0cYAk0=JLL`3FS7/20=JLL`050<jDL`3F
W7<0eYac0=jUS03W]I`00`3W]I@50=jUS0@0eYb40P3FYH`01@3NW8@0eZF<0=JUS03FYH`0YHB40080
BS4a00<0Ng=k0?Ogm`3gmoL08@3gmoLP0?ooo`007P3oool0103Hf=P0inOV0>OWiP3Ti><30>3Pg`@0
h>3P103PhN080>3Qh@030>3QhP3Ph^80h>;R00@0h>;R00H0h>;S0>3Si03PhN00h>7P0=oGd03Oc;h2
0=o6]@050=k2/@3J^:D0f[RU0=>/U@3>XXX00P3;XHT01P3<ZY@0dKBS0=RfZ@3H]ZT0gKFZ0>2h[@80
h<6d00<0h<Rj0>3<_P3PcL001@3PcL001@3Pc/40h<g00>3=`03PbK/0hLBc0080h;j/00H0gkRS0=Z`
V@3DZ8l0e:R?0=6QR03BX8T20=NZU`060=fl[@3PbK`0hLg10>7=`@3Qbkl0hLJj0P3P`kL01@3Pa;L0
h<Ni0>37^@3PakT0g/6c0080f[NX00H0eZjN0=:XU@3>XHd0cZ6=0<ZJQ@37Uh820<JGP`060<>CO`2n
RgH0^XA_0;Z4K`2iPfd0^HI_0P2iR7<01@2kS7H0_Xmi0<:ANP32TGX0a95j0080ai9l00H0bYN10<jM
Q`3@Xhd0d:>=0=2TS`3=X8/20<^LQ`060<VJQ@38VH@0aiR30<NHP`35UX40`i=n0P31TW`01@31UWd0
aI^10<BKP`34Vh<0YX=`0080JeA800H0@C8/04Pk=P1cIf80LfMR0:^SX03Ed]820>7Rh`050>3Si03P
i>@0hNCT0>7Ti03Phn@00`3Phn<20>3Rh`@0h>;R1P3PhN401@3PhN00h>3P0>3Ph03Ph>00i>CS0080
j>OW00<0f=WH0?ooo`3oool0:03ooolS0?Ogm`<0mmJm00<0mmK60?ONcP3gg/h00P3W]I`20=j]U006
0?Nm]@3_c[D0mmJm0?OF_@3g_KD0mmJm0P3ge/H50?ONcP030?OWgP3gg/h0mmk>00<0mmk>00H0mmK6
0?OF_@3gc[D0mlje0?O6[@3__JD20>NeU080ijF<0P3_aZd20?OFaP80mmk>0P3ge/H20?ONcP050?OF
aP3gg/h0mmk>0?OFaP3ge[d00`3__Jd00`3W]I`0g[FL0=jeW0040=jUS0060<jDN`3>S7<0_HA[0;f4
J`3>S7<0cYAc0P3>U7/01@3FW7<0eYb40=J<N`3FS7/0gYb40080gZfD00<0ijfD0>NmY@3W]I`00P3W
]I`00`3NYH`0ijfD0>N]U0040=jUS0050=JUQ03FW8@0eZF<0=JUS03FYH@00`3FYH`01@2]Q6/0@RTQ
048Y8@1B>C40HdY20080imk_00<0mno_0?Ogm`3gmoL07@3gmoLP0?ooo`007P3oool0103Hf=P0inOV
0>OWiP3Ti><30>3Pg`@0h>3P103PhN080>3Qh@030>3QhP3Ph^80h>;R00@0h>;R00H0h>;S0>3Si03P
hN00h>7P0=oGd03Oc;h20=o6]@050=k2/@3J^:D0f[RU0=>/U@3>XXX00P3;XHT01P3<ZY@0dKBS0=Rf
Z@3H]ZT0gKFZ0>2h[@80h<6d00<0h<Rj0>3<_P3PcL001@3PcL001@3Pc/40h<g00>3=`03PbK/0hLBc
0080h;j/00H0gkRS0=Z`V@3DZ8l0e:R?0=6QR03BX8T20=NZU`060=fl[@3PbK`0hLg10>7=`@3Qbkl0
hLJj0P3P`kL01@3Pa;L0h<Ni0>37^@3PakT0g/6c0080f[NX00H0eZjN0=:XU@3>XHd0cZ6=0<ZJQ@37
Uh820<JGP`060<>CO`2nRgH0^XA_0;Z4K`2iPfd0^HI_0P2iR7<01@2kS7H0_Xmi0<:ANP32TGX0a95j
0080ai9l00H0bYN10<jMQ`3@Xhd0d:>=0=2TS`3=X8/20<^LQ`060<VJQ@38VH@0aiR30<NHP`35UX40
`i=n0P31TW`01@31UWd0aI^10<BKP`34Vh<0YX=`0080JeA800H0@C8/04Pk=P1cIf80LfMR0:^SX03E
d]820>7Rh`050>3Si03Pi>@0hNCT0>7Ti03Phn@00`3Phn<20>3Rh`@0h>;R1P3PhN401@3PhN00h>3P
0>3Ph03Ph>00i>CS0080j>OW00<0f=WH0?ooo`3oool0:03ooolS0?Ogm`<0mmJm00<0mmK60?ONcP3g
g/h00P3W]I`20=j]U0060?Nm]@3_c[D0mmJm0?OF_@3g_KD0mmJm0P3ge/H50?ONcP030?OWgP3gg/h0
mmk>00<0mmk>00H0mmK60?OF_@3gc[D0mlje0?O6[@3__JD20>NeU080ijF<0P3_aZd20?OFaP80mmk>
0P3ge/H20?ONcP050?OFaP3gg/h0mmk>0?OFaP3ge[d00`3__Jd00`3W]I`0g[FL0=jeW0040=jUS006
0<jDN`3>S7<0_HA[0;f4J`3>S7<0cYAc0P3>U7/01@3FW7<0eYb40=J<N`3FS7/0gYb40080gZfD00<0
ijfD0>NmY@3W]I`00P3W]I`00`3NYH`0ijfD0>N]U0040=jUS0050=JUQ03FW8@0eZF<0=JUS03FYH@0
0`3FYH`01@2]Q6/0@RTQ048Y8@1B>C40HdY20080imk_00<0mno_0?Ogm`3gmoL07@3gmoLP0?ooo`00
7P3oool0103Hf=P0inOV0>OWiP3Ti><30>3Pg`@0h>3P103PhN090>3Qh@H0h>;R00H0h>;S0>3Ti@3P
hN00h>7P0>3Gc@3PbkP20>35/@050=g0[@3D/I`0e;6L0<bPR039W8@00P3=Y8d01P3C[YT0fKBR0=fe
Y`3M]JL0gkJZ0>2k[P80h<:d00H0h<Rj0>3;_P3Pc/80h<k20>3?a03Pcl<20>3>`@050>3=`03PcKl0
h<fo0>3;_03Pb;H00P3Qa;001P3P_ZT0fkJO0=F/T`3E[9<0d::90=2PQ`80e:VC00H0f[VX0=k6]`3P
bkh0h<^n0>7;_@3Qb[/20>79^P050>79_03Qb[h0hLZn0>79_03O`kH00P3K^Z/01P3F/9l0dJRD0<fQ
S03=XH`0bYb80<RKQP80aiV500H0`iF10;n>N@2lR7<0_8Qc0;b7K`2kQfl20;Z8L0050;^9M02nSGT0
`i5n0<>AOP38UH<00P3=VXP01P3BXHh0e:NB0=>XT`3CZ9<0d:JA0<bRS@80bIj900H0b9b70<RKQP37
VX@0aiZ40<FGPP32UH020<6DOP050<6FOP34Vh80`ib40<>LQ02`S7L00P27J5D01P1QASH0E3/_069<
@`1RC4<0QGE`0:bTXP80blW:00D0gMoP0>;ViP3Qi>D0hNCU0>3Si0030>3Sh`030>3Rh`3Ph^80h>;R
00<0h>;R1@3PhN420>3Qh0<0h>3P00@0i>CS0>SWi`3XinL0f=WH:P3oool00`3gmoL0mno_0?O_k`09
0?Ogm`80mno_503gmoL01@3gimh0mlje0?OF_@3ge[d0mmK60080klje00H0gYb40>NeU03W_JD0ikfU
0>o>]@3g_KD40?OF_@80mmK61@3gg/h30?OWgP@0mmk>00D0mmJm0>o>]@3_c[D0mkfe0?O6[@020>nm
Y@060>N]U03WYH`0ikFL0>NeW03g_KD0mmK60P3gg/h40?OFaP050?ONcP3gimh0mnON0?ONcP3ge/H0
0P3_c[D01@3__JD0ikFL0>N]W03W[I`0gZfD00@0gZF<00D0eZF<0=jLQ03NW8@0_HA[0<J<L`020<j<
J`030<jDL`3FS7/0gZF<0080gZF<1`3W]I`01@3W[I@0ijF<0>NUS03NYH`0gYb40080gZF<103FW8@0
1@3FYH@0eZF<0=jeW03N]I`0]Hac0080LdXi00H0FS4Y034Q602<Lf/0S7=[0=k>eP3gknlN0?Ogmb00
oooo000N0?ooo`040=SHf03WinH0inOV0>CTh`<0h>3O103Ph>040>3Qh0T0h>7Q1P3Ph^801P3Ph^<0
h>?S0>3Og@3Pgmd0h=C:0=o7]080g/2Y00D0f;NQ0<fTS03=Y8`0`i9h0<FHOP020<n[U0060=RcXP3M
/jH0gkJX0=nfZ03P_:`0h<6`0P3Pa;D01P3PakT0h<^n0>3?``3Pcl<0h=770>3AaP80h<k200D0h<g0
0>3=_`3PcKl0h<^m0>38^@020>76]@060>32[P3K^Z@0eJjG0=F^U`3AYXd0dJF;0P3D[I@01P3H^J@0
g<>b0=o7^03OakP0h<Ri0>78]P80hLVh00D0hL^l0>7;_`3Qbkl0hLRl0=o3]@020=^jZ@060=F_W03?
Y8l0bYb70<ZLQ`39VXD0aiZ50P34VH@01P32UX40`95l0;n>MP2oSWH0_Xa`0;b:K@80^XI]00D0^XIa
0;j<N034Th40a9>10<^JR@020=6QT@060=JXUP3G[9P0e:ZF0=BZUP3@Z980bjF@0P39Xhh01P38X8/0
aif80<FJQ@35VXD0`iR30<6GP@80`IJ000D0`IN00<>KQ034WhP0a9n80;fHP@020:Z3J006091WC@1i
D3`0JdPl06]8?01]EDh0QGYf0P2d/K00103JgMd0iNSY0>;Ui@3RiND20>3Sh`<0h>;S1@3Ph^850>3Q
h@80h>7P0`3Ph>00103Ti><0j>OV0>SWiP3HfMPZ0?ooob80moOg00D0klje0?OF_@3ge/H0mmK60>o>
]@020>o6[@030<j<J`3FW8`0klje0080klje00<0mkfe0?OF_@3ge[d00P3ge[d20?OFaP80mmk>0`3g
imh60?ONcP80mmK60P3_c[D00`3ge[d0mkfe0>NeW0020>NeW0040>NeU03__Jd0kkf]0>o>]@<0mmK6
00@0mlje0?OF_@3ge/H0mmK60`3gg/h01@3ge/H0mmJm0>o6[@3_aZd0ijfD00@0gZF<0`3FYH`20=JL
Q080gYb<00H0eYac0;f4J`3>S7<0cXac0=J<N`3FW8@20=j]U0030>N]W03W]I`0ikFL0080kkfU0P3W
]I`00`3W_JD0g[FL0=j]U0020=j]U0050=jUS03FYH`0eZF<0=jUS03FYH`00P3FW8@20=JUS080g[FL
00D0eYac0<J<H`36S6<0YF=:08A:>@0205Y2>@0306=:@P2]U9@0moOg01d0moOg803oool001h0oooo
00@0f=SH0>OWiP3WinH0i>CS0`3Ph=l40>3Ph0D0h>7P203PhN440>3RhP80h>;S00H0h>;R0>3OgP3O
em80gmOB0=k9_03K^:D20=J[U@050=2NR@36T7T0aY1i0;n:L@31V7l00P3;[YT01P3F^:L0gKRY0>2k
ZP3P^jX0h<6]0>34/@80h<Fe00H0h<Ni0>3;_P3Pc/<0h<k30>3AaP3Pd<D20>3>`P050>3=`03PcKl0
h<fo0>3;_P3Pb;X00P3Pa[H01P3N`jl0f[bV0=JbW03F/Y`0djfF0=>^UP80e[FL00H0fKfV0=g3[`3O
aK@0glFd0=o3/`3O`Jl20=o3/@050>37]`3Qb;X0hLRj0>73]`3N_:l00P3I]J801P3CZi@0c9j80<RG
PP38Uh80aYF10<BFP@80`9F000H0_i=m0<2BN@2nSg@0_Xmd0;^;KP2hQVX20;N3JP050;Z5L02oSWX0
aYR50<JHQ@3=Whh00P3CYYD01P3G[9T0ejjI0=B[UP3DZiH0d:RC0<^VT080bJB>00H0b:2;0<NMQ`35
VX@0aIZ40<>IPP31V8020<6GO`050<:FO`35VH<0aYn:0<JORP35X8L00P2oU7P01P2aP6@0WF]D08]Q
DP2;HE80PVUP0967P`80^;Nf00@0f]gN0>CWj03Ri>D0h^CU0P3Phn<30>3Rh`@0h>;R1P3PhN420>3Q
h0<0h>3P00@0i>CS0>SWiP3XinH0f=WH:P3ooolP0?Ogm`80mnOW00D0mlJ]0?OF_@3gaZd0mlJ]0>Ne
U0020=jUS0050=jLQ03N]I`0klje0>o>]@3g_KD0103ge[d00`3ge/H0mmJm0?OF_@050?ONcP030?OW
gP3gg/h0mmk>00<0mmk>00<0mmK60?OF_@3ge[d00P3ge[d00`3g_KD0klJ]0>o6[@020>nmY@80ikFL
103ge/H0103_c[D0klJ]0?OF_@3ge[d30?OFaP060>o>]@3g_KD0kkfU0>nmY@3N[I@0gZF<0`3FW8`0
0`3FW8@0eZF<0=JUS0040=JLQ0060<jDL`2mQ6<0cXa[0<j<J`3FW7<0gZF<0P3W[I`30>NeW0030>nm
Y@3W]I`0ikFL0080ikFL0`3N[I@00`3W[I@0gZfD0=jUS0020=jUS0030=JUQ03NYH`0gZF<0080gZF<
0P3N]I`01@3FW8@0eYac0=JLL`3>S7<0_HA[0080HdY200<0S7]c0>ONi`3gmoL07@3gmoLP0?ooo`00
7P3oool0103Hf=P0inOV0>OWiP3Ti><30>3Pg`@0h>3P1@3PhN080>3Qh@@0h>;R0P3Ph^<01P3Ph^80
h=oN0=oGdP3Oem80g/Vl0=^hY@80eZ^E00D0d9j90<J@N@36T7T0_hYa0<6HO`020<^^V@060=JhY`3M
^:T0h;^Z0>2kZP3P`Jd0h<Ba0P3PaKD01P3PakT0h<^n0>3>``3Pc/<0h=760>3@a@80h<k200D0h<g0
0>3=_`3PcKl0h<^n0>38^P020>36]P060=k3[`3J_:H0e[:L0=JbW03C[IH0djjF0P3F]I`01P3I_JH0
gL>_0=o5]03OaK@0gl>c0=o1[`80gl>a00D0h<Ng0>78^P3Qb;X0hL>g0=jl[`020=VeXP060=>[U03<
WXP0b9N20<RGPP36UH40a9J10P30UH001P2oTgd0`99i0;j?M02nSg@0^h]^0;R6JP80]h=Z00D0^XE`
0;n>NP36V8D0aYR50<fOSP020=>VU@060=N/V@3G[YT0e:^F0=B[UP3@Z9<0bjJ@0P39Y8h01P38X8/0
aif70<FJQ035VX@0`iV20<6HP080`IMo00D0`YIo0<FIP`36WhX0aYn:0<FPQ`020;nDN0060;60I02M
Je@0Rf5B08]QDP22JF00THN30P2h]kH0103JgMh0i>OX0>;Ti@3Ri>D20>3Sh`<0h>;S103Ph^860>3Q
h@80h>7P0`3Ph>00103Ti><0j>OV0>SWiP3HfMPZ0?ooob00moOg0P3ginL01@3gaZd0mmJm0?O6[@3g
aZd0ikFD0080gZF<00D0gYb40=jeW03_c[D0klje0?Nm]@040?OF_@030?OFaP3ge[d0mmJm00D0mmk>
00<0mnON0?ONcP3gg/h00`3gg/h00`3ge/H0mmJm0?OF_@020?OF_@030?Nm]@3_aZd0klJ]0080kkfU
0P3W]I`40?OFaP040>o>]@3_aZd0mmJm0?OF_@<0mmK600H0klje0?Nm]@3__JD0kkfU0=j]U03NYH`3
0=JLS0030=JLQ03FYH`0eZF<00@0eYb400H0cYAc0;f4H`3>S6/0cXa[0=JLL`3NYH`20>N]W0<0ikFL
00<0kkfU0>NeW03W]I`00P3W]I`30=j]U0030>N]U03N[I@0gZF<0080gZF<00<0eZF40=jUS03NYH`0
0P3NYH`20=jeW0050=JLQ03FW7<0eYac0<j<L`2mQ6/00P1SBT800`2<Ng<0imkW0?Ogm`0M0?Ogmb00
oooo000N0?ooo`040=SHf03WinH0inOV0>CTh`<0h>3O103Ph>050>3Qh0P0h>7Q0P3PhN820>3RhP80
h>?S00H0h>7Q0>3Ie@3Obl80gl_20=^iZ@3EY9020<j?N`050<N0K@31OFX0`GeZ0;n8LP30VhH00P36
[i`01P3@^ZT0fkj/0>31[@3P`Jd0hL>^0>34/@80h<Fe00@0h<Ni0>3;_@3PcL00h<g00P3Pc/830>3=
`080h<bo00H0h<Zm0>37^P3Na;@0g/Bd0=c1[@3I_:H20=NfX@060=JeW`3G^:40fKfV0=VmYP3L`Z`0
glFa0P3Pa[801@3O`Jl0g;^[0=fl[03M_:`0gl:a0080hL>d00H0hKb`0=fdY`3G[YT0ejjI0=2US03;
VX<20<JCOP060<>AO@2oT7`0_8ii0;b>N@2lSWH0_Xmb0P2kS6h01P2dQFX0/H1X0;F1J`2ePF/0_8Qc
0<>DO`80bIj:00D0cZBA0=>YU@3CZID0ejfI0=N^V@020=B[UP060=2WTP3;Y8h0bJ6;0<VQR`38WHP0
b9Z50P37V8<01P35V840`iMo0<:FO032UW`0a9=l0<JFP@80b9j900D0aj2:0<>HO`33V7l0_HYa0;F0
J@020;26M0060;BNU@30_;X0d=?D0=3Ce03Mh>40hNCU0P3Qhn@0103Phn<0h>;S0>3Rh`3Ph^<50>3R
hPH0h>7Q00<0h>7P0>3Ph03Ph>000P3Ph>00103Ti><0j>OV0>SWiP3HfMPZ0?ooob00moOg0P3ge/H0
1@3gc[D0ijF<0=jDL`3NU7<0eW=S0080eW][00@0eYb40>NeW03Fa[D0e/Je1@3ge[d30?OFaPP0mmk>
00<0mmK60?ONcP3gg/h00P3ge/H20?OF_@060>o>]@3g_KD0klJ]0>o6[@3__Jd0klje0P3gaZd01P3g
e[d0mmK60?OF_@3ge[d0klJ]0>nm[@80klje0`3ge[d01P3g_KD0kkfU0>NeU03W]I@0ijfD0=jLQ0<0
eYb4103>U7/01@3FW7<0cYAc0<jDL`2mQ6/0aXaS0080cXac00<0gYb<0=j]U03W]I`0103W]I`20>nm
Y@<0ikFL00<0gZfD0>N]U03W[I@0103NYH`01@3NW8@0eZF40=JLQ03FW8@0gYb400<0g[FL1@3FW8@2
0;fLS200moOg803oool001h0oooo00@0f=SH0>OWiP3WinH0i>CS0`3Ph=l40>3Ph0D0h>7P2P3PhN40
1P3Ph^80h>;S0>3Si03Phn@0h>3P0>3Cc`80gkne00D0fZVJ0=:CP@39OF`0bGe/0<9`H0020;mfI006
0;n:M@32Wh/0ak6N0<NaWP3A_:X0fl>_0P3PaK801P3Pa[<0h<Fd0>35]P3PaKH0h<Ni0>3:_@80h<bo
0P3PcKl20>3=`0050>3<_`3Pbkd0h<^m0>39^`3PakL00P3Ma;400`3J`:/0fK^V0=ZiX`020=ZiX`05
0=VmY`3K`J`0fl6/0=k4/@3PakD00P3Pb;H01@3O`k<0gKf^0=fm[P3M_Jh0gl6a0080hL6a00H0h;V[
0=baX@3EZYD0eJZE0<jQR@38Uh420<B@O0060;n=N@2kRgL0^8Qc0;R8L`2gR700^HU]0P2gQf/01P2b
PVX0/H5/0;R7LP2hQg80`91k0<NKQP80c:B?00D0cjRC0=>/U`3C[9L0eZjI0=N^V@020=B[UP060=2W
T@3;XXd0bIj90<VNR@38VhD0b9R30P38UX801P37UH40aIAo0<BCO034Tg`0a95k0<JDP080aif900D0
aYn:0<:EO`32UGl0_XYb0;j9LP020<JLRP060=G1^@3Qh>00hnOY0>?Wj@3Phn@0h>;S0`3Phn<30>3R
h`@0h>;R00<0h>7R0>3Qh@3PhN400P3PhN430>3Qh0@0h>3P00@0i>CS0>SWiP3XinH0f=WH:P3ooolP
0?Ogm`80mkfe00D0mlje0>NDQ03WNf/0ig][0=IkJ`020<j<J`060=jUS03W[I`0klje0>o>]@3ge[d0
mmK60P3ge[d50?OFaP030?ONcP3gimh0mnON00D0mmk>0`3ge/H01@3ge[d0mkfe0?Nm]@3_c[D0mlJ]
0080kkf]00<0klJ]0>o>]@3ge/H00P3ge/H0103gg/h0mmK60?OFaP3ge[d30?OFaP050?OF_@3g_KD0
mkfe0>o6[@3__JD00P3W]I`01P3N[I@0eYb40<JLQ036W8@0aXac0<jDN`80cYAc00<0aXac0<jDL`3>
S6/00`3>S6/20=J<N`040=jUS03N[I@0ikFL0>NeW0<0kkfU00<0ikFL0>neY@3W]I`00P3W]I`00`3W
]I@0ijfD0>N]U0020=jUS080gYb40P3FYH`20=JLQ0040=JUS03N[I@0g[FU0=jeY@<0cYAc0P3FW7<2
0<J]YB00moOg803oool001h0oooo00@0f=SH0>OWiP3WinH0i>CS0`3Ph=l40>3Ph0D0h>7P2P3PhN40
1P3Ph^80h>;S0>3Si03Phn@0h>3P0>3Cc`80gkne00D0fZVJ0=:CP@39OF`0bGe/0<9`H0020;mfI006
0;n:M@32Wh/0ak6N0<NaWP3A_:X0fl>_0P3PaK801P3Pa[<0h<Fd0>35]P3PaKH0h<Ni0>3:_@80h<bo
0P3PcKl20>3=`0050>3<_`3Pbkd0h<^m0>39^`3PakL00P3Ma;400`3J`:/0fK^V0=ZiX`020=ZiX`05
0=VmY`3K`J`0fl6/0=k4/@3PakD00P3Pb;H01@3O`k<0gKf^0=fm[P3M_Jh0gl6a0080hL6a00H0h;V[
0=baX@3EZYD0eJZE0<jQR@38Uh420<B@O0060;n=N@2kRgL0^8Qc0;R8L`2gR700^HU]0P2gQf/01P2b
PVX0/H5/0;R7LP2hQg80`91k0<NKQP80c:B?00D0cjRC0=>/U`3C[9L0eZjI0=N^V@020=B[UP060=2W
T@3;XXd0bIj90<VNR@38VhD0b9R30P38UX801P37UH40aIAo0<BCO034Tg`0a95k0<JDP080aif900D0
aYn:0<:EO`32UGl0_XYb0;j9LP020<JLRP060=G1^@3Qh>00hnOY0>?Wj@3Phn@0h>;S0`3Phn<30>3R
h`@0h>;R00<0h>7R0>3Qh@3PhN400P3PhN430>3Qh0@0h>3P00@0i>CS0>SWiP3XinH0f=WH:P3ooolP
0?Ogm`80mkfe00D0mlje0>NDQ03WNf/0ig][0=IkJ`020<j<J`060=jUS03W[I`0klje0>o>]@3ge[d0
mmK60P3ge[d50?OFaP030?ONcP3gimh0mnON00D0mmk>0`3ge/H01@3ge[d0mkfe0?Nm]@3_c[D0mlJ]
0080kkf]00<0klJ]0>o>]@3ge/H00P3ge/H0103gg/h0mmK60?OFaP3ge[d30?OFaP050?OF_@3g_KD0
mkfe0>o6[@3__JD00P3W]I`01P3N[I@0eYb40<JLQ036W8@0aXac0<jDN`80cYAc00<0aXac0<jDL`3>
S6/00`3>S6/20=J<N`040=jUS03N[I@0ikFL0>NeW0<0kkfU00<0ikFL0>neY@3W]I`00P3W]I`00`3W
]I@0ijfD0>N]U0020=jUS080gYb40P3FYH`20=JLQ0040=JUS03N[I@0g[FU0=jeY@<0cYAc0P3FW7<2
0<J]YB00moOg803oool001h0oooo00@0f=SH0>OWiP3WinH0i>CS0`3Ph=l40>3Ph0D0h>7P2P3PhN42
0>3RhP80h>?T00H0h=oN0>7?b`3O]jh0gkN^0=ZPT`3BS7`20<UjJP050<5aH@2nNFL0_WUW0<2=N036
Xhd00P3?]9l01P3G_j/0gLBb0>37]`3PakL0h<Vi0>38^080h<Jh00<0h<Ni0>3:_03Pc;h01@3Pc;h0
1@3Pb[d0h<Rj0>38^P3Pa[L0h<Fc0080gL:^00H0f[nY0=ZkY@3L^:80g;RR0=biX`3J_:L20=_1[@06
0=k4]03Pb;P0h<Zk0>3:^`3Pb;T0glBf0P3O`[D01@3P`kD0hL6b0>71/P3P^JT0g;6O0080eJVD00H0
cJ2:0<JFP@30SgX0`8mj0;b;MP2hR7<20;F5L0060;>3K@2cQ6`0/hA/0;>4K02dQFh0^8Ud0P2oTWd0
1@36VhH0c::=0<nWTP3?Yi80dJ^F0080djjI00H0eZjJ0=N]V03DZY@0e:ZD0<nVT03;XX`20<RNR006
0<RJQ038UX80b9>10<RCP@38TH40ai600P35T7d01@34Sg/0a9B00<JMR`36WH/0aIj<0080`99l00H0
_8I]0;j8L039Whd0bIn=0=W6_P3ViN@20>GZk0040>7Ti@3Ph^<0h>?S0>3Sh`80h>;S1P3Ph^850>3Q
h@<0h>7P103Ph>00103Ti><0j>OV0>SWiP3HfMPZ0?oooal0moOg00D0kmK>0?Nm]@3g_KD0mlJ]0>ND
Q0020=jDL`050=IkJ`3>S7<0cXac0=JUS03__JD00P3_c[D0103ge[d0mmK60?OF_@3ge[d20?ONcP80
mmK6203gg/h30?OFaP060?Nm]@3ge[d0mkfe0?Nm]@3_c[D0kkf]0P3gaZd00`3g_KD0klje0?OFaP02
0?OFaP@0mmk>103ge/H20>o>]@060?O6[@3__JD0ikFL0>NeW03NYH`0eYb40`3>U7/50<J<L`<0cYAk
00@0eYb40=j]U03N[I@0gZfD0`3W]I`30>NmY@050>nmY@3W_JD0ikFL0>NeW03W[I@00`3N[I@20=jU
S0@0gYb<0`3FW8@00`3FYH`0g[FU0=jeY@030<j<J`80eYb40P3N]I`00`3oool0moOg0?Ogm`0M0?Og
mb00oooo000N0?ooo`040=SIf03WinH0inOV0>CTh`<0h>3O103Ph>050>3Qh0P0h>7Q0`3Ph^801@3P
hN40h>3O0>3Pg`3Pf]H0hL_40080h;N[00D0g:>D0=B@O`39Ofd0bGm]0<5hI@020;j0JP060<:BN`3;
Yi00e[RQ0=JhX@3M`Jd0glBd0P3PakT20>3:_0<0h<Rj00D0h<Vk0>39_03PbK`0h<Vl0=o9^P020=k8
^0050=k7]P3OaKD0glFe0>73/P3P_jl00P3M_J/01P3J^jL0f[RR0=beW`3L]Il0fkFP0=ZiY080fkj/
00<0g/>d0>37^@3PbKX00P3PbKX0103Pb;T0h<Ni0>37^@3PaKT20>71/`060>2iZP3L[ih0eJJC0=FV
T`3=WHP0a9B00P2nSWT01P2jRWD0]hMa0;B4K`2dQ6l0/XA^0;64K`80/XMa00H0]h]d0;fANP34VX<0
a9Z30<VQR`3>YI020=6YU0050=>/V03D[YX0e:jJ0=F]V03EZYD00P3CYi401P3?Y8h0bj6;0<RMQ`38
WHL0b9R20<RCO`80b91n00H0b8mo0<N>OP34SWd0a8im0<:@N`32UX020<FNS0050<JNS@32Tgh0`Y=n
0;n8K`2oRG400P35W8X01@3@_;@0fmSH0=oRi03Oh^@0h>?T00<0h>?S0P3Ph^<60>3RhPD0h>7Q0`3P
hN040>3Ph0040>CTh`3XinH0j>OV0=SIf2X0oooo7`3gmoL01@3g_KD0mlje0?O>]@3g_KD0ijF<0080
iiB40`3>S7<01P3N[I@0kkf]0>o>]@3_c[D0mmK60?OF_@80mmK600<0mmk>0?OFaP3gg/h00`3gg/h2
0?OFaP050?ONcP3ge/H0mmK60?OFaP3ge[d00P3_c[D01P3ge[d0klje0?OF_@3ge[d0mkfe0>o6[@<0
kkfU00<0kkf]0?OFaP3ge/H00P3ge/H20?ONcPD0mmK60P3ge[d01P3_c[D0ikFL0>N]U03W[I@0gZF<
0=JLQ080aYb400<0cYAk0<jDL`3>U7/00`3>U7/20=JUQ0040=JLQ03NYH`0gZfD0=j]U080ijfL0`3_
_JD20>NeW0030>nmY@3W]I`0ikFL0080ikFL00D0ijfD0=jUS03NYH`0gZF<0=JUS0020=JLS0030=JL
Q03FYH`0eYb40080eYb400<0eYb<0=jeY@3N]JD00`3FS7/0103FW7<0eZF<0=JLQ03FW8@P0?Ogmb00
oooo000N0?ooo`040=SIf03WinH0inOV0>CTh`<0h>3O103Ph>050>3Qh0P0h>7Q0P3Ph^801P3Ph^<0
gn3P0=oJeP3Of]H0gm770>35]P80g[NU00D0fJFB0=2COP35Q6d0aHA]0;enI@020;f5K0060<BFO`3?
Zi@0f[^U0=ZkY@3O`jl0h<Fe0P3PakT01P3Pb[`0h<^m0>3:_03Pb[`0h<Rj0>37^@80h<Jh00D0glJg
0=g4]03K`Zl0fl:_0=c2[P020=k2[P060>2n[@3O]jX0gKFW0=feY`3J]Z<0fKFP0`3I/id01@3I]Z40
fkbZ0=^lZP3N`[<0h<Jg00<0h<Nf00@0h<Nh0>37^P3PakX0h<Ji0P3Q`KD01P3P]j`0g:bN0=FQT03E
XI00c9V40<BCO@80_Xii00H0^XYe0;R7LP2fQW40]XIa0;B7LP2bRGD20;B=M`060;ZAN@30Ugh0aYf5
0<JMQ@3:XH`0cjF@0P3BZI@01@3E[9L0eZfH0=J]V03DZiH0djRB0080dJB>00H0cj6<0<^PRP38W8L0
b9b70<RFP@38TGd20<R?O0060<N>O034SW/0`Xmj0<:?NP31TWX0`YR00P34Wh`01@36WXh0aYB10<JD
P@33S7D0`Hef0080`YZ700H0aJjT0<g4`P3Ge]L0emKG0=oQh@3Qi>@20>3Sh`030>3Rh`3Ph^80h>;R
00<0h>;R1`3PhN420>3Qh0D0h>3P00@0i>CS0>OWiP3WinH0f=WH:P3ooolN0?Ogm`060?ONcP3__JD0
mlje0?O>]@3ge/H0ijF<0P3NW8@01@3>S6/0aXac0<J<L`3N[I@0klJ]0080mmJm103ge/H40?ONcPD0
mmK600@0mmJm0>o>]@3_c[D0klje0`3ge[d00`3g_KD0klje0>o>]@020>o6[@80kkfU00@0kkf]0>o6
[@3ge[d0mmJm0P3ge/H20?OF_@D0mmK60P3ge[d01P3g_KD0kkfU0>NUS03WYH`0gZF<0=JLQ080aYb4
103>U7/20<JLQ080eYb400@0eZF40=j]U03N[I@0gZfD0P3W]I`30>nmY@80ikfU0P3W]I`20>N]U080
gZfD0P3NYH`0103NW8@0gZF<0=jLQ03NW8@20=JLQ080eYb<00D0eZF40=JLS03N]JD0g[FU0=JUS002
0=jLQ0050=JUQ03FYH`0eXak0=J<N`3Fa/H07`3gmoLP0?ooo`007P3oool0103HfMP0inOV0>OWiP3T
i><30>3Pg`@0h>3P1@3PhN080>3Qh@80h>;R00H0h>;S0=oPh03Of]H0gm[F0=oAa`3PaKH20=jgY@05
0=VUTP3@Tgh0aHA]0<F4K@2mOVD00P2mQF`01P34UWl0cj^D0=ZkY@3J^jD0gl>_0>35]@80h<Ni00H0
h<Zl0>3;_@3Pb[`0h<Zl0>38^P3PakT20>36^0050=o6]`3Ma;@0fl:_0=_2[`3L`Zh00P3N`Zh01P3P
_Zd0gkNZ0=feY`3M]JL0f[JS0=VeX0<0fK>M00D0fKJQ0=^lZP3K_:X0g/:c0>36]`030>37]P040>37
^03PakX0h<Nj0>36^@80hL6e00H0h;N/0=b/WP3EXI00eJ6@0<bIQ034Tgd20;j>N@060;Z:M@2hQg80
]XIa0;J6L@2dQg80/XUe0P2dSGL01P2jTGT0`9Mn0<JMQ@36WHD0bZ6<0<nUT080dZVD00D0eJbG0=J]
V03F[IP0e:^F0=>XTP020=6TSP060<nQS03;X8X0b9b70<RLQ`38UX40b95m0P38Sg`01P37SW`0a8ik
0<:?NP32SgX0`I9j0<:HP080a9n<00D0aYj>0<JDP@36U840`hae0<6=MP020<:JQ`060<F^Y03=a<80
emKG0=OFe`3OhN40hNCT0P3Phn<00`3Ph^<0h>;R0>3RhP030>3RhPL0h>7Q0P3PhN050>3Ph0040>CT
h`3WinH0inOV0=SIf2X0oooo7P3gmoL01P3gg/h0kkfU0?O>]@3gc[D0mmK60>NUS080gYb400D0cXa[
0<J<L`36S7<0gZfD0>o6[@020?OF_@@0mmK6103gg/h50?OFaP040?OF_@3_c[D0klje0>o>]@<0mmJm
00<0mkfe0>o>]@3_c[D00P3_aZd20>nmY@040>nm[@3_aZd0mmJm0?OF_@80mmK60P3ge[d50?OFaP80
mmJm00H0mkfe0>nmY@3WYH`0ijF<0=jUS03FW8@20<JLQ0@0cYAk0P36W8@20=JLQ0040=JUQ03N[I@0
gZfD0=j]U080ikFL0`3__JD20>NmY@80ikFL0P3W[I@20=j]U080gZF<00@0gYb40=jUS03NW8@0gYb4
0P3FW8@20=JLS0050=JUQ03FW8`0g[FU0=jeY@3FYH`00P3NW8@01@3FYH@0eZF<0=J<N`3FS7/0e/K6
01l0moOg803oool001h0oooo00@0f=WH0>OWiP3WinH0i>CS0`3Ph=l40>3Ph0D0h>7P203PhN420>3R
hP060>3Sh`3Ogmh0g]?;0=kCb`3K`k80fKJP0P3DZI801@39VH80_8Q`0;AmI02dOF@0/gaR0080^XQ^
00H0aY^40=>_V03L_ZL0g;jW0>34/03PaKD20>36^0060>38^P3PbK/0h<Vk0>39^`3PakP0h<Fe0P3P
`k801@3O`[00gL2]0=ZnZ@3J_ZT0f[fW0080fk^W00H0g;NV0=^aY03J[j40fZnQ0=VbX03H/j020=Rd
W`060=ReW`3I^:80fkfY0=^mZ@3N`[40h<Fd0P3Pa[@00`3Pa[D0h<Jg0>36^@020>36^@80h<6e00H0
g[V]0=Z]W`3DXHl0e:6?0<fHP`35TWd20;j=N0060;Z:M@2hQg80^8Mb0;R7LP2gRG@0]Xeh0P2hTG/0
1P2lUGd0`YV10<RMR038WHP0c:6=0<nUT080dZRC00D0e:^E0=F/UP3E[9H0dj^F0=6XT`020=6US`06
0<nRS03;X8X0bIf70<VMQ`38V8<0b9Ao0P36TWd01P34T7/0`Xmj0<2?N@30SgT0`95j0<:HPP80aIn=
00D0aYf<0<F@O035T7`0`hQ`0<>>M`020<:IQ@060<6PTP35[JH0d/O50=;7a@3Ng]h0hNGU0P3Qhn@6
0>3RhPH0h>7Q0`3PhN040>3Ph0050>3Pg`3Ti><0inOV0>OWiP3HfMP0:P3ooolN0?Ogm`060?OF_@3W
]I@0mmJm0?OF_@3W_JD0ijfL0P3NW8@01@2mQ6/0aXac0<J<L`3N]I`0klJ]00<0klje00D0mmJm0?OF
aP3ge/H0mmk>0?OFaP030?ONcP030?OFaP3ge[d0mmJm0080mmJm1@3_c[D01@3__JD0klje0>o>]@3_
c[D0kkf]00<0kkfU103_c[D00`3ge/H0mmJm0?OF_@020?OF_@H0mmK600D0mmJm0>nmY@3W[I@0ijfD
0=jUS0030=JLQ0030<JDN`3>U7/0aYb40080aYb400D0eYb40=JUS03FYH`0gYb40=jUS0020>N]W005
0>NeW03W_JD0ikFL0>NeW03W_JD00P3W]I`01P3W_JD0ikFD0>N]U03W[I@0ijfL0>N]U080gZF<00D0
eZF<0=JLQ03FYH@0eZF40=JLS0040=JLQ0040=jeW03W[I`0ijfL0<jDL`80eZF400D0eZF<0=jeW03F
S7<0eXac0=j]U00O0?Ogmb00oooo000N0?ooo`040=SIf03WinH0inOV0>CTh`<0h>3O0P3Ph>070>3Q
h0P0h>7Q0P3Ph^<01P3Phn@0gmkL0=_;`03Kbl00e;:L0<bNP`80`8ee00D0[WeV09i`F@2JJe@0VV]D
0:=bF`020;B6K`060<NOR03E/id0gKnY0=foZ@3Pa;40h<Bd0P3Pa;H01P3PaKL0h<Jh0>36]`3Pa[L0
h<Fe0>34/P80h<:^00D0h<2/0=fnZP3J_JP0f[fX0=VjYP020=ZfY0060=RaX@3F[Yh0eZfM0=J]W@3G
[Yh0f;:P0P3H]Z801P3G^J<0f;^U0=ZnZ@3J_ZT0g/:^0>35/P80h<Fe00D0h<Ff0>35]`3Pa[P0h<Jh
0>35^0020=o3]0060=bl[03H/Yl0djB@0=>TT03<VH@0a99m0P2nSGP01P2jRG@0^8Mb0;R7LP2hQg80
^HUd0;^=N080_I5l00H0_iIo0<BIQ03:WHX0bYf:0<jPS`3@Y9020=6VT@050=:XTP3BZI<0dZVC0=6Z
U@3AZI@00P3@YY401P3>Xhd0bj2:0<RMR038WHP0ai^60<JIP`80a9J000H0`Y=m0<2@NP30SWT0`8ii
0<2?O032UH@20<FMSP050<FIR031Qg40`HMa0;mnI031S7800P33V8401P31U840aI^=0=6l]@3A_;D0
gMcK0>7UiP80hN?T1@3Ph^870>3Qh@<0h>7P103Ph>001@3Ph=l0i>CS0>OWiP3WinH0f=WH02X0oooo
703gmoL20?O_k`050>NeU03WYH`0cXac0<j<L`3NW8`00`2LJe801@2eNf<0_HA[0;f4J`3W_JD0klje
0080mmJm1@3ge/H0103gg/h0mmK60?OFaP3ge/H30?OF_@050?O>]@3ge[d0klje0>o>]@3_aZd00`3_
_Jd01@3W_JD0kkf]0>nm[@3__Jd0klJ]00H0klje00D0mmJm0?OFaP3ge/H0mmK60?OF_@040?OFaP80
mmJm00H0klje0>nm[@3W[I@0ijfD0=jUS03FW8@60<jDN`060<JLQ03FW8@0eYb40=JLQ03FYH`0gZfD
0P3W[I`01@3W_JD0ikFL0>N]U03W[I@0ikFL00<0ikfU0`3W]I`00`3W[I@0gZfD0=j]U0020=j]U004
0=jUS03FYH`0eZF<0=JLS0<0eYb400D0eYb<0=JUS03N]JD0g[FU0:e[DP020<icDP030=JUQ03N]I`0
eXac0080eXac00<0knOW0?Ogm`3gmoL0703gmoLP0?ooo`007P3oool01@3HfMP0inOV0>OWiP3Ti><0
h>3O00@0h>3P1P3PhN090>3Qh@80h>;S00H0h>CU0=oMf`3Ia;L0fLBg0<bQR02gPVD20:1/D`0508iO
B@24FDD0PUQ6089HAP2=HU000P2VOFX01@33WXT0ekJP0=k0[03N`:`0h<Bb00<0h<Be1@3Pa;<01@3P
a;80hL>`0>73/03P`Jh0gl6]0080gL2]00D0g;j]0=biZP3L^JX0fKBT0=J`W`020=F/V`060=FZV`3E
[9/0e;6M0=BaW@3D]Z00ekZT0P3J_ZP0103L`J`0g/>`0=o5]@3OaKD20>35^080h<Jg00D0h<Ff0=k2
/@3N`[40f[bY0=JaW@020=2TS`060<VGQ032SWd0_8Ug0;b9M`2iQg80]hI_0P2fQFl01P2hQg80_8ag
0<2BO030TW`0`YN20<JJQP80bib:00@0cYj<0<jRSP3?Y8l0cjB?0`3@Y9001P3?YI40cZJA0<jTS`3>
Y8l0c::<0<RNR080aIb600H0aI^50<BKQ@32V880`YR20<2EO`30TG/20<2>NP050<2=O@31TX@0`iV:
0<>IRP32UH400P2mQ6T01P2jO5d0_XU[0<6BN031TWP0`H]e0<JAP@80d[J^00@0gM[J0>7Vi`3Phn@0
h>?T103Ph^800`3PhN80h>7Q0>3Qh@050>3Qh@<0h>7P0P3Ph>030>3Pg`040>CTh`3WinH0inOV0=SH
f2X0oooo703gmoL20?OF_@060>NUS03FS7/0cXac0<j<L`2<FT80[G=J0P2<FTX01@2DHdX0W7=S09ac
H`3W_JD0mmJm00<0mmK600<0mmJm0?OFaP3ge/H0103ge/H0103ge[d0mmK60?OFaP3ge/H20>o>]@80
klJ]00D0klje0>o6[@3_aZd0kkf]0>NeW0040>NmY@80kkf]1@3_c[D30?OFaP80mmJm0`3ge/H20?O>
]@060>o>]@3__JD0ijfD0>N]U03FW7<0eYb40P3>U7/01P36S7<0cYAk0<jDL`3>U7<0cXb40=JLS080
eYb400H0eZF<0=j]U03N[I@0gZfD0>N]W03N]I`20=j]U0<0ijfD00<0ijfL0>N]U03W[I@00P3W[I@0
1@3N[I@0eYb<0=JLS03N[I@0eZF<0080eYb<0P3FW8@40=JUS080aZfU00D0]G=J0<I[DP36Je80cYAk
0=JUS0020=JLQ0030=JLL`3g_KD0moOg01d0moOg803oool001h0oooo00D0f=WH0>OWiP3WinH0i>CS
0>3Pg`040>3Ph0H0h>7P2@3PhN420>3Rh`060>3Ti@3OgM/0fLBg0=W4]`3<XHP0]h9U0P2PK5<01@2>
GdT0Q5U5089HAP22F4H0SF9@0080YWeZ00D0`ij90=NfX03N`:`0g/2/0>34/P030>34]@D0h<Bc00D0
h<Bb0>73/03Q`k00h<6^0=o1[@020=g0[@050=bn[@3L^JX0g;VZ0=VdY03F/9l00P3E[9/01P3EZY/0
eJbK0=BaW@3D/Id0e;JP0=NjY080f[jX00@0g<6/0=k3/03OaKD0glFe0P3PaKP20>36]`050>35]P3N
`[40g/:a0=ZlZ@3F/Id00P3@Y8l01P39Uh@0`Xim0;b9M`2lRGL0^HMb0;N6K`80]XE_00H0^8Mb0;b<
M`30TW`0`99l0<:GPP36VXH20<^LRP040<jNS03>XXh0cjB?0<nTS`<0d:B@00H0cjFA0<jVT@3>Y8l0
cZB?0<bRS038WXP20<FLQP060<FKQ@34VhD0`YR20<:HPP30UGl0`95k0P30SWX01@30SGd0`I:40<>I
RP33VHX0`YF10080_HAY00H0^WaM0;j9J`31TWP0`I9h0<6;M@36TH420=:f[P040=gJfP3Qi^L0h>?T
0>3Si0@0h>;R00<0h>7R0>3Qh@3PhN401@3PhN430>3Qh080h>3P0`3Ph=l0103Ti><0inOV0>OWiP3H
f=PZ0?oooa`0moOg0P3ge[d01P3WYH`0eXak0<j<L`3>S7<0S5Y20:ecFP80S5Y:00D0U6=:09acH`2L
Lf<0ikfU0?OF_@030?OFaP030?OF_@3ge/H0mmK600@0mmK600@0mmJm0?OFaP3ge/H0mmK60P3_c[D2
0>o6[@050>o>]@3_aZd0klJ]0>nm[@3W]I`0103W_JD20>nm[@D0klje0`3ge/H20?OF_@<0mmK60P3g
c[D01P3_c[D0kkfU0>N]U03W[I@0eYac0=JLQ080cYAk00H0aXac0<jDN`3>U7<0cYAc0<j<Q03FW8`2
0=JLQ0060=JUS03N[I@0gZfD0=j]U03W[I`0g[FL0P3N[I@30>N]U0030>N]W03W[I@0ijfD0080ijfD
00D0gZfD0=JLS03FW8`0gZfD0=JUS0020=JLS080eYb4103FYH`20<J]Y@050;EcFP36Je80aV]B0<jD
N`3FYH`00P3FW8@00`3FW7<0mkfe0?Ogm`0M0?Ogmb00oooo000N0?ooo`040=SIf03WinH0inOV0>CT
h`@0h>3P1`3PhN090>3Qh@80h>;S00H0h>CU0=oLfP3I_k80fKnb0<RFO02VKU8208AC>P0507I;=P1e
C3/0LD/m075;?@1fDDD00P2ELF801P2nVXL0ekJR0=o1[`3O`Jl0h<Bd0>34]@80gl>c00H0gl>`0=o3
[`3O`jl0gl>_0=o3/03O`k420=o2/@050=o1/03N`K00gL2`0=g0/03M_k000P3L_:h01P3J]jP0ejnP
0=BXV@3DZ9T0dZ>E0=2RTP80cZFA00H0d:bF0=FdW@3H^Z@0f;ZT0=ZnZ03L`Jh20=k4]080h<Fh0P3P
a[H01@3PaK<0g/2^0=k0[P3J]jH0e:bJ0080cJ2<00H0aI>20;j9N`2jQGH0^XEf0;R5K`2fQF`20;B3
J`060;J5K`2kRWD0`95l0<2AO034V8<0aY^60P38VXH01@39VhH0bYf90<^PS03;X8`0cZ6>0080cZ2>
00H0c9j;0<ZNR@3:WhT0bYn90<ROR@35W8H30<:IP`050<6IPP31V840`IR10<2EO`30TG/00P30SWX0
1@30SGd0`I220<6EQ031UH@0_Y5j0080^8AW00H0]7eK0;J1H@2jQFT0^XEY0;f2J`35SWl20=:e[P04
0=gJf@3Qi^L0h>?T0>3Si0@0h>;R1P3PhN430>3Qh0@0h>3P0`3Ph=l0103Ti><0inOV0>OWiP3Hf=PZ
0?oooa`0moOg0P3gaZd01P3NU7<0cYAk07=2:@1c@RT0eYb408aJBP80Q59200D0LdY20:EcFP2ULeX0
ikfU0?OF_@060?OFaP040?OF_@3ge/H0mmJm0?OF_@80mmK60P3_e/h70?OFaP040>o>]@3__Jd0kkfU
0>nmY@80ijfL0P3N[I@00`3W[I`0klJ]0>o>]@020>o>]@040?OF_@3ge/H0mmK60?OF_@<0mmK60`3g
e[d01P3__Jd0ikFL0=jUS03NYH`0eXak0<j<Q0<0cYAc00D0cYAk0<J<L`36S7<0eYac0=JLQ0020=JU
S0040=j]U03NYH`0gZF<0=jUS080gZfD0P3W]I`0103W[I`0ijfD0>N]U03NYH`30=j]U0060=jUS03F
YH`0gZfD0=j]U03FYH`0eYb<0P3FYH`01P3FYH@0eYb40=JLQ03FW8@0eYb<0<J]Y@80eZF<00D0]G]S
0<J<H`36S6<0cXa[0<jDL`020=jUS0030=J<N`3NYH`0moOg01d0moOg803oool001h0oooo00@0f=WH
0>OWiP3WinH0i>CS0`3Ph>080>3Qh0P0h>7Q00D0gn7Q0>3RhP3Ph^80h>?R0=oIeP020=Vm/0060<RD
OP2WKU@0Q58j08AB>P1cB3@0KDHf0P1U@SL01@1YB3l0S6YM08aZG@2kV8D0ekJR0080gl6_00H0gl>b
0=k2/@3N`[00g/:`0=o3[`3Pa:l20=o3[@060=boZ`3I^jT0f;ZY0=RjZ@3G^JP0e[NV0P3C/j801@3B
/J00d[2O0=:`W`3A[9`0cjFG0080cIjA00H0biR<0<VGR@39VhP0bI^80<bRS03AZY@20=FbW0040=Nh
X`3J_Z/0g/>c0=k3/`80h<Fh0P3Pa[H01@3Pa;<0g[n^0=jo[P3J]:D0e:RH0080c9b:00H0`i5n0;b7
M`2hPg40^8=a0;N2J`2ePfP20;>3JP060;B4KP2hR7<0_Hmi0;f?N@2oU7l0_iN10P2oUX001@30UX00
`iV30<NMR@37WHT0bj2=0080c9n<00H0bI^70<NIQ037VhD0ai^50<JMQ`34VhD20<:IP`80`9N10P30
UX001P30UGh0`95k0<2>NP30SWX0`8em0<2@P080`9:000D0^Xif0;20H`2`P6<0Z7AD0:M_D@020:a`
E0060;EeGP32S7/0d[J^0=:f[P3Mf]T0hNGV0P3Phn@20>3RhP80h>7R1P3PhN430>3Qh0@0h>3P0`3P
h=l0103Ti><0inOV0>OWiP3Hf=PZ0?ooo`030?O_k`3gmoL0moOg01P0moOg00D0mno_0>NeU03W]I@0
iiB40:EcFP020;EcFP0506=2<@2<FT80S6=B08aSDP24He800P24JeX01P3W_JD0mmJm0?OFaP3ge/H0
klje0?OFaP80mmJm00H0klje0?OF_@3_c[D0klje0=K6]@3_c[D70?OFaP80e/Jm0P3ge/H20=K6]@80
ikfU0P3N[I@0103NYH`0gZfD0=jeW03N]I`20>o>]@H0mmK60`3ge[d01@3__JD0ikfU0=jUS03NYH`0
eYb400<0cYAk0P36S7<20<jDN`060<JLQ03FW8`0eZF40=JUQ03NYH`0eZF<0`3NYH`60=j]U0030=JL
S03FYH`0gZF<0080gZF<00<0gZfD0=jUS03NYH`00P3FYH`20=JUQ0060=JLQ03FYH@0eYb40=JLQ03F
W8`0aZfU0P3FYH`01@2eNf<0YF=:0:ESBP2UDST0YD8a0080cW=B00<0eYac0=J<L`3gmoL07@3gmoLP
0?ooo`007P3oool0103HfMP0inOW0>OWi`3Ti><;0>3Qh0D0h>7Q0`3OhN401@3Oh^80h>7Q0>3Qh@3P
g]`0gm?=0080f[^_00H0bYZ80;1hH`2AGDL0TEe707M;=`1T@34205Xk<00506=4>`29JE`0RFUL0;ZG
Q03G]Z000P3O`J/01P3N`Jd0g;n[0=c0[@3L`:d0g/:`0>34/@80gl:]00H0fK^U0=:bW@3>[IT0cZfI
0<b[U`36Y9020;nKQ`050;^FPP2jUH40^YF10;VCPP2iT8400P2iRgl01P2kQgd0_hYm0<>AOP33TGh0
aiN10<VKQ080bj6;00H0cjZE0=FeXP3K_Zh0fkj^0=o4]P3PaKP20>35]`050>34]@3N_Zl0g[j_0=Zc
Y@3DYiL00P3;W8T01P33TW`0_8Ub0;R4J`2hQ6/0]h9V0;F2I`80/hA[00D0/hI`0;N8L`2iS7H0^Haf
0;R@N`030;NBO@050;VCO@2nUX00a9^60<BKQP37X8/00P37Wh/01034VhH0`iR20<FJQ035VX@20<JM
Q`80a9^400H0`IR20;nFP02oUWl0_iIo0;nDOP2oTG/20;n>NP050<2=O030T800`9>00<2CP02hS7@0
0P2XN5h01P2KHdT0UeTo09iI@02NFD00[6M=0;j7LP80dKFZ00H0gM[H0>7Ui`3Phn@0h>?T0>3RhP3P
hN880>3Qh@<0h>7P103Ph>030>3Pg`040>CTh`3WinH0inOV0=SHf2X0oooo6`3gmoL01@3gimh0gYAc
0=jDL`3W[I`0[G=J0080]G=J00D0@QP@07=:>@1B<BT0DS4Y07=:@P0208ASDP040>NmY@3ge[d0mmJm
0?OF_@80klje0`3ge/H30?OF_@060>o>]@3N]I`0aYb40<JLQ03N]I`0eZF40P36U7/00`3>S8@0aYAk
0<JDN`020<JDQ080eYb<00H0cXb40=JLS03NYH`0gZF<0=jLS03NYH`20=j]U0030>NmY@3_c[D0mmK6
00H0mmK60P3ge[d01@3__Jd0ikFL0=jUS03NYH`0cYAk00<0cYAc00@0cXa[0<J<L`36U7/0aYAk103>
U7/01036W8@0eYb<0<JLQ036W8@40=JUS0<0g[FL00<0eZF<0=j]U03N[I@01@3N[I@40=JUS0060=JU
Q03FW8@0aYb40<JLQ03FW8`0g[FL0P3FYH`01@2eQ6/0YF=:0:ESBP2]FT80YE8i0080_EY200<0cXAS
0=J<N`3gmoL07@3gmoLP0?ooo`007P3oool0103HfMP0inOW0>OWi`3Ti><;0>3Qh0D0h>7Q0`3OhN40
1@3Oh^80h>7Q0>3Qh@3Pg]`0gm?=0080f[^_00H0bYZ80;1hH`2AGDL0TEe707M;=`1T@34205Xk<005
06=4>`29JE`0RFUL0;ZGQ03G]Z000P3O`J/01P3N`Jd0g;n[0=c0[@3L`:d0g/:`0>34/@80gl:]00H0
fK^U0=:bW@3>[IT0cZfI0<b[U`36Y9020;nKQ`050;^FPP2jUH40^YF10;VCPP2iT8400P2iRgl01P2k
Qgd0_hYm0<>AOP33TGh0aiN10<VKQ080bj6;00H0cjZE0=FeXP3K_Zh0fkj^0=o4]P3PaKP20>35]`05
0>34]@3N_Zl0g[j_0=ZcY@3DYiL00P3;W8T01P33TW`0_8Ub0;R4J`2hQ6/0]h9V0;F2I`80/hA[00D0
/hI`0;N8L`2iS7H0^Haf0;R@N`030;NBO@050;VCO@2nUX00a9^60<BKQP37X8/00P37Wh/01034VhH0
`iR20<FJQ035VX@20<JMQ`80a9^400H0`IR20;nFP02oUWl0_iIo0;nDOP2oTG/20;n>NP050<2=O030
T800`9>00<2CP02hS7@00P2XN5h01P2KHdT0UeTo09iI@02NFD00[6M=0;j7LP80dKFZ00H0gM[H0>7U
i`3Phn@0h>?T0>3RhP3PhN880>3Qh@<0h>7P103Ph>030>3Pg`040>CTh`3WinH0inOV0=SHf2X0oooo
6`3gmoL01@3gimh0gYAc0=jDL`3W[I`0[G=J0080]G=J00D0@QP@07=:>@1B<BT0DS4Y07=:@P0208AS
DP040>NmY@3ge[d0mmJm0?OF_@80klje0`3ge/H30?OF_@060>o>]@3N]I`0aYb40<JLQ03N]I`0eZF4
0P36U7/00`3>S8@0aYAk0<JDN`020<JDQ080eYb<00H0cXb40=JLS03NYH`0gZF<0=jLS03NYH`20=j]
U0030>NmY@3_c[D0mmK600H0mmK60P3ge[d01@3__Jd0ikFL0=jUS03NYH`0cYAk00<0cYAc00@0cXa[
0<J<L`36U7/0aYAk103>U7/01036W8@0eYb<0<JLQ036W8@40=JUS0<0g[FL00<0eZF<0=j]U03N[I@0
1@3N[I@40=JUS0060=JUQ03FW8@0aYb40<JLQ03FW8`0g[FL0P3FYH`01@2eQ6/0YF=:0:ESBP2]FT80
YE8i0080_EY200<0cXAS0=J<N`3gmoL07@3gmoLP0?ooo`007P3oool0103HfMP0inSW0>OXi`3Ti><:
0>3Qh0D0h>7Q0`3OhN401P3Ph^80gn;R0=oPg`3Oh=l0gmSB0=g:_`80f[RY00H0bib=0:ahI`25E4<0
QEA306Hn;P1B=2L204/b:00505U0=`26J5/0QVQK0;ZHQ@3H]Z000P3N_jP01P3L_jP0fkfW0=bnZP3L
_ZX0gl:_0>34/@80gl:]00H0fKZS0=2^U`38YHl0b:F?0<6NR02gTg`20:^6K`050:5mJ02KNFH0VgUV
09IeIP2DLVH00P2FKf@01P2NKf@0ZWMY0;J2K`2fPVl0^XI_0;V3K080^89/00H0_8Ye0<NLR@3D/Z00
e;:P0=g0/03Pa;H20>35]`050>34]P3N_k00g[n`0=ZeY@3DZIL00P3<WHT01P33TW/0_8]_0;R6J02h
QVP0]HAU0;>4I`80/HE[00D0/hM`0;N:M02iSWP0^Hih0;VBO@030;RDO`050;^EP030Uh40aIZ50<FJ
Q@35W8P00P33VhL01P2oUh<0_YJ10<:JQ032VX@0aif70<RNR080aYb600H0`YV30;nFP02lU7h0_9An
0;^BO02jSgX20;b>N@050;j?O030TX00`IB00<6DP02hRg@00P2ULe`01P2EFT@0T4df09M==@2GCCD0
Yee30;b0JP80d;:V00H0gMWG0>7Vi`3Phn@0h>?T0>3RhP3PhN870>3Qh@<0h>7P1@3Ph>030>3Pg`04
0>CTh`3WinH0inOV0=SHf2X0oooo6`3gmoL01@3ge[d0gYAc0=jDL`3W[I`0_HA[0080Ld8a0P0a8AP2
048Y8@0506=2<@1cBT80LdY20>o6[@3ge/H01P3ge[d01P3ge/H0klje0>o6[@3_aZd0g[FL0<J<L`80
]HA[00@0Q58i07=:@P2LJe80W6]B0`2mQ6/01P2ULeX0W7=S0:E[DP2UJe80]HA[0;EcFP80aYAk00H0
eXak0<j<L`3N[I@0gZfD0>NmY@3_aZd20?OF_@D0mmK60P3ge[d01P3__Jd0ikFL0=jLQ03NW8@0eYac
0<jDN`80cXa[00H0aXac0<JLL`2mQ6/0_HA[0;F<L`36W8@20=JLS0040=JLQ03>U7/0aYb40<JLQ080
eYb40P36W8@01@3FYH`0gZfD0=j]U03N[I@0g[FL0080gZfD00<0ijfL0=j]U03FYH`00P3FYH`0103F
W8`0eYb40=JLQ03FYH`30<JLQ0@0eZF<00<0[HA[0:E[DP2UJe800P2]FT820;eJ@P030<j4H`3NW8@0
moOg01d0moOg803oool001h0oooo00@0f=WH0>OXi`3Wj>L0i>CT203PhN030>3Qh@L0gn7Q00H0h>;R
0>7Ti03Qh=l0hN3O0=kCbP3L`K420=ZaW`060<VIR02JJed0Hc/`06<k<0149Q/0>R@K0P0j9b001@1=
>C00P6IH081VF02kVXH0fKRP0080gKjV00H0g;fV0=flY@3N_ZP0g[jX0=o2[03Pa:l20=o3[@060=bm
YP3D/Y`0bJF?0<VUS`2kUh40[XYd0P2QOFL01@2ALEh0OfIH07mVF01aFe40JU=:0080KE1500H0NUA5
08eQCP2OKUX0WfiJ0:I`F`2UJ5<20:=RC@060:MYE02gPVd0c:B@0<bTT03K_:X0h<Be0P3Pa[P01@3P
aKP0g/2b0=k0/P3J^:H0e:bH0080bij800H0`i9j0;^:KP2fQfP0]XMX0;:6I@2^Pf@20:]nI0060:f0
J@2eR7<0_95k0;bAN`30Uh00`9V20P30VH<01@31V880`iJ00<BEP@34UH40`YB20080_Y>100H0^I9n
0;VDOP30VH<0`9V30<NMQ`39WXP20<NLQP060<>IP`2nUGl0^95l0;RAO02dSgT0]8eh0P2fSWT01@2k
TG`0`9B00<2EO`30UGl0]hYd0080YW=L00H0UU]5099>>02ICCL0VDdg0:QJ@P2lO6L20=2_Y@050=gI
e`3Qi^L0h>?T0>3Si03PhN80203PhN430>3Qh0@0h>3P103Ph=l0103Ti><0inOV0>OWiP3Hf=PZ0?oo
oa/0moOg00D0klJ]0>MkJ`3WNf/0ijfL0=JLS002048H4005048@4012:B40DS4Y058a:@1B>C400P1k
He801@3_aZd0mmK60>o>]@3_c[D0mmJm00<0mlje103ge[d01P3_c[D0klJ]0=jeW03N]I`0aYb407=:
>@80[HA[00D0c[Fm07]SFP1kHeX0[HA[06=:@P0202TH600608AB>@1c@RT0]G]S0;EkH`2]Je80[EY2
0P2UDST0102]FT80ikFD0>o6[@3_aZd50?OFaP80mmJm00H0klJ]0>NeW03NYH`0gZF<0=JLL`3>U7<2
0;F<L`060<JLL`2mQ6<0_HA[0;f4J`36W8@0eZF<1`3N[I@0103NYH`0eYb<0=JLS03FW8`20=JLQ005
0<JLQ03FYH@0gZfD0=j]U03N]I`00`3N[I@20=JUS080aYb400@0eYb40<JLQ03FW8@0eYb4103FYH`0
0`2eQ6/0[F]B0:e[DP020:eJ@P80_EY200<0cW=J0=JLQ03gmoL07@3gmoLP0?ooo`007P3oool0103H
fMP0inSW0>OXi`3TiN@40>3Qh@<0h>7P0`3PhN480=oQh@060>3RhP3SinP0i^KT0>KVi03Se<X0gKbY
0P3JZiD01P35TX00TF=F05@b:@1D<RT0=1`E02dL5@80<20I00D0Ac<[07iTE`1nI5L0^ib80=ZjX`02
0=joZ0060=bmYP3L_:D0g[jW0=jnY`3O`J/0h<B]0P3P`jd01P3O`J/0fKVT0<fZU@3=ZYD0_YV40;B>
N@80ZXIb00D0U7IV07EOE01eGe@0FTY204`k=00204hf;00605/l;@1_C3X0PUa:089LBP2?H4h0UU]7
0P2KF4<01P2THTd0]GiX0<^RS03;XX`0f[^X0=o5]@80h<Rl00D0h<Vm0=k5]`3NaKL0f[bZ0=B_V@02
0<^OR@060<6@N@2hQfd0/XAV0;:4IP2]Pf80Y7QJ0P2JJE401P2MJUD0[7aW0;^>MP2kSWH0`IAk0<:F
N`80`9El00D0_95j0;R;M@2gR7<0]hQc0;V9M`020;V<N`060;N?O02hTgd0_iR00;nHP036W8@0aif6
0P36W8D01P32VH<0_IAn0;J?N@2fSgT0/8]e0:n;MP80/hii00D0^I5l0;nCO`2nTWd0_Y9m0;B6L@02
0:9`F`0609AKA`2CDch0W5@n09aD?P2[GdT0_Wi]0P3B/JT0103OfmT0h^OX0>7Si03Qhn@80>3Qh@80
h>7P1P3Ph>040>3Pg`040>CTh`3WinH0inOV0=SHf2X0oooo6P3gmoL01P3oool0ikFL0<icDP3>Le80
ijfD0>neY@80DS4Y00D0>BTQ048Y<@1B<BT0DS4Y06=2<@0207=BBP040>o>]@3ge[d0mmK60?OFaP@0
klje00@0mmJm0?OFaP3ge[d0mmJm0P3_c[D20=JUS0050=j]U036U7/0YHAk0:F4N`1J@ST00P1J<B40
1P2DQ8@0Q7>D02TH600Y61P0Le9:08AB>@80_JFL00H0]IbL08aJ@P2]FT80[EY20=JLL`3__JD20>o>
]@80mmK60`3gg/h20?OFaP060>o>]@3__JD0gZF<0=jUS03FW7<0cXa[0P2mQ6/20;EcFP80_HAS00<0
eZF40=jeW03N]I`00`3N]I`20=j]U080eZF<0`3N]I`20=JUS0060=JLS03FYH@0eZF<0=JUS03N[I@0
g[FL0P3N[I@01P3FYH`0eZF40=JUQ03FYH@0aYb40=JUQ0<0aYb400@0eZF<0<JLQ036W8@0W7=S0P2D
HdX20:ESBP80aV]B00<0cXa[0=jLQ03gmoL07@3gmoLP0?ooo`007P3oool0103HfMP0inSW0>OXi`3T
iN@40>3Qh@<0h>7P0`3PhN480=oQh@060>3RhP3SinP0i^KT0>KVi03Se<X0gKbY0P3JZiD01P35TX00
TF=F05@b:@1D<RT0=1`E02dL5@80<20I00D0Ac<[07iTE`1nI5L0^ib80=ZjX`020=joZ0060=bmYP3L
_:D0g[jW0=jnY`3O`J/0h<B]0P3P`jd01P3O`J/0fKVT0<fZU@3=ZYD0_YV40;B>N@80ZXIb00D0U7IV
07EOE01eGe@0FTY204`k=00204hf;00605/l;@1_C3X0PUa:089LBP2?H4h0UU]70P2KF4<01P2THTd0
]GiX0<^RS03;XX`0f[^X0=o5]@80h<Rl00D0h<Vm0=k5]`3NaKL0f[bZ0=B_V@020<^OR@060<6@N@2h
Qfd0/XAV0;:4IP2]Pf80Y7QJ0P2JJE401P2MJUD0[7aW0;^>MP2kSWH0`IAk0<:FN`80`9El00D0_95j
0;R;M@2gR7<0]hQc0;V9M`020;V<N`060;N?O02hTgd0_iR00;nHP036W8@0aif60P36W8D01P32VH<0
_IAn0;J?N@2fSgT0/8]e0:n;MP80/hii00D0^I5l0;nCO`2nTWd0_Y9m0;B6L@020:9`F`0609AKA`2C
Dch0W5@n09aD?P2[GdT0_Wi]0P3B/JT0103OfmT0h^OX0>7Si03Qhn@80>3Qh@80h>7P1P3Ph>040>3P
g`040>CTh`3WinH0inOV0=SHf2X0oooo6P3gmoL01P3oool0ikFL0<icDP3>Le80ijfD0>neY@80DS4Y
00D0>BTQ048Y<@1B<BT0DS4Y06=2<@0207=BBP040>o>]@3ge[d0mmK60?OFaP@0klje00@0mmJm0?OF
aP3ge[d0mmJm0P3_c[D20=JUS0050=j]U036U7/0YHAk0:F4N`1J@ST00P1J<B401P2DQ8@0Q7>D02TH
600Y61P0Le9:08AB>@80_JFL00H0]IbL08aJ@P2]FT80[EY20=JLL`3__JD20>o>]@80mmK60`3gg/h2
0?OFaP060>o>]@3__JD0gZF<0=jUS03FW7<0cXa[0P2mQ6/20;EcFP80_HAS00<0eZF40=jeW03N]I`0
0`3N]I`20=j]U080eZF<0`3N]I`20=JUS0060=JLS03FYH@0eZF<0=JUS03N[I@0g[FL0P3N[I@01P3F
YH`0eZF40=JUQ03FYH@0aYb40=JUQ0<0aYb400@0eZF<0<JLQ036W8@0W7=S0P2DHdX20:ESBP80aV]B
00<0cXa[0=jLQ03gmoL07@3gmoLP0?ooo`007P3oool01@3Hf]T0inWX0>OYj03TiN@0h>;Q00L0h>7Q
1`3OhN401@3PhN40h>;Q0>3Rh@3Oh^80hNCT0080hn7N00H0hLo40=jhY03IYXl0fJJ?0<F>N@2FIeP2
064n=@0503dV800^7AL0;Q`G02hL5`16;bP00P1nHeD01P2kWXX0fkfV0>32Z`3P`Z/0g;nX0=^mYP80
g;jW00H0g/6Z0=o3[03P`jd0h<>]0>33[`3L_Z`20=:aWP050<NQS034VhL0_iR60;nHQP2VQGD00P1o
IEP01P1LB3l0BCH^04L_9@17;bD0DC@V05m2<`80Ke=500H0PEa=09=OC02SIe40XfMA0;9hH@31T7X2
0<nZU0050=VmZ@3NakL0h<c00>3<`03Pc/<00P3Nb[d01P3J`:h0e;6K0<^OR@3;WhT0`8mh0;B2J`80
[GiS00H0Z7]M09YYC@28D3X0R50j08U??@2NJUL20;:3JP060;J8K02bQVP0[89X0:b2J02TNfD0WG=N
0P2NM5l01@2XOFT0[hIb0:n6LP2`RWH0/Xih0080^I9i00H0_iIl0<6GOP31UX00`IJ00;nEO`2lTW/2
0;F<MP060:n9L`2^RW@0/Xeh0;:=N02iSg`0_Hmm0P2jS7P01@2/OfX0V6UE09QYE@2:ET@0SEA00080
Ve]500H0[FQE0<67N@3F^;00e[R`0>;Ng@3Tj>P20>7Si0P0h>7Q0P3PhN060>3Ph0@0h>3O00@0i>CS
0>OWiP3WinH0f=SH:P3ooolH0?Ogm`80oooo00H0Ld8Y0?O6[@3>Le80cW=B0=jLQ03W[I@207=:@P05
034Q8@12:B40DS4Y058a:@1J<BT00P24He80103_c[D0mmJm0?OF_@3ge[d40>o>]@030?OF_@3ge/H0
mmJm0080mmJm00<0mmK60>o6[@3_aZd00P3N[I@20>nm[@050=jeW024He80Q6=B06=2<@1B<BT00P0a
8AP206<i:@80Nf=J00H0[F]B0;EcFP36Je80aV]B0=jUS03W]I`20>o>]@050?OF_@3gg/h0mmk>0?ON
cP3gimh00P3ge/H01P3_c[D0kkfU0=jUS03NYH`0eXak0;f4J`<0_HAS00D0[F]B07/Y601k:AP0Q4Xi
0<J<L`020<jDN`060<J<H`2eNf<0]HA[0;F4J`2UJe80W6]B0P2eNf<01036U7/0aYB40<JDQ036W8@3
0=JUQ0030<JLQ03FYH`0eZF<0080eZF<00<0aYb40<JDN`36U7/00P36W8@20=JLQ080eYb<0P36U7/0
1@2LJe80U5Y:09AJBP2UJe80[F]B0080cXAS0P3FS7/20?oooa`0moOg803oool001h0oooo00D0f=WH
0>OYj03WjNP0i>KU0>3Qh0030>3Pg`030>3Qh03PhN40h>7Q00P0gn7Q00D0h>;R0>?ViP3Si^H0gn7Q
0<k<b`020<2e/@060<N[W`3GZiH0fjJ=0=^VS@39U7d0Xg=Q0P1dCd<01@1<<bd0=2<P02dL6@0]71T0
@bdV0080Nf5C00H0^Yj:0=^nY`3P`j/0h<>[0=c0Z03K_ZL20=^oZ0060=g1ZP3M`ZX0g/:/0=k2[03O
`k00g/6`0P3G^:H01@3A[9L0dJRC0<jTT@3>Y940^I:10080UWIU00H0NEe?06U=@@1TACL0I4Dg06I4
=01[C3/207EHB00608ITDP2LKeT0/GaU0;5lI@31SWH0cJ290P3D/I/01@3J_ZX0g/Ng0>3=`@3PcL40
h=350080g/^n00H0f/6^0=BaV`3;WhP0bin80<2>M`2dPFT20:akH@060:IeF`2GHTX0Q4Te08A9=@22
B3P0Tf9A0P2PMf<01P2MMel0Sf]D07mOC01oGd`0N5M607]GAP80QV1=00D0TfmK09UgH`2IMf<0UgMT
09YiI0020:>0J@060:b6K@2`R6l0/hU`0;>9L02hRg80^Hac0P2eRW<01P2`RG80[hYe0;><N02cS7P0
^Hej0;^<NP80]8Mb00D0XWQS08YPCP2:H4h0Ndln081>?@02099KA`060:]`G@35Th@0fL2h0=W0^03T
hMl0i>SY0P3Qhn@00`3OhN40h>7Q0>3Qh@030>3Qh@<0h>7P1`3Ph>040>3Pg`040>CTh`3WinH0inOV
0=SHf2X0oooo5`3gmoL01@3Wg^L0FS4Y05Xa:@1J<B40mlJ]0080ikFL00H0mlJ]0>NeW024DT80Q592
03TY8@1B<BT2048Y8@05058a:@24He80Q6=B0>o6[@3ge[d0103_c[D20?O>]@D0mmK60`3ge[d00`3_
c[D0ikFL0=j]U0020=j]U080g[FU00H0[HA[09a[DP1cDTX0Le9:09a[DP24DT820:e[DP030;f4H`2e
LeX0ikFD00<0ikFD0P3_c[D00`3ge[d0mmk>0?OWgP020?OWgP80mmK600H0klJ]0>nmY@3NYH`0gZF<
0=J<N`3>S6/20;f4H`060;f4J`2eLeX0YG=B0:EcDP2<FT80aZf]0P3Fa[d01P2m]Kd0Q58i07/Y601k
:AP0Ld8Y08AB@P80W7=S00D0U5YB08aJ@P2<FT80]G]S0;F4J`030;F<L`030<JLL`36U7/0aYAk0080
aYAk0`3>U7/01@36W8@0eYb40=JLQ03FW8`0aYb40080]Hac00D0Q59208aJBP2<FTX0S5Y:09a[DP02
0=J<L`030=JLL`3>Q6<0moOg01d0moOg803oool001h0oooo00D0f=SG0>OYj03WjNP0i>KU0>3Pg`02
0>3Ng@040>3OgP3PhN00h>;Q0>3Rh@D0gn7Q0P3PhN401P3OhN00h>7Q0>;Ti03Ri>@0e=CD0:RNW080
QFaU00H0UfiQ0<6>N@3DWXH0e9j60<RFO`2WNFH207]EB005058i=00e9RL0:A`M02TL7@0l:bD00P1f
Ge40102hWHT0f[fV0=k1ZP3N`JX20=boZ080fkjX00H0f[fV0=VlY@3J_JL0f[fW0=c0[@3N`K420=^n
[@050=RhY03F/I`0dZVE0=:YU@36W8P00P2cS7P01P2TP6`0W7MU09E^FP2EKUX0SfI@08eUC@80TVYB
00H0WGEM0:j3J@2nSgD0_Xme0<ZIP@3AY8h20=JaV`050=ZmZ@3MakL0glg00=o=`03Oc/400P3Nb;X0
1P3J_JX0djnI0<^NR03;WXP0`Hmg0;R3J@80/7aQ00H0Z7IL09eXD@2AFD@0TEU408iIA`2BJ5X2099b
I@0608EZG01YDdH0C3T`04`i<015<2P0Fcda0P1cDD401@1mGdh0NF5@07UQD01bFTT0M5U80080QFEC
00H0U75L09adG02SMe`0XgML0:mnHP2fQFX20;F9L0060;2:M02_S7H0/heg0;>=M`2iSGP0^HUe0P2/
PF`01@2EL5/0NeM507]GA@1[ASH0KdDe0080Q5A300H0YG5N0<JIR03Ka;/0flBk0>GQh03Tj>P20>7S
h`030=oQh@3PhN40h>7Q00<0h>7Q0`3PhN060>3Ph0D0h>3O00@0i>CS0>OWiP3WinH0f=SH:P3oool0
103gknl0moOg0?Ogm`3gmoL30?O_ka00moOg00D0Hd8a058Q601B8AP0BR4H0>NUS0020?O6[@060>Ne
W03WYH`0S5Y:08aJBP1B@ST0@S4i0P0a8AP00`12:B40S6=B08aSDP040>o>]@80mmJm0P3W]I`0103_
c[D0mmJm0>o>]@3_c[D20?OFaP80mmJm0P3_c[D20>NeW0<0eZF<00H0g[FL0=JUS02eS7<0]Hac0;f4
H`2eLeX20;f4H`060;EcFP3FYH@0gYb40=jLQ03W[I@0ikfU0P3_aZd01@3ge[d0mmk>0?OWgP3gimh0
mmk>0080klje00H0klJ]0>NmY@3NYH`0gZF<0=JLL`3>S6/20;f4H`060;f4J`2mQ6<0[F]B0:e[DP2U
Je80YHAk0P3Nc]H01P1kHeX0YHAk024@400Q4100@S4i08AB@P80Hd8a00D0Q6]J09AJBP2DFTX0Hd8a
09a[DP0209acH`0609a[DP2ULe80]G]S0;EkH`3>S6/0cYAk0P36W8@01P3FYH@0aYb40<JLQ036W8@0
eYb40<JDN`80[HA[00D0Q59207=:>@1cBST0Q6=B08AB@P020=JLQ0040=jUS03>Le80oooo0?oooa`0
moOg803oool001h0oooo00D0f=SG0>OYj03WjNP0i>KU0>3Pg`020>3Ng@040>3OgP3PhN00h>;Q0>3R
h@D0gn7Q0P3PhN401P3OhN00h>7Q0>;Ti03Ri>@0e=CD0:RNW080QFaU00H0UfiQ0<6>N@3DWXH0e9j6
0<RFO`2WNFH207]EB005058i=00e9RL0:A`M02TL7@0l:bD00P1fGe40102hWHT0f[fV0=k1ZP3N`JX2
0=boZ080fkjX00H0f[fV0=VlY@3J_JL0f[fW0=c0[@3N`K420=^n[@050=RhY03F/I`0dZVE0=:YU@36
W8P00P2cS7P01P2TP6`0W7MU09E^FP2EKUX0SfI@08eUC@80TVYB00H0WGEM0:j3J@2nSgD0_Xme0<ZI
P@3AY8h20=JaV`050=ZmZ@3MakL0glg00=o=`03Oc/400P3Nb;X01P3J_JX0djnI0<^NR03;WXP0`Hmg
0;R3J@80/7aQ00H0Z7IL09eXD@2AFD@0TEU408iIA`2BJ5X2099bI@0608EZG01YDdH0C3T`04`i<015
<2P0Fcda0P1cDD401@1mGdh0NF5@07UQD01bFTT0M5U80080QFEC00H0U75L09adG02SMe`0XgML0:mn
HP2fQFX20;F9L0060;2:M02_S7H0/heg0;>=M`2iSGP0^HUe0P2/PF`01@2EL5/0NeM507]GA@1[ASH0
KdDe0080Q5A300H0YG5N0<JIR03Ka;/0flBk0>GQh03Tj>P20>7Sh`030=oQh@3PhN40h>7Q00<0h>7Q
0`3PhN060>3Ph0D0h>3O00@0i>CS0>OWiP3WinH0f=SH:P3oool0103gknl0moOg0?Ogm`3gmoL30?O_
ka00moOg00D0Hd8a058Q601B8AP0BR4H0>NUS0020?O6[@060>NeW03WYH`0S5Y:08aJBP1B@ST0@S4i
0P0a8AP00`12:B40S6=B08aSDP040>o>]@80mmJm0P3W]I`0103_c[D0mmJm0>o>]@3_c[D20?OFaP80
mmJm0P3_c[D20>NeW0<0eZF<00H0g[FL0=JUS02eS7<0]Hac0;f4H`2eLeX20;f4H`060;EcFP3FYH@0
gYb40=jLQ03W[I@0ikfU0P3_aZd01@3ge[d0mmk>0?OWgP3gimh0mmk>0080klje00H0klJ]0>NmY@3N
YH`0gZF<0=JLL`3>S6/20;f4H`060;f4J`2mQ6<0[F]B0:e[DP2UJe80YHAk0P3Nc]H01P1kHeX0YHAk
024@400Q4100@S4i08AB@P80Hd8a00D0Q6]J09AJBP2DFTX0Hd8a09a[DP0209acH`0609a[DP2ULe80
]G]S0;EkH`3>S6/0cYAk0P36W8@01P3FYH@0aYb40<JLQ036W8@0eYb40<JDN`80[HA[00D0Q59207=:
>@1cBST0Q6=B08AB@P020=JLQ0040=jUS03>Le80oooo0?oooa`0moOg803oool001h0oooo00D0f=OF
0>OYj03WjNP0i>KU0>3Ph0020>3Ng@040>3OgP3PhN00gn;Q0=oRh@D0gn7Q0P3Ph^801P3Qhn80g=gM
0<o=c03?cL`0/:VV07]YI@80ESH_00H0Ic/^09=OCP2_NfH0[g]V0:ioJ`2DJe/206e;@P0504Tc<@0`
9BH09QdM02HM7@0j:bD00P1eGe801P2hWHT0fKbU0=c0Z03L`:P0g;nY0=g0Z`80f[VU00H0eK6L0=6]
U`3C/I/0dk6K0=RiYP3N`K420=o5]0050=g3/03J_:P0ek:O0=NbW`3AZID00P3;X8`01P36VXH0`YJ0
0;^>MP2kSWH0]8I/0:n0I@80/81U00H0]XQ/0<2DM`39W840bIb10<nQR03DYi020=N`VP030=ZkY`3M
a[D0glbn0080glbn0P3MaKH01P3I^JP0djbH0<^PRP3;X8X0`i=j0;^7J`80/h1S00H0[7aP0:IeF`2R
KUD0XViE0:1^F@2NMVL209QiK00608I/H01OC4@0<bLT03<W900V6AH0@RTR0P1Q@SD01@1YD4<0HDi2
065>@P1EA3P0FD<f0080Ke9300H0QF9?099YDP2NL5D0WW1E0:ekGP2gQ6P20;J9L0060;6:M02`RgH0
]8eg0;B=M`2jSWL0]HMa0P2OMf801@22HDl0JT`l06Y<?01M?Rl0HCd^0080MdXj00H0WVQE0<>CP03J
`;H0f/2f0>?Og@3SinP20>7Sh`030=oQh@3PhN40h>7Q0080h>7Q0`3PhN070>3Ph0D0h>3O00@0i>CS
0>OWiP3WinH0f=SH:P3ooolF0?Ogm`0608A[FP1J<BT0@RTQ048Y8@126100Ld8Y0P3NU7<01P2eLeX0
YE8i05Y2>@1J@ST0BS4a048Y8@80>BTQ00<0DS4Y08acH`2<Lf<00P3gc[D20?OF_@060>o>]@3ge/H0
ikfU0>NmY@36S7<0kkfU0P3_c[D20?OFaP<0mmk>00@0mmK60>o>]@3_c[D0klJ]0`3W]I`00`3N[I@0
gZF<0=jUS0020=JUQ0<0gYb400D0gZF<0>NeU03W]I@0ikfU0>o6[@020?OF_@030?OFaP3gg/h0mmk>
0080mmk>0P3ge[d01P3_aZd0kkfU0=j]U03N[I@0eYb40<J<L`80_HAS00H0cXa[0;f4J`2mQ6<0_HAS
0;EcFP36S7<20;EkH`0607=:@P2]YJd0610@01P@401JDU80LdY20P1S@S401@2UQ7/0S7]c08akL`1B
@ST0Hd8a0080LdY200H0Nf=B0;EkH`2mQ6<0_HAS0<jDL`3FYH@40=JUS0<0aYb400@0aYAk08aSDP2<
He80Je9:0P1cBST01P1B>C40Q58i0=JUS03FYH`0cXa[0<icDQh0moOg803oool001h0oooo00D0f=KF
0>OXi`3Wj>L0i>KU0>3Rh@030>3Ph0030>3Qh@3OhN40gn7Q00D0gn7Q0P3Qhn<01P3Si^H0emOG0;2X
Y@2`Z:D0OF]V05Dm=P80@bDM00H0B28H05h_8`1gAcP0MdLh081FA`1^CD<204lf=00503HW9`0Z81l0
:1dI02PM6@0o;BH00P1iHE<01P2iWHT0fKbT0=boZ03L_jP0g<2[0=fo[@80f;>R00H0cj>A0<ZMR@3;
XXd0bj:=0=:^V`3J^jX20=g3/`050=g4]03K`K00fKZY0=VjZ@3F/J000P3BZ9L01P3=X8d0b9V30<>D
O@33U7d0`99i0;f>M@80_Xec00H0`I5f0<NJO@3=XHH0cJ660=:US@3EZY<20=NaV`030=VjY`3MaK@0
gl^m0080gl^m0P3M`k@01P3I]ZH0dj^I0<^RSP3;XXh0`iMo0;^;L080]HEV00H0/8AT0:f1H@2^O5l0
[WaO0;1nI02`QG020:f7M@0609mjJP1fFTh0@C4]044a;@0Z7Q/0?BLO0P1G>Rh01@1PAS/0FTHm05Y6
?@1@?SD0ED0d0080KDlo00H0QV1;09M[E02UMU`0YGIL0;:3IP2jRVh20;V:L@060;B9LP2bRWD0]Hmg
0;F?M`2jTGL0[hE]0P2?JUP01@1]CT40FSlb05Xo<P1C>2T0F3LX0080KT0`00H0UEU50;b2K`3E]J/0
eKF[0>3Kf@3Ri^L20>3Sh`@0h>7Q103PhN070>3Ph0D0h>3O00@0i>CS0>OWiP3WinH0f=SH:P3oool0
0`3gknl0moOg0?Ogm`0A0?Ogm`80oooo00D0FS4Y06<i:@1B<BT0DS4Y048H400304X@200508AB@P1B
<BT0@RTa048Y<@1B>C400`0i:B401@1B<BT0YG=J0:EcFP3_c[D0mkfe00<0klje00D0mmK60>o>]@3_
c[D0gYb<0=JUS0020=j]U0030>o>]@3ge/H0mmk>0080mmk>0`3ge/H0103_c[D0kkf]0>nm[@3W]I`3
0=jUS0050=j]U03NYH`0gZF<0=jUS03NW8@00`3W]I@01@3__JD0klJ]0>o6[@3_aZd0mmK600@0mmk>
0P3_c[D01P3__Jd0ikFL0=jeW03N]I`0eZF<0<jDL`80cXa[0P36W7<20<j<J`060<JLL`3FYH`0]Hac
0;F<L`36S7<0Je9:0P0a8B401@0a8AP0HcTY058a:@1B<BT0Le9:00<0FT8i00D0Q6=B09a[DP2LJe80
aYac0;f4J`020<JLL`050=JUQ03>U7<0cYAk0<jDN`3FYH`00`36W8@01@3FYH@0aYAk07=:@P1cBT80
LdXi0080Hd8a00H0DS4Y07=2<@3NW8`0gYb<0<icFP3>HdXN0?Ogmb00oooo000N0?ooo`050=SGeP3W
j>L0inSW0>CVi@3Ph^800`3Ph^480=oQh@80h^CS00H0iNOW0=?Bd@2KSX/0Vhj;05e4?P129Qh2040U
700603lN5@116A40CbLM04lW7@1I=R`0BS8]0P0c8bD01@0X7Ah0:AhI02lN5`0_7QL0ARlV0080OF5D
00H0^ib80=ZkX`3M_jL0gKnW0=boZP3L_J/20=NbXP060=2SU03:W8X0aib70<NLQ`38XH`0c:RE0P3>
[Yd01@3@/j80ck>R0<f_WP3=[ih0b:JF0080`IZ;00H0^8im0;64L@2^PF`0[X5/0:n4K@2aQFh20;B4
K@060;N6K@2lS740`iIl0<>FO03<XHX0dj^E0P3F/id01@3I^jL0gLBc0=o9^P3ObKX0glVi0080gL6`
00H0fKBS0=>ZV@3;Y900bjB@0<>KP`2kSW<20;J7J@060;>7I@2cQf@0]HIT0;F6I02hRFX0_8md0P2n
TGT01P2eRG<0Ug5P06aCB01/DdP0ED0h05]0=@80J4Pj00D0K4`o06M:?`1WBSl0HDLl06Q;?P0207iJ
A`0609IZD`2UME`0[h1T0:n0I02fRVh0^Hmc0P2jSG<01P2hRg80]Xae0;RAN@2hTGT0^I9h0:V3JP80
Pf1?00D0GT4e04dd:@1==2T0Bc8U058b900206Ph9`0608i;=`2eLV00d:^Q0=2[X@3Mf=H0hNKV0P3P
hn<40>3Qh@80h>7P1`3Ph>070>3Pg`040>CTh`3WinH0inOV0=SHf2X0oooo00<0mno_0?Ogm`3gmoL0
4@3gmoL20>oWi`0605Xa8@1J<BT0HcTY06<i:@12:B40DR4H0P126100101J@ST0BS4a03TY8@0i:B42
034Q8@<0@RTQ0P2<Lf<00`3_aZd0mlje0?OF_@020?OF_@050>o>]@3ge/H0mmK60>o>]@3>U7/00P3N
[I@0103FW8`0klJ]0>oFcP3_e/h20?ONcP80kmK>00@0mmK60>o>]@3_c[D0klJ]0`3N[I@0103N]I`0
gZF<0=JLL`3FW7<20=J<L`80gZfD0P3W_JD20>o>]@050?OFaP3gg/h0mmk>0?ONcP3ge/H00P3_c[D0
1P3__JD0ikFL0=j]U03N[I@0eZF<0<JLQ0<0cXa[00D0cYAc0<jDN`3>U7/0cYAc0;f4H`030=JUS005
0:EcFP2LLf<0W7=S08AB@P1SBT800P24DST01@1B>C40S6=B08aSDP2]Q6/0[G=J0080[HA[00H0]Hac
0<J<L`3>U7<0cYAc0<JDN`3FYH`70<JLQ0040:f4J`1cBST0LdXi058i<@80HdY200H0FS4Y06<i:@3F
YH`0eZF<0<iSBP3>Le820?oooa`0moOg803oool001h0oooo00D0f=OF0>OXi`3Wj>L0i>KU0>3RhP03
0>3Rh@P0gn7Q0P3Ri><01P3UinL0dm;A09^>R`2KSX/0GD@n048V7P80@2DL00H0?ahE044I4@1?9ad0
CbLM05Tf;01:<Rd203<S9@0502PM7P0Y7QT0;ahG02lN5`16;bH00P1mHE@01P2kW8P0f[^S0=foY`3M
_jL0g;nZ0=bmZ`80ek:R00H0d:>D0<ZLRP37W8L0aib70<RQS03<Z9D20<j^W@050=2cXP3?/j80cJnN
0<f_WP38YYH00P31VX/01P2hSWd0/HAa0:j1K02^PF`0[hA]0;65KP80]8A]00H0]hI]0;b<L@33UW`0
`iIl0<bQRP3CZiD20=JcW@050=VkY`3Ma;<0glVj0=o9^P3ObKT00P3M`K001P3I]:<0djZI0<^TT03;
Y900`i^30;^>L`80]XMY00H0/hMU0;>7I02eQV@0]HIT0;R9JP2lSg@20;jAN@060;F9L`2GLF00K5=8
06aCB01E@3P0Fd0e0P1XB3X01@1/C3l0IdXo06M:?`1QAc`0J4/n0080OUY700H0UVYC0:EeG02_P6@0
[h1T0;J:KP2iSg<20;Z=L`060;R;LP2fS7D0^95i0;RAN@2iTWP0ZH=Z0P23H4l01@1N@CD0CC@Y04dd
:@1;<RD0DS8T0080J3PW00H0ST/g0;EbH03@Zj40d:^Q0=gHeP3Qi^H20>3Sh`@0h>7Q0P3PhN070>3P
h0L0h>3O00@0i>CS0>OWiP3WinH0f=SH:P3oool00`3gknl0moOg0?Ogm`0A0?Ogm`80knOW00H0FS4Q
05Xa:@1S>BT0HcTY048Y8@1B8AP2048H400405Y2>@1:<C40>BTQ03TY8@80<B4Q0`12:B4208acH`03
0>o6[@3gc[D0mmJm0080mmJm00D0klje0?OFaP3ge/H0klje0<jDN`020=j]U0040=JLS03_aZd0kmK>
0>oFcP80mmk>0P3_e/h0103ge/H0klje0>o>]@3_aZd30=j]U0040=jeW03NYH`0eYac0=JLL`80eXac
0P3N[I@20>NmY@80klje00D0mmK60?ONcP3gg/h0mmk>0?OFaP020>o>]@060>nmY@3W]I`0gZfD0=j]
U03FYH`0aYb40`3>S6/01@3>U7<0cYAk0<jDN`3>U7<0_HAS00<0eZF<00D0YG=J09acH`2LLf<0Q592
06=:@P0208AB>@05058i<@2<He80S6=B0:f4J`2]LeX00P2]Q6/01P2eS7<0aXac0<jDL`3>U7<0aYAk
0=JUS0L0aYb400@0[HA[07=:>@1cBST0DSTa0P1SBT801P1J<BT0HcTY0=JUS03FYH`0cV=:0<icDP80
oooo703gmoLP0?ooo`007P3oool0103HfMP0inSW0>OXi`3Ti^D40>3Rh@P0gn7Q0P3Ri><01P3UinL0
d]3?09N9QP2GRHH0FChg044T6P80@bTM00H0@RDK03lO5P128a/0@R<K048Z8P0d920202@I6P0502@I
600_7QT0=R0I03HP6@1;<2L00P1oH5<01P2kVXH0fkVQ0=nnYP3O_ZH0g;fV0=ZlY`80fKVW00H0ek>S
0=6[VP39XXh0bJ:>0<6IP`2kTG`20;ZAO@050;bFPP2jV8@0]9B00;BDP02/RgT00P2SOg001P2ILV@0
TfUH095VE02AIU@0TfUD09Q]E`80WVmH00H0XVmH0:MdG02cPf/0/h=[0<>JP`3?[9D20=FfX0050=Zm
Z@3M`[80glJf0=o6]P3OaK<00P3M_JX01P3I/il0djZG0<^UT03;YI00`Y^50;Z>MP80]XAY00H0]85S
0;>2H@2bQV<0/XIS0;J<JP2lTW<20<6EN@060;jBN@2aR7<0Wg]Y09mkJ@2BLF00Sf]I0P2=Ie@01@29
H4h0PeY908=JB@20FDL0R5m=0080VFeH00H0ZWYQ0;B2I@2gR6T0]hQY0;J<L02fSgD20;V@M@060;b@
M@2lTGP0_9=k0;bCN`2gTGT0XGiX0P1hFTT01@1C>Rd0@b`S04</8`15;280D30T0080J3LV00H0RdDa
0:mYE`3<YI/0c:FK0=gGe@3Ri^L20>3Sh`80h>7Q0`3PhN080>3Ph0L0h>3O00@0i>CS0>OWiP3WinH0
f=SH:P3ooolD0?Ogm`80[IBU00@0FS4Y058i<@1S@S40Hd8a0P1J<BT2058a:@80DSTa0P0Y61P01@0a
8AP0DS4Y034Q600a8AP0FS4Y0080Q6=B00H0klJ]0?O>]@3gc[D0mlje0?OF_@3_c[D20?OF_@060?OF
aP3__Jd0g[FL0=jeW02]Q7/0_HA[0`36U7/30;F<L`0509a[DP2LLf<0W7=S08ASDP2<FTX00`2DHdX0
0`2<FT80YF]B0:E[DP020:e[DP80cYAk00@0g[FL0>NmY@3_c[D0klje0P3ge/H30?OF_@80klJ]00H0
kkfU0>NeW03N]I`0g[FL0=JUS03>U7/20<jDL`80cXa[0P36W7<01P3>U7/0eZF40<jDL`3>U7<0eZF<
0=JUQ080eZF<0P36U7/20:f4J`050:ecFP2]Q6/0[HA[0:ecFP36W7<00`3>U7/01@3FW7<0eYb40=JL
Q036W8@0eYb40080eZF40P3FYH`20=JUQ0050<JLQ024He80Hd8a06=2<@1J@ST00P1B<BT01P128AP0
Ld8a0;f4J`2mQ6/0_EY20<icDQh0moOg803oool001h0oooo00@0f=WI0>OXj03Wj>P0i>GT0`3Ph^40
103Oh^40gn7Q0=oQh@3OhN450=oQh080h^CS00H0i>OW0=;@c`2JS8P0VXb805e3>`129AX2040W6P06
03lW7@0l9Ad0>RDN03XU7P0f9Al0;1lK0P0S61D01@0V6QH0<1lJ03PS7@0h8ad0CC@[0080P65D00H0
^IN30=ZeWP3P_:@0h;bT0=jlY@3K_JH20=boZ`060=fo[`3I^ZT0d:jK0=2^V`34WhT0^Y1i0P2eR780
1@2bQW40Zh=_0:5nK02QOV`0VWQX0080UW5R00H0TFQI08YOC`28GDX0R5e:08YPBP2>HT`209=SC006
09UUCP2QK5D0/81Y0;20J@32Vh@0cjnI0P3G^ZD01@3K_jd0g/:b0=o1/P3O`K80gkj^0080gKRU00H0
fK6M0=>/UP3;YHl0bjF?0<:JQP2jRgL20;9lJ0060:]bFP2VL5@0YGIF0:EfEP2ZPEl0]Ha[0P2nU7D0
1P31Ug/0`IIm0;nEO02oUG`0_95i0;J;M080[h9[00D0YWQQ09i`F@2NL5T0W6mH0:9dGP020:eoI`06
0;N8K@2jRfd0^Ha^0;V<KP2gS7<0]Xeg0P2hT7L01P2kTWL0_YAi0;fDNP2mU7X0]8ef09QgHP80Je92
00D0AC8V03HU700f9A`0@2XR05Ti;00207M4<P06091;=P2[J5D0bZBK0<ZTV`3Of]P0i>SY0P3Qhn<4
0=oQh0T0h>3P1`3Ph=l0103Ti><0inOV0>OWiP3Hf=PZ0?oooa@0moOg0P2eYJD00`1B<BT0@RTQ048Y
8@02048Y8@0503TY8@12:B40@RTQ058a:@12:B400P0i:B400`0a8AP0<B4Q058a:@02058a:@80S6=B
00D0klJ]0>o>]@3ge[d0mmJm0>o>]@040?OF_@050?OFaP3_c[D0klje0>nm[@3FW8`00P2DLf/00`2D
Ng<0[Hb40:ekJ`020:ekJ`80W6]B00H0S6=B0:EcFP2DFU80U5YB09AJBP2DDST209AJBP060;EkH`2m
Q6/0eYb40=JLQ03W]I`0mkfe0P3_c[D20?OFaP<0klje0P3_aZd20>nmY@80g[FL00@0gZfD0<j<Q036
S7<0aXac102mQ6<01P36S7<0cYAk0=j]U03N[I@0gZF<0=JUQ080cYAk00D0cYAc0<JLL`36W7<0aYac
0;f4J`020<jDL`060<jDN`3FW8@0eYac0=JLL`36W8@0eYb<0P36W8@00`3FW8@0aYb40<JLQ0050<JL
Q0050;F<L`1cBT80BS4a04Xa<@12<CT00P1B@ST01P128AP0U6=:0;f4J`2mQ6/0[EY20<I[DQ<0moOg
0P3gknl90?Ogmb00oooo000N0?ooo`040=SIf03Wj>L0inSW0>CUi0<0h>7P2@3OhN020>;Th`060>CW
i`3CdM00WI2909f@R@1QAS`0@2<G0P0g7Q<01P0c81L0<28J030R6`0`8Q/0;b4J02/N60<09a/E00@0
:alI03DV7`0e9Ql0CSXb0P1oI5H01P2eTgl0eK2H0=jjXP3N^Z80gkfU0=joZ080g/6]00H0gl>b0=g0
/@3I^ZX0fKZZ0=6bWP3:YY420<:IQ0050;V<NP2/Pg<0Wge`09mmL02NO7000P2UO6l01P2UN6P0X75O
09a`F`2LL5/0W79L09eaF`80WVmH00H0Y79K0;1mI`2nTGX0_Y5j0<^WT03D]j820=Zn[0050=g2/@3N
`[<0gkf`0=nm/03O]jX00P3M/Z<01P3I/Id0djjG0<^WT03;Yi00`i^80;^:N`80[WMX00H0WfIB09AL
A02AGT@0TEi409U[CP2WOUh20;>=K0060;ZCM02oUGT0`YMk0<:GN`34Ug`0a9El0P30T7P01@2jRg40
/hI[0;>6J`2^Pf/0/8E]0080]h]a00H0^hmc0;V?L`2fS7@0]Xad0;N;M`2hS7T20;J=N0060;N@M`2l
TgP0^i5f0;^AMP2/QVd0RfaH0P1KAcT01@0d:1l0:AlH02TO600n;B@0JTTk0080SeY600H0VeM00:IW
E031WiD0`InE0=[Ed`3QiND20=oRhP030=oPh03PhN00gn3P00D0gn3P103Ph>080>3Pg`040>CSh`3W
inH0inOV0=SHf2X0oooo503gmoL20<J]_@0306<i:@1:8AP0@R4H0080@R4H00D0>BTQ04XQ601:8AP0
@RTQ024@4002048Y8@05034Q600i:B40DSTa058i<@1SBT800P1kHe80103N]I`0klJ]0?O>]@3gc[D4
0?OF_@@0mmK600@0mmJm0>o>]@3FYH`0eZF<0P3FW8`20:f<Q0050<j<Q03FW8`0eYb<0<JDQ036S7<0
0P2]Q7/01P36U7/0_HA[0;f4J`2mQ6/0cYAk0=jUS080kkf]00<0klje0?OF_@3ge/H00`3ge/H20?O>
]@050?Nm]@3__JD0kkfU0>o6[@3W_JD00P3N]I`01P3N[I@0cXb40;f4J`2mQ6/0W5Y208aJ@P80W5Y2
00H0]G=J0<JLL`3>U7/0cYAk0=JUQ03NYH`20=JUQ080gZF<1@3FYH@20<JLQ080eZF400D0eYb<0<JL
Q03FYH`0eZF<0=JLS0030<JLQ0060=JLS03FYH@0aYb40<JLQ02]Q6/0Hd8a0P0i:B401@1:<C40>BTQ
03TY8@0a8AP0aXac0080_HAS00<0[EY20<icDP3gmoL03P3gmoL00`3gknl0moOg0?Ogm`0<0?Ogmb00
oooo000N0?ooo`040=SIf03Wj>L0inSW0>CUi0<0h>7P2@3OhN020>;Th`060>CWi`3CdM00WI2909f@
R@1QAS`0@2<G0P0g7Q<01P0c81L0<28J030R6`0`8Q/0;b4J02/N60<09a/E00@0:alI03DV7`0e9Ql0
CSXb0P1oI5H01P2eTgl0eK2H0=jjXP3N^Z80gkfU0=joZ080g/6]00H0gl>b0=g0/@3I^ZX0fKZZ0=6b
WP3:YY420<:IQ0050;V<NP2/Pg<0Wge`09mmL02NO7000P2UO6l01P2UN6P0X75O09a`F`2LL5/0W79L
09eaF`80WVmH00H0Y79K0;1mI`2nTGX0_Y5j0<^WT03D]j820=Zn[0050=g2/@3N`[<0gkf`0=nm/03O
]jX00P3M/Z<01P3I/Id0djjG0<^WT03;Yi00`i^80;^:N`80[WMX00H0WfIB09ALA02AGT@0TEi409U[
CP2WOUh20;>=K0060;ZCM02oUGT0`YMk0<:GN`34Ug`0a9El0P30T7P01@2jRg40/hI[0;>6J`2^Pf/0
/8E]0080]h]a00H0^hmc0;V?L`2fS7@0]Xad0;N;M`2hS7T20;J=N0060;N@M`2lTgP0^i5f0;^AMP2/
QVd0RfaH0P1KAcT01@0d:1l0:AlH02TO600n;B@0JTTk0080SeY600H0VeM00:IWE031WiD0`InE0=[E
d`3QiND20=oRhP030=oPh03PhN00gn3P00D0gn3P103Ph>080>3Pg`040>CSh`3WinH0inOV0=SHf2X0
oooo503gmoL20<J]_@0306<i:@1:8AP0@R4H0080@R4H00D0>BTQ04XQ601:8AP0@RTQ024@4002048Y
8@05034Q600i:B40DSTa058i<@1SBT800P1kHe80103N]I`0klJ]0?O>]@3gc[D40?OF_@@0mmK600@0
mmJm0>o>]@3FYH`0eZF<0P3FW8`20:f<Q0050<j<Q03FW8`0eYb<0<JDQ036S7<00P2]Q7/01P36U7/0
_HA[0;f4J`2mQ6/0cYAk0=jUS080kkf]00<0klje0?OF_@3ge/H00`3ge/H20?O>]@050?Nm]@3__JD0
kkfU0>o6[@3W_JD00P3N]I`01P3N[I@0cXb40;f4J`2mQ6/0W5Y208aJ@P80W5Y200H0]G=J0<JLL`3>
U7/0cYAk0=JUQ03NYH`20=JUQ080gZF<1@3FYH@20<JLQ080eZF400D0eYb<0<JLQ03FYH`0eZF<0=JL
S0030<JLQ0060=JLS03FYH@0aYb40<JLQ02]Q6/0Hd8a0P0i:B401@1:<C40>BTQ03TY8@0a8AP0aXac
0080_HAS00<0[EY20<icDP3gmoL03P3gmoL00`3gknl0moOg0?Ogm`0<0?Ogmb00oooo000N0?ooo`05
0=SIf03Wj>P0inSX0>CUi03Ph=l00P3Pgml00`3Oh=l0gn7P0=oQh0060=oQh080hN?S00H0i>OW0=CB
d02QTh`0XI><06I;?P118QD2038H3P0602/I4@0Y7AH0:AlH02TO600Y7QL09a/E0P0U6A<01@0T6A<0
9adG03<X8@0c:240CShe0080O6=F00H0[Hah0<fXT@3J]Yh0f[JN0=jmY@3O`:X20=o2[P060=o2/P3O
`k@0g/>d0=k3]03L`[40fKfY0P3B/Ih01@38XY40^iN:0;6BR02aTXP0/iB90080_IN:00H0`IN60;fC
P02jTWh0^Y9n0;VCOP2gTG`20;J>N@060;^@N`35VX@0cZN@0<jWT03D/id0fKfY0P3L`[801@3N`k@0
gL6b0=fk[@3M^jd0g;BW0080fk6R00H0f;:N0=>`V@3=ZI<0cJVC0<NOS030TH820;=oL@060:5/FP2@
FdL0Qe8n08MB?P27Ed40SVI<0P2FLeH01P2LNEd0Y7iS0;26J`2`QV/0_8ic0<BDN`80aYMn00D0a9Mk
0;jDM`2nU7L0^I5f0;R@M`020;VAM`060;ZAMP2fSWD0]8Ye0;B:M@2dR7D0]8Qf0P2dRWL01P2gSWP0
^i1g0;J;L02fRg00X7UQ07YLB@80C3X^00D0:b8K02DO6@0U7aT0@C<Y07ID@`0209eVC`060:5MA@2M
Gd`0ZHIk0:V6N`2n]K80d=7A0P3Lg]h00`3Ph^80h>7Q0=oPh0070=oPh080h>3P203Ph=l0103Thn<0
inOV0>OWiP3Hf=PZ0?ooo`<0moOg00<0mno_0?Ogm`3gmoL00P3gmoL00`3gknl0moOg0?Ogm`090?Og
m`80e/kN00H0HcTa034Q6012:B40@RTQ03TY8@12:B42058a:@03048Y8@0Y61P0@RTQ0080@RTQ00@0
<B4Q03TY8@0i:B40HdY20P2<He800`3FYH`0klJ]0>o>]@020>o>]@<0mmJm103ge/H00`3gg/h0mmK6
0>o>]@030>o>]@D0mmK600H0e/Jm0?Nm]@3Fa[d0e/Jm0?Nm]@3Fa/H20?Nm]@030?OFaP3_c[D0klje
0080klje103ge/H30>o>]@050?O>]@3__Jd0kkf]0>o6[@3__Jd00P3W_JD01P3W[I`0eZF<0<jDN`3>
U7/0W6]B08AB@P<0Q4Xi00@0YG=J0;f4J`2mQ6/0cYAc0`3FYH`00`3N[I@0gZF<0=JUS0020=JUS080
eZF400<0eZF<0=JLQ03FYH`00P3FYH`01@36W8@0eZF<0=JUS036W8@0eZF40080aYb400H0eZF<0<JL
Q03FYH@0eZF408aSDP1B<BT203TY8@05048Y<@0a8B40<B4Q058i<@3>U7<00P3>LeX0102]FT80aV]B
09B4Q02DQ8@L0?Ogmb00oooo000N0?ooo`050=SIf03WjNP0inWX0>CTi03Pg]h00P3PgM`00`3Og]d0
gn3O0=oQh0060=oQh080hN?S00H0i>KV0=CBd@2TUXl0Y9J?06]@@`159AT203@H3P0602dH400Z71D0
:AlG02TO5`0V7AH081LB0P0K4Ph01@0N50l09a`F03DY8P0e:B80CShf0080MemB00H0YHAa0<FPR@3F
/IT0e[6I0=fkX`3O`:T20=o2[P060=o2/P3Oa;H0glNh0=o7^03Ob;T0g/Nf0P3K`K401@3F^Z/0d;BW
0<^bYP3;/ZH0cK>W0080d[FW00H0e;FV0=>dY03B]:<0d[BS0=6dX`3?/j820<naX0060=6aW`3E]9h0
f;NP0=RgX03H^Z<0f[n[0`3Ma;@0103K`:h0fK^X0=VkZ03I]j@20=VeXP060=NcWP3D/9X0cj^E0<n[
U@3<YY80b9n=0P31UH<01P2cQG80XG1N08aKC02<Fd`0OU1207QA?`80M5@o00H0LeE007iLA`2DJeD0
U6]E0:]mI@2iRg<20;nCNP050<2EN@2mU7L0_IAg0;^CMP2hTGH00P2eSgD01P2cS7@0/hQa0;65K`2a
QFl0[89]0:b3L080/hMf00H0_8ej0;j>N02`PV/0/89[08mXD`1VB3P2048^900502`R6`0/9Al0;2DO
04Lh;P1dDD000P2GGDL01P2KESh0Se0l08ENDP25GU80TH9m0;Jc/P80f=WI00<0hnCT0>7RhP3Oh>00
1`3Oh>020=oPg`P0h>3O00@0i>?S0>OWiP3WinH0f=SH:P3oool40?Ogm`<0mno_3@3gmoL20>ONk`06
07=:>@12:B40BR4H04XQ600i:B40@RTQ0`0i:B400`0a8AP08A0@024@4002048Y8@80DS4Y00D0HdY2
07]SDP1kHe80aYb40>NmY@020>o6[@050?O>]@3ge[d0mmJm0?OF_@3ge/H02`3gg/h00`3gimh0mmk>
0?ONcP080?ONcP060?OFaP3ge[d0mmJm0?OF_@3_c[D0mmK60P3gg/h00`3ge[d0klje0>o>]@020>o>
]@@0klJ]0P3W_JD01P3_]JD0ikfU0>nm[@3__Jd0eZF<0;f4J`80U5YB00H0S5Y:07=:>@1S>BT0HcTY
06=2<@24DT820;EkH`040=JUQ03FYH`0eZF<0=JUS0@0eZF40`36W8@20<jDN`80aXac00H0]Hac0<jD
N`3FW8`0eYb<0=JUS03FW8@20;F<L`0507=:>@0i:B40@RTQ048Y8@0a8B400P1B@ST01P1J<BT0[F]B
0;f4J`2mQ6/0YE8i0;EkH`80Je9:00<0g/kF0?Ogm`3gmoL06@3gmoLP0?ooo`007P3oool01@3HfMP0
inWX0>OYj03Ti><0h=kM0080gmcL00<0gmkM0=oPg`3OhN001P3OhN020>7Sh`060>CViP3Ddm40Y9RA
0:BHT@1[DdP0Ab/O0P0g7A@01P0a71@0;QdF02/O5`0[7aL09QdF01dF4@805Pl<00D06a8=02PL5@0g
:B80=bTR04hm=00207EKCP060:1nJ`31Vh@0djjF0=>^UP3K^Z80g/2Y0P3O`Zh01P3O`[80glFf0=o8
^@3Ob;T0glVk0=o:^`80g/Zl00<0g/Zm0=g:_@3Mb[d0103Mb[d01P3NbK/0g/Rj0=k8^P3Nb;X0gLVk
0=g9_080gLRj00H0g/Jf0=k4/03L`:/0g<2[0=ZnZ03K`:/20=g4/@050=g4/P3K`:/0f;^U0=RkY@3G
^J800P3G]Yl01P3F/Y`0eJnI0=:]U`3B[IL0dJfG0=2/UP80cZNB00H0aif90;N;NP2PLfL0X7=W08eQ
EP1nEdX2075?@00606I8>@1YBSX0NeE307]E@`2=I500VG5L0P2QNV@01@2VOVL0ZH5X0:V1J02YPfT0
Yh=Z0080Y85Y00H0Y7eV0:IjI02WNV@0YgYT0:QmJ02/PVh20;N8MP060<2=NP30RgL0ZWYV0:YjIP1o
FDL0E3P[0P0i9Qd01@0_8Q/0<bPS03<X8`16=Bd0I44d0080OTLd00H0QT@_07`n:`1[@C@0Jd4d07=Q
FP2TX9d20=GFe@030>CViP3Qh^80gn3P00L0gn3P0`3Oh=l70>3Pg`040>CSh`3WinH0inOV0=SHf2X0
oooo5P3gmoL01P1S>C40Hd8a058a:@1B<BT0@RTQ03TY8@@0@RTQ0P0Q41001@12:B40>BTQ058a:@1B
<BT0LdXi0080Q6=B00D0aYb40=j]U03__JD0kkfU0?O>]@030?OF_@80mmK60P3gg/h00`3ge/H0mmk>
0?OWgP020?OWgP040?ONcP3gimh0mnON0?OWgP80mmk>1@3gimh50?ONcP80mmK600D0mmk>0?OFaP3g
e/H0mmK60>o>]@030?Nm]@050>o>]@3_aZd0klJ]0>nmY@3_aZd00P3__JD0103W_JD0kkf]0>NmY@3W
_JD20=jeY@80eZF<00H0_HA[09AJDP2<FTX0S5Y:07=2<@1S>BT206=2<@0507=2<@2<FTX0]Hac0;F<
L`36W7<00P36S7<01@3>U7/0aYAk0;F<L`2eS7<0]G]S00<0W6]B00H0_HA[0=JUS03FW8@0eYb40=JL
S03FW8@20:f4J`0305Xa:@12:B40@RTQ0080@RTQ0P12:C401P128AP0Q4Xi0:e[DP2]Je80_HAS0:Ec
FP80LeYB00<0W8b<0?Ogm`3gmoL06@3gmoLP0?ooo`007P3oool01@3HfMP0inWX0>OYj03Ti><0h=kM
0080gmcL00<0gmkM0=oPg`3OhN001P3OhN020>7Sh`060>CViP3Ddm40Y9RA0:BHT@1[DdP0Ab/O0P0g
7A@01P0a71@0;QdF02/O5`0[7aL09QdF01dF4@805Pl<00D06a8=02PL5@0g:B80=bTR04hm=00207EK
CP060:1nJ`31Vh@0djjF0=>^UP3K^Z80g/2Y0P3O`Zh01P3O`[80glFf0=o8^@3Ob;T0glVk0=o:^`80
g/Zl00<0g/Zm0=g:_@3Mb[d0103Mb[d01P3NbK/0g/Rj0=k8^P3Nb;X0gLVk0=g9_080gLRj00H0g/Jf
0=k4/03L`:/0g<2[0=ZnZ03K`:/20=g4/@050=g4/P3K`:/0f;^U0=RkY@3G^J800P3G]Yl01P3F/Y`0
eJnI0=:]U`3B[IL0dJfG0=2/UP80cZNB00H0aif90;N;NP2PLfL0X7=W08eQEP1nEdX2075?@00606I8
>@1YBSX0NeE307]E@`2=I500VG5L0P2QNV@01@2VOVL0ZH5X0:V1J02YPfT0Yh=Z0080Y85Y00H0Y7eV
0:IjI02WNV@0YgYT0:QmJ02/PVh20;N8MP060<2=NP30RgL0ZWYV0:YjIP1oFDL0E3P[0P0i9Qd01@0_
8Q/0<bPS03<X8`16=Bd0I44d0080OTLd00H0QT@_07`n:`1[@C@0Jd4d07=QFP2TX9d20=GFe@030>CV
iP3Qh^80gn3P00L0gn3P0`3Oh=l70>3Pg`040>CSh`3WinH0inOV0=SHf2X0oooo5P3gmoL01P1S>C40
Hd8a058a:@1B<BT0@RTQ03TY8@@0@RTQ0P0Q41001@12:B40>BTQ058a:@1B<BT0LdXi0080Q6=B00D0
aYb40=j]U03__JD0kkfU0?O>]@030?OF_@80mmK60P3gg/h00`3ge/H0mmk>0?OWgP020?OWgP040?ON
cP3gimh0mnON0?OWgP80mmk>1@3gimh50?ONcP80mmK600D0mmk>0?OFaP3ge/H0mmK60>o>]@030?Nm
]@050>o>]@3_aZd0klJ]0>nmY@3_aZd00P3__JD0103W_JD0kkf]0>NmY@3W_JD20=jeY@80eZF<00H0
_HA[09AJDP2<FTX0S5Y:07=2<@1S>BT206=2<@0507=2<@2<FTX0]Hac0;F<L`36W7<00P36S7<01@3>
U7/0aYAk0;F<L`2eS7<0]G]S00<0W6]B00H0_HA[0=JUS03FW8@0eYb40=JLS03FW8@20:f4J`0305Xa
:@12:B40@RTQ0080@RTQ0P12:C401P128AP0Q4Xi0:e[DP2]Je80_HAS0:EcFP80LeYB00<0W8b<0?Og
m`3gmoL06@3gmoLP0?ooo`007P3oool01@3HfMP0inSW0>OXi`3Ti><0h=oO00<0gmoN00<0gn3O0=oQ
h03OhN001@3OhN020>7Sh`060>CViP3Ddm40XIRC0:6HT`1WEDd0AS0W0P0k9Qd01P0d8QX0;alH02`N
5`0/7QL0:AdF024H4P806a@>00D07aD?02XM5P0h:B80>2TR04hl=00207AIC00609mjI`2oUh00dZbD
0=:/U03K^J40g[nY0P3O`Zh01P3O`[80glFf0=o8^@3Ob;T0glVj0=o:_080glbo00D0h<o40>3Aa`3Q
d/L0hM;70>7Bb0020>3Aa`040>3?``3PcL00h<k10>3>`@80h=350P3Pc/401P3Pbk`0glVh0=k5/P3N
aK80gL:]0=g1Z`80gL>]00D0g/>^0=c1ZP3J_JH0f[fV0=RhX@020=JcW0040=J_V@3F[YP0eJnI0=F_
V@80eK6J0P3E[iT01P3BZIH0b9j?0;VAQ02iTH@0[8=g0:5fJP80TFUL00H0OUa>079B@`1_CCd0Kddm
071=?01aDD0207QGA@0508=OC02;IU80RfIB08][E`2;KUT00P2>KEL01P2BJe@0U6YC09]_F@2KKeT0
Z7]X0;B6M080_8Yh00H0`8ah0;f9L`2SMF40XgEQ07=?@@17;R@203<P6@0502lQ6`0c9R80<bHR03d[
9P1;;2@00P1K;1l01P1X;Ad0JC0P064i;@1Q>Bd0KeeF0:>MVP80e=GD00<0i>KV0>7ShP3Oh>001P3O
h>060=oPg`D0h>3O00@0i>?S0>OWiP3WinH0f=SH:P3ooolF0?Ogm`0406=:@P1cBT80DSTa058i<@80
@RTQ0P0i:B42048Y8@80<B4H00D0:APH048Y8@1S@S40Hd8a06=:@P0208ASDP050<JDN`3FYH`0klJ]
0>o6[@3gc[D00`3ge[d20?OFaPH0mmk>103gimh0103gg/h0mnON0?OWgP3gimh30?ONcP80mnON0P3g
g/h01P3gimh0mmk>0?OFaP3ge/H0mmJm0?OFaP80mmJm00@0klje0?OF_@3ge[d0mmJm0`3_aZd01P3_
_JD0klJ]0>o6[@3_aZd0kkf]0>o6[@<0kkf]00D0ikfU0=jeY@3N]JD0gZfD0=JLS0020:f4J`0409ac
H`2<FTX0LdXi07=:>@80Hd8a0P24DT801@2<FTX0W6]B09a[DP24JeX0S5Y:0080W6]B00H0YG=J09a[
DP2eQ6/0]HA[0=JLS03FYH`20=JLQ0060<JLQ03>U7/0YG=J0:EcFP1B<BT0<B4H0P12:B401@12:C40
BS4a04Xa<@128AP0DR4H0080S34Y00D0Nc4Q06<i:@1cFU80LeYB0;FUY@0K0?Ogmb00oooo000N0?oo
o`050=SIf03Wj>L0inSW0>CTh`3Ph>000P3Oh=l90=oPh080hN?R00H0i>KV0=?CdP2PV9D0X9RE06MH
D@1;>30204<`:00603TY8P0_8AX0:ahF02/N5P0[7AH09a/D0P0S6A801@0U6Q@0;AlJ03PZ9@0h:RD0
CS`d0080LUM:00H0VgMR0;ZCN`3>Z900cZR@0=RgW`3M_jP20=o2[@060=o2/03Oa;<0glJg0=o6]`3O
b;T0glVk0P3Obkh0103Oc/<0gm370=oBb@3Od/T30=oBbP060=o@aP3Oc/80glk30=o>``3Od<L0glo5
0P3Oc<001P3Ob[`0glVj0=k7]`3NakL0g/Fb0=k3[P80g/:/00D0g/:[0=k1ZP3L_JH0g;fV0=RgX002
0=JaVP060=J^U`3F[IL0eZnH0=J_V03F/IX0e[:K0P3G/9`01P3F[I`0dZVJ0<^TU@3;Y9D0aIj>0;nD
Q080/XMg00H0WgQX08aYF01lFdX0O5]:06mA@01XC3/206Y<>`0507A@?`1jETD0NUI507YKBP1nH4d0
0P27I4l01P2?ITl0TVQA09Y_F`2JKe/0Zga[0;V6M`80_H]i00H0_8af0;J7L02KLEd0Vg5M06]:?@11
:R82030N600502dO6@0_8Qh0;b8N034Q7P0c7AL00P0l6Q401P1<7a<0EbPL05`i;`1L>Bl0Lf9K0:NR
W`80e]KF00<0i>KV0>7RhP3Oh>001@3Oh>080=oPg`@0h>3O00@0i>?S0>OWiP3WinH0f=SH:P3ooolF
0?Ogm`80LdXi0P1S@S40101B<BT0@RTQ058a:@1B<BT2048Y8@80>BTQ00D08A0@058a:@1B<BT0DS4Y
06=:@P0207]SDP060;F<L`3FYH@0ikFL0>NeW03gc[D0mmJm0P3ge/H01P3ge[d0mmk>0?OFaP3ge/H0
mmk>0?OFaP@0mmk>2P3gimh50?ONcP@0mmK61P3_c[D01@3_aZd0mlJ]0?O6[@3_aZd0kkf]0080klJ]
00H0kkf]0>o6[@3_aZd0klJ]0>NmY@3W]I`20>NmY@80g[FL0P3FYH`01@36W8@0_HA[09acH`2LLf<0
U5YB00<0LdXi0`24DST208AB@P80U5YB00D0[G=J0;f4J`36W8@0aYb40=JLS0030<JLQ0040<jDN`36
S7<0S5Y:08aJBP80@RTQ0P0i:B401@12:B40>BTQ03TY8@0a8AP0@PP00080HaP@00D0HcTY05Y2>@1k
He80Nf=B0?ooo`0K0?Ogmb00oooo000N0?ooo`050=SIf03WinH0inOV0>CTh`3Ph>002`3Oh>020>7S
hP060>CVi@3Ddm80XYVF0::IUP1]Fe@0EChf0P1>>C401P0o;bP0;b<K02TM5P0Y7AH0:adF02/M5@80
:QdE00D0;1hI034S7`0k;2P0>b`X04dl=@0206eDAP06099`G02aRg@0aZ6:0<JQRP3D/Y/0g;fV0P3O
`Z/01P3O`Zd0gl:`0=o3/`3O`k<0glJg0=k8^P80g/Zl00@0g/bo0=k>``3Nd<P0g]380`3Nd/X01P3N
dLP0g]360=k@a`3Nd<L0g]380=k?a@80g/^o00H0g/Vk0=k9^P3Nb;T0g/Ri0=k7]`3NaK820=k3[@05
0=o2Z`3N`JX0g;fV0=bmYP3I]Z000P3F/I/01P3F[iT0eZjH0=J^U`3F[YL0ejnH0=NaVP80ek2L00H0
ejfL0=F[V`3AZYP0dJZH0<fWU039XHd20<6HQ0060;F=N@2XPFd0VWIS09YfH`2>KEX0QFIB0P21H4`0
1@21G4T0PU]8089KB022GDX0R6=>0080U6YD00H0WW5K0:5gH@2VNfP0YW]X0;1oL@2hPgH20;R8M`06
0;F:M02/Q6`0TVeI099]F@1VB3/0@2TQ0P0`7QL01@0]7QP0:alJ02/O6P0X7AP09QTC0080:QL?00H0
>1`C04LV7@1D>C40E3Ta079RF`2WXIh20=GEe0030>CUi@3Qh^80gn3P00D0gn3P2@3Oh=l30>3Pg`04
0>CSh`3WinH0inOV0=SHf2X0oooo503gmoL20=kFi`0607=BBP1cBST0Le9:07=BBP1B>C40>BTQ0P1B
<BT4048Y8@80BS4a0P1J@ST01@1SBT80Q6=B08ASDP2]Q6/0_Ib<0080g[FL00<0kkfU0?OF_@3ge[d0
0P3ge[d40?OFaP@0mmk>0`3gimh00`3gg/h0mnON0?OWgP060?OWgP80mmk>00D0mnON0?ONcP3ge/H0
mmK60?ONcP050?OF_@80mlJ]103_aZd30>nmY@@0klJ]00D0kkf]0>neY@3W_JD0ikfU0>N]W0030=je
W080eZF<0P36W8@01@3>U7/0]Hac0;EkH`2eNf<0YG=J0080W6]B00@0YG=J0:ecFP36S7<0aXac0P36
W8@20=JLQ0060<j<Q036W8@0aYb40<JLQ03>U7/0]Hac0P1S@S401@1B<BT0@RTQ048Y8@12:B40DS4Y
00<0>BTQ00<0<B4H058a:@1B<BT00P1B<BT207=JDP0309b<S03gmoL0moOg01T0moOg803oool001h0
oooo00D0f=WH0>OWiP3WinH0i>CS0>3Ph00;0=oPh080hN?R00H0i>KU0=CCdP2RVIH0XYVF06eKE01E
?SH204hi<@0603l_:00_8a/0:AdF02TM5P0[7AH0:adE0P0Z7AD01@0/7QT0<B<O03//:00k;2P0CC`e
0080KEA600H0TW1L0;6;M036XHX0aZ6:0=BbV`3L_JH20=o2Z`060=o2[@3O`[00gl>c0=o3/`3Oa[L0
g/Rj0P3Nb[`0103Nc;l0g/k30=k@b03Nd<P30=kBbP060=kAb03Nd<H0g]370=k@a`3Nd<P0g/o50P3N
bkl01P3NbK/0g/Vj0=k8^@3Nb;T0g/Ng0=k5/P80g/>]00D0gl:[0=k1ZP3L_JH0g;fV0=VfX0020=Ja
V`060=J_V@3F[YP0eZjG0=J^U`3G[iP0ek6J0P3G/9`01P3G[I`0eJ^K0=6ZV03AZYP0cJND0<VQS@80
`IR400H0]Hei0:R1K@2JMV<0VWIS08i]FP25IU82085PC005085LB@22FdP0PU]8089MBP28Hdh00P2D
JU@01P2NLE/0XGMQ0:IkJ02VNfP0/7ma0;R3MP80^8Qg00H0]HYd0:b4K02BKET0TVeI06I8>`10:B42
030N5`0502dN600[7aX0:alJ02PM600V6A<00P0Z5`l01P0h71<0AbHM05@i<@1D>C40LV9K0:NQWP80
eMGD00<0i>GU0>7RhP3Oh>001@3Oh>090=oPg`<0h>3O00@0i>?S0>OWiP3WinH0f=SH:P3ooolD0?Og
m`80g]KW00H0Le9:07=:>@1cDTX0Le9:058i<@0i:B42058a:@@0@RTQ0P1:<C4205Y2>@0506=:@P24
He80Q6=B0:f4J`2mW8`00P3N]I`00`3__JD0mmJm0?OF_@020?OF_@@0mmK6103gg/h30?OWgP030?ON
cP3gimh0mnON00H0mnON0P3gg/h01@3gimh0mmk>0?OFaP3ge/H0mmk>00D0mmJm0P3gaZd40>o6[@<0
kkfU103_aZd01@3__Jd0kkFU0>NmY@3W_JD0ijfL00<0g[FL0P3FYH`20<JLQ0050<jDN`2eS7<0]G]S
0;EkH`2ULeX00P2LJe80102ULeX0[G=J0<J<L`36S7<20<JLQ080eYb400H0cXb40<JLQ036W8@0aYb4
0<jDN`2eS7<206=2<@05058a:@12:B40@RTQ048Y8@1B<BT00`0i:B400`0a8AP0DS4Y058a:@02058a
:@80LeYB00<0W8b<0?Ogm`3gmoL06@3gmoLP0?ooo`007P3oool01@3HfMP0inOV0>OWiP3Ti><0h>3O
00@0gn3O1`3Oh>020>7ShP060>CVi@3Ddm40YIVE0:FIU@1aFe<0FSle0P1C>c401P14<RT0<RHN02/O
600[7aP0;1dF02hL5@80;adF00D0<QlJ03LU8@0o;BT0?bdY04hj<P0206I>@00608EWD`2TPF/0_YV2
0;jIPP3@[IH0f[^S0P3N`JT01P3O`Z/0gl6]0=o2/@3O`[40g/Be0=k7^@80g/Zl00D0g/^n0=k<`@3N
c/@0g/k40=k@a`040=kAb@80g];:00H0g]790=k?a@3Nbkh0g/^n0=k9^`3Nb;X20=k8^@060=k7]`3N
aK<0g/>_0=k3[`3N`J`0g[nY0P3L^j@01@3I]9d0e[6J0=JaVP3F/IX0e[2I0080eZjH00H0eZjG0=J_
V03G[YX0ejjJ0=J/VP3EZYP20=6YU@060<jVT@3:Xh`0aij70<NNQ`32V840^i9k0P2dSGH01@2]R780
Yh=]0:9lIP2RO6H0W7AN0080V6mH00H0V6iG09ibF`2XN680Z7QR0;20JP2bQG020;B7M@060;J3M@2h
PgD0]XId0;J6M02`QW00XgeU0P28IE401@1QA3H0@2TQ034N600a7QP0;AhG0080;1lH00H0:AhG02@K
500T6Q8091XB02hM5P0k9Qd204/f;@0506aJDP2PUI00cLS70<g8a`3NgMd00`3Ph>020=oPh0/0gn3O
0`3Ph=l0103Thn<0inOV0>OWiP3Hf=PZ0?oooa@0moOg0P3>]KD01P1cBST0Je9:07=:>@1cBST0Hd8a
058i<@80DS4Y1P12:B42058a:@0506=2<@1cBT80LdY209acH`36U7/00P3N[I@00`3_aZd0mlje0?OF
_@020?OF_@040?OFaP3gg/h0mmk>0?OFaP<0mmk>00<0mnON0?ONcP3gimh02P3gimh40?ONcP80mmK6
0P3ge[d40>o>]@<0klJ]0`3__JD01@3_aZd0kkf]0>nm[@3_c[D0kkfU0080klJ]00<0kkf]0>NeW03W
]I`00P3W]I`30=jeW0040=j]U03FYH`0eZF<0=JUS080eYb<0`3>U7/20<j<Q0060<j<L`36W8@0aYb4
0<JLQ03FW8@0aYb40P3FW8@01P3>S8@0eYac0<JLQ036W8@0aXac0:f4J`80FS4Y00<0DS4Y048Y8@0i
:B400P0i:B4204Xa<@0603TY8@0a8B40<B4H034Q6012:B40DS4Y0P1:<C400`1[DTX0moOg0?Ogm`0I
0?Ogmb00oooo000N0?ooo`050=SIf03WinH0inOV0>CTh`3Ph=l01P3Oh=l50=oPh080hN?R00H0hnKV
0=CBd@2UV980YIRB079IC@1H>bh2050g:P0604Hc:00i:b80<B<L034S700^7QL0;a/C0P0b6Q<01@0e
7QL0>B@N044/9011;2@0C3L[0080GDHg00H0MUY809IdH02eSgT0]Hmi0<^VS`3F]Yl20=boY`060=k1
ZP3O`Jd0gl6a0=o1/@3Na;D0g/Ni0P3Nbkh01@3NcL40g/g20=k<`@3Nc<40g/g20080g]3700H0g]79
0=kAbP3Nd/X0g];:0=kAb@3Nc/@20=k;_P060=k9^P3Nb;T0g/Ng0=k7]`3NaK<0g/>`0P3N`Zl01@3N
`:d0g[fX0=bgX03L]j00f;6J0080eZjH00H0e[2I0=JaVP3F/9T0e[2I0=J^V03F[IL20=J/UP060=JZ
UP3DZ9@0dJJ@0=6VT03>Xh`0c:290P3:WHH01P37Vh<0`iR10;jEOP2nUGh0_9=l0;^BN`80^8mh00D0
/hUb0:n4K@2_Q6d0[h=/0;64K@020;J5K`060;V8LP2kRWL0^hYi0;^:N@2kR7L0^XId0P2gQW401P2]
P6T0VG1I07]G@`1kEd<0FC`_03hW7`80<AlH00D0;ahH034P6@0a81T0<24I02TN5`0202@L5@0602PM
5P0c8QX0@bhT04<^901RCD80T7ih0P2l/:h01@3Ecll0g]kN0>3Rh@3Ph^40h>7P00h0gn3O00D0h>3O
0>CSh`3WinH0inOV0=SHe`0Z0?oooa@0moOg0P2LS8`207=:>@80Hd8a0P1B>C4204Xa<@80@RTQ0P1:
8AP0101B>C40DS4Y048Y8@12:B4306=2<@0608ASDP2]Q6/0eZF<0=JUS03__JD0klje0`3ge[d30?OF
aP@0mmk>00<0mnON0?ONcP3gg/h00P3gg/h80?OWgPH0mmk>00D0mmJm0>o>]@3ge/H0mmK60?OF_@03
0?O>]@050>nmY@3_aZd0klJ]0>o6[@3__JD00P3_aZd20>nmY@80ikfU00H0kkfU0>NmY@3W]I`0ikFL
0>NmY@3W[I@20=jeW0050=j]U03N]I`0eZF<0=JUS03N]I`00`3N[I@40=JUS0<0eYb400<0eZF40=JL
S03FW8@00`3FW8@20<jDN`030;F<L`2DHdX0DS4Y0080DS4Y00@0>BTQ048Y8@12:B40>BTQ0P1B<BT2
03TY8@<0@RTQ00D0<B4H06=2<@1S@S40Je9:0<J][@0J0?Ogmb00oooo000N0?ooo`050=SHf03WinH0
inOV0>CTh`3Ph=l02@3Oh=l20=oPh080hN?R00H0i>KV0=CBd02SUXl0XiJ?06iEB01C>2P204de9`06
04Ld:@0o;RD0=bLP03LW800b81T0;a/C0P0_61001@0b6a@0=b4J03`W7P0l9ah0ABlS0080DSX/00H0
Id`l08MTD02XP6T0Z81Y0<:KPP3B/9P20=^lY@060=k1ZP3O`Jd0gl:a0=o2/@3Na;D0g/Ni0P3Nc<02
0=k?a@80g/c100@0g/c00=k>``3Nc/<0g]360`3Nd<P01P3NclH0g/g10=k:_@3Nb[d0g/Vj0=k8^@80
g/Je00H0g/>_0=k1[@3N`Jh0g/6^0=jo[03L^ZD20=ZdW@050=R_V03F[IL0eZfG0=J^V03F/9T00P3F
[iT01P3F[YL0eZ^E0=JZU03FZY@0eZVC0=BXTP80dJB>00H0cZ290<bMQP3;Vh@0bi^40<RJP`34VX<2
0<:HP@050<6GP032Uh00`YIo0<:FO`30U7d00P2nTW/01P2mTGX0_91h0;^=MP2kSGH0^XYf0;Z:N080
^X]i00H0^X]g0;V9L`2dQ6h0]8A^0:AhH@29HTd206Q8=`0504Xa9@0f8a`0;alI02lO6@0`81/00P0b
8A`01P0`81/0:AhG02<K500S6a@08QPB02TJ4`80>BDK00H0EShc081XH@2ZV9D0ZYRE0<[1`03Lfm/2
0>7ShP030>3Qh@3Oh=l0gn3O00`0gn3O00D0h>3O0>CSh`3WinH0inOV0=SHe`0Z0?oooa00moOg0P3g
knl20?Ogm`80Q6]J00H0Hd8a06]BBP1cDTX0Le9:06=:@P1B>C4206<i<@03058a:@12:B40@RTQ00D0
@RTQ00D0DS4Y06=2<@1S@S40LdXi08aSDP020;F<L`040>NmY@3_aZd0mlje0?O>]@D0mmK61`3gg/h9
0?OWgP@0mmk>0P3ge[d01@3_c[D0mmJm0?OF_@3ge[d0klje00@0klJ]0`3__JD30>o6[@80kkfU0P3_
]JD20>NeW0<0ikfU00D0ijfL0>NeW03W]I`0g[FL0=j]U0020=jeW080gZfD0`3FYH`20=JLS0030=JL
Q03FW8`0eZF<0080eZF<00D0eYb<0<JLQ036W8@0eYb40<JLQ0020;F<L`060:EcFP1cBST0DSTa058i
<@12:B40>BTQ0P0a8B400`1B>C40:APH02TH6002034Q8@80>BTQ00H0@RTQ02TH601:<C40BS4a06=2
<@2]W8`J0?Ogmb00oooo000N0?ooo`050=SHf03WinH0inOV0>CTh`3Ph=l02@3Oh=l20=oPh080hN?R
00H0i>KV0=CBd02SUXl0XiJ?06iEB01C>2P204de9`0604Ld:@0o;RD0=bLP03LW800b81T0;a/C0P0_
61001@0b6a@0=b4J03`W7P0l9ah0ABlS0080DSX/00H0Id`l08MTD02XP6T0Z81Y0<:KPP3B/9P20=^l
Y@060=k1ZP3O`Jd0gl:a0=o2/@3Na;D0g/Ni0P3Nc<020=k?a@80g/c100@0g/c00=k>``3Nc/<0g]36
0`3Nd<P01P3NclH0g/g10=k:_@3Nb[d0g/Vj0=k8^@80g/Je00H0g/>_0=k1[@3N`Jh0g/6^0=jo[03L
^ZD20=ZdW@050=R_V03F[IL0eZfG0=J^V03F/9T00P3F[iT01P3F[YL0eZ^E0=JZU03FZY@0eZVC0=BX
TP80dJB>00H0cZ290<bMQP3;Vh@0bi^40<RJP`34VX<20<:HP@050<6GP032Uh00`YIo0<:FO`30U7d0
0P2nTW/01P2mTGX0_91h0;^=MP2kSGH0^XYf0;Z:N080^X]i00H0^X]g0;V9L`2dQ6h0]8A^0:AhH@29
HTd206Q8=`0504Xa9@0f8a`0;alI02lO6@0`81/00P0b8A`01P0`81/0:AhG02<K500S6a@08QPB02TJ
4`80>BDK00H0EShc081XH@2ZV9D0ZYRE0<[1`03Lfm/20>7ShP030>3Qh@3Oh=l0gn3O00`0gn3O00D0
h>3O0>CSh`3WinH0inOV0=SHe`0Z0?oooa00moOg0P3gknl20?Ogm`80Q6]J00H0Hd8a06]BBP1cDTX0
Le9:06=:@P1B>C4206<i<@03058a:@12:B40@RTQ00D0@RTQ00D0DS4Y06=2<@1S@S40LdXi08aSDP02
0;F<L`040>NmY@3_aZd0mlje0?O>]@D0mmK61`3gg/h90?OWgP@0mmk>0P3ge[d01@3_c[D0mmJm0?OF
_@3ge[d0klje00@0klJ]0`3__JD30>o6[@80kkfU0P3_]JD20>NeW0<0ikfU00D0ijfL0>NeW03W]I`0
g[FL0=j]U0020=jeW080gZfD0`3FYH`20=JLS0030=JLQ03FW8`0eZF<0080eZF<00D0eYb<0<JLQ036
W8@0eYb40<JLQ0020;F<L`060:EcFP1cBST0DSTa058i<@12:B40>BTQ0P0a8B400`1B>C40:APH02TH
6002034Q8@80>BTQ00H0@RTQ02TH601:<C40BS4a06=2<@2]W8`J0?Ogmb00oooo000N0?ooo`050=SH
f03WinH0inOV0>CTh`3Ph=l02P3Oh=l01@3Oh>00hN?R0>7ShP3Ti^H0dm7?0080X9B<00H0JE95054h
:P1>>Bd0CST]04Tg;P11<2P203/Y8P0603LS700_7AD0:ATA02TI4@0Z6Q80<1hF0P0d8QT01@0i9Q`0
Ac0T04L`901L@340N5E00080UViD00H0]8eb0<fYT03J^Z80f[ZR0=k0Z@3O`Jd20=o1/@060=k3]03N
akT0g/c00=k<`03NclH0g]370P3NclD01@3NcL40g/c00=k<`03NcL80g/o60080g/o500H0g/g10=k:
_@3NbK/0g/Vk0=k9^P3Nb;T20=k6]0060=k3[P3N`J/0g/2[0=k0Z`3L_JP0f[NQ0P3H/Y`00`3G/9T0
eZjG0=J^U`040=J/UP030=J[U@3FZY@0eZVC0080eZVC00D0e:NA0=6TS@3AY8d0cIn80<ZLQ@020<RJ
P`060<JJP`35Vh@0a9b50<BLQ@33Vh@0`YR10P32UWl30<BEOP060<6DO@2mTW/0^8ih0;R>N02eRgH0
]8Yf0`2eRgH01@2bRG80ZH1Y0:V0J@2EKeT0LeE40080DCX^00D0=bLN02/N5`0]7aX0;AlJ030Q7P02
02dO7@0602LK600S6Q@07QL@01hG400I4@d07A4=0P0^71D01P1;<bX0LUQ?09b6P@2LQX40`[Nd0=[I
f080h^?S00<0h>7Q0=oPg`3Oh=l0303Oh=l01@3Ph=l0i>?S0>OWiP3WinH0f=SG02X0oooo503gmoL2
07=BBP0606=2<@1SBT80Je9:06]BBP1SBT80DSTa0P1J@ST0101B<BT0@RTQ034Q600a8AP2048Y8@80
DS4Y00D0@RTQ06=2<@1S@S40LdXi07=:@P020:EcDP050=JUQ03_aZd0klje0>o>]@3ge[d0103ge/H3
0?ONcPD0mnON0P3gg/h40?OWgP030?ONcP3gimh0mmk>00<0mmk>0P3ge/H40?OF_@80klJ]0P3__JD0
0`3_aZd0kkfU0>nmY@040>nmY@060>o6[@3__JD0ikFL0>NeW03__JD0ikfU0`3W]I`00`3N[I@0g[FL
0=jeW0020=j]U080g[FL00D0gZF<0=JUS03FYH`0eZF<0=jUS0040=JUS0L0aYb400D0cYAk0:f4J`2]
Q6/0Nf=B05Y2>@02048Y8@05034Q600a8B40BS4a04Xa<@0Y61P00P0a8B401P0Y61P0<B4H034Q600a
8AP08A0@034Q6080DS4Y00@0Hd8a0:F4N`3oool0oooo603gmoLP0?ooo`007P3oool01@3Hf=P0inOV
0>OWiP3Ti><0h>3O00/0gn3O0P3Qhn801P3Ti^H0dm7?0:2DS02PU8`0J595050i;080Cc/b00H0BcXc
04<c:`0o;2D0?b`U03/W7`0b8AT202TL500502PK4`0/7AH0;QlH02hO600c8a/00P11;B@01P1E>bh0
JT/h08=OA`23GdL0YGmU0<FPQ`80f;FM00H0g[fW0=o0[03O`K00gl6`0=k3]03Na[L20=k:_@050=k=
`P3Nd<L0g]380=k@b03Nc/@00P3Nc<401P3NcL80g/o50=k>``3Nc/<0g/Zn0=k8^P80g/Ri00H0g/Rj
0=k8^@3Na[D0g/Je0=k3[`3M`:/20=bnZ0050=ZjY03G]Ih0e[6J0=JaVP3F[iP00P3F[IL01@3FZiD0
eZVC0=JYT`3FZI<0eJVC00<0e:VC00H0e:RB0=>VS`3@Xh`0d:><0<bPR038W8D20<JJP`060<FJP`35
Vh@0aIj70<FNQ`34WHH0`YV20P31UGh30<>CO0060<6CO02kTGX0]8ig0;B>M`2`RgD0/HYd0P2cRgD0
1P2bRW@0[8E^09ehHP2MN680Pf=@0658>`80@S4X00D0;b<K02PN5`0Y7QX0:AhJ02XN7@0202@J6`06
01hF5@0J51005a4<01LA300C3@X05Pd;0P0V5a<01P11;2@0IDa4091jL`2@NW<0^k2/0=WHe`80h^CS
00<0h>7Q0=oPg`3Oh=l0303Oh=l01@3Ph=l0i>?S0>OWiP3WinH0f=SG02X0oooo303gmoL20?O_k`H0
moOg0`1SBT8306]BBP0607=:>@1SBT80FT8i05Y2>@1B<BT0@RTQ0P1B<BT0100a8AP0BR4H048Y8@12
:B43058a:@0607=BBP24He80Q59208AB@P36U7/0gZfD0P3gc[D00`3ge[d0mmK60?OFaP020?OFaP@0
mmk>2P3gimh00`3gg/h0mnON0?ONcP050?ONcP80mmK60P3g_KD20>o>]@80kkf]203__JD00`3W]I`0
ikfU0>NmY@020>NeW080gZfD00@0ikFD0=jeW03N]I`0g[FL1@3N[I@40=JUS080eZF40P3FYH`20=JU
Q0060=JLQ03FYH`0eYb40=JLQ03>U7/0]Hac0P2ULeX01P1cBST0DS4Y048Y8@12:B40>BTQ058a:@80
>BTQ0`0a8B45034Q600503TY8@12:B40@RTQ06=2<@2<Lf<06P3gmoLP0?ooo`007P3oool01@3Hf=P0
inOV0>OWiP3Ti><0h>3O00/0gn3O0P3Qhn801P3Ti^H0dm7?0:2DS02PU8`0J595050i;080Cc/b00H0
BcXc04<c:`0o;2D0?b`U03/W7`0b8AT202TL500502PK4`0/7AH0;QlH02hO600c8a/00P11;B@01P1E
>bh0JT/h08=OA`23GdL0YGmU0<FPQ`80f;FM00H0g[fW0=o0[03O`K00gl6`0=k3]03Na[L20=k:_@05
0=k=`P3Nd<L0g]380=k@b03Nc/@00P3Nc<401P3NcL80g/o50=k>``3Nc/<0g/Zn0=k8^P80g/Ri00H0
g/Rj0=k8^@3Na[D0g/Je0=k3[`3M`:/20=bnZ0050=ZjY03G]Ih0e[6J0=JaVP3F[iP00P3F[IL01@3F
ZiD0eZVC0=JYT`3FZI<0eJVC00<0e:VC00H0e:RB0=>VS`3@Xh`0d:><0<bPR038W8D20<JJP`060<FJ
P`35Vh@0aIj70<FNQ`34WHH0`YV20P31UGh30<>CO0060<6CO02kTGX0]8ig0;B>M`2`RgD0/HYd0P2c
RgD01P2bRW@0[8E^09ehHP2MN680Pf=@0658>`80@S4X00D0;b<K02PN5`0Y7QX0:AhJ02XN7@0202@J
6`0601hF5@0J51005a4<01LA300C3@X05Pd;0P0V5a<01P11;2@0IDa4091jL`2@NW<0^k2/0=WHe`80
h^CS00<0h>7Q0=oPg`3Oh=l0303Oh=l01@3Ph=l0i>?S0>OWiP3WinH0f=SG02X0oooo303gmoL20?O_
k`H0moOg0`1SBT8306]BBP0607=:>@1SBT80FT8i05Y2>@1B<BT0@RTQ0P1B<BT0100a8AP0BR4H048Y
8@12:B43058a:@0607=BBP24He80Q59208AB@P36U7/0gZfD0P3gc[D00`3ge[d0mmK60?OFaP020?OF
aP@0mmk>2P3gimh00`3gg/h0mnON0?ONcP050?ONcP80mmK60P3g_KD20>o>]@80kkf]203__JD00`3W
]I`0ikfU0>NmY@020>NeW080gZfD00@0ikFD0=jeW03N]I`0g[FL1@3N[I@40=JUS080eZF40P3FYH`2
0=JUQ0060=JLQ03FYH`0eYb40=JLQ03>U7/0]Hac0P2ULeX01P1cBST0DS4Y048Y8@12:B40>BTQ058a
:@80>BTQ0`0a8B45034Q600503TY8@12:B40@RTQ06=2<@2<Lf<06P3gmoLP0?ooo`007P3oool01@3H
f=P0inOV0>OWiP3Ti><0h>3O00/0gn3O0P3Qhn801P3Ti^H0dm;@0::ES@2RUHd0K5A7058j;@80CS/b
00H0CC`e04Th<@14<R/0A38[03h/900h9Qh2038Q6P0502hN5`0]7QH0;b0I02lP6@0f9Ql00P13<BT0
1P1B?C80HDPi07IHA01fF4@0V7AN0;bEOP80e:bE00H0gKVQ0=nnZP3O`;00gl2`0=k2/`3N`k@20=k6
^0050=k:_@3NcL80g]360=k@aP3Nd<L00`3NclD0103NclH0g/g30=k=``3Nb[d30=k8^@060=k8^P3N
b;T0g/Jf0=k6]P3N`[80g;n/0P3J_:H01@3G^:40e[BL0=F`V@3E/9T0eJfF0080eZ^D00H0eZVC0=JX
TP3FZ980eZRB0=BYTP3BZ9820=6WT@060=2US`3@Xhd0cj:;0<nRR`3<WhP0b9b50P35VX<01P35VH80
aI^30<FLQ@35W8D0aI^40<BIPP80`YIo00D0`IAl0<2BN`30TW/0_i9k0;Z@N@020;>=MP060;6:M02d
RW<0]XYc0;J:L`2cQg00YWmX0P2AKET01P1eETH0ECda03h[8`0n:b<0<bDN02hQ70809Q/I00D081HG
01dE5P0M5AH06Q<C01D?3P02018<2P0601<=300I40l09ALD02DG500l:B80GTU10P2:N7401@2i[j/0
fMSG0>;Ti03Ri>@0h>7Q00`0gn3O0P3Ogml01@3Ph=l0i>?R0>OWiP3WinH0f=SG02X0oooo303gmoL2
0?O_k`@0moOg00H0mno_0?Ogm`1kHe80Nf=B07=:>@1[DTX206=:@P0306]BBP1SBT80DSTa0080DSTa
00@0@RTQ058a:@1B<BT0<B4H0`12:B43058i<@0606]BBP1kHe80Q6=B08ASDP2mQ6/0gZfD0P3_aZd0
1P3gc[D0mmJm0?OFaP3ge/H0mmk>0?OFaP<0mmk>2P3gimh00`3gg/h0mnON0?ONcP030?ONcP<0mmK6
00D0mmJm0>o>]@3_c[D0klje0>o6[@090>nmY@040>NeU03W_JD0kkFU0>neY@@0ikFL203N[I@01@3N
YH`0gZfD0=jUS03NYH`0eZF<0080gZF<00<0eZF<0=JLQ036W8@00P36W8@01@3FW8@0cYAk0<jDN`36
U7/0]HA[0080S6=B00H0Hd8a058a:@0i:B40>BTQ058i<@1B<BT302TH6080<B4Q00H0:APH024@400Y
61P0:APH034Q8@0i:B42048Y8@03058i<@2DNg<0moOg01T0moOg803oool001h0oooo00D0f=SH0>OW
iP3WinH0i>?S0>3Pg`0;0=oPg`80hN?R00H0i>KV0=CBd02TUi40Y9NA06mHC01D>c0204lk<`0604lo
=`1>?CH0BCPa04Th<@13<RX0?b/T0P0k9Qh01@0c81P0;1dE02lP6@0_81T0>BPQ0080AS<[00H0E3hd
0618>`1cETD0LeI5099]F02eRG420<jRR@060=ZbVP3N_:H0g/2^0=k0[P3N`K40g/6b0P3N`k@01@3N
aKL0g/Vl0=k=`P3NcL80g/o60080g]370P3Nd<P20=k>a0060=k;_`3NbK/0g/Rj0=k8^P3Nb;T0g/Ni
0P3Na[L01P3N`[<0g;n^0=VlY`3I_:L0ekRQ0=JdW080eJnH00D0e:^D0=>XTP3CZ980djNA0=BVT@02
0=FVTP060=BWTP3@Yi40cZF>0<jUSP3>XX/0cZ290P3>WhT01@3<WHP0b9^50<FJP`35VX<0aIZ200<0
aIV200D0aIR10<BHP@32UWl0`YIo0<2DO@020;jANP060;b?N02iSGH0]H]d0;F;M02dRG<0]hQa0P2f
QFl01P2]P6X0W7AO08APCP24H4h0JDTk04ld:P80?BLP00D0=BDM02hR700R6AH08QTF01TB4P0201PA
4P0601PA4@0D3Pd04P`;018<2`0F3`l071@B0P0V6AD01P0o;RL0J5QA09R;QP2HRhH0`[bi0=_JfP80
h^?S00<0h>7Q0=oPg`3Oh=l02@3Oh=l30=oOg`050>3Pg`3Thn80inOV0>OWiP3Hf=L0:P3ooolD0?Og
m`80LdXi00<0Hd8a07=:>@1SBT800P1SBT80101[DTX0FT8i05Y2>@1J@ST4058a:@04048Y8@1B<BT0
DS4Y058a:@80@RTQ00H0Hd8a07=:@P24JeX0Q6]J0;f4J`3FYH@20>NmY@030>o6[@3ge[d0mmK600D0
mmK600<0mmk>0?OWgP3gimh00P3gimh20?ONcP@0mnON00<0mmk>0?OWgP3gg/h00P3gg/h30?OFaP06
0>o>]@3g_KD0mmJm0?OF_@3gc[D0kkf]0`3__JD30>NeW0<0kkfU00H0ikFL0>neY@3W]I`0ikFL0>Nm
Y@3W]I`20=j]U0060>N]U03N[I@0gZfD0=j]U03NYH`0eZF<0P3N[I@01@3NYH`0eZF<0=JUQ03FYH@0
gZF<0080eYb400<0eZF<0=JLQ03FW8@00P3FW8@01@3>U7/0cYAc0<jDL`2eS7<0W7=S0080LdY200@0
HdY206=2<@1B>C40DSTa0P0i:B42034Q8@05034Q600Y61P0:APH02TH600Q41000P0Y61P01P0a8AP0
>BTQ034Q600a8AP0Hd8a0>oWiaX0moOg803oool001h0oooo00D0f=SH0>OWiP3WinH0i>?S0>3Pg`0;
0=oPg`80hN;R00H0i>GU0=?Bd@2SVI<0XiVC06eJD@1C?SD2054n=P0605=1>P1B@CX0CShg04hn=`19
>300A30Y0P0m9b001@0a7aP0:1/C02/N5P0[7QH0>BHO0080B34X00H0ES``06E8>@1iET<0NEI309AY
D@2aOf@20<NGO0060=F/U03L^J<0g[nZ0=joZP3N`Jh0g/6a0P3N`K801@3N`[@0g/Fg0=k9_03NbK`0
g/g20080g]3700H0g]790=k@b03NclL0g/o70=k>a03Nbl020=k9^`060=g8^@3MakP0g/Fg0=k5]`3M
`[<0gL2^0P3K_JT01@3I^J80ekBM0=B_V03D[iP0dZZD0080d:N@00H0d:B>0=:SSP3DXi00e:>@0=>T
T@3@Xhh20<jQRP060<fNQ`3>W8H0cI^80<fKR03;VhL0b9Z50P35VH<01P35VH80aIR10<FFO`35UWl0
a9Am0<:DO@80`9Am00D0_Y=l0;b@N02lT7P0^X]d0;V9LP020;R9LP060;R8L@2fQ6d0[giX0:mnJ02P
MF40S6ME0P1fDd<01P1O@380BblU03/U7@0k9Ad0;b0H02HL5P807QLD00D06A8B01L@4@0G41405a0?
01L@3@0201LA3@0601TC4@0N51<0:AXF02TJ5P1:>380PWE`0P2h/Jh01@3Dd]40g]kM0>3Qh03PhN00
h>3P00X0gn3O103Ogml01@3Ph=l0i>?R0>OWiP3WinH0f=SG02X0oooo503gmoL306]BBP0307=:>@1[
DTX0Je9:00@0Je9:00<0HdY205Xa:@1B<BT00P1B<BT0100a8AP0DS4Y058a:@1B<BT2058i<@0607=:
>@24DT80W6]B09a[DP2]Q6/0cXa[0P3W]I`01P3_aZd0mmJm0?OF_@3ge[d0mmk>0?OFaP80mmk>00@0
mmK60?ONcP3gg/h0mmk>1@3gimh20?ONcP80mnON103gg/h30?OFaP<0mmJm00D0kkfU0>o6[@3__JD0
kkfU0>NmY@040>NeW080kkFU00<0kkfU0>NeW03W[I@00P3W[I@0103N[I@0ijfL0>N]W03W[I`40=j]
U0030=JUS03NYH`0gZF<00D0eZF<0P3FW8`01@3>U7/0aYb40=JLQ03FW8@0aYb400<0aXac00H0W7=S
08acH`1cBST0LdXi05Y2>@1B<BT4034Q6080<B4Q0`0Y61P01P0Q4100<B4H02TH600Y61P0<B4Q03TY
8@80DS4Y00<0LeYB0?Ogm`3gmoL06@3gmoLP0?ooo`007P3oool01@3Hf=P0inOV0>OWiP3Thn<0h>3O
00/0gn3O0P3Qh^801P3TiND0dm;A0:>IT`2SVI<0KEYA05<n=@80DChf00H0Dd4j0591>P1>?SL0CShg
04Th<014<2T203dW8005034O600X6a<0:ahF02/N5P0i9Ql00P18<BP01P1F?300IDPi07UF@`1iET<0
U6UA0;5oI080aiMl00H0eJbD0=biX`3N_jX0g[nZ0=k1[P3N`K420=k1/P050=k2]03NaKL0g/Vl0=k9
_03NcL800P3Nd<L01P3NdLT0g]380=k?a`3NclL0g/k40=k;`080g/Vk00H0gLRi0=g7^03NaKL0g/Fg
0=g2/`3M`:h20=^mZ@050=ViXP3G]9d0e:nH0=B_V03BZY@00P3@Yi001P3@Y8h0dZ>>0=BST03DXi00
djBA0=2SSP80cZ6:00H0cIj70<jLQP3=VhP0cI^80<^KQ`38VXD20<FIP`060<FIPP35V840aIIo0<FF
O`34U7d0`YAm0P30U7d01@2nTg`0_91h0;b@N02jRg@0^HUb0080^8Ub00H0^8Qa0;J4K@2_OVP0[giX
0:1eH@2<IeD207IC@`0605m0<P1;;bD0>bDM03/U7@0_81P09Q`F0P0N5a@01@0I4Q805a0A01L@4@0G
40l05a0=00805a4=00H06A<A01hD4`0Y6QH0:AXF04Xh<P22MG020;Ra[P050=CBd@3Ng]d0h>7P0>3Q
h03Ph>002P3Oh=l40=oOg`050>3Pg`3Thn80inOV0>OWiP3Hf=L0:P3ooolD0?Ogm`<0Je9:00<0LdXi
06]BBP1[DTX0101[DTX00`1SBT80FS4Y058a:@02058a:@04034Q601B<BT0DS4Y058a:@80DSTa00H0
LdXi08AB@P2LJe80W6]B0:f4J`3>S6/20>NeW0060>o6[@3ge[d0mmJm0?OF_@3gg/h0mmK60P3gg/h0
103ge/H0mmk>0?ONcP3gg/h50?OWgP80mmk>0P3gimh40?ONcP<0mmK60`3ge[d01@3__JD0klJ]0>nm
Y@3__JD0ikfU00@0ikFL0P3_]JD00`3__JD0ikFL0>N]U0020>N]U0040=j]U03W[I`0ijfL0>N]W0@0
gZfD00<0eZF<0=jUS03NYH`01@3FYH`20=JLS0050<jDN`36W8@0eYb40=JLQ036W8@00`36S7<01P2L
Lf<0S7=S07=:>@1cBST0FT8i058a:@@0<B4H0P0a8B4302TH6006024@400a8AP0:APH02TH600a8B40
>BTQ0P1B<BT00`1cFU80moOg0?Ogm`0I0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CSh`3P
h=l02P3Oh=l01@3Ogmh0hN3P0>7Ph03Sh^80d/o=0080X9NC00H0JEYC054o=`1@?cL0D3lg05A3>`1D
@c`20591>P0604dl=015<BX0>RHO03XV7`0_7aL0:1`E0P0]7aP01@0i9Ah0ARhU04H^9@1D>B`0IdLf
0080OUM100H0UfM=0:iiG@32T7D0`Y1e0=2WS`3I]j020=fnZ0060=k1[@3N`K00g/6b0=k1/P3N`[<0
g/Be0P3NakT0103Nbkl0g/o50=k?a@3Nd<P30=kAb@060=g@a`3McL<0gLZm0=g:_@3Mb;T0gLNh0P3M
aKH01P3L`K40g;n/0=bmZ03L_JP0fkVR0=NcW080e:fF00D0dJZC0=2WT03@Yi00d:B>0=6RS@030=:Q
S`050<nQS03>WhL0cYn70<fLQ03=VX@00P3<VXL01P3:VhL0aiZ50<BHPP34V880`iJ10<>EO`80`i=l
00D0`Y9k0;nBN`2nTg/0_Y=k0;fBN`020;b?N0060;Z9LP2iQW00^HMa0;V7L@2hQg00/H1Y0P2VMf40
1P2FKET0PUi<06a;>`1/Bc/0EcT[04L/8P80>B<K00D0:QdE020I4P0N5a<07QLC01dF500201XD4P06
01TB3`0J50h071D?01`E3`0M5Q407aDB0P0/6aH01P1C@C/0Uhb90=7?cP3Aclh0hnCT0>3Qh@80gmoO
2@3Oh=l60=oOg`050>3Pg`3Thn80inOV0>OWiP3Hf=L0:P3ooolC0?Ogm`030?O_k`1cBT80LdY20080
HdY20P1[DTX01P1cBT80Je9:07=JDP1cFU80DSTa05Y2>@80DS4Y00D0@RTQ058a:@1B<BT0DS4Y058i
<@0206=2<@0606=:@P1cDTX0S6=B08aSDP2eNf<0aXac0P3NYH`00`3__JD0klje0?OFaP050?OFaP80
mmk>0P3gimh30?ONcPD0mnON1@3gg/h20?OFaP030?OF_@3_c[D0klJ]00<0klJ]0P3__JD01@3W_JD0
ikFL0>NeW03W]I`0ikfU0080ikFL00H0kkfU0>NeW03W]I`0ikFL0=jeW03W[I@20=jUS080gZfD0P3N
YH`01@3N[I@0gZF<0=JLS03FW8`0eZF<00<0eYb400D0eZF<0=JLQ03FW8@0eZF40=JLQ0030<JLQ005
0;F<L`2]Q6/0[HA[09acH`2<FTX00P1S@S401@1B<BT0@RTQ034Q8@0a8B40>BTa00<0<B4Q0`0Y61P0
0`0a8B40:APH034Q6003034Q6080DS4Y00<0Le9:0?Ogm`3gmoL06@3gmoLP0?ooo`007P3oool01@3H
f=L0inOV0>OWiP3Thn<0h>3O00T0gn3O00H0gmoO0=oNg@3QgMd0hMgM0>7Ng@3?bLP209bBSP0606EG
D01=?3D0CSde04hm=@1C@CX0ED<l0P1C@S/01P1>?3D0@S0Y03HU7@0f9Ad0<B4I034S7080=BHN00D0
>RTQ044^9@11;RD0CCL[0695=@0207eF@00609IVC@2[Med0_Hed0;f=M03<Xh/0e[BL0P3L_JH01P3N
`:`0g/6`0=k2/`3N`[<0g/Be0=k5]P80g/Nh00D0g/Zn0=k>a03Nc/@0g]380=g@b0020=g@b@060=g@
b03McL<0gLZm0=g:_@3Mb;T0gLNh0P3K`k<01P3J_Z/0f[bV0=bjY03L^Z@0fkJO0=R`V@80e:ZD00D0
djRB0=:WT@3BYi40dZJ?0=:TSP020=6QS@060<nPR`3>X8X0cYj70<jNQ`3=Vh@0c9Z40P3:W8H01P37
W8L0aIZ40<>FP@33UX40`I9n0<2@O080`91k00D0_i5j0;jANP2mTWX0_I9j0;fANP020;f?N0060;b:
L`2jR740]XQa0;J8L@2aQFh0ZGeV0P2OLe`01P2CJE<0OeY606I7=@1VAcD0DCDW04<Z8080=b<K00D0
:QdF024J4`0P6Q@081XD020J5@0201lI500601hG4P0M5Pl07AL?01dG3`0N61408QLA0P0^71H01P1F
@cd0WY>@0=WHe`3If=L0jN[Z0>;ShP<0gmoO103Oh=l:0=oOg`050>3Pg`3Thn80inOV0>OWiP3Hf=L0
:P3oool@0?Ogm`80mno_00<0moOg0>oWi`1SBT800P1SBT800`1S@S40HdY206=:@P0406]BBP80HdY2
0`12:B40101B>C40DS4Y058a:@1B>C4206=2<@0605Y2>@1cBST0W6]B09a[DP2eNf<0aXac0P3FYH`0
0`3W_JD0klje0?OF_@020?OF_@<0mmK600@0mmk>0?OWgP3gg/h0mmk>0`3gimh00`3gg/h0mnON0?OW
gP020?OWgP<0mmk>00H0mmK60?ONcP3ge/H0mmK60>o>]@3g_KD20?O>]@P0kkfU00@0ikfU0>NeW03W
]I`0ikFD0`3W]I`0103W[I@0g[FL0=jeW03N]I`20=j]U080gZF<0P3FW8`40=JUS080eYb<00@0eZF<
0=JLQ03FW8@0eYb40`36W8@00`36U7/0]HA[0:EcFP020:EcFP0307=:>@1S@S40Hd8a0080DS4Y0`0i
:B40101B<BT0>BTQ03TY8@12:B4203TY8@06034Q8@0a8AP0<B4Q034Q8@0i:B40@RTQ0P1B<BT00`2<
He80oooo0?Ogm`0I0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CSh`3Ph=l02@3Oh=l00`3O
gml0gmgM0>7Mg0020>7Mg0050<k8a`2ISh/0VHn;069CC01;>C000P1>>S001P1B?cH0E48j05=2>P1C
@SX0CSdf04@c;080>BTR00D0=bLP03XZ8`0l;2D0?2`U03d]9P02040_9`0604Pf:`1MA3D0NEI207UF
@P2@ITl0Y7AM0P2fQg001P37WHD0djnG0=ZjX`3J^Z<0gKn[0=k1/080g/:c00D0g/Bf0=k6]`3NakT0
g/Ni0=k:_@020=g=`P@0gLk500H0gLk40=g;`03Mb;X0gLRj0=g5]P3K`k<20=Vo[@060=NjY@3G^:40
fKNP0=VgX03I]9d0ejfF0P3EZ9401@3CYXl0djJ>0=>VSP3CYXh0dJB=0080cj::0P3=X8P20<jNQ`06
0<fLQ@3;W8D0b9f60<RMQP35WHH0a9^40P33UH001031T7d0_hej0;j?NP2nSgX40;f@N@050;f?N02m
SWL0_Hig0;^;M@2gRG<00P2`Qg401P2YPV/0XGQQ09Q]E`2HKEL0S69=07QC@080Gd0`00H0BC0T03`W
7@0c8AX0<b4J02TM5P0R6a@2024J5005024J5@0Q6Q@08AXD01hG4P0J50h00P0G4`d01P0J50l081H@
02lL5P0_71H0FD@m09nBS`80f=KE00<0j>WY0>;ShP3Ogml0403Ogml01@3Ph=l0i>?R0>OWiP3WinH0
f=SG02X0oooo303gmoL20?O_k`D0moOg00D0knOW07=BBP1cDTX0Je9:05Xa:@0206=:@P0607=BBP1[
DTX0LeYB07=JDP1[DTX0HdY20P1J<BT01@12:B40DS4Y058i<@1B>C40DS4Y0080DSTa00<0LdY207]S
DP2ULeX00P2ULeX01@2eNf<0cYAc0<jDL`3N[I@0klJ]0080klje0P3ge[d30?OFaP040?ONcP3gimh0
mnON0?ONcP80mnON1P3gg/h60?OFaP060>o>]@3_aZd0klJ]0>o6[@3gaZd0kkfU1`3W]I`20>N]W0@0
ikFL0P3W[I`20>N]U0060=jeW03N[I@0eYb<0=JLS03NYH`0gYb<0`3FYH`01036W8@0eYb40=JLQ03F
W8`30=JLQ0050<jDN`36U7/0aYAk0;F<L`2]Q6/00P2DHdX01P1kHe80LdXi05Xa:@1J<BT0DS4Y048Y
<@80@RTQ00D0BS4a058a:@0a8B40<B4Q02TH600303TY8@05034Q8@0Y61P0:APH02TH600i:B400P1J
@ST00`3_inL0moOg0?Ogm`0I0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CSh`3Ph=l02@3O
h=l00`3Ogml0gmgM0>7Mg0020>7Mg0050<k8a`2ISh/0VHn;069CC01;>C000P1>>S001P1B?cH0E48j
05=2>P1C@SX0CSdf04@c;080>BTR00D0=bLP03XZ8`0l;2D0?2`U03d]9P02040_9`0604Pf:`1MA3D0
NEI207UF@P2@ITl0Y7AM0P2fQg001P37WHD0djnG0=ZjX`3J^Z<0gKn[0=k1/080g/:c00D0g/Bf0=k6
]`3NakT0g/Ni0=k:_@020=g=`P@0gLk500H0gLk40=g;`03Mb;X0gLRj0=g5]P3K`k<20=Vo[@060=Nj
Y@3G^:40fKNP0=VgX03I]9d0ejfF0P3EZ9401@3CYXl0djJ>0=>VSP3CYXh0dJB=0080cj::0P3=X8P2
0<jNQ`060<fLQ@3;W8D0b9f60<RMQP35WHH0a9^40P33UH001031T7d0_hej0;j?NP2nSgX40;f@N@05
0;f?N02mSWL0_Hig0;^;M@2gRG<00P2`Qg401P2YPV/0XGQQ09Q]E`2HKEL0S69=07QC@080Gd0`00H0
BC0T03`W7@0c8AX0<b4J02TM5P0R6a@2024J5005024J5@0Q6Q@08AXD01hG4P0J50h00P0G4`d01P0J
50l081H@02lL5P0_71H0FD@m09nBS`80f=KE00<0j>WY0>;ShP3Ogml0403Ogml01@3Ph=l0i>?R0>OW
iP3WinH0f=SG02X0oooo303gmoL20?O_k`D0moOg00D0knOW07=BBP1cDTX0Je9:05Xa:@0206=:@P06
07=BBP1[DTX0LeYB07=JDP1[DTX0HdY20P1J<BT01@12:B40DS4Y058i<@1B>C40DS4Y0080DSTa00<0
LdY207]SDP2ULeX00P2ULeX01@2eNf<0cYAc0<jDL`3N[I@0klJ]0080klje0P3ge[d30?OFaP040?ON
cP3gimh0mnON0?ONcP80mnON1P3gg/h60?OFaP060>o>]@3_aZd0klJ]0>o6[@3gaZd0kkfU1`3W]I`2
0>N]W0@0ikFL0P3W[I`20>N]U0060=jeW03N[I@0eYb<0=JLS03NYH`0gYb<0`3FYH`01036W8@0eYb4
0=JLQ03FW8`30=JLQ0050<jDN`36U7/0aYAk0;F<L`2]Q6/00P2DHdX01P1kHe80LdXi05Xa:@1J<BT0
DS4Y048Y<@80@RTQ00D0BS4a058a:@0a8B40<B4Q02TH600303TY8@05034Q8@0Y61P0:APH02TH600i
:B400P1J@ST00`3_inL0moOg0?Ogm`0I0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3P
h=l02@3Oh=l01P3Ogml0gmkN0>7Og`3Qgml0hn7P0<o<b`80V92<00H0Ge1904`f:`1A>2`0DCP/05@m
<P1B?cH20591>@060550>01;>S<0A3</04@c;00o;bL0?RhV0P0o;bL01@10<BP0@c4X04<a:01:=RX0
G4Dg0080LUQ600H0QV=?09M]EP2[OFD0ZgeU0<2BN`3?Yhl20=NfW`060=^mZ@3M`:l0g/6b0=k1/P3N
`k@0g/Be0P3NakP00`3Mb;X0gLZm0=g:_@020=g:_P80gL^n00H0gLZn0=g8^`3Ma;H0gLBf0=c1/@3I
_Z/20=NjY0060=JfW`3F]Id0ekFN0=NeWP3G/i`0eZbE0P3DYXh01@3BY8X0d:>90=2SR@3@XhX0cj:9
0080cZ6600H0cJ250<fPQ`3=WhP0cIn80<fNQ`3;WHH20<NLQ0060<BKP`34VH80a9Io0<BFO`32TG`0
`8mj0P2nSgT00`2mT7T0_Hig0;f<M@020;f<M@80^h]e00H0]hYd0;68L@2YPf`0ZH=/0:5lI02ILET2
08eTCP0607aEA01WACL0DSDZ058e:P10:B00<b<J0P0Z7QL01@0T6a<081TB01lH4`0O61<07QPD0080
7ADC00H0618?018>2`0?30T03``901<?300O514203LR700606A=AP2UUi<0emGD0=OEe03UinL0hN;R
4@3Ogml01@3Ph=l0i>?R0>OWiP3WinH0f=SG02X0oooo4P3gmoL0103gknl0moOg07]SDP1kHe8205Y2
>@80LdXi00H0Je9:06=:@P1cFU80LeYB06]BBP1S@S4206=:@P05048Y8@1B>C40DSTa058i<@1J@ST0
0P1B>C401P1S@S40Nf=B08acH`2<Lf<0Q5920:EcFP80_HA[00<0gZF<0>o6[@3_c[D00P3_c[D40?OF
aP/0mmk>0`3ge/H0103ge[d0klje0?OF_@3ge[d20>o6[@80klje103__JD00`3W]I@0ikFL0>NeW002
0>NeW080ikFD1@3W]I`00`3W[I@0gZfD0=j]U0040=j]U0060=jUS03FYH`0eZF<0=JUS03FW8`0eYb4
0P36W8@30=JLQ080aYb40P2eS7<01P2]Q6/0YG=J07]SDP1kHe80LdY205Y2>@80DS4Y00H0BS4a03TY
8@0i:B40>BTQ034Q6012:B43034Q8@<0:APH00D0610@024@400Q4100:APH048Y8@0207=:@Q`0moOg
803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`0:0=oPg`050=oOg`3Qh^40hN;Q0>CUi03B
dLl00P2KTi001P1QDDT0CSDY05<g:01C=bP0EC`_058n=@80DT4j00H0Dd8k0510>01;>S<0BcXc04@c
:`0o;BH2040^9P0504@b:017=2P0Ac@X04hi:`1KAcT00P1/EdP01P1jGT`0R65<09i_F02NKeP0]hI_
0<ZOQ`80e;:K00H0f[fX0=g0[P3N`:l0g/2_0=k1/03N`[820=k4]@<0gLJf1@3Ma[D01@3Ma;D0gL6b
0=g1/P3K_Zd0fK^V0080e[NP00H0eK>L0=FbV`3E/i/0eK>K0=F_V@3DZ9820=:SRP050<nPQ@3>WX@0
cYj40<fNQ`3=WhL00`3=X8D01@3=X8L0cIn70<fOQ`3=WHH0bib40080aiZ200H0a9R10<BGP034UGh0
a9En0<BCN`32TGX20;n@N@050;f?N02mS7D0_HUc0;f9L`2lR7400P2hQg401P2aQW00Z8=/0:1lI@2P
O6D0Ug5K08aUC`80OEI400H0JTLi05Lh;P16;2@0AR`T03LS700/7aL202DL5005024I4P0O5a407QHC
01hF4`0L51@00P0H4A401P0C3@d03@X900/8200;20P04`d;02XM6P80DCdi00H0Q6mZ0;J[Z03IemH0
fMOF0>?Ti03PhN4A0=oOg`050>3Pg`3Thn80inOV0>OWiP3Hf=L0:P3oool<0?Ogm`80mno_0P3gmoL2
0?O_k`80moOg0P2<Lf/01P1SBT80FT8i07=:>@1cBST0HdY207]SDP<0Je9:0`1SBT801@1B<BT0>BTQ
06=2<@1S@S40FT8i0080HdY200H0DSTa07=:>@1cDTX0Le9:07]SDP2LJe820;EkH`040=JLQ03_aZd0
klJ]0>o6[@80mmJm103ge/H20?ONcP040?OFaP3gg/h0mmk>0?ONcP<0mmK600<0mmk>0?OF_@3ge/H0
0`3ge/H30>o>]@040?O>]@3_aZd0klJ]0>nmY@<0ikFL00D0ijfL0>NeU03W]I@0ijfL0>NeW0030>N]
U0030>N]W03W]I`0ikFL00@0ijfD00H0ijfL0=JLS03NW8@0gYb40=JLQ03FYH`20=JLS080eZF41@3F
W8@01P3>U7/0aXac0;F4J`2eQ6/0W6]B08aJBP80LdXi00<0HdY206=2<@12:B400`12:B4303TY8@<0
<B4Q00D0:APH034Q8@0a8B40610@024@400202TH6004034Q601B<BT0S7=S08acHa`0moOg803oool0
01h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`020=oOg`T0gn3O0P3Qh^801P3TiND0dm;A0:2GU02P
Ui@0JEI>054g:`80DCHW00H0Dc/^05=0=P1D@c/0E4<k05A3?01A@3P204Xi<P0504<a:@0o:b<0@R`S
048/8`17<RH00P1;=RX01P1>>bl0F4Lj06EBA01UDT@0KUA307UC@P80Sf1<00H0ZgYS0<>GO`3A[iL0
dJnG0=VlY@3M`:X20=k0Z`030=k0[03N`Jh0gL:a0080gL:a0P3M`Zl50=g2[@050=g1[`3M`:l0gL2_
0=bn[@3J_:L00P3H^:001P3F/i/0eK2H0=B]UP3D[IH0djVB0=6RR`80cif500D0cI^20<fJP`3=VX<0
c9^50<fLQ`020<fNQP80cJ270P3=WHH01P3=VH80biN00<NGP037Uh00a9Mo0<BEOP80a9=l00H0a99j
0<>ANP2oTGT0_i5i0;f?N02mRg@20;b8L@050;Z5KP2dPf`0]8=/0:Z1JP2QO6@00P2HLU/01P2<IDl0
NeE406Y7>@1ZAcT0Fc``04`b9P80?BLN00H0<1lH02LL5@0T71@091`D02@K4`0T6A<2020G500501/D
4`0F41005Q0@018<300>2@X00P0@2@T01P0M4@h0@30/07][I`1kJfL0/ZNU0=7<bP80gMcK00<0h>7P
0>3Ph03Ogml0403Ogml01@3Ph=l0i>?R0>OWiP3WinH0f=SG02X0oooo503gmoL209AkL`0607=BBP1J
@ST0Hd8a06=2<@1J@ST0Je9:0P1SBT801P1[DTX0FT8i05Y2>@1J@ST0Je9:058a:@80>BTQ00D0Hd8a
058i<@1B>C40HdY206=2<@0207]SDP0607=:@P24DT80[HA[0:f4J`36S7<0ikFL0`3_c[D40?OF_@@0
mmK60P3ge[d01P3ge/H0mmJm0?OFaP3ge/H0mmJm0>o>]@80mmK60P3ge[d20?Nm]@80klJ]0`3__JD0
103W[I@0ikFD0>NeU03W[I@20>NeU0030>N]W03W]I`0ikFL00<0ikFL0P3W]I@00`3WYH`0ijfD0=j]
U0020=j]U0@0gZF<00D0eZF40=JUS03FYH`0eZF<0=JLQ0020<JLQ0<0cYAk00H0]Hac0:f4J`2ULeX0
YG=J08aJBP1cBT8306=2<@03058a:@12:B40@RTQ00@0>BTQ00<0@RTQ03TY8@0a8B400P0a8B4202TH
6006024@400Y61P0<B4H034Q601B<BT0LdXi0P3ooolL0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0
inOV0>CShP3Ph=l00P3Ogml90=oPg`80hN;R00H0i>GU0=?Bd@2PUi@0X9ND06UFCP1A=b/2054f9`06
05<k;P1C@3H0E4<k05A3>`1D@c`0DD0h0P1:>C801@13<BT0?b/S048/8`12;2<0Ac8V0080BcHZ00H0
CS/_05Q7>P1UDT@0IE9406iD@`1iDd8208mPC0060:]jH`33Ugl0dJnG0=6_U`3I_:D0gL2Z0P3N`:/0
0`3N`:`0g/6^0=g2/@020=g2/@80gL:_1@3M`Zd01@3M`Jl0gL2_0=g0[`3L_Zd0f[bW0080f;RP00H0
e[>K0=F`V03D[IH0e:fF0=>YTP3AXX/20<nMQ@050<fKPP3=VX<0cIZ30<bKQ@3=W8L00P3=WXH20<fP
Q`80cIf600H0cIV20<^GP037Uh00aiN00<BGO`34UGh20<BCO0060<BBNP33TGX0_i5i0;nAN@2mSgP0
_H]d0P2lR7401@2jQFh0]8=/0;B3K02ZPFX0XGaT0080V79K00H0S6E?07]EA01ZAcT0JTLi05/l<01<
<RH203dW7P06030O600W71D091`D02@L500T6a<091TC0P0P5a@01@0K51<05Q0@01H@400B30`03PT:
008040T900H07A4>040`;01kJfL0Nf]W0;:WY@3Ac<X20=gLf`030>3Qh03Ph>00gmoO0100gmoO00D0
h>3O0>CShP3WinH0inOV0=SHe`0Z0?oooa@0moOg0P2DNg<01P1cDTX0FT8i06=2<@1S@S40FT8i06]B
BP80HdY200H0Je9:05Y2>@1J@ST0FT8i06]BBP1B<BT203TY8@0506=2<@1B>C40DSTa06=:@P1S@S40
0P1kHe801P1cBT80Q5920:f4J`2]Q6/0aXac0>NeW0<0klje103ge[d40?OFaP80mmJm00H0mmK60?OF
_@3ge/H0mmK60?OF_@3_c[D20?OFaP80mmJm0P3g_KD20>o6[@<0kkfU00@0ijfD0>NeU03W]I@0ijfD
0P3W]I@00`3W[I`0ikFL0>NeW0030>NeW080ikFD00<0ijF<0>N]U03N[I@00P3N[I@40=jUS0050=JU
Q03FYH`0eZF<0=JUS03FW8@00P36W8@30<jDN`060;F<L`2]Q6/0YG=J0:EcFP2<FTX0LdY20`1S@S40
0`1B<BT0@RTQ048Y8@0403TY8@03048Y8@0i:B40<B4Q0080<B4Q0P0Y61P01P0Q4100:APH034Q600a
8AP0DS4Y07=:>@80oooo703gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O00<0gmoO
203Oh=l20>7Rh@060>?Ui03Ddm80YifI0:NMV@1cGeP0EShc0P1>=bX01P1?>Rl0Dd0g05I3?01F@c`0
ET<k054n=@80BCL]00D0@blV040[8P13;280@b`R04La9@0204Xf:`0604dl<P1C@cT0FTTl05Y9?01P
BC/0JTTk0P20ETD01P2NKeT0^8ed0<^WSP3;Yhh0e[NN0=^mY@<0g;nX00@0gKn[0=g0[@3M`:d0gL2]
0P3M`:/01P3M`:T0gL2X0=boZ03L_jP0g;jW0=^nZ@80fkj[00H0g;j[0=bnZ03J^J80f[VR0=NbV`3E
[9D20=>WT0050=6RRP3?WHD0c9V00<bIP03;Ugl00P3;Uh401P3;V8@0biZ60<^LQ`3;W8L0bij70<bN
QP80c9Z300H0biEn0<VCO036U7d0aYAm0<BDO@34TW`20<B@NP060<>@N@31TGT0_i5h0;nAN02mSgH0
_8Yc0P2kQVl01@2gPf`0/85Y0;21J@2UO6D0VGAM0080SVMA00H0OeM406]7>@1I>bl0FC/_04dc9`11
:al203<R600602PL500S6Q@091/E02@K5@0X71D0:A/E0P0S61D01@0K51<05Pl?01H?3`0B2``040X:
00805@/:00H09QDA0590>P2ISXX0VHj:0=?Ad03Ti>@20>3Ph0030=kOgP3Ogml0gmoO0100gmoO00D0
h>3O0>CShP3WinH0inOV0=SHe`0Z0?oooa@0moOg0P2DNg<01P1kHeX0FT8i06=2<@1S@S40HdY205Y2
>@80Le9:00H0Nf=J058i<@1SBT80HdY205Y2>@128AP2058a:@05048Y8@1J@ST0FT8i06]BBP1B>C40
0P1SBT8207=:>@80W6]B00D0]G]S0=JUS03W]I`0ikFL0>o6[@040?OF_@030>o>]@3ge/H0mmK600<0
mmJm103ge/H00`3ge[d0mlje0>o>]@020>o>]@050?Nm]@3_aZd0klJ]0?O6[@3_aZd00`3W]I@00`3W
[I@0ikFL0>NeW0050>NeU080gZfD00D0ijfD0=j]U03WYH`0ijF<0=j]U0040=jUS0050=jLQ03FYH`0
eZF<0=jUS03FYH`00P3FW8`20=JUQ080cYAk0`36S7<01P2mQ6/0YG=J08aJBP2<FTX0Q59206=:@P80
FS4Y00<0DS4Y048Y8@0a8AP00P0a8AP703TY8@05034Q8@0i:B40>BTQ02TH600Q41000P0i:B400`1J
@ST0LdXi0?Ogm`0M0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l0103Ogml70=oP
g`80hN;Q00H0hnCT0=GDd`2]Xil0[J>O07aZH`1LAch204lk<@0604dk<@1@?SH0ED8j05E2>P1H@SX0
E3dc0P1<=RX01@16<BH0@RlV044^9@11;RD0@blV0080Ac@[00H0BcXb04hn=@1??S@0Cchd058o=@1M
A3T2079@@@0608mUD02ZOVD0`9Ml0<2GO03>Zi00e[NN0P3I_:@01@3J_:D0fkfV0=bnZ@3L_ZT0gKnZ
0080gKnY00H0gKnX0=foY`3K_JD0fkfU0=VkY03H^Z<20=RjY@060=ZlY`3K_JL0f[VR0=ZiXP3G/9T0
djJ@0P3AX8T01@3?WH@0cIb10<^IOP3;VGh0bIEm0080aiAn00H0aiJ10<NHP`37VX@0aiZ40<VKQ03;
VX<20<^GP0060<VCO036TGX0aI5j0<FANP34T7/0a8ej0P33S7T01P31SWT0_i5h0;fAMP2mTGH0_8ec
0;V8K`80]h=/00D0/h5Z0:]oI`2[OfL0X7UQ099]EP0208=KA`06075:>@1O?Bl0CC<W04dc9`10:Ql0
=28H0P0Y71<01P0Q61407aLB028I5@0R6AD09a/E02TK5P808aTE00<06a<C01@=3@0D3@d00P0@2@T2
01L;2P0602TG4`1GA3h0WiFA09nET@3If=L0j>[Z0P3Rh^800`3Ogmh0gmoO0=oOg`0@0=oOg`050>3P
g`3Thn80inOV0>OWiP3Hf=L0:P3oool<0?Ogm`80mno_1P3gmoL20;FLW00608acJ`1SBT80HdY206=:
@P1[DTX0HdY20P1[DTX0101cDTX0HdY206=2<@1S@S4205Y2>@80@RTQ0`1B>C4206=:@P80FT8i00H0
Le9:06]BBP24He80Q6=B0:EcFP3>U7/20=JUQ0040>NeW03_c[D0klJ]0>o6[@80klje2@3ge[d40>o>
]@040?O6[@3ge[d0klJ]0>o6[@80kkfU0P3W[I@01@3W]I`0ikFD0>N]U03W[I@0gZF<0080ijfD00H0
gZfD0=jUS03N[I@0gZfD0>NUS03W[I@20>NUS0030=jUS03NW8@0gZF<0080gZF<00D0gYb<0=jUS03N
YH`0eZF<0=JLQ0030=JUQ0040<jDN`36W8@0aYb40<JDN`80]HA[00H0[HA[0:EcFP24DT80Q59207=:
>@1S@S42058a:@80@RTQ0`0a8AP01@0a8B40<B4H034Q6012:B40>BTQ0080<B4Q00D0:APH024@400Q
4100610@02TH6002058i<@03058a:@24JeX0moOg01d0moOg803oool001h0oooo00D0f=SG0>OWiP3W
inH0i>?R0>3Pg`0:0=oOg`050=oPg`3QhN40hN7Q0>?Th`3FeM<00P2`Yj801P21LFP0HDi40590=`1B
@3L0CS`d04ln=P80E40i00H0Ed4i05@m<`1>=b/0CSL[04Lc:012<BT203h^9`0503h^9P12<RX0@S8Z
04Ph<01:>S800P19>C401P1;>S80E3le06E9>`1UBC/0OUQ409Q]E080[hEY00H0`Y^00<j/TP3D/i/0
e;>K0=JeWP3H^:020=^kX`030=bmY@3L_JH0g;fV0080g;fV0P3J_:@01P3G^J80eKNP0=JgX03F]j00
f;VQ0=VjX`80fKJO00H0eJfF0=6SS03>Vh@0cY^40<bIP03;VWl20<VIO@050<JDN`34TW/0a99k0<BC
O034UGh00P34UWl01P36Ugl0bIMo0<VEOP39UGh0aY9k0<B@N080`hmh00H0`Xeg0<::M`30RGL0`8Ug
0;f;MP2kSGD20;Z=LP050;N:KP2cQ6X0[gmW0:moI`2ZO6D00P2TNF401P2JLU/0RVE?07IA?P1fDCh0
HSl_054d9P80@R`O00H0=2<I02TL500Q60l08AP?01`E3P0J510201dE4`05028G500T61<07QDC01hE
4`0E40l00P0>2PX01P0>20P050/:01d?300M3``0;APB05M1>P80Vi2;00@0e=;A0>GWi`3Qh^80hN;R
4@3Ogml20=oOgP050>3Og`3Thn80inOV0>OWiP3Hf=L0:P3ooolD0?Ogm`80e[g600D0U7=[07=BBP1S
@S40Hd8a06]BBP0306=:@P0507=BBP1kHeX0DSTa058i<@1[DTX00`1B>C401@1B<BT0DSTa058i<@1J
@ST0Je9:0080HdY200H0Je9:06=:@P1kHe80Nf=B08aJBP2eS7<20=jUS0030>NeW03W_JD0klJ]00<0
klJ]1@3ge[d01P3_c[D0mmJm0?Nm]@3g_KD0klje0>o6[@80klje0P3_aZd30>nm[@<0ikFL00D0ijfD
0>NUS03W[I@0ijfD0>NUS0020=jLQ0050=jUS03WYH`0gYb40=jLQ03W]I@0103NYH`01@3FYH@0eYac
0=JLL`3FW8@0eYb<00<0eZF<0`3FW8@01@36W8@0aYAk0<JDN`36U7/0]Hac0080[HA[00<0W6]B08aJ
BP1cBST00P1cBST01@1J<BT0DS4Y058a:@12:B40<B4H00@0:APH0`0a8AP3024@40@0610@00D0<B4H
058i<@1B>C40FT8i0;FLW00N0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l02P3O
gml01@3Oh=l0hN7Q0>7Qh@3Si><0e]GC0080/:NR00H0PG5X065>A01B@3L0DT0g04hl=01??SH205A0
>@0605M1>@1D?C<0CSL[04hg:`17<bP0@S4Y0P0n;RL01@0n;RH0@S8Z048b:P18>300BSXb0080BCTa
00H0BcXb05@o=@1UBC/0IDTk07iHA02HKE@20:n5J@060<:KP03>[980e;>K0=BcV`3F]Ih0f;RP0P3K
^j<00`3L_JD0g;fV0=bmYP020=bmYP80f[bT00H0ekVR0=FgX03F]j00e[NP0=RiX@3I^Z<20=VfW`06
0=F]UP3AXh`0cY^40<jKQ03<VH00biYo0P39VGd01@36U7/0a99k0<BBN`34Tg`0a9En0080a9Io00H0
aYMo0<VGO`39UGh0bIEn0<JBN`34T7P20<>?N0060<:=M`32RWL0`8Ug0<29M`2mRgH0^hee0P2jSG80
1@2gRVh0/hAZ0:moI`2_OfL0ZWaU0080Y7UQ00H0VW9K08YUC`1fDCh0MU4n068o;`1A=2H2048/7`06
03@S6@0Y71@08AP?024H3`0L5@h06Q@@0P0M5A<01@0R5a@091PC01hE4`0N5A<05A0?00803PX:00H0
3PP801@;2P0M3``07@l<02dH4P1G@CX209^@R`040=CBd@3UinL0hN;R0>7RhQ40gmoO0P3Ogmh01@3P
gml0i>?R0>OWiP3WinH0f=SG02X0oooo503gmoL20=JmaP0509AcJ`1cDTX0Hd8a06=2<@1[DTX00`1S
BT801@1cDTX0Nf=J058i<@1B>C40Je9:00<0DSTa00D0DS4Y058i<@1B>C40FT8i06]BBP0206=:@P06
06]BBP1SBT80Nf=B07]SDP2<FTX0]Hac0P3NYH`00`3W]I`0ikfU0>o6[@030>o6[@D0mmJm00H0klje
0?OF_@3g_KD0mkfe0>o>]@3_aZd20>o>]@80klJ]0`3__Jd30>NeW0050>N]U03WYH`0ijfD0>N]U03W
YH`00P3NW8@01@3NYH`0ijF<0=jLQ03NW8@0ikFD00@0gZF<00D0eZF40=JLL`3FW7<0eYb40=JLS003
0=JUS0<0eYb400D0aYb40<JDN`36U7/0aYAk0;F<L`020:f4J`0309a[DP2<FTX0LdXi0080LdXi00D0
FS4Y058a:@1B<BT0@RTQ034Q600402TH60<0<B4H0`0Q410401P@4005034Q601B>C40DSTa05Y2>@2e
W9`07P3gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O00/0gmoO0P3QhN401P3Si><0
emGD0;6YXP2aZJ80Pg=X06AAA`80ET@l00H0DD0i0550>01C@3P0Dd0h05<o=`1B?C@204di;`0504Dc
:`0n;BP0>R/V03X[9P0l;2H00P10<2P01P15=Bd0BSTb04`l=01<?3@0CC/b04lk;`80FCh_00H0JTTf
085LAP2KM5/0VgAK0;6:L031VX820<^TS0050=2YTP3D[YL0ek>L0=NcW03I]Yh00P3I]il01P3I^:00
f;VR0=NjXP3G^Z80e[RQ0=FfWP80eKBL00H0e[BL0=NdW03E/IX0eK6J0=:ZT`3=X8X20<VHP@050<ND
O037U7/0aYAj0<JDNP34TWT00P33SgP01P33SWL0`hmh0<>ANP33TGX0a99k0<JCN`80aY9k00H0a95i
0<:>M`30S7D0`8ae0;n:M02oR7@20;f7L`060;Z6L02gQVh0]8I]0;B6K@2`Q6X0ZWmV0P2SNF401@2M
LU/0UfeE09M]E@2?ITl0P5Y40080JTLe00H0DcHW048Z7P0e8aT0=B<I02/N5P0T6Q8201hG3`0601XC
3@0H4@h0610?01P@3`0K4A006Q4?0P0C3Pd01@0<2PX01`H700L61`0<20P0714>0080;1PB00H0>R0F
05e5>`2MT8X0WI2:0=CBd03TiND20>7RhA00gmoO0`3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0
oooo5P3gmoL01P2<Lf<0Le9:06]BBP1[DTX0HdY206]BBP80FT8i00<0HdY207=JDP1SBT800P1SBT83
04Xa<@03058i<@1:<C40BS4a0080FT8i0P1[DTX01P1J@ST0Hd8a07=:@P1cBT80LdXi09a[DP80[HA[
00<0aYAk0=JUS03W]I`00P3W]I`0103W_JD0klJ]0>o6[@3_c[D20>o6[@D0klje0`3_aZd01P3__Jd0
klJ]0>o6[@3_aZd0ikfU0=jLQ080gZF<00<0gYb40=jUS03NYH`00P3NYH`30=jLQ0<0gZF<00H0gYb4
0=jUS03NW8@0gYb40=jUS03FW7<20=JLQ0050=JLL`3FW8@0eYb40=JLQ03>U7/00`36U7/01036S7<0
]Hac0;EkH`2eNf<30:EcFP0609a[DP1cBST0Hd8a06=2<@1J<BT0@RTQ0P1B<BT00`0i:B40<B4H034Q
6002034Q60@0:APH00<08A0@01P@400H41000`0H41001@0Y61P0DS4Y058i<@1B>C40HcTY01l0moOg
803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`0;0=oOg`80h>7P00H0h^?S0=SGeP2g[jX0
]jnZ08alM01]FE0205]8@00405E2>`1D@SX0DT0i0590>@80D3hf0P1??CD01@18=Rl0?b`X03/X8`0k
:2<0?2/T0080@C0X00H0ASD^04/k<`1??SH0Cchf04ll<P1>>2`204lf:00605Pk;01ZC3/0Pf=?08=S
C`2IMf00ZX=/0P2gS7D01@31UGh0bYn80=6XT@3AZ940djbE0080djfE00H0djnH0=>bW03C]9l0dkBO
0=>dWP3B/Y/20=:_V080djjG0P3B[9D01P3=YXl0aY^40<2AN@30TGT0_H]c0;f:LP80_h]b00D0`8]c
0<6:LP31RW80`XUb0<::M0020<:<MP060<:=MP32S7D0`Xae0<:<M@32SGH0`Hed0P2oRW401P2mR6l0
_8M_0;V5KP2iQFh0]X9[0;9oJ080[WiV00D0ZGeU0:5jHP2ILe/0VG=K091WD@0208UNB006085G@@1c
C3P0G3d/05`m;016;R40=R<I0P0/7AD01P0U6a<081TA01`F3P0L5Ph06A8=01H?30805@d<00D050`<
014:2P0:20P02PP800D51@0200@51@0600d9200R5A40>R@M03XT7@1B>2h0N65G0P2]XI`0103GeM@0
hnCT0>3Qh@3PhN420=oOgPX0gmoO1`3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0oooo00<0moOg
0?O_k`3gknl04@3gmoL20?ooo`0609B4Q01kHe80Je9:06]BBP1cBST0Le9:0P1SBT801P1SBTX0LeYB
06=:@P1SBT80Hd8a058i<@80@RTQ0`1B<BT01P1:<C40HdY206]BBP1[DTX0Le9:0592>@80DS4Y0P1c
BT8208aJBP060:EcFP2eS7<0aXac0<J<L`3>U7/0eZF<0P3N]JD01@3N]I`0klJ]0>o6[@3_aZd0ikfU
0080e/Je00H0ikfU0>nmY@3_aZd0klJ]0>NeU03_aZd30>NmY@030=j]U036W8@0aYb40080eYb40P3N
YH`40=JLQ0050=JUQ03NW8@0gYb40=jLQ03NW8`00P3NW8@20=JLQ0<0eYac0`3FS7/01P36W7<0cYAk
0<J<L`36S7<0_HA[0;F4J`<0YG=J0P2<FTX01P24DT80LdXi06=2<@1S@S40FS4Q048Y8@80>BTQ00@0
<B4H02TH600Q41008A0@1@0Y61P00`0Q4100610@01P@400301P@4005034Q8@1B<BT0DSTa058i<@2D
Lf/07`3gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O00/0gmoO0P3PhN001P3Qh^40
f]WI0<>m_033_K`0XI>B07i[IP80Hde700H0Ed8j05A2>P1A@3P0DD0h04ln=P1A@3T205A2>`0504ll
=016<BP0?bXQ03lZ8@0n:B400P13<2P01P1:>C40CC`d04`l<`1<?3<0CS`b04lk<@80BcH/00H0BcDZ
05M1<`1/E4<0K5A307aRC`29JED209Q`G0050:UkI@2jRg@0aYZ20<JJPP3:X8P00P38WhP00`38XH/0
bZJB0<^YU`020<^YU`050<^XU03;Yi00bjN@0<fWT03>Z9400P3<YHh01P36WHH0^i1i0;64K02aQ6`0
[7aU0:ikI080/WeT00D0]h1U0;^2J02kPVP0_XE]0;n8L@020;n9LP060;n7L02nQ6`0_X=]0;j3K@2n
Qg00_XU_0P2mR6/01P2kQVP0^8AY0;F1J@2ePFT0/GeV0:ijHP80ZGMP00D0Y7IO09aeG@2AK5H0TFaF
08ENB@0207Y@?@060716<`1R?2/0Cc4S04la8`0n9a`0<AlG0P0Y6a<01P0R61007AH>01TB3@0I4Pd0
5Pl<01@=30804`/;00D040T900`61`061@D01PD500@51@0200L61P06010:2@0R5100@c0X04<`:01c
H5P0YIJ@0P38`Kh0103Kf]T0hN;Q0>3Ph03Ph>0C0=oOgP050>3Og`3Thn80inOV0>OWiP3Hf=L0:P3o
oolF0?Ogm`060<jmaP24JeX0Le9:07=BBP1J@ST0Je9:101SBT8207=JDP0305Y2>@1S@S40DS4Y0080
DS4Y0P0i:B40101[DTX0FT8i05Y2>@1J@ST206]BBP80Le9:00@0DSTa07=:@P1kHe80Nf=B0P24He82
0:ekJ`050;EkH`36U7/0gZfD0=j]U036U7/00P3FYH`01@3N[I@0g[FU0=j]U03N[I@0g[FU00<0g[FL
00H0gZfD0>NmY@3N[I@0gZfD0=JUS03>U7<20;F4J`80_HA[0P3>U7<01@3>S6/0eXak0=J<N`3FW8@0
cXa[0080eYb400@0cYAc0=J<L`3FS7/0eXak0P3FW8@20=JLL`80cYAk1036S7<20;f4J`050;F4J`2]
Q6/0W6]B09a[DP2<FTX00P24DT80101c@S40Hd8a058a:@1B<BT2048Y8@808A0@00<0<B4H02TH600Y
61P01@0Y61P00`0Q4100610@01P@400201P@4080:APH00D0DSTa048Y8@12:B40@RTQ0>oWi`0O0?Og
mb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l02`3Ogml20>3Qh0060>7Rh@3JfMT0`kfl
0<>m_02QTi80OV]V0P1SCDL01P1G@SX0E48j0550>01A@3P0Cchf0550>@80E48k00D0Cc`d04Ha:00o
:R40?bXQ03hY8@0204<`:00604Xi<@1=?3@0C3`c04`l<`1>?380Cc/a0P1;=R`01P1;=BX0Ed4c06aD
@`1/E4<0O69?08UYE@80V71L00D0ZG]U0;Z;M036VX80aYZ20<ZPR0020<ROR0030<RQR`3:YY80bjVG
0080bjVG00D0bjRD0<^WT03;Yi00cJN@0<jXT@020<bUSP060<JMQP2kT7T0/HA/0;64K02/O6D0[W]T
0P2bOF@01@2gP6D0^h9X0;^2J02nQFd0_hQa0080_hUb00H0_hM`0;j4K02nPfd0_X=]0;j7L02nRFl2
0;f8J`060;^6J02hQ6T0]H5Y0;F1J@2aOFH0[WYR0P2YMf001@2TMUl0W7EM095/EP2AK5H0QEi90080
NU0m00H0L4Hc068l:`1?<B<0Cc4S03hW700a7aL202TK4`06028H400M5Ph06A8=01TB3@0F3``050d<
0P0C2`/01@0@2@T030H700H51@061@D010D500801`H600H040X9028D4013<2P0@c0X07=PF02UUY02
0<S1_P040=_Jf@3Qh^40h>3P0>3Ph1<0gmoN00D0h=oO0>CShP3WinH0inOV0=SHe`0Z0?oooaH0moOg
00H0c[g608A[FP1cDTX0Le9:05Y2>@1[DTX406=:@P80LeYB00<0FT8i06=2<@1B<BT00P1B<BT203TY
8@0406]BBP1J@ST0FT8i05Y2>@80Je9:0P1cDTX0101B>C40LdY207]SDP1kHe8208ASDP80[G][00D0
]G]S0<JDN`3N[I@0gZfD0<JDN`020=JUS0050=j]U03N]JD0gZfD0=j]U03N]JD00`3N]I`01P3N[I@0
ikfU0=j]U03N[I@0eZF<0<jDL`80]HA[0P2mQ6/20<jDL`050<j<J`3FS7/0eXak0=JLQ03>S6/00P3F
W8@0103>U7<0eXac0=J<N`3FS7/20=JLQ080eYac0P3>U7/40<J<L`80_HA[00D0]HA[0:f4J`2LJe80
W6]B08aJBP0208AB@P0407=2<@1S@S40DS4Y058a:@80@RTQ0P0Q41000`0a8AP0:APH02TH600502TH
6003024@400H4100610@0080610@0P0Y61P01@1B>C40@RTQ048Y8@12:B40knOW01l0moOg803oool0
01h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`0;0=oOg`80h>3O00H0h>7P0=gMg03BcM00d/g@0;V_
/P2BP7l206]FCP0605M2>@1B?cH0Cchf04ln=P1>?CH0DT4j0P1FA3`01@1B?cD0BSHZ044/8@11;240
?RPQ0080A2lX00H0CCXa04dl<`1:>C40BSTa04dl=01A?cL204dk<`0604Lf;@1=>c40FTPk05Y8>`1T
D480K5A50P1kFDT01@2@I540Y7EO0;:5KP2bQFh0]hae0080]8ag00H0/hik0;FBPP2gUHD0]iF50;ZF
Q@2kUX<20;fHPP060<2LQ032WHH0_iR20;nHPP2fSWL0ZX1Z0P2OM5d01@2JKED0VfaD0:5^E02QKU@0
ZG9F0080[gMK00H0]7eS0;J1J@2gPVX0]h9Z0;V0I`2jO6<20;YlI0060;V0J02gPVP0]H5R0;F1HP2c
OUl0/G]P0P2_NF401P2/Mf00YgAM0:9aFP2RLEX0VfiH09=[E@80R69=00D0NU9006e3<`1]@c<0H3LX
058^8@0204@W7@0603LQ6@0]71D09ATA02DI4@0N5@h06A4<0P0D3@/01P0B2`X04@X:00l92@0?2@T0
30L700P41@8010@400D01@H600d:2@0=2PT05@d:028D3P0204Ph<P0508f1O039`/00g]_K0=kKf`3O
g]h00`3OgmlC0=oOgP050>3Og`3Thn80inOV0>OWiP3Hf=L0:P3ooolF0?Ogm`060?ooo`2<Lf<0Nf=J
07]SFP1SBT80Hd8a0P1cDTX01P1S@S40HdY206]BBP1[DTX0HdY2058a:@80Hd8a0`1B<BT2058i<@80
LeYB00H0He9:06]BBP1SBT80HdY206]BBP1cFU8207]SDP0608A[FP2<Lf<0Q6]J08A[FP2ULeX0U7]c
0P2eS7<00`2eQ6/0[HA[0:f4J`020;F<L`80]HA[00H0]Hac0<JDN`3FYH@0eZF40<j<Q03FYH`20<JD
N`050:f4J`2ULeX0YG=J0:EcFP2LJe800`2ULeX01@2mQ6<0_HA[0;f4J`36S6<0_HA[0080cXa[00<0
aXac0<jDN`3>S6/00P3>S6/40<J<L`040;f4J`2eS7<0]Hac0;f4J`<0]G]S00<0W7=S08aSDP24DT80
0P24DT8207=:>@0306=2<@1J<BT0@RTQ0080@RTQ00D0>BTQ02TH600Y61P0<B4H02TH6004024@40H0
610@00D0:APH04Xa<@1:<C40DS4Y048Y8@0208aSDP030?ooo`3gmoL0moOg01d0moOg803oool001h0
oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`0;0=oOg`<0gn3O00D0gmoO0=cKg@3Lfmd0blK70:>FTP02
07ERF00605Q4>@1=>c80BcXb04/j<P1=?3@0DClh0P1B@3P01@1>?C<0ACH[03d]9@0m;BD0>bPS0080
@RdV00H0BcD[04di;P1<>S40C3Xa04lo=`1EA3d205=2>`0604dm=P1=?3@0DD4g0551=`1FAS/0GTXo
0P1[D4801@1lF4L0S69>09M/EP2GK5H0VW9N0080UgAT00H0U7EW09AhJ@2HNFP0V7UX09ijI`2UOVP2
0:Z4K@060:f9LP2^RG80Z8=^0:R3KP2NN6D0UFeI0P2>IDl01@2:GdP0REe508iOA@2>GdD0UVE80080
WVY=00H0Y6iD0:UbF@2[MU`0ZgIL0:mhG02dN5`20;AhG@060;1hG`2ZMUd0YW9G0:IbE`2TKe80Y6eC
0P2UKED01P2SKEH0WVaF09IYE@2FJED0SFAA08EMB`80Ne9000D0KTDd060h:@1P>2T0DbdQ04HV7002
03XQ600602lM5@0V6A407aD>01lE3P0J4@`05@d:0P0A2@T01P0>1`L02`L700T61P091PH01`D500D4
10800`@400D01`L6018>2`0B3P/07A8=02TI4P02050o>@0509R>R`3Dd]40iNGU0>GUi@3QhN405P3O
gmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0oooo5`3gmoL01@2]S8@0Q6]J08A[FP1[DTX0FT8i0080
Je9:101SBT801@1[DTX0DT8i058a:@1B<BT0BS4a0080DS4Y00D0Hd8a06=:@P1SBT80HdY206]BBP03
07=JDP0406]BBP1kHeX0HdY206=:@P80LeYB0P1kHe80102<He80W7=S09a[DP2LJe8309AcJ`040:Ec
FP2<Lf<0W7=S09acH`80YG=J0P2eS7<01@3FYH@0]Hac0:f4J`2]Q6/0W7=S00<0W6]B00D0S6=B09AS
BP2<He80S6=B0:EcDP030;EcFP@0_HAS00<0cXa[0;f4H`2mQ6<00P2mQ6/20:ecFP060;EkH`2eLeX0
]HA[0;F4J`2eNf<0[G=J0P2LLf<01@2LJe80S5Y:08AB@P24DT80Ld8a00<0FS4Y00@0DS4Y048Y8@12
:B40@RTQ0`0a8AP202TH60<08A0@1`0H41001@1B<BT0>BTQ03TY8@12:B40DS4Y0080kmK>803gmoLP
0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O00h0gmoO00D0h>7P0>;Rh`3Rh^<0e]CC0;2W
X`02081aI`0605e<@@1<>c80BCP`04Th<01=?3@0Cchg0P1>?SH01@19?3<0@CH^03T]9`0i;BL0=BLS
0080>bTR00H0AS4U04`h;01@?C@0D3dd05A3>`1IAd0205Y8@@0605M6?P1D@c/0DT8j0592>P1FACd0
GD]20P1VD4@01@1`E4D0NEQ507iJAP1nFTH0Oee<0080NeiB00H0MeiC07EMD01iG4`0NEa<089MBP2;
Hdh2099/EP0609MbG02FLUd0SfaI08m/F@24HU80OU];0P1lET@01@1kDch0NU4k07iC>P1nDcX0Q5Ll
0080Re]000H0TEa409MQB@2LJ4d0W6Q=0:9^D@2XLE<20:Q`E@060:9]E02KJE40UVA<09ITC02DH4P0
UEm60P2FH4P01P2FHT`0TF=?08QOC@28Gdd0OUQ807I>?`80Jd<d00D0GcPY05@_8P1D;b80BBPN03dR
6`02038N5P0602LI4@0P5Ph06Q<<01XC300F3`/04PX:0P0?1`L01P0;1@D01P@400<4100310@00P@4
00<410801`H500D03@X901LB3P0G4Ph091TC03LU7P02065=A`050::GT`3Ee=<0i>GU0>CUi@3QhN40
5P3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0oooo5`3gmoL0103Fc]h0U7]c09AkL`1[DTX306=:
@P0606]BBP1SDTX0DT8i0592>@1kHe80FT8i0`1B<BT204Xa<@06058i<@1S@S40LeYB07=JDP1[DTX0
Nf=J0P1JDU801P1SBT80Nf=J08A[FP24JeX0Nf=J07=JDP80S6=B00D0YG=J07]SDP24JeX0Q6]J08AS
DP0408aSDP80S5Y:00<0W6]B08aJBP2ULeX00P2ULeX01@2]Q6/0YG=J0:EcFP2ULeX0Q6]J0080Q6=B
0P24DT8208aJ@P0508AB@P2DHdX0U6=:09a[DP2ULe800`2]LeX30;EkH`030:ecFP2ULeX0YG=J0080
YG=J00<0W6]B0:EcFP2ULeX0102LJe8208AB@P80LdXi00D0Hd8a05Xa:@1J<BT0DS4Y048Y8@02048Q
600603TY8@0Y61P0:APH02TH600Q4100:APH0P0Q410601P@4080:APH00D0@RTQ04Xa<@1:<C40>BTQ
06<i<@0R0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l03P3Ogml01@3PhN00h^;S
0>;Rh`3Fe=<0/:NS0080P75W00H0GDa104`k<P19>300BCP`04dl=01??SL204hn=P0504Tl<`11=Rh0
>BdW03T]9`0e9b<00P0k:B801P16<BD0C3P/050m=01@?C@0E4<k05U7@080FTQ100H0EdHn05A3>`1B
@SX0DT8j05I5?@1MBd8206I@A005071DA@1iF4D0OUY607iJAP1oGD`00P1kGU801P1gGU<0MEe@07UL
C01iG4`0PUe:08]SCP80TVaF00H0Ug9L09IbG@2?K5T0SfaI08ARDP1nFd/207aFA00507]C?P1jDC/0
OU<j07iC>P24Ec`00P2;Fd001P2AG4@0Uf5909aXC@2LJ4d0XViA0:QaD`80Z71E00H0XVeD09]YD@2F
I4`0UVA<09APB02EGdH209IPB00609IRC02AHdl0R5m=08QOC@1nF4P0MTho0P1[@c@01@1O>2T0E2lR
05@_8P19:1h0?B8K0080<QhF00H09aTA020F3P0J4``06Q<<01H?2`0B2PX200l71`0600/51@0610@0
0`@400<4100210@00`@40P071PD01@0=2PT05a8>01LB3P0T6A<0=bDN0080HDe700D0XYNC0=GDd`3T
iND0i>GU0>7Qh@0F0=oOgP050>3Og`3Thn80inOV0>OWiP3Hf=L0:P3ooolG0?Ogm`040=K>gP2DNg<0
U7]c06]BBP<0HdY200H0Je9:06=BBP1B@ST0DT8i07]SDP1J@ST3058a:@80BS4a00H0DSTa06=2<@1c
FU80LeYB06]BBP1kHeX205YBDP0606=:@P1kHeX0Q6]J08A[FP1kHeX0LeYB0P2<He801@2ULeX0Nf=B
08A[FP24JeX0Q6=B00@0S6=B0P2<FTX00`2LJe80S5Y:0:EcFP020:EcFP050:f4J`2ULeX0YG=J0:Ec
FP24JeX00P24He8208AB@P80S5Y200D0Q59209ASBP2DHdX0W6]B0:EcDP030:ecFP<0]G]S00<0[G=J
0:EcFP2ULeX00P2ULeX00`2LJe80YG=J0:EcFP0409a[DP80Q5920P1cBST01@1S@S40FS4Y05Xa:@1B
<BT0@RTQ0080@R4H00H0>BTQ02TH600Y61P0:APH024@400Y61P2024@40H0610@0P0Y61P01@12:B40
BS4a04Xa<@0i:B40HcTa0280moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`0>0=oO
g`050>3Qh03Si><0hnCS0=[If02j];<00P2?PX001P1YFE@0DD4i04/j<P1;>S80Cchf0510>@80CD0h
00D0Bchf04Dh<@0i;BL0>BdW030U7`0203@V7`06044`9P1=>S00E48j05A2>P1IAd00FdY20P1MC4@0
1P1NCDD0G4]305]:@P1KBT80GDa306=AAP80J5E700D0K5I606iEA01^E480KUA206]A@`0206M>A006
06A;@@1SB3/0IDLh06E7>01ZAcP0LT/l0P1jDd401P20FDL0P5a:07UIB@1iFDT0Ke5406Q;@080J4Tl
00D0JdPi06i7=@1aB3<0LDPc07A:<P0207M;<`0607]<=`21DC`0RUY208YJ@P2AHDL0U6A90P2BHTP0
1P2>GdH0RUa408QJ@`28FT<0QUM008AD?080Pe<m00H0PUI207mFA01iDT40NE91075:>`1Y@c@205di
:`05050_8`16:1h0ARPN040V7P0g8a/00P0[71@01P0P5Ph06a@;01TB2`0I4P/05@h;018:2P803PH7
00H02P@400D30`020`<00P<300430`061PD2014<2@0501TA3@0L510071@@02XO6P1=>S<00P1oJF<0
1@2cYj<0f=KE0>;Th`3Ri><0h>7P01H0gmoN00D0h=oO0>CShP3WinH0inOV0=SHe`0Z0?oooaP0moOg
0P2]W:D01P1cDTX0HdY206=:@P1SBT80Je9:05Y2>@<0He9:00@0HdY2058i<@1B>C40>BTQ0P1B>C40
0`1J@ST0Je9:07=JDP0507=JDP0607]SFP1SBT80Nf=J07]SFP2<Lf<0Q6]J0P2<He8208A[FP80Nf=B
00D0LdY207=BBP1cDTX0Le9:07=:>@0207]SDP0607=:@P24DT80Q59208AB@P24He80S6=B0P24JeX0
0`1cDTX0Nf=B07=BBP0207=BBP0308AB@P1cBT80LdY200<0Q58i00<0Q59208aJ@P2LJe801@2LJe80
102DHdX0Q6=B09a[DP2LJe8208aJ@P80U6=:00H0S6=B08aJBP24DT80Q59207]SDP1cBST205Xa:@<0
DS4Y00H0DSTa03TY8@0a8AP0<B4H034Q8@0a8AP302TH600401P@400Q41008A0@024@40@0610@00@0
8A0@048Y8@12:B40DS4Y0P0a8B400`1S>C40[Hb40?Ogm`0Q0?Ogmb00oooo000N0?ooo`050=SHe`3W
inH0inOV0>CShP3Ph=l00P3Ogmh<0=oOg`050>3Qh03Qh^40hN;Q0=_KfP35`<<00P2RUi/01P1iJVX0
FTQ204ll=01??3@0D3hf0511>P80CT4j00D0CD0h04Xj<`0n<2T0?S0Y03<X800203HY8@06048c:`1?
?SH0FDLo05U7?`1MBd@0GTa40P1OCDD2061?A`80H4i600H0HTm506IAA@1ZDdD0JU=506]DA01YDT82
06E??`0505m9?01K@cX0Fd<j05Ln=01F>Rh00P1F>Bd01P1H>S00G3/a068n<@1R?S40J4@e06Y9>`80
IdXm00H0GTDk05Q0>01G?SH0Echf05Xm<`1O?2l2068l:`<0HS`Y00H0Hc`/06U0<01aBCH0LDTf07Q?
>P1jDC/207Q@>P0607I>=`1eCSL0Mdli07M?>@1eC3L0L4Lb0P1/A3401P1[ASD0JTDg06I1<`1V@C<0
HC`^05Xg:@80Cc4T00D0@RPN03PS6`0h8a/0=B<K02hP6@0202<I4P0601XC300H4@X0610;01P@2`0E
3P/04@X:0P0=1PL01P0810@010<300<41@0310D01PH700l;2`807A<?00D091LA02@H4`0T61<0=bXV
06UGD`020:6?R@050<Nm^P3Kf]T0hN;Q0>7Rh@3Oh=l05P3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG
02X0oooo603gmoL20=kFi`0308acJ`1cDTX0HdY20080HdY200D0Je9:05Y2>@1J@ST0He9:07=JDP02
06=:@P<0DSTa00<0Je9:06=:@P1kHeX00P1kHeX01@1[DTX0Q6]J08A[FP1cFU80HdY20080Le9:00@0
Nf=B08ASDP24JeX0Q6]J0P1kHe8208AB@P0507=:>@1J@ST0FT8i07=BBP1J@ST00P1SBT801P1cDTX0
Hd8a07=BBP1cDTX0LdXi07]SDP80LdXi00H0HdY207=JDP1SBT80HdY2058a:@1S@S4305Y2>@@0Hd8a
0P1cBST207=2<@H0LdXi2@1S@S400`1S>BT0FS4Q05Xa8@03048Y8@0303TY8@0a8B40:APH0080:APH
00<0<B4H034Q8@0a8B400P0Y61P601P@400502TH6012:B40@RTQ048Y8@0a8B400P1B>C400`1cBST0
oooo0?Ogm`0Q0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l00`3Ogmh;0=oOg`05
0>3Pg`3PhN00h>7P0=gMg@3Ac]800P2g[[D01P2=OWl0I51;058m=@1B?CD0Ccde04lo=`80CSlg00D0
CShf04`k=015=Rh0ACH^040b:P02048d;00604Xj<P1C@S/0FdU105]9@@1OCDD0H4i60P1OCDD01P1L
Bd<0FdY205]:@P1KBT80GDU00658?P80ITTm00D0JT/l06M9>@1PACH0H4Df05U1=@02058m<`0604`g
;P19<RT0BC8Y04Tb:@1<=2d0CC<[0P1=<2L01P1A<bT0EC/a05Ho=@1F?cD0DSde04dj<`80BSL`00D0
BS<[04/_9P1<;R<0C2hS04`_8P0204/^8P0604/]8P1?;R<0EC8V05Db9P1K>2T0GC`[0P1N?R/01P1M
?RX0GSh[05lo:`1O?b/0GC`Z05Pe9P80E34T00H0Dc4V058a9`1?;bD0CblU04`]8P18:b02040W7@05
03@R6@0[7QH0:ahF02LL500R6A800P0K4`h01P0F3`/05@h:01D=2`0E3@/050`;014:2@802`H600H0
1@@300<30`071PL01`H7014<3`0L4Q@202HH5@0502/K500`8A/0<24K04ho>`29O7P00P2o][<01@3H
dm40g]gL0=oPg`3Oh=l0gmoO01H0gmoN00D0h=oO0>CShP3WinH0inOV0=SHe`0Z0?oooaP0moOg0P3W
g^L00`2DQ8@0Le9:06=:@P0206=:@P0306]BBP1SBT80HdY20080HdY20P1[DTX01@1SBT80FT8i05Y2
>@1[DTX0Nf=J0080LeYB00H0Q6]J07]SFP1kHeX0Nf=J06]BBP1SBT8206]BBP80LdY20P24He801@24
DT80LdXi07=:>@1cBST0FT8i0080HdY200H0FT8i058i<@1B>C40DSTa06=:@P1J@ST2058a:@0307=B
BP1SBT80HdY20080HdY200D0DT8i05Y2>@1J@ST0FT8i058a:@03058i<@<0DS4Y0`1J<BT806=2<@06
06<i:@1J<BT0Hd8a06=2<@1J<BT0DSTa0P1B<BT01@1J<BT0DS4Y058i<@1B>C40>BTQ0080@RTQ00<0
<B4H03TY8@0Y61P01P0Y61P501P@40808A0@00D0@RTa03TY8@12:B40@RTQ05Xa:@0206=:@P030=K6
gP3gmoL0moOg0240moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`030=oOgP/0gmoO
00D0h>3O0>3Qh03PhN00gMgM0=7>dP020;N^]@0608enO`1TD4/0DSde058m=@1??CD0Cclg0P1>?cL0
1@1>?SH0C3/d04Df;P15=Rh0@38Z0080@S@/00H0BSXb05=2>`1KBD40FdU105m=A@1PCTH205m=A@06
05a;@`1KBT80FdY205]:@P1MBD00HDPn0P1VBCd01@1ZBc`0IdTi0615=P1PACH0FD4e0080DSdc00H0
C3L^04Tb:@19<RT0BC8Y04`d;@1=<b/204d`9`06054c:@1E>c40ESle05Ho=@1B?CD0CCXc0P1:=c00
1@1:<b/0BblV04`^8`1<;R<0C2lR0080BbhR00H0BbdR04l^8`1E<RH0EC8V05/h:@1M?2/205hn:`06
05dn:P1N?R/0Gcl[05lo:`1M?2X0F3DV0P1D<B@01P1C<BH0DS4W04l_9@1?;bD0C2dR04P[8080@2LM
00D0=28I02/N5P0[7QH09a`D028I4P0201/C3P0601H?2`0E3PX05@d;01D=2`0D30/04@X90P0;1PH0
1P0510<00`<300L61`071PL04@`?01`B50809QPE00D0:a/D030Q6`0`8A/0CSlk08UlN0020;nf/`05
0=SCd@3NgM`0gn3O0=oPg`3Ogml05P3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0oooo603gmoL2
0>ONi`0309B4Q01cDTX0HdY20080HdY200<0Je9:06=:@P1SBT800P1SBT8206]BBP0506=:@P1J@ST0
FT8i06]BBP1kHeX00P1cFU801P24JeX0Nf=J07]SFP1kHeX0Je9:06=:@P80Je9:0P1cBT8208ASDP05
08AB@P1cBST0LdXi07=:>@1J@ST00P1SBT801P1J@ST0DSTa058i<@1B>C40HdY205Y2>@80DS4Y00<0
Le9:06=:@P1SBT800P1SBT801@1B@ST0FT8i05Y2>@1J@ST0DS4Y00<0DSTa0`1B<BT305Xa:@P0Hd8a
00H0HcTY05Xa:@1S@S40Hd8a05Xa:@1B>C42058a:@0505Xa:@1B<BT0DSTa058i<@0i:B400P12:B40
0`0a8AP0>BTQ02TH600602TH60D0610@0P0Q41001@12:C40>BTQ048Y8@12:B40FS4Y0080HdY200<0
e/KN0?Ogm`3gmoL08@3gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O00@0gmoN2P3O
gml30=oPg`060=oOg`3KfM`0b/?80<[3b02RU9D0MF5L0P1JACh01P1??CH0CC`d04dl=01=?3@0CS`e
04dl=080C3/c00D0C3/d04ln=`1??SL0E4<k05M5?@0205U7?`0605a;@`1OCDD0G4Y205a:@P1FA3d0
Dd8j0P1E@c/01P1I@c/0GT8i06=3>01S@cP0IT<f06=1<`80G3h`00D0E3``04dj<@1=>S40ASD]044`
:00204@b:P0604Te;P17<B/0@2XS040Z8`0o:R<0A38Z0P18=bl01P18=Rh0AS<[048_:012;bP0?RXR
03XT7080>28J0`0g91`01P0h8QX0>b4I040R6P108QX0A2HL04P[7`80B2hP00H0B2lO04L^7`17;Ql0
AbhO04D[7@129Q/3044R6P05040R6P0m8QX0?B8J03/R6P0i8AT00P0d7aL01@0Z71@08AP@024H400M
5@d06A8;00805Ph:00H04`/:01<;2`0C2`X04`/:014:2P0=20P200L51@0600830`030`<030T:00`9
2P0L4aH0:ATK0P0/6aP01@0d8Q/0BSXc04Xj<`1dIf80ZjFR0080eM?B00@0hN7P0=oOg`3Ngmh0g]oN
5`3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0oooo6P3gmoL00`36[Jd0U7]c06]BBP0206]BBP05
06=2<@1[DTX0Je9:0592>@1SDTX00P1SBT801@1kHeX0Je9:06]BBP1J@ST0Je9:0080S7=S00<0He9:
07]SFP1kHeX00`1kHeX207=JDP0607]SDP1cDTX0LdXi07=:>@1[DTX0LdXi0P1cDTX0101B>C40HdY2
06=:@P1SBT830592>@0506=:@P1[DTX0HdY206=:@P1B>C400`1SBT801P1S@S40DSTa04Xa<@1:<C40
DSTa04Xa<@<0@RTQ0`1B<BT3048Y8@0505Xa:@12:B40DS4Y058a:@1B>C401@1B<BT2048Y8@06058a
:@12:B40DS4Y058a:@12:B40DS4Y0`12:B4203TY8@06034Q600i:B40:APH02TH600Q4100:APH0P0H
41000`0Q4100610@01P@400301P@40<0>BTQ00@0DS4Y034Q8@0a8B40FS4Y0P2]Q7/T0?Ogmb00oooo
000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l01P3Ogmh;0=oOg`060>3Ph03Pgn00eM;C0=GBd`2f
[:`0SGej0P1ZF5801P1D@S/0BcXb04`j<P1<>S80Ccde050o=`80D3hf00D0D3lg05I4?01FA3`0FdU1
05Q6?P020591>@0605E4?01JBD40EdHn05M6?P1??SH0CC`d0P1B@3P01P1JA3/0HDHk06=6>P1SASX0
H4<g05Xn=080E3/`00D0CcX`04/i<01;>C00ACD]048b:P0204Hd;@0604`h<@18<bd0?2TU03`Y9@0g
9b<0>RdW0P0n<2P01P0o;BD0?RTR03`V7`0l9Ql0=b8K034M5P80:a/D0`0Y71D01P0[6a@0<1/D03HL
5@0f71D0>QlH03`R6@80>b<I00H0=b8G03DQ5P0d81H0=20F03<O5@0b71@203@L5080=adF0P0c71D0
1@0`71@0;a/D02/J4`0[6Q<08aL@008071D<00H06A<:01L@2@0D3@X050d:01<:2P0B2PX201092P06
00`820071PH010@400@410030`@01`D60P0C3@d01@0U6AT0<AlM03<O6@0c7aT0AC8[0080M6MQ00H0
Z:6M0<_9b03Mg]d0gMkM0>7RhP3Oh=l20=kNgQL0gmoN00D0h=oO0>CShP3WinH0inOV0=SHe`0Z0?oo
oaX0moOg00H0e/K>0;FUY@1[DTX0Je9:06=:@P1[DTX206=:@P0306=BBP1[DTX0HdY20080HdY20`1k
HeX00`2<Lf/0FT8i05Y2>@0207=JDP80Je9:00H0FT8i058i<@1[DTX0Je9:07=BBP24He8206=2<@03
06]BBP1cBT80HdY200@0HdY20P1J@ST206=:@P0307=BBP1B@ST0BS4a0080BS4a00<0DT8i058a:@1B
<BT0101B<BT2048Y8@<0>BTQ1012:B42058a:@0303TY8@1B<BT0@RTQ0080@RTQ00@0>BTQ048Y8@12
:B40DS4Y0`12:B401P1B<BT0@RTQ048Y8@12:B40<B4H048Y8@80>BTQ00<0<B4H024@400Q41000P0a
8AP202TH600601P@400Y61P08A0@024@400H4100:APH0`0H41001@0Y61P0>BTQ03TY8@1B>C40<B4Q
0080DS4Y00<0YHB40?Ogm`3gmoL0903gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O
00h0gmoN00D0gmoO0=oOgP3Ogmh0h>3O0>7Qh@020=_If@060<K0`02TV9P0O6]X07a[J01KB440CCXb
0P1=>c<01@1A?cL0Dd4i054o>01A?cP0Cchf0080E4<k00H0F4Q005A4?01??SH0Cchf0591>@1HAcl2
05E4?00604`l=019>S80Cchf04ln=P1JACX0HdTl0P1PAcX01@1G@CL0Cc`d04/i<@1;>C40BSP`0080
B3L`00H0A3@]044b:`15=2h0AC@^04`h<P17<bl203/Y9P0603@V8`0f:B@0>2TS03PY8`0h91l0=R0K
0P0d7aP01@0`7AH0:QXB02@H400T61008AL@00808AL?00@091L@02XI4P0`71@0<1`D0P0d7QH2030L
500302/J4@0V5`l09AH?00809AH?00D09QH?02/I4@0[6A40<A`D038L500202dJ4P0502PH400V5a00
8aH?02<F3`0N50`00P0K4`/01P0I4P/0610;01D=2`0E3@/04PX:01092@803@P800H02@H600H51@07
1PD01`H500/9200B3@/201dC4@0502`M600j9b00BC@]04Td;@1ZFE<00P2SVYH0103Aclh0gn3O0=oO
g`3Ogml20=oOgP80g]oN5`3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0oooo6P3gmoL01P3gknl0
c[g609AcJ`2DLf/0Je9:06=:@P80Je9:00D0HdY2058i<@1J@ST0FT8i06=BBP02058i<@0307=JDP1k
HeX0Nf=J0080Nf=J00D0DT8i05Y2>@1J@ST0Nf=J08acH`0207]SDP0406=:@P1cBT80Hd8a06=2<@80
FT8i0`1B>C4306=:@P05058a:@12:C40@RTa048Y<@1B@ST00P1:<C401P12:C40DS4Y048Y<@12:C40
DS4Y048Y<@<0>BTQ00@0<B4Q03TY8@0i:B40<B4Q100i:B42048Y8@06034Q6012:B40@RTQ048Y8@1B
<BT0@RTa0P0a8AP203TY8@80<B4H00H0@RTQ034Q8@12:B40@RTQ034Q600a8B42048Y8@03034Q8@0i
:B40>BTQ00@0:APH00<08A0@01P@400H41000`0H410202TH60@0>BTQ0P12:B4208aSDP030>oWi`3g
moL0moOg02@0moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Pg`0>0=oOgP050=oOg`3O
gmh0gmoN0>3Pg`3QhN400P3KfMT01P36`<00Y9RH07a[J01lJfP0FdQ104dj<P80CC/c00D0DClg05=1
>@1A?cP0DClh04ln=P0205A3>`0605Q8@01DA3`0Cchf04ln=P1B@CT0F4Lo0P1EA3`01P1<?3@0BCXb
04ln=P1??SH0FTDj06=9?080H4Lj00D0Ed4g04ll=01;>C40BcTa04Xh<00204Pg<00604@d;@11<R/0
AC@^04Dd;P1<>380Ac<_0P0k:BH01P0d9R<0=RTT03PY8`0h:B<0>2@O03HP6`80=1lH00D0<1dF02XJ
4P0T610091P@024G4002024G3`0402@G400Z6A80<1`D030L5080=1hF0P0`71@00`0[6Q409QL?02DF
3`0202DF3`0502HF3`0[6A40:aTA034L500b71@00P0]6Q801@0X61009QL@02<F3`0S5Pl07Q@<0080
6a<;00H06A8;01P@2`0E3@/05@d;018:2P0@2@T200d8200600T61P061@D01`H500L61@0;2@P04Pd;
0P0M4a401@0/7AP0>RLP04Td;@19=2d0JUUC0080XiZF00@0dLo>0=oPg`3Ogml0gmoO0P3Ogmh20=kO
gQL0gmoN00D0h=oO0>CShP3WinH0inOV0=SHe`0Z0?oooaX0moOg00H0mno_0<jmaP2DLf/0U7=[06]B
BP1SBT8206]BBP0506=:@P1B>C40FT8i05Y2>@1SDTX00P1B>C400`1cFU80Nf=J07]SFP0207]SFP05
0592>@1J@ST0FT8i07]SFP2<Lf<00P1kHe80101SBT80LdY206=2<@1S@S4205Y2>@<0DSTa0`1SBT80
1@1B<BT0@RTa048Y<@12:C40DT8i0080BS4a00H0@RTa058a:@12:C40@RTa058a:@12:C4303TY8@04
034Q8@0i:B40>BTQ034Q8@@0>BTQ0P12:B401P0a8AP0@RTQ048Y8@12:B40DS4Y048Y<@80<B4H0P0i
:B42034Q6006048Y8@0a8B40@RTQ048Y8@0a8AP0<B4Q0P12:B400`0a8B40>BTQ03TY8@0402TH6003
024@400H4100610@00<0610@0P0Y61P403TY8@80@RTQ0P2<He800`3_inL0moOg0?Ogm`0T0?Ogmb00
oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Pgml04@3Ogmh01P3Oh=l0h>7P0=gMg@3MgMd0dLc>
0;JZ[@80S7Uh00H0I4a6058k<`1@?CD0D3de05=1>P1D@SX20590>00504lm=P1=?SH0CChf04e0=`1>
@3P00P1B@ST01P1HAch0G4]305M8@01GB400CD0h04Pj<`80BcXb00H0E3hc05e2=01H?c80F3lb04`i
;`15=Bd204@e;@0504Hf;P15=Bd0ACD]03l`;00i;2/00P0k;b`01P11<bh0@30[03PX9@0h:2D0=2<Q
03DT7`80=B<N00H0<AhM02dK6P0Z6QD0:QXE02LI4P0T610201lF3P0501`D300L4``071<<01lE3P0S
61000P0W6A801P0Y6Q<0:AXB02DH400U610081@=01`A2P<06@h:00D0714;028E3@0R5@d0:QTA02/I
4@0202DG3`0501lC300L4@`06Q0;01X@2`0J4@X00P0J4PX01P0J4Pd0614=01D=300E3@`040T900/7
1`<02@H600D030T8014=2P0A3@X061<?028I500202/L5`05038O6@18=Bd0Lf=M07=SG@2RVIH00P39
aL@0103Ogmh0hn?S0=oPg`3Oh=l20=kNgP80g]oN5`3Ogmh01@3Pgml0i>?R0>OWiP3WinH0f=SG02X0
oooo6`3gmoL01@3Nc]H0c[g>0<jmcP1cBT80HdY200@0Je9:0P1J@ST01@1SBT80He9:06=BBP1B@ST0
HdY20080LeYB0P1kHeX207=JDP80He9:0P1J@ST00`1[DTX0LdXi058i<@02058i<@0406=:@P1J@ST0
FT8i04Xa<@<0FT8i00D0@S4i048Y<@12:C40DT8i06=:@P0204Xa<@05048Y<@1B<BT0>BTQ03TY8@12
:C401@0i:B42034Q8@05034Q600a8B40<B4Q03TY8@0a8B400P0i:B401P0a8B40>BTQ03TY8@0i:B40
<B4H058a:@80:APH100a8AP2048Y8@<0<B4H00<0:APH03TY8@0i:B400`0a8AP00`0a8B40:APH02TH
600202TH60<0610@00H0:APH034Q8@0i:B40>BTQ034Q8@1B>C42048Y8@03058a:@24DT80moOg02P0
moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Og`0A0=oOgP060=oPg`3Ph=l0g]kN0=kN
gP3IeML0a;Vm0P2KQhL01P1_E4l0Echf058n=P1B?SH0Dd8j05A2>P80DT0i00D0CSde04Pj<P18>S80
ACTa04Xn=P0205E5?@0605a;@`1NCD@0F4U105Q9@@1>@SX0ASXb0P15=Bd01P1;=R/0DCLZ04`c9`1<
<bL0@BhU03d]9@80@30Y00D0@S8Z040a:P10<BX0>B/Y038V:002034W:00603D[9`0f:BD0<b@R03<T
8P0a81h0<AhJ0P0^6aT01P0X61X08aHH020F4`0P5Q<07aH@01dF3`806a<=0`0H40X01P0J4``07A@>
01dE3`0M5@l07QD?01dE3`8071<=00H06A0:01D=200C2PP04`X801<;200G3`T201dC2`0602<F3P0S
5@h07A8<01dB300G3PT04P/80P0A2PL01@0C30P05@l901D?2@0E3``050d=00804@/;00H03@P800T6
1P091PH02@H600d9200C30X201PA3@06020G4@0[7QL0=bDN03LU7P16<BX0J5MA0P2RV9D00`3@c/d0
gmoO0=oOg`020=oOg`80gmoN0P3Ng]h20=kOgQL0gmoN00D0h=oN0>CShP3WinH0inOV0=SHe`0Z0?oo
o`030?O_k`3gmoL0moOg01T0moOg0P3Nc]H01024JeX0HdY205Y2>@1J@ST206]BBP80He9:00D0HdY2
06=BBP1SDTX0HdY207]SFP0206=BBP80HdY20`1kHeX01@2<Lf/0HdY206=:@P1B>C40Hd8a00<0DS4Y
0`1J@ST01@1B<BT0HdY206=:@P1B>C40FT8i0080@S4i00H0DT8i04Xa<@12:B40@RTQ03TY8@12:C43
034Q8@0304Xa<@0i:C40>BTa00@0<B4Q100Y61P303TY8@03034Q600Y61P0>BTQ0080>BTQ00D0<B4H
03TY8@0i:B40<B4Q02TH600203TY8@0602TH600i:B40<B4H034Q600Y61P0<B4Q0P0Y61P00`0Q4100
:APH02TH600201P@4080:APH0P0H4102024@400602TH600a8B40<B4Q034Q8@1J@ST0@S4i0P1B<BT0
101cBT80knOW0>oWi`3_inLW0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Pgml04@3O
gmh01P3Ogml0gn3O0=oOg`3Ogml0g]gN0=3:b`80ZY^I00H0OFIP05m8@01C?cL0Dclg0550>01C@CX2
0590>00504hm=@1;>c<0Bc/c04Xl=01=@3P00P1BACd01P1HBD40FDQ005A4?01DA3`0Bcde04<e;@80
@30X00H0@RlV04@^900o:R00?bXP03LU7@0h9al203d^9P0503l_:00k:bL0>b/W03DV9P0`8bD00P0^
8R401P0^8Qh0;R4N02dN7`0]7Ql0:a/M02LG5`808A<C00H0710B01T?4@0I4A006A4@01TC400I4Pl2
01H?30<050`900H05Pl<01L@3@0F3P/05Ph;01D>2`0F3``201H?2`0601@<2@0B2PL04PX9018:2@0D
3@/0614;0P0L4`d01P0M4`h0714=01L>2P0G3PX040X700X61@8020D400D02@H400/81@0;20D02`P7
00X71`0200T61P0600T61`0<2@T040`;010<2`0D3P/05`l;0P0H40`01P0L4@`09aL@044^9`11;RL0
KEYE09fAS@80al;000D0gmoN0>?Th`3Si><0gmoO0=kNg@040=kNgP80g]oN5`3Ogmh01@3Pgmh0i>?R
0>OWiP3WinH0f=SG02X0oooo7P3gmoL01P2DNg<0Q6]J06=:@P1SBT80FT8i06]BBP80FT8i00D0HdY2
0592>@1B@ST0Je9:0592>@0206=BBP0607]SFP1[DTX0HdY206=:@P1J@ST0Je9:0P1B>C40101SBT80
DSTa058a:@1B<BT2048Y8@80FT8i00D0DS4Y04Xa<@1:<C40DS4Y04Xa<@02034Q8@06048Y8@0a8B40
@RTa048Y<@1B<BT0<B4Q0P0i:B401P0Y61P0<B4Q034Q8@0a8B40@RTQ034Q8@D0:APH00H0<B4Q02TH
600Y61P0:APH03TY8@0a8B4302TH60@0<B4Q00@0>BTQ024@400Q4100<B4Q100Y61P00`0H4100:APH
02TH600701P@4006024@400a8B40<B4Q034Q8@0a8AP0>BTQ0P0Y61P0100i:B40@R4H09a[DP2LJe82
0>oWibT0moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3Og`0A0=oOgP060=oOg`3Oh=l0
gmoO0=oOg`3NgMh0d<[;0P2ZViT01P1mIV00GdQ005<o=`1C?cL0DD0h05=1>P80DT0h00D0CSde04/k
<`1;>c<0BS`d04e0>0020595?@0605Q9@@1IB400E4@l05A4?01;?CD0@cD]0P10<2P01P12;bH0A2hT
03lZ800o:R00=bDM03PW7`80?BhV00D0?blX03/[9`0k:bL0=BHV030S9@0202hR8@0602hR7P0^8Ah0
;AhO02dN7`0[6ad09aLG0P0Q4a<01P0L41806@lA01TA400I4A006A<@01TB3`805Pl<0`0D30T01P0F
3``05a0=01H>2`0F3P/05@h;01H?30805Pl;00H050`9018:1`0B2PT04PX901@=2`0H4@/201`C3@06
01dC3P0L4@d05`h:01L>2P0@2PL02PH50P081@@01@091P@02`P500/81@0;20L02PL700802@H600H0
2@H700`92@0@30/040`;01@>2`0G3`/201P@300601`A300W5a00@BhW044^9`1]FUD0WI6=0P37`/00
1@3Ogmh0hnCS0>?Th`3Ogml0g]kM00@0g]kN0P3NgmhG0=oOgP050>3OgP3Thn80inOV0>OWiP3Hf=L0
:P3ooolN0?Ogm`0609AkL`24JeX0HdY206=:@P1J@ST0Je9:0P1J@ST01@1SBT80DT8i0592>@1[DTX0
DT8i0080He9:00H0Nf=J06]BBP1SBT80HdY205Y2>@1[DTX2058i<@0406=:@P1B>C40DS4Y058a:@80
@RTQ0P1J@ST01@1B<BT0BS4a04Xa<@1B<BT0BS4a0080<B4Q00H0@RTQ034Q8@12:C40@RTa058a:@0a
8B4203TY8@0602TH600a8B40<B4Q034Q8@12:B40<B4Q1@0Y61P01P0a8B40:APH02TH600Y61P0>BTQ
034Q8@<0:APH100a8B40100i:B408A0@024@400a8B4402TH600301P@400Y61P0:APH00L0610@00H0
8A0@034Q8@0a8B40<B4Q034Q600i:B4202TH600403TY8@128AP0W6]B09a[DP80knOW:@3gmoLP0?oo
o`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h=oO01<0gmoN0P3Ph=l01P3Qh^40fMOF0;bd/@2l];40
U8J0079PF080FdQ000D0DD0g050o=`1??SH0Cchf04dl=00204hn=P060511>@1@@S/0Cd<l04m3?01B
ACd0E4@l0P1@?cP01P18>340@C4Z03h/9@0n;2D0?B/S03/Y8@80=BDM00D0;b0H038S6`0i:B40>BTQ
03TZ900203@U8P06030Q800_81l0;1dJ02`M6P0X6AD09QLF0P0U5QT01P0Q5AT0718D01L?3`0G3`l0
4`/<01<;2`8050d=00@05Pl?01H?3P0D30`050`<0`0A2@T201<<2`804@T900H04`X901L=300F3@/0
5Pd;01081`0>1PH2014:2@0601H?300K4`h071D?01`E3`0J4Pl05Ph=0P0A2PT01@0:1@D010820041
0@010@400P41008010<200H01@@400H51@061@D01PD500T71`0A30`201TA400601dD3`0N50d07A<=
01dC3@0P4@/0;AL?0P1D?C@01@2DQ7h0bL;00=gKfP3MfmX0gmoN0080gn3O00<0gmoN0=kNgP3Ng]h0
0`3Ng]h20=kOgQL0gmoN00D0h=oN0>CShP3WinH0inOV0=SHe`0Z0?oooah0moOg00H0imkW0:F4N`24
JeX0Q6]J06=:@P1[DTX206=:@P0306]BBP1SDTX0He9:00@0HdY200H0DT8i06=:@P1[DTX0Je9:06=:
@P1B@ST2058a:@0606=:@P1B>C40DS4Y058a:@0i:B40@RTQ0`1:<C42048Y8@06048Y<@1:<C40DSU:
058iBP0a8B40@S4i0P12:B400`0a8B40>BTQ034Q8@03034Q8@<0>BTQ100Y61P2034Q8@@0:APH0P0i
:B4402TH60<0<B4Q00<0:APH048Y<@12:C400P0a8B4202TH6004024@400H41008A0@024@40@0610@
00D0:APH034Q8@0a8B40>BTa034Q8@0202TH6006048Y<@0a8B40>BTQ03TY8@1B<BT0Q5920P2]W8`0
0`3_inL0moOg0?Ogm`0X0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l04`3Ogmh2
0=oPg`060>7Qh@3MgM`0d<k<0=3>c02h/Jd0U8N20P1`GeP01@1IASh0CC`d04Xi<@1:>C40C3/c0080
Cclg00H0D48j04m3>`1>@c/0CT<k0554?01EACd20591>`0604/i=013<2/0?BTS03dY8`0k9b00>2LP
0P0a91`202/O5`80<28J00D0<28L02`O6P0/7aX0:ahI02/L600202LH500601lB3`0J3`h06@hA01T>
4@0I3a805`lA0P0E3Pl01P0C30`04P/;014:2P0A2PX04`/<01@<3@804P/;0`0@20P01P0B2P/04@X:
0107200@1`P05@X901l@3@8070l<00H03`L600P4100>20P03PP801L?3@0L50l201dE3`0501TB3`0C
30`02`H700/61`040P800`0000001@0200001P8200H20P0:1PH03@X900803PX:00H040`<01D?3`0M
51807A@B02HH4`0/6a<202lN500603PQ5P1=;b00MUU;07IIB`2_WYL0fMGC0P3Shn<00`3Oh=l0g]kM
0=kNg@020=kNg@@0g]kN6@3Ogmh01@3Pgmh0i>?R0>OWiP3WinH0f=SG02X0oooo7`3gmoL01@3>]Kd0
U7]c09AkL`1kHe80FT8i0080Je9:00D0HdY206=BBP1SDTX0He9:07]SFP0206=BBP0606]BBP1cFU80
LeYB07=JDP1SBTX0DT8i0P1B<BT0101[DTX0DSTa048Y8@12:B4203TY8@80@RTQ00<0BS4a03TY8@0i
:B400P12:B420592>@0602TH601:<C40:APH02TH600i:B40<B4Q0P0Y61P0100a8B40:APH02TH600Y
61P2034Q8@D0:APH0P0a8B4202TH6006034Q8@1B<BT0<B4Q034Q8@0H4100:APH0`0a8B401@0i:B40
:APH02TH600a8B40:APH00H0610@00D08A0@02TH600Y61P0<B4Q048Y<@04034Q8@80>BTQ00H0DS4Y
048Y8@1S@S40Hd8a07=:>@2ULeX20>ONib/0moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R
0>3Pg`0C0=oOgP<0gmoO0`3Ogmh01P3Ee=80^K6^0963O@2APgd0KUaD05E3>P80BcTa00D0BcXb04`m
=P1<?CH0C40h04e2>P0204m4?00605A7?`1IB440EdE005M5@01@?SX0AS<_0P0o:R@01P0l:200>BTQ
038U7`0b9Al0:AlI02HK5P809aXE00D09a/D02HK500V6a@09Q/D02HI4`02028E4@0501T?3@0D30/0
50`;01@<2`0E3@d00`0F3`l01P0E3Ph04P/;00l8200?20P040P8018:2P804@T:0`0?1`L201492@80
4@P800H060`902<B3P0R4`l08Q<?01@=3@0>2`d201@@4@0601`E4`0N5A807A<@01dC400H40h040X:
0P081@D01@030P800`8100D30P050`802@@300803PL600H04``;01PA400K51<06a@C01dE500N5Q@2
02<G5@0602hL5P0i8AT0A2TM04@Y7@1G>BT0MUE30P2MP7401@33]:`0fmWG0>7RhP3Qh^80gn3O00@0
g]kM103Ng]hI0=oOgP050>3OgP3Thn80inOV0>OWiP3Hf=L0:P3ooolP0?Ogm`80aZf]00D0S7=[06]B
BP1SBT80HdY206]BBP0205Y2>@0606=BBP1J@ST0He9:06=BBP1JDU80He9:0P1SBT801P1J@ST0DT8i
03TY8@0i:B40Je9:058a:@80BS4a00@0<B4Q03TY8@0a8B40<B4Q0`12:B401@0a8B40<B4H034Q600a
8AP0:APH00<0<B4Q00H0:APH034Q8@0Y61P0:APH034Q8@0Y61P2034Q8@0302TH600a8B40:APH00D0
:APH00@0<B4Q02TH600Y61P0<B4Q1012<CT302TH60@0<B4Q00D0>BTa034Q8@0i:B40>BTQ03TY<@04
03TY8@80<B4Q00H0@RTa034Q600Y61P0:APH034Q8@1:<C43048Y8@<0Hd8a00<0W6]B09AcJ`3gmoL0
;03gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O01<0gmoN0`3Ogml30=oOgP060=GD
dP2i/Jh0TH=m0963O@1^G5@0ED<j0P1;>C401@1;>S80C3df04`m=P1<@3P0CD8j0080Cd@l00H0E4Lo
05U8@@1GAD00EdE0050n>P16<bl203lZ900603`X800i:B40<RDO038U7`0Y7aT09Q/F0P0W6QD01@0W
6a@09Q/D02HK500V6a@09QTC00808QDA00D06@l=01@<2`0D30/050`;01D=3@0301H?3`0601D>3P0B
2`/03`P800l8200@20P04PX:0P0A2@X300l71`804@T90P0A20P01P0H30T08a8>028C3`0R4`l050d=
00h;3@80510A00H071DC01hE4P0M4a007A<@01P@3P0@2PX200P51@0500<20P030P401@<200D30P09
10<00P0>1`H01P0C30/0614@01/D4`0K51<07ADD01hF50808aLE00H0;Q`F03TQ6@14:Ad0A2TM05Li
:@1fED<209f0L@050<>d[03KfML0hN;R0>7RhP3Oh=l0103Ng]d40=kNgQT0gmoN00D0h=oN0>CShP3W
inH0inOV0=SHe`0Z0?ooob00moOg0P36[Jd01@2<Lf/0Je9:06=:@P1SBT80Je9:0080FT8i00H0He9:
05Y2>@1SDTX0He9:05YBDP1SDTX206=:@P0605Y2>@1B@ST0>BTQ03TY8@1[DTX0DS4Y0P1:<C40100a
8B40>BTQ034Q8@0a8B43048Y8@05034Q8@0a8AP0<B4H034Q600Y61P00`0a8B401P0Y61P0<B4Q02TH
600Y61P0<B4Q02TH6080<B4Q00<0:APH034Q8@0Y61P01@0Y61P0100a8B40:APH02TH600a8B44048a
>@<0:APH100a8B401@0i:C40<B4Q03TY8@0i:B40>BTa00@0>BTQ0P0a8B401P12:C40<B4H02TH600Y
61P0<B4Q04Xa<@<0@RTQ0`1S@S400`2LJe80U7=[0?Ogm`0/0?Ogmb00oooo000N0?ooo`050=SHe`3W
inH0inOV0>CShP3Ph=l05P3Ogmh01@3Oh=l0h^;R0>;RhP3Oh=l0d]3>0080^;2/00D0TX=m06eID@1G
A3/0Ed@k04dn=P0204Tl=00604Pk<`1<?cL0DdDm05=5?@1IBD40FdY30P1KBD801P1EA3l0BcXd040a
:@10<BT0?BdU03`]9@80=RPS00D0;1lN02@I6@0Q5Q@08AHD028G4P0202@I4P0602@H4P0Q5Q807A@A
01dD4@0J4Pl0614=0P0G40d01P0G40h05a0?01D>3P0E3Ph04`/<01082@<03PH60`0?1`L300d51@06
00h61P0@2@L050/801@;200I3PX07Q4=0P0Q5AD01P0R7240928X02LU:00W9BP0:B8S02DK6`807Q8C
00H05P`<01092@0<1`L030L700`81`0?2`P2018=200501D>2@0F3P/05Ph;01P@3P0O5Q@00P0Y7AX0
1P0_8Qd0;R4L02hO6P0^7aX0=20I040U6`80DS4T00H0LDm009^0LP2o[ZD0_jjU0=C=b03Mg=X20=oP
g`030=kOgP3Ng]d0g]kM0080g]kM103Ng]hI0=oOgP050>3OgP3Thn80inOV0>OWiP3Hf=L0:P3ooolR
0?Ogm`050<jmcP2DLf/0LeYB07=JDP1SDTX00P1[DTX00`1J@ST0He9:07=JDP0307=JDP80Nf=J00H0
LeYB06=BBP1B@ST0DT8i06=:@P1J@ST2048Y8@05048Y<@0a8B40<B4Q034Q8@0Y61P00P12:B42034Q
8@80<B4H00H0>BTQ02TH600i:B40>BTQ02TH600a8B4802TH6080>BTQ00<0:APH01P@400H41000P0Y
61P203TY8@80<B4Q0P1B@ST01P1JDV<0HdY205YBDP1JDU80<B4Q048Y<@80<B4Q00<0:APH034Q8@0a
8B400P0a8B40100i:B40@RTa048Y<@0i:B43034Q8@050592>@1J@ST0FT8i03TY8@1B>C400P1S@S40
1@1B<BT0LdXi08aJBP2<FTX0S7=S02h0moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0i>?R0>3P
g`0F0=oOgP030=oOg`3Oh=l0gn3O0080gn3O0P3Edm801@2i[Z/0TX1j075NEP1aGUH0FDY20080C3hf
00H0BCXa04dm=@1D@c/0E4<k05Q7?`1JBD4205]:@`0605Y9@@1A@S/0ASTa04Hi<@12=2/0@C4X0P0k
:RH01@0a8B809QXL01lF5P0O5QH07aHB00808aLB00H08ADA01/B4@0I4Q006A8@01/D400M5Pl201`E
400601XC3`0G3`h04`/<01<;300@20T03PH70P0>1PH0100=1@H03@D500d41@0=10D400`4100500l6
1@0D30P050`801P@2`0K4a400P0S6al01P0_:S@0>CDo03di?@0m>Cd0?3<d03DX:@80:Q/M00H081<D
01/A4@0M51807A@B020G500R6A@2028I4P05020H400N5Q007QH@01hE4P0U6QL00P0b9Al01P0l;2D0
?B`T03/X800k:200?RHN04`^8`80J4Dh00D0Sg1T0;VXX@3Fd/l0e];?0=oNg@080=kNg@<0g]kN00<0
gmkN0=oOgP3Ogmh05`3Ogmh01@3Pgmh0i>?R0>OWiP3WinH0f=SG02X0oooo8`3gmoL0102<Lg/0U7]c
09AkL`1cFU8206]BBP0506=BBP1J@ST0HdY206=:@P1SDTX0101cFU801@1SBTX0DT8i0592>@1cFU80
FT8i00<0DS4Y00@0@RTQ02TH600Y61P0<B4Q0`0i:B401@0a8B40:APH02TH600a8AP0:APH0080>BTQ
0P0a8B42024@4080<B4Q0P0Y61P0100a8B40:APH034Q8@0a8B4302TH600601P@400Y61P0:APH02TH
601B>DX0@S4i0P0i:CT00`1JDU80Nf=J048Y<@02048Y<@<0@S4i00<0DT8i048Y<@0i:B400P0i:B40
100a8B40>BTQ03TY8@1B<BT205Xa:@0605Y2>@1:<C40DS4Y058a:@1B>C40DS4Y0`1S@S401024DT80
W6]B09a[DP3gknl^0?Ogmb00oooo000N0?ooo`050=SHe`3WinH0inOV0>CShP3Ph=l05P3Ogmh00`3O
gml0gn3O0=oPg`020=oPg`80eM?B00D0^Jj[09:0NP1aGUH0LEiF05U:@P0204`n=P0604Tj<@1=?CD0
E4<k05A3>`1HAcl0FTU10P1KBT<01P1JBD40DD8k04Hi<@16>C40@S@[044a:080>bXV00D0<B4R02HJ
700O5QH07aHF01lF4P0202<G4P06024E4@0K4Q406A8@01TB400K51007AH?0P0L5A001P0J4`l05`l>
01<;300C2``040P900h61`803PH600@03@D600d51@0=10D03@@5100<10@01@0?1PD050`801@<200H
40/06a<A00808a/O00H0;bXd03Te?`0m>Cd0?CTm03`c=00e:2T202XK7@06020C500K4A407A@B01dD
4P0P5a@08QTD0P0R6A801@0P61007QH@01hF400N5A809AXG0080<RDO00H0?2`U03d/900k:200>bPP
03hV7P1<;R<206Q5>00508m`I02iZ:40e];?0=KBc`3Og]d0203Ng]d30=kNgP030=oNgP3Ogmh0gmoN
01L0gmoN00D0h=oN0>CShP3WinH0inOV0=SHe`0Z0?ooob<0moOg00@0S7=k09AkL`2DNg<0LeYB0P1[
DTX01@1SDTX0FT8i06=:@P1SBT80He9:00@0LeYB00D0HdY:0592>@1B@ST0LeYB05Y2>@03058a:@04
048Y8@0Y61P0:APH034Q8@<0>BTQ00D0<B4Q02TH600Y61P0<B4H02TH600203TY8@80<B4Q0P0Q4102
034Q8@80:APH00@0<B4Q02TH600a8B40<B4Q0`0Y61P01P0H4100:APH02TH600Y61P0DSU:048a>@80
>BTi00<0FU9B07]SFP12:C400P12:C43048a>@030592>@12:C40>BTQ0080>BTQ00@0<B4Q03TY8@0i
:B40DS4Y0P1J<BT01P1J@ST0BS4a058a:@1B<BT0DSTa058a:@<0Hd8a00@0Q59209a[DP2LJe80mno_
;P3gmoLP0?ooo`007P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O01T0gmoN00H0gn3O0>7RhP3Ph=l0
h>3O0=C@cP2l/Jh209N7P@05079OF01KB400FdQ00591>01??SD00P1>?CD01P1@@3P0DdDm05U:@P1I
BT80GDe405Y:@P80DT<j00H0C3`a04Ld:@11;BD0@BdU03LV8`0/7ad2028I5`0501lG4`0N5A807QDB
01/B400G3`h00P0F3`d01P0I4`d071D?01/D400K5100614?01@<308040P90P0>1PL200l7200400l7
1`0=1@D030@500`41@<03@D500H030<300`30P0@1`D040L501P@3@0R7A`202`V:`0603H]>010=D00
BSi104Xn@@1>@Cd0BSXg0P11<2h01P0f9RH0<b@S03LY9P0g:BH0>R`V03LY8P80;b<J00D09adD02<J
4`0S6Q<09a/F02hQ6`0203PX8@0603l_9`15<b/0B38Y04Pb:@1?<BH0ID@h0P2<KfD01P2eXI/0dLS6
0=kNgP3Ng]h0h>;R0=kOgPL0g]kM0`3Ng]h00`3Og]h0gmoN0=oOgP0G0=oOgP050>3OgP3Thn80inOV
0>OWiP3Hf=L0:P3ooolS0?Ogm`040?ooo`2<Lg/0S7=k09AcJ`80Nf=J00H0LeYB06=BBP1J@ST0FT8i
06=:@P1SDTX206=JH`0607]SFP1SDTX0LeYB07=JDP1SBT80Hd8a0P1B@ST01@1B>C40@RTQ03TY8@0i
:B40:APH0080<B4Q00<0>BTQ02TH600a8AP00P0a8AP01@0i:B40<B4Q034Q8@0i:B40:APH0080<B4Q
00@0:APH034Q8@0a8B40<B4Q100Y61P00`0a8B40:APH02TH600402TH600301P@401JDU80DSU:0080
DSU:00D0@S4i07]SFP1kHeX0Jf=[07]SFP0205Y:FP80HdY:0P1cFU80101SBTX0FT8i058a:@1B<BT3
03TY8@@0DSTa00H0FT8i06]BBP1cBST0LdXi08AB@P24He820?O_kbl0moOg803oool001h0oooo00D0
f=SG0>OWiP3WinH0i>?R0>3Pg`0I0=oOgP80gmoO0P3Ph=l01@3Rh^40f]SF0;bb[P2l/Zh0Th1j0080
MEmF00H0HTe405A1>01<>c80C3/b04/l=01?@SX205M:@@0605m?A`1QD4L0GD]305e;@`1F@cP0CcX]
0P17<RH01@0m:b<0<R@N02TO6@0Y7aT091`G00808QTG00H07QHE01XC4@0I4@h06A4>01XB300J4`d2
01TB3`0601H?3P0B2P/03`L800l7200>1PL03`L80P0@20T0100?1`L030@500d51@0=1@D300l72006
00d41@0:0@4030<200`30P0F3`h09R4Q0P0`:Rd01P0d:C40?Bhd04`k>@1<>cT0E4<l0591>@80BCTd
00H0@C4^040_;014=2l0A3@_04De;P0n;RH2038T7@0502PL5@0V6a<09Q/C02hP600f9Qh00P0k:B00
1P11;RD0CCP]05To=01I?c@0JDPl08IVG080/IbG00H0dl[90=kLf`3Ng]h0g]kN0=kOgP3Ng]h70=kN
g@80g]kN00<0gmkN0=oOgP3Ogmh0603Ogmh01@3Pgmh0i>?R0>OWiP3WinH0f=SG02X0oooo9P3gmoL0
1@2LS9`0Q6]J08A[FP1[DTX0He9:0080Je9:00H0FT8i06=:@P1[DTX0Je9:07=JDP1[Hf/207][N`06
07]SFP1J@ST0FT8i05Y2>@1S@S40DSTa0P1B<BT3034Q8@0603TY8@12:B40<B4H034Q600a8B40<B4H
0P0Y61P00`0i:B40:APH02TH600302TH6080<B4Q100Y61P3034Q8@0601P@400Y61P0>BTQ03TY8@0a
8B40:APH0P0i:C401P1B>DX0HdY205YBDP1JDU80DT8i03TY<@80<B4Q00@0>BTQ04Xa<@1B>C40DSTa
1@1J@ST206]BBP@0HdY20P1S@S4207=:@P0309a[DP2DNg<0moOg0300moOg803oool001h0oooo00D0
f=SG0>OWiP3WinH0i>?R0>3Pg`0J0=oOgP050=kOgP3Ph=l0h>3O0>?Ti03Rh^800P3Dd<h01@2i[ZX0
UH9j09F2NP1dFe00GdLl0080ET<i00H0DD8j0593>`1HBD40F4U1061@A`1SDTT2069@A`0605m<@P1I
ACX0CSX`04hj<010;bH0=RLO0P0b9Ad01@0b9Al0<RLR038W8P0`9R80:R4M00809A`F00H08AL@01hD
3P0K4`l06a<?01L@3P0D3@`2014:2`0601492P0@20T03`L700l71`0<10@02`<30P0=1@L01@0A2@`0
4PX=018:3@0@1`P03@D400803`H300H05@h;01lH5`0W82009b0P02lT9@0j:bX204Le<00604Th<010
<BX0=RTT03HY900c9R40=2LQ0P0g:R<01@0f:B80<2<M02TL5`0Y71L09ATB0080:A/C00H0<R8I03XX
7P0o:b00?b/P04Ta901L?bl2079BA00608a]I02ZTXl0bKfl0<Vm_03Mf]X0hN7Q0P3Og]h90=kNg@80
g]kN00<0gmkN0=oOgP3Ogmh0603Ogmh01@3Pgmh0i>?R0>OWiP3WinH0f=SG02X0oooo:@3gmoL01P2<
He80LeYB07]SFP1kHeX0HdY206]BBP80LeYB101kHeX00`2<Lf/0Nf=J058i<@05058i<@0504Xa<@1S
BT80HdY203TY8@1B@ST00P1:<C401P12:B40@RTa03TY8@0i:B40:APH034Q8@80:APH0P0a8B4202TH
6005034Q8@0Y61P0>BTQ03TY8@0i:C40100a8B4203TY8@06048a>@0a8B40@RTa048Y<@1B@ST0>BTi
0P1SBT800`1SBTX0<B4Q03TY8@0203TY8@05048Y<@0i:B40>BTQ03TY8@0a8B400P1:<C401@12:B40
DT8i0592>@1B>C40DS4Y0080Hd8a00D0Q59209a[DP2DFU80U5YB0=k>eP0b0?Ogmb00oooo000N0?oo
o`050=SHe`3WinH0inOV0>CShP3Ph=l06P3Ogmh01@3Ngmh0h>3O0>3Pg`3Si>@0h^;R0080e=3>00D0
^JjZ09F2NP2EPWX0M5]@05m7?00205I3>@060552>P1B@c/0F4U105Q9@@1PD4L0He990P1RD4L01P1O
C480FDDj04hj<01>>S00@2lV03HW7`80<RDM00D0<RDO038W8P0b9b80<2HR02XQ7@0202DL5P06024G
400N50h06a<?01/C3`0G40h050d<0P0A2P/01P0A2@X040P900l71`0?1`L030@400/30`803@D700D0
4@T<018:3@0B2Pd040L800d5100200l60`0601D>2`0O61L09b0P02LP800_92D0>R/Z0P17=C001P19
>300@34Z03HY900f:B@0<bHQ03@W8@80=bXS00D0=RTR030S7@0Y71L0:A`G02DI4P0202TK4`06038R
6@0j:1h0?b/P03l[8019<B@0G3l_0P1bDT@01P2<KF@0ZY:?0<Vm_039_K`0gM[J0>7Qh@80gmkN2@3N
g]d20=kNgP030=oNgP3Ogmh0gmoN01P0gmoN00D0h=oN0>CShP3WinH0inOV0=SHe`0Z0?ooobT0moOg
00H0S6=B07=JDP1kHeX0Nf=J06=:@P1[DTX207=JDP@0Nf=J00<0S7=[07]SFP1B>C401@1B>C401@1:
<C40HdY206=:@P0i:B40DT8i0080BS4a00H0@RTQ048Y<@0i:B40>BTQ02TH600a8B4202TH6080<B4Q
0P0Y61P01@0a8B40:APH03TY8@0i:B40>BTa00@0<B4Q0P0i:B401P12<CT0<B4Q048Y<@12:C40DT8i
03TY>@80HdY200<0HdY:034Q8@0i:B400P0i:B401@12:C40>BTQ03TY8@0i:B40<B4Q0080BS4a00D0
@RTQ0592>@1B@ST0DSTa058a:@0206=2<@0508AB@P2LJe80U5YB09AJDP3Nc]H0<P3gmoLP0?ooo`00
7P3oool01@3Hf=L0inOV0>OWiP3Thn80h>3O00<0gmoO603Ogmh20=oOg`050>3Pg`3Ph>00h>3O0>3P
g`3Ed]400P2fZJ<01P2?Mf`0M5]?06EAAP1UDDH0FDPo05=2>@80ED@l00H0GDa406=BB@1VE4`0IUA<
06MFC@1TDdX205Q7?P0504Pg;`0m;B@0>BXR03TZ8P0l;2D00P0o<2T01P0n<2X0>2dV038V7`0b9Ql0
;B0H02PL5@808aTC00H07ADA01H@3P0B2``04P/<01492`0@20T200h6200500d41P0=1@H04@P;0148
2`0F3Q800P0G3a<01P0D30h05@`:01T?2P0I3`X06A0<01P@3P807aDD00H0;B8N03`^9`13<R/0@c8[
03d/9`0^8Ad202DJ5P0502DK5@0X7AH0:AhF02TN5P0W7AH00`0U6QH01@0[7AH0<R4I038Q6@0h9ah0
?b/Q0080BC4S00H0G3h/07ID@02CLf@0Tg=T0:nHT`36^K`20=G@dP030=gLg03Ogmh0g]kM00T0g]kM
00@0g]kN0=oNgP3Og]h0gmkN6P3Ogmh01@3Pgmh0i>?R0>OWiP3WinH0f=SG02X0oooo:@3gmoL00`2e
YJd0S7=S06]BBP0306]BBP80He9:00H0LeYB07]SFP2<Lf/0S7=[09B4Q02<Lg/206]BBP0405Xa:@1B
>C40DSTa058i<@<0DS4Y00<0DSTa05Y2>@1J@ST00P1J@ST01@12:B40@RTa048Y<@0i:C40DS4Y00@0
<B4Q0P0i:B401@12:C40<B4Q034Q8@0a8B40DSU:0080>BTQ00H0@S4i048Y<@0i:B40>BTQ048Y<@1J
DU84048a>@80>BTa00H0>BTQ0592>@1B@ST0DT8i04Xa<@1J@ST20592>@05058i<@1B<BT0HdY206=:
@P1S@S400P1B<BT01P1S@S40LdXi07=:>@1cBST0S5Y:08ASDP80g/kF<`3gmoLP0?ooo`007P3oool0
1@3Hf=L0inOV0>OWiP3Thn80h>3O00H0gmoO5`3Ogmh01@3Ngmh0gmoO0>7ShP3Qhn80gmoN0080cl[6
00H0]JRQ09F3N@1eHUH0MF9F05a:?P1>?C<204hm=00605M6?@1RD4P0JeU@06]ID01_GeH0KEmG0P1T
ETd01@1GASh0BCP_03l^9`0o;RL0?2/U00<0?B`W00D0>bXT03/Z8P0k:R80>RXR03LY8@0202lU7P06
02@M600I4Q404@X;014:2`0>1`P03`P:0P0C2`l0100E31405PdA01XA500J4A@301lF5`0601`B500P
5AD0:1`H02PL600V6QH07A8B0P0Q5aH01P0f:B@0ACD]04Hd;P16=2h0?B`W03<T8080;R4K00H0;b8K
034S6`0`8QX0<28J02hQ6P0_8Q`203HW8@0503l_9@14<bP0A3<X04@b:@1:=2P00P1L?Rd01P1iEd<0
Vge]0;VSV@2iXiT0bknm0=KAd`80fm[K00<0gMgM0=kNg@3Ng]d02@3Ng]d30=oNgQ/0gmoN00D0h=oN
0>CShP3WinH0inOV0=SHe`0Z0?ooobX0moOg00D0e/KN08acH`2<Lf<0Je9:05Y2>@0206=:@P0306]B
BP1kHeX0S7=[0080S7=[00D0S7]c08acJ`2<Lf/0Nf=J0592>@02058i<@03058a:@1:<C40BS4a0080
DS4Y0`1SBT801@1J@ST0DT8i0592>@1cFU80<B4Q0080@RTQ00H0:APH04Xa<@12<CT0@S4i048Y<@12
<CT204XiBP<0DT8i00H0@S4i07]cN`1[DTX0Je9:06=JH`0i:C4206=:@P0407]SFP1JDU80HdY:06=:
BPD0HdY20`1J@ST206=:@P80Je9:00D0Nf=B06]BBP1[DTX0HdY208AB@P020:EcFP0308ASDP3gknl0
moOg03@0moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0hn?R0>3Pg`060=oOgaT0gmoN0P3Oh=l0
1@3Ogmh0gmkM0=oNg@3Dd/l0]jjX0080Sh5f00H0KeiC05]:@P1C@S/0Dd8k05I4?01OC4@206YGC`06
071OE`1`HUX0JeiG06]NE`1SEDd0ETLo0P19>C801@11<B/0?bh[03l^:`10;RX0@RhX0080A30Z00H0
AS@^048e;P0j<2X0>S0Z02lW900T7Ad201`E5`0401TA4`0L4aD081LL020G70808QPP0P0U6al01@0Z
81l0:R0P02XP800X7R40;b8U0080>BTV00H0=BDR02PK6`0/7al0;1lO044a;01??3D204/g<P0604@`
;012;RP0@blW04<_9`13;bH0@RlV0P0o;RD01@0o;RH0AC<Z04lk<01?>c00FD@f0080FD@e00H0Dcd`
05To<`1eED@0MEE409alJ`2oZZ020=G<b@050=cIf03Mfm/0gMgL0=gMg03NgMd02P3Ng]d20=oNgQd0
gmoN00D0h=oN0>?ShP3WinH0inOV0=SHe`0Z0?ooobd0moOg00H0U8BD08A[FP1cFU80LeYB06]BBP1k
HeX308akL`0509b<S02DQ8@0U8B408akL`2<Lf/00P1cDTX01@1kHeX0Q6]J08A[FP1SBT80FT8i0080
BR4H0P1SBT8207=JDP0605Y:FP1SBT80He9:06=BBP1J@ST0>BTi0P0a8B401@1[Hf/0HdY:05YBDP1J
DU80Nf=J0080Ng=k0P1JBUX205YBDP0607]SFP1[Hf/0HeYS06=JH`1cFU80He9:0P1[DTX0101kHe80
Le9:07=JDP1cFU8407=BBP0506]BBP1J@ST0Hd8a06=2<@1cBST00P1kHe801@2DHdX0LdY20:F4Q02U
Q8@0oooo03H0moOg803oool001h0oooo00D0f=SG0>OWiP3WinH0hn?R0>3Pg`060=oOgaT0gmoN0P3O
h=l01@3Ogmh0gmkM0=oNg@3Dd/l0]jjX0080Sh5f00H0KeiC05]:@P1C@S/0Dd8k05I4?01OC4@206YG
C`06071OE`1`HUX0JeiG06]NE`1SEDd0ETLo0P19>C801@11<B/0?bh[03l^:`10;RX0@RhX0080A30Z
00H0AS@^048e;P0j<2X0>S0Z02lW900T7Ad201`E5`0401TA4`0L4aD081LL020G70808QPP0P0U6al0
1@0Z81l0:R0P02XP800X7R40;b8U0080>BTV00H0=BDR02PK6`0/7al0;1lO044a;01??3D204/g<P06
04@`;012;RP0@blW04<_9`13;bH0@RlV0P0o;RD01@0o;RH0AC<Z04lk<01?>c00FD@f0080FD@e00H0
Dcd`05To<`1eED@0MEE409alJ`2oZZ020=G<b@050=cIf03Mfm/0gMgL0=gMg03NgMd02P3Ng]d20=oN
gQd0gmoN00D0h=oN0>?ShP3WinH0inOV0=SHe`0Z0?ooobd0moOg00H0U8BD08A[FP1cFU80LeYB06]B
BP1kHeX308akL`0509b<S02DQ8@0U8B408akL`2<Lf/00P1cDTX01@1kHeX0Q6]J08A[FP1SBT80FT8i
0080BR4H0P1SBT8207=JDP0605Y:FP1SBT80He9:06=BBP1J@ST0>BTi0P0a8B401@1[Hf/0HdY:05YB
DP1JDU80Nf=J0080Ng=k0P1JBUX205YBDP0607]SFP1[Hf/0HeYS06=JH`1cFU80He9:0P1[DTX0101k
He80Le9:07=JDP1cFU8407=BBP0506]BBP1J@ST0Hd8a06=2<@1cBST00P1kHe801@2DHdX0LdY20:F4
Q02UQ8@0oooo03H0moOg803oool001h0oooo00D0f=SH0>OWiP3WinH0hn?S0>3Pg`030=oPg`@0gmoO
603Ogmh20=kOgP050=oOg`3Rhn80h^?R0=oPg`3?c<T00P2f[jT01P2NTXh0R7Yg079QGP1bHEh0H4m8
05a9@@80H4i500H0IEA;06MHD01WFeH0Ie]F06IKF@1REU8205a=A`0505Q6@01FACl0ETDo05M6@01H
AT000P1E@cd01P1>?CT0ACTe03hg=@0n=cD0>cDg03/d>P80?3<i00H0?C<d03X_;P0e:2/0=BP[030S
:`0]8R`202hS:P0503<V9`0g:R`0=bX/03/_=@10<SP00P13<S401P0m:bH0=B@P03PW900h9b@0AcD^
054l=@80CcTc00H0C3@^04db:`1?<bT0Cc<Y050d:01>=2T204/e:`0504di;`1F@3D0I4Xk06A:>`1_
DCh00P1/C3T01P1O@C00J4do095iK@2ANFd0_J^Q0=G<a`80gmcK00<0h>3O0=oOgP3Ng]d02P3Ng]d2
0=oNg@030=oNgP3Ogmh0gmoN01d0gmoN00@0hn?R0>OWiP3WinH0f=SG:P3oool^0?Ogm`030=K6cP2D
Ng<0U7]c0080Nf=J0P1[DTX207=JDP80S7=k00D0Ng=k08akL`2<Lf/0S7=[08akL`0308acJ`0508ak
L`1kHeX0Nf=J06=:BP1[DTX00P1JDU801P1kHeX0Nf]k07]SFP1kHeX0S7]c05YBDP80HdY:00D0@RTa
05Y:FP1B>DX0DSU:06=:BP0205YBDP0307][N`1cFU80Je9:0080Je9:00D0HdY206]BBP1[DTX0LeYB
07]SDP0307=BBP0307=:@P1SBT80HdY20080LdXi0P1[DTX01@24DT80Q6=B08aJBP2<FTX0YG=J0080
Nf=B00<0LdXi0<je_@3gmoL0>03gmoLP0?ooo`007P3oool0103HfMP0inOV0>OWiP3Si><40=oPg`@0
gmoO6`3Ogmh20=oPg`060=kOgP3Lg=/0e]GD0=KEe03<a/L0^Znb0P2MShl01P1mKVP0IeM?05e<A01M
C4@0FdQ105a;A080GU9?00@0HEYL06MOH01^HEd0KV5M0`1aH5T01P1`HEX0KV5J06AGD@1TEe40ETQ5
04a0?`80B49200H0C4M<05E=EP1NDeT0GU=I061CD`1GBDD204Ph=`0503`]<@0g:S<0=RTa03HY<@0i
:Bd00P0n;S801P15=ch0AcTn04@c<@14<c40?b`U03dZ8P80@2dU00H0B3@/04hh;`1B=bh0DSL^05@e
;01F=2/205Pe:@0605Tg:01H>R/0ESd`05Hm<01H@3D0H4Hh0P1^CSd01@1lET<0O5I207aF@P1dDT40
PVYN0080[Z:K00@0e=3=0=oNg@3Og]d0gmkM303Ng]d0103Og]d0gmkN0=oNgP3Og]hO0=oOgP040>?S
hP3WinH0inOV0=SHebX0oooo<@3gmoL01P2eYJd0Jf=[07=JDP1cFU80Nf=J07=JDP80S7=[00<0U8B4
08akL`2<Lf/00P2<Lf/208A[FP0308acJ`2<Ng<0S7=[00<0S7=[0P1SFV<01P1kHeX0LeYB08acJ`2<
Lf/0Jf=[07]SFP80Ng=k00D0FTYJ058iBP1B>DX0DSU:048a>@02058i<@0305Y2>@1kHeX0Je9:00<0
Je9:0`1J@ST406=2<@0505Y2>@1cBT80LdY208AB@P1kHe800P24He8208aJBP80Q6=B00@0LdXi07=:
@P1cBT80e/KF>P3gmoLP0?ooo`007P3oool0103HfMP0inOV0>OWiP3Si><50=oPg`<0gmoO6`3Ogmh2
0=kOgP060=oOgP3PhN00hN7Q0>7Qh@3Mg=d0e<oA0P33_;`01P2ZXYl0Rgil06iMF`1^GE/0GT]705]9
@`80FDi;00D0FeII06MRI@1gKF/0Mfe[07maK@0207i`J`0607Y^J01fJf@0KV=L06iSG01TF5@0GUAC
0P1NEUL01P1RFUh0JEeQ06iOH@1^Gf40KEeJ069AB`80DD0k00D0AcHd04<c=@10<3<0@30c03d[;@02
03`Z;00603h];`0o;Rh0?R`W03h/9`0o:b<0@RdT0P15<2L01P17<RT0C3<Y05Dd:@1E=2T0G3HY060g
:P80Hc//00H0ICl_06M5=@1XBCX0J4Tj06Q9>`1YAcL2071:>P0507iHB@2<JUh0S6YN09V0MP2^WiP0
0P39a<40103LgM`0h>7Q0=kNg@3Ng]d20=kMg0P0g]kM0P3Og]d00`3Og]h0gmoN0=oOgP0P0=oOgP04
0>?ShP3WinH0inOV0=SHebX0oooo<P3gmoL0103>_LH0S7=k08acN`1kHe8307]SFP0506]SJ`2<Lg/0
W8b<09b<S02<Ng<00P2DQ8@208akL`80Q6]J00H0S7]c09AkL`2DQ8@0U8B408akL`2DNg<208akL`06
08acJ`2DQ8@0LeYB07=JDP2<Ng<0Nf=J0P1[DTX306=:BP0605Y2>@1B@ST0HdY206=:@P1kHeX0LeYB
0P1SBT8206]BBP80Q59200H0Le9:08aJBP1kHe80Nf=B08aSDP2<Lf<209acH`050:EcFP24DT80HdY2
06=:@P2UQ8@00P3ooolk0?Ogmb00oooo000N0?ooo`040=SIf03WinH0inOV0>?Th`D0gn3O0`3OgmlK
0=oOgP80g]oN00H0gmoN0>3Qh03QhN40hN7Q0=gLg@3Dcm420<>l_0060:ZRW`2;OW`0KUeK06iMF`1N
BdL0FdU30P1ICT/01@1KEUT0If9U07M]J`1gKF/0Og5]0080OW1[00H0NViX07I[I01^He`0KV=L06AH
E01NE5<205iFE`06069JGP1YGF40KUmQ06iOH@1]GEX0HU5;0P1A@3/01@17=S@0@c<e040`<`10<3<0
?B/]0080?2X/00H0?Rd_03l^;P0n;2L0?R`W03l[8`12;B@204D`9`0604Lb:@1<<bT0EC@Y05Dd:@1L
=RT0H3LZ0P1S>b`01P1U?bl0IdDe06Q9>P1XBCX0J4Tk06U7=`80L4Xj00D0OUQ908aZGP2<JUh0VH1f
0:jOV0020<W4`@040=cMg03PhN40g]kM0=kNg@80g]gL203Ng]d20=oNg@030=oNgP3Ogmh0gmoN0200
gmoN00@0hn?R0>OWiP3WinH0f=SG:P3ooolb0?Ogm`040<jmaP2<Lg/0S7=k07]SDP<0Nf=J00D0Jf=[
08acN`2LS8`0W8b<08akL`0209B4Q080S7]c0P24JeX01P2<Ng<0U7]c09B4Q02DQ8@0S7]c09AkL`80
S7]c00H0S7=[09B4Q01cFU80LeYB08akL`1kHeX206]BBP<0HdY:00H0FT8i0592>@1SBT80HdY207]S
FP1cFU8206=:@P80Je9:0P24DT801P1cDTX0S5Y:07]SDP1kHe80S6=B08acH`80W7=S00D0YG=J08AB
@P1SBT80HdY20:F4Q0020?oooc/0moOg803oool001h0oooo00@0f=WH0>OWiP3WinH0hnCS1@3Oh=l3
0=oOgah0gmoN00D0gmoO0=oPg`3Oh=l0gmkN0=gLg0020=cKfP060=7?cP2c[:d0SX6308j1P`1iJ6L0
LF9M0P1/HEl01@1XHfH0KfY_07adMP1lM7H0PgMg0080PWIe00H0P7Ab07ebKP1jKfX0NVmZ07M[IP1e
JFH207EYJ00607EWI`1dHf40LV1K079PF`1]FUD0I51;0P1IAD001@1D@3/0Dclj04hk=`1>>cL0AC8`
0080?R/Y00H0>bPS03/X800m:B40?BTQ048^9018<bX204`g;P0604dg;P1A=b`0FcPZ05/h:P1S>R/0
J3h]0P1Y@C401P1[ASH0LDlo07]IB`1kFD/0Oee?07eIB`80OU]?00D0Rf]T0:6;Q`2QRhL0_[:_0=??
c@020=_Jf@050=gMg03Ng]d0g]kM0=kNg@3NgM`01`3Ng]d20=oNg@80gmkN8`3Ogmh0103Shn80inOV
0>OWiP3Hf=LZ0?ooocH0moOg00D0imk_06]SJ`1[Hf/0DT9B06]BBP0206=JH`0507]cN`2]U9@0[IBD
08acN`2LS8`00P2DQ8@01P2LS8`0U7]c08acJ`2<Lf/0S7]c0:F4N`@0U7]c0P2<Lf<0102UQ7/0U7]c
09AkL`2DNg<308A[FP0608acJ`2<Lf<0S6=B08aSDP24JeX0W6]B0P2<He801@24JeX0U7=[09AcJ`2D
Lf/0[G][00<0[HA[00H0S7=S07=BBP1SBT80HdY208ASDP3>_LI00?Ogmb00oooo000N0?ooo`040=SG
eP3Wi^D0inKU0>?Th`D0gn3O0`3OgmlO0=oOgP80g]kN00H0gmoN0>3Pg`3Rhn80h^?R0=kOgP3=b//2
0;J_/@060:ROW`2RVYP0WINF09fGUP2FT9@0RhF<0P22NH401@21MWX0R7Yl08QjO02>PH80TXF80080
THB600H0SGmn08UhM@24LVl0Q79_07m[I`1iIEl207=OF@0606iJE@1ZEE40Ie1=06M@C@1WCTX0IDe6
0P1OB4401@1F@3/0D3Xe050j=@1@>300CcL/0080C3HZ00H0CSP]05@n=01J@cX0FT<j05i5?01QACX2
06A5=P0606Q6=@1ZB3H0J4Lf06Q7=P1WASP0LU970P29JV801@2MP7T0YH^40:RCS@2XThd0/9nL0080
_kBc00H0d/g=0=oNgP3Ph=l0h>3O0=kMg03MgM`20=kMg0H0g]kM0`3Og]d00`3Og]h0gmoN0=oOgP0S
0=oOgP040>?ShP3Wi^D0inKU0=SHebX0oooo00<0mno_0?Ogm`3gmoL0=P3gmoL00`3Wg^L0[Ibe08ak
S00208akS080[IBD00<0YIBU0<JeaP2eW9`00`2eW9`30:F4N`0509AkL`1kHeX0Nf=J09AkL`2UQ7/0
0P2UQ8@40:F4N`<0U7]c00H0YHAk09AcJ`2<Lf<0S7=S09AcJ`2DNg<20:ekJ`060:F4N`2]Q6/0S7=S
08acH`24JeX0S7=S0`1cDTX0102<Lf<0c[Fm0<je_@3ooom10?Ogmb00oooo000N0?ooo`040=SEe03W
i^D0inKU0>?Th`@0gn3O0`3OgmlV0=oOgP060=gMg@3JfMT0eMCC0=GDd`3BdLl0d<o>0P3>c<`01@35
`LD0[ZR`09F=U`2ESIL0ShB:0080VXf?00H0YiZN0:jSZ`2]XJX0[J6Z0:JGW02OS8`209R2O`0608mi
M@24L6d0NFMU07UWI@1bGeh0L5]L0P1bFU/01@1bF5P0L5E@06U@B@1YD4T0HT]30080HDU100H0I4Y1
0698?01L@cH0G4<f05Q1=01KA3T20699?`0606U<@@1ZCCl0J4dm06Q=?@1/Dd80M5a<0P1fGe401P1d
G540P6MQ09j7Q@2NQhD0^ZRY0<_0_`80d/c:00D0e=3>0=ODdP3Ge=80f]WH0=gLg0020=kNg@80g]gL
1P3Ng]d20=oNg@80gmkN9`3Ogmh0103Sh^80inKU0>OVi@3Hf=LZ0?oood00moOg00H0imk_0>oWi`3F
a]H0e/KF0<JeaP2m]Kd20<JeaP80[IBD0P2UQ8@01P2DNg<0U7=[08akL`2<Ng<0Nf]k08akL`<0U7]c
0P2UQ7/01P2<Lf/0U7=[08acJ`2<Lf/0U7=[08acH`80U7=[00H0S7=S08A[FP24He80Q6=B08A[FP24
He8209AkL`030:fL]@3oool0moOg04<0moOg803oool001h0oooo00@0f=GD0>OVi@3Wi^D0hnCS103O
h=l30=oOgbH0gmoN00H0gMgM0=[If@3Ee=<0eMCC0=;Ac`3@clh20<k<c0050<G1a@2^Z;00UHfG09F=
U`2?Q8X00P2JSHl01P2WVYh0[Z>[0:fQZP2]XJX0YYNL09n<S080V89o00H0SgUe08A`K@1iIfD0NFMU
079OGP1`Fe`2079JF`05079HF01`EE00JE1906U@B@1RBd<00P1QBD401P1TBT40HTPl05a3=P1L@cH0
F44d05]4>@80HTTo00H0JDa106Y=?`1XCCd0J4dm06aC@P1dG4`207IOD@0607ALD@20If40WXN509j7
Q@2jZ:T0bl2o0P3Bc<X01@3Dd<h0emCB0=ODdP3JfMP0gMcL0080g]kM0P3NgM`60=kNg@80gmkM0P3O
g]hW0=oOgP040>?RhP3Wi^D0inKU0=SHebX0oooo@03gmoL01P3Wg^l0knOW0=K6eP3Fa]H0a[G60;fe
_@80a[G60P2]U9@20:F4Q00609AkL`2DLf/0S7]c08akL`1kJg/0S7]c0`2DNg<20:F4N`0608acJ`2D
Lf/0S7=[08acJ`2DLf/0S7=S0P2DLf/01P2<Lf<0Q6]J08ASDP24He80Q6]J08ASDP80U7]c00<0[Ibe
0?ooo`3gmoL0@`3gmoLP0?ooo`007P3oool0103Ge]D0i^KU0>KVi@3Shn8:0=oPg`80h>3O2P3Pgml0
0`3Pgmh0gmoN0=oOgP0B0=oOgP80g]kM00H0gMgL0=kNg@3Ogmh0gmoN0=oPgP3Oh=l20=oOg`050=[H
fP3;bL`0^kNl0;^g_02g/[D00P2n]kP01P37`L80blK;0<S1bP38`LX0`;Jo0;b^]080^JVZ00H0/9nQ
0:2?U@2<O8@0S7b407YZL`1bH6X2075MI`04071JG`1/De40ITi706I>A`<0HT]200H0I4]206=9?`1O
ASX0GdHj05]4>01K@cP205i3=`060612=01O@C40HDLe0657=@1cGDd0T7mc0P2TUHd01P2WVY@0[Z6N
0;nc/`2o/k<0d<S90=_Ge`80gmoM00<0gmoN0=kNg03Ng]`00P3Mg=/20=kMg0030=kNg03Ng]d0gmkM
00<0gmkM0P3Og]hG0=oOgPX0h=oN2P3Ogmh0103Sh^40i^KU0>KVi@3GemLZ0?ooo`030?Ogm`3gknl0
mno_03l0moOg0P3_inL01P3Wg^l0knOW0?O_k`3gknl0knOW0=K6eP80c[g600D0W8bL0:fDY@2LS9`0
W8bL09B4Q00709AkL`030:F4N`2DNg<0U7]c0080S7=[0P2<Lf<01P24He80LeYB08A[FP24JeX0[IBU
0?O_kdP0moOg803oool001h0oooo00@0f][I0>WZj@3Yj^T0i^OV303Shn880>CShQL0hn?R0P3Rh^40
103RhN00hN3O0>3OgP3Pgmh20=oOg@80h>3N00D0h>7O0>7Rh@3Ri>80h^CR0>?Uh`020>CVi0060>GW
i@3TiND0g]gS0=kMh`3IeN00fM?M0P3LeM/01P3FcM@0aKW50:^N[P2[WZh0T8BE085eQP80Nfmn00D0
N6Yb07ARH@1`G5D0L5aE06iJDP0206iID@0606eID01]F500KEQ?06eHC`1/ETh0JE=:0P1WCT<01P1T
BC/0HdLf06YB@01ZDT00R7EX0;NZX`80fM7>00<0h]kL0>;Og@3Qgmd00`3Qgmd30>3Ng080h=oM00D0
hN3N0>;Qh03RhN00h^7P0>;Rh@050>?Rh@80hn;R6`3Shn820>CShP/0hn?R0P3Sh^801@3Sh^40i^KU
0>WYj03YjNP0f][I02X0oooo00D0mno_0?Ogm`3gmoL0moOg0?O_k`110?Ogm`<0mno_203gmoL0103g
knl0imkW0>ONi`3Ne^L20<jmaP040=k>eP3Fa]h0knOW0>oWie80moOg803oool001h0oooo00D0gMkM
0>g]k03]kN`0jN[Y0>KVi@0/0>OWiP060>KVi@3Thn80h=oN0>3OgP3NgM`0g]cK0P3Ng]`01@3Rhn00
jnkZ0?Kim03fnO@0n_kj0080moci00H0loSe0>ocl03[kNh0jng^0>SXl03[j_<20>o_m@060>gZl@3P
f^D0b/;A0<[2d@2c[;/0Y9j]0P2MV:D01@2ITiX0UXb<09B7P`2DQh<0U8Eo0080TXAn00H0TH=n0964
O`2CQH00ThF009B5P02APW`208emM00608UgK028MFP0TGmc095oL`2]WiH0elk:0P3fl_801P3oool0
o?kl0?;el@3bmO40jN[V0>?Qg@80h=cJ00D0h=cK0>;OgP3Rgmh0i>?R0>KUi00<0>OViBD0inOV0`3W
i^D01@3Vi^D0jNWX0>g/j`3]k>/0gMgL02X0ooooE03gmoL00`3gknl0moOg0?Ogm`1F0?Ogmb00oooo
000N0?ooo`050=gNg@3]kN`0kNg/0>WZj@3Vi^D0;03WinH01P3Vi^D0i>?R0>3OgP3Pgmh0g]gL0=kL
f`80g]kL00D0h^?P0>_^jP3fnO@0m_Wd0?[nnP020?Oln@060??hm@3_lo00jng^0>_]kP3Xj?00jn[c
0P3_koD01P3]j_40h=[U0<[2d@3:`]40/jbk0:BN[@80WIRU00D0VI>J09J<S02DQh<0U8N309B5O`02
09:4OP060963OP2AQ7l0ThF009>5P02DQH00TH9l0P2=OG@01P29Mf`0R7EX095oL`2AOg<0[InF0=O>
bP80m_;b00H0oooo0?cno03bmO40l_Ga0>WZiP3ShMd20>3LfP050>3Lf`3Rgmh0h]oN0>CShP3ViN@0
303Wi^DU0>OWiP<0inKU00D0i^KU0>WYj03]k>/0kNc[0=gMg00Z0?oooe@0moOg00<0mno_0?Ogm`3g
moL0EP3gmoLP0?ooo`007P3oool01@3Cdm<0gMgL0=gMg03Jf]T0emSG02`0f=SG00H0emOG0=KFe@3E
eM@0eMGD0=CDd`3De=820=GEd`040=OHeP3Jg=T0g^3N0=kPgP<0h>;P00H0g^7O0=gOg@3KgMd0fmgM
0=_Lg@3Kg=h20=cMg`060=_KgP3FeMT0clkC0<o>d`38a/`0`/760P2o_/801@2m_;h0_;Vi0;^g]@2k
]kD0^[Bb0080^[>a00H0^KFb0;Vf]02j][@0^[Jd0;Zf/`2j]K820;Rc/0060;Rb[P2h/jh0_KRc0;fh
/`37`[l0dm3?0P3Mg=/01P3Rh^40hN;Q0=kOg@3Ngmd0f][H0=OFe0<0eMCB0P3FeM@00`3Ge]D0emOF
0=SHe`0c0=SHe`050=OGe`3Jf]T0gMgL0=gMg03Cdm80:P3ooon]0?Ogmb00oooo003o0?oool<0oooo
003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo
003o0?oool<0oooo003o0?oool<0oooo003o0?ooodH0oooo0T00001k0?ooo`00o`3ooom80?ooo`03
@000003oool0oooo07P0oooo00130?ooo`9000000`3oool2@00000030?oood00001000000080oooo
00=000000?ooo`3oool00T0000020?ooo`=000000P3oool4@0000080oooo0T0000030?ooo`900000
0`3oool3@00000l0oooo1D000000103ooom00000@000040000030?ooo`03@000003oool0oooo00@0
oooo00A000000?ooo`3oool0oooo1T000000103ooom00000@000040000030?ooo`03@000003oool0
oooo0980oooo0T0000020?ooo`=000000P3oool3@00000<0oooo0d0000001@3ooom00000@0000400
0000oooo009000000P3oool00d000000oooo@0000003@00000040?oood0000100000@00006L0oooo
00120?ooo`03@000003ooom000000080oooo00=000000?ooo`3oool00P3oool01T000000oooo0?oo
od000000oooo@00000D0oooo00A000000?ooo`3oool0oooo0d0000020?ooo`06@000003oool0oooo
@000003ooom00000103oool014000000oooo0?oood00000A0?ooo`05@000003oool0oooo0?oood00
0000103oool00d000000oooo@00000060?ooo`03@000003ooom0000000<0oooo00E000000?ooo`3o
ool0oooo@00000040?ooo`03@000003ooom000000980oooo00A000000?ooo`3ooom000000P3oool0
0d000000oooo0?ooo`020?ooo`05@000003oool0oooo0?oood0000000P3oool014000000oooo0?oo
od0000030?ooo`05@000003oool0oooo@000003oool00d0000030?ooo`03@000003oool0oooo06H0
oooo00120?ooo`05@000003ooom00000@000003oool00d0000020?ooo`05@000003oool0oooo@000
003oool00d0000030?ooo`03@000003oool0oooo00<0oooo00A000000?ooo`3ooom00000103oool3
@0000080oooo00A000000?ooo`3ooom000004@3oool00d000000oooo0?ooo`020?ooo`07@000003o
ool0oooo0?oood000000oooo@00000070?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool00P3oool01d000000oooo0?ooo`3ooom000000?oood000000TP3oool014000000oooo0?oood00
00020?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0oooo@00000020?ooo`04@000
003oool0oooo@00000<0oooo00A000000?ooo`3ooom000000`3oool01D000000oooo0?ooo`3ooom0
000006P0oooo00120?ooo`03@000003oool0oooo0080oooo0d0000000`3ooom00000@0000002@000
0080oooo0d0000020?ooo`A000000P3oool2@00000030?oood0000100000009000000P3oool3@000
00<0oooo0d00000A0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00P3oool00d00
0000oooo0?ooo`050?ooo`03@000003ooom0000000<0oooo00=000000?ooo`3oool00P3oool00d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo0940oooo00E000000?ooo`3ooom000000?ooo`04
@00000030?oood000010000000@0oooo0d0000000`3ooom00000@00000020?ooo`A000000`3oool2
@00000<0oooo00=000000?ooo`3oool0IP3oool00480oooo00=000000?ooo`3oool06`3oool00d00
0000oooo0?ooo`0:0?ooo`03@000003oool0oooo00l0oooo00M000000?ooo`3oool0oooo@000003o
oom000000080oooo00=000000?oood0000001@3oool01D000000oooo0?ooo`3ooom000000080oooo
00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood000000TP3oool01400
0000oooo0?oood00000P0?ooo`03@000003oool0oooo06H0oooo00120?ooo`=000009`3oool2@000
0100oooo0T0000040?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool02P3oool2@000
00@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`2B0?ooo`900000203oool00d00
0000oooo0?ooo`070?ooo`03@000003oool0oooo00/0oooo0T00001X0?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00o`3oooo30?ooo`00
O@3oool2@00003<0oooo0T00000m0?ooo`900000B@3oool2@00008@0oooo001o0?ooo`03@000003o
ool0oooo0380oooo00=000000?ooo`3oool0?03oool00d000000oooo0?ooo`180?ooo`03@000003o
ool0oooo0840oooo001a0?ooo`=000000`3oool3@00000<0oooo0d0000050?ooo`03@000003oool0
oooo00E0000000<0oooo@000040000001`3oool00d000000oooo0?ooo`090?ooo`9000000P3oool3
@0000080oooo0d0000030?ooo`=0000000D0oooo@0000400001000000?ooo`02@0000080oooo00=0
00000?oood0000000d000000103ooom00000@0000400000@0?ooo`I000000P3oool00d000000oooo
0?ooo`03@00000/0oooo0d0000020?ooo`90000000<0oooo@000040000000P3oool00d000000oooo
0?ooo`02@0000080oooo0d0000020?ooo`A000000P3oool2@00000<0oooo0T0000030?ooo`=00000
403oool3@00000070?oood000000oooo@000003ooom000000?ooo`04@0000080oooo0d0000020?oo
o`9000000P3oool2@00007/0oooo001b0?ooo`03@000003oool0oooo00<0oooo00E000000?ooo`3o
ool0oooo@00000020?ooo`03@000003oool0oooo00P0oooo00=000000?ooo`3oool00`3oool00d00
0000oooo0?ooo`0?0?ooo`04@000003oool0oooo@0000080oooo00=000000?ooo`3oool00P3oool0
1D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom000000`3oool01D000000oooo
0?oood000000oooo00=000000`3oool00d000000oooo0?ooo`0?0?ooo`=000000P3oool01T000000
oooo0?oood000000oooo@0000080oooo00=000000?ooo`3oool0203oool01T000000oooo0?oood00
0000oooo@00000@0oooo00I000000?ooo`3ooom000000?oood0000050?ooo`04@000003oool0oooo
0?ooo`=000000P3oool01T000000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom0
00004@3oool02D000000oooo0?oood000000oooo@000003ooom000000?ooo`03@0000080oooo00I0
00000?ooo`3ooom000000?oood0000060?ooo`03@000003oool0oooo07P0oooo001b0?ooo`03@000
003oool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00P0
oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0@0?ooo`04@000003oool0oooo@000
0080oooo00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom000000080oooo00A00000
0?ooo`3ooom000000`3oool014000000oooo0?oood0000030?ooo`05@000003oool0oooo0?oood00
00004`3oool014000000oooo0?oood0000020?ooo`03@000003ooom000000080oooo00=000000?oo
o`3oool0203oool01D000000oooo0?oood000000oooo00=000000P3oool01D000000oooo0?oood00
0000oooo00=000000`3oool00d000000oooo0?ooo`030?ooo`04@000003oool0oooo@00000@0oooo
0d0000020?ooo`04@000003oool0oooo@0000140oooo00Q000000?ooo`3ooom000000?oood000000
oooo@00000<0oooo00A000000?ooo`3ooom000000P3oool00d000000oooo@0000002@00000<0oooo
00=000000?ooo`3oool0N@3oool00780oooo0T0000030?ooo`900000103oool3@00000X0oooo00=0
00000?ooo`3oool00`3oool00d000000oooo0?ooo`0?0?ooo`05@000003oool0oooo@000003oool0
140000000`3ooom00000@00000040?ooo`=0000000<0oooo@000040000000P3oool4@00000<0oooo
0T0000030?ooo`03@000003oool0oooo0100oooo0T0000000`3ooom00000@0000002@00000<0oooo
0d00000;0?ooo`=0000000D0oooo@0000400001000000?ooo`04@0000080oooo0d0000020?ooo`A0
00000P3oool2@00000030?oood0000100000009000000P3oool3@00000<0oooo0d00000@0?ooo`90
00000P3oool2@00000030?oood000000oooo0080oooo0T0000030?ooo`=0000000@0oooo@0000400
001000000`3oool2@00007X0oooo001b0?ooo`04@000003oool0oooo@00001@0oooo00M000000?oo
o`3oool0oooo@000003ooom000000140oooo00A000000?ooo`3ooom00000803oool00d000000oooo
0?ooo`0L0?ooo`03@000003oool0oooo02H0oooo00=000000?ooo`3oool02P3oool00d000000oooo
0?ooo`2T0?ooo`00L@3oool5@0000080oooo00=000000?ooo`3oool03P3oool2@00000@0oooo00=0
00000?ooo`3oool04@3oool2@00000P0oooo00=000000?ooo`3oool01`3oool00d000000oooo0?oo
o`0;0?ooo`9000007@3oool2@00003@0oooo0T00000A0?ooo`03@000003oool0oooo0980oooo003o
0?oool<0oooo003o0?oool<0oooo0000\
\>"],
  ImageRangeCache->{{{0, 449}, {449, 0}} -> {-0.0937372, -0.0500106, 
  0.00487189, 0.00487189}, {{19.1875, 214.688}, {438.688, 
  243.25}} -> {-46.0316, -21.7489, 1.48824, 1.48824}, {{234.25, 429.75}, {
  438.688, 243.25}} -> {-366.097, -21.7489, 1.48824, 1.48824}, {{19.1875, 
  214.688}, {223.688, 28.1875}} -> {-22.9861, -170.803, 0.743868, 
  0.743868}, {{234.25, 429.75}, {223.688, 28.1875}} -> {-182.964, -170.803, 
  0.743868, 0.743868}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Obviously, the generated high-resolution images are not so clear than \
these of original ones. However, their correlation coefficients between the \
generated and original image data are very good values. ",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function corRelation",
    FontFamily->"Times New Roman",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["A ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]corRelation\[CloseCurlyDoubleQuote] for \
computing a correlation coefficient is given as follows. The lists \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]b\
\[CloseCurlyDoubleQuote] have to contain the real numerical values and be the \
same order one-dimensional array.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
corRelation=Compile[{{a,_Real,1},{b,_Real,1}},
\tModule[{aa={0.},bb={0.},av=0.,bv=0.},
\tav=Apply[Plus,a]/Length[a]; bv=Apply[Plus,b]/Length[b];
\taa=a-av; bb=b-bv; aa.bb/(Sqrt[aa.aa]*Sqrt[bb.bb])]];\
\>", "Input",
  CellLabel->"In[74]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "A correlation coefficient between the generated and original 128 by 128 \
images is given by",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["corRelation[Flatten[sampleH1C],Flatten[sampleH1]]", "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(0.968676648212538538`\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Similarly, a correlation coefficient between the generated and original \
256 by 256 images is given by",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["corRelation[Flatten[sample],Flatten[sampleH2]]", "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(0.955257421624079761`\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox[
  "Only the 6.25 percent data quantity has yielded over 95 percent \
recoverability. Thus, the differential equation method is a quite effective \
tool for generating the high-resolution images.",
    FormatType->InputForm,
    FontFamily->"Times New Roman"]
}], "Text",
  FormatType->InputForm]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.7 Three-dimensional color image generation",
  FontFamily->"Times New Roman",
  FontSize->18]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In this section, we generate two types of three-dimensional color images. \
One is the shadowed lighting three-dimensional image, and the other is the \
color illusive image. The principle is similar to that of monochrome ones in \
chapter 2. One difference between the monochrome and color images is that a \
monochrome three-dimensional image generation process should be repetitively \
applied to all of the color components red, green and blue.\n\tBefore to \
continue the computations, we remove the needless memories and check up \
them.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Remove[\"source\",\"sampleH1\",\"sampleH2\",\"sample1G\",
\t\"sampleH1C\",\"sample2G\",\"sample2CG\"];
Unprotect[In,Out];Clear[In,Out];Protect[In,Out];
Print[\"Memory: \",Round[N[MemoryInUse[]/1000]],\"K Bytes used\"];\
\>", "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    InterpretationBox[
      \("Memory: "\[InvisibleSpace]5096\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ "Memory: ", 5096, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\tWe define a ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]colorImage3D\[CloseCurlyDoubleQuote]. \
This function requires the function \"eigen\"2Dvect\" and \"imageNormalize\". \
The former generates the two-dimensional characteristic vectors in each of \
the color components, and the latter converts the two-dimensional image data \
into the values between 0 and 1. The parameters \"color\" and \"rotation\" \
are the color image data and the number of lighting angles, respectively. An \
output of this function is a four-dimensional array. The first, second, third \
and fourth indices in this output array refer to the number of lighting \
angles, color components, y-axis pixels and x-axis pixels, respectively. ",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox[" function colorImage3D",
    FontFamily->"Times New Roman",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The parameter \[OpenCurlyDoubleQuote]color\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]rotation\[CloseCurlyDoubleQuote] of \
\[OpenCurlyDoubleQuote]colorImage3D\[CloseCurlyDoubleQuote] are the list \
containing color image data and a integer giving a number of lighting angle \
subdivisions.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
colorImage3D[color_,rotation_]:=
\tModule[{view,dim,vector,dummy,sol,i,j,k,p},
\t\tview=Table[{Cos[2.Pi i/rotation],Sin[2.Pi i/rotation]},
\t\t\t{i,0,rotation-1}];
\t\tdim=Dimensions[color];\t\t
\t\tvector=Table[eigen2DVect[color[[i]]],{i,dim[[1]]}];
\t\tdummy=Table[vector[[p,i,j]].view[[k]],
\t\t\t{k,rotation},{p,dim[[1]]},
\t\t\t{i,dim[[2]],1,-1},{j,dim[[3]]}];
\t\tTable[(1-imageNormalize[dummy[[i,j]]])*color[[j]],
\t\t{i,rotation},{j,dim[[1]]}]];\t\
\>", "Input",
  CellLabel->"In[80]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Using this function, we compute the shadowed lighting color image data.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
rotation=8;
color3D=colorImage3D[sampleL,rotation];//Timing\
\>", "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \({5.93000000000006366`\ Second, Null}\)], "Output",
  CellLabel->"Out[82]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Figure 14 show a set of the shadowed lighting images. From the left to \
right images on the upper in Fig. 14 are corresponding to the 0, 45, 90 and \
135-degree lighting angles, respectively. Similarly, from the left to right \
images on the lower are corresponding to the 180, 225, 270 and 315-degree \
lighting angles.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell["\<\
color3DG=Table[Show[convertRGB[color3D[[i]]],
\tPlotLabel->StringForm[\"`1` deg.\",
\t(i-1) (360/rotation)],AspectRatio->dim[[2]]/dim[[3]],
\tDisplayFunction->Identity],{i,rotation}];\
\>", "Input",
  CellLabel->"In[83]:="],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[Table[color3DG[[i+j]],{j,0,3}],{i,1,rotation,4}]],
\tImageSize->{400,200},PlotLabel->\"Fig.14. 3D color images\"];\
\>", "Input",
  CellLabel->"In[84]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48837 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0116279 0.238095 [
[.5 .50087 -71 0 ]
[.5 .50087 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 .48837 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50087 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.14) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
117.000000 12.812500 moveto
(D) show
129.000000 12.812500 moveto
(color) show
165.000000 12.812500 moveto
(images) show
201.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .48837 L
0 .48837 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0116279 0.245293 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7D7E78
76695C7C6D607C6D657C71687C6D657C71697C71697C71697C71687C6D647D6D5F78695B796455\
745C4F755B4E6F584B6F584B6F584B6F584B6F574A7054456B54446B54456B5444
654C3F7C7E7E7C7E7E7C7E7E7C7E7E7C7F7E7C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7A797C79797C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E81837E
7C6D657C6D607C6D607C71687C6D657C71697C6D60786555736555736154745C516A584C6A584B\
6A55486B54476A55486F584B6F584B6F54476F544770544A6B54476B54456B655C
65605B7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C83827C7A797C79797C83827C7E7E7C7E7E7C7A797C79797C7A797C79797C7E7E7C7E7E\
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E787A75
7669587C6D657C69617C71697C6D657C69617869606B655C645C546F544C6F51486F594C6F6052\
6F6052745F516B54476651446651446654476654436B54446B54476B544A7C6A61
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7F7E7C79797C7E7E7C7E7E7C7E7E7C83827C7E7E7C83827C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E817E78
7C69617C6D657C6D657C69617C6D657C6D6081716892766D82766A81706784635B7A584B7A554C\
7A554F754F4A7050476B54476B54476B54476B544A6F584B70574A6B5447654C3F
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C837E
7C6D5C7C6D5C7C6D607C6D657C6D657C6D697C71697C766D8176707876637D6C627D685E7D6857\
795F527E685A7F594F744C47745854705B4F6F54476F51447054476F5C4F6B5548
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7F7A
7C6D607C6D657C6D607C6D607C6D657C71697C6D657C69617C7169817670817A6B7D716278645B\
7D685A745C4F7A6355755F516F5141745C546B5B4F6654476B5447736561766A65
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6F5C546B5B55
7C6D657C6D607C6D607C6D607C71697C6D657C71697C766D7C71697C71687C6D69817167816D5B\
7D64577D6457795F527A584E75574A6B4D3F6B54476F5447705447675A51767474
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7A797C7575\
7C79797C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E463A3242473F76695C
7C6D607C6D697C6D697C6D657C6D657C71687C695C7C6D607C6D657C6D657C6D607C716478685E\
786057785C5479604E6F57476F584B74574A7054476A5C4F745F51705A4D7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C8382\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B65693F231F161A227C6D64
7C71647C71687C71697C71687C69617C71697C76717C6D657C6D607C60587855516F5146735C4D\
7860547464546F5B51745B4E75584B6B57456B5444664D42665144654C3F7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8082823D2B1E7E725F7669587C6D65
7C69617C6D657C69617C6D657C6D657C69617C6D657C71687869607368587860577960526F594C\
6F594C745948755B4B6A54476F514474544A7454477054476F584B674638766A65
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E2F20187C71698176707C6D647C6D60
7C6D657C6D657C6D607C6D607C6D657C71697C6D657C6D657D4E4D783C3C743637743335743335\
74433F6F51476F51446F4F436B50406A54446F54477054436A4C3E613C2E654C3F
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C7979\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B6565C4B3B27669657C6D657C6D647C6D60
7C6D657C695C7C65587C65557C695D7C69617C605C7C55557D5A5574433A6F362C6E3B356F3E36\
6E3332713C3966463E6654436B4F436A50446F544774544A6F5345745448603828
6B51437C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E352923151D1C7669587C6D5C7C6D607C6D60
7C6D6078695B735C517664597C6D607C6558784F446F362F6A493F5E3D2E615C4C6E6D5B713E33\
612A216F322C703C376B4A446B533C66503B6A54446F54476F584A6F51446F5548
6B4B3C7C746F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E5B4F4F95726260524A7C6D6578655B7668617C7168
7C655B795C4B6A4C3E6B4543743B393C0E092F2A24745A507E595198A09D844E4767362D5A513A\
55574848382A4E282067332D664C3C6F4C3E6F544874604E755B4A6F584B6F5447
603C2E6B4B3C7C746F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E433630363F3F7669617C6D607D685A765B517C6D65
7C6D627952416B4436390F0B353837B4D0C887979487ABAD81979E7C767682A08E929C949EA2A5\
7A7471583E352420143120196240386A5343745549745C527A63517557476F5447
6F5548604E4D67636D7674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E6F6D75452A2510191F7669587C6D60817A6B7C6D607C6D65
745B4F684D38562E1F54190E3F120F6D393073493D76544A7C6D5C7C6451795B526D4E4874584B\
926D5DA6877092766837291F2D1C195D3C33695143786554796458755F516F5245
6F4D426B4D35595146564E516B6A747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E463A32160D08634B43604E4A7C6D607C65587C5D517C65557C6D5C
7E685789675E949883C5C5A7877F747D5C5A74584F6A3F376D3C3C6A36376A3932651E18662824\
5B302A704D3F75423B82554B311209311C1C694A42735C4D7964517557476B584A
6A584B74514387756B7A717165606A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E6F696D2318121B130F2234367C6D647C695C7C645F78645F76695C7C605C
7E6259674434654A427C716D7C7F70817F7487887D87877C81907A887B67837F6B7F81657F745C\
754C407948437A3830742C206E251938140F4725266D5147796051755B4A704F43
6A4D426F51453119103830207871717674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7F8388F2CDBDEFB191735C4E76695C7C6D5F7C766081645F7C605C7C7A64
7E6F5E7F5F5267483D7660557C71697C71687C69617C71697C64637D605A786054796055745B4E\
715B48615C466B654D7A6C588E766083665D624638644D3D745C4E755B4A705845
6A54446F5548624B4122201D6B6A657C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E8D7F677C6D65817F797D7167736558766D607C6D657C7A6D7C716D7C716D
8275697F6A596A463B674B3F76685C7C766D7C71687C6D657C7F6B7D6C5D7454477455456B5743\
634F435E4B3A634136634536634436674B366A554B6E594C74584E7152456B4C43
6650406651423D261E1F232A716F797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7876757676737865546F513F6659556B65637C69617C71697C766D7C71697C766D
816C6A8268617F6152734D44765B517C6D657C645F78585176695C796758745F516B443A6B4A41\
704A3C67483A674E3E6B4F3C6C513A6747366A4A3D7455486F54477053456B4F43
6B50476F584B2B1A18000703605A577C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
8176677C6D657963586F584E7D5C4676605C7C605D7C6D657C71697C71697C7169
7C7F6B8171627E6B576F51417153497C6D657C7F7081716D7C6D698270697963587A6555745447\
70504167443A67483C664C457452487E5F54745C4F6F574A6F544774584A705345
6B50406651423F22190B0A0A1713127C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7F7A7869586C503C6D584A7C605C7C6D607C6D607C6D657C76717C76707C7169
7C716D7C766B7E6B5E7463516D58467665597C6D607C71647C71687D7162745B4D6F54476B5447\
70594B70563F6C4A3866493E6F584F7860577960527563556F5F516B574A6B584A
6B544A6F5C4FB9784F6632211207051714137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C6D65\
74544A662F287046405C4C476572607C6D607C6D607C6D657C6C617C71697C7169
7C71687869607D71627D72677C6D607C6D5C786058765B517C605879584E7556456B4C4067483C\
664C385F43365E44386A51456E5C4C735C5079605275584B6F5447745447705443
6F4F406F5146795F559C6F5ACAB0A47C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7071\
7E545075493F6B463F78584A7669617C716D7C71687C6D657C71697C71697C6D65
7C6D607D6D5F7C695B7D65587669617C716D817F747C6D697C715F7E645871594A674B3E63473A\
5A423A6C4E416F5B4E745C4F746054736054796052755B4E6F574A6F4F47744C4A
6B4F456A514A6C503F66493B69483C8183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C71697C7A67\
7E6C5771563F6A4D3F705B517C6D607C6D657C766D7C6D657C6961786558766958
7C605C7D5C58736054785C517665597C695C7C6D607C6D657C68677E574F7553456C4E416C4E41\
6852456657466A55456E594C785C50745C4F74584B75584B6F52456F4F406B4F40
6B54436A5547795F5570544753392E6560617C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7467595E3E31\
43302442342C5A49407160557C6D607C69617C69617C6D607C69587D695C735C54
6F6051735C5478695F786D5F7669587C6D657C6D657C6D65787663796A597556486C4E41674B3E\
704C406B50476F554C74594F6F594C746054746355755B4E6F5F516B5B4C6B5345
6B4C476A514A6742306A463A70412F653C307C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7964553E2314\
36241E2C1F1D2A2A2D7160597C6D657C6D607C6D5C7C6D657C716D81716D817A70
826C6574584F6A4A426D554A73615576695D7C6D657C6D607D645B745B4F6C4A4567483D634738\
62493E6F54486A54446A51456E554C6F4D446A51456B54476651446B54476B5345
6B4F44664A3F6859405A3C2B664A3E653C357C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7671847C77955946\
462A1F3925202A2A2D7160517869587669617C6D646F5C4C604D3F553F32483328
4D3C33543E3B65464265463C694D447160557C6D657C6D697D6C627A5E5270543C674736684B3C\
5E483C5A463B564C405D4D426559496B5B4C6A5548745B4E70574A6B54476B5345
6B4F446B50475A382C401F174B30226037267C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E786D627963552A0F0A\
180F0D1E18151524287361557C695C7C69587C6D608875656C5648574638352E2A
1D1C1B1B1C142E251E43241B3B17124728217665597C6D657D71627A615270524163523C5F4634\
614D42795C4E7E5F5174574A6B4942634C436151456F584B70574A634F435A4F43
6254446B54476E48365A3325542E26602D217C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E80828287817A7959486B3E33\
2A1813291713151D237C6D60786D5F76695C7C6D6081766C8D71629874696C483A
301C16241813222221423D33745E4F6D584E766D607C7A757D7A717A655567493C5A3B303D140B\
311C1A563C2A4F382A3C2D2343392D634C405D4D3E6651426B54476C4F41634C40
624C4463483E54372C4B362B58443C693E368183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C75757C79797C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E27100B0A10157A6052734635\
2E1F221C141205141C7365587C6D6078695C73655876695D887E71746452A67660
B984689B6649814E34705B466F584873554A7664587C6C617D6D627A61527A533F684638764E3A\
4738353230330B06071517172A25211F19141C1E1E382C214B3627684C3E634F43
624F405E4638412D212D231D3D3C3469493C8183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7A797C79797C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E2D19142B1B1606030209080A1F1418\
1C141027191410191F78695C76696174524D65433D6B574D81767187837C8E7770
7F5E52846659846557795C4E7864547860547664587C71697D6C657A675B705A486C563C75583F\
835742955E482F1B181B16112F1F1D3124203229215A4036615143704F3E684C40
625443462B2531211A2F1F172A1E1A5A281C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E543129342119331F181F1816160D0C\
2517142D191415181E7C65587865558788787F6F6252382B432A21423026352C24
2C221E281E1831251C37231C4737306D60557665597C695C7D6C5A7A605270574A6C4438634F3A\
62503B755E4DCD8A6BA2735B7E4D387E4835714E4175563F634C3E665746755847
634F45482F202919142F1E182F231B541E137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E5C392921100B18130F1C130F251611\
1A14102824201924276B5C51816D607C6D608D7F789E938383665A664D4B755952
8C5E4C7F5A4A705141795E4F7861557C6D657C6D657C60607D655E7A645570534D4E2E253C1F19\
43322862503B6B5440795B4A8868537A63506657466353486B4F47634C45625040
5E4636281B15181410433E365B3929491E137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E6848392F140E2414101C14100F0808\
1C120F281F1C202627574C447665597C6D607C7169817A75929689AE9E8D929689
9D9E959D9A91A3A3998D8B7E7D6D5F766D60786D5F73725C78695B7F685A847761987D68623E38\
29191816121021201E5343396B5445755843634F43674B3E5744366149416B4C45
462A202B18122B211D1F231E532D1F1D08041C19187C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E55453F2E221D2416122214101D120D\
1E1410281F1C2D2D2B5D4C437665597C6D607C6D657C71697C76717C7B797C7B79
7C76707C76717C76707C767181766B7C69588171647D695B7860547D65587D695B887065A78978\
AB796B80544831241D16120F191717272221322921382B215C433C6B4F43674B3E
3D221B241511211616120C0A21130E3E2621221E1C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E684D45442F2A2419141F1410241511\
2519192A211F272B28473E376B5B517C6D5C7C695D7C6D657C6C617C71687C7671
7C7B797C76717C76707C71697C76717C71687C6D607D6D5E78695B7860547860547864587F6457\
7A6B58926F5A99735D8C6651654936623D2D684A3C7A5C4D5E47405F4943574A3D
3F241C2415111B140F15110C1817142F2421221E1C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E63443431201732201A24161225100C\
2917122D1D1627221E36322E62504776695C7C6D607C6D657C76717C71697C7168
7C76717C76717C76707C71697C6D607C6D657C69607D645778605478695B786054786051795C4F\
7A584B7A5B4E795B4C8463548D6C5A88685875594B754F47705645704B3E543427
381F182415112B19142116121C1410241913120A065A51527C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E553E2F3529252E201B2C1B1619120D\
1B130F1B120F241B1625201947382F7665597C6D607C6D657C71687C7B797C7169
7C71687C71697C71697C71697C71687C6D5C78695B78695B786054785C51786054786054796052\
6F5B4E6F584B7460526B574A6F54477054476353455A4F405A4F43534638332721
19120D21181717101117100C0F07071A12111E1A184437357C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E68473834241F3629242D201B301C17\
241511291D192C26242D2A282E2D2B6B544A7C695D7C69617C685D7C71687C7B79
7C76717C76707C71697C71697C716D78696078695B7860547860547860547460546F5C4F745C4F\
755B4E6F584B6F5548745B4E6B574A6B54476C53456B4F436C4B3E50362C341D17
301F1A150C0C1710101008081810101B13102123223832307C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E5C4D47382B27382B27382A252D1C17\
1A110C211612311F184730244230255D44397665557C6D607C69617C685D7C7168
7C76717C7B797C76707C71697C71688171687D6D5E7464576F5C4F73595079594F74584B74554C\
75584E6F584B6F54476B51446B5447674B3E704C4063473A4E38303E281F301C16
18100B191110140C0C19110C1810102518144F51527C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A7978717155413A2F2420332824342722241712\
2D1E1A291E19251E1C322B24483C335A453D7160557C6D607C71697C71697C7168
7C76717C76717C76707C7169786D5F7665587D64577D60547D645774604F745C4F745B4E6F5C4C\
6F5B4E6B4F476650476B54476B5447705648634F435B483A5E3F2F3F281C2D1B15
2116121D15101F161119110C1C14102318140B05048183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C8382818887523E3537241B34241F3529253D2D28\
2D1F1A2D211D312119302F2A38332A47362E67504776695D7C69617C6D657C6C61
7C6C617C6C617C6D6578655878655873655878685A745C4B6F5949745C4B745C4C74605275584B\
6F584B745B4A7054476B4F436B4C40634F435B473A533D2F3925212C1A161C1410
18100C171010130B0C0B0708100A0B2C211F1C0F0E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B4E4731231A3528223529252F231E\
2B1A152F1E173125212F2823332620322A265D473F7669587C6D5C7C695D7C695C
7C69587C69587C6D608171687D6D5E785C5174584B74554B74554C745952745C4F745447755548\
6F54476F54477054476B5345674B3E5F4438533A2D3925213121192416111E1410
2215111A1110150C0C160C0C2919146972728183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E796A623D2E2A2F242037282438241A\
31241E271D192D221F271D1A292624292A253F2F266250437365587669587C6D60
7C6D6078695C73655576695C7D685A74584B745C4B6F57476A55456A55486E55486F574A6F5144\
6F4F476B50476B5443674F3E634B3E5F4638452D2436231921141018100C171010
1E14101A1110110808130B0B1F16130600007C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6F605341322B382B272F2521312724\
271A1A271C19291E1A352925312119241C1727252344362E644A406D554A735D51
73615578695C786558735D517464576F5B4D6A4D446F54476F4C406F4D426A51446F54476B4F43\
664F4067483C5F453C57473A4B382C4B322638251A2114101C141019110C140C0B
110B0B0B07070B0808251814311D141709047C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EA49EAA593F3B382925342722392E29\
3D281C2D1A143326222D211D332927271E1A1E201E21221E2925214C3831614A3F
604A4465514D65554C69584D6B544757433649382E543C2E62493B664C4066443866463B6B4F3A\
674B3963473A5F40345A4034493128341E182C191424151119100C140C0C140C0C
1008080C0808140C0C19120F626D717674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E98A29A72625333251F2F24202D221F\
29231F251B1A281C16342520372C283F302B2D22202F28262C2A262B231C322A27
2928242D281F3E302842362C40332C4332283C2C21382F23422F234D36285944325A3E304B342C\
4A312652372C4B38303F2A243921192D191422141018100C140C0C1008080B0707
0B08080C08081A1410271914110E0E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8E8691483632352925342B27\
362824201712221D1A372C28392E2940342F46383345392F3F382F35322B312621
311F19291E1C2A1C193324203426222C242436262136231A30231C352923382D243C2C21433226\
3C2C20362A233C261F37241C291A15271D191A120D18100C150C0C1108080C0808
0C0808211410191010474240493C3A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EA3A3A3634842342521312420\
3125213D2B26382B27372C283D322D35292531262231211F3C231D3C221A31241F
251D1A28221F211814211C1B2D242029201C1F17141D18171D16131A12101F1814241C16221B15\
2316132012101F15122116131C1410150F0B140C0C130B0C140C0C0C08080C0808
2114192114123627214955577C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E878D879D9898483631312521\
3529253427223B302C2F231E2F26232F231E3026223F342B352D282F2724312521
31241F3728242C1D1C231D1A2518142717132114101A130F1C14102318142517141E13101B120F\
1C14102318142114101E141019100C18100C150C0C140C0C0C08080C0808140C0C
231A162C1B16706F6F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E989397613E383A2925\
352925342722231D19372E293D322D3A302B2B211D2C1F192B1C17291E1A2B201B
21191D1E1C1A261B192717142114191A14111B141018100C1A141018141018141017100C120B0B\
150F0B1B130F18100C120B0B17100C181010150C0C0C0808140C0C1F15112C1F1A
2919147C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8D979180736C3D2D28\
3328243427223A2B272F28242E26222F211D291D19211A18211410271D19251919
2619181F13101F1417161011120B0B160F10171010140C0C160F10130B0C160F10140C0C181010\
1C1411171010140C0C0C08080A07070A07070A070718101019110C130B0B190E0A
6D6D6C7674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EBFCACB87736C\
3728222F24202F2824312925372E29382A2A2D1B17291C181F16121B120E1B140F
1E140F140C0C110B0A171010191111140C0C171010150C0C171010150C0C2717140E0908150F0F\
1B14101911100C08080C08081008081910101C12121810102919153D251A624433
49372A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EBFCACB\
8A6E673F322C2D211D372A26392E293E312B3028222D231E27171B1810121F1410
1810101D15111F1611191110140C0C140C0C130B0B140C0C130B0B1C1410151010332D36373336\
27191E160C0D1A11112016122017121911102D211D32211B291A153F2A246B6F74
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
C6D6D78A6C644C39332D211D2A252138302C46353038251B302019211712171010
140C0C160F0B171010140C0C140C0C181010150C0C181010150C0C120B0B2B2828291D223B2C2C\
5140364833314937313B29232117122B1E19271B183529254B30267675757C7979
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
767979BFCFD079594A4E3A333C2D28382E2A40342F463A3632231D2E1F1A3A2A24
3629222718131F15101A1211191111140C0C140C0C1B14171A12121D1511140D0C211D17261F1C\
150E0E14100D130F0C140E0E1F1410251A173121194B32247E76756B6A6F7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7EC5D9DF7665573527202C231F4036324D433F51423C32231D211717
2717143627223227211D1312140C0C21191D251C212B231E271D20382B2925191D352C2C382A29\
3F2D283D2B263727213D2B25493A303D2D26533D31827F7E8D928C7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7EC5CFD5C8BEC6624F4A3026222F24213B383C564B49604D45
5C534C3D2E2E312B2D4B434D66585546332F352A3134272B493D433A2F2E3F2D253228253E2D27\
3E27223E251D3D2B2545342B573A2D4E2D205A656A7C83827C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E929C96D1D9DA7C6A71463836352E2E404247514B4D
49413F564D455E514D54463D493A3646373046362C382A28271C162D221F392E293529253F2921\
4D2F2550362D5C3F344B2D2443383B9EA2AA7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C75757C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EC5CFC7D1D9DACDC3C263586553484E
75677478666E624B4551413C4D413C624E4D664E4B6550486D564F604B3F54463F65514A53493F\
464238392D28504D55AEBBC6B4C5C17C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E878D87C5CABDAEBBB8
9DA69A9EA3ADA9AFBCA69EAC6A61744A4A584641434A3E3A433C384D413F463A36392E263F322A\
767574D6DEDF98A6A07C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E878D827C8382929C91BAC0B3BAC0B3BFCACBBFC3C5BFC5C7BFCACBC5CFD0CAD9DFCAD4DA\
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0116279 0.488926 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(225) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807D78
79685C7F6C607F6C647F70687F6C647F70687F70687F70687F70687F6C63806C5F7B685B7C6355\
765B4F785B4D72574B72574B72574B72574B7256497353456E53446E53456E5344
664A3D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7B7B7F7A7A7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D82807C
7C6A607F6C5F7F6C627F70687F6C647F70687F6E637D6A5D7B6A5D7B665B7C6356755F52755D4F\
72574B7356496F554972574B72574B7255487255487353486E53456E53456E5C50
66544C7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7F7F7F79797F7A7A7F7F7F7F7A7A7F7D7D7F7B7B7F7A7A7F7B7B7F7A7A7F7D7D7F7D7D\
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7D7B76
7C6A5B7F6C647F6A607F70687F6C647F6C647D6C6378685D706156765C5278594D755B4F725D50\
725B4F755B4D6E53466E53466E53466E55486E53447053456E53466E534872594C
726E6B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F78787F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7F7F7F7A7A7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D827D78
7C685E7F6C627F6C647F6A627F6E667F6C61826E66886E64776C627C675D7F5D5576574B76574D\
76574F75534B7353486E53466E53466E53466E53486F55487055486E5346664A3D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F807C
7F6A5B7F6C5F7F6C627F6C647F6C647F6C667F6E647F706882706A7B6E5F80655E7B61567B5F52\
795B507B60557A534B724F4672564E70564B6F53466F51457355486F584C694F42
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7E7A
7F6C5F7F6C627F6C5F7F6C627F6C647F6E667F6C647F6C647F706882706A7F71637D685C7B6157\
7D635776594F7C605375574C725044755B536E564B6E53467053466F5B54725E55
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7A6A63756C67
7F6C627F6C5F7F6C617F6C607F6E667F6C647F70687F70687F6E667F70687F6C66826E627F6859\
7D61567D6155795C507A574D75564970504270564B6F5346705346685349796E6C
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7B7B7F7979\
7F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D5E4D4360615B726158
7F6C607F6C667F6C647F6C627F6C647F70687F6A607F6E647F6E667F6E667F6C617F6E637D675C\
7D61567B5D537C5F4F75564975574B7555487053466C584C75594C6C51447C7878
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7D7D\
7F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7870724E2A241E272B7C6A60
7F6E617F6E667F6E667F6E667F6A627F70687F706A7F6C627F6E637F655D7D5F58795D507B6355\
7B5F55796153785B51765B4C7555497056467053456B50446E5548694C3F7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F79797F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807E7E4F3527756A62413E3A7F6C64
7F6A607F6E667F6A627F6E667F6C647F6A627F6E667F70687D6A617B695B7D5F587C5F5274594D\
765B4F795B4C785C4E6F55487553467555497253457053466F5549684B3F7C7270
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D482F248279744A49467C6A607F6C60
7F6C647F6C647F6C617F6C627F6C647F6E667F6C647F6E668058537B4E4879454279443F76423E\
764E467555497555467252457051426F53457253467353446C4F416B493B6F5951
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D787070A798974442407F6E667F6C637F6C60
7F6C647F6A5F7F685D7F68597F6A607F6A627F67617F5F5B805E5779453D783B32733E39753F38\
733A3876463F6E4B416E5344704F426C51447253467553486F5244755246674537
75665F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D48342D3B403E796A5F7F6C5F7F6C617F6C60
7F6C617D6A5E7B61557C655A7F6A5E7F685C7D584F79453D7852496F3E316D5045705448763C32\
6B312775393270413A6E4C446E523D6B4F3E6F5345725346725548725044725549
6C4E427F78757F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D6F60609072643437367C6A607D685C7C69607F6E64
7F685E7F635275554672524B7C4C45571A0F56453C79524A7B4E4885747074433B6F45396B503C\
63483D5B35286030276C3D356B4F3E6F4D3D6F544673594B755648725549725346
69493C755F557F78757F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D533E37414647695A527F6C5F80695D795F547F6E66
7F6C62805745734C3C5218125B4B49988582594E4D7F7E7B7C6D6E7C6663838A7D856863847370\
6F5D555E3C323823164F2A2166453C6C504073524773594F7A5F4D755546725548
725448695149746B6E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7A75794E2D270E1D2479685A7F6C618273657C655A7F6C64
7C615477543D6634245E1C0F3A1A186C4E467B5D537C645C7F73697F6C617F665C755A517C6458\
886C62896E6072554C39251B48282166473A6D5043786052795F53785C4D725245
725044705140675D5B6A61627572787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D5E4D43341E186D57523130327C6A5D7F685B7F64577F685A7F6C5F
826759825D537B6E5D917767594C457B5450795B50744C4478524F784D4677493E6F322A733F38\
6A433A7B5648744840754E45361209482B276A4C43755B4D7C6352785849705749
6F5448755245786A6173686569636E7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7A73742E1D152617120F23276C5A547F6A5D7F675F7D645B7C665A7F655D
8265597149396C51487C6C647F7568826E688270687F6E667C73658463587B675A796151795749\
72453C764D45763C3372322665251A3917125936337156497C6152785A49735044
6C504472544849291D59534B71696E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D838082B69A947763563937347C6A607F6C5F7F6E5D82615D7C635C7F7361
82665B7D5A4D65473C7C665C7F70687F6E667F6A627F70687F676380655B7B5F537C5F53765B4C\
7658476B55447355467655487855466948415938306A5042795D4F785A49735545
6C514472544865473D25221F75706E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D887E70756C6C82756C7D685D7866597C6C5F7F6A607F73667F67647F6E66
8370637C62536F4A3E71574B7C69607F726A7F6E667F6C647F776980655B79584B79594B735846\
6F5245674E3C6A463A6A4B3A6A483A6C4C3A6A4E486D544576594D765546704F44
6B51416E51444729212227256C66697F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7D79797C79767D6859795D4E76645E72665F7C685E7F6E647F70687F6E667F726A
826B6680655B7C5C4D714E447961567F6E667F69627D61597C6C617F6859795E5073493D735145\
714C3D674B3C6A4C3D6B4B3B6C4E3A6A4637684B3D7355497556497654466E4F42
6E4F456F55482F1B180A13116963677F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
8279707C716C7F6659785D507B5B496F615F7F635C7F6C647F70687F70687F7068
7F776982685E7F655374514476584E7F6C647F776C8267647C6A62836D63795F537B5D4F724E42\
714F416A453A6A493B684B427250427355496E5245755649755548755548705044
6E4F416B51444222191613133836347F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7E7A7D6A5B79584572594D755C547C6A5D7F655E7F6C647F726C7F736C7F7068
7F706A7F7065826759765F4D7255477C685E7F6E637F6E647F6E66806E627A5C4F755649705346\
7355486E4F3C6C4839684A3E6E544A74574E795B4F785F5272594C705548705548
6E51466F584A9963454A281D2116124745447F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7570\
7C645A7642387853496349406F6C5D7F655D7F6C607F6C647F6E647F736C7F7068
7F70687D6A61806E607B665B7963567C6A5B7D655C7C63587F675F7F61557B5A4A704F426F4C3F\
6B4F3C6846396748396A4D426D5649755A507C5F5278594C725649755548705344
6F50426F5247785C4F835C497F61584747477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7574\
825B5379493E6E423B7152486F665E7F6E667F6E647F6C647F70687F70687F6E66
7F6E63806C617C685B7D645879685E7F6E6682756A7C65607F6E5E8261587658496F4C3F6A493C\
63453B6F4E3E6750456E5247735C50755D517C5F52785B4D725649725046754F48
6E50446F50487152406B4B3E664438827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F77727F7B6F\
826456774F3D6C473D6C564D7C6A5E7F6C647F726A7F6C647F6C647D6A5F7C6C5F
7F655F80645B7863567D605479665A7F6A607F6E647F6C647F6964825C507955476F4E416C4C3F\
684D416650416A504370584C785C50765D50795B4E78594C725346725042704F42
7051446C5246775C516E4E416043397570707F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7C7064715042\
6040305D3F345F483E6F5A507F6C607F6A627F6C647F6E637F6A5D806A5F786157
7965567B5D577B665B7B66597966587F6C647F6C627F6C647D70637F64587954466F4E416A4B3E\
6E4B40684F456E544973584D74594D795F53765F5278594C725B4D705548705044
6E4D456C52486F47356F4A3F704837664C477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D80695A522B1A\
4D2E253B25203C3432735F567F6C627F6C617F6C5F7F6C647F6E66826C647F7166
80655E765B5075544B745E527864587C6A5E7F6C647F6C6180675E7A5F52744E466C4B3D68483A\
664A3E6F52466C534572544973574D75534872574B7356496E53467055486E5245
6E4F446B4C426F5640623D2D6E4F43663A307F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7977857974884E3C\
42271C3F272125292C735F527D6A5D7C6A627F6C617A6353725B4F6D5143654B3E
684F456A4B456F4E466C4E4273584D7663587F6C647F6C66806B607D5D5274523E6A46396A4B3B\
62483B654A3E6550446850446C584A73584C6F544875594C7055486E53466E5245
6E4F446E4F46653D2F522A1C5A3B2C63382C7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7D746C7F695E37120C\
281611281B17172429755F547F6A5D7C685A7F6C61877061725749654C3D48362F
3627223B291D4B342C5B3124562A1F5D433A7C685E7F6C64806E627D5F52745141684F3B664535\
634C4172544772574B6C53466E4D446D524667524672574B7356496A5044655044
6851446E5146704635593124522F266030227F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807E7E857E787D5C4C6A3A31\
2615112817130B1B227C685C7B6A5D7C685C7F6C5F82706688695B7D6157634134
331D172B1B153127234F3C3164493E5C413B79675B7F726C80736A7D62536F4B3D6341334D1A0E\
472F29634533614435563A2C5B45386A4D42614E406E53457055486F4F42654D41
634D446A4C40603A2F52362A563C34633228827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F79797F7A7A7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D3D19124544417F6153724132\
2E1D201F141105151C7866597F6C5F7B685B7B685B7C6A5E87756A735D4F966959
7E5E4D6347375A3B2C53493D624B3F7153497965597F6E648070677D625379513E6644376E4533\
442E2A47363216090935251F3B2D2637241A3E312C523A2A5D42326D4F41654D41
634F4168483B4E30233B2620463B33663F358582817F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F79797F78787F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D43251E3F261F16060338211B311B1E\
24161227181502151C7B685B79685E7D5C52725449725F5482706A82756C846960
78584C7A5D507255486A5043715C4D785B507963577F7068806D657D65587455446D4F3A6C4E3A\
6E493A7751422B18161C1611382420362620332A22553E3558473A6F4B3B684D41
6351425330283E261C35201831272163382C827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D593129322018301B162317141B0E0D\
2617142918140B181E7C66597B665885796E7A5F5563443663463A61493C584137
4F332A4A30245036295434285F493D745F547963587F6C61806D5E7D5F537457496C4638654F3A\
664C3A7358499E69545B493F5B3B2D5F3C2F4B3D3560483763483C6B5544705144
654F445030212E1A1632201831251C5923187F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D60382924110C1E1510211410261611\
1A13102B221E162125725F54826A5D7C6A5E88756E89776A73554B684B45685048
6F4E4163473D5F4437644C41634A4275635A7C6A607F656180685E7D615374534B5C3427522B20\
54403168513E6E5342755748785A496A50425E4A3D684F446E4F42654D44685141
68493A301E161E151131322D4C30234D1B117F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D6C47382E130D2313101D1410120808\
1F1310271F1C222A2A6353497C665A7F6C607F6E6682726C887E728E756A6F6C66
85756E7F6E6682756C72655C775F5479695D7D6C617B6E5F7D645B7F65587C69588462565B362F\
39201B32211846352C604A3E705345735542654F426C4E3F5F483A684B44684D44
533023321B14281F1B1B231E5D31213419134A4A497F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D5D453E31211B2415112214101C120C\
1C130F291F1C2A2E2C5D4D447963587F6C607F6C647F70687F726C7F75707F7570
7F736C7F726C7F736C7F726C8270657C685A8270657D685B7B63567D64577B645781675C8E6E60\
7B574F61413834241C301E163F2A2345332B4E372A4E372A63473E634B406C4C40
46231C2816112316161D0F0C3919114628231819187F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6C4C453E2B27231712211410231511\
2317172A201D2B2D2953453C725F547F6C5D7F6A607F6E667F6E647F726C7F7570
7F77747F726C7F75707F70687F726C7F6E637F6C5F806C5E7B66597B5F537B62567B64577F6156\
786355835F5077584A664B3D4E3A2D56372B544237654B40554139684B44644B3D
46241C2515111D141019110D2016133624201B1B1A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D69443535221933201B22151125110C\
2817132C1D172E2622433B3468554B7C6A5D7F6C607F6C647F726C7F70687F726C
7F75707F75707F75707F70687F6E637F6E667F6A5F8067597B62567B66597B5F537B61537C5D52\
7A5B4E785B4D76574975594C765A4C6E5346634B406E4B426B52446F493F5D3A2B
3E211A2515112918142015111D1310291B15201E1B6C66677F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D5D3E2F3828232F1F1A2C1A151B110C\
1F130F2013102C1F18332A2157453C79665A7F6C607F6C647F6F677F77747F7068
7F726C7F736C7F736C7F70687F70677F6C5D7D6A5E7D685B7B5F537B5F537B61557B5F537C5F52\
755B4D75574B755B4F6E55487255487053466A5245654F41654F4461483A412A23
21140E2518171911111B110C1108081F151227231F4D42427F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6C463734241E3627232C1E1A2E1A16\
211410281B172B2321342A263A352E725B517F6A5E7F6A627F6B627F726C7F7774
7F726C7F75707F70687F70687F706A7D6A5F7D6A5C7B61557B61557B5F53795F53765D50795D50\
785B4D72574B725549755B4D6E55487053466F5245684F426A4C3F593B303B1F19
2F1E1A160C0C1A11111108081910101B120F2724233B33307F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D634C453929243729253627232C1A16\
1C110C24161331201A402F263E342A654D437C66587F6C627F6A627F6B627F726C
7F75707F77747F736C7F70687F7068826E657D6A5C796456765D50785B517C5B50765B4E76574D\
78594D72574B7255487053467055486C4E40704F4265493C5E3F354C2D22351D17
1B110C1C1211150C0C19110C18100F2317142226275956557F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7D77775D433C322521352824352722271713\
2C1C18261B17281E1B362C244A3B325F463C7661567F6C607F6E667F6E667F6F67
7F75707F75707F75707F70687D6E627C685D8067597D61557B6155765D4F795B50765B4D75594C\
75594D7052486E53487053466E5346705446684D4166493B63403143281D301B15
2216111D14101E151119100C1C1410221713000000827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F827F7F573D3536241C342420372925392924\
2A1C182D201C302018312D2944352B533F366F574D7C6A5E7F6A627F6E667F6E64
7F70687F70687F716A7D6A5F7D6A5E7866597D6759795D4E765B4D795D4E765B4D765D5078574B\
72594C7558497051466E50446E4F426A504466493C5D4133462A24361D18201611
1B110C191010150C0C0D0808130B0B29201D0C0707827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6D4D4531221A38272235282431231E\
2D1A162F1F173124203328233D2B2340342C654C4479685A7F6C5F7F6A607F6C61
7F6C5F7F6C5F7F6E64826E657D6A5C7B6053795E5079594E76574C765950765B4D76564978574B\
7255487255487353466E52456C4C3F68483B5D4032462B253C251B281712201511
2115111A1110160C0C160C0C221613232F32504A497F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7B655E3B2A2631241F38282437241B\
30221D291C1830231E2C201C322925352D26503B316F5B4F7B685B7C6A5B7F6C61
7F6C5F7D6A5D7B68597C6A6080695B795D4F795D4E75564872554872554B73574B75584B755145\
7252487051467053446C4F406A4C3F6646394F31263F261B2616121C120C191010
1F14101B1110120808140B0B1F1513000000827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D75605443312B372925312521352723\
291A192A1C192A1F1B3528243121192E211B3C312A58443970584C755E527B6457
7B66597D6A5D7B66597862567C6759785B4E725146755648724F427251456F5346755548705044\
6E50426F4A3F684B3F644B3C5A3D3058392B41281D2816122016111B110C150C0B
140B0C0D08080C08082116132A1A130904027F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D988C93503732382925352722382B27\
39251B2B19153125212E211C3529262B1E192C2521392E264B382E61493F705548
6F564D725B53725D52735D51765A4C684C3D5F42366445366B4D406E4D416E493C6E4B4070503D\
6C4C3D6A493C66443761443752352A41241A351C162616111B110C160C0C150C0C
1108080D0808140B0B19120F353B3D443D3B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8E8F8B6D574C35241F322521302420\
2E241F281A192B1D16352621352A263C2C282D221F362B27382E27422E244F3A34
4837304E3A2E5842385A45395A4137583B2E4C33264C362856372A5F40316448376641345D3C31\
5D3B2C5F3E32583C334E302745261C351B162716111B110C160C0C1108080C0808
0C08080C080819130F2317130004047C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8A7C8344302B342723342925\
352722211712261D1B362A25382B273F322D40332E3E332B3E352D3E322A3E2A23
3C261E3625213D261F463027432D273B2A27422A2240271C4029204830274C352851342652372A\
492F224830274A2C2240281F311B162D1D181D120D1A110C160C0C1108080D0808
0C08081D1310181010313231251E1D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D9690905C403C342521342521\
322622392824302622352A263D312C382A263729253825224028213F271E362721
2C1E1A30231F2A19162F211E3627222F221D2919152A1C182A1914291713312018342219312018\
311A152E18132C19152C191522161119100C170D0C150C0C150C0C0D08080C0808
1D13161D131030231E182629635C5A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8584818F8183412E29322521\
352824342622392E2A31231E35292633241F3427233D3129382A26362722352520
31231E3326222C1C1B271D1A2A19152B19152416111E1410211511271814291714231511211410\
2215112818142415112114101C110C19110C160C0C150C0C0C08080C0808140B0B
1F18152A19153435354747477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D91888A5C3A35382824\
35282435272229201B3B2E2A392E2A3A2D292D211C32231C311F192E211C2E211C
251A1D251E1B2B1B1A2817142316191E14111E15111A110C1B14101B14101D14101B110C150C0C\
18100C1E13101B110C150C0C19100C191010160C0C0C0808150C0C1B1310241B17
251713414242413F3F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8889877A65613B2924\
3528243527223829252F272334282433241F2C1E1A271C18261611291E1A271919
281918211411221518191111160C0C191011191010160C0C181010150C0C181010160C0C191010\
1B1310181010160C0C0D08080C07080C08070C080818101017100C140B0B1C0F0B
3C3E3D3E3A3B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA4A3A46D5953\
352520322521312724342925372C283728272D1A162A1C182016111E130F1F1511
211410170C0C150C0B191011191111150C0C181010160C0C180F10160C0C2416130E0808160F0F\
1B13101A11100D08080C08081008081810101910101710102617143120183E3129
1F16107C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA4A3A4\
6F554F392C272F221D362A27382C283E2F2A3025202D201C26161A191111211410
1911101E15111D1410191010150C0C150C0C140B0B150C0C140B0B1C141016101030272D2A2729\
23161A170C0C1A11111C14101C1410181010281E1B2B1D192618143827213E3D3D
60544E7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
A6A8A96F534D42322D2E211C3127233A302B42312C34231A2F1F19201611181010
160C0C18100C191010160C0C150C0C181010150C0C181010150C0C140B0B282423261B20372C2D\
4337313A2929372A2730221E201611281C17251A173427233E2A223E3D3D564A47
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7C7A7AA7A8A965473C47352F382925372D2A40332E42353131201B2D1E19312420
2D221E2215111E14101A1111191010150C0C150C0C1B13161A11111C1410160E0E27201B2A201F\
1C12121E15111B13101B1211231511251A163020183C2D23534E4C4A3F3F7F7A7A
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7DA7ABAE624D42372620312622413531483D394A3A342F1F1B251817
2B19153225212D221D1C1211150C0C20171B21181C261E1B241A1D2F252322171A2C2626342726\
3A29243124212F221D322520372E2734262140332B4A4744665C537570737F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7DA7A6A9897C7D4D3C38342723392B27413A3B4D403D493B36
463D3A3627263129293F373B463D3C3527262F252B2F23263D34373328283B2A242C25233F2C27\
3B26223B251D3929243D2F2746342B482B20343A3D6056507F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D8B8C89A19B9F624F53413330382F2E403F444E4444
493E3B50453F4C403E443B364639384635303F312B3527282C1F1A342724392C283528243E2A22\
462D254831294E362E432B234437377366644D47447F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F79797F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA7A6A285828782777451475052474B
60565C61535656454050413D4E3F3B56454452413E55433D52423F4B3B33463A3552423E483C35\
4639313F2C27484141787275726D6960595A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D858481A19B9872757A
75726E827E877F7B827E70745E51594C454B4E4041503F3B483C3951403D483A3542332B48372F\
53514E8884825C5E5A6F686B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D85847F79777D8B8984958F8E7F7D7D8282897F7B7B7F7A7A7F7D7D827F7F8282847F7A7A\
5354507F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0116279 0.732558 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(270) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817E76
7B6B5D806F61806F65807368806F65807369807369807369807368806F64816F5F7C6A5B7C6555\
785E4F785D4E735A4B735A4B735A4B735A4B7358497355456F55456F55456F5545
6C534380807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
7B6B5D806F60806F65807368806F65807369807367817266817266816E61816D5D7C68587C6353\
785D4E785B4C735A4B735A4B735A4B7358497358497355476F55456F55456F5848
6C534380807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E807C7A80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E817E76
806F60806F65806F61807369806F65807368817266806E5F7C695A7C67587C6353786152735E4F\
735B4C735A4B6F55477358497358497358497355457355476F55476F55476C533F
6C655E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E807C7980807E807C7980807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807E76
7B6B5D806F61806F65806F65807368806F64806F657B6B5D6E675C776256785B4F735A4B735D4F\
735D4F735A4C7358496F55476F55476F55476F55476F57466F55476F55476C5343
80807E80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
806B5D806F64806F65806F65806F65806F65806F61806F65806F657C6B5C81625B775F50775B4E\
785A4F775B507351476F54476F574B6F55476F55476F55477358496F574A6C5343
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
806F60806F61806F60806F65806F65806F65806F65807368807369806F657B6B5D7C63587C6255\
7C6254785B4F7C6052735348735247735E546F55477355477355476E574B715B4C
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E817972807F78
806F61806F60806F64806F61806F65806F65807369806F65806F65807368806F65806F5F7B6758\
7C62577C6254785D4F785A4E735849735547735B4F6F55476F55476E55477B6E67
80807E80807E80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E6D5E52817E76715F56
806F61806F65806F61806F61806F65807368806F64807369807368807368806F64806F6481695B\
8166577C61547C615178584C785A4B7355476F55476F574A7357486C53437B7775
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807C79\
807C7980807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E807D7B512F27403F397B6B5D
806F61806F65806F65806F65806F65807369806F65806F61807367806D63816D60816B5B816D5D\
7C62577C62547C5D51785D4B7357487358487355476F5547735B4C71574880807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7A80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E7F807D573D2E6E6766221F22806F65
806F61807368806F65807368806F65806F65807369807368816F63816D5E81625A7C6152785E4F\
7C61527C61517860517358497858497358496F55456F55476F57486E574B80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E573D2E85847F2728237B6B5D806F61
806F65806F65806F64806F65806F65806F65806F658073688163597C60547C554C7C554A785347\
785D4E785B4C785B497357487355457355477355477355456F54457358497B6E67
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E807D7A817F7B272823807368806F64806F61
806F65806F63806F63806F5F806F65806F65807066806D638163597C49417C413778443E78423A\
78443E7853457354457355457351436F55457355477355476F54437353466F5748
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807C79\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E513D356E67637B6F67806F64806F64806F61
806F64816E6181695A806B5D806B5D806E6181635981554B815C547B4134784A41734038783A31\
73382E78423A6F483E6F52456F543F6F5243735547735547735547735245735A4B
715A4D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E7B716F7E71642228297B6B5D816E5E806F61806F61
806E61816B597C604F7B6256815D506925158163557C4D45774A42715149653B3073554575503F\
6E3C3469332773382E6F4A3E6F54416F513E6F5746735748735547735748735547
735A4B80787180807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E57433C5A5452635348806F60816D607B675A807368
806E61815D4978554364201880635D7744403B151077584E774D437B5E5581766C774038694B3F\
624A3C5F3A2F4927176E35296B4F406F513E735447735B4C785E4B735547735849
735748735B4B81787180807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E817F7E4B2F272B2E2E7B6B5D806F64806F607B6356806F65
8168597E5B42713A285F1E114529266E665D817269807871807B758077728170667C6B5D817063\
7B6F6867584F4F3A333B22186737296F5443735446775F51785E4F785D4B735445
735547735C4F736D707C777580807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E6D5E524B2F277263601D1F227B6B5D806E5E806E5E806F60806F64
81685978574A644C3B5D332D3B231D7750487C60527C5D5281686081655681594A78473B7C5549\
785B4C80604F6F504560493E3B1309673E336E5446775F4E7C6553785B4C735849
73534673574A6C665B6B635D716E7580807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E817E7C3121182E1C151D1F20634F48806F5F806D5F816759806759806D5F
816A5977503E775F527B6B5D806F6180635D7B5F56775B52775B527C514B72544B73463E734038\
6F42397353476F42366A392B57261A411D156F4C42775F4E7C6553785B49735445
6F5547735A4B593829807C7A6E676D80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E\
80807E817F7E716B6A0D1F20171E21806F64806F5F806B5D80625C7B6B5D806F60
816158785748694D3F806F65807369806F65806F65807369806D63816D5D7C62547C6152785D4B\
7858487351437849406F4239623A30522E2856312973574A7C6151785B49735545
6F52457357485D44393B2F29807C797B777580807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E807F78716F73806F617C63567C6B5C806F60806B5D806F6180635D806F61
816E5E785D4E7351437C6759806F65807369806F65806F6580736781625A7C5E4F7C6151785B4A\
7757486F523F6F4E3F6F523F6F4E3F6F4F3F6B4D466E5441785D4E785A48735445
6F5543735547462C233B362B6C655E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
81807E807F78816E5E816B5B8071687B6B5C7B6B5D806F61806F65806F65807369
806D637C66577858497254487B6B5D807369807066816F63807367816B5B7C6051785041785B49\
6F503F674F3F6B4D3C6B4B3A6B4D3A6B48386A5040735A4B785B4C7857486F5143
6F52456F57462D1B182D2A2777727980807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
807F787B7773816B5B7C6353775F4F6C6663806B5D806F65807369807369807369
80736780635B7C61517855477B6356806F6580736880635D7B6B5D816D5E785E4F7858496F4C3F\
6F50416B483A6B4D3C6B4E406F513E6A50406A4D3E7858497858497355476F5143
6F52436F55473B2119271F1C68615B80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
807F78816F5F7F604C775F52715B4F7B6B5D80635D806F65807369807369807369
807368806F60816555785E4B77584C806F65807367806F65806F65816E617C5E51785B4C735547\
7354456B4B3A6B483A6B4E406E5347725448785B4C785E4F735748735547735547
6F52456F57476E503B2F211A332621807C7980807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F7A\
8174688055467C62516B4D3E7B6B5D80635D806F61806F65807369807870807369
807368816F63816E5E775F52775F4F7B6B5D816D61806F60807066816B5B7C604F735445735243\
6F54416E4B3C6F4E3A6B4D406E5447775B507C6152785D4E735B4C7358496F5545
6F54456F574A735A4A674B393B201627201B80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807B76\
816356784B3E6F433A6E54486C675D806F61806F61806F65807369807369807368
807367816F637B6A5B7C67597B6B5D806F61806F617B635A806E5E816158785A48734F416E4E3F\
6B4B3C6F4F3C614A3E6A4D41735B4E775F507C6152785D4E735849735447735447
6F54437354487355426F51436B4B3C80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807B807E76\
815E54774B3C6F463E6C574C7B6B5D806F65807369806F65807368817266807367
806D63816E5E7C695A8167587B6B5D806F64807368806F65806D63816251785A4A6F4F416B4D3E\
674B3E674C3E6B5043735B4C775F507861527C6051785D4E735748735445735145
7352456F5448735A4D6B4C3D6F544885858280807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E81796B7F6251\
734F3B744B3B6A4D3F715B4F806F61806F65807368807367806F63816F637C695B
816D5D81625B7C67597C63567B6759806F65806F61806F65816F638160567854456F4F416B4D3E\
6B4E406752456E5747735B4C785E4F7C6254785E4F785A4B735A4B735245735143
6F51456F5748734D387354476F50416C656380807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E816E5C5C331E\
5F392C472C245C463C776356806F61806F64806F64806F65806F61806B5D7B6B5D
7C62587860527C60537C6A5B7C6B5C806F61806F65806F64816D617C65547753486F4F3F6B4B3C\
6B4E406F53466F5547785A4E785D4F785B4C786051785B4C7358497358496F5445
6F51456F52477255416B42327355476C453680807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807D81776F704432\
3B251B422922373130776356816F63806F65806F60816B5B816B5E7E63537E6353
7E63567B584F78584C7358497C66577B6B5D806F65806F65816D5E7C5E517352416B483C6B4D3C\
674A3C6E5143725748735547735B4C78584C735748735A4B6F55476F55476F5445
6F51456F52476942306335226B49366C453A80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817D748170663C140D\
341C15311F19342F2F776356806F5F7B6B5D806F64816E5E725A4A6E5342563E34
4B322A5A36266944396E3E2C6E3E2C776355806F65806F65816E617C5E517352416B4E3A6A4736\
674F426B50436653466652456F5447725A4A6F5748735A4B7358496E54456E5445
6F52456F52476B453456302256332768402D80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E7F807D807D747C604F5C372E\
22130F2918142126277B67597C6B5C806B5D806F60806F617C6353645448523A2E
321F19331F17422F275E3E2F593A3056352E7B675A806F65816F637C6251714E3E6A4936562011\
6246386E503B7050406A47357252436E51456752437358497358496E5243675143
6751456E5243643E305A37295A392F66342580807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E4B211885776B816555643C2F\
2A1C1E2215102522247C6B5C806F607C6B5C816F5F806F61816F63735B4C7C5E51
443D35312C25392E25403D375C433872584B7B6B5D80736981756B7C655473503E624436603D2C\
452923563C321E0C0B5433274C372C4B2E216146396948326F503E6E5445674E40
6751436B4B3E533225492C225940356B423785858280807E80807E80807E80807E80807E80807E\
80807E80807E80807E
807C7A807C7980807E807C7980807E80807E80807E80807E512F274B2F27280804643A2C3C2224\
291913271916171E217C6B5C7B6B5D8165567C67567B6B5D806F657B6B5D775F51
6F55476F574861493A604A3B6E5848775C4E7B675A8073698170647C65557352416B4B38624636\
5A403557463C221615231812402A243828213B2D23533F345643346B4A3A675143
67524357342B452C1F3B231946332971534385858280807E80807E80807E80807E80807E80807E\
80807E80807E80807E
807C79807C7980807E80807E80807E80807E80807E80807E512F27311F182D19142918141E0F0E\
2718152718142124257B6B5C7C6B5C806F6573544A7150407E63537B6251735548
6A43356742306C47356E4534785E4C7C63567B675A8073678170637C61557358476B4B3867513A\
6B4C3C6F5547674C3F1F26263B2C2441332A31312C51403262483C6F55436B4F42
6751434F3122311C17372219402A1F68372880807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E57362726120D231712261611241612\
1B13102F221E2C28287B6759806B5D7B6B5D806F65725F5262483D644B405E4B3F
5241364B39314F3A2E544035563D34715F527B6B5D806D63816E5E7C615273554A643A2A643927\
67513A6F55436F55456F5547674F405B42375A43376B4E406F513F6751436F5543
6B4E3E3120182317122F2C27412A1F5D291B80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6043352B120D2214101D1510130908\
22151029211C373430725F51806B5D806F61806F65806F657B6B5D6C524B544A47
6C524B634A3F634E435D473E72584C7B6B5D816F63816F6381635B7C6657735F506B4C45502E26\
47291E4B2F206C4B396F55457355456F55436751436F5241654E3F6F5147675143
573526331D16251E1A292721633524492C2480807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E57433C311F192314102215101A110C\
1D130F2B211C37342F6454487B6759806F61806F65807369807369807369807369
807369807369807369807369806F607B6B5D8073677C6A5B7C695A7C67587763557762556F574B\
4D3A3541312937251C472A1E623E305F45366745326143326B4E425E4B3E6F4F43
45251D2A18122518172A130E4F1F14492D252C241F80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E604942372924211612221510221510\
2217162B211C3B332C6650447B6759806F60806F65807369807369807871807871
807871807369807870807369807369806F60806F60816E5E7C67587C62547C67587C66587C6257\
735E526F524752423941342B3B2F254B352A473E34524034523E346E51456C4E3F
43241C2416111E15101C120D2A17133E262131292480807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60433537241B31201B20151025110C\
2718142D1F193A2E265A493D725F52806F60806F61806F65807369807369807871
807871807871807870807369807367807368806F5F816D5D7C67587C67587C62547C66577C6155\
786051735D4E6F55476653465E4C3F564338564237674B3F6751436B4A415F402F
3E231B2416112718141D15101F14102F1F183F393580807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E573D2E3929232E1E192A1A151B110C\
23141024161137251C4837296E584B7B6B5D806F61806F65807369807871807369
807871807870807870807369807367806F60816E61816A5B7C62547C66577C66577C62547C6152\
785D4E785A4B735B4C6F55477358496F55476E54456E51436E51456B4B3C482E25
25160E2819181B11101D120D1309082718143B312A63575580807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60433533251F3527222A1D192A1914\
1F1410271B172D231F3F2E255443357B6759806F61806F65807369807871807871
807369807870807369807369807368816F5F816E5E7C66577C66577C62547C62547C61527C6152\
785D4E735A4B735A4B735D4E6F55477355476E5445675143674F415C40323C221A
2C1E19160C0C1C12121208081911101D130F352B274F403A80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E5C49423929233529243326212A1A15\
1D120D27181432231C3E3128463C30725C4E806B5D806F65806F65807369807871
807871807871807369807369807368806F647C6A5B7C66577C61527C61547C6152786051785D4F\
785D4E735A4B7358497358497358496F52436F5445674E3F674639533225361F18
1D120D1D1212150C0C19110C170F0F241714130D09453B3680807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E81807E57433C352722372A25352722271813\
2A1C18241A162D1F1B412F25523E326A4D3F7B6759806F61806F65806F65807369
807871807871807870807369817266806F63816D5D7C6657776254785E4F7C5E52785D4E785B4C\
785A4E7357497358497355476F55476F54456B4E406C4B3C63423241291E311C16
2116111C14101C141018100C1C1410241714190E0980807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E807C794F3A3337261E332621372A25332621\
271B172D211C2F2119372F2952392C664C3F776356806F61806F65807369807369
80787080787080776F8172668171647C6B5C81695A7C61517C61527C6151785E4F785E4F785A4B\
735D4E7358496F52476F54456F54456E54456C4E3F6346364E30273B2019231712
1D120D1A1110160D0C0E0908160C0C2B211C1D120D85858280807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60494231221939292335292432241F\
2E1C172F2119312520382C2347302657413472584C7B6B5D806F64806F65807367
807367807367807368806F647C6A5B7C66577C67567C6051785D4C785E4F785E4C785B4C785D4E\
7358497358497355476F54456F4F416C4E3F6346364E312843291D2A1813211611
201510191110160C0C150C0C1F151200000031201B80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6D5E5737272233251F392A2535241B\
2E221D2A1C1833251F30231E3B2D27483329674C3E7C6B5C816F5F806F60806F64
806F60816F5F816F5F806F64816D5D7C63537C6151785849785A4B785A4E785D4E785B4C785547\
7357497355477355456F52436E4F4168493A54352843291D2A18131F130D1B1110
2015101B1110120808150C0C2216131D120D85858280807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6D5E5240302B352924332621372722\
2B1B192C1E192D211C35292431221939271F563F326F55457C68587C6A5B816E5E
816F5F816F5F7C6A5B7C6A5B816D5D7C5E4F785849785B49735445735849735849785849735445\
735445734F436E52436C503F664434614131452C1F2D19132317121B110C160C0C
160C0C0E09080D08082015122519131D120D80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E807B7A423029372A25352722372B26\
33231A2919153126212E221D372A252E1E193D2E25523A2E6C4B3B785D4E7C6251
7C65577C685A7C68587C66577C6251745544714E3E73503E735445735143735041735445735441\
6F4F416E4E3F6A493A64493A56392C49291D391F182717121B110C160D0C160C0C
1108080D0808130C0B1B130F21191427160D80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E5C4B4334241F352722332621\
3125202B1B192F1F18352722342A25372A252F231F3E30294633295A3B2C674A40
62483B6C4D3C7055477055456D4F41674534593A2B5F402E6942316E4B396F4E3C6E47386B4636\
6C463269473761423659372B4C2C1F391E172A17121D120D170D0C1208080D0808
0D08080D080819130F221613130D097B777580807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E7971723B2C25332723332924\
3326212117122B1F1C372A23372B263D312C3B2F2A3A2F293F332C453329472F27
452D23422D264F3025563C2F4E352C4730294C2F24492D1F4F30245A392B5D3D2C623C2B5D3D2E\
54332556372B543226472D22361E17311E191E120D1B110C160C0C1108080D0808
0C08081B130F160F0F2929261D120D80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E81807E4C3834332621352722\
3327223326212A231F342A253D312C392C273B2D283E2A25442F25402C21392A24
31201B372620311C173B27213D2A2434241F311D1734201A341D16381D1741281C41281C3F271B\
3D1F18391E17361F18341D172518121D120D190E0D160C0C160C0C0D08080D0808
1B13151B130F2B211C09090954453F80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E746B6C372722332621\
352924332621382E2932241F3B2E29362721372A253C2F283929243B2721372620
30231E3226212B1C1A2A1F1B2E1C172E1C172617122116112416122A19142C1914271712271712\
2717122C19142616112416111D120D1A110C160C0C150C0C0D08080D0808130C0B
1F1815271815130D0927201B80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817E7C4E3530352924\
3529243527222E231E3E302B362C27372C272E221D39271F34231C32241F30231E
271C1E2C221D2D1D1B2919152417192116112116111B110C1D15101E15102116111D120D170D0C\
1B110C2215101D120D170D0C1B110C191110160C0C0D0808150C0C19130F1F1815
2216131D16121D120D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E675753372621\
372A253527223529242F2723392C273627212E201B2C1E192A18122D211C291B19
291B192216122417191C1212190D0D1B11121A1110160D0C191110160D0C1A1110160D0C191110\
1B1310191110170D0C0D08080D08080D08080D0808181010160F0B150C0C20110C
211D191D120D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E4D403A\
30231E352722332924352A25372D283527252C1B162A1D19211612221510221712
231612180D0D170D0C1B1112191110150C0C191110160C0C181010160C0C2216130D0808181010\
1C14101A11100D08080D0808100808160F0F160F0F160F0F241714271D16242420
1309047B777580807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
4D3E3831272330231E372D28372D283B2E292E231F2D1F1B2416191A1110221510
1A11101E15101B1310181010160C0C160C0C150C0C160C0C150C0C1C14101810102D2425201E1D\
1F1417160D0C19111019130F19130F170F0F251D1A241A17241714352620271B12
4F372880807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807D4D3B36372D282E221D372C273D312C3B2E292F22192C1E191E1512191110
170D0C19110C1A1110160D0C160C0C181010150C0C181010150C0C150C0C272321241A1F362F2F\
362F2C2B212127211F251D1A1D1510251B17241A1733272334261F1D161140291F
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E8585824B372E3D312C332723382F2A40332D3D312C2E1E192A1D1929211C
241D1A1E13101C1410191110181010150C0C160C0C1B13161911101B13101810102C24202F2322\
221615261A15231813211514261712251B172F2119352B2335312B3B241B807C79
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E49372E362721372A2543373243393440332D2A1D19281A19
2E1C172F2520271E1A1A1110160C0C1F171A1E1618221C1820181C28211F1D15172924222F2523\
332621271F1C271E1A29211C2924212B211C342C25271F154A322471696C80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E494238362C27372A2542332E453E3C433732352C28
322B292F2220302926332D2C292725251E1D2922272B2223332D2C2D24233527222B24233E2D28\
37262237261E352924372C253B31293E2A2027201B4F3728807C7980807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E6C65674337353B2F2A3931304441424A3F3C
493D3849403A3B333238343243393A42352F382E2A31262830231F392C2A392D283529243F2C24\
402D25402E264131293C2A22483A344F372831201680807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E40373A3B362D3D393D534A48
4F4A484C45414B423C4D423F4D403A4B3F3C4138334439343B3331372F293B322E4138333D332D\
46332B422C254A3C334A372D3B241B4F403F80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
807C79807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E777275403B43
544948655F64594F4E5649424E43414E434153423F53423C4D403A53423C493B3449382F4F3D34\
40393040372D31241F685B5E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E777279807C796C656C4A454C4A454C453E38453B36453B36453B364037313B2E24\
3B3228807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0116279 0.97619 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(315) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282789282789282788D6C58
92705C92706092756492706092756492756492756492756492706092705C8D6C588D6854895F4C\
895F4C835B48835B48835B48835B48835B488357447F57407F57447F57407F5744
928278928278928278928278928278927E75928278928278928278928278928278928278928278\
928278928278928278
92827892817792857B92827892817792857B928278928278928278928278928278928278928278\
92827892827892817792857B9282789282789282789282789282789282788F6E5A
8F6E5B92705C92756792706092756492756492736191746494746494705D8F6D588C69548D624E\
8A5F4C845B47865D4A835B48835B488359468359467F57427F57427F57407F5D4E
927566928278928278928278928278927F75927F75928278928278928278928278928278928278\
928278928278928278
928278927F75927E7592857B927F75927F7592827892817792857B92817792857B928278928278\
928278928278927F75927F75928278928278928278928278928278928278916F5A
95736192706092736092756492706092766591715D8A6D5A956B548F6654896650876450835D4A\
835A488156447F5744845B47845B478459468457428157467F57447F5742856E60
856E6392827892827892827892827892827892817792857B928278928278928278928278928278\
928278928278928278
928278928278927E75928278928278928278928278927F75927F75927F75927F75928278928278\
9282789282789282789282789282789282789282789282789282789282788F6C58
8F705E92705E92706092736392736392705F8F6E5E8268567E614F89594D7F5844825B48825F4E\
825F4C8058467F5B467F57447F57447F57447F57428159447C54427F5744928278
928278928278928278928278928278928278927F75927F75928278928278928278928278928278\
928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278928278928278928278928278928278926E5A
926E5C92706192706392706092706092705E92725F926F5F8F6B598D64538D5C50875C48875A4A\
86564A87594A7A4C3F7E56447E5D4A7C523F8157448159467F5946815A488F7B72
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92827892827892827892827892827892827892827892827892827892827892705C
92705C92705E92705C9270639270609272629270609276659275648F6B598C65538A5D4E8D6050\
8A5E4C895D4C88584A805143835648815F507F523F8457448157448765558C7566
92827892827892827892827892827892827892827892817792857B928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282789282788C72659C8774
92705E92705C92705F927060927262927060927564926F5F92726292706092705E8F6A538C6352\
8A60508A614E86594A855B48805744815B49815B498157447C57448D7368927B6F
928278928278928278928278928278928278928278927F75927F7592827892827892817792847A\
92857B928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282786B5546B0907C8C6857
92706092705E92705B92705E92756492706092736192776A92736392736392705F926E5C916452\
9166508D6150895F4A875747875B488154427C5744835A488154438C786F8F7B72
928278928278928278928278928278928278928278928278928278928278928278927F75927B72\
927F75928278928278
92827892827892817792857B928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282788A787141221AA3846D8F6E57
927262926E5E927262926E5E927363927564926F5D92705E927361926B5F91725B927059946D5B\
8D63528C6150895B48895B46805946815742815746815B47845D4995857B928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278927F75927E7592857B928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789483794B2F2380645D573B36927060
927360927363927363927363927060927363927767927060916F5A946658916352895F4C8C614E\
8F64508C644E835D4C875946875B478159447E57427C57448159468D796F958F88
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928177928278927F75928278928278928278928278928278928278928278928278\
92827892827892827892827892827892827853362795807455382C8F6E57927060
92706092706092705F9270639270609272629270609273638D5B4D8D65548C5A4A8C5C4A895A48\
896B51875D47875D478356438159438657468357447F57428356458768569C9591
92827892827892827892827892827892827892827892827892827892827892827892817792857B\
928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282788A786F654E435B403492736392705C927060
927060926F5D92715F92715F927366927363926D5F9272628D54488C493C893F348C4A42874237\
8C5043815844845A4584574281524083594483574481574281523F815946896D5C
9C9F9E928278928278928278928278928278928278928278928278928278928278927F75927F75\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278473028BD9A8692736692706192705F927060
92705F916B59946B5695735E926E5E926D5B915B52925A4B8F5E52853B2C8F5144893B34813127\
873D30874A3D7C51407F5B447F5239815745865746835744835442835644835D4A
927F75928882928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892817792857B928278928278928278928278928278928278928278\
9282789282789282789282787E6962685243644F448F6E5B916D56957764926E5B
926D588C69518C5E4C9975638F5C4B6A2513B67F6B8C443A8753467842357333257F5E487F4534\
823A33753022923E317D5B4781563B815440815B46855844805242835946835744
8C6D5A9C958E928882928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892817792857B927F75927F75928278928278928278928278928278928278928278\
9282789282789282789282784730299D7763825F4F92705C8D6655927665927363
92685487553E8454416C2018A982746B1B135E1E138644368945348F67568A51447F392F6B3521\
653D2D5B2D20592716974532815F4583503D855D4A855D48855A44805444835946
835B488C766D9A867395887E928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278928278\
9282789282789282788C7C76361E1694745F92705F92705F8F68558F6859927060
8F5F4B8253377F372655180D85594D8A7F6D947A6D958F8592796D927C728C695A9482718F6B59\
82706857382F452921451D1395493287604A8C5F4A8A6352865A46835944835240
835B47817068877574988A889C8F7E928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282786B55465131297D5D54614C408F6E5A926D5892725D927663927061
8957467D533E6E3829510D0C5E221D8755448C5F4E926D5E976B5D8F71598F56448D53428A5B49\
92796287564474534751382C4812089B5E4A89644A8D6854895F4A835947815644
8656448162507F7169735D5B95887F928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892817792857B928278928278928278928278928278928278\
9282788C7A7326170F321B14855D4F7F5A49926F5A926858916D54956E5A926B5A
895F4882513B997C6A8F6F5A9265568F5D5189574A865245894C4284453E80453B7F362E7F3630\
7D4A3B824C3F7642346937274E1E1564281B986E56916B5489624A8357447F5442
835B47835F4C5C3B2CB9ADAE84706D95887E928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278927F75927F75928278928278928278928278928278928278\
928278836E6B4430280000064E3E38957361926C5892685A8F61568F765C92685A
8955487E4C3A8A685495796A927564926E5E9273639275649268588D6B528D6350895F4A895B46\
815440874A3E84433876352C62292159231D73422E8F64548C614A8357447F5440
835444835B48473027876D619C8C858F7B72928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92827888706888706A8F69558A614D916F5A95705C926E5B92685992695A926E59
8A634D825141865845977D6895776A927262926E5E92756492685A8D5C4E8C5D498C664F845945\
80564382523B7F513E7F553E7F4F3E7D4F3E815444865A44895D48815642815642
81594284594737221B927B718C7866928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
917F76957661916D5B92705B8D786D996F538F705E92725F926F5F927262927262
8F645487614A82503F8A6652927968927767926B5D917A649576638C614E8C5B4884513C846149\
774D3977513B7A4C3A7C4E36774A387A4935855D4A855D4A875B478254427F5240
7F57428159441F12108D746D9C8F8E928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
8F76688F766A8C644E89624C876C5D88665D927660927564927564927564927564
92685A8F5D508658448C594895796892756492685B8F65568F6E598A614D865A46814E3D7E503F\
7749387A4B387A4F3C7F523D7E50397A4F3B7F53408757448759468154427C503F
7F574281594726151049332BBDADA192857B928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92705C916F5D85543F916F5D885E4F8F6E5A92685E92756492766792715F927564
92705E926B55895A46895A44916A5B957668927361927265926E5E8D6554875847875B47815744\
7F4E3D794A357748397F5442855646875946865A48835A48835443815442815442
7F5441815A464930242B1B164D3A32CDC3B9928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278927C6F\
8F6C598D564484654C8465519C6B5A92685A927060927564927869927869927564
927060916F5A8D6552875E4A8C65508F6E5C916B5B957C66926D628C6B518658478156437F5440\
81563E774A38824F398156448658488D6150895F4C835D4A835B478159467C5742
81544381624E794E3A5D392A371D18583D34928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278926B5D\
8958457F42347F5241846756886E5E92725C926E5B927564927564927564927363
9273618D6C5B8F68548A6C5892705E92725C8F65548F6856926554895C4C81523F7F4F3D7A4D3B\
7D4F397A4E39784D3D7F5342855E4C8D614E895F4C835B48835744835444815642
7F543F865F4E7D4D378156459483798F7F75928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278927E71926F63\
894E427D42338354468C6B578F6E5E927564927262927060927665917461957666
926B5D8D7258916854916D58927363927361927366927060926656895D467F56437A4E3C774C3A\
734C3B7C4E3B815646895F4C8A635089614E8C5F4C835D4A835442835443815243
815442835C507E4E3B79503D8D776FA2988E928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789282788F6B558D614E\
794D37884F3A8F644E8F6B57927060927363927665927361926F5F8D6F5D916B58
926B589466588D6A548D6452926E5C92706092705E9270609167588C54467F503F7A4E3C7A4E3C\
795240795742855B48855F4A8C614E8C6350895A4883594683564481503F81503F
7F544283624E7F442E8666547C5344929998928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827892827892827892827887553E562E1A\
6B3C2D532E24A1725992705E92705E92705F927061927060926E598F6B568C6554
875C4C895F4E8C685394755F91715D95736392706092705F8D6859875D477F4F427D5139784B3B\
8154428159468457468A5F4D8C5F4E875F498A644F845B47845B478159467F5240
7F5244815B497A4731824F3C845142928275928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278927F75855848552F1F\
3C231948282289635092705F916F5F9573639270598C69569572608D6552946D58
926757905A4D8C614B89614D92725D95766592706092705E8D63528357447A4C3B7A4938754E3C\
7D4E3C7F58458458458A5B47895F4E845444865B488159467C54427F57447F5240
7F52447F57446A3A277539238A553C958581928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789172618C6458331009\
381D153B221B976B578D6C58926F5A8F705F92705F876350775442744E3A5C3E32
56352A723C288C54417F402B844831A78C759576689270608D65548354447A4E38784E36754535\
7F56447851417251417852417F58477D5A45895D4A835B487F57447A54427F5442
8454447F5444643727622D1E773E2C92897C928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789483798C65528456453C231D\
22120D341A148A6C588F6B578D6A5695705C92705C8F6B5978523F6B4D3F3E2B20
311B164222165A3C2F7A3C2A6F3C2F7B5142926F5F9270618D644F835442754935784E34571D0F\
8F634B82563B7E55437749348F5D4A7A5444815943845B49815946754F3D755442
7F54447A543F6134276D38277C403390796C8F7F75928278928278928278928278928278928278\
928278928278928278
92847A92857B92817792857B928278928278928278928278928278471D14CF9A7C8B614E4B2920\
24171929150F976F5A916F5A92705C8D6C5894715D95736387614F85584865473B
3526232D1D18412E265D4136794B3D8A68549277679278698D6D5B8359467448346B4333582D1F\
5D392F5E3C2C1F0C0A723D2B6143325430208356417E4F338D5A4378564575503E
7F52426D49384E2A1E5E30238F5744947C76928278928278928278928278928278928278928278\
928278928278928278
927E75928278927F75927F759282789282789282789282784C292045281F3E0B05844B36391F20\
2919122F1915876A568D6C5892705E895E4B8F7259997C6A8F6F5D89604C7E5240
78503D754F3D6C433176513B845A488A63509275649275648D6654835D487A4834724A356C3D2F\
63453B4E3930150E0E3D1E144D312839251C5E3929694333744B36754A39735442
7F54404E2C2446291B4A25198548359C998E95857B928278928278928278928278928278928278\
928278928278928278
927B72927F75928278928278928278928278928278928278351914382117301511351D161D0E0D\
301A153019138A6B568F6F5A8D6F5D8C5F547A4C3C81554197735C8C6B55815748
7844347C4B34844F38864F379E775E946C589270609276638D6657835F4E7A4E3A774D34755238\
815240795040412D282119183B251E3F2D254E382E65422F724E3F81543E765040
75523F3F2419351B15472418753322998C81928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278391D1429120C2718112C1711261510\
2115103D251E865D4A99725D8F6E5A8F6E5E886554714938683D316448396D4838
50352953362B5935286941327451418865548F6E5B926B5A8D6D54835C4A7A4B3E693723734029\
8865438459457F57437B5242684534603B2F734736784E3B7F523F75543F845942
6D4A39271812271711633B2E542419998278928278928278928278928278928278928278928278\
928278928278928278
92827892827892817792857B92827892827892827892827841251A29100B251510211510150908\
2917113927207D58459A725D95735E9270609272628F6C5A825748684039684039
7240336B3D2E683A2B714132845C4B927262916C5B94695D91635485614E7C524662362D4C241C\
55301F5A3522965C418D624B8157407954407552407D523D724F3E84564879543F
4E2E202C19122C20196639296A301F584238CAC3B9928278928278928278928278928278928278\
928278928278928278
928278928278927F75927F759282789282789282789282783D271F311B1526140E2615101B100B\
25140F3A2720754F3D8D6B5792705C927060927564927564927667927361927361
92715F92766792715F92725F8F6B558F705F8F705F8A68548D68548A6854876250815949603E33\
43272135241C45271B5732217D48356F4F397B4A33734733845847734E3D7D4F3F
361C152A17102C1B183D160E6322144A332A8F7F75928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278412A233B26201F130E28151025150F\
28181639261E6D493792695499766192705F927366927767927869927D7292796C
92766792766792756492756492725F926E5792705C8D68548D65528D63508D6B568D6354856150\
7D55486843384831293B261F452A205236295D40325A3D2F6F42387D5642774B39
331A1427151023161021110C3A19134B2F27928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827844271D3D251B2F1E1824140F2B110C\
2E1A15392319573A2D8F644D94745F95735E927060927564927667927564927D72
92796C92796C927564927564927361927363926F588D68548D6B568D65528D63508D6654896150\
855F4C7D5B487652416F4F3F6041325D3C2F684133744E3F764E3F754C3D5D3C29
351D162715102D19131E140F2815103F261B8A7670A69F94928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282783D2318402A222F1C162E19131D100B\
2B16102C17114D2C1F734A32A07A6692735E92706092756492796C927667927564
927D7292786992786992756492705C92705F916B599168548D63508D69548D66528D6350895F4C\
875B48875B48815A487F54428359467C57447A52407F52427F524274493742281E
24140C2E1A181F110F20120C150908371D156F51479F928B928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827841261B39272039251F2E1B162C1712\
23140F2E1C163E282057352695664E997761927363927363927B6C927D72927667
92766792756492756492756492705E916F58916B568D66528D66528D63508C63508F614E8C614E\
835B48835B48835D4A815B487F5442815744755240795240704F3D5A3A2C361D16
2D1D17180C0B1F12111408081D110F27150F5F443B99857B928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278402A223F29213C292236241D2E1813\
1E110C321B1542281E54382A774F3B977561957361927063927363927B6C927D72
92796C92766792715F9275649270608F6E5A8A65528C63508F614E91645389644E895F4C895F4E\
835D48835B48835946815B478159467D523F7C5644754D3B6B4536502D20331B15
1F120C1F1210180C0B1C100B1B100F2E1913654E446B5147928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789281779182793D29223D2821402C253A2720281610\
2E1C162C1B1539221B6239287849368F665095735E92706092726292726292796C
92796C92796C927564927564916F5D95715F8D68548A665287614E895D4C8C5F4E895B48875D4C\
875948815646845B468157447F57447C503E78503E754735643E2E3B2319321A14
21150F20140F1F130F1B100B2115102F19149483798F7F75928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278927F758F786F35211B43271D3927223F2B2434221C\
2C1B1534211B382117543B2F6E3F2D92644F947761957363927363927767927869
927B6E927B6E92766891746191705D916F5A9163508C614C8F64528C614C895F4E895D4A835B48\
835D4A8154447C54447F54427F56437A5442754D3B6A4230502D24391E16251710
1F120C1E1210190D0C0F09081B0D0C41261E887B7295857B928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282783F2922392117402B243E2A2336231C\
311B1539231939261F4C352858312487564097745F92705F927061927366927663
9276669276669273668F6E5A8A65528D68548C644F8C614C895F4C89614A895F4A895B47835F4C\
8359468359467F57447F52407D4F3D724F3C6A4431502E2545281B2A1611231610
25150F1B100F180C0B170C0B2917124D322C5B3A31928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282784D362F36221B3C271F442C25382218\
33211B311D163D28203A261E492F2671412E92684F9A7C6894715D95736192705F
92705C916F5A94715F9573618D66528C624E8C614C8757468A5D4C8A5D4C8C5F4C875946875946\
8356468159448157427D4F3F7A4F3D6B473557302342271B2C171121130C1F1210
2816101D1110140808180C0C30191495857B95857B928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278533C313E2A243C29223C27203D271F\
2D1A17321F1836231C3E2A233922184E2D207F553D956A5295725C94755F94725D
94745F916F5A8D6B5691705B8F68548959468A5D47875B46835643835D49875B47875946815442\
8454437F52407D5641774F3B71443169422F42271B2E18112517101D110B180D0C
1A0D0C1009080F08082C1713311B138C7F78928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278644D433621193E2B243A2720412D26\
341F162D19143C2A2335221B412B23331E16593C2C6A43329159419B725A8D6650
92705D8F6E588F6B54926B57875F4B7C513D86533F8A563F87584784544284513E845A4781543C\
7D4F417A4D3B754A386B4A385A342650291B381E162916101D110C190D0C180D0B
1408080E0808170C0B2715105E3C315B3D31928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278826B66422A2335211C3D28223D2821\
35241C2E19163D24193A2721412D263926203A271F4B342A60392A774732775244
74523F86553F87614C855E48774E3E714530673D2A77472F80483581533B854F3B7A4A39794832\
7E4A34774A376942346138284E291C3C1D162B17101F120C190D0C1408080F0808
0F08080E080720140F2C171389786F8F7B72928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282785B463D3220173C2922392922\
38251E21151039231C432D25412D26453129412D264531274C3429513427503027
4E2F2252302663382767433253342A5332275A302158311E5F332571422D71422D6D3E2A6B3F2D\
603423653C2D5C32254D2C20381C15361E171F110B1E110C180C0B1308070E0807
0E080722130F1A100F4F372E6E5E56928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278735D5936211B3927203C2821\
3A272134231D35241E412D2647322A402C25452F274A2C24523225452C203E2A23
372019422921391C15492D24432A223B251E3A1D163D231A3D1E164621184E2D1D4B2A1C4B2A1C\
4420174321183D20183B1E1627171121130C1B0D0C190D0B180D0B0E08070E0807
22131522130E32221D61474175574D928278928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282788C7872533A35301D173A2720\
3E2A2339261F45312936231C4A342C39251E422D264A302640272141271E3D271F
34211B3F29222B191633231C351C16331D162917112517112B1711331A14331B142C18112E1811\
2D1711341A142916102A16101E120C1D110C180C0B180C0B0E08080E0808170C0B
2C1B172C1713513A31583D34928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278755F5839221B3B2A23\
3E2A233A272036261E473029422E2738272136221B4A2B1F36221B3A261E38241D
2A1B1C38261D2F1B19301B152817182516102416101E110C23161024161026161020120C1B0D0C\
20120C2A16111F120C1B0D0C1F120C1D110F180C0B0E0808180C0B1D130E261814
2B171351372E51332B928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827892827892827888726C4A2F2936221C\
402C253A27203B2922392A23452E2639261E3220193620192C171137241D2D1B18
2C1B192817112917192012101C0D0C1F12111E1210190D0B1E1210190D0C1E1210190D0B1D110F\
20140F1D110F190D0B0F08080F09081009080F09081C100F1A100B180C0C2A130C
583F37543A31928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789282786B5147341E18\
301F193D28223C2B243C2B24422E273825212F1913301E182215102A1711251712
2916111A0D0C1B0D0C1F12111C100F180C0B1D1110180C0B1D1110180C0B2C18130D08071E1110\
2115101D11100E08080E08081308071A100F190F0E1B100F2C18132C1C1438251F
685B5A8F7B72928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789282789282786B5147\
321C1631231D36231C433029412E27412D272E1F193420192515161D110F281610
1D111021150F1E130F1B100F180D0C180D0C180D0C180D0C180D0C2115101E1110302425261C17\
211213180D0B1B100F1C120E1C120E1B100F2F1F192618152C1713492C21624434
724E3D928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
6B4D43321C1636272035221B412F274A342C3C2A243420162D1C181F14101D1110
190D0C1E120C1E1210190D0C180D0C1C100F170C0B1C100F170C0B190D0C3127232C1B2144352E\
372825281A1A2D201B271A151E130E2C1B162D1C173C29223E231B54382F68473A
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
95857B6E5147371D163D2D2738262047342C47322A422D252D1B142D1C162E201B
241A1621120E1F140F1B100F1B100F180C0B180D0C2115161B100E1F130F1F13123627213E2824\
2416142C1C152A1B142415132A17112F1E173821174C3227523B366F4E3E927F75
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92827892827868473A371E1635221C452F27523C344B39303D29232B1A142E1B19
331D1635251E291C161B100E180D0C2518192115162A1D1822161934231C1C12133F2D2534231F\
32221C2C1E192A1C162D1F1A33241D2F1E194C302454382D643D3188726C928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278684E412F14072D1C15422D264E39304D3F3C462F25372521
372521311E1B3429243829262C1E182518182D212534231E3A2D2C35231C34231E3E2C27422B25\
3E26203E271C392923432D244E352839251C6B4E41724A3A927F75928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278856E6954342E2F1B15402D244035355C4740523C35
513D3349373140302E4433304D3B37412E283F2D2A3524243A2721412C27422E273E2A234C2C21\
492D24472D244A312844291F62453B5E37215E3D31928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92847A92857B928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278928278684E4A37130F2D140E3A2B2A644E44
5B4A434E3B2E523E36534039563F36523B3549352C42302B412D2839282146322C49342C442D24\
513127482A2272514451261344130972544D928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
927B72927F75928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282788C787262474A4B292B
6240416446455E3B2C4C2E224A352B5C443C5E41355B42395B42395A4136533C33573A2E573F32\
6B5145340F034E2622826863928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278928278928278928278928278928278928278
9282788C78758C7572856B6961444A4A2D34472625442217442318442015411C123A1306371000\
65473A927F75928278928278928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.25526 0.245293 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B797972503C
816D607B69657B71697B655D7B71697B6D657B6D657B6D657B655D7B6959726155775D526E5146\
73594D6951466F55496F55496F55496F55496F4D4266513E6B51476B513E6B5147
92ABB87B79797B79797B79797B79797B70717B7E7E7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B75757B7E7E7B79797B75757B7E7E7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B797976533F
7B69617B695D7B716E7B655D7B71697B6D657B695D7769607C69607C6558736054745D4F745549\
74584B6B514574584B6F55496F55496F51456F51456651426B51456B513E6B6160
92979C7B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B74757B75757B7E7E7B74757B79797B79797B75757B7E7E7B75757B7E7E7B79797B7979\
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B7979775440
816D647B69617B6D657B6D657B69617B6D657765556B615983605178584F6F5B4C6F5C4F6F554A\
6F554A6A4E436B51456F54476F54476F51456F51416B51476B51456B51427B8D96
7B79797B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B70717B7E7E7B79797B79797B79797B74757B79797B74757B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B797976503C
7B6D657B69617B69617B6D657B69617B695D76655D6560596D584B764D4E6351406D55496D584F\
6D584D694C426654456B51456B51456B51456B51426F5549664D426B514592ABB8
7B79797B79797B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B533F
7B69617B69617B69657B69617B69617B695D7B6D657B686176605577585272514B72554772554D\
6E4E4971554B5F433C6A50456A5D51664A3C6F51456F54476651456F594D8CA2AF
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B5743
7B695D7B69617B695D7B69657B69617B6D657B69617B6D657B6D65766055765B5272554B775852\
72554A73594D6D4A47694D436F544A6A59516B4A3C6F51456B51457C716D818D92
7B79797B79797B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79796F59518C7A68
7B69617B695D7B695D7B69657B6D657B69617B6D657B68617B6D657B655D7B695D765D4E765952\
72584E72594D6E4E496D5546694D426B574D6B51456F5145665145888D96818383
7B79797B79797B79797B79797B79797B79797B79797B74757B79797B79797B79797B75757B7A7A\
7B7E7E7B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B7979463830AD8775816D60
7B69657B695D7B695D7B69617B71697B655D7B6D607B716E7B69617B69617B695D7B655977554E\
775C4E7759516E55456F4D456F55496A4D4266514574594D6A4E43879DAA7B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B74757B7475\
7B79797B79797B7979
7B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79796B61651A0E09E1BCA37B6959
7B6D6A7B655D7B6D657B655D7B6D657B6D657B685D7B69617B695D7B5C5D7768547864557C6058\
775C517359516F51437351466955496B4D3E6B51476F574A6F544792ABB87B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B75757B7E7E7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797F7D7D261712715C55816D647B6961
7B6D657B69617B6D657B69617B69617B6D657B71697B655D7765557C5555775C4E6E5549785C50\
785C50735C4C6951497451456F54476A51426A51456651456F5549889096818D92
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B75757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79793321197B6D657660557B69597B6965
7B69617B69617B695D7B69657B69617B6D657B69617B696172453F775750734E44735146735146\
736A546F54456F54476F4C416B54437451476F5145665141744F4675685D92ABB8
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B75757B7E7E\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79796B61612B231C816D617B69617B69597B6965
7B69617B65597B695C7B69607B6D697B6D657B5C597B68607239377340386F342E7949466F3C34\
7951486550416F56466F51416B4C417454476F51456A51426F493E6A584B7E746B
8CA6B47B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B74757B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B7979241815DAB199816D647B69617B695D7B6965
7B695D775D527C60548172647B69657B6155774547784E4474524D682E237D594F79404065241E\
7538306F493F6650446B5B486B49366F54497451476F51456F4D426F54476F584B
8C9CA17B83887B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79795A4C4D3129219783737B696177615181766D7B655D
7B61516E5949744F468C7871734941471A0EB78378733934715C545F4741632D23675646623329\
703C3B5D2A20883A3267614D6F4F366F50466F584B735546694A426F55496F5145
7E71658C9CA17B83887B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B75757B7E7E7B74757B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79791F1312B98F75816D657B695D72554B817A757B6961
7B594B6542316B473D521915A08E8543171670504A7044427650497B71686D2E27654B4A513429\
4C38343C1B144E2115944A3874654B74494173605273594A6D5143694D456F5145
6F584B7E889A88847A8183837B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79796F69720D0704DFB595816D647B695D765B527B69657B6961
734A3C5E3E2A662C23300F09A882758283747C6B678192947B69617B726C6E514A828886735549\
656969301E1B2A26243C1811994E38795F507E64517761586E5143694E436F493E
6F584A6B7980756C6E8888968C8D837B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79794638303B24216348419788737B695D7B61557B695B7B71687B6961
693D345E4D3D5B3632321116703D4072594B73554D7D6E65825750746655744138794C41704B3E\
838571663F34584A492B251F410E06A56F5E7E6B517C695F6E5143694D456B4D42
7455496A6459707A845C556592978D7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B7979\
7B79796F65690D0805271511D5A2907B69597B65597B5955776955816D607B5C59
694A3A674736928C847B6D617B5755765752705651704F4A76464367413E6C3D3A68342E683837\
694F436E3B375C3A32492E212E130F6D2E21978066826C5E6E5543694A42664C41
74584A6F5B4E413028BFBFCF7776768183837B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B79797B7979\
7B79795F535F050900000B147C7267816D607B61557B605D7659557B76607B5B59
69463D5F3C31887D708176717B6D657B655D7B6D657B6D657B5952725C4B775C516E5546735146\
654A3C753F3E6B40365C2F2C4826244B252774563A83675F735946694A42664D3E
7451476F584B191818B4A6A08C8D927B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79796A57567B6961765F55725D4E7C695C81695D7B69617B5B597B6D617B6559
6D514468433A7456498883758176717B68617B655D7B71697B575272514873514573604E6B4D41\
634C417048386B4A3D6B4E3D6B473D67483D745849795C4F73554665493E6B5041
6F54436F544A141212C7BBC586887E7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
77717281604A7761597863546F6D718C69527B6D657B6D657B68617B6D657B6861
76514B6D554468433A7C7061817A757B71697B5955777664816D606E4D44734E436B47386B5B4A\
5E4136674B3867453C6B4C366242386744347D635773584B6F514566493E6B4C41
6B54456F5549050608CEB5B2979DA07B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7660567B69616E51436F554672726E815C597B76697B71697B6D657B6D657B6D65
7B575276554B694A3D78544A86837D7B71697B57557665597B695D6D4D446E51436440376A5145\
5E3C31674738674B3F6F4F3E6A493B694E4073594D6F4D426F51456A4D4266493E
6B54436F544A020607573F37E0DCDD7B7E7E7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B574377655D623C2E82766B7B5C597B695D7B69657B71697B716D7B685D7B6D65
7B65597B6052694A3D73514382766E81716D7B695D7B6D6A7B655D72554B6A4A3F6F51456B5145\
66433966463462423A6F524678554D775C4E6E55496951476F4E436B4D426B4D42
6B51426F594D0D14131D181751423DE0E3E47B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B6961\
7351426F443A665643797A6E92645D7B695D7B69657B71697B726D7B6D657B6D65
7B655D77655572554B725C4E7B695D7B6961775C55817A6C7B5C5D6E5D4669463E6B5043674C3F\
6F4F3B5E403470473A745B4F79594F7C60546E55496955496F51456A5145665141
6F4C436F64555C3C2F3A2C292D47537B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B4D44\
693F3461322C6B5E4D77766B816D657B6D617B655D7B71697B6D657B6D657B6961
7B695D7261557B5D5272695C816D657B6D617657527B695D7B554E69514365433967483C634438\
6B4A3861453A6F514673594D735C517C5C516E55496951466F4D426F4C456A5042
6B4C3E74645A623C2C6F524996B7C37674757B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B6D657B544E\
6939345D362C745F54877A6C7B69657B71697B68617B69617B6D6577695C816D64
7B5C597269557C5C5177695B81716D7B6D607B69657B69617B554E694D3C61493E62453A62453A\
5E493E6F4D3E74584E795C4F77605473594D7355496955496F493E6F4C436B4C43
6B514174605E653C2E665145838D989297967B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979734D3A704D41\
583B2D7346368D74648676687B69657B6D657B6D657B695D7B655D7265597C6058
785C547C6158776555776155816D647B69617B69617B69617758526E433A61463C62453A67483C\
664F436B544578584F735C4D785C50735C517351466951466F4D436B4A3F6B493E
6B504574645B673122746F62664A4492BBC77B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B797965301D341F14\
55352B462A24BD937886766D7B69617B695D7B69617B69617B6559766559765B55
6D514773554D7463518271637C6D60816D697B69617B695D7259526A4A3C62413E674B3663443A\
7452466F584B745147745B4E79584F6F5748745B4E6B51456F54476B51456B493E
6B4C476F5B4D5E33237457486F423C92BBC27B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B716D633125201A13\
2C1F19392421BD937886766C77655D816D657B69596F59507E675C7054497D6152
795750794D48785E4A795E507E70618676717B69617B695D72514B64473A5E3F366744345E483F\
704B3F6B564970504379584A795C526B4A3F74584B6A5146664D426B51456B493E
6B4C476B54454B2A1D65322183534097C0D17B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B797977594B6E4A46170805\
29191334201CDAA2857C6D607B65597B6D647B695D67514759463B563E3246342F
462D276935258755446A3527724230A89E8B81716D7B696172554B64433A5E42316349365E3E36\
75574A655146604D436A4D426B524A6350417D5C4E6F5549664D42634C416B4C41
7451476B51453F231B52261C79443397CAD67B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797F7D7D70453365433B070C0E\
18100D311A15DAB1927B695D776155816D607B695D76605A513C31574944171A18
2115123F20155940387336276A463D82766781716E7B6D69725444644037563B2E6348323D140C\
947058705038664B415F3D2E825A4D634F437958466F544A6B51455A453A634F43
745047634C3C3F231D6234267E473F96C1C97674757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B7A7A7B7E7E7B75757B7E7E7B79797B79797B79797B79797B79792A100CDD94766D554A191414\
13121625140FE9B9997C695C7B695D7765597C695C816D6967504373514A302F2C
1D2124221D193C362E664A3E78554B7C7163817A757B726D72594B64433A54392C553E32371C18\
5E4B464832271509086E3A2A5A463843281D7F54446D46308356435E4F46634C41
744C434E3E32311C17572F24A1685896B6C37674757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B75757B7E7E7B74757B79797B79797B79797B79797B79792D1814271612430C057B4937221419\
1C14102B1814DFB595776559816D656A493F796A578C7F7976685D70534A61453D
5F473A5A463A5A40346E5946775951776558817A757B6D65725147644E405E392B59463658332C\
524D4A312D2B02060848221744322D291D186A41306343347554415E453C5E4F43
7451412C1E1C31201744231AA4543F9DCFDB7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B74757B79797B79797B79797B79797B79797B79797B79790500002F201826121032201B120A0B\
2C1A152D1814DAAE8F7B695C776960704E4E5F463A6B4B3F826959735B4D67463E
5F372B6B4531744635764835977D6B826E6081716D7B6D6072514B6455495E3C30624732634C38\
74544961463F091B2124211F2E25212E2A255D453A6146346350466F4D3E614D45
634C3E1A13102918144423198E3727A3D9E47B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B797906000021100C2015112515111C120F\
1F14103A2521C590748C726476695D7B69656A574D513B32523631463F3961433A
3A2D264739304D332A65463C776D607B69617B69617B5C5572614E6451465E39364E2C1C603B28\
82694A7454496B5143654A424E3C314C39336F4D3E63493B6B4C4563503E745443
4E3D34100D0B201410824D3D522118AED9E47B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B75757B7E7E7B79797B79797B79797B79790A01001B0C091D14101C1410110707\
2516113A2A25A6765D987A698171647B69657B6D65766459654845493F41654845
5A3F385A443C543B356A4A3F72615581716E7761557C5C59775D5268554A6345443E2824321B1A\
4930204C2F20945A448362526B513E614D41634C4167483C5E473D75524A6B503E
2C1F1816100E27201C8E48335224194D4946DBDEDF7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79790D04022316131E120F1F1410140E0A\
2414103A2A25996650927A6A8171647B69657B71697B6D657B716D7B6C657B6C65
7B685D7B716D7B685D7B685D7660527B6D64766559725D52775C51726155725C52674D47372C2D\
2B23211C1E1B41251C4C2F217242335D48386A4130633F307959506B4C4167483C
140F0D1E130F281B1A3F140D591E12343330D5D9DB7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790A05042F2320140F0D2214101D130F\
2518183829238559439776658C7A6C7B69617B6D697B71697B726D7B76767B716D
7B6C657B716D7B685D7B6D657B685D7B65557B695D72594E775C52775C5177655877585568594E\
644A434436322C29272925223F2A2343362C5E42364C3F367044436752415E4236
120D0D1E130F1D14111B0F0B391A15443530D5D9DB7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790F060431211A1F18161E120F25100B\
291A1636241B5D4033A0725D8D7E6E816D607B69657B71697B716D7B6D657B7676
7B716D7B716D7B685D7B6D657B695D7B69617B655572594E776558775C52775C51775C546E594D\
6D55496451465C4A3F5A4A404939314E3C34614339614C4566463E5E483C3F2E23
1A12111E130F27181417120E2514103E281DB4A2A79DA6A57B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790D0401352824231815251612170E0A\
2715112716114E2F227F5238A88E7E8171647B69657B71697B76767B6C657B6D65
7B76767B6D657B6D657B6D657B65557B6961775D52775C52775C51776154775C51775C516E5549\
6F51466F55496A554A6B4D426F514566514563493E6B4C436B4C415A3E32261B17
170E0A28191919100F19100B120808381E17876963B3C0C27B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790A03012F25232C211D251815211511\
1E130F291C183F2B2557382AB07F698C7A6B7B6D697B6D657B76717B76767B6C65
7B716D7B685D7B6D657B6D657B6559776555775D52775C51775C51775C51735C5178594D73594D\
6951466F55496F584B6A51466B4D426B51455A493E6B4C415A483C3C2C251D1411
211916130B0B191010100707181010271510725851BFC5C77B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790E05023326233326232A1F1C251511\
160F0B301B16412A20553B2D8C5B459281738171687B69657B6D657B76717B7676
7B716D7B6C657B685D7B6D657B655D76655572594E73584E78594D7C5C546E5C4D73554973584F\
6955466F55496F51456B54476B514567483C664F436344384E3A32342119211512
18100C170F10140B0B170F0B1810102C1914A8A6A57B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B75757776760D09073325213729252F221F1D110E\
251A17291A1735231D6A3F2D7E503F8D78688676687B69657B6D657B6D657B7676
7B716D7B716D7B685D7B6D6577615581695C72594E725C5172594D73554D73594D7351466F594F\
6F51466B4C456F54456B51456B514566463B634C415A3B3047332A231914251613
17120E1B13101A120F170F0B1C14102E1915F4FAFB7674757B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B7475766F700804033C251D2F2523352824261C1A\
2519162D201C3120185C44386D3F2F976F5E887E6E816D697B6D657B71697B726D
7B726D7B726D7B696177695C7761557C695C77554B735949785C5373594973594F73554A695549\
6F55496A4A426651456B4C416B5043634C415A443852362A3924202517121C1410
18100B191010150C0B0C0807180D0C462923DBE8E97B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B7979070302311F163529273528242B1F1B\
27171333231A3124204B3A2E512B2194614D928775816D647B69617B6D697B6D60
7B6D647B6D647B696576655572594E77605473554973584973584F735C4A73594D73514569584B\
6F51456F51456651456B493E67483C56473B52382C3924203120181D120F1B1410
1F130F160F10130B0B120B0B291814968D8D7674757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B7979120908261B173325213C29252A1D16\
281D1B2B1C1736272333241E412B267C493596765D8D7E717C695C816D647B695D
7B695D7765597C6960816D6072554B7355497359496F4D4574584E74584B79584B6F4D426F5447\
6F4C456B54456B514167453C63483C4E3E323F241D2C1F1821141018100B191010
241410160F100F0707150C0C321B15F1F7F77B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79791C120F291F1E33262333242031221D\
2317172A1D1831231E3528243120184E2D21855E47926F5D836B5C8271637C695B
7C6D607765597761557C695B73584E6F4A3F7457476F51456F4F436F584A7454476F51456B4C41\
6F4C43674C3F674F3F5E44385A3A2E51392B2A1C162114101C1410170F0B140B0C
170C0C0C08080C07072C1915311C14E0EEF37B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79792A1E1B1A120E3328242F221F392C28\
261914251714372B272D201C3828232A1A165C43336340338C5542927563755B4D
7E6B6179645779604F7E64586B51455E4034744B3D79503D7452496F50436F483A6F56496B4C38\
6748416344385E43365243364228213E23192518141E130F17100B140B0B140B0B
1007070B0707140B0B2816118D7A768183837B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79795F555D110807261C19342521352723\
291F192516163A251B2F24213C2E2A2B211E35272144312B5F382B714835614943
624B3E784B3A775B4A7355465C3F3658392A5736286D442E7344376F4E3A75473862463B623F2E\
6B4233634436513B324C30253920182D18141F141018100B140B0B1007070C0808
0C07070C07071F14102B1814E6E9E97B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79791F16131A130F3528242F2623\
2C211D18110E37241E3C2E2A392C283A2E2A352A273F322A44322A453026412B28
412A1F492B255A3528593E323E2B27462D254E2B204E2F1E532F2566412E633D2D57362858382B\
4F2E2155382E472B233C251D2917132A1C18160E0A18100B130B0B0F07070B0707
0C0707211410171010664A43AEBBBD7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979443B440F0A072F2420312521\
312420261E1B3226223C2E2A3D302C3528243A2B27412923482F2436271E312523
2C1C173A2723301914412D2735252131211D321A1534201A341B153F1F1843291C3E251B41271C\
371B15391E18321C16301B151C14101B110C140B0B150C0B140B0B0B07070C0707
21141821140F2C2220AEA2A07B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979706A70180D0D1B1310312420\
3528242F221F40322E2B1E1B44332E2B1F1B3A2B27442E2635242133221D312420
281D193C29261E14142E241E2C19152A1A152114101F15112514102E19152C1A15241510271611\
2514102E191521141023141017100B18100B130B0B140B0B0C07070C0707140B0B
2E1E1B2516128788887B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979463B3F120C09302824\
3528242F221F2E241F3C2C283D302C28211E2F201C462A1F271D1A31231E2F211D
21181C34251E2316172A1A152114181F140F1D141018100B1F141020141020141019100B160C0C\
1B110C27151118100B160C0C19100B181010130B0B0C0707140B0B19130F251917
2918147B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79796A6066140707261C1A\
3729252F221F3026223329253C2B272B201C291C18301E1921141033241F251818
23181922151022141A1A100F160C0C1A1110191010140B0B1A1110150C0B1A1110140B0B181010\
1C140F191010140B0B0C07070D08080D08080D0808181010170F0B150C0C28120D
827A7B8183837B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979382D2C0D0707\
2219163425213329253128243C2C282A1F20251611291D191A120F2716121D1411
241411140B0B170C0D191010170F0F140B0B191010130B0B191010130B0B2A19150906071B1111\
1D1410170F100B07070C0707100707171010150E0E181010291813261C16432F27
AEC0CC7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979382D2C\
090404241F1D2D201C3C2F2B392C283428262119162D1E1B1B111518100F221410
1810101B130F1A120F170F10140B0B140B0B150C0C140B0B150C0C1C14101B101026242C221E1B\
1B0F12120B0A160F0F18120E18110E170F102D201C1F17152917134C30258C8883
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
3929280A070627211E2D201C382D2843322E2C24222A1C1521181817110F191010
140B0B1A110C191010140B0B140B0B181010130B0B181010130B0B160C0C2F2A2A291C2740362E\
2A22231B16182923201E181517110E271A182A1D1935282438211B817A7A7B7E7E
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
817E7E382827120A082C28272E242143342F3A2E2A3528231F1613231916281F1E
1B18161B100D191310160E0F170F0F140B0B140B0B1D1519160E0E1B130F1D13143024213C2A25\
1B12122418132519141D12122214102C1E1A31201851382D6058618C8D887B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B7979321E18160E0B241B183F2F2A4C3D383F373429201E1F1613281A1A
2A1A152D221F1F1B17140D0E140B0B21181C1C1517271F1B1B1418322620130F1346362E2A1F20\
231C1A261E1B221B17261E1C322822261C1B5236287570716A656B7B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79793228220E08081914103A2B27443530403B3F3628212C2526
2F2826261B1B2826252F272E26231D1D161A241F282F221E322D3730231B231C1C41312D342523\
34221F34241C2E26243F2E264E382C241C189D928D7B74757B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B7979655B61261E1D0F0909352A2335343D5C4A45433836
423934362D2D3533363F34364238342C2322352C2E2A1F21332522362723392C28352824442820\
3F2A243C2C253F332E39251D614B4859554D7B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B7A7A7B7E7E7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B7979322830261E1D1A1B242923265A4C46
514D523D362E433935433936463A364336363F36302F2A2B382E2B2C28233F34343F3330392A23\
46312A3925217E6768493C314332367B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B7979706A70322D3A493C3F
5A515D493B424E403330282A312A285142444D3A2F4A3C38513F3A463A344638344B342B443830\
817A7B2119185F51577B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B7979706A757B7475655B663D37443D3744382D2C382B2A383230382D2C3228272D1E182D231D\
7B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.25526 0.488926 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(45) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6F513D
7E6E61786A6678726A78665E78726A786E66786E66786E6678665E786A596F6256745E526B5247\
70594D6652466C55496C55496C55496C55496C4E4263513F68514868513F685148
91ADBA787A7A787A7A787A7A787A7A787172787F7F787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787474787D7D787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A755641
7B6C66786A5D78726C78665E78726A786E6678685A7164587464587460526B594E69564A695045\
6C5549634E426F574B6C55496C55496C50446C504463514468514668513F686A6C
91A3AB787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787878787676787D7D787878787D7D787A7A787474787D7D787474787D7D787A7A787A7A\
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A71533E
7B6C61786A62786C66786E66786A62786A627162525D5E58765B4E70504A66544669594D6C584C\
6C594D695246685145685145685145685044685140665146685145685144859EAB
85898C787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787172787F7F787A7A787A7A787A7A787878787D7D787878787D7D787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A75513D
7B6E68786A64786A62786C64786860786A5B7568606F68627861527B565868584770554970554F\
70554D6948416352446851456851456851456851446F574C66504468514591ADBA
787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A785641
786C61786A5D786A64786A62786A62786A6078706A786E6675665C745F566F574F745C4E745D53\
6E524B745D506448416C4D456C5F57664E416F51456F53466350446F5D508EA8B5
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A785843
786A5D786A64786A5D786A64786A62787068786A62786A62786E6675665C78655A715E50745B56\
715A4E705B4D6A4D486955486C5548695952684E41685145665145807B7A8599A2
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A644A41826A56
786A64786A5D786A5B786A66787068786A62786E66786E6678706878665E786A60756052785E54\
715B4E715C506E504B6D5546694E42665549664E416F514566514587949E7E898B
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787474787676\
787D7D787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A2D261F8F6C59857565
786A66786A60786A62786A6478726A78665E786C5D78706A786860786860786A5B78685A715650\
715B4E7458526B5644694E42695549695044665145715D506954488BA6B37B7F7F
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878787A7A\
787D7D787A7A787A7A
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A5D565C0C0704D9AF9B7B6C5D
78706C786860787068786860786C64786E66786E64786A6478685A785758715D4D6E584B745950\
745D506E5C5266524370524869574B664E3D6651466B55486850448EABB8787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787676787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A7F8181130D097A6452B69883786A62
786C66786860786C64786860786A62786C6478706878665E716454745352715D4D6B564A735B4F\
70594D6E59486650466F50446951456950426C51466651456F574B878B8F7B8487
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787474787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A1B120D75655AAD8D807B6C5D786A66
786A62786A62786A5B786A64786A62787068786A627868606F3B387446446E3E396E403B70413D\
705E4E6950426950456C4A3F6653416F51466C5145635140714D426B5C50889EA6
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787474787D7D\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A5D5656483E37B39486786860786A59786A66
786A6278645678665878665B786C66786C64785654785D596F35346E3E35662F28744542693B33\
74494360453B685043685140664D417153486C51456951446F4940695B4D77675C
829198787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A110D0BB48E767E6C5D786A5D786A5B786A66
786A5B715C4F745B507B7163786C68785E50713B3D6E3E35664A42572C2071655677595360261F\
6B322A694238664B406859486849356B55456F51466C51456C50446C55486C574B
8B999C787F82787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A463B3C362A1FC39F877B6C66715E507B756E786862
785E4E68524269463D856B696B38352C0E089067606E413974665D72736E73372F5F473A523426\
634C464A2E2176332B6257456B4D346F4F476F594D745B49694E446C574B6C5145
756458828888787F82787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787474787D7D787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A100C0BAE886D8E7C74786A5D6F54487E7772786860
785A4B5E3D2D633F363A100F7B7B745F615C9E99917871747B7A797B817B6C4337727E7B6B635E\
575050351D173B1E13774130705F48714B44746355745B4D6D56466950456C5044
6C594C75849E7B7C797B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A64616E040302E1B1917E6E63786A5B7563587B716C786A62
6B44374F382557261E260C08AD7A6B836F5F7458527B8382786354786A5B68473F7A7C7D6B493C\
6F6A644D362C4B4740391C157E42307055497A655077665B6E56486650466C4A3F
6C5548667475675F5974758582847F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A2D261F1D1210593D31C6A68A7B6C5F785E52786256786E63786A5D
653D33655748745F58665F569E716F7461556E524B73605877413D664F4567312C6F383063342B\
7472615B352B5A4344382C263C0E068E60547C68507A6A606B5242664D42664E42
6F594C6963567F858E635E708E9489787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A645B610303021C110EE8B39F8B7C68786458785656716A597B7063785758
65473A5C42318B847E7B726A78615E75685E756E667868607B63586B594D74564B6E54436E554B\
6C57487136356036304B271C36130E6B2A1F856E597D675B6B5442664B42634B40
7155486C594C29201B9E9BA47D7E797B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A5B5665413B2978594FB697817B6C5D78625678675F755C587B736178635C
654E41614237897F717B706A786E66786860786C64786E667856526F574A745D526B5648705248\
604C3C6B474063503D60463C5D473D6544427D64437C65596E5845664B4263503F
7153486C594C151B1CB1A39E8287897B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A6F584D826A5A75696271665877685B7B6A5D786C6678636078776A786860
6C56496A4B406F52457D776A7B756E786C6478686078726A785F546F574A6E4D416E5B49634D3D\
564A3F674636644539644939644439624839745E4C7A615670544660473D664D40
6B53426853480B0F0FC5B7CA8B918E787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
716E6E7B5C47715E546E57466062688568567B6E6878706A786E66787068786C64
75524F6F57496A493E7D6F607E7570787068785452716C5B7B6A5B684C426E4F43634235635347\
5D3F3567493664483E6B50386246396445347F625674574B694E4260483D684D41
6855466F574C010608C4AAA38E9490787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
755D4D7B655A684E4266504374736C885B5678736A78726A786E66786E66786E66
785F54755E4F685040735348817E7878726A785F5A756E627B6C646C50496E564863473D6C5749\
5D3C32644639644B3F6D50416C4B4174574B796356694E42695044695044664B40
6855426B53480006074D362FBFB9BB787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
78584371645A5534267D75688261617B6C5F78716878726A787572786B62786E66
78665C786658654E427056467D796D7B6E6878685A78706A7868606F584B64493D694E42665145\
63463C684D3662443A6D52457959527B65576E594D66564A6C5448665044665044
6853456F5D522C281D39211B41342FB0B2B3787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A786156\
6B413260302B5D483B737D74886A5F78715F786A6678726A78706A786B62786E66
78665E7164546F584D7468597E73677B6C617157507B736578565668543F634239664D415F483B\
6B4D36553D3167443A7460527A5F537A63556B564A6654486C4E42695044665140
6F4B416F63555E403453403A78969FB0B0B0787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A784840\
6538305D312C6863507D7B6D88706878706878686278726A786E66786E66786860
78685A6F62547B5E52716A5D7E6E6878706875615C7B716678584F65544460433B5F483B5B4236\
6346385F463D775D4F7963557461557A5F536B564A6652466C4E426C4B45694D44
684B406F655D5D392A6B504599BBC8757878787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A78675C785346\
654136573C2D7166568B80707B6C6878726A786C64786A62786A627164567B6A5D
7857566F625277594E7166597E706C786C5D786862786A6278545065493B5D463C5F463A62483B\
5E4F43705542745D50775D5077615570584B6E52466654486C483D6C4B41664D41
66534071635F67403368574B76838D828787787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6B45305C3B31\
3C2B21583B2F887567887C6C786A66786C64786A6278685A7864586F6456775B56
6E574E74605674685974685B7E7065786A62786A64786A62715D5268493C5D483D5F463A64493D\
6850446D5546795953745D4F735B4F6E5D5270564A6654486C5246665044664B40
684F4671635D5F2C1D6F6A5C66443B91ABB0787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A5E2A1921160F\
3F2B24382421AB8872847770786A64786A5B786A5D786A62786860756A62786560
6F574F70524B6959497B685B776A5D7B6C68786A62786A5B6F564F64463A5A3E3D6249355E4439\
7052456F5B4D7251466C594B74554F6951446C5549634E4268514566504468493F
684D486B59495735226C5745683C3891BDC7787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A786E676233282D241D\
31231C332320C2947984776A7164587B6C64786A5B6452496C594D59433860493D
5E443F64413E6E574572574974655881736E786A62786A606F524D61483A5A41346445315B493F\
6C4C3F605245604B406D5548725D52634D406F594C69544866504468514568493F
684D4868554540251B52271C74483794BFCB787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A71524168433D0A0503\
19130F2A1D19D8A2847A6E607864587B6E63786A5B68564B54453B47382D322D2A
2C221F48281B6A473752281E562F229283737B6E68786A626F584B61463A5A43325E4D38573E36\
73584B6C594C6C5549715245684E48594A3D775B4D6C5549634E425B4B40604B40
6D53486853453C241C54281E7B433397C7D5787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A7F8181724835614038080F10\
1B130F311915E4B3937B6E617464587B6E61786A5D756660564339715C5620211E
1E1311371D13493B366636297A5C4E938C7A7E77727875726F5B4B6142394E392D5A42302E0E09\
7E5C4A6346305340364630256B4F435B4F41755744685146665044574439604F43
734F485B483A331F1B5B3527804F469CCDD7757878787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787676787D7D787474787D7D787A7A787A7A787A7A787A7A787A7A140705A2614B6854481A1917\
13131822140FEAB99877685B786A5D7466597466597B6C6868594B74574D403C33
58473E5A3D2C634837835C468562557D72637E797478706A6F5646614239553B2C5740343E251E\
615650342D270A06064F2C22483E332B1E165D4137523927714938594D42604F43
734D42453C2F251A15482B22986A5999C0CA727576787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787676787F7F787878787D7D787A7A787A7A787A7A787A7A160C0A120B093409044C3126100D12\
14120F2B1813EDB9987466597E6E6861403A6C594B857772756E6475615A6B544D
664D406450436C50447C65507D6158776A5C7E7B76786E666F50486150445A3E2E594D39623E30\
685C524F3B3106080A4622173B2D29241C186941306845367E5E495F493F5E4F43
7353411F1A19251B143E21189D4C3994BFCB757878787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A0000003022182915122E211C0D090A\
2C1914301814E4AE8E7B685B74685D725C586456475A4035634E4053423644312C
3D271F4A33255435285937297F6C5E7B6F617E726E786A5B6F50466156485A3D32624533604D39\
705949634C42383B376B4A3B52372C4E362A83574576533B6353486B5040665348
604D4012110F2316134022188B34259ED4DF787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0200001D100B1A13102014101C120F\
1E1511372723C89477856E61756C5F7B6C686F615865574B63464145413F6D4B44
573E32634C3E5E40347A584B8C847382736C7B6C667857546F5E4F6154485A383840261A4A2E21\
725C426D5345685141694E445D4B3B5B4B41785A465E4D40684D49604F406D5342
453A30090B0A1A131095594561291EAADCE6787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A0703011B0D0A1E15111B14100E0707\
2215113B2A26A3725A8C73637B7063786A66787068756C626F605C696964887268
726960787068756962857161786E617E7570716254745F5671625268574D6B544D524236392423\
39291D3020186F4537765A4D66513F635041604D4162463B5644396E50486D4F40
1F1A150F0D0C2A221D914733482117363836ADADAE787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A0604032018151D13101F1410140F0B\
2516113A2A269C664F9279697E7265786A6678726A786E6678757278726E78726E
786B62787572786B62786C627566587B6E63756658715E5274594E7162567462566E5650504744\
5B453D3A322B3F261C32231A4D2F263E372E4E33274E342773554E73504462483A
0C0D0C19120F261A1A34110B42170F2C312FDFDEDF787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A07050535262315110E2114101E1310\
271919392A248257418A7060857769786A60786C6678706878706A78757278726E
78706A78757278695E786E66786C6278685A786A5D6F5A4F746054745D52746457745956685C4E\
66524753463B4F43394F413556392C4E3B2E72493B605044794B4A5E5040514135
0C0C0C1D130F1B1411170F0A311A153C3531DCDCDD787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0905032D20171E18151F130F25100B\
2A1916362419563C3093695787796A7B6C5F786A6678726A787572786E66787572
78726E78726E78695E786E6678685A7868607864566F564B746457746054745D52745B526B584A\
6D5246665246604E42695447604B406851457350446850496B4A405F4B3B37291E
130F0F1D130F28181419130F2415113A261BA68F928B9190787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A060301332926221916261613160F0B\
221511211510462A207148309881717E7063786A6678726A78787678706A786E66
787572786B62786B62786E66786656786A60715C4F715E52745D52745D52745B50745D526B564A\
69524669554969594D6850446C50446651455B493F604D42604D404B3C30181715
0F0C0A25181917101016100B0F0707321B167E615BAAB5B5787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0703012F26232C221E251A16231613\
2014102A1D19402E294F382CA47865857364786C68786C6478736C78757278706A
78757278695E786E66786E6678665C716456715C50745B50745B50745D526E5D5270584B6E584B\
6652466C55496C574B69524668504466514557493F6D4D415B483B32282216110F
221A16130B0B1610100F07071710102616116D564FBCC4C7787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0705043128253428242C221E251612\
140F0B2E1A1642291F5B3B2C90584089796A7B7065786A64786C6478736C787572
78726E78706A786B62786E6678665E756858715C506E594E70584B7759536B594B70524670554F\
6654466C55496C504466514566504462463A664D416042363E342E261C161C1311
15100B140F0F140B0B17100B1911112E1914D5D1D09EA1A2787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A7874747170700606053024203529252D231F1B110E\
251C182C1D1931231D653F2D7C5141887769817567786A66787068787068787876
78726E78726E78695E786E667160527B66586F564B715B50745C5070584D6E594B705246695B50\
695446664A4468524466514568514566483D5E4F434F3A2F423329201913211513
16130F1B14101B131017100B1C14112F1915FFFFFF757878787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A7878787578780304033C251C2F25223428242A201D\
271C182D211C3221185B463A613D2F8A66568077687B6C68786C6478706878706A
786E66786E6678655C716456715C4F77685B71554B6E584670594F6E584670594F70584C665549\
6C5448694C42665345684B40684D415B4B404F42364832272C1F1D1B131118130F
150F0B171010130B0B0A0707150C0C492A24EBF0F0757878787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A050504312016332A27352925281E1A\
241612342219312521483A2F47261E8558468982717E6E63786A5D786C66786A5B
786A5D786A5D786862756858715C50745D526E4E436E5446705550705B4C70594F704E42665549\
6C50446C504463514568493F62483B4D44384833282C1E1C261C1519110E181310
201310161010130B0B120B0B2F1A15DCD0CDA7ADAE787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A110E0C271F1B3126223B29252B1E15\
291F1B291C183227232E221C3828246F4633856A528073667466597B6C61786A5B
786A5D71645874665B7B6C5D6F544A6E50456E5846694E446C574C6C5749745549694D41695346\
6C4A4466534566514062443A5B483B473D3235211B231C151B120F140F0B171010
221410150F100E0707140C0C321B16F7F7F7757878787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A16130E28211E3428243124202D231E\
201617281C172F221E35292531201745281D7053417E6153765D507A685B746256
74685B7164587460547764576B554B66493E6C5345694E446C4D416C53466F5145695044664B40\
684B415F493B5E493B5141364A352A44312621191319120F18130F160F0B130B0C
150C0B0A07070B0707301A16391E15EEF3F5787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A363033221A173328242D231F3B2E2A\
2A1C15261713392D282C201C352824261B174E3D304A352C6A43357D6455665044
6F5F586C59526C584A745F53604B404C382D5E41356A46356B4E44684F42684236685044664B35\
62483E5B42365740344B40343A251F321E161C14121B120F16100B130B0B130B0B
0F07070A0707150C0C281611BAACAAB3BABC787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A69686C17140E251D1A302420322622\
231E1921161737241A2D24203E302C2E25213527223C2E2A54352A593C2D443937
443B3356392B5C493B5A463A42322C442F23483024593C295F3B305E44326A4434574237503629\
58372D563D314436303D29222E1B142515121A130F150F0B120B0B0F07070B0707
0B07070B07072016112E1915F7F3F37B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A2220221E1916372A262F2824\
2D231F17110E33241D3C302C3B2E2A3C312C3A302B45382E45362C3D3127352726
36241A3C2420472C2246332A2F242238272342271F432A1C432822533A2B503629422F244A3327\
422A1F44332B39261F322119201512241B18130F0A16100B130B0B0F07070B0707
0B07072415111911117B5952D2D9DA787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A514E5716110D2F24202F2420\
3024202A211E3B2C273E302C3D322D3327243428243B242043292033231B2C2320
251A163226222817133428242C23202A201B291713281C182817143019153122182F2017312118\
2816132C181526171325171316120F17100B110A0B140B0B130B0B0A07070B0707
24151A241510322723DFD1CE949B9D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A727276262422211B18302420\
3529252F2420423530281E1A3E302C261D19372A264732283327242C231F2D2421
281E1A3F2C271D14152B241E2817132617131D130F1B14102113102B18142919141E1310201410\
1F13102A18141D1310201410140F0B17100B130B0B140B0B0B07070B0707150C0C
32201B281713C3C2C2B0B0B0787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A4D464C17100D332925\
3529252D231F28221D382B274235302924212D201C40271C2019172C201C2C201C
1C161B2D231D1E15162A19141E13171B140F1A131016100B1D14101D14101B1410160F0B130B0B\
18100B231511150F0B130B0B17100B171010130B0B0B0707140B0B1D15102D1E19
2D1915B6B5B5B6B8B8787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6F6E7019151227201D\
3529252D231F322824342B27362925261E1A251A162B1C181B120F30231E221717
21171821140F1F131817100F120B0B171010171010130B0B191111130B0B181010130B0B171010\
1D1510181010120B0B0A07070C08070B07080B070718101019100B140C0C25110C
B3A9AAB9BDBC787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A535453272220\
251C18302420312A262F28243C2D292B2122241612281C1818120F231511191310
211410110B0B140B0C171010171010140B0B181010130B0B191111130B0B2E1A150907071A1111\
1D1510160F100A07070B07071007071911111710101911112C1914312118674131
D8E1E77B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A535453\
241D1B2A26222A201B3C2F2B3B2D29352A27211C182D211C1B121617100F211410
1710101A13101B1410171010130B0B130B0B140C0C130B0B140C0C1C14101A1111292A362F2A28\
1E1216110B0B1610101C14101C141018101131231D271B172C1814543328B9BABA
97A3A9787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
59575625201D3028242C201C312A2640332E3128252F1E1622191718130F181010
120B0B19110B171010130B0B130B0B181010130B0B181010130B0B150C0C312D2E2C1E2943362C\
372C292920213C2F2A291F1A19130F2A1C192D1E19372A2645271FB9B2B2A1ADB0
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
7B7D7D504F4E261B15342E2A3328244335303A302B392E29201815241B17312522
241F1B1F130F1B1410160F10171010140B0B130B0B1D151A160F0F1C14101B12122B211D392922\
140E0F1A130F1D1510150F0F1E130F2D1E1A3221185F3E2E8B7F8AADB8B8787D7D
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A504C492A2620221B18392C274B3D39443E3A312825221915251819
26171330242024201B140E0F130B0B21191D20181C2C231E1D161B3C2C261611164E3C332F2324\
28201D3125202A201B30242143352A2F232065402FADA8AB919BA4828784787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A50514E4D4A512E2621372A26392E2A3A393F3F332D423735
463E392C22232828283C343F463E362D22242A242E3426233D374438292127201E46352E342522\
38241F38241B31282547342A5F3F2F2B1E18C3BDBA97A1A7787D7D787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A6C6B6E565C582A23283A302A33343C5B4C48464040
423C373B35334844454F3F3C463A332C24223B322F2E22212E221E2F231D392D2935292545271F\
462C244432284E3C3540271E614C4D849193AAB0B3787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787676787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A5051557275706567733B343B5B4C49
655F6A5348454E3F3A443A35463B384E3E4052433C3F373552413B41372F4D403D52413D44362D\
463A3233262386747C7F8482858A8E979E9D787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A727276565C5F85827D
82848965606878746D5855613E3B42504750463A32443B384C3E3A423A354439364230273B332B\
A49EA16F72759B999D888F8C787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A7272787E807A6C6E73626869787A7A75756E787474787D7D787A7A757878757573787D7D\
A4A3A7787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.25526 0.732558 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(90) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777797777797777797777797777796E503E
7B6B60776765776F6977635E776F69776B65776B65776B6577635E7767596E5F56735C526A5047\
6F574C6650466B53486B53486B53486B53486B4C42634F3E674F47674F3E674F47
8BA4B4777779777779777779777779776F71777B7E777779777779777779777779777779777779\
777779777779777779
777779776F71777779777779776F71777779777779777779777779777779777779777779777779\
777779777779776F71777779777779777779777779777779777779777779775744
7B6B6977675D776F6977635E776F69776B657763566E5C4F6E5C4F6E584B665048614D44614940\
6650465E49406B53486B53486B53486B4C426B4C42634F45674F47674F3E676E75
8BA4B4777779777779777779777779777779777B7E777779777779777779777779777779777779\
777779777779777779
777779777779777375777779777779777B7E777779776F71777779776F71777779777779777779\
777779777779777779777B7E7777797777797777797777797777797777796E503E
77675D776761776765776B6577676177635E6E5C4F5658566A534B6A46446149406654496B574C\
6B5A4F6B5348674F45634C42634C42634C42634F3E634F45674F45674F458BA4B8
8B9299777779777779777779777779777779776F71777779777779777779777779777779777779\
777779777779777779
777779777779776F71777B7E777779777779777779777779777B7E777779777B7E777779777779\
77777977777977777977777977777977777977777977777977777977777977503E
7B6B6977676577676177676177635E7767597767617B6B69816759805B5F6F5A4C74534874504C\
74504C6B4240634C42674F45674F45674F45674F456F564E674F45674F458BA4B4
777779777779777779777779777779777779777779777B7E777779777779777779777779777779\
777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779777779775744
776B60776759776761776761776761776761776F6D776F697767617363596E5B52775E54776257\
6F534C7762546B4B456F48456F5D5A674F456F4F456F4F45634C426F5D528BA4B4
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779777779775744
77675D77676577675D776761776761776F6977676177635E776B657767617B6B60736355735B58\
735B516F5A4C6A4D496B5A4B6B53456B5751674F45634F45634F45817E83869CAB
777779777779777779777779777779777779777779776F71777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777797777797777797777795D3C33775744
77676577675D776759776765776F69776761776B65776F69776F6977635E776761775F567B5F55\
735B4E735B516F504C6F53466B4C42634F4563493D6F4F45674F458191A07B8990
777779777779777779777779777779777779777779777779777B7E777779777779776F71776F71\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777797777797777791F15106E503E867767
776765776761776765776765776F6977635E776759776B6577635E77635E7767597767596E5352\
6E574E7354516A5443664C406653486B4F45674F456F5D526B564B8BA4B47B8082
777779777779777779777779777779777779777779777779777779777779777779777779777B7E\
777B7E777779777779
777779777779776F71777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779564952080101B7978C7B6B60
776F6D776761776F69776761776761776B65776F697767657763567750526E50456649416E5048\
735B4E6A5B516150436F50486B564B634C3C634F45674F4563494086A0AF777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777375777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779807F820C040281674FD5B69B776761
77676577635E77676177635E776761776761776B6577635E6E5F526E504F6E5B4B6A54496F574C\
6A54496A5443664D436B4C42664C426B4C426F4F47674F456F564B817E83777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779776F71777779777B7E777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777790C0402725A4FD0AEA27B6B60776765
776761776761776759776761776761776F6977676177635E6E31337334386A2E2F6A2E316F3133\
6F50466649406649426B453C634F3E6B4F456B4F45634F3E6F483E634C427B8990
777779777779777779777779777779777779777779777779777779777779777779776F71777779\
777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779777779\
77777977777977777977777977777956494C6E5752D0AEA277635E776759776765
776761775F52775F52775F56776761776761774D4F7750526E31336A3A326129226F3F3C663830\
6F3F3C5E393563483E634F3E634B416F4F476B4F456B4F456F48416B5A4E6F564B
777779777779777779777779777779777779777779777779777779777779777779777779777B7E\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777790804048167527B6756776759776759776765
7767596E584B6E534B776B60776B6977584B6E3133662E275D3F384B291D666B5B746D635E2821\
632A2366383067433C6753476748346753416B4F456B4F456B4F456B53476B5348
868D91777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779776F71777779777779777779777779777779777779777779777779\
7777797777797777797777793A2B2D472B1FD5AE947B6B696E584F776F6D776765
77584B66493B613C357B5B5F66272A1A03026649476A473E776B63869695823F3A5B362E473324\
57574F3B2F23632A235F4A3C6748326F4B466F564E745D4B6B4F456B564B6B4F45
6B5348776F6D777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779776F71777779777779777B7E777779777779777779777779777779777779777779\
7777797777797777797777790C0606957A6394837E77675D6E50457B6F6C77635E
77584B5D36295E363027090956636080A39EBCD2CE8096A1809AA47B89896E574880A7A5868B8F\
636369351F1A291A115735286B55436F4B46746155745A4F6F57486B4F456B4C42
6B564B6B7B9C6E6F76777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779777779\
7777797777797777795D5769060101C4A0877B6B6077675977675D7B7370776761
663D334731204B1F19250A07A26B5D8157486E423C776F6D775B48775F4B663C36736B70663C30\
7B675E6F4C3D6E6259371F195F332867484174614E77675B6F574C6650486B483E
6B4F45636A665B5045615F71777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777791F1510060101533124DAB69B7B6B6077584F77584F77675D776759
663D336F5D528B827A9AA390BC9A9877645D6A4D496A50496E2B2B5D36355D222166231F5A1D19\
665A4F562C235F3B3E4C322C370D066F4E4779614E77675E6A5040664940634C42
6B5A4E6B5D528B89946B6379868982777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779776F71777779777779777779777779777779777779777779\
7777795D5059000000130C0BDAB6A6948775775F567750566E675C776F63775056
66433B563B2C8077747B73707767657773697B7F78807B74807B6A736C5A7D695A746F56746D5B\
6F594A74313367312D53211644130E63241B6F584A775E576A504066494263483E
6F4F456B534819110F77737581807A777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777B7E777779777779777779777779777779777779\
7777795D5769866B52E19D84D8B094776759775F56776B60775B597B6B6077675D
66544466453C86796E776761776B65776761776761776B657750526E5048735B516A54496F5048\
5E4C3C634B415E5B4367594A7462547C5D5B806A49745D526A5443664942634F3E
6F53476B564B1D1F209A9694777B7E7B8082777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779775744866753776F6D736B5F73635977675D776B69776765777B70776765
6E584F6F50466B4B4173675C776F69776B65776761776F697763566E5B4B6A463D6A54435E493A\
4F453C5F41345F3E345F41345F3E345F443473604E79615B6F50465E423C63483E
674F41634F450B0C0DACA8C48B9299777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
6E67697757446E584F66493856545E7B63597B6B69776F6D776F69776F69776B65
77505273574E6F4C427D695D7B6B69776B65774D4F6E5F527763566649416A4D435E3B325E4942\
5F3B3467443463473E6B50386347386343327D5D537453486649405E453C674B41
6753476F564E030608A1938E80857E777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7757447B5F53664941614940776F668B5752776B69776F69776B65776B65776B65
7763567763526A54436F4F457B7370776F6977635E7773697B6B696E504F6F574C664C426F584C\
5F3B3263433863473E6B4E436F4B467D5D537D685D664C42664C426B4F45674B41
675341674F450607073B2A258F8E94777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7757446E5F564E2C1F776F638662667B6B60777369776F69777475776B65776B65
77635E77675D6650476F5748777669776761776356776F697767616E584B61463A664940634F45\
63483E6B50386343386B4E43795A557D695D6F5A4F66574C6B564B634F45634F45
6753476F5D55573B2754291F2F2320777B7E777779777779777779777779777779777779777779\
777779777779777779
77777977777977777977777977777977777977777977777977777977777977777977777977574C\
663123561D1D5A39326B79767B6B60777360776765776F69776B6577665E776B65
77635E6E5F526E584F776F6380776E7B6B606E504B77675D774D4F664938613C3563483E5B4138\
6748324F382E5F3E387360537961557762546A54496650466B49406B4C42674F3E
6F483E6F5D5263423A6F504ABCD7E1D0D7DC777779777779777779777779777779777779777779\
777779777779777779
77777977777977777977777977777977777977777977777977777977777977777977777977423E\
66312D5E2F2C676251817A6C8B6F69776F6D776765776F69776B65776B6577635E
7763566E5F527B5C5273675C7B6B69776F6D7767657B736C77584F6654445E423C5B443A573E34\
5B41365F443E7C63567D685B746257775E546A54496650466B4C426B48456B4845
6748416B615D5B3629674B4194B4C3777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779775E5277503E\
66463856412E6F67568B7E717B6B69776F69776B6577676177635E6E5C4F776356
7750526E584F73534B6E5F557B6B6977675977635E77676177505266433A5E423A5F443A63473C\
5F50466F5846735D51745A4F775E546F54496A4D436650466B453C6B483E634B3E
63533E6F615D6B42376B584F67727E727275777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779663C284E2921\
281B16412F277D7066867B6E77676577676177635E776356775F526E5F52735352
6650486E5B5273675C736B5F7B6F637767617767657767616E5F52664D3E5E483E5F443A63473C\
6B4E436F5347795655745A4F6F574C6A5B516F574C6653486B5348635347634B41
674B476F5D5D5B26196B6155673B328B9294777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777797777795D2617160E0A\
2D211D2B1E1E8B7769807370776765776759776759776761776765776B697B6B69
735B556F4D49614D40735C527363597767657767617767596E504B61403856393C5F44345B4136\
6B4E436F5A4E6F4F456653466F504C664940664D435E4940634C42634C4267483E
674B476753455336226352416336338BB2C1777779777779777779777779777779777779777779\
777779777779777779
77777977777977777977777977777977777977777977777977777977777977676166362D452E27\
37251E30211FB08C758073676E5F5277676177675D5D49415D493E473128473128
47312D523435664C406B4C426A574E7B6B697767617767616E504F61463A5B413263432E5B473E\
674A3E574B4153453C634F456B5A4F5E4C406B564B6B5348674F45674F4567483E
674B476753453B2119421C16633A2D8BB2BD777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777796E4939663C36050302\
0D0C0C201917BB967E776B5F775F567B6B607767596E584F53423A3E3129242425
1717182A1B124C36293E1C153E1C157763587767617767616E584B61463A5B41325B4E38533D34\
6F554A735D51785A4E78534767484553423A6F564B6B5348634C4257483E57483E
67534767534542251D56291F7740328FB7CA777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779807F82774939613C35161313\
1F1511301814CEA88E7B6F63736359776B6077675D7767656149408B6964322823
1F120F2F191138333257352A856B5B9999877B77747778796E5F5261433A4B352C533A2D240907\
63463A573B2745332B32231C534138574B3E6F5341634C42634C425741385F4B41
6F4B475741382F1C195333287C534C99CBDA777779777779777779777779777779777779777779\
777779777779777779
776F71777779776F71777779777779777779777779777779777779060000612E21665047271E1A\
17141A1F1310CAAC9173635977675D7363596E5F567767656E5F52745A4F5A463A
9268568C583D84563D96684D8B6A5B7D6E617B7370776B656E50426140385B3B2C5B3F344C2D25\
605A572426270203042F1E1A37332D1713103B2C293B2A1F5F3B2C57483E5F4E43
6F4B4142382C2017133A261F85655694BDC8727275777779777779777779777779777779777779\
777779777779777779
777375777B7E777779777B7E7777797777797777797777790801010601012207031F181505060C\
0F0F0D2A1712D8B0947363597B6B695D363561463E7B6B69776F697B6B69775E5B
6F4F456F564B7C5B51876B5981655D776A5E7B7774776B656E4D486150475B41325B503A6B4634\
7C65566F46360E0B0C3F2016322725221917603D2E6A443680624F634A415F4B41
6F53411B16161D1611371E1788403186A4B4727275777779777779777779777779777779777779\
777779777779777779
777B7E777B7E7777797777797777797777797777797777790801013122192D171429201C0A0809\
2A1813321814CEA2877B63597363597767616B61524B332B4731283A2921281D1B
2117142C211938231C3E251D66574F736B5F7B6F6C7763566E4D426154475B3C336341325F4B38\
6B5848674F456F584CA76D557246366B402F9D624E855C41635348674F416B554A
5F4B4114110F2014113B1F187D30238FC0CF777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777790C03011B0E0A15110F1B130F1D120F\
1D1510332724B28D747B675C776B607B6B697767617D6F6374534F48414378504C
734B3C7B5A496E493C8965569991808677747B6B697750526E584F6154495B363A381F1838211A\
5F4B38674F41674F3E6F4F456F55436B594D7C624D5B4E43674B4C5F4B41674F41
42352C07090915110F97604B6B30239ACEDC777779777779777779777779777779777779777779\
777779777779777779
777779777779776F717777797777797777797777797777791206041F0E0A1F14101B13100D0607\
1F13103929258F68547D675B776B60776765776F69776F697B73708B8C83A39487
8B8C8394948F94908B9A8E7F7D76697B73706E5F526E5F526E63526A574E745E546B5847442B2B\
2B211A171211482F29674F47634F3E674F415F4B415F413A4F3E34674B456F4B41
1B14120E0B0A2C231F844331421C14222625777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777B7E7777797777797777797777790C06062019171E14101F1310160F0B\
2516113729258F604C8B72647B6F63776765776F69776B65777475777475777475
776B65777475776B65776B6577675D7B6B60776356735C5273534B735F55776358775B586F5D5A\
8962565A423A3B251D1B17122A1C1925252435251F3B271F6B4E4A7850465F4438
0D0B0B17100E251819270D0A2C110C292D2CCBD3D8777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791209083B292518120F1F13101F1310\
28191A37292572503E7864587B6F6377675D776761776B65776B65776F6D776F6D
776F6D77747577665E776B65776B6577675D77675D6E584F735F55735B51735F557357556A5B4E\
6B574967534573594A7458476A4434593E2F7F4E3F735C4F7C4E4F574B3E483E34
0E0C0C1D130F1A1310140E0A271915353331C6CED3777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791206042B1D15201815211310250F0B\
2A18143522184A352B7C5B4F7D6F6377675D776765776F69777475776B65776F6D
776F6D776F6D77665E776B6577635677635E775F566E5048735F55735F55735B5173574E6A5447\
6F4D436B5046674F45785A4E78584C80625480594D6F504C6F4B41634A3A35231A
130D0D1D130F2A18141B1310221410332219877378777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777790C0402312927241A18271613150F0B\
1E14101D130F3B251D5C3B28816E617B6B60776765776F69777475776F6D776B65
776F6D77665E77665E776B6577635677675D6E584B6E5C52735B5173574E73574E735B516A5449\
6650466653486B5A4F674F456B4C42674F4557483E574B41574B3E42382E111313
0B0B09221719150F10130E0A0D06072A18146A535094A0A2777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791206042F25232D221F271B18271714\
2214102A1D193E2F2B45352C896A5E7B675C776765776761776B65776F6D776F6D
77747577665E776B65776B6577635E6E5F566E584F73574E73574E735B516A5B516A54496A5449\
6650466B53486B53486B5046674F45634F4557483E6F4B415F443A2F231F150E0E
251A17120B0B140E0F0E0707170F102516115F4F4BA8B7BD777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777790F09083129273529252F2320271613\
130E0A2A181440261D5D392988503A7D6A5E776B60776761776761776B65776F6D
776F6D776F6D776B65776B6577635E776759735C526A574E6A54497354516A54496F4D436F504C\
6650466B53486B4C42634C42634C425F413867483E5F3E34352C292017131B1210
130E0A130E0F130B0B170F0B1911112E1914E4EAEEB2BCC1777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779776F716E67690C06062D221F3327242D221F1A100D\
271C192E1E1A2D221E5A3B2C734E417D70667B6F63776765776F69776F69777475
776F6D776F6D77665E776B656E5C4F775F526E504873574E775B516F574C6A57496F5046665A4F\
665346634542634C42634F45674F4567483E5B4E4348382E423127221812201412
18130F1C14101C141018100B1C14102E1914E6F1F6777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777B7E0A07063B231A2F23203327242F2320\
2A1D192D211D33211854443A53392D78584C776B5F776765776761776B65776B65
77665E77665E775F576E5C4F6E54487363596E534B6A54436A54496A54436F574C6F574C665348\
6B50466B4C4267534567483E67483E57483E483E34422C24241A1A16100F15110F
130E0A160F10120A0B090607120B0B472925DAE5EA727275777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779120908311F17312927352925271D19\
24141133211831252142372E3D211B6F4B3F7D76697B6B60776759776761776356
77635677635677635E776759735C5273574E6A463E6A4D436F504F6F574C6F574F6F4940665046\
6B4C426B4C42634F4567483E5F443A483E34422C242418191F181317100D18130F
211310170F10120B0B130B0B331B16FFFFFFC6D7DC777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791F15132B221F2F25233927242D1D15\
2B1F1C271C192F2523291E1A2F24235C40316F58467363596E5F5677675D776759
77675D6E5F566E5F567767596E50486A49406A5443664C426653486653466F5046664940664F45\
6B4542634F45634F3E5F413857443A453A302F1C191F181317100D110D0A150F10
211310150F100E0707130B0B2F1A15DAE5EA727275777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791F15102B211F3529252F23202B221F\
1F1518251A172D211D352925311F17392219564438674F476A4D44735C526E584F
6E5F566E5F56735C52735C5266504861463D664C426649426B483E6B4C426B4C42664C4263483E\
63483E5B4438574138483B343F2E253B29211D161115100D15110F150F0B120B0B
120B0B0906070A0707311B163D1F15DAE5EA777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777794E424C3021203327242D221F3B2E2B\
2F1E162917133A2C282B1F1C332724241A183D352C322823482F276650465A433A
61504E614D4B614D446A574E5A433A412E274B352C5B3B2C63483E634B41633B3263483E634832\
5F443A573E34533A30483A3035211D2918131811101A110F150F0B120A0B120B0B
0F07070A0707150C0C261611CECED2D0E1EA777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779271F16251D192D221F2F2320\
201C181F15183322192D221F3E302C332724332623352928462F28412F252C282B
2A2A2738261D45362B45362E2E242235251D3B281F4533234C31284F38295F3E2E4F3D32422C24\
482C274C342B3B312D32221F27161120131117110F130E0A110A0B0E07070A0707
0A07070B07072016112F1A15E4EAEE7B8082777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779342B33271E1D382A272F2925\
2F232018110E2E221D3B302E3B2E2B3D312D40332F4A3B3145372D362F282B2223
2E1C15301C1B35211D352622241C1D2B212037221E3A241935211E4131263E2D2532261F3E2D23\
38261D352C262F201B2B1C161B1311201A18120E0A150F0B120B0B0F07070B0707
0B07072616111A111184625DDAE5EA777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779665E692719152F23202D221F\
2F221F2F2320402F2B3E302C3D312D3126232F2421351F1D3F221D321E17291F1E
2018152B2321201411272220251F1E251D192014111D18161D1412221411221914221914231A15\
1C11102013111B12101D141113100E130E0A0F090A120B0B120B0B0A07070B0707
26161B261611372925EEEEEEA3B2B8777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779413A392B221F2F2320\
3529252F2320423531271D19372B28241A173327244733293129252722202B2321
291E1A402C281F141627221E2414112414111B110E18130F1D120F2717142517141A110F1A110F\
1A110F2517141B130F1D130F130E0A160F0B120B0B130B0B0A07070A0707150C0C
33201B2A1813E4EAEED0D7DC777779777779777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777795D5059241412352925\
3529252D221F241E1A3529264537322B26232B1F1C3922191D1614271D19291E1A
1A141A251F1C1C14152917131D111718130F18130F150F0B1B13101A131018130F130E0A110A0B\
150F0B1F1310130E0A110A0B150F0B170F10120B0B0A0707130B0B20161133201B
2F1A15DAE1E5DAE5EA777779777779777779777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777797777792C241F2B2320\
3327242D221F352925332A27312623241A17241815251A1717100E2D211D201517
2015171F130E1D1117140E0F0F0A0A150F0F160F10120A0B170F10120A0B160F10120A0B170F10\
1D1510170F10110A0B0A07070A07070A07070A07071810101A110C130B0B210F0B
CECACEDAE5EA777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779473B38\
291E1A2D221F2F29252D27243B2D292D2224251512271B1818120F1F131016110E
1E130F100A0A110A0B150F0F170F10130B0B170F10120B0B181010120B0B2F1A150A0707181010\
1C1410160F100A07070A07071007071A11111A11111A11112E19143B241A814F39
E4EEF37B8082777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
473532312A27291E1A3B2D293B2D29372B28241E192D221E1D1218160F101F1310
160F101A13101D1510181010120B0B120B0B130B0B120B0B130B0B1C14101810102D2D3D393334\
221419120A0B170F1020161120161119111134241F2E1E192E1914573329D0DCE5
A8C0CF777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
807F824737343B2D292B1F1C2B26233D312D372B28331F17251A171A130F170F10
110A0B170F0B160F10120A0B120B0B181010130B0B181010130B0B130B0B322F312E1E2B45332A\
45332D3729284C383234241F1B13102C1D192E1E19382A274F2C23DAD9DEB7CED8
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779727275402C233D312D382A2742332F3B2F2C3D312D241A18271B18392925
2E241F2315101C1410170F10181010130B0B120B0B1D151A170F101D1510181010251D1833261F\
0E0B0C120E0C15100D0F0B0C1B110E2C1D19332118673F2EA99DABBCD3DC777B7E
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779433B34241A17332724493B3849423F3B2F2C271B18221618
2414113325212A231F160F10120B0B22191F231A202F262021181D42302B1B1319513E37332527\
2F23203B2A2532231F392925513E31372925704634D0D0DAADC5D3868E8B777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777798D849645373233272430262336353E493B38574642
5A4F4933272929292B473D4E62544D3D2C2C302732372727473D4E3E2D272D221F47352E352421\
3B231F3B231A3529254D372C6A4231351F18D0D7DCA8C0CF777B7E777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777798B9290493B4540332F31313A574B4A4A4448
433D3A433B385950525C464149393030242242352F312321291E19291E18392D2935292545261E\
4C2D244C352B5A423A47271F5C494FA8C0CFC6D7E1777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
776F71777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779B7C0BDACA8B94E424F5A4A4B
776B7E69565B59423E473834473B38594448634C4750423F6A504954443A594845634C474E4036\
464038302624847889ADC0CABCD3DCA8B7B8777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777B7E777B7E777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779808582B7BCB4
A3AEAF827F8B9EA0A1807D944E485B4E485B413834413836473B384138364337363A2A22352D25\
B7B6BFB7C0CAC6D3D88F9C99777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779777779777779
77777977777980857E777B7E8B928BADB2ABADB2ABB2B1B7B2BCC1B2BCC1B2BCC1B7C0C6BCC9D3\
BCC5CF777B7E777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.25526 0.97619 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(135) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E61625D
65656165656565696965656565696965696965696965696965656565656161625D615E585E5650\
5E56505A524C5A524C5A524C5A524C5A524C5A4E47574E43574E47574E43574E47
65757E65757E65757E65757E65757E65717A65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E656E7765727B65757E656E7765727B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E686863
68686A65656165696765656565696965696965635C5E5A515B5A515B565058504C524C48514B46\
544D48514A4458504A5A524C5A524C5A4C465A4C46574E49574E49574E4357686F
65829165757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65788165717A65727B65788165788165757E656E7765727B656E7765727B65757E65757E\
65757E65757E65788165788165757E65757E65757E65757E65757E65757E5E5F5A
62635C6565656563666569696565656560605E5C584C595A52525058464854474457514C5A5852\
5A5A545D564F574E47524A44524A44524C46524E42544E46574E47574E49728997
72899465757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65717A65757E65757E65757E65757E65788165788165788165788165757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E68625D
68656865656865656565636365636365655E686868756E70716D666E6468675D5865524C654D4E\
654D505E4446574A46574E47574E47574E47574E495D544F5A5049574E4765757E
65757E65757E65757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656863
65686065655B656563656565656565656568656C6F656F6E686B6D616A6161615D68615D68635B\
61565268645B63504D60454760585B5A524D5D4E475D4C46574C465D5A54687B85
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656561
656561656568656561656563656565656C6C656565656060656969686B6D6B716A65695F615C5D\
655E595E58505F54515E5B515A4E445D565457524D524E47544E476871796B8291
65757E65757E65757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E5243405B4F49
65656865656165655E656565656C6C656565656969656F6E656C6C6565656565686864616B635B\
655C54655C5761545262524C5E4E47544A42544A425D4E475A4E4761747F657C88
65757E65757E65757E65757E65757E65757E65757E65788165788165757E65757E656E77656B75\
65727B65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E211E1C3F3E386B6E65
65656565656865656B65656865696965656565635C65666465636365636365655E6568605E595B\
5E57546153545E564A574E4457524C5D50495A4E475A5A545D59516B7F88687B85
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E657881657B85\
65788165757E65757E
65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E4C4E5D180E0E545259686866
656C6C656868656C6C656868656363656969656F7165656865635C6552555E4A4A5545425B504A\
615A525B5C5454524C5E524D5E544D544E42544E46544A4452484262727B65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165717A65727B65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E6B7C8617120E6E6A58A09B86656565
6563666563636563636563636565656563636566676565655E5F5A5B57545E5A525E56505B534E\
58514B5B51465A5048574C46574A445D4C47604E495A4E475D544D615D5F62686F
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E656E7765757E65788165757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E0F0B09625D5AA29E9A686866656565
65656565656565655E656563656565656C6C65656565636361383F612E385B2A315B28315E2A32\
5E42425748445748445A4640544C40584E465A4E47574E425A463F4F3D365B6266
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656E7765727B\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E4C4E578A878B9C9592656363656561656565
656565655F58655C56655C56656360656363655056654A536140445B3B36542B265B3939573834\
5B343754333752413E524E42544A435A4C475A4E475D4E495D4A455D544D544037
5B585965757E65757E65757E65757E65757E65757E65757E65757E65757E65757E657881657881\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E13111132332F65635765655B65655E656565
65655E5E5B545B524E62625E6568686559525E3839552A284F3E394130264F64585E726754312B\
4F262157302D5A3B3A574A47574A39544E3E584E465A4E475A50495A4E475A504A
656869656F7565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E37333A5E4A4093877968686A5E595762666A65686A
6559545B4C42523D385E485158282F1A0304312D305B504A68625F7FA5A97447454F2E2B3E3E2F\
4459513033274424205138345446385D48435D524D625D4F5E52495A544D5A4E47
5240395B5250656F7565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E656E7765727B65788165788165757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E1B1918525751757777656561615750656060656363
655E58573E355137321F08082D44498CCCCB99C9CB71AAB96EA2B3688088657D7178AEAF84A1AC\
617077382D29191A122F261F54463F5A4C47625852625854625A4F5E50475A4C46
5A524C526079556174626F7865757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E525A711C12125B595665655E65655E686E68686E6D656565
58454044392B3E221B2F100A623A36653E385B3B38625859655D50655A4B5B44425B545D58423B\
75655E7F6D5D77736B2D241E31211F4F3B395B564A65635B615B565A544F5A4A43
5A4A4454564D464841464C5F5B687865757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E211E1C01000049362F968A7D68686365595465545065605965655B
5E4E466A625D81958CA6C9B1999A97685F615B4D4E55403E58292F4F2B334E25275118174C181A\
4C3B3A4F352F5A393D5B423F2A0E083B2E315E514A615E585E564A5A4C44544E47
58574F5D534C787E8663697B626F7865757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E\
65757E5254630A09080F0D0C727977787C74655F5A65545D5E616162686365525A
5E4D4C4C3B305E5A5C686F746571706879746E86837184816E8A7B6B78676E7869687E66687764\
61524864373C60302F54221A4E1A14411A154636365E52505E534A5A4E47574842
5A4A445A4D48160E0C3E42416B7779626F7865757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E65757E\
65757E5A687CB3A695EFBD9FA1907C62635C65625D656E63685C5F686061656E63
5E5F5460504A655E58625D5B65696965686865636365696965545D615252615A545E56525E524D\
5450434F524551624C606757747363756966635A455851485B534A5A4E47575043
5A50475A524C3333324F595C5B6B72687B8565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E6F65556F655B687579656D685E5F5A62656165686A656E6D65757465686D
65635F645B5358443E58514D626664656C6C656868656969656E636161565B48425B4F44514C3F\
4646404C42384F3B354F3E354F3D355144355D594F615B585E504C544642544542
544C42524C441B161555637E6B7F9165757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
5E687162605C5E5952554539494E595E5F61686568656C6F656F6E656C6C656C6C
685961685C5B64554D655752655D5E6566676552585E54516260595B534E5B524B513B36514342\
573F395742385448405A4E3C574A3B54423562504A62504A574A44544842574A43
574E495D544F120E104148485B686965757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
68605568605B5B514E544B486862586F5758656065656969656969656969656969
656E6368695D615D4F5B4C44625D5E656969656E6A68717068686D655C5F615A565D574F60554D\
57423B54403B54443F574A47604C4A6D5D5967625B574E47574C465D50495A4C45
574E42544C441C13101A16163A424E65727B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
6565615E5F5849372C5E5F586F5E66686863656E68656969657177656C6E656969
656568656B685E5A555E5A4F5E645A62605E65635C656C69656868616158574C44574A44544E47\
574E475D523E57443957484262575568645F615A545A5A545A5951545049545049
57504B5D5A557D5C3F582E22160F0F2A343D65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E655A57\
583833491C1F5137385160635B6B63656E63656565656969656664656664656969
6565655E5F5A61615B686F6A6B716C6868605E5252625A576550535B4A4258433D5445404F403A\
5446354539324C3D395D574F615D54615C545E56505A504A5A4A445D4C465A4E42
5D48405D534E5D4E4A796259C0DADF9FBAC265757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E655258\
5E3C3E57383757534B6B675F6F6868656C7265686A656969656969656969656363
65635C61625A685E5865625D656568656C72687172686E706561595E5850544A454F443D4C3F38\
493D39544642665F57676259625E59615C575E56505A524C5A4E475A48475D4549
574845585657513F3454463E6B7C8668788165757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65605D655F51\
5E5749514A385A594D6B6B65686868656969656C6C6565656560605E5A53626057
6552586153545E54505E585465636365635C65636065656565575F5E474657464054463F574840\
5350485A57495D574E5E5650655A545E534E5B4D485A504A5A48425A4840544A40
5450425A5854604E485D554F494F57555F6965757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E584A3F412A25\
221D1A2D2B28585957686B6665656565636365606065635C655F55615F585E5254
55524C5B5754616461616A636568606565656565686565655E675D5B594D574C4554463F54463F\
5D4A435D4E496252546256525B534E5B5A545E5A545A544D5A574F54554D544C45
5748495A53564F2F23584E485A392F655E5F65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E573E351C140E\
211D1C201B1D464B4C65656865656865655E65655B65656565686D686B706B7172
6861615E4D4E5244405B514E5E5C5862636365656565655E6154545747444E3D425142394E4038\
5448425D544D5A4E46544D465B4D4E574642544944514A44524A44544C46574A43
574A47544A424C44314C4436523B3965758165757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E6568696254545F443A\
3627202A21205E5A5465655E5E5F55626363656563524C4649433C392E29322723
342D2C3E323652434154433F554A48626060656565656568615A5B5A4E4754483854423251463F\
51463F47443E41433F4C4A4454564E51504758524C5D544D5A5049574E47574A43
574A47574E473A2823301816442F2662727565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E5E534C5B49440E0706\
090B0C161616585B5661625D655F5A68655E65655E68635D4E48423936301E2427
0C14171115112826212D191629111048393862605E6565656161585A504754463B4E4E3C483E35\
574E48665B536C5B5366534B57444449413F554F4A5A524C574E474C4842474842
52504757504749342B4B2D2357352E656E7B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E6B7C866B605B5A463F362724\
20161326161465625D686B6561645F626561656561686B6D665B5584706E453831
20151320161220272A3B36306F695C747D73656F6E65777C616A655A5049483B3545362F230B08\
372828443527372F2825211D3736314C4840544C40524A42544C4651443D514842
5748474C403C3225233F322B5A4C486F869368788165757E65757E65757E65757E65757E65757E\
65757E65757E65757E
656B7565727B656E7765727B65757E65757E65757E65757E65757E0A0303180B0F5C534E413029\
1D1920181311585F5A5E5F5A65656161625D5B5C58626363686D66625D54715D50
A17E6990674A7C553C79644E6E6257655E586566676566646158525A4C465A4437524038543E32\
484B4B1D272E0103051114172327270E1110181C2127241E4131284E463F514C45
574A423F3B33241F1A26211E4F4E486B838965757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65717A65757E65788165788165757E65757E65757E65757E0E07080C09090B040200060B080910\
0F0F0E22171468645F61625D656568543D414E3B3B5E5A5B686F716E7679716B6C
66544F695D5772625B7164586B635D65635D6569696569696157585A5854544C3F54523D624F3C\
7360507853421B1213251A14252021211C1C3D312954403862594D594A42534842
575043241D1D1C1815291C17492A255B5E6962727B65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
657B8565788165757E65757E65757E65757E65757E65757E2417152B2119291B171D1B1A0B090A\
211614291715655B56685F5A615F586B777263695F3B2F292F211E28211E1A1B1B
141516171716211C19271C1A403E3E5B625C65656565605961574E5A564E544640573F37514A3B\
5452435D554B957864A47B62724D3B6D4534805B4D715A43544E455450455F554B
514A45231D171D15132C1D1848271F5E6B7565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2A1B15180E0B11100F15110F1C1310\
1714112625235858525E5C586868636868686F71727E857C6E5E5B49444A685454
755749735D50634E437464597B7D736F717268686A65525A6159585A585254404533221E281A18\
3E372F524C3E574E406353496D604F666154635D4E4E4E49574A4D514845524C42
3F393111100E11110F6351455935285E757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E656E7765727B65757E65757E65757E65757E32251E21100C1C13101713100B0607\
1811102A232149443F55535062635E656565656C6C6872747586868F9E958F9E95
859E9B8CA1A08FA4A286958B6B726A656C6C5E625A5B65585E6358625C576B6B5F746F5E483535\
1E1919090C0E1F1E21494340544E435D5043514A4351423D423D355146445D4845
241B18150F0E26221F4631293A21191210112D343D65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E262322201D1B1B15121C131016100C\
1C141128232151443D615B5665656165656565696965696965717765747C65747C
656C6E657177656C6E656C6F686B6868655E68655E655E58615450655E5868645D6E64637E7771\
92756B664E462D231D0B0F0F0F1115151C2020201E28231E514444634E4751443C
1C14131711101D1618140A09180E0C28272868788165757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E322826382B291915121A13101C1411\
21181B2924233F3B344C4C485E605C65655E656360656667656664656A6C656E72
657177657177656969656969656C6F656866656561615E5861615B615A54615B56615A58625C54\
615F546E62547D6B5B7A65535F4939523C30684B406B5E545F4A4C4946423E4039
1E16141B1310151310100F0B171715272A2B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2F221B261C16221B181D14111F0F0C\
231614291E172D282446413F5B5A5662635E656565656969657177656969656A6C
656E72656E7265696965696965635C656363655F5D615450615B5661615B615A546157505E534C\
624D4861524C5F534B6F5E5576645979695D6D5A51624E4D5F4E4559483D362720
1D14121B13102417151A14111A1311231C163C373C51586365757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E261E182A2827221C1B23171513100C\
16131015110F251D1932281F4F4B4765635E656565656969656E72657177656969
656A6C65666465666465696965656165655E5E5B545E5E58615A54615450615752615A545E5650\
57524C57524C5D5A545750495A4C465A4E474C4A43474A42474A42393B34171A1A
0C0D0B1B1619120F11100E0B0B06071B141336323458656C65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E32241D2923212A2422231D1B251916\
1E1411231C1A2D2A292D2D2C4947465E5753656363656363656362656A6C657177
6571776569696569696569696565685E5F5D5E5B56615752615752615A545B5A5458534E5B534E\
5A524C5A524C5A504A5D524C575049544E47514A435D4A4356443D3128251C1312
241B19100B0C110E0F0C0708140F111B14113437385E727B65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2A28272B29282E29272C2624231816\
120F0C1F161430211B473228573D3058514C62635C656563656363656362656A6C
656E72657177656C6E65696965656568686365605B5B5A5458534E5E51525E514E5E4D485E4D4E\
5A504C5A524C5A4C46544A44544C4651423C5A4640513F38312D2C221C191E1513
110E0B120E10100B0C14100C15101123171592A9B38CA6B065757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E656E775E656E26201F2621202A2625282321191310\
231C1A251E1B211F1D39312A4E423C58575462625E656565656C6C656C6C656E72
656E72656E726569696569695E5F58625C56615450655752685C575E58505B564E5E524C575850\
57544C544646524A46544E47574E475A4C454E4C45403D3541352B271E171F1614
18141118141119151115100C1814102217156B7C8668788165757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E657881687F8824201D30221B2922202B27262F2826\
251E1B26201D2B201937383436332D4C413D5B5753626363656363656667656664
65635F65635F65605E5E5A535E56505E5F5A5E5A545B534858514A5B53485E564E5E58525A524C\
5A504A5D50475A50475748425745404C4842403F383A3029221C1D181213131110
110E0B120E100F0A0C0806070E0A0B3224236F7C8562727B65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3329272A20192A27262D2826231E1C\
2016142A1E172A24222F2D2A2B201D3F353258595665655E65655B656360656059
65605765605765636068686365605B6154505B49445B4B485E4D505E53525E56525E4A445A4D48\
5A4C465A4C46574E47574A4351443D423D363A2F28221B1D1E1A1617120F151310
1C1411151011100B0C110B0C291916B2CDD39CBDC565757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3E3C3C2C28262723222F26252B1F18\
27211D201B1A252221201B1B21222434322B433D3555514D5B5C5862635C65655E
6565615E5F5A5B5C5662635C6157525B4B465B5348574E465450485450485B4D48574C46574C46\
5A4646544C47544E4251443C4C443D423D352D211E201B1615110F100D0B120E10
1A1310140F100D0708100B0C21171562727B62727B65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3936312D28262E2927272321262322\
1C16191F1918231E1C2D28262A1F18241C182D2F2D413B395243405B514E5B5450
5B5A565E5F5A615B565E5652585550544C46544844574A465A46405A4742574A44574C46544842\
5248404F423A493E3A3E3D38342F28332922201B1614100F131110130F0C100B0C
0E0A0B070607080707251916311E166B787E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E6A70833C30312D2726282321322D2C\
2F221A2418142E2827241F1D2A27261E1B1A2227261A1F1F232221433B39493F3B
4C45484E474C4E4A4855524E4F454039322D37302C44352C4F443D524842523B3552413D544836\
51443A4C3F38483933423933312623221815191212191210130F0C0F0A0C100B0C
0D0708090708110B0C1B131091ABB69CBAC665757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E758C9142413724201D252120262120\
1D1D1C1B171A261D17282220322D2C312B292823222725282C292825231F1D2126
1821231E1E1A2D2A262F2E2B2424252B26212D251F2D2C22342A253B3127493D30433931342A27\
3729263E302B33302F2A22212418141D1413161110110E0B0F0A0C0C0708080707
0807080907081814112519166E7F88687B8565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E525667302A2A2E2927292927\
2B2523171310211E1C302D2D322D2C3531303A35333E3A323837302A2F2B222122
241A1621191B211A1A251F1F201D1F201F222A21202B201A241E1D2B29252B292427241F312B25\
2C261E272725281F1C261D181914131C1A19120F0C120F0C100B0C0D0708090708
0907081F15111610115D55568999A165757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E74818D3C302E292321272120\
2822212F2725352D2B322D2C33302F2A2625262222291D1D321F1D2D1D19241F1E
1B18172021211814131A1C1D1F1F1F1E1C1B171312141516141213141010151413171714171714\
15101116101014101016121212110F0F0E0B0E0A0B0F0A0C100B0C090708090708
1F151B1F151230282596B0B682A0AA65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E6B7F85616B6F332D2B282321\
2D2826292422353130231E1C292626211C1B28242439332C2A2A28222323262322
26201D3329271F171A1E1E1D1D14121E141218110F13110F16110F1E16141E161415100F14100F\
15110F1D1614181310171210120E0B130F0C100B0C100B0C090708090708110B0C
251D19251915A6BDC59FBAC265757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E696F7D3928262F2826\
2D28262823211C1B1A2C29293834322B2A28231F1D281E191C16151F1B1A221D1B
17151C1A1B1B1A1617211614191118131210141310120F0C151310141310121210100E0B0E0A0B\
100E0B171210110E0B0E0A0B120E0C140F11100B0C090708100B0C1B15122B201C
261916A6C0C9A6C4CC65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E6F858B4A4C492C2826\
2A26252823213029272A2827262323211B1A1F18171C181715110F221D1B1C1618
1D16171A110F181117100E100C0A0B110E0F120E100F0A0C120E100F0A0C120E100F0A0C140F11\
181411130F110F0A0C08070808060707060708060714101116110C100B0C170D0B
97A8B0A3BDC665757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E8CA6B05F5C5A\
292220252120272726272726302C2B2B2528221715211A1816131017110F13110E
18120F0E0A0B0D0A0B120E0F141011100B0C130F10100B0C140F10100B0C2518150A0708120F10\
171310140F100907080907080E070816101118111216101125181637251C6D4D3A
8F9C9D687B8565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E8CA6B0\
615654312E2C231E1C302929322C2B322D2B23221F26221F1C141A130F111A1310
130F101714111A1511151011100B0C100B0C100B0C100B0C100B0C181410120F11292D3E34363A\
20161E100B0C1510111C16121C16121511112A221F2B201C251916422E2895B3C3
85A9B965757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
94B2BC6156543C3331241F1D222222302F2E362F2E2F211A241C18191510130F10
0F0A0C120E0B120E100F0A0C100B0C141011110B0C141011110B0C0F0A0C282B2F251D28372D2B\
443B343A3030453A363328231A1512251D1A241C192E2927452E26A3B7BF8FB0BC
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
62727B89A6B055453B3D3532322B29332F2E33302F383534241E1C241C1A342A26
2D2823211613191411151011151011100B0C100B0C18141A151012191511120E0E1C1B1724211D\
0C0A0C0C0D0C0E0E0C0C0B0D17110F221B192B201950382B8C93A088A9B9657881
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E8FB0BC55554D241F1C2622223936374142423D3937261E1C1B1517
1E14132D2523292522161112100B0C1C181F201B232824201F1A20372E2D1C161D3C35342F272A\
302826372C282F2522352B27473E34342C28594236A3B7C293BAC66F858B65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E8FA9B6A6B2C64D46442824242421212D333F464445554D49
555652312C2F26292E424254605C5A3D31322D29352F272B403E4E352E2D2F2723352E2B302625\
35242135231C31292640352E573E3139251D8CA9B685ADBC65788165757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E72898EA3C3C95C58653A35362A2E353F444B42474F
3B3D3F4244425453565047423E3834322C2A3C352F2D2626201B17221D1A302C2B2D2826382620\
422D2644352E52413A402922433E4999C0D699BAC665757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
656B7565727B65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E8FA9ADC0E4E8BACAD9514F6249464F
6B6B8366616D524545403A393E3C3C52494F5B4E4E524A48645753534A414E49465B504E48463F\
3B413B2A28275C6478A6D1E4B3E4EE85A3AA65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
657B8565788165757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E6B7F8595B0ADACCDCC
95B7B68398AA99B4C38A98B45257713F485F363A3D3838393838393A3A3C3936382D28242D2B27\
8C9EAAC3E8F4A9D1D5758F9465757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E6B7F816B8285728C8E96B3ADADCAC3B0D1D2B3CDD7B3D4DFB3D7E2B6DBE5BDE4F1C0E7F7\
92B0BC65788165757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[84]:=",
  ImageSize->{400, 195.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000`b000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`008P3ooolG07anOP0607enN01fJE`0O6eP07a]I@1lLFP0O6eU0`1lLFT0
1`1lLFP0O6eT07e]G`1hJE/0NFAE07ALC`1eFdh0101_F4/01P1_EdX0L5A506]DA01[E4D0JeA406E<
?`@0O7in00<0O7mn07aiN@1lOWh0201lOWhI0?oooaL0Ogem00H0P7eh07UXG01oK600OfaT07m`J01o
K6@407m`J00607m/H`20K5l0NfQK07aSE@1fFdl0N5]=101bEd/01P1bETT0Le=506iCA01^DdD0KU=4
06I:?@D0Ogem00<0OgQh07mmO@1oOGd01`1oOGdH0?oooaL0P81n00H0PGif07][G@20Kf40P6mU081c
J020KfD3081cJ@07081cJ020Kf@0PFmO07aZF`1lIED0N5i?07QMCP0407=JB`0307=HB@1cEDD0KeE5
0080KeE500<0K5=30820OP20P7h00`20P7h00`20O7T0P81n0820OP070820OQT0oooo5`2BPWP01@2=
K5P0TW1L099`H02BMF@0TW1P00@0TWET00@0TW1P099`G02=K5P0SFQD0P29Gd`508=KB00508=GA01o
Ed00OeM407mG@01oEd@01@2BPWP00`2BOWD0TX9h09:2N00809:2N2@0oooo000R0?ooo`0607anOP1l
NWT0O7Ui07anOP1lNWT0O7Ui2@1lOWh00`1lNWT0O7Ui07anOP0507anOP0A0863OP1lKFD0O6eP07a]
H01lLFP0O6eU07aaJ@1lKF00N6EE07=UE@1cHE@0M5aA06YHC01ZF4/0JUE806]DA`1ZEDP00P1_F4/2
06mDA`05071DBP1[E4L0JeA506]UG01UH5/0101lOWh00`1lPh80O7in07anOP0807anOQT0oooo00H0
Ogem07mkN`1oNWX0Ogem07mkN`1oNWX907mmO@0307mkN`1oNWX0Ogem00D0Ogem0140PX1l07aZH01o
K5l0OfaR07m`J01oK6@0Og1X07m^H`1mJUd0NfYM07]VF`1lHeH0MEmB07EMC`1bEd/0LeI906mEB@02
079GB`80LUE800D0Le=806iCA@1^DdD0KUa@06IDC00407mmO@0307moO`1oNWX0Ogem00P0Ogem603o
oolG0820OP08081oN01kJed0P6mP081_I@20LfP0P6mU081cJ@20LfL2085bIP06085^H@21KEd0O6QH
07aSD`1hGDh0N5]<0`1cFT/207=HB@0507=EA`1_EDD0KeE506mHB01/Dd<01@20P7h00`20O7T0P81n
0820OP070820OQT0oooo00H0TX9h09:1M`2BQG/0TX9h09:1M`2BQG/909:2N00309:1M`2BQG/0TX9h
00D0TX9h00D0SfiJ08m^F`2BL5`0TWEW099`H002099eI00:099cH@2AM6@0U7AT09A`G@2?KEP0S6UD
08eRCP2:Gd`0Q5]708IMBP80Pe]80P23FDH207mG@P0307mG@01oGDh0TWEV00@0TX9h0P2BOgD909:2
N2@0oooo000R0?ooo`0507anOP1lPh80O7Yi07aiN@1lPh800P1lOWh0101lNWT0O7Ui07ajN@1lNGT4
07anOP0307b3PP1lOWh0O7in00D0O7in00d0N7Ye07IYF01lKFD0O6UQ07aaJ@1lKFD0O6UQ07QYH01[
IE`0I5aD06mDC01_DDP0KeU<0080Kf1B00X0M5mA06]DA`1VDD@0IU5406IDA`1VE4<0JeA406]DA`1[
E4X0O6YQ1P1lOWh00`1lNWT0O7Ui07anOP0707anOQT0oooo00/0Ogem07moO`1oNGT0OgYj07moO`1o
NWX0Ogem07mkN`1oNWX0Og]k07mjNP0407mmO@0307moO`1oNWX0Ogem00D0Ogem00D0OG]f07aZF`1o
K6@0OfYP07m`J00207m/I00907e/H`1hJ5d0L65F07ILDP1hFDd0ME]?079MD01bFdl0ME]=00<0KU=6
00L0KUE806iCA01`DdD0KU=606iCB01bFD`0LVi[00D0Ogem00<0Og]k07mjNP1oOGd01`1oOGdH0?oo
o`80P81n00@0P7aj0820OP20P7h0P7ai2P20P7h00`20O7T0P81n0820OP040820OP0A085nMP20Kf00
P6mU081_H@20LfT0P6mU081cJ021LVH0P6iO07aYFP1lIeP0O6=C07QQDP1cGTl0Le]<07=JB`1_EDL0
0`1cF4T01P1cEDD0LeE706mEA`1_EDL0K5<o06aUGPl0P81n6@3oool0102BPWP0TWme099nM@2BQG/2
099oM@0509:2N02BPGL0TXEk09:1M`2BQG/0102BPWP2099oM@H0TX9h0140TFmJ09EcH@2BL600TW=P
099eI02BL600TWIU095aG@2:KEX0UF]D08mVE029IU00QfA@08=MBP23FTP0PEI407mGA00208AKA`07
08AIAP24Ed80PEM607mGA01oEd80QFiP08E^H`0509:2N00309:1M`2BQG/0TX9h00L0TX9h903oool0
0280oooo0P1lOWh00`1lOgh0O7Ui07anOP0207anOP0307b3PP1lOWh0O8>200d0O7in0140PGih07aY
H@1lKFD0O6eU07aYH@1lKFD0O6eP085aJ02BMVd0PWIZ085`I`24He/0NUQ;07YEC01jEDl0MDm:071@
A`0306]DA`0506]DBP1_F4/0L5M:06]DA`1UC3l01P1lOWh00`1lPh80O7in07anOP0707anOQT0oooo
0`1oOGd0201oN7P0Ogem07mmO@1oOGd0Ogmo07mjNP1oOgl0OgYj301oOGd04@22OGP0O6QN07m/HP1o
K6@0OfYR07m^IP1oK640PViV08Q^I01gK680O6MM07mME@1fEd/0MUM=07IGC`1eDd/0Le=800<0KU=6
00D0KU=806mEB01`EDP0KU=606I:?@0607mmO@0307moO`1oNWX0Ogem00L0Ogem603oool30820OP03
081lN@20P7h0P81n0080P81n00<0P7ai0820OP20O7T03020P7h00`20OWH0Nf]M081_H@02081_I@08
081cJ020Kf@0P6mU07][G@1^Ie`0Mf9F07QKC`1cFT/207=MC`0307=JC01cF4T0KeE700<0KeE700@0
KeM606mEA`1_EDL0K5=31`20P7h00`20O7T0P81n0820OP060820OQT0oooo0P2BPWP00`2BOWD0TX9h
09:2N00209:2N0@0TWme302BPWP0102?K5P0Sg1N099`GP2BL602099cH`0;099`G`2?KUh0PVQF07iQ
C`29FDd0OeQ4089KB022Gdh0PUm<081HAP1oFdH00`1oEd@0101oEd80PEU407aD@P1oEd@709:2N080
TWme202BPWPT0?ooo`008P3oool207anOP0307b3PP1lOWh0O7in0180O7in00@0O8=n07a]G01lKE`0
O6eP0P1lKFD04`1lKFT0O75Y07afK@21MW00N7IS07e/HP1mJ5h0OFQG07UODP1nJ5X0OeU?07A<A`1d
F5@0L5]?06mDA`1_DD@0L5A706mLC`1[EDP0401lOWhI0?ooo`80Ogem00<0Ogmo07mjNP1oOGd04P1o
OGd0101oP7`0OfYK07m/G`1oK68207m/I00C07m/IP1oKV@0Og1X089`JP1kKUl0P6EN07]QEP1kGe80
NE]@07]PE@1jDd/0LTm6079FCP1`ET/0Ke=606mAA@1cEDP0KeQ<06U?@P0@07mmOAP0oooo0`20P7h0
0`20O7T0P81n0820OP0A0820OP03081oN020Jed0P6mT00@0P6mU00`0P6mQ081_I@20KfD0O6]L085R
F`1gGe00Me]>07QJC`1gFe00Le5706mDA`1_Ed/306mEA`0307=HB@1_EdX0K5=30100P81n6@3oool2
09:2N080TWme4`2BPWP0102BKUX0TViL099`H@2BL6<2099`H00C099`GP2BLUl0TVmO08m[F@2=I5<0
SEa@08MLB027FTX0QUI:08MIBP1jC3l0OUI407iMBP1lDSl0PEM4085IAP1oFDH0PEY808mkLP0@09:2
N2@0oooo000R0?oooaL0O7in00<0O7mj07a]H01lKFD00P1lKF00501lKFD0O75Y07a]I@1lJF40O75Y
085fL021NV/0OG5R07QTF`1mJ5X0M5a?07YSE@1eGe40Ke5107ALE01[Fdl0IUA706]DA`1cIF40MVYU
1`1lOWh00`1lNWT0O7Ui07anOP0607anOQT0oooo5`1oOGd01`1oOWX0OfaO07m/HP1oK5l0OfaR07m/
I01oKVH00P1oK6@0401oL6P0PW1Z07maH`1mJ5`0Nf5G07eSE`1fFDl0O61C07EGC01bD4@0ME]C06iF
B`1^DdH0L5=606mKE01bGUD707mmO@0307mkN`1oNWX0Ogem00H0Ogem603ooolG0820OP04081oN020
Kf00P6mQ081_H0@0P6mU00d0P7=X081cJ@20KfD0Nf]M07aSF01lHUD0O69D07QKC`1lH580Le=807=B
A`1cGU@0KeE70080LeE700<0KUM;075KC020P7h03`20P7hI0?oooaL0TX9h0P2BL5`05`2BL5h0TW1L
099`H`2BL600TW9R099`H02BMVD0TWET08m[F@2<IE<0RUe>08ePD02:GT`0REe<08QHBP20DD<0PeI8
085OD01oDSl0Q5M4085GA027IED0S7EV00L0TX9h00<0TX5g09:5N`2BPWP01P2BPWPT0?ooo`008P3o
oolF07anOP0306mLE01[FeD0O6eU00<0O6eP00T0O75Y07a]I@1lLFT0O7I]07aaJ@1lLFP0O6eY085a
I`21KE/00P1mI5L02@1iGe80NUQ>07EGBP1[CCl0JeA706mDA`1`E4L0IeYA07IdM00707anOP0707b3
PP1lOWh0O7in07anOP1lNWT0O7Ee07aiN@0207anOQT0oooo5P1oOGd0201jJV<0MFaW07m/HP1oK5l0
OfaQ07m/H01oKVH0OfaT0P1oL6P0401oKVH0Og1X07m/IP22KV80OfQI07eQEP1mHED0NEa@07YGC@1e
ETT0L512071FB`1_DdH0L5=606QCB@1iKV`707mmO@0707moO`1oNWX0Ogem07mmO@1oNg/0OgUi07mj
NP0207mmOAP0oooo5P20P7h01P21NG80P7mh081_H@20Kf00P6mT081_H@80P6mU00h0P7=Y081_I@20
KfD0P7=X081_I@20Kel0NfMH07aRE`1lHU@0N5e?07QJCP1cF4T0LeE707=KC`80KeE700<0KUE707]^
I`20P7h01`20P7h00`20O7T0P81n0820OP050820OQT0oooo5P2BPWP0502<LVD0W8Md099`GP2BL5`0
TW1O099`H02BLV80TW1P099eI02BKel0TW9R099`H02BL5h0SfYC08aSDP2:H500RV5>08IIBP25FdP0
P5M40P21FdT01021Ed@0O5M408ecJ02BNfl709:2N080TWme0P2BPWP00`2BPGL0TXAj09:5N`0209:2
N2@0oooo000R0?oooaD0O7in00@0ASXb0497?`1fJE`0O6eP0P1lKFT207a]I@0307aaJ01lJE`0O6eP
0080O6eU00d0O6eP07aaI01hJ5h0N61G07QLE01iH4h0KeM706mHB`1dEdX0L5A706YLC`1dGe40L5Y=
00`0O7in0P1lPh8307anOQT0oooo5@1oOGd02`1NCD<0H65K079QF01oK600OfaV07m/I01oK680OfaT
07m`J01oJV00OfiT0080OfiV00h0OfaQ07m^H`1mIe`0OF5F07]MD`1lGdl0MEI907EGB`1eEDP0L5=6
06aHC01eFD`0K55407ahN0/0Ogem00<0Ogmo07mmO@1oNWX00P1oOGdH0?oooaD0P81n00D0KEiB085n
MP1aGeH0P6mQ081_I@02081_H@04081_I@20LfP0P6mT081cJ@80P7=X0P20Kf@03021JE/0PFIG07aQ
E01lHE40N5Q<07QJB`1cEDL0KeE706mGBP1cEdP0K5=307]gM@`0P81n0P20O7T20820OQT0oooo5@2B
PWP02`1[EDH0/91l08aXE`2BL600TW1N099`F`2BL5h0TWET099`H02BLf40TWMZ0080TW=S00h0TW1O
099^G02AI580TFI@08eQD029GdX0QeM708MKB021E480O5M408=JB021E4<0S7Q_08mkLP/0TX9h00<0
TWme099kLP2BOgD00P2BPWPT0?ooo`008P3oool207anOP0307ajN@1lNGT0O7in00l0O7in01/0JfEY
03lS7`0F6R80O6eT07aaI01lLFP0O75Y07aaJ01lJF40O75Y07afL@1lKFD0O6eP07aPF01hEE40Ke56
07=LC@1hH5@0M6AD06mKD@1dFdh0MEQ;06]GA@1[E4@0ITe206IAA01UC3l04@1lOWhI0?ooo`80Ogem
00<0Og]k07mjNP1oOGd03`1oOGd01@1hL780CRXT01hW:`1lJV00OfiQ00<0OfiV01<0OfYR07m`J01o
L6X0OfaR07m^H`1oIEd0OEmH07UMD01kHeD0NemE07UQD`1hFe40MU]<07EEB@1`ETH0L5=506]@A01^
EDP0JD`o0140Ogem603ooolD0820OP05081mN`1A;bL0@3li07][G@20Kf401020KfD04P20LfT0P6mU
081_H@20LfL0P6eS085]H021Je/0PFeM07aRE`1lHU@0O5eA07QMB`1cEdP0LeQ807=EA`1_EDL0Le]<
075GB140P81n6@3oool209:2N00309:1M`2BQG/0TX9h00l0TX9h01/0RWQa044R6P2SQ6d0SfiG099b
HP2BKUh0TW9R099^GP2BLf<0TWET099_G@2BL5h0TW=Q099[G`2ALU/0TW1I09A]F`2=He80S65@08UK
B029FdH0P5U6085G@P21EdH0PE]708AMB@2EQG/04@2BPWPT0?ooo`008P3oool207anOP0307b3PP1l
NWT0O7Ui00h0O7in00P0P8:203d[7P1nLUl0MVUH07a]I@1lJF40O6eU07aYH@80O6eU00L0O6UQ07a]
I@1lLFP0N6UP07=XF01hH5L0NF1B0080KeU<00X0M5U807EKB`1ZE4L0Ke5407ADBP1dE4L0L5A706mH
B`1WASP0MVYU401lOWhI0?ooo`80Ogem00<0Ogmo07miN@1oNWX03P1oOGd07@20OWh0CcDW07EZHP11
?SX0OfaT07mZH01oKVH0OfYR07m^IP1oK6@0OfYR07m^IP1oL6P0OFYQ07]YF`1mGeP0O5mB07AIC@1f
Fdl0NE]<07QLCP1_EDP0ME=607EEB@1bDdD0L5=606mEB@1XBcl0O79`0100Ogem603oool30820OP03
081lNP20P7h0P81n00d0P81n00T0Oh1m05Lm;P1^IfH08QlR081_I@20Kf40P7=X081_I@20LfP00P20
KfD04@20LfT0P7=X085_H`21KEh0PF9J07aQDP1hGTl0O65B07aQD@1hH540LeQ907QHB@1cF4T0KeE5
06mEA`1_EdP0KUM;0140P81n6@3oool209:2N003099oM@2BOWD0TXEk00h0TX9h00H0U8=i04/_8`20
I5d0Ec/f099`H02BLf03099cH`0D099`H02BLf<0TWMW099`H02AKeX0U6IH095SDP29Gd`0S65>08mT
D02<I4h0Pee<08MIAP27FdL0PEU407iG@P1lEd@0PEU608eiK`2EShP@09:2N2@0oooo000R0?ooo`80
O7in00<0O7Yi07anOP1lOWh03P1lOWh01@0_81P0O75Y085fL01lKF@0O6eP0080O6eU0P1lKF001`1l
KFD0O75Y07a]I@1lKFD0ODi=07Pl?01d=SL00P1d<cD02`1d@cl0Ke5706mAA01_Cd<0Je1006YDA01_
E4L0L5A306Y<?P1Q?2h0ID`o00/0O7in00<0O7Yi07aiN@1lOWh00P1lOWhI0?ooo`80Ogem00<0Og]k
07mmO@1oNWX03P1oOGd01@18;b@0PWUd04Y9AP1lJV00OfaP0080OfaT01H0OfaQ07m/HP1oK6@0OfiV
07m/I01oKVH0P5QC07]>B01iAD80ND@o07I2?P1fCTH0MEE907EEAP1bDTD0L55206mCA@1bDdH0Le=4
06a?@@1[BC/0KeUA2`1oOGd00`1oNg/0OgYj07mmO@0207mmOAP0oooo1020P7h00`20O7T0P81n0820
OP0<0820OP0505Lm;P25Q7l09bPS07][G@20Kf400P20KfD00`20Kf@0P6mU081_I@02081_I@0;081c
J021HeT0O61D07aEC01lEDX0N5=707QMCP1hFd`0N5]907=GB01cEDD00P1cEDL0101cEDD0KeA507=H
B@1kKVL@0820OQT0oooo0P2BPWP00`2BPGL0TX9h099oM@0>09:2N00405<f9`2EP7@0ECP/08m^E`<0
TW1P00`0TW1O099`H`2BL600TW9R099`H02BLf<0SE]=08eUE02<FTX0S5a:08UJB029Je4208MMA`08
08=F@`21FD<0QUM608=GA01oEd80PeI508MXEP2LUI4;09:2N00309:1M`2BQG/0TX9h0080TX9h903o
ool00280oooo0P1lOWh00`1lPh80O7in07anOP0=07anOP0O06]UI@34/k80MVUU07a]I@1lKF@0O6eP
07a]I@1lJE`0O6EH07aUE@1lJEd0O6UQ07aPG01lEED0OEYE07A3>P1_=R`0KS/e06ln=P1^<c80LC`i
06I6?P1VE4<0Jdm306Y@A01_E4L0M5A:06mCA@1dE4P0H3PX06]A@`0:07anOP0307b3PP1lOWh0O7in
0080O7in6@3oool207mmO@0307moO`1oNWX0Ogem00d0Ogem01l0N71`0:NHU`14@T00OfiV07m/H`1o
K600OfaT07mZG`1oJ5d0OfQI07mZH01oJV80OfMQ07mOF`20GUL0NDDm07Pk<P1c?ST0MClh07<j>01f
ASl0KT]106iCA01`Cd80K554079CAP1eDdP0Ke9407EBAP1WACL0MFIO00X0Ogem00<0Ogmo07mjNP1o
OGd00P1oOGdH0?ooo`<0P81n00<0P7ai0820OP20P7h03020P7h01`20OGX0PGmk02LX8`20LfP0P6mT
081_H@20KfD00P20Kf<04020Kel0P6mU081_I@20L6H0P6eS085SF@1lBD40O44g07Q4?P1h@SX0N4@n
07QCA@1cE4D0LeE507=A@`1_EDD207=EA`0306mD@`1cDdH0KeM800`0P81n00@0P7ai0820OP20P7h0
P81n6@3oool209:2N080TWme3P2BPWP01@2:N6l0IDi305]0=02BLf<0TW1L0080TW1P01P0TVmM099a
G`2BLEl0TW=V099cH`2BKEl0TW9R08eDB02<BC`0RCld08a:@P27@SL0S513085HA024FTD0Q5M2085B
@023FD@0PeM4085G@P21DSl0PEU608U]G02LWih:09:2N080TWme0`2BPWPT0?ooo`008P3ooolB07an
OP0403DY8`0E7A`0MVUH07a]G0<0O6eP01T0N6UK07=LD@1fI5T0O6eP07aUF01hCd@0KcH_06Y9?`1N
?Bh0HEa<06i]F`1a?S<0HBXQ06lb;01`?3L0JdY406]C?01VD3/0JUA406mDA`1_F4X0Ke5406mEB01[
Bc`0O7A_00h0O7in6@3ooolB07mmO@0P04Pd;@0k@3h0NFYO07m/G`1oK640OfaP07m/H@1mJUh0Nf5E
07aUFP1oJUh0OfQL07eHC`1iACd0N59906ln<@1]D4D0L5A807Hl<P1[<BL0MCTb0711>P1^C4@0KU8m
06]??P1_DdD0LU=6079EB01bD4@0LUE906a>@P1oN7D>07mmOAP0oooo4P20P7h00`1A?CD0KVMS07]_
I`02081_I004081_H@20Kf@0PFiQ085YFP80P6]M00h0P6iQ085SF@21ED/0PEaD07]1=01hBT40Ld0h
07Pj<@1c>2h0N48j06m8?P1_DTD0Ke@o06mB@`<0LeE700<0Le9507=JB`1aFTd03`20P7hI0?oooa80
TX9h0200Ac0X0;fJQP2BLfH0TW1Q099`G`2BL600TW1O095[F@2DJeH0UG=N099^GP2BKE/0TE]B099J
B`2?GU80QC//08mAA029>c@0PC4W08Lm<027BSd0O55007mKA01oDST0PEM508IGAP23Ed@0PeA208=F
A023GDX0TWme09:8PPh0TX9h903oool00280oooo101lOWh00`1lNWT0O7Ui07anOP0:07anOP0R05]?
C`2ELV80H59:07a]I@1hIE/0MVQQ07aaJ01lIE/0NEa;06Y<?P1[AD<0M3/i03`>2@0_:R@0M5Y@07iI
D@2HX9d0Q4i706Lf;@1JDCX0EEM804Ph:P1>:200Ic<]06I<?01_C3h0KeA807APCP1eFdX0KeQ;06mD
A`1P?2h0Jd/l07adK`d0O7in6@3oool407mmO@0307mkN`1oNWX0Ogem00X0Ogem0280Kf1P091bI00d
=cH0O6YP07eXG01lJF00OfiT07mXGP1oHe80MEE6079BB`1lC4D0EaX?05I5?01iDTX0Ndi808EdL01d
@c/0KdDi06]@?01SB3d0FcDX060`9`1/?CD0Jdln06m=?@1_E4H0LeU;07EFB01bEDT0LU=606U9?01e
GeD0OgQe3@1oOGdH0?oooa40P81n00D0Ng5_07iaI00R:2T0Nf]M085^GP02081_H@0J081^H@21JeT0
O61?07]REP21GE00JBDE085SE@1lCDD0MdY2075AB@1U>c00LeE507E@?`1^?3@0JC<W07<h;P1_BSh0
KeA106mA?P1_EdH0LeM807=EA`1cEdP0LeE707=JB`20N74>0820OQT0oooo102BPWP00`2BPGL0TXEk
09:2N00:09:2N00R07iYHP1XDT<0I4m408m^F`2AKEH0UGMT099^F`2BKEP0S6UA08aNC02IMF<0Sea;
06XU4`2fOf/0S4@j08MCAP1h@SD0Lc<U07mNB01oAC@0PSXc07D`8P2B?S40OE]7085F>`21E400PE]6
08EHA020DT80PeU608=GA02<KEX0W9F>09:8PPd0TX9h903oool00280oooo0P1lOWh00`1lNWT0O7Ui
07b3PP0<07anOP0S04<f<00f?cl0MVUQ07a]H01mJ5X0MU]A07a]I@1lKF80NE9106]4=P0i3`/0=CPg
0;C@b027Ui@0Qj^]086GWP1lMWH0PZ2>09:LU02NXZD0NWAa05Pn=@0T81@0<B0I0690>01ZDd<0M5E9
07ALDP1jHe40MEM706mDA`1_EDP0H4i=06MSK@1fM7@0301lOWhI0?ooo`80Ogem00@0Og]k07mjNP1o
Ogl0OgYj2`1oOGd08`1C?SL0@DI706UJDP1oK5l0P6UM07UOE01oKVH0OfaR081GA@1cC3`0DQPB05];
B@2HQH80FDi=07mnN`1lKFh0O6IS08>:O@25J6<0Q7=`06mME@1N?380>2<F04lZ8@1VAC`0K51007=B
A`1cFDl0NUm=07EEAP1bEDP0LUA806UAB@1dJfh0O7Qh00`0Ogem603oool50820OP03081lN@20P7h0
P81n00T0P81n0280Ed<l05YDDP1SDdP0P6mP085]H01kIeX0P7=X081^H@21GDT0N5E306@P6020Hed0
MdA003/E401gF4h0Mde307]NE@21MV`0Md0h06U;?`1RBS`0GcX_04TW5`1^=BT0Jdm006mA?P1cE4L0
Le]<07QNB`1cEDL0LeQ907=GB01cFd/0PGQa3@20P7hI0?ooo`80TX9h00@0TX5g09:5N`2BOgD0TWme
2`2BPWP08`17<2T0WGMS089OC`2BL5`0SFIE099fI@2BLf<0TVQD08ME?P24E440K20H0:V2M01[6a<0
GQhC08I4=P29AC@0SfMF08YAA01o>Bl0JcDQ06Dm;@1K;B00FBLF09M5<P21GdD0Pe0m08EMBP25GDP0
QEY4081DA023FDH0Pe]808afK@2JQW<0UHQn00`0TX9h903oool00280oooo0P1lOWh00`1lPh80O7in
07anOP0;07anOP0U06m]M@15:RD041TO07IYF01lKF00PGY[07a]H01lKFD0M5]?06Q=>01F;Ql0E1T>
03lB3`1]>C00LdTm07IDBP1lKE`0O6AA07UKDP1]CTP0M5Q;099]G@2VQg00TWIX03LY7`0]71T0GC`c
06UA@`1hIE@0NFAH07EOD@1_DTD0Kde206]==@1IDDH0ETiA06]ZM00;07anOQT0oooo0P1oOGd00`1o
Ogl0OgYj07mmO@0;07mmO@0U07YeN@1>;BL03QdT07UXFP1oK640PW=U07aUFP1oK6@0O65D07MD?@1V
=2@0GQ`?03XJ601/CTH0NeeC07aTG01oLfT0OfaQ07mVG01eFU40O6AH08Q/HP29KV00LUE<03TU6`18
:240ITLj06e@@`1hH580NEmC07QLC@1bDTD0LU14071A@01WGE/0JV5R07EbN00;07mmOAP0oooo0`20
P7h00`20O7T0P81n0820OP0:0820OP0T085oOP1;;bL0:bh^07][G@20Kf@0P6mP07]SEP20KfD0PFQI
07iK@P1a>RP0GahA04DY9P1^IUd0PG9Y081hL@20NgD0P7Mb085`IP1lJed0PG1S07]_J01WF4l0CcXc
03/R601W=bT0KeA307=DAP1gGe40N5i?07QMB`1cE4D0LeE707=LC`1cKG00O7Me3020P7hI0?ooo`80
TX9h0P2BOgD<09:2N00308alMP0f7QH0U7AO0080TW1O0200SfQE08mXF@2BL600Sem;089C=`1o=bH0
EAP=08EIC@2:Ofd0U7Y]09F?Q@2BNFd0TWab08aYFP2DPW40Sf]I089`J01G>2l0ABTQ04DM4`2EBC80
Qf1:08aOBP2:He80QUY608=IA023DT00Pe]7085`J027MG@0V8Z809b?OP/0TX9h903oool00280oooo
3`1lOWh09P16>S805Pd806=;@`1PCTX0O6eP07aUF01lGE40O6EE07a]G01nJ5L0RFMN09BHP`35aJL0
Qgmd07eLFP1dF4l0JSlg06dl?01Z=SL0JSTb06DN601V:2@0Fc0Z071=?`1e@S/0PUE;034B2@0a71`0
JDY207=LC@1iI540MEM706]HBP1ZF4/0M55308MeJ`1jLG40IF1Z2`1lOWhI0?ooo`l0Ogem02H0GTe3
03@N601]Ee80<C0b07aZG@1oJ5/0OfAG07mXFP1oK5l0PVMI089MD`1kKUd0TGMW05U<A@1kE500NE]@
07A<A01hDTl0N4e607M9?P1_<RX0Lclh06Y3>P1kETP0M4Q007E>A@0f4PT0B2/W06Y<@`1eFdd0O6=B
07QHB@1`EdT0KeA807EBA@1hJV40LfQU06USKP/0Ogem603oool?0820OP0506eNDP1;;bL0LV=P01dO
8P1kJed00P20KUh07`20Kf00P6mT085XF@1hEdX0I4`k05dc;@0k8ad0Me1807aPDP1lGE80PFQP085U
EP21FDX0N4Lk07aEB@1hFd`0P61?06m@A@1PBCh0>a<906Ln<`1^E4H0Mem>07aUD`1hFd`0LeQ907=C
AP1cEdX0K6IK06]SG@1aKWD02`20P7hI0?ooo`l0TX9h02H0JeE6054a:@1mGE@0HDa008m^FP2BKEP0
TW9M099fH`2BL640REM607eC?P1^>2T0D@d<05hR7@27ED@0S5m>099]GP2GJed0Sg5I08mFA02=Dd80
RU]9099iHP27ET@0M5=7054h;0184PP0Vei:08UTBP2=J5@0REm:08=IA`21ET@0QUI4085RD01oLFT0
LeeK09F8O`/0TX9h903oool00280oooo1@1lOWh00`1lNWT0O7Ui07anOP0607anOP0X06mYK@0S6180
6a<?028d=P1lKF@0O6UL07aTG`1hI5l0MVUL07aPG01nHUT0Id@d06E:@P1lLFd0O7m`085oM027R7d0
QhMl086@NP28NfL0Pgm[07n1I@1oM5`0MDa007U8@`1j>300M2`P06hU6@0h50l0AbDV06eAA`1iH540
ME]:071?@`1ZCD80Ke55034I400h<200N75a07IdM0X0O7in6@3oool507mmO@0307mkN`1oNWX0Ogem
00H0Ogem02P0NW=d02hM5@0V5a803b<W06aJE01oJUd0OfMO07eTF`1lIUX0OfEM089UF@1aBCT0K558
07a/I01oMFP0PViX089`J01oKVH0O7=U08ASF01kIeX0NF5A07UGB@1bAC`0MTe507Hl<`1b<RH0IBDJ
03TG4P1I=S<0LEI907aQDP1hFTT0Le1406a@A01bE4P0BBTM05UCB`1aJFh0O7Qh2P1oOGdH0?ooo`h0
P81n0140PGil034Q600^71D07AlP06=?B020Kel0P6eO085WF@20IeT0P6eO085ZF@1gD3h0MemB07][
G@20Kf40P6=M07]OEP0207MKDP0D07aAB`1bE4/0LdHn07=0>01_@ST0Le=706m2=P1Z>B/0EbHJ044M
5@1_C480Mem>07aUD`1hFdT0LeA506mEA`1cFT/0FCPY081lNP1^Ifd;0820OQT0oooo1@2BPWP00`2B
PGL0TXEk09:2N00609:2N00X08ajL`0V5`l0<Q/D08EMC`1oFTT0TVmJ099XF02AKE@0UFiJ099[FP29
GdP0PU4k09UlJP2?KeX0TVEF08mMD@29EdX0QU9508U<@P24ACh0P4Dk07lf;P1o=S00ODXk089<?`1f
@S@0JCLW04hN5@1T:1/0V6iF095[E029HTX0PeM407mD@P23FdL0Pem<05`k;02i[Jh0Q71]09F8OPX0
TX9h903oool00280oooo1@1lOWh00`1lPh80O7in07anOP0607anOP0W07n3R03bcKd0kk6A07=LCP1f
JE`0O6eO07afH021I5l0O61L07ajI01nKeh0OemB06M8?@1fH5D0O75Y07aaJ01lJF40O75Y07aTH`1m
H5X0N61D07UPE@1dFdh0LE]8065LAP1[IDd0NVaH08ifH023IUd0HTHh06A=?@1dG4h0ME]:071HA@1Z
E4@0KeE8069;@@0R81d0JfYU00/0O7in6@3oool507mmO@0307moO`1oNWX0Ogem00H0Ogem02P0Ph22
0;JJU01gHeH0>CLd07aZH01oK5l0OfiM089QG@1lHe`0Og=Q089VF`1mFTd0IDLl07aVG01oL6P0OfiV
07mZHP1oL6P0OfMS081UF`1kGe<0O5mC07IKC01fF4L0JeE407=EAP1fEDP0N5E606U8@@1I>300JU12
07UMC`1hFTT0LeE506aAA01bE4P0IDLm02DR7`1eL6h0O7Qh2P1oOGdH0?ooo`H0P81n00<0P7ai0820
OP20P7h01@20P7h03`21Ogh0LF]Z00dO800G7R40P6mT081_G`20Jed0P69L07][G@20Kf00PF5H07QG
B01YCCl0P6mU081cJ@02081_I@0G081cJ@20KF<0PFeM07aRE01lHE80N5e;07QHB01cDD<0N4U006m2
>@1R>S00DRhX05Ha:@1cEdX0O65A07QKB@1cEDD0Ke9507=GB01MA3T0>blY081lN@1kMgD02P20P7hI
0?ooo`D0TX9h0P2BOgD709:2N00X08=^J`14<2P0000604hn>02ELf40TVaH099XFP2?HEH0SgIL099X
FP29EDP0OT`j08YXE02ENFX0TWET099^GP2BLf<0TWET099XF02=Je80SF=@08UOBP29FdH0PEA008M:
?P24@cP0MSD/068Y8@1I8ad0Ld8^08mTE02<HDX0PeM407mD@023E4@0Pe]804L`9`27KF40W8b508mk
LPX0TX9h903oool00280oooo3P1lOWh0202=OfL0O6eU085oN@1mLFL0LfEH07I]H01lKFD0O7Y]0P1l
LFd07@22MFT0OfYI06Y6>`1WBcl0MVQL07afK@1lLFP0O6eU07aoJ`1mK5d0M5A707AEA@1[Ed<0Hdm3
05i;>P1S@CH0HdDf06=4=P1WBcH0JUE;06iIC01dF4h0LE9506]<@`1VD400IU5203dV7P0O8bX0LFmi
00/0O7in6@3oool>07mmO@0W08QnL01eK6`0PWE/07eXG@1hIUT0O6aO07mZH01oLfH0OfMT07m^IP23
L6<0O69C06m:?P1aEd/0O6UP07mbJP1oKVH0OfaT07mgJ@20IE/0NEQ;07UIB`1cF4H0Ke9506M>?01Z
ASX0JT/j06Y8>P1/C3X0JTi806eDA@1fFDd0MUE6071?A01[DD40KU5404LY8@0R9bD0K6IY00/0Ogem
603oool>0820OP0@081oN01aKg<0P6mQ07aSEP1lJe`0P6mP081[G@20Kf40P6=M081_H@21KUh0N5e>
07=A@`1lIeT0P6mU081cJ@80P6mU01D0P7=W085RFP1lGTl0O65A07QKBP1gEdP0Ke8o06m>?`1_DSl0
Kdho06m??`1[CDH0KUA107QMCP1hFTP0LeA506mE@`1cEDL0AR`S03/f:`1/IEh02`20P7hI0?ooo`h0
TX9h0200R71X08Q`JP2?JED0RV5=095_FP2EL5`0TViK099XF@2BJEX0TViI08YSC@22DD40QUQ509Mm
J02EMfX0TW9R099^GP2BMF@0TVQJ08eLCP2<GDT0S6I?08AIA@20ET<0PU8k07mA?P1oECh0Odln07e?
?P21E4@0QUY408UMB080PEI200D0PEU208AIA`0g8Q/0TW]a08ahIP0;09:2N2@0oooo000R0?ooo`d0
O7in02P0N7Ie07IfL`1hIE@0Ke4o06IIE@1[IF<0O6UQ07aaJ@1lMVd0O75Y07afK@21K6X0PVQQ07mQ
DP1cCD@0MU]A07a]I@1lI5l0N5QA07IYG01iIeP0M5mA06]4>P1[BT40L4Xl06M8>P1WCSh0Jdll06aA
>P1WAcH0JTXm07AEB01_E4L0L5=506]?@`1[D4L0KeQ;02/J60001`<0H5YG2`1lOWhI0?ooo`d0Ogem
02P0OGUi07aiMP1mJ5T0NEe>07ITGP1bIUl0O6QN07m^I01oL6P0OfiV07mbJP22JfH0P6EK07aLC@1a
CT@0NF5F07m^IP1oJF80OF5I07a/H@1oJ5T0NEi@07=9?@1cDDD0LD`m06M;?01ZC3d0Jd/k06a>>P1Z
ASL0J4/m07=EB@1eETT0MUA606i?@P1^CdD0KeE802lK600:4a40JF=W2`1oOGdH0?ooo`d0P81n00P0
PH1n081oN021KUh0PF]K081aJ01kJe`0Nf]M081_H@80P6mU01h0P7=Y081]H`1lIUL0N5Q9079DB01k
Jed0P7=Y081`IP21Kf<0P7=W085[F`1lH540N51107QKB@1_D3l0Idlo06]=?01[BcX0Jddj06]8>01Z
D400LeY;07QKC01hEdP0Ke5306mBA@1_EdH0;A/H02dZ9`1gLWT;0820OQT0oooo3@2BPWP02@2AOgH0
UGIQ095]F`2BL5/0SGQ]09U_D`2?L5h0TW9O099_G`02099bHP0C08mTE027HDX0PU0o08YVDP2BNFP0
TWMW099[G@2ANV@0UGIS08aQCP2<FdP0Q54l08AQB@1gCCT0Me4k07Y<>P1lCSH0MdXh07Y9=@0208EM
BP0808MKA`22E480Oe9007mG@P21FD@07a8@08edK@2LShh;09:2N2@0oooo000R0?ooo`d0O7in00P0
PGIW07a]I@1iHeP0KeQ>07eLAP1fH5`0O61M07a]I@<0O75Y01h0O7m[085aHP1nJeL0Ke51075CB@1l
KFD0O7m`085aK@1lKFT0PW1Y07USF01jIED0M5A7071@@@1WA3X0IdPl06I<A@1dDTP0OUmD07ALC`1_
EdX0KeA707AHBP1`DdD0Je1006IA@P0o8QT02`X:01LC4P1lNGT:07anOQT0oooo3@1oOGd02022NG00
O75/07mVF@1hGE00Ne]906mQG`1oHe`0OfaT0`1oL6P05@1oMfT0PVQN07mUD`1dDD@0MUQ>07m/I01o
Mf`0PVMT07aZHP23KF<0NEmC07]MC`1bCT80LDm106Y5>P1ZBC/0J4]2079@@P1cEDT0KU9507EFB@02
07EEB007071@A01^Cd40Je54048R6@0F4a<0>3Hd07mjNP0:07mmOAP0oooo3@20P7h02020OgP0NgMc
085[F`1lHe<0Mem?06aVH`20Jed0P6mU0`20LfT05020LfL0P6=K07aQD@1hEDL0Nf=F081_I@20LfP0
P6=M07][G@21KEh0N5i?07QHB@1_C3l0Ke1106]8>P1[CC`0Jdi006mA?P1ZD400JTdn0P1hF4T01`1c
EDL0Ke5306mB@`1_EDL0>b4I02LO701XHE/02`20P7hI0?ooo`d0TX9h00L0SgIX08mfJP2<I4h0RF9<
08M/G@28IUd0TWIP00@0TWET01h0TVQJ08mMD026F4@0S5U809EiJ02BMF@0TVQK08mUEP2?KUT0RV5=
08IJAP21CSd0OU0o07M9>01jBcP0NTll07mB?@1nD3T0NTlk07mC@027Ed@0QeU6085D@P1lD3l0OeM2
085IA`0V5A00BC<[0;f]X@2BQG/:09:2N2@0oooo000R0?ooo`d0O7in00D0O7mj07QYF01/D3`0KEQ:
07aPG00207a]H00R07a]I@1lMW40O7I`07aaJ@1lLFd0O7I[07i[GP1dHe40KEQ607IUF@1lKF00O75T
07aaJ01mLF80M5]=06mDA`1[E4L0L5U;071F?`1/BSP0ITTn06mHC`1hH5L0NF1B07ESE@1_Ge40JeM:
06]HBP1[E4X0Kea?0;UhC`1V<R404PL501LD4`X0O7in6@3oool=07mmO@0Q07mnNP1mJU/0NEQ5079I
C@1eG5@0O6YM07mUGP1oK6@0Og9/07mcK01oL6P0Og1Z07m`I@22IeT0MUm=079EA`1lJ5h0OfiS07m^
I01oKVH0P6iR07YLC`1eETT0L5=607=EB01^Cc`0K4Pi06Q:?P1^E4X0M5M>07UKC`1hGe80LUU<0080
L5E800H0KU5606mHBP2IHdD0BRPM024F4P17AD@:07mmOAP0oooo3@20P7h02020OgP0PFmO07mPC01g
Ge80LE]?07][G@20Hed0P6mU0`20LfT01`20LfP0P6mP085UE@1hGT/0MeQ<081_I@20LfL00P20KfD0
3@21KV40O5iA07QKC01cEDL0LeA506];>P1[B3X0Jdi006iCA`1bE4P0N5]<07QNC`1cEdP00P1cEDL0
1P1_DTD0KeM706i@>`0_8AX0<bHQ081lN@X0P81n6@3oool=09:2N00Q099`G02AKed0QE@o095_G@28
GTl0SfiJ099XGP2BMF@0TWIW099aG`2BMF@0TW1N099[E@29FTH0REY4095ZF`2EMVP0TW=Q099bI@2B
KUh0SFED08MHA`27FdL0PEM407m>?@1iBSD0MdPi07mD@P25ETH0QeU608IJB023FTP0PeA30080PEA2
00H0OeA1085JAP19<2@0:a/F04dj<P3=`kT:09:2N2@0oooo000R0?ooo``0O7in00H0O6eU07ADBP1V
;bP0L4I005a<A`1ULV0207a]H00Q07a]I@1lK640O75Y07aaJ@1lLFP0N6UP07eaHP1mLVL0O6eP07a]
G01hH5P0MU]A07aPF01iF4h0MEI506]<@01WB3`0IT`h05m3=P1NA3P0JU5506iLC01cG500NF1B07EH
B`1_E4L0M5A7071D@`1_Cd00Ke5607UOE@2LKeX0b[2T00/0O7in6@3oool<07mmO@0;07meL01lI5X0
MT8h07QCB@1SBD00KfaM07mUG@1oK600OfaT07m^I01oLf`00P1oL6P07@1mJV40P6iP07]VF`1iHeH0
O6YK07eUG01lHeP0OfMO07mQE@1kFTX0L4m206m<?`1[Cc`0J4Hi06M8>@1ZCD80KEI907EJD01lGe80
N5U<079FB@1eEDP0L5=406m@@P1_DTL0N5a?08=LB@1oHEP0AdM700X0Ogem603oool<0820OP0Z081o
NP21M6P0P5E607aRD@1[CCh0Nf]M081SG@20Kf40P6mU081cJ@20N700P7=Y081cJ021Kf<0PFiN07MO
DP1gGdl0Nf]M085]H@20Kf00P71V085[F`1lH4l0LeA507=B@`1_E440KT/l06m>>P1[CD00KUA707MK
D01lHE80N5e>07=KC01cF4T0KeE506mDA@1_EdX0LeY:06M;>@0k81H09b0K2P20P7hI0?ooo``0TX9h
00T0TWa_08m/F@2=ET@0Q6E<08AUD@2LJeX0TVQJ099`H02BMF@00P2BN6T07`2BMF@0TW1P095_FP2=
IE80Qei:08aUD02?KU`0TF]K09ElIP2BKF80S6]A08IHA`21ET<0OeA0085F?P1gBSP0PTli085FA026
F4P0SF5@08UOC023GDX0Pe]7085IAP1lEd80PEA3085RCP1iCSX0GCTZ03LM601H?C@02P2BPWPT0?oo
o`008P3oool<07anOP0907a`L@1nE500MDTo06]6?`1hF4X0MVUQ07aaK@1lLFP0O6eU0080O75Y01l0
O6eU07a]H01mKEl0O6UK07eUF01fJF40O75]085oM01lKFT0O75O07iTF01aFDX0Id/n06=7>P1J@SX0
K4i106mKCP1dG4l0M61D07=PE01iH580ME]>06mGBP1_CdL0M4a:06]?A@1ZDDX0K50o06I9>`1YB3`0
PH>200X0O7in6@3oool<07mmO@0907meM022Fe<0NDTn06i2>`1aDTP0KfIN07m^IP1oKV@0OfaT0080
Og1X01l0OfiV07m^H`20K640O6QK07eTF01iJ5h0OfiV089eJP1lIF00OfiN089QF01fF4T0Kd`o06Y9
?01SAC/0Kdhn06M@A@1^DTL0Lea@07EMD@1lGe80N5]=079FB@1bD4H0MDm806i@A01_D4P0LE9006];
?P1VA3P0PWmo00X0Ogem603oool<0820OP06081kMP21HeH0N4/n06m3>P1^E4P0K6MM0P20Kf402@20
KfD0P7=Y081cJ@20LfP0P7=W085_H`1kJU/0O6MI07][G@02081_H@0?07]SFP20KUh0PF5H07QJB01c
Cd40KTho06];?01_Cc`0HDXn06Y=@@1cFdh0Mem@07aQDP1hGDh0LeQ90080LeA700D0KeA307=DB01c
ED80Ke5306];?00;0820OQT0oooo302BPWP0202BJed0REQ507m2=01oDT40Q6MF08Q^GP2BLU`0TViK
0`2BMF@07`2BLf<0TW=Q08e/F`2?J5@0RVaH099`GP2BLU`0SfED08mXEP2BIE@0REa<085B?`1oCcd0
NTdk07e?>@1jCST0N4dm07mC@P25GT`0SF5>08UOC023FdP0PeM408=DA021ET80Oe@o08IOCP1mCCL0
PEI509B3N@2?OgD02P2BPWPT0?ooo`008P3oool;07anOP0H07aaJ@1lNVL0OVaG075F?`1ZCCl0L5]A
07a]H01lKFD0O7I]07a]I@1lJF40N6EH07IYF01lH5`0OEaH07=PE01hG540MVEI07aYG01lKF00O6eU
07aXI`1nEdl0ME=50P1/CT404@1XDTD0IUM606YEA@1^FD`0N5a@07ALC`1dF4/0MEQ;06mBA@1_Cd00
Jdm006]D@`1ZEDL0NEmE071DA`1C>Bh0IF1Q00X0O7in6@3oool;07mmO@0907mgLP1oNfl0PVAF07M?
?@1/Acd0K5I=07aZGP1oK6@0Og9Z0080OfaT0200OFYO07a/G`1oIEl0P6AK07QSEP1mH5@0NFIJ07mZ
H01oKV@0OfaT07mYI022G500NEE706m>@@1/C3l0J4e106I@@@1ZD4<0L5Q<07QLD01fGE00NE]>07QI
C01bDdH0LU12071?@P1`DD@0K59607MLD@1^CT40H4<i07E`L0X0Ogem603oool;0820OP0[0820N`20
OWH0PEiD07M;?01_ASh0K5M<07][G@20KfD0P7=Y081_I@20LfP0PG9V081cI`20KF<0PFiN07aYFP21
IeP0Nf]M081_I020LfP0P6mU081]H`21HU40N5Y:06m?@@1[CCh0Id/n06M<?P1[D4<0Le]<07MOD01h
HE80O61A07QMCP1cEdP0LeA507=AA@1cDTD0KeA807=JC@1[C3d0KeA808F5PP0:0820OQT0oooo2`2B
PWP0:`2BOW40TVmS08U>@P1m@S<0PeA608a[E`2?KUh0TWET099bHP2BL600TWIU095dH@2EMVH0TV]M
08ebF02AJ5@0TFeH099cH`2BLf40TW=V099`H02BIUH0REe607mF@`1jCS`0Md`j07=<>`1lCS/0PEI6
08UOC02:He00RF5>08aOC023GDX0PeA208=D@`21DT<0PEA208=LD01nCS/0NE0m08egK`2RV8h02P2B
PWPT0?ooo`008P3oool;07anOP0707AWF@1N?S40@c0T048d;01JBD00LF1E07a]H00207aYH@0907a]
H01lJEP0OFUL07=LE01_H540LeaD07QYG`1hKEl0MVUH00<0O6eU01H0N7IS07UZF@1eETP0K4i106M;
?P1`C400Je1706mEC01dFDl0KeU<07APE01dHeD0ME]>06mOD@1[Fd`0Je=506]<A`1ZDDX0Id8`06Y6
>P1`@Bl0IC``2P1lOWhI0?ooo`/0Ogem02/0O71T075@@P1P@300GCld05m8?P1_FU00OfaP07mZHP1o
K6@0OfiS07mZG@20JUl0N65G07UUEP1kGEL0NfIK07]VF@1iIUP0OfaT07m/HP1oK6@0OG1S07mTF01i
E4H0Kdi106Y;?P1^Bd00J4m506iDB@1cF4d0M5U=07UOD`1fGe80N5U<079KC@1`EDP0L51406i=A@1/
DTP0KdLe06m:?`1`B3L0ITa700X0Ogem603oool;0820OP0[085iJ`1oHU40Ldlk07A;>`1ZCCl0LE]?
081_H@20KfD0P7=X081cI`20Kf<0PFmS07aYF`21KEd0PF9K07aWF@1lHeH0NfMI081_I@20Kf40P6mU
085_H`21H5H0N5A506m?@@1[CCh0Jdi006MBA@1^EdL0Le]<07QNC`1lHU@0N5i?07QJB`1cFT/0Le95
07=A@`1_DDD0KeM807==>01cE4L0Ke1106aUH`0:0820OQT0oooo2`2BPWP0602?JeD0SF5>07U==`28
CcX0SfA>08m[E`2BL600TW=S099fI@2BLf40TVmO08e_G@2AJeP0TV]H09AVF02=JU@0SFAB099^G02B
L600TW1N099`H02AIeP0S5A607m@?`80NThl00T0NE9007UG@P25FdP0QEm:08aQCP2<He00REY808=I
AP23ET@00P21D3l01P1oE480Pf9>07m4;P26IU@0O5=409:IV0X0TX9h903oool00280oooo2`1lOWh0
:`1iI5D0?R<D03HT7P0/7ad0:RX]075PF@1lKFD0O6eP07a]G01lKFD0O75]085aK@21NW00PVaU07AH
C`1ZBT80KEE:07=QE@1fJEd0O6eU07a]H01mI5/0M5]?06a:A@1WB3d0HdLh0699?P1_E4P0JUA406YA
A@1^ED`0Kde406YAA@1[E4L0IU5406]DA`1[DdD0Jdm406I:?`1XFD00FS`[06I:?P1U?3D02P1lOWhI
0?ooo`/0Ogem02/0P6UJ058[6P1=;RD0>bDP03`d<P1cGeH0OfaR07m/H@1oK5l0OfaT07m^IP22K6@0
Og5V081UGP1fFe00MEA;07ANDP1hI5P0O6YN07m/I01oK640P6MN07YODP1dCTH0K4/m06Q8>P1VBSh0
Ke9606aCA@1bE4T0LeM=07ECB01bEd/0LeI906iCAP1`EDP0KU9506i?A01[C480KeI0068m;@1^Cd<0
ISX`00X0Ogem603oool;0820OP07085^G01L<ah0GcT/04L/901LAS`0Mf=F081_H@02081_I00I081_
I@20Kf40P6]M07][G@1lHUP0N61B07aPD`1lJU/0O6]L081_H@20KfD0P6mT085]H@1lIE@0Me=806m?
?`1[Bc`0Jdi006mCAP1_EDL0N5Y>07QMC`1hFd`0N61A07QKC00207=HB@0706mDA@1_DDD0Ke97079E
@@1[@S80LeE706a5=P0:0820OQT0oooo2`2BPWP01@27ECh0ERhJ06/l;@1C;R@0XG9I0080TW1N01X0
TW1O099`H@2BL600TViI08m[EP2<IE@0Qea<08UOCP2<J5<0U7EO095aG@2ELf<0TW1P099`G`2=J5T0
Qee707m?@P1mDCT0N4/k085D@P21FDH0Q5M608YOC@2<Gdh0Qem908YTC`80Q5]700P0PEU607mB@01o
DT@0PE]907Y7<@22Cc`0Q55209:2M@X0TX9h903oool00280oooo2P1lOWh0;01lMW40Q7ag09EIAP16
:Ql0>BDP02XZ;@1aH540N6UH07IYH@1lKF@0Kea<061=?`1E?c80B3<X04dl<`1D?S/0IDI206E6?01Y
CD@0LF1E07a]I@1lKFT0OFaR07YNDP1`E3`0IdLf06Q;?01NB3`0FTHk05I<@01MCD80IEU906]KC01Z
EDP0M5]>071GBP1[E4L0Je=506]?A01[D4L0FSP/040O5`1;<280H3LV2P1lOWhI0?ooo`X0Ogem02`0
OgUg08EiM028CS`0@RLL03lW8@0U:B`0LemB07eZG@1lJV80OfaQ07YSD`1bFdl0KE5306E;?P1XCdD0
JT]506m>AP1/CT80LeQ=07ISF01oK6@0OfaV081[H01mGE80M58n06Y6>@1ZBc/0HTPk06E:?P1UD4@0
J51406aHBP1cF4`0KeA807EIC01`EDP0KU=606iBA@1^Cd@0KTm606Dm;`1B:Q`0FS//06<h;0X0Ogem
603oool:0820OP0<0820O@21Mfl0L4@b03/U6`12:B80=c4`07MSEP21Kf<0P6mU081_H021Je/0PF]N
0P1nHe<01P1nHeH0NeQ?07QHC01cF4T0O6IG07][G@80P6mU00d0PFeN07aND@1cDT40JdPl06]=?01W
BS`0KU53079GB01cEDL0Le]<07QHC01cEdP0LeY;0080KeE700L0KeA506mAA@1_DTL0JD8`06<e8P1[
BCH0K4Dj00X0P81n6@3oool:09:2N00/099oM@25F4P0EBlO03`S6@18:280RF=@099`G`2AKel0UG=S
099`F@2<JEH0UG9P08eUDP2DKEP0TVMG091JC@2<HD/0RF5=099bG@2EMVD0TW1P099`GP2=He80PeM4
07Y<>`1jBCP0MDhl07e>?01oF4D0Q5Q508YKA`29Gdh0Q5A408IKB021FDH0O5A207mGA01oDT00Oe94
07mGA01Z>RL0MCTS08YE?02EQH4:09:2N2@0oooo000R0?ooo`X0O7in02`0N6eR07USE@0Z3`X060l=
01hH5@0E92P0Lf5E07aYG01lJEP0O6eP08QeI@1/ETP0EdHh03D^:P0M71/06a`D02hU7P1391/0>aLB
04LX8@1fIET0O6eU07eaHP1jHE80L59106=B?01OAS@0HDe207ULCP1nGe40M5M:06]9@P1SC4<0HE55
06mHB`1`EdX0Hdm305Y?@`1RE4@0JeA706i8=P1J<bD0E2hV060]8@X0O7in6@3oool:07mmO@0/07ed
K01oJEh0=a8<02PF4@0X6aL05b@Y07EOE01oJUd0O6QJ07m/H@27L640LUM906E<?@18=Rl0=RLR03/Y
7@1;=2`0Fc4T05HZ7`1M@cX0O6QN07m/I020KV80OEmB07AA@@1XCc/0ITDe06=<@@1bE4L0LUM;06aC
AP1^CD@0KE9606MBAP1bEd/0LeI906Y@A01UD4@0J55406iAAP1`ASD0FC4T058_9P1P<28:07mmOAP0
oooo2P20P7h04@21OG@0PG1V03`D3@0d71D0<AlI03@_;`1gHeH0P6mO07][G@20Kf@0PFiN079JBP1^
Dd80EShd04/b:P1J=RH0JD@i0080KSh/0140Mf=E081_I@20KfD0PFiQ07aND@1cDT40Jdhj06Y7=P1W
Cd80Je1306ICAP1VDTD0KeA7079JBP1_EdP0LeY;07=HB@0206iDA@0606mBA@1_DTL0JdDd05H`8P1F
<bL0J40]2P20P7hI0?ooo`X0TX9h02`0TG9Q08aTF00c40T0>1dE03/R6`2GJeL0SFaH099_FP2?L5l0
TW1O08MSD01gE480M4hj05`n<P1F=BX0LS`X08aD@@1o@2/0Q4Pa0:N<M@2EMVP0TW1P08eUE023E4@0
NThh07Q>=P1eACD0OeI407QA@@1bDD40N59107mHA`1mFTD0REe:08=KB01oEd@0NUA207mD@P24E4@0
OeA406@g9`1R;Ah0Mch/09:9O0X0TX9h903oool00280oooo2@1lOWh0;P20PX80Qh5j07UIB01[?S<0
:QPC02TG4`0E7B<0O6eP07Q]G`1fJE`0O6eP085fK02=LF80V7AY06a8>P0`71H091PC028R8@12?C<0
M5i?06eHCP1fKF00O7Ye07ejL@1jIED0IdTl05Xk<00m50/0<A`J05Hl:P1?>2X0?2dS04<i;@1SC400
GDdn06IA@P1[E4L0K4m106=<@01RC4@0HdPn05@g;01;=R/0F4@l06Tn=P21Ph8907anOQT0oooo2@1o
OGd0;P20OWh0QGih07eLC01Z>S409QDA02PG4`0;6b80O6QL07]ZG@1lJ5`0OfaO089`IP28JE/0OF5G
06=1=00c7AL0:a/E034W8`1??340I4Tn05a1>`1iIe/0Og9/081cJP1mHU<0Kd/m06=1<`1=6Ph0AblY
06=5<`1QA3D0ESX/05]5>01ZCD80HDi006iCA@1`EDP0Kdm206E=@@1SCD@0JTa0060j;`1B=RX0ES`d
06<b:022Ogl907mmOAP0oooo2@20P7h08`1oP7d0P7ed07aPC`1L=bh08Q<?02TH500Q9RL0NfMI07a[
G020Jed0P6mP081_H@1lHe<0I5A8058j;P0b7aT0<alG048_9`1N?Rl0FCX`05He;P1kIeX0P6mU085_
H`1lHU40LDhn06Y9=P1F8140HTHh06i@>`1`D400JTLe079B@`1^DDD0Ie930080LeQ900P0KU9306MA
@`1WDDD0KU9306@n<01J=bT0FST_06Hd9@X0P81n6@3oool909:2N00^09B3N@2<IE80Q5I503`S7@0R
4Pd0=1XD08Y/F02?JeL0SFYF09E`G02BL5`0Sf]I07QB?`1[CCl0?R/P034K5P128QH0FS`_07Xl:P1_
?2l0Ne52099_G`2BL640SFA?08=D@P1eBCD0N4hd05LM3`2?Hd/0PUHk07iE@`1gBC@0See:07YDA021
FD<0Q5]9085IAP1eCcd0MEA207mDA01jE3l0HC@W06dh9`1l@3<0T7U/08moM@T0TX9h903oool00280
oooo00@0O7Ee07aiN@1lNWT0O7Ui1@1lOWh0;P0W40/02Q0E07YPDP1cASD0;QlR01`D4P0551`0LfEH
07a]H01hJE`0LfEH07IYG@28OW40M6AB0:IfH02iQ6P0VfI9085>=01`FdH0KeQ807=EBP1fI5P0O6aQ
07e]HP1jHE80NU<o06Q6>01fCSX0AcPe038`<`0;1PL05ALG02XU8@0O6A@071hN03P/8@1;=RL0J4`n
06=?@`1RCd00GTHh044]8@0]8ad0?C`d06U9?021Ph8907anOQT0oooo00@0OgUi07mjNP1oNg/0OgYj
1@1oOGd02@0m6A80ADA107mQD`1b@C80;QdP01lD4@055A`0N6II07m/G`0207]XF`0S07aZGP27MFX0
Lee?09IYF@1nGTd0HdLg05Xk;01CBCd0HT/o075CB@1iIET0OfiT081`I`1mHU<0NE4n06I4=`1^AC<0
A2hZ04Lf<P0F2@T0=BDO03/]9P0g91X0?S4/058j:P1M@S80KDm106E=@@1SCd40J4Pk04h`8`0k9R00
AS/c06Ho=@25PX402@1oOGdH0?ooo`T0P81n02h0Bb4H08EgJ`21IED0I3`_02XL7P0R5A009B8T07a[
G020Kf00O6]L085_G`20Kf40PFmS07=KC01lGU40A3de034/9@0i;RD0@3dg05a3>01bF4/0Nf]M081c
J@21MF/0O6ED07=@?P1RA3H0H3d/04DY8`1F?3807P`;05@c9`1<=b`0BbhQ0656>@1YB380Ke0n06iD
A@1WCT00Ie5306];?P1C<RD0BB`R05U0=@1[@SL0QHF22@20P7hI0?ooo`0409:4NP2BQG/0TX5g09:5
N`D0TX9h02d0AadD0<nJO02;HDh0BbTP02@G6@0Y5@l0UfmJ095_FP2BL5`0SFaH09AaG@2ELf<0Qf5?
08EHB01UAc/0=BHS02dM6011;RH0GD4f07U;?@2:J5@0TWMW099hJ@2=KE/0PeU607A8=01[@c<0F2dO
05di;`1N?2`07``:078m:`1Q@c80E30P08=F@@1nCc<0SEY307QFA@1eD3h0Oe9206e9>01>:Qh0GS0S
08mGA02DO7H02P2BPWPT0?ooo`008P3oool00`1lNWT0O7Ui07b3PP0507anOP0^02dI500[6aH01P<2
00T82P0O51P071@@02LI500@6Al0N6UL07IYH@1dDTd0ID<m06]GC@21MW40Qh=l08igL01oGU80Q6II
08AUE`1iG4h0N6AD07QPE01fI5P0O75Y07e/I@1jIe/0L5Y806aF?01eF3l0PeM209ENB00_6aP06aHA
02lO7@0a9200<RTQ05Y0=P1QDD<0L4ln06Q<@01RE4<0AR/U034Q6P0_7aL0:QhJ05XX70X0O7in6@3o
ool0101oNGT0OgQh07moO`1oNWX407mmO@0_04<U7P0o9Ql05PH303PQ6`0a6ah091HB02LH5@025A`0
NfQK07UXGP1mG580LUA9079OE022L6X0PWE/08AYH01hF4`0NUe@079EB01ZD4<0LEa=07QKD01iHeL0
Og1X081]I@1mIEP0M5E406e?>P1/CSX0KTTj07MA@P0[61H071HA03PT800f9R00<bXR05Dn=@1HAcX0
Kd/k06Q=@@1SDD80Dc0X03hV700e81P0<BLQ06<h;022Ogl02@1oOGdH0?ooo`04081lNP20O7T0P81n
081lN@@0P81n02l0DBlW04/_9`0X20@0I3X/03`R900Y6A<09aTF01LN8@1lJe`0Nf]M085UEP1lIeH0
Nf]M081_I@1kJed0MemA06mEA`1_EdP0HDTj061:>`1^F4P0Mea>07]WFP20LfT0PG1T07aUE@1cDT40
Jd/h0696=P1J@3D0EdHl028F5@0S6180@2XT03PX8@0k;B<0Dcld05I3=01[BSX0Ie5306MB@`1G=2/0
AB`O03/S6@16<bT0LE=308F5PP090820OQT0oooo00@0TWie09:2N02BOgD0TWme102BPWP05P1<:B00
ABPO03h;1@24BcH0>AlP02TI4P0_6AD0QfYF08e/F02BL5h0REi;08mbF@2IO6X0SfmM08UPC01nDT00
N50m07E??@1/@c40MU4k08AJB02:He02099eI00G08eVE023GDP0NTPd079:=@1/?Bl0HdDk04hi<00E
3Ph0?AhD04da:00i9A`0GSTY06U3<`1dBcH0MDXi07=D@P1oE400CR`T04HY6`1:9AT0QDPe09bISP2E
QG/02@2BPWPT0?ooo`008P3oool00`1lPh80O7in07anOP0507anOP0^05@a:@0d8AT0<alH01lH5P0F
3@`09ALD02dI500E61h0O6EH07QUE@27R7P0OfmR058h:`13:R40@S0V03D/900/8Qh0:1hH034U700g
8a`0AcL`06ePE@1fIET0O6UL07e/FP1jH580L5M:06a4>01SCcX0HU0k07ENC@3=RV/0XW=K07i=>01n
B3D0LDi107EF?`1SC3h0IUM607EHA`1SCdD0B2lP02TI500_7QP0;b<K05@N4`X0O7in6@3oool00`1o
OGd0OgYj07mmO@0507mmO@0^05Ta:@0b81P0<1/F02<G500K3Pd09QLD02TH500;61h0O6II07]VF025
NFh0NUmE06=4=P1SASX0HDTl05Q1=`1?<bX0BS0T050f:@1D=2P0GdTm07AOE01iHeP0OfaQ081]GP1m
Ge<0M5M906a6>01UCcX0IT`j07=HB@2NJE@0FdTo05/k;@1O?2l0Bcde0618=`1SB3`0JeE4071AA01U
Cd@0D30Q02hJ5P0b81P0<BDL05TS60X0Ogem603oool2081lN@H0P81n02h0DBlW034O600]6A@0:APD
01h?3P0W61D09aPD024T9@1kJe`0O6]L081_I@1cE4X0LE1007iSD`1kHU40LeE806Y3=@1W@S00K4Le
06i5=01hGT`0O6=F07]WFP20LfL0PG1S07aQE@1cF4L0Jd/h06MA>P1[C3`0KeE706M<?`0O9RH0>b`T
044c:P0a<B`0DD0b0698?01_ED<0Jdm206MA@`1?<B80<A`G03LR6@10:Ql0J3LX2P20P7hI0?ooo`03
099kLP2BOgD0TX9h00D0TX9h02h0=ATD03PQ5`0`5A40=AdF01d>3@0`6QD0<1TC08Y[EP2?KeX0SFmM
08aOE01jC3`0PEE109McG02<JeD0PEM807Q4=01lBc@0Q4lh08I?=`2NMeh0U6aH099`H02BMV<0SFIG
08=OCP1jCSX0Mddd07EB>021DT00NE10044]:00Q6AP0>bDN03l]9@1>>2h0ID8_079>?`21E3h0MU10
07EB?`0o91T0=A/E04LT601e<b80VHb12P2BPWPT0?ooo`008P3oool807anOP0E05`i:@0Q40/061<?
01`C3`0U5Q406Q@@02PT800I92L0JeaA085]H01lKF00SGmh09jCP`23IUX0ITe;07EIDP2<GT`0OeY:
071A@@1iGTl0N65E0080O6eU01L0O61P07eUGP1jI5D0L5==04h^9@0l7aT0@c8X069@>`1[E400NE]:
08QXD`1jHe00IUM606=CB01[CdL0Hda5069@@01NASH0:1/E01PD4013?SH0FcTY04TN4`0:07anOQT0
oooo201oOGd0;P1P>2T0914<01hE400Q51009QHA01XC400[8Qh05R4U079OE022JUd0O6YN08QeKP29
MfX0LeE;06Q;A@1XD4P0Kdi106=7?@1OA3L0I4a106=:@P1eHeX0O6YP07mUH@20J5h0OF5C07ACB`1L
=2L0DR/P05A0<@1XDCh0KU=207EGB01hFTT0JU1205i:?@1XCd@0KTm206E=A01XDD40J4Tj030N5P0N
5A40<C8]04``8`1=6a4:07mmOAP0oooo2020P7h0;P1G=RL09Q8=02<G4P0V5Q4091HB01/C400_8Qh0
;2PX07]WF@20Jed0Nf]M081_I@1bGe80HTPm06A;@01NBcl0DT4f04/i<@1?>Rh0E40e05Hm=01aGe80
Nf]M081]H`21KUh0O65B07=EBP1T>RX0I3TW06MA>P1_ED<0KeE506mEA`1WCd00Fd8g05Y3=`1[CT00
Ke4o06MA@`1_ED<0Jdhn034P600S5a80;b`W044Z7`1M:A/:0820OQT0oooo202BPWP0;P0i7A@0:A8<
02LH4@0/5a409QD@024E400m9Ah0QUe:09UbG@2?KUX0SfiN08QUE01aBCP0J3da06A8>@1]B3P0D3DY
05<f:`1I=BP0JD4b07AA@@28IE@0SfiK099[FP2=KE@0Pea:07Y;?P1Y=b<0Ld0Y08QU@`24FDD0OeM3
07]B@P1XAC@0H3/_07=7=P1hCS/0Oe8o07ED?`24FD80KDXi02LH4P0W5a40Hc/^05@T6@2IPWP:09:2
N2@0oooo000R0?ooo`80O7in00<0O7Yi07aiN@1lOWh00`1lOWh0;`1XB3T0;a@>02@D400L51003`P8
01`B3`0X7a`082HW05M<A01fIET0O6eP07aaJ@21NWD0TYJ90:jNS@2BUXT0WIjE09fJT@2SXiT0SH]n
07e]G`1fKF00N6eO07=bG01hJE/0OfQJ08AgH@2HOFP0HShh02TI600F4Q008B0N05=3>@1[E4D0MEQ3
06=?@`1WBch0Ed@f0659@@1[C4D0ARXP02/H4P0[8Ad07b<N05<]7`0M20@071TH00T0O7in6@3oool2
07mmO@0307mkN`1oNWX0Ogem00<0Ogem02l0K4Lh02hC3@0S4a007A@@0188200O4a009alL028Z:P1S
DdT0O6IJ07m/H01oKVH0PW9/08QnLP2>MFX0KfaV08EeKP1oKVH0PWE/079UG01gGe@0NFUM07e/H@1k
KUl0OFAK07mUF01lJEP0Q69F05/f;`0i81/0<R4H04He;01PBSh0L5=507=E@P1UCd80K4ho05m8>P1X
Bd@0J4e405<`8`0b6a@0:1lK01/S7P1M<B40=1TC04Y:B@0907mmOAP0oooo2020P7h02`1P@cD0:a8=
028D400M5A004`T8028E400Y8A`0=c@`079OD@20Jed0P6mQ0080P6mU00T0Nf]M06aBB`1DBTL0K59;
06=:?`1SCT<0GDLn079HC01kJed00P21Kf<05P21He/0O6IG07=OD01[C4D0D2hV04LY7P1;;b00K4/i
06mEA@1cEDD0KeE306MA@`1_DT40IDho06mAA`1WDD<0EcDV03<M5P0U7QX0:BLQ06<e9019;2@:0820
OQT0oooo0P2BPWP00`2BPGL0TXEk09:2N00309:2N00>044U6P0Y40/09AD@024E400E2@P0:ALA03TW
801mF4D0VW9M09EcGP2BL600TW9R08m/FP22EdP206Q0>@0O0790<`1[?Bh0J3X[0751<P24G4/0TW9R
095/F`2DJEd0TF=D08EQCP1lDTH0HSH]04`T701E<1l0FSDR09IL@@2=HT/0PEM007UD@01eDT00OE8m
079??P24ETP0NE@o04h^800/6A80;20I06Hi:@1Z<1l0F48h0<[3^@0909:2N2@0oooo000R0?ooo`80
O7in00<0O8>207anOP1lOWh00`1lOWh03P1EACl0;R8M02@F4P0R51007A8=01hD400X7a`0;Bd[05e<
@`1fIET0O6eP07a]I@1lLFT0O7Ia0P1lNgT07`1lMW00O7Ia07afL01lMW40PGI[07aYF021LF@0OFUK
07QPE01mIEP0OFUK08Q`I@2WRGP0ZgU[081DB00a91d05Q8?01TG5`0W8R40<RTQ03P[8@1L@c`0Jdm3
06M;?P0m8Q/091DA024F5P0B30X08A<>03hV8@0R7Q`02@1lOWhI0?ooo`80Ogem00<0Ogmo07mjNP1o
OGd00`1oOGd03P1MACh0<B4K02@E4@0R5100718<01`C3`0Y7a`0:Rh/05e=A01iHeP0OfaP07m/I01o
L6P0Og9/0P1oMG004`1oLf`0Og9/07mcK01oLV`0PW1U07aXFP22L6D0OFQK07]SEP1mI5L0NfAG085W
G02>KV00NeM?0651>00d91`0<1hF03lZ8`15<b/00P1>=bX02P1SAch0Hd]006a<@0168a`0:1HA02<F
5P0M3``0>ATA04HX8`0H6AP907mmOAP0oooo0`20P7h00`20O7T0P81n0820OP020820OP0<05M3?00a
7aT08a@@028E400J4@`07A<?02/Q700g=2l0I5A807]WF@20Kf40P6mU2020LfT06`20Kf00Nf]M081c
I`1lJU/0O6UJ07aWF01gHeD0Mf9E06mGB`1=>SD0@C4Y03LU7017:Qh0HSh`05m5=P1WAC80HD<b06]>
@P1NBch0Kdm304DU7@0Z61809APG02XC3P1?7a@0BBdU02`T7`090820OQT0oooo0P2BPWP2099oM@@0
TX9h00/0?BLO034K5@0V50h09QD@01/@2`0U50l0>RLP07E??@2=JeL0TW1L099`H002099eI008099f
I`2BLf40TW=Q099aG`2BMVL0TW5O099bG`2?JeD208m`G`0H08YXE02=J5@0RVQD08MRD021FDT0H3hc
04<W8@0e91`0ABLK05Lb8@1mB3D0Kdli07]:<`1cAc<0Q5Q707=>?@1mCcl0=Q`E02XG400/6aP0?AH>
06<R501:<bX0Sgme2@2BPWPT0?ooo`008P3oool807anOP0I06Q=A@14;bX091TD01lD400T5A409ATI
02XQ7`0W:bP0Achg06]KD@1lKE`0O6UM07a]I@1lK640O75X07afL@1lNgT0O7Ia07afL01lLFT0O7Ia
07aaJ01lKF00OFeN07QYF`0207QPE00D07QTF01oI5L0NV]H099_FP2ILed0S6IA06E9=P1R?Bd0J4Xl
07YLC@1NAd00GdU305M:?@0o91`091DA01/D3`0E4@`061LD02lT8@0R7Q`907anOQT0oooo201oOGd0
;`1/C4D0?R/W02<G4P0Q51008aDA02<G5`0Z81d0:bdY05=5?01bGe@0OfaM07mZH01oKVH0OfiT07mb
K01oMG00OgMd07mbK01oMG00Og1X07mbK01oKV<0OfaO081/GP1kIUT0NemC07]REP1kI5L0Of5F07QS
E@23Ge00MeQ:06I;?@1>>Rd0ESL[05A2=`1UBd00ED4i06Q;A01TBcd0AR@L02DE4@0M51006A4=020F
4`0f92006a/J00T0Ogem603oool80820OP030619@P0g:B@08AHB00808QD@00L08QLF02/Q700k<b`0
IU1407]WF@20Kf00P6mU0080P7=Y0`20N7401020LfT0P7Q`081cJ@20LfT2081_H00H085^GP1lIeP0
O69D07aWF01lIUP0O69G07=NDP1_DTL0DT8i044d:`0k;bD0BcDZ04Ln=01B@3@0DShd06iAA@1/CSl0
@b@L02@F4@0N5A00718=02XG4`0n9R40<BTT2@20P7hI0?ooo`P0TX9h0100@BXS03/V800O4`h0:1D@
02DE3`0X61H0>BHN06e9=`2BJE@0VGIQ099`G`2BLfH0TWMW099hJ@2BOG80TWU/0P2BMVL2099eI00J
099bG`2BKUL0TW1L08eXE02=IE80SF=@08e[EP2=He@0QF5@07eEB01X@cP0B34Y03/V7`15:R00DSHY
05e0<P1J?Bl0Kd8h07eF@P1gBcT0<aXD02LE400S5Q008A4<03XI4`1;;bL:09:2N2@0oooo000R0?oo
o`P0O7in0100Hd@d034P5`0b81X091HB02D@300Y5a80;AdF02LR7P0f<Rh0HU1707IYG01lKF00O6eU
07afL@1lLFT0O75X0P1lMW407P1lMW00O75Y07a]H01lKFD0O6UP07eTE`1hH5@0N6UK07QPE01hH540
NEa?07YHB`1jFdh0NE]<08ASE02=K5X0R6QH07EIB`1eCdL0L5I5071;?P1D=2L0>1lH02@E4@0[6A@0
8AHB01`D400T6A<04PX605YADPP0O7in6@3oool807mmO@0@06U4=@0e8QT0<b0K028E4@0U4@`0:1LC
02`M5`0^9R80@c/d06QEB`1lJUd0OfaP07m/I01oLV`0Og1X07mbK0<0OgE`01d0Og1X07m^H`1oKVH0
OfYO081WF@1kHUH0NfII07]OD`1kHE<0O5eB07YKCP1hFdd0MUM907EIC01fFT`0KU=606=;@01^Bd80
Je9406m9?`1M>R/0?R4J02DE4@0Y61@081DA01dC400Y6aD081hK06aVI`0807mmOAP0oooo2020P7h0
3@1P@cD0=b@K034P6`0P5A009A4<02LH500]7aT0>RhV05Y9?@1bGe80P6mP081_H@20KfD00P20LfT3
081hL@06081hL020LfT0P7=W081cJ020Kel0PFeM0P1lIeP05@1lHU@0O6IG07aQE@1hH540Lee>06mE
A`1VDdH0GT`o05I3>01F@SL0Id/o06MA@`1[BT40Gd0_03hS6`0T5Q409aPD01dE400O5100;alH03li
=@090820OQT0oooo202BPWP040149ad0?BDK02lN600T50l0:a4<02hJ5@0i8aT0EcX]08mTC@2DM5l0
UG=N099`H02BMF@0TWIW099eI02BOG82099iK080TWET01`0TW=Q099cH`2BKeP0SFQD08e[EP2=IE80
SF=@08eVE029HE00QEm<07eKB01fDT40Kdlo0611<P1M?2l0J44c07A>?`1fCSl0MD`m05dl:@0e7AH0
9aD@02dI4`0N50l0:1D@03lV6`2:MW00YYnD202BPWPT0?ooo`008P3oool807anOP0A05Dn;`0e:BD0
;R0K02`K5P0I4Pd06a<?01/B3`0T6aH09B0I04Lh;`1fIET0O6eP07a]I@1lLFP0O7]i07aaJ@1lLFP0
0`1lLFT01P1lLFP0O6eL07QYF`1hJE/0N61D07QLD@80N61D01@0NF1B06mKCP1_F4/0M61B06]GBP1_
E4L0L5A706=CA@1JCd00FTm305=6>00c9b406A8=024H5`0G41405a0<00l71`0J4Q407QXH04@g=@P0
O7in6@3oool807mmO@0A05dn;`0h:2<0;alJ02`J5@0K4@`07a<?020C400/7aP0<bXQ05M5?01iIUX0
OfaP07m/I01oKfL0OgMd07m`J01oLV`00P1oLf`01@1oL6P0Og1W07m/G@1mJUh0OFQK0080NemC01H0
Nf5E07]OD`1lGe80ME]=07EGB`1eFdl0KUE8079EB01`DdH0JU9506E?@@1UCd@0HDPj044Z8`0Q50h0
9APG01TA4@0K4@`04@P801lE4P0W8al0CD92201oOGdH0?ooo`P0P81n0140Ecd^03TY8`0^7QT0:QXE
01/A300S510091HA03LU7018=bT0KUQ;07][G@20Kf40P6mU081cJ@20N740P7=Y081hL@02081hL006
081cJ@20LfL0P6mP085^H@21JU/0O69D0P1lIUL05@1lHU@0O65B07QMCP1hFT/0Le]<06mEA`1cF4T0
KeE706iDA@1^DD<0KU5506];?018;RD09AH>02PI600K4A007A8=01<9200W61@0>c4Z06=GE@080820
OQT0oooo202BPWP04@0m8aP0@2XR02lL5P0^6A<07A0;02/F400/5a40CB`O07=:<P2PNVH0TW=N099`
H02BMF@0TWU/099fI`2BMF@0TWeb0080TWQY00X0TWET099`G02BL5l0TF]I095XE02=He00SFUD08eV
DP2=He00REm<0P27FdP01@21FTP0OeA208=IAP1lEd@0NU900080Oe9200X0M4Tg048X7P0T50`0;QXH
01lA3`0P4P`05@T803LM5@1_DDL0Wi:;202BPWPT0?ooo`008P3oool807anOP0B06Q7>00d91l0=RTT
02dP6`0`71L091DA02TM6@0/9R@0;BXX02h]:`1[E4X0O6UM07aYH@1lJ5d0O75X07akN@1lMW40O7I`
0P1lLFT00`1lLFd0N6UP07QYF`0307QPE00F07APE01_G4l0M5a?07EKCP1_F4/0KeE807AKCP1[EdX0
JeA706aCA@1[Cd<0K4/n050f;00d7AL0<1lJ01D<300G410040P801P@400K4a008B<R03Pb<0P0O7in
6@3oool807mmO@0B06a6=`0d91h0=RLS02`N6P0^6QH08A@@02PK5`0[8b40=2XV03Xe;P1bFe40OfYN
07mZHP1oJf80Og9/07mgM01oLV`0OgE`0P1oL6P00`1oL6X0OFYO07eZG00207]QE@0G07]OD`1iGe<0
MUe@07UMD01hFdd0LUM;079EB@1eFdd0KUE8071CAP1_DTD0J4m206Y<?`1I>c00>alI02lN6P0F30`0
6Q4A0148200I41006a8?02LT8`0k<c00201oOGdH0?ooo`P0P81n00h0H4<e03<U7`0e9b80:QdI02XI
500O51009a/G02dS7`0o;RD0E4<e07]WF@20Kf40P6mU081cJ@80P7Qa00L0P7=Y081hL020LfT0P7=Y
081cJ021Kel0PFiN0080O6IG0P1lHU@207aQDP0C07QMCP1cFT/0LeY;07=MCP1_EDL0LeE706iDA@1W
DD<0Idm105a0<P0l8QX0;1hI01H<300L4Q804PP801TA400M4`l0=B/W04m0>P080820OQT0oooo202B
PWP02`119Q/0>BLP03TU7`0^6aH0;1LB02<D3`0^71H0?RPP05Le9P2EITh0VGMQ0080TW=S00@0TW]/
099mLP2BMVL0TWIW0`2BMF@00`2BL5h0TFmH095[EP0208eVDP0408eSD02<He00Sf5>08aQCP80Pe]8
0140Pee:085KB01oE480PEM407EB@01iDT00L4lm05Xj;00f7AH0;AdG01P<2`0O4Q4050P801dA3`0W
5@l0Gd@k09V5N`0809:2N2@0oooo000R0?ooo`P0O7in02l0G4e703P[9`0h:bL0>2XU02dL5`0J4@`0
8AHB034O6017<2@0@S0U05e4>@1fIED0O6eP07aYH@1lJ5d0O75X07afL@1lNgT0O7I`07aaJ@1lLFP0
PG5X07e]GP1dI5L0Kea?07=ID01iFDl0M5Q;07AEC01eF4h0KeQ;06mDA`1[DD@0JeA706M;?P1`C400
HdLj04hh<00n:1l0<1`F01P@2`0I4A0050`<01TA300H41009APD04mADP0907anOQT0oooo201oOGd0
4`1SC4D0>BTT03LY9@0f9b<0;1XF01`A300T5Q<0<B0J040_9P0n=2X0IDe307aVF01oK680OfYR07m[
HP1oLV`0OgE`07mgM01oLf`00P1oL6P06`22KVD0OFYL07UTEP1fGE00N5]A07aKD01fFdh0MUM=07QI
C@1bEd/0LUE8071CAP1`EDP0K4i0071?@P1UBC`0GSle04`]8P0e7AL06a4<01`B4@0E30`06A4<01P@
3`0S5a@08RHW05UFE@0807mmOAP0oooo2020P7h0301LBD80>BTS03DY900c9R40:QXE01dB3@0W61@0
<R<L03ha:016?300LUa>081[G@80P6mU00@0P7=Y081hL@20N740P7Qa0P20LfT02`20LfP0P6mT07aZ
F`1lIUL0O65B07aQE01lHE80N61A07QMC`1hGDh0LeY;00<0LeQ900h0Ke9306mDA@1WCSl0IdHi05<b
9@0f7aP07A8=01dB4P0E30`06A4<01L?3`0T5a@04`d904Dk=PP0P81n6@3oool809:2N00`040Z8P0o
:B40?2TR03HT7@0^61<07Q4<038K5@12:1h0E3PZ07M?>`2GMF40UG=Q099`H`2BLf<0TW]/099mLP2B
NF`0TWIW099aG`2BMF@0TW1P08m^FP2:IE80S6=@08mQCP2AI5<0RFA>08UOC029Gdh0Pee808=KB023
FDH0PE]7085IAP1mDSl0O5I407E=>`1[ACH0D2dP03<K5@0O4P`07a8@01P<2`0L40/06a0?02hI4`1U
CT@0Je57202BPWPT0?ooo`008P3oool607anOP0?07ajN@1hLG40ED4j02lT800c:2@0=2LR02@G4P0]
7QX0:AhI02DN700b:b@0B3`c05Y5?@1aH5D0O6eP0080O75Y0140O75X07afL@1lMW40O7I`07aaJ@1h
KEl0MVEH07eTE`1mH5@0OFAG07APC`1dG4l0M5]>06mLC01_Fdh0Jdm706I@A`0206]DA`0>071FB01S
Cd<0FdPj05ho;`0o:1`0;A/E024F4P0M5A007aHA01TA300L51008aPD00/51021Ph8807anOQT0oooo
1P1oOGd03`1oNg/0OGMg05e3?00b9B40=BPT03DW8P0W5a<0;1`H02HK5`0X7Q/0=R`T04Xk<P1OAS`0
MV5F07m/H00207m^IP0Q07m_I`1oMG00OgE`07meL01oL6P0OFiR07aXG@20IeT0OF5E07]QE@1fGDl0
NE]@07IKC@1eFD`0MEU=071BB01^DdP0L5=606iCAP1`E4H0J4e106I9>`1S@340@bPM030K5@0R5Q40
7A@@01hE4@0I40`071@@028G4`000000PWmo00P0Ogem603oool70820OP0>0860OP1G@c`0=BLR03LZ
9@0e9b809aPC02XL600T6QH0;AlK044_9@1B?S80JTdo07]WF@20Kf42081_I@0J081cJ@20N740P7Qa
081hL020LfT0PG9V081_H`21KEd0O6IG07MRE01hGTl0O5iB07QMCP1hFd`0N5Y>07=GB@1cF4T0LeE7
06mEA`1_E4D0Jdi006a;?01S@S80@BTN034L5P0Q5Q4201`D400401P@300L510091LD01T>2@T0P81n
6@3oool609:2N00?09:1M`2APWT0?BTR03dX8@10;2D0>RLP02PF400^71H0;1/E03TR6`1R>BP0N4Tf
08mVD02ELeh0TW1P0080TW9R0`2BNF`2099eI00L095_G@2ELEl0SFQD08YVDP27HDh0REe<08aOCP29
FdP0Qee<08MIB021ETH0Q5]6085GA01oEd@0O50n07Q@?P1eAcD0I3h^03/S6@0b6Q@08AD?020D3`0O
4`l06a0;024E400_6A@0U8=i08moM@P0TX9h903oool00280oooo1P1lOWh04@1lPh80PHR7058n=@0g
91/0=2@O03DY9@0m;BP0;AlJ02dQ7@0a8AT0<2lZ03Pc:P17=Rh0Ie1707IYG@1lJF40O6eU00<0O6aQ
01d0O6eU07QUF01hIEP0LfEH07QXFP1dG4/0KeU907ALB`1dG4`0M61B07EHB`1_F4/0M5]:071DA`1[
Cd<0Jda006=?@`1KAcX0Dcd_03TU8@0/6QH071@@01P@300G41004`/<00/7200@2P/0;24O01`?3P09
07anOQT0oooo1P1oOGd04P1oOgl0PWmo05Lm=@0f91`0=2@P03LY9@0i:B@0:Q`H02dP700`81P0<BdY
04@e:`1C?cH0KeM=07aZGP1oJV80OfiV07m^I080Og1X01h0Og5Z07eZG`1mJUh0N6II07eWF@1iGDh0
MU]=07UMCP1fFdd0MUe@07QGB`1bFD`0MEQ9071AAP1^D4@0KTm206Y@A01VBC`0GD4c04HZ900f7AP0
81HA01/A300I41005@`<00d8200C2`/0:B0M00`71`22Ogl807mmOAP0oooo1`20P7h03`20O7T0CcXc
03LV7P0c9R40=bXU03<V8@0W6aL0;B4L02lQ6@0g;bT0DST/06I<?`1gHeH0P6mQ081_I@02081cJ@80
P7Q`00P0P7M_085bIP21LF@0O6]L085YFP1lHE40O65B07aQD@80N5i?00@0N5Y;07=MCP1cF4T0Ke97
0P1_E4D03P1^E4D0K4ho06=6=P1><2L0>b0I02<G4P0M4Pd06Q4@01H=300>2@P05P`<02/Q700M4Pd0
QHF22020P7hI0?ooo`H0TX9h0180TWme08mhK`0e8A/0@bLM03TW8P0o:b@0=28L02`K5@0d8A/0>24G
05@k;`1^?bd0TVA?09AgH@2ELf<0TW=S099gI`2BN6T2099kKP0N099fJ02AM640TG1M095_FP2AHe00
S65<08mTDP2<HD`0REm>08UMBP23FdP0Pee:085DA01lE4@0OeA207mF@`1jE480MDdk06Y2<01@;B@0
>AhF02DG400O4P`07Q8@01T=300?2@P06`d<044V7P28Ng80UHEk202BPWPT0?ooo`008P3oool807an
OP0@06]>A`0a8aX0=BPR03DY9@0_8ah0:aXE02lN5`0a9B40;bPS03<V800b:RH0GDLo07IYF01lKE`0
O6UM07aYG080O6UH00/0O6eP085aJ01mKEh0N5aA07AHB`1dED/0M5E<07AIDP1dG4l0M5A707EEB002
06mDA`0@071DA`1[DdD0Id/n05m4>01C>Rd0>BDQ034Q6@0T5Q407Q@@028E4@0J4A005@`<01H<300Y
6A@0JG9b0863PPT0O7in6@3oool807mmO@0@06e=A@0a8QX0>2LR03DX900a8ah0;AXF02lO5`0a9200
<bPS03d[8`10=2`0IDa407UXFP1oK5l0OfYP07m/H@80OfaO00/0OfiT089^I@1mJU`0Nf1C07UND01i
FDh0MUM<07IID01fFdd0MUI907QGB`02079EB00;07=CAP1^DTD0K4`o06Q8>`1M@380AR/U03`U6`0X
5a8081DA024E4@0J4A000P0F30`00`0R5Q<08blb051:B@0907mmOAP0oooo2020P7h03`1PBD80<B8I
03TY8`0e:B@0<R@O02hL5`0_8AT0<BDP03P/8`17<2H0Ed4d079HC01kJed0P6mT081_I@03081cI`0;
081cJ020Kf@0O6YK07aVE`1lIeH0O61A07QMC01hGTl0N5i<07QKC01hGDh00P1cF4T0401cEDL0KeA5
06m?@@1/CSl0HdHf04ha:013:Ad0:QPC024F4@0P5A006A4@01H<300E30`07aDB0000000a81/90820
OQT0oooo202BPWP0400o:B80>B4G040[900n:R<0=R<L034K5@0i8aT0>BHO04`e:01H<B@0QeI009Md
G`2BL5l0TW1Q099cIP2BMV<2099fIP0;099cIP2?KUX0RVEB08eXE02<I4l0S65<08UOC029HDX0REm:
08UKA`23Gd`00P23FDH0401oEd@0Oe9007e??@1bCc`0JT@a050^9@15:1/0:QHA02<F400U5@l06a0?
01P<2`0G30/0:ALB04db;01K>S4909:2N2@0oooo000R0?ooo`P0O7in00l0NFYR03d^:P0_9200=bPT
03PT6P0a91h09adI02dR7`0W7AX0:BHT02TZ9@0o;bH0HU1307=UF01fJEP00P1lKF007@1hJE`0LfEE
07IYG01mJ5X0M5Q;07ALB`1_EdL0JUE506YEB01^EDP0KeM:06mAA01_CdL0Je1706]D@`1WCch0Hd/n
05m6>015;B@0=R<I024D400H40`05a0@01hD400J4A004@P801<;2`0O5Q<01P0000X0O7in6@3oool8
07mmO@0_07]UGP0k:RH0<B@O03PX900g91/0<28M02TL600`8ah0;20L038Y9@0e;BH0D3/a06mKC`1k
J5/0O6YK07m/H@1oK5l0OFYM07]XF@1lJV00P6UK07UMC`1iGDh0MEI8079EB01bED/0LeM;07EHB`1e
DDD0LU98071AAP1`Dd@0K4m006Y<?`1VAST0Cc4V03lV6`0V5Q80718<01T@400O51006a4@0188200D
2`/07aDC00000022Ogl02@1oOGdH0?ooo`P0P81n0140KEiG03LW8P0c9Al0>BXU03DT6`0^8Qd0:Q`H
03<U7`0`8ah0>bdW04Pc:@1WC3h0O6]L085_G`20Kf00P6mT081_H002085_G`0L081_I021KEd0O6=C
07aQD@1hF4T0N5Y;07QJCP1hGDh0N5]<07QEA`1cEdT0LeE707=EA@1_DT<0KTm106Q9>P1D=BP0@bTM
02XH4`0O4`d06a4@020E400K4A004PP801D<300R5Q<07A8=08F5PPT0P81n6@3oool809:2N00H04df
;`0f8Q/0?2LO04@/9@0h8QP0<b4K034M5P0m:200>RHN04T_9P1a@Bh0TVQ?09YlJ02DLEd0UG=Q099`
G`2BL5`0TFmJ09AaG`2ELf40SFIB08aRCP2<HD`0QeM60P2:GD`04`2<Gd`0QeU608MIAP23ETH0PEU4
085G@P1mCcl0NTlm06]7=@1G<2<0@RLK02`G4@0Q4``07a8@02PF400M4A0050P801P<300`6A@00P2E
QG/909:2N2@0oooo000R0?ooo`P0O7in02h0Kf1C044b:`0h:bL0;bDQ034W900W6QX09a`I02TN6P0e
:BD0<B4I02@L5`0W9B<0A3H^06A:@01]EDX0LeeA07=QE@1hJE`0N6EH07=MD@1dI5L0Ke]=06Y=A01_
E4L0Kda006m=@P1ZDD@0KeA706]?@`1VCd00IdPl05m5?01GAcX0BcP/04/b9P0h9AX08A@@01`D400I
4@`050`;014;2`0;1`L02`P802DH500a7A@05`T42P1lOWhI0?ooo`P0Ogem02h0MF1D04<a:`0g:BD0
<BDQ03DW8`0Y6QT0:Q`I02XO6`0e:2@0<B4I02hQ6`0l<BX0F4@i071HC01eGU80NfAG07]VF@1mJUd0
NfII07QREP1lIeT0N5]>079AAP1eETP0LTm2079AA@1_DdH0MEE8071@A01^D480KdXo06Q;?`1TBc`0
FSd`05Pi:`11:1d0:1HB020F4@0K4@`05@`;01@;300=20P030P8024F4`0Z6Q<02@@22P1oOGdH0?oo
o`P0P81n0100KEiB040`:`0e:B@0<bHQ03LW8P0[6aT0;1hI02dQ700e:B@0<B8I03TW7`1F?c80KeE5
07aXF01lJU/0PFiN0P21Kel207aZF`05085]G@1lGTl0N5Q907QKB@1cE4D00P1cF4T0301hF4T0LeA5
07=DA@1cCd<0KU9306a@?`1VA3@0HD4a04D/7`0]6A<08aLB01/A30805P`<00D03PT800d8200P5A80
9ATC01dB3@0:0820OQT0oooo202BPWP0;P1C?340?RXT03`Y8P0l9b00?BLO02dJ5`0b7aP0=R<L03hZ
8`0i8QP0CRdP07mE?@2EJU80UG9L09AeG`2DLUd0U7AO095_FP2=JeH0TG1K08mXE029FDH0RUe708MK
AP23ET<0Pee908MKA`27FDH0PEA208AD@`1oDT00OEI107M?>`1aA340JD8_048W6`0^61409AL@01dA
2`0H3@`06Pd<0109200?20P0;1LC034K4`2<OgP:09:2N2@0oooo000R0?ooo`P0O7in02H0Y9jZ05To
>`0h:BD0=2LR03T^:@0m:1`0;AXD03<V8P0]8Ad0<bTW02LN6P0N81h08B8N02TU8@1<>340HDXo061:
A01UDDd0IEE<06UHC@1[E4L0Ed<f04Th;P1D?2h0HTTk06I<@01VA3P0ITHk06]?>P1WBcT0HdLj05m0
=01J@3@0BC4X03@N600/6A@091DA01T@308050`<00H040P800`8200D30`06A8?069]L@1fM7@:07an
OQT0oooo201oOGd0;P2HS9<0D3Lb03PY9@0e9b80>2/W03TU6`0[6AD0<BDQ02hQ700e:BH0:ahI02`U
8@0i;RH0BcP^0659?`1`EDP0KeI=079KD`1bGE80LeeA07IJC01XC3d0Gd8f06A5=P1[CD00KTe106i9
?01^Bd00L50m06a<?@1ZBC`0IT@g0654=`1B=BX0@B@J03DL5P0V5Q406a4<01H<300E30`04@P800d8
200D2`/06A8?03Dk?@14?C/:07mmOAP0oooo2020P7h0;P20NgX0@S0Y03LZ9@0e9b80=b/V03<S6P0Y
6AD0<BHQ02hR7@0g:RD0;QhI03d^9@1B>Rh0K4/k07QMCP1lHU40O6EG07aXFP1lJ5P0O6IG07aRD@1d
ED@0LDhn07=@?P1cE4D0Le5307=@@@1cE4D0LeA106m?@@1^CSl0JTTj06A9>P1F>B`0BBTM03TO600W
5a806a4<01H=300F30`04@P800d8200C30/06a<?024I500W5Pd:0820OQT0oooo202BPWP0;P1TCD<0
=R4I03h[900j9b00@BdV03@O5P0]6A@0?2XS03DR6`11:b<0<ahF05Tl;01Z@c80TEU109]bFP2=IU00
TW1M08m^F02?Je@0TV]G08MOB`1lDCd0QU<o08YF?`27F4L0Q5A208AA?P24FTL0PE@l07e?@@1jCC/0
MDXh06]:>01J=2H0D2TK03PN5P0Y5Q007A4<01T=300H3@/050P800h8200G30/09aD@05hl<@1K?C4:
09:2N2@0oooo000R0?ooo`P0O7in02d0V::J079RD`0c9Al0;b@P02dR7`0Y8al09A/J02PL5P0d9B00
=b`X03l`:`0]8R00;bPV02`Z9P0[8a`0<RXW02TX900]:1l0?S0X048f;010<b`0@c8X03`/8@0h;b<0
@RlS04df:01IA380FSh`04/d;01:<BH0DSL/04/h<00o:R@0>B4I02dI500R5100610<01@<300@20P0
2`L700/8200<20P06Q@@02LI500A3Ph02`1lOWhI0?ooo`P0Ogem02L0SXn;06eGC00e91l0<RDQ030T
800^91l0:1XI02/M5P0e9R40=BXV03`/:00]8Ql0=R/W03P^9`12;R@0CcXd04Pg<01>>Rh0F48h05Y5
>@1J@CL0F3/^04`c9P1<=RP0ESLZ05m0<@1TB3L0IT4d05dl<@1M>b`0Gchb05Pl<`1><2L0ABHL03DK
5P0W5Q406a4<01H<300A20P00`0<20P0100I4`l08aLC0004101lN7P:07mmOAP0oooo2@20P7h09P1L
Bd<0=2@O03DW8P0c9R40<BDP02/K6@0_7aP0=BLR03@Z9@0g:RD0;b<O03h`:@16<bT0FS//06M:@01R
B3/0K4dl071EA`1`EDD0KDm106M5=01I>R/0Gd0^06U2<@1^BcT0Kdhl06i7>01[ASH0K4Hb06U7=`1Q
@SH0FCL[04`/7`0i7QL0:QLB01dB3@0G3@`04PP80`0=20P0100I4`l08QHC01<=2@1kMgD:0820OQT0
oooo202BPWP09`22JfH0@RXS03DQ700m:280?BPQ03DT700^6AH0?B@I03XW8@11;BH0>BHP03XW7`1;
=2X0H3TZ07M7<P1gDT@0M58o08IE?`27HD`0QEi807M>?P1aAC00IcdZ07M7;`20B3D0PE<k08E?>`1j
BST0NDPb07i:=01gBSL0JD8d064h:01>:A`0?1dF02/G400O4P`06@d<01@8200200l8200500h81`0P
50l0;1LC08UhK`2?Ng802P2BPWPT0?ooo`008P3oool907anOP0V08j6T@18=S80=BTU03@[9`0f:2@0
81LB028M6P0g;2P0>BhY040d;`16>3<0ACT_03lh;`0e<R/0<BHQ034O6@0Y7Q`0:Q`I03<T800d9R80
;2@T03HV8@0f8aX0<2<L03DY8`0h;B@0?2`Q04<b9P0l;200=RXS03`V7`0g91`0:AXE02LM6@0J4Pd0
610<01D<300A20P200`82004024D400I4100Ad9004Tl>P/0O7in6@3oool907mmO@0/08YlP`14<2/0
=2LS03@Y9@0e9b808ALB02HM6`0f:RD0>2/W03lb;@10<bh0?S<[03he;@0n<RX0?RXS03`V7P0f9B40
?BHO04H`9`13;BL0>bXW048Z8P109a`0@2TP04P`9`1<=BP0DC@V058g:P19;b80B30W04X/8P10:1l0
<A/F02dM600M4Pd06Q4<01H<300A20P03@P800`8200M4a00610@034b<@0U7Qd;07mmOAP0oooo2@20
P7h0;01iLG80>b`U03<W8`0c:B@0<bHQ024G4P0[7a`0=bXS03L[9P0m<B`0>blZ03X_:@0o<b`0AC<Y
04L_9`15;B<0@RdV04l`9@1F?2l0CSD/04L`:@1<;b@0BBdO04l`901J>B/0GCd/068l:`1M?Bh0E3<U
05Hg:`1D<RH0AbdR03HN5`0a7QT07Q8=01/A300F30`04@P800d8200<20P06a<?01H?3`0Y:BH07A8=
2`20P7hI0?ooo`T0TX9h01P0FdHm038P5`0l:B80>BTR03PU7P0Q5A00>B<L04<]9@11;BH0AC4Y044]
9P15<BL0C3@Y054d9`1@<2L0CRlR058`9P1S>2L0Id<b05<d:P1C<RL0FS0Q05Pa7P1O<bD20752;@0<
06dn:P1[?bd0H3@S06Dl;@1L<RD0CB`P03PL5@0f7QL07a4;01hA300H30/04`P70P0>20L0100R4`l0
6Q0?04lg;P1^GUH;09:2N2@0oooo000R0?ooo`T0O7in02D0Xj>S06=8@P0d9B40<B@P034U8@0m:bH0
>2/W03L/:00m<Rd0=BTU034V8P0a8Al0?2<M03`R6P0a91l09AdJ02PR7`0Q61@08A`K02dT800Y81`0
7aLD01dH5`0M5Q<06Q8@01lH500T71H08Q/E02<F4`0P4Q007aDB024F4`0L51005@l;01@<300C2``0
50`<008030P800@08A@I024D4P0f9b40BEEG301lOWhI0?ooo`T0Ogem01h0UY2@05a0?00d9B40=2DQ
038V8P0i:2@0<2HR03DZ9P0m<B`0>2XV03LY9@0h9B80@2PQ03lW7P0f9b40;1hJ030S7`0Z6AH0;b4N
03HW8P0_8Qd0:ATE02XL600Z6A@0:ALC034P600d8QT0<B0H034J5@0^61<202`I5@03028F4@0I40`0
5`d<00805@`<00L03@P800`8200M4aH07A<@030S7P0H9RT0HeaJ00/0Ogem603oool90820OP0I0860
OP1<>3@0<bHQ03DW8P0c9b80<bHQ02XS7`0d:RD0?C4/03T/9`0k;BP0?RXU04@_9@10;240>BXT034P
6`0g9R00<A`G03/W8@0m:R@0=2@O034M5`0d81X0=1dF03PM5`02044X700803lW6`0m7aP0>AhG03HO
600d7AL09APB01dB3@0I3Pd201H<30803@P800D06a<E01/C3`0[8A`02@T905A5?`0;0820OQT0oooo
2@2BPWP06P1cGET0=R4K03TW800l:240>RLQ03@S7@0e91h0@BdV04Lb:P10;2D0ABlW04X/901B<RD0
AB`P03hZ8`0g81T0@RTQ03TL5@19;B@0@bXR03/U7P0j7AH0?B<J03dN5P168AP0CRdM0P1;:Q`02@14
81L0@b4H03dP600k7QH09aLA024C300K3@`06@d;01P=2`0200h81`05028C5@0R4`h0<R8M0657@@1e
Edd02`2BPWPT0?ooo`008P3oool907anOP0T08N=Q`2MV9P0B3Ha034U8@0e:BD0=2LR03/`;00_8ah0
;bHS02lS7P0`9R80?c@[03D]:00_9b@0<BDQ034T7`0g:2@0;1dL02<M6P0U61@09aLC024D400J4`l0
71@@02<H500U5a@07Q<@01/B3`0L51008aPD024D400N51006A0<01P@300E30`050`<0P0<20P0100D
30`08aXF02`K5P1`Kfl=07anOQT0oooo2@1oOGd09025Q840Sh63044^:@0b9B40=BPT03@V8P0i;RX0
<B<N03DY9P0c91l0=2LS03da:@0h:RH0=RLR03DU800a8ah0<bHR02`L6`0W7AX0:QTE02/I5@0T5Q40
7Q@@024E4@0W61@0:ALD02<E4@0Q51008QDA02PH500T5A408A@@01`A300I4@`05P`<01D<308030P8
00D050/;01lH5@0Z6AD0=3De04M7A`0<07mmOAP0oooo2P20P7h04P1dJf`0=bLR03<V8@0e:B@0<bHQ
03P^:@0b91l0>bhY03HW8@0g:RD0?2lX03TY900k9b40=bHP030S7P0b9R40:a`J02XO6`80;Q`G00D0
9QLB024F4@0T5Q80:QTD02`I500302LG4P0702`I500V5Q4091HA01dB3@0J4@`05P`<01D<300200d8
200501<<2`0O61D09aPE01<=2@0W81/03020P7hI0?ooo`T0TX9h0280S7Qb05<j=@0`7AL0>RLP03hZ
8`0i9Ql0AC4Y03HS701:=2`0>BDN048]9P1:<2H0@2LQ044W7P0m9al0=24K03lY8P0[6AH0<b<L03DL
5P0c7AH0:ALA02DG4@0[5a40<aXD03<K500/6140;QPA02dG4@0d6Q@0:AH@02XF400N4P`07A4<0P0H
30/200h8200501L<2`0/6aL0;1LC054j<@1H?C@0302BPWPT0?ooo`008P3oool:07anOP0G09RCU`1Q
?SP0>RTU03DY9@0d9b808adI03L^:@0m<Rd0>S0[02/Q7@0/7aT0:a`G02TN6P0[81/08ATM01hL6P0V
6aT09aLD024D6@0J51406a@@01P@300J51000P0H51003P0G40`04P/;01D?2`0K4`l0610<018;2`0G
40`0610@01D<300<20P050`<01lE4@0/7aX0:ATD3`1lOWhI0?ooo`X0Ogem00`0THR:05`j=@0h:2@0
=BPT03DW8P0Y81/0>bhZ03T^:P0j;BT0;B4L038S700a7aT202hQ700802DJ7@0U7Q/0:a/J02PG500S
5QT07Q@A01hE4@0J4@`201/D400A01dD400K4@`05@`<01P@300N4a006a4<01D<300I40`06A0@01H<
300<20P05@`<01/C400T6aL09ALC0452@P11?cl03@1oOGdH0?ooo`X0P81n01<0PGil04he<00e:B@0
=BTT03DW8P0^8ah0?S0[03H/9`0g;2L0;R8M03TW7`0d8a`0<R@O030S7P0W71h0;28M02dM6`0Y6AD0
91LI00808AHA01@06a4<01dE400N5A008AHA01dB3@0G3@`06a4<028E400M4Pd05`d<01/A300I4A00
5P`<00d8200E30`06A<?01lH5@0R5Q<07AHB01dB3@d0P81n6@3oool:09:2N00Y07EOF00i8Q/0>bXS
03hZ8`0j9b00=RHN04L`:@12;RL0>2LQ03HR6`1::al0=R8K03XV7P0h91d0:Q/L03PV7@0_6aT0<1/E
02PG600U5Q0091H@01hA300S5Q0091H@02HF400P4P`06`d<020B300Z5Q407a8<01/=300O4P`07A4?
01P<2`0>20P060`;01dC3P0V61@0:aLC054g;P1A<b/03@2BPWPT0?ooo`008P3oool:07anOP0O08fG
T@20Lf`0?BdX03<X900d9b80>R/W02lX900^9R80;b4M02TM6@0Q6QP08A@@02LM6@0U6AT09QTH01lC
400O51L05Q0A018;2`0F3a005a0@01@<300F3a004`/<01H?400D30`0610@01`D4@0G410050`<00`8
200300X71`0601P@400I4@`04`/;01T>2P1]KF`0MWAd3P1lOWhI0?ooo`X0Ogem02P0R8V707YUH@0k
:B@0=BPT03DW8P0h:BD0;bLS03@X900c91l0;1hJ02LL600V5Q40:AhJ02LI6@0X6AP08A@A028E600I
4A405P`<01T@4@0I41005P`<01P@400E30`0610@01H<300I41006a<@01P@400F30`03@P800`7200<
20L030P801P@400G40`050/;01`?2`0l?Sd0?SXk3P1oOGdH0?ooo`/0P81n00`0IeMC03LV8@0g:RD0
=BLR03DY900_9b<0>B`W03HW8@0^81/0;1hI02XH4P0]8A`202TK6@0?028F4P0T5aT0718B01T=3@0K
4A806Q4@01H=300I4A005Pd<01XA400F3@`06A4@01/C400I4A005`d<00@03@P800H0610@01H?2`0E
30`0814<024M6@0M4Pd>0820OQT0oooo2P2BPWP0:028LV`0BRlY03HR7010;2D0>RLP03/Y8P0i:R<0
ABhV03TV7P0b81T0=R0I02`G4@0g91d0;A/H02`K6@0X5a40:ALI020B400L3@`07a8A01hB400I3@/0
7Q8@01T=300N4Q006@d;01dA3`0P50l07A4?01T=2`0?20P03`T80109200?2@P0710?01X@2`0H30`0
:Q<<05Po=`1D>S4>09:2N2@0oooo000R0?ooo`/0O7in01`0_l[;08McK00g:280;b@P02lX900a:BD0
=bhY03PZ:P0]6aL0:A`H01lF4P0K4Ph06a@?01hD3`0D30`04@/:01L@400I4A4050`<01L@400E30`0
5a0@01D<300W5a@03PT801D?3`0K51006A4@0P0<20P0200@20P06A0@01`B4P0H4100:ATE03dU6P1R
A3<0BCLZ3`1lOWhI0?ooo`/0Ogem02L0Y:>T06eID`0e9B00<RDQ034W900d:BD0=b`X03LX9`0]6QH0
:Q`H020F4@0N4`l07aDA024D400G30`05@`;01T@4@0I4A405@`<01P@400F30`060l@01H<300T5Q<0
3PP801H?3`0K4a006Q4@00d8200<20P040P801P@400I41005a0@02HG500a81P0?S4Y01lF401lN7P0
3P1oOGdH0?ooo``0P81n01/0CD0j030S7P0e9b80<bTT03DZ9@0g;BP0=BLU02`K5P0Z7AT08AHB028E
400R5a808aHB01P=3@0G3@`06a4B01TA400E30`06A4@01H<300H41005P`<028F4`0=20P0610@01`D
400J4A000P0=20P02@0@20P05Pl?01H?3`0F3`l091LD02LM5P0T92004`T407]gM@0>0820OQT0oooo
2`2BPWP0101[DDL0=1hH030O6@0m:28203`[900F048^9`0h9B40;aTC030N600R5A00:QLA02DG4P0Y
5Q406Pd<01/=300O4Q40710?01P<2`0M4A0060`;01dA400H30/0;1PC00d81`0N4A008AD@01dA4080
3PP800T04`P701X@3`0I3`h06a0?02`H4`0/71@0>2DO06QKFP2?Ng803P2BPWPT0?ooo`008P3oool<
07anOP0@0;o:b`2:KVL0?c8/02dQ7@0g:RH0>BhY03ha:`0`:280;B<N02LG6`0H41807a@@01P@400M
5A407aHA01TA408050`<01804`/;01@<300C2`/071@@01D@400c;CH0=c<f02LI7P0F30d06Q4A020F
4P0P5a806A4@02dQ7@0b8A/0:AXE03lZ901[Kg@@07anOQT0oooo301oOGd0402TXj@0KeE?03T/9`0_
8Qd0=RXW03P/:00n;bX0<2DP02dP700V5QX06A4A024D400I4A007QDA01dD400I410201D<300:01@;
2`0E30`050/;01`D400F4100<2L]02XW:@0S5QX05``<01XA4@8071@@00L0610@02PN6`0[7AT09QPD
03PW8@0n?Cd0H5A>00l0Ogem603oool=0820OP0304dn>00a9b<0<2<N0080=bdX00X0>bhY02hS7`0]
7a/091HI01XA400R5A006Q4@01hE400K4a00610@0P0F30`02P0E30`05P`<01D<300L5100610@02dT
9@0P7Qd07a@G01H=300I4A0201TC3`0701L?3`0U7AX091XG02@G500e9R009a/B04lg:00?0820OQT0
oooo302BPWP0401[DDL0<Q`F034S7@0f8a`0@c0Y044^9`11;BL0;QlI03@P6@0U5AH07A4?02PF400M
4A008AD?01hC3`0K40l501P=3007024E400N4A00<2@U02HL5`0Q4Q<060d;01/@3`0201`B3P0701/@
3`0_7aT09QPE02`G4`19;240HT@d079>?@0?09:2N2@0oooo000R0?ooo`d0O7in00h0a]KG08Y/I01<
>C<0;B4M02XU8@0h<2`0ASD`03PU6`0`81T08ALB01L@400D30`05Pl;01L@408050`<01<0610@01D<
300H41005@`<018;2`0[:2P0:AdR03//;01A@3H0B3<a04Tg<@0k:B<08ALB02/N6@0W6aP0=BTU04/`
9P1fMGD0O7Ui0100O7in6@3oool=07mmO@0S0:JXZ@1_Ddd0@S8]02hQ700a9b<0>S0[048a;00d8aX0
;alI020F4@0H41005P`<01P@300I41005P`<01D<300H41005@`<01P@400E30`050/;02PT8`0V6b00
=b`]04<g<@0j:BT0=bXW030R7P0P5Q40:1`G02DJ5`0d9b<0?RXR03hm?@1FBTL0401oOGdH0?ooo`d0
P81n01<0P81m04dk=P0g;BP0;R8M03L/9`0m<B`0>bhY02lR6@0/7QT07QDB01TA400G3@`06A4<01XA
400F3@`05P`<01P@400E30`0610@00805@`<00h09b<Q02@J7`0f;bl0=Rl/02/Q8@0W8Al09AdJ01dE
400U6aL091XG03<W8`0d9Ql07AHA040Y7a00P81n6@3oool=09:2N00S06]=@`0b71H0=RLP03DR6`11
;bL0BS@/03`Z900d81H0;A`H01lD400M4A006@d<01hB300N4Q006@d<01P=300L40l05``;01`@3`0G
30/06@d<034W8`0/6b40A3D^03LX9@0X6QX0;B0K02LJ5@0N4`h0;1/F02dL5`0l:B80?R<K05@h;`1X
AcX0402BPWPT0?ooo`008P3oool=07anOP0@07IiN@2ocm00NEU:04hj<`0l;BP0>2hZ040d;`16>SH0
<R<M02hO6P0j:R@0=RTR02LH4`0O5A006Q8A01TA4@8050`<01006a@G01XB4P0M5A4050d<024M5`0V
7a`05@h>01@@3@0C3``050h>01lD400U6QL0<B4I04/b901nMWD0JfY_4@1lOWhI0?ooo`d0Ogem0100
O7Yj0:NXZ@1UAc`0AcD_03PY9@0g;BX0@3<^048e<@0a81/0;AhI034T800]8Qh08QDA01hD400J4A40
6A0@0P0E30`04@0K4aH06Q4A01`D400F3Ph09b0K02XP7`0L4Q807QDA01/C400K4Q408aDA02DJ5P0`
81P0?2dS05=>C01:?cl0OgYj0100Ogem603oool>0820OP0R08F5PP1;=bh0?C4/03<W8`0h;bX0@3<]
03da;00^7QT0:QdI02TQ700T7AX07Q<@01`D400I4A00610@01D<300F30`06a<F01TA400K4a00610@
02`T800_8b808QHE02HJ5@0S61<08ADD02HG4P0U6aL0;b4I03D[8`0e<B/0>b@K081lNA00P81n6@3o
ool=09:2N00>09F5N`1^DDL0=adF03d]9`0h9R00Ac@/04Lb:P12;BD0;A/D02dL5P0^81/091XF024B
3P0O50l201/@3`0C01P<2`0H3@`08ADF01/@3P0O4`l07a<B03HW8@0n:2@091HD02`L5@0Z6a@091DC
02XG4@0_7QL0>24G04`b9`1B>cH0Kdhn099oM@0@09:2N2@0oooo000R0?ooo`l0O7in01l0aMWO07IU
E`0e9b00;2<O040f<P1=@cl0DD8l038S7@0Q5aL09aLD03HW8P0b9b407A<B01@<300Q6Ad09A`Q02/S
7P0W7B00>2/Y02DI7@0e;2`0>2XY03l]:00m:bH0=bLQ03d[9@19>S00?BdV05<m<@22Ogh0SI:<0180
O7in6@3oool?07mmO@0P0:N[[P1RCD80=bHP034V8P11=C40B3di04Xj=00_7a/09APG02/I5@0b9B40
;B8M01`B4@0E30`081LK024H700V7Q/091XM02lU8`0R5aX0;2HV03@W9P0j:B@0<B@Q02lR7@0b9B00
=bhW03@V8@10<b/0BTM406ILD`1eL7<A07mmOAP0oooo4020P7h07`19=bh0=RLQ03LZ9@13=c80@cTd
040c;@0Z7AT0:1XI02hL5`0_9B009ahJ01XA400F30`07aLJ01hF600R71P081PL02PQ7`0M5AL0:B@R
02lU8`0c9R409alL02LN6P0Y8A`0:B@Q02/Q700d;2D09alE04Xb901aJF`04@20P7hI0?ooo`l0TX9h
0200J4Lj03LN5P0e8Q`0ABlW058l=01;>C00?BTS02/J500^6aT0<adF03DU7P0Y71H06a0>01P=300U
61T08ADF02XM600R5QT0=2<L01`B4`0o;BD0=2<O038R700/7QT0:Q`F02dO6P0c91d0;ahI04``901D
>2d0I3da08QbK140TX9h903oool00280oooo401lOWh07@35cmD0b;k6069?BP0`9R80;b@Q03/h?01F
BdT0H4e505aCC00m;Rh0<B/]04]3C@1VF5D0AS<_03DZ<@0d9b/0BCe303X_;P0o;BD0<RPU03h]9`0n
9b80?RDM03d[9@15=2/0EcX]04h]801JIFX0O8>201<0O7in6@3oool@07mmO@0N0:NVZ@29O7d0CC`h
03@W8`0i:bL0@CXk04e0?@19>cH0ASdj03HW9P0a:BT0?cLk04Hm?00e9bH0;bD[02lS9P0m=3L0<bPX
03/Z900/9B<0?b`W03/V8P0k9Ad0>BTT03d_9`16=2/0B2/P03@j?@1PEU00OgYj4P1oOGdH0?oooa40
P81n01d0BD8h03H/9`0g:RD0@S<^04Dn?013=c80=B`X038[:@0_8R00<2TV03<];00Y9bD09AhM02TR
9`0[8R<0<bd/02dT8`0e9b80:b@S03h]:00g9R80=bHN03DY900g;2D0>c4Y03hZ800W81/0CcLX081l
N@0B0820OQT0oooo402BPWP01`1XCT40;a@702dL5@12;BH0CST`04do?016;bD00P0g9B405@0a7Q/0
=2TT03PY9P0/7QP09APH02dQ9@0d8ah0>Rd/03DS700d8ah0?R`W048[9@0n9R00?RLL03TY8`13;B@0
CSDX03TU701[CT40LTXj099oM@0B09:2N2@0oooo000R0?oooa40O7in01X0TYbF0=7IfP1lJW40ASPf
03D^;P10@TL0DD]=04U1?`1FCDD0GU5=05A6?@19>SH0ASL`04Hf;00h:RP09a`F02dR7`0i;RT0=BTU
03lY8@1=;bD0D3H]05`o=01;;B@0@cPk09jRZQD0O7in6@3ooolA07mmO@0K08^<R@2QVil0HTmC044c
<00h;bh0@3m404i4A019?S/0D4Do04a0?P14>cH0ASTh04He<00o<B/0=BLX02`O6P0d9b@0>B`X03DX
900n:R80ARdU04Pa:@1>=Rh0@b/S04@g=`1cIV@0CDM401@0Ogem603ooolB0820OP0J06aUI`13=cD0
>blZ03Ta<014@D80BSll04Tm>019@3X0>c<b03Pd<P13>CX0@SD_03P^:P0a9RP0<2<O03T/:P0i;BP0
=BTT03l/9010;BD0@2hV044a:@0l:R80B3Xd04lg:00a81HD0820OQT0oooo4@2BPWP06`25KVT0E3@^
02lK5@10;B@0@3De05a7@01B?3D0DCdc04Tg<@10<2h0A3<`04dk=`11;RP0?bdZ03DT900j9b40@B`W
048^9`0n:R<0C2`Q04T]9017;B@0BS4X04@Y7`1RAC/0GSLQ05hm<@0D09:2N2@0oooo000R0?ooo`03
07aeM@1lNGT0O7in0100O7in01L0aLo70=7IfP3=`l80HeQU05=8CP1eIg@0N6I^069;A@1A@C`0CD4l
069>C@1VCT/0IE1806eFC`1PBcl0E4Ho06EABP1CBCl0AT8h03T]:01@CED0[[_60;C5`@0F07anOQT0
oooo00<0OgUi07mjNP1oOGd0401oOGd0602WYZ80QH:7089gM01AAe00DTM;061FG01QDeH0ETE00511
?@1>?c/0ETE40591?P1E@cd0DT8o04/k<`16>SD0DT8n04Pl=@16>C40?b`W04Q1@@1hLWD0LVeY061I
FQD0Ogem603ooolD0820OP0G040g>P0k=Rd0?CTm05=:B01?BTP0C4E104]2?01=@Sl0CD0j04/o?011
>3<0A3Td03/c<@0g;bT0>c8^044h<`0m<bd0AS<[048/9@1:?3<0BSL]03/T6`1?@3l05@20P7hI0?oo
o`0309:4NP2BQG/0TX9h0100TX9h01P0J4i:03LC3`0]50h0>R/Z06A>A01KBT<0CS/^058n=P1C@3T0
ESlf058k=@19=B`0@S0[044]:00i:240AS8/04Td;014;B@0DC4W04PZ8P1bDD@0DBHC04@C2@1bE4dE
09:2N2@0oooo000R0?ooo`0307b3PP1lOWh0O7in0180O7in01<0Qhf70<G:_@2^^kP0WJJJ09jS[@2Y
[k`0YYj/06YQM01:BUP0AT5304Xn>P13?3P0CD4o04Hj=P0i;RH0?c8Z07IeM03Fg]l0V:JP01P0O7in
6@3oool00`1oOGd0OgYj07mmO@0B07mmO@0D08F4P@2QViP0LWEj07EbKP22OXL0Og^207i`M01NDET0
C4E;04i0@@1@?c/0B3`i0550?@18>SD0@S<[04Pg;`1CDDh0R8B205aNFP1_J6/G07mmOAP0oooo0P20
O7TD0820OP0607MbM@10>d<0E4U806EOI01ICdh0ETU20P1>@d402`1C@Sl0Dd8l04e0>P1C@S`0BC/d
04Th;`1??C@0@3T`040g;@0a91l0J5]N01L0P81n6@3oool00`2BNg80TWme09:2N00B09:2N00:08ah
LP1RAdX0BbT[0690@@1TATD0GS//04`^8P1:=B/0G4@l05i1=@80Fd8i00P0FT4f05<l<`1G>Rh0Eclb
06]AA@0d3`<0CRHR089XHaL0TX9h903oool00280oooo6@1lOWh00`27SH80O8>209:LT@020;[0/`08
0;o:b`2o`lD0_lG70;o:b`35cm00b]WO0<[DfP1lPh8J07anOQT0oooo6@1oOGd03P25Q7l0NGMm08^9
Q02EShh0Ogem08:2R@1oNg/0OgYj07mmO@22Ogl0PX:407mjNP1CE500OgYj6@1oOGdH0?oooaX0P81n
00<0Mg9i081lN@1/IF`00P1:AD`02015?SP0AC/f04Dk=P15>cH0@3La03/^900k<RP0P7ai6@20P7hI
0?oooaT0TX9h00h0S7Qe08aeLP25JfT0HDA:04X]=0179RD0A28G04@S601481D0@A`B03XC1P0g4000
IDLj099oMAT0TX9h903oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool004h0oooo0T00001G0?ooo`900000EP3oool2@00005L0oooo0T00000f0?ooo`00D03oool0
0d000000oooo0?ooo`1F0?ooo`03@000003oool0oooo05D0oooo00=000000?ooo`3oool0EP3oool0
0d000000oooo0?ooo`0c0?ooo`00:P3oool5@0000080oooo00=000000?ooo`3oool00P3oool00d00
0000oooo0?ooo`0;0?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000003oool0oooo
02/0oooo0d0000020?ooo`=000000`3oool00d000000oooo0?ooo`0;0?ooo`=000000P3oool2@000
00<0oooo0d0000050?ooo`03@000003oool0oooo02X0oooo0d0000030?ooo`03@000003oool0oooo
0080oooo00=000000?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d00
0000oooo0?ooo`0[0?ooo`9000000P3oool5@0000080oooo00=000000?ooo`3oool02`3oool3@000
0080oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`0]0?ooo`00;03oool01d000000
oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000;0?ooo`06@000003oool0
oooo@000003ooom00000103oool014000000oooo0?oood00000c0?ooo`03@000003oool0oooo0080
oooo00=000000?ooo`3oool00P3oool00d000000oooo@000000;0?ooo`06@000003oool0oooo@000
003ooom00000103oool014000000oooo0?oood00000b0?ooo`03@000003oool0oooo00<0oooo00M0
00000?ooo`3oool0oooo@000003ooom0000000/0oooo00I000000?ooo`3ooom000000?oood000004
0?ooo`04@000003oool0oooo@00003D0oooo00E000000?ooo`3oool0oooo@00000030?ooo`03@000
003ooom0000000/0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0oooo
@00003D0oooo000/0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003o
oom0000000/0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A000000?ooo`3ooom0
0000=03oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo00<0oooo00=000000?ooo`3o
ool02@3oool01D000000oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood00000c
0?ooo`03@000003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000003ooom0000000/0oooo
00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A000000?ooo`3ooom00000=03oool00d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo00<0oooo00=000000?ooo`3oool02@3oool01D00
0000oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood00000e0?ooo`00;03oool0
0d000000oooo0?ooo`020?ooo`07@000003oool0oooo0?oood000000oooo@000000<0?ooo`=00000
00@0oooo@0000400001000000`3oool3@00003@0oooo00=000000?ooo`3oool00P3oool014000000
oooo0?ooo`3oool2@00000d0oooo0d000000103ooom00000@000040000030?ooo`=00000<`3oool0
0d000000oooo0?ooo`030?ooo`06@000003oool0oooo@000003ooom00000303oool3@00000040?oo
od0000100000@00000<0oooo0d00000e0?ooo`05@000003oool0oooo0?oood0000000`3oool2@000
00d0oooo0d000000103ooom00000@000040000030?ooo`=00000=@3oool002`0oooo00M000000?oo
o`3oool0oooo@000003ooom000000080oooo00=000000?oood0000003P3oool00d000000oooo0?oo
o`0k0?ooo`03@000003ooom000000080oooo00=000000?oood0000000P3oool00d000000oooo0?oo
o`0>0?ooo`03@000003oool0oooo03X0oooo00=000000?oood0000000P3oool00d000000oooo@000
00020?ooo`03@000003ooom0000000h0oooo00=000000?ooo`3oool0>`3oool00d000000oooo@000
00030?ooo`05@000003oool0oooo0?oood000000403oool00d000000oooo0?ooo`0m0?ooo`00:`3o
ool2@00000@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0<0?ooo`900000?P3o
ool00d000000oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`=000003@3oool2@00003d0oooo
00A000000?ooo`3oool0oooo0d0000030?ooo`03@000003oool0oooo00`0oooo0T00000n0?ooo`04
@000003oool0oooo0?ooo`9000000`3oool3@00000d0oooo0T00000o0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`008P3ooolG07]iN@06079@?021KF00NfUU07]aJ@1kIEd0Ng5Y0`1kKFD01`1kIEd0
NfUI079QE@1gGE80KU5607=IC@1YDDH0101_EDT01P1_CD80IU4n06]AA`1[DCh0Je5709:[^0@0NgUi
00<0Ng1a07]nOP1kNGT0201kNGTI0?oooaL0N7Yj00H0Ke4m07i^H@1hJVH0N79Z07QVGP1hLVX307Q^
IP0707QVGP1hJUT0Kf9F07ANDP1[DTL0L5U=06IBAP0406aEB@0606a>@P1SDCl0J55806QA?`1XDDP0
TJfj101hNWX00`1hLG80N7mo07QjNP0807QjNQP0oooo5`1gMgT01P1^D3h0Nf]P07MWI@1gKfT0Mf=N
07M_J@<0Mf]U00L0Mf=N07MWF@1^GeH0LeaB06Y@A`1_Ed`0IU1600@0Je=800H0Jda206=??P1WCdL0
Idln06M?A`2;Y;@407MgN@0307M_L@1gNgh0MgMi00P0MgMi6@3ooolG06EeOP05065RG@1UIF40IFEU
06EYJ@1UIFD0101UJFT0101UIFD0IFEQ065RG@1QGUP205iFD0D0FU9<00D0FTi705M>@`1GCTL0Edi3
05M>A`0506EeOP0306EaNP1UMGh0IGEn00P0IGEn903oool00280oooo00H0NgUi07]eM@1kOWh0NgUi
07]eM@1kOWh907]iN@0307]eM@1kOWh0NgUi00D0NgUi0140MU<o07]YH@1kJEd0Ng5^07]UG@1kLFT0
NfeU07]YG@1gJF00O6UP07aUF01cH5@0M5e?07AEB@1dF4/0Je5507AHB`0206mEB@80Ke5500D0IU52
06]AA@1[DCh0Jf5P09:GW00407]iN@0307]dM@1kNGT0NgUi00P0NgUi6@3oool01P1hNWX0N7Ad07Qm
O@1hNWX0N7Ad07QmO@T0N7Yj00<0N7Ad07QmO@1hNWX01@1hNWX04@1eET40NfaV07QZG@1hLV`0N6IN
07QbJP1hKVH0N6QJ075TF01dI5P0M61B06]ICP1YETX0JE1506aEB@1SCT80KeM;0080K5E90P1/D4@0
1@1SDD@0J55606QA?`1XJV`0TJ>[00@0N7Yj00<0N7Qh07QmO@1hNWX0201hNWXH0?ooo`0507MgN@1g
Kg40MgMi07MgN@1gKg402P1gMgT00`1gKg40MgMi07MgN@0507MgN@0807MGA01kJfT0MfMM07M_J@1g
Heh0MfmY07M[I@1gHeH206iLC`0606iHB`1VD4P0HDe40659@01VD4H0GTU00`1[DdP206]<@P0506=?
A@1WCdL0Idln06M^M@2;Y;@01@1gMgT00`1gNgh0MgMi07MgN@0707MgNAT0oooo00H0IGEn06E^M`1U
LW/0IGEn06E^M`1ULW/906EeOP0306E^M`1ULW/0IGEn00D0IGEn00D0J6QS06QXJP1UIF40IFUW06EU
I@0206EYJ@0:06ESG01NFU40FeYA05]FD01HD4`0DTa8055;AP1DCDP0DDY405Q@BP80FU9<0P1JC4H2
05M>B@0305M>@`1GJ6l0IH:A00@0IGEn0P1UN84906EeOR@0oooo000R0?ooo`0507]iN@1kM7D0NgEe
07]nOP1kM7D00P1kNGT0101kMGD0Ngin07]eM@1kOWh407]iN@0307]dM@1kNGT0NgUi00D0NgUi00<0
MeA0085]I01kJF400P1kKFD0201kJF40NfeU07MUE@1[HET0Pf1A07QHC`1_Fd`0Kea?0P1_EDX02P1Z
CT<0Je5506mDA`1_E4L0Ke5506mA@@1[DDL0Je5506]A@P1kSIH607]iN@0307]eM@1kOWh0NgUi00L0
NgUi6@3oool02`1hNWX0N7Qh07QfMP1hOGd0N7Qh07QmO@1hNWX0N7Ad07QmO@1hM7@0N7em00@0N7Yj
00<0N7Qh07QmO@1hNWX01@1hNWX01@1aDch0NfaQ07QZHP1hK6H0N6iV0080N6YR00T0LF9B05eNF01f
Fdh0L51:06IDAP1YFDd0K5Q<06aIC@1YDTH00`1XDDD01`1XD4@0J55006IAAP1XDDD0J55408FNZ`25
RH`01@1hNWX00`1hM7@0N7em07QjNP0707QjNQP0oooo0P1gMgT0201gLgD0MgMi07MgN@1gNgh0MgMi
07M_L@1gMgT0Mfma1P1gMgT00`1gNgh0MgMi07MgN@0407MgN@0A06i@?P1gIed0MfMQ07MWI@1gJfD0
MfMQ07MSGP1^G4l0EUQF06YCB`1ZAT@0HDU006IDB@1[Ed`0JeY?06]CB01WCdD00`1SC4801P1SCch0
Hdm506M?A@1WCdD0RjBh08^BV@D0MgMi00<0Mfma07MgN@1gMgT01`1gMgTI0?ooo`0406EeOP1UN840
IG5j06EbN`80IGR100D0IGEn06E^M`1ULW/0IFig06EbN`0406EeOP80IGR11P1UMGh04@1NGeX0HV=L
06EUI@1UHfH0IFUY06EUI@1UH600GUaH04aIFP1BDU00F4I805A7A01GDD`0FUQB05YJE01METl0Edi7
0080DTY400L0DTa6059>@P1DCTH0Edi705M>B@1bRIL0LXVD00D0IGEn00<0IFig06EbN`1UMGh01`1U
MGhT0?ooo`008P3oool207]iN@0307]`L@1kOWh0NgUi0080NgUi00<0NgAe07]iN@1kM7D03@1kNGT0
4@1fD3`0NfeU07]YH@1kJF40NfeU07]YH@1kJEd0MVEM06EPF@1]F4/0MTe>06=A@01]EDT0KEQ?06eH
C@1YC480IUA500<0Je5500D0Je5206mEB@1VCD80Je5509:[^00607]iN@0307]dM@1kNGT0NgUi00L0
NgUi6@3oool207QjNP0307QaLP1hOgl0N7Yj0080N7Yj00@0N7Qh07QmO@1hN7P0N7em301hNWX04@1e
DCd0NfiX07QZI01hJV80N6aT07QXH01hJU/0MFQP06mXHP1hHE80NeIH06QHA`1`EDT0L5E?071EC@1Y
B440He9400<0J55500D0J55406mGC01VD4@0J555096]^P0607QjNP0307QhN01hOGd0N7Yj00L0N7Yj
603oool207MgN@0307M_L@1gNgh0MgMi00<0MgMi00<0Mg]n07MgN@1gNgh0301gMgT00`1gD3h0Nf]Y
07MWI@0207MWH@0807MSGP1gIeT0MfMQ07][J@21IeT0P5]O06mJC01dDdP207A@C00306]2@01SC480
Idm500<0Idm500@0KeI>06M?A@1WCdD0RjBd1`1gMgT00`1gNgh0MgMi07MgN@0607MgNAT0oooo0P1U
MGh00`1ULGX0IGEn06EeOP0206EeOP@0IGR1301UMGh0101XHUd0J6EX06EUJ01UIFD206ESH`0;06EU
GP1XJ6P0MFi`075]IP1^I6P0IeeH06EBC01UCDh0IDe@05i4AP1GBTH00`1GCTL0101GCTT0GEA?05Y@
B@1GCTL706EeOP80IGR1201UMGhT0?ooo`008P3oool207]iN@0307]dM@1kNGT0NgUi0180NgUi00@0
Ne<o07]YH@1kJF40NfUU0P1kJF404`1kJEd0NfeU07]XH@1fH5D0MeQB079AB`1bEDL0LUE=06i>B@1a
ED/0Gd<l06Y@A@1ZGE40ITXl06mAA@1_E4L0IU5506mIC@2<XZl0401kNGTI0?ooo`80N7Yj00<0N7Qh
07QmO@1hNWX04P1hNWX0101hET40N6aQ07QZG@1hJV@207QZHP0C07QZH01hL6X0N6iV07EVG01dGeH0
KeM?07ALCP1dGE<0KU9;07AMD01TB440K4e506aOE`1VCT40Ke5506mCAP1SD4@0Kee@08jX]@0@07Qj
NQP0oooo0`1gMgT00`1gNgh0MgMi07MgN@0A07MgN@0307MGA01gJf00MfMI00@0MfMQ00d0Mfm]07M_
J@1gIf40Lf=I06iKDP1gGU@0Mf9G06mCC01gHU@0Jd]506m8A@1_GEX0Idm50080Kdm500<0Hda206mM
DP2;Y;@0401gMgTI0?ooo`80IGEn0P1UN84C06EeOP0406EXH`1UJ600IFEK06EUH`80IFEU01<0IFEX
06E/K`1UKfh0J6]]065ZH@1QHEd0J65M06QSF`1QEU80J6AK06=@C@1PADL0H5QK05YBC@1MCTL0GDa6
05M<AP1MFU@0J7^50100IGEn903oool00280oooo5`1kNGT0201kEd<0NfUM07]YH@1kJEd0NfUU07]Y
H@1kKFD0NfUQ0P1kKFD03`1fH5D0MU]B079EB`1gF580LUE:07=IC@1]BTL0JDe306mDBP1ZFE40JdXl
06mAA@1[DDD0O75]086=TP0707]iN@0307]eM@1kOWh0NgUi00H0NgUi6@3ooolG07QjNP0707QH@`1h
JUd0N6YT07QZG@1hJV@0N6YR07Q`J00207QZHP0@07Q^IP1eIU`0N6EJ075ND01dFeH0LEY>071KC@1Z
CDP0JEE806aEB01YFE80J4i106QAA@1VDDD0P7]j08FIXPL0N7Yj00<0N7Ad07QmO@1hNWX01P1hNWXH
0?oooaL0MgMi00@0MeM407MWG@1gIfD0MfMM0P1gIf403`1gKfT0MfMQ07MSGP1gJfD0MfMQ07][H01c
HeD0Le]H07=KD@1_FT`0JTe906]JB`1[DdD0JeMA06M?A@0206=?A@03085nP`26W:/0MgMi00H0MgMi
00<0Mfma07MgN@1gMgT01P1gMgTI0?oooaL0IGEn0P1UIF405`1UIFP0IFEQ06EUH`1UIFD0IFa/06EU
I@1UH600IFUY06Q[K@1[LFX0IFUO065LG@1UGUT0GUQ@05mDD@1NFe40FTi405eFE01GDTd0DTi705A>
A`1XLGT0Jh:A00L0IGEn00<0IFig06EbN`1UMGh01P1UMGhT0?ooo`008P3ooolF07]iN@0306mID@2<
NVP0NfUQ0080NfUM01D0NfUU07]]I@1kJF40NfeU07]XH@1kKFD0NfEM07]YG@1fGDh0MUUB079HCP1b
FDd0KTi906eEAP1YCD80JeM=06]AA@1_DDD0IU5508R=UP21Ph<01`1kNGT01`1kM7D0NgUi07]iN@1k
NGT0NgEe07]jNP1kOWh00P1kNGTI0?oooaH0N7Yj00P0I4Y1089ZEP1hJV@0N6YM07QZF`1hJVH0N71X
07QZHP80N6iV0100N71X07QVGP1hJV00MF1B07QNE01aFdh0LEa@06i@B`1]EDH0JDi206IEB@1VCT40
Ke5506IAA@27U9h0OXV;1`1hNWX01`1hN7P0N7em07QjNP1hNWX0N7Ad07QfMP1hOGd00P1hNWXH0?oo
oaH0MgMi00T0GC`c07MGA01gIfD0MfMM07MWF@1gIfD0MfmY07MWH@1gJfD00P1gKfT03`1gHeh0MfMQ
07MOEP1kGeD0Le]>07=KD@1_D4`0Ke=606]<@P1SCdD0HdTm06m?A@1WCdD0PI6P07^9T00807MgN@03
07MkOP1gMgT0MgMi0080Mfma0`1gMgTI0?oooaH0IGEn01@0DT=005]?B@1UIFP0IFEQ06EUGP1UIFD0
IFa/06EUI@1UJFT0IFm^06E/K01UIFD0IFEX06QTH@1[He/0IEaD06ELE`1QE580HU9<05i>A`80E4Y2
00@0GDi705Y>A`1QM7l0IGb81`1UMGh206EhP@80IGEn00<0IFig06E[M@1ULW/00P1UMGhT0?ooo`00
8P3ooolE07]iN@0404Hh<02]QgD0PFeP07]YI@80NfUM00D0NfUQ07]aJ@1kIEd0NfeP07]aKP0207]Y
H@0=07]YG@1kIET0MeE>07MLCP1gFE40KUE506m=A@1_EDT0JTe206IAA@1dFDd0JTi308NMZP0<07]i
N@80NgAe0`1kNGTI0?oooaD0N7Yj00/0;BHO08m/F@25MFD0N6YV07QZH01hJV80N6YT07QbJP1hIUh0
N6aM07Q`JP0207QXH00>07QZF`1hJ5X0LEI@075KCP1dF580JeI406U>@P1YEDT0JE1406IAA@1aGE00
JEA808^V/`1kOgl;07QjNP0307QhN01hNWX0N7em0080N7Yj603ooolE07MgN@0501lE401^D3h0QWMW
07MWI@1gIf400P1gIfD0101gKfT0Mf=N07MWF@1gJfD207MSGP80MfMI00`0KU=B06iGCP1cE540JUA3
06I<@01VDdP0Jdm506M?A@1_GE80JeI;08^T]01kP88<07MgN@80Mg]n0P1gMgTI0?oooaD0IGEn00/0
8AhL03ln>01[KVD0IFEU06EUJ01UIF/0IFEX06EYJ@1UIFD0IF=L06EVI00206ESH`0>06EUGP1UJ600
GUUK05iGE01QDe@0GUI:05M>A01GDT`0GE1905Y>A`1JFU@0GEUA06]oR01XNhD;06EeOP0306EhP@1U
NhD0IGR10080IGEn903oool00280oooo0P1kNGT00`1kMGD0Ngin07]iN@0?07]iN@0806]QI@0J3PT0
hKbS07]YF@1kKFX0NfEM07]]I@1kIEd207]]I@0A07]XG@1kJF40NfUM07]LG@1gJ5@0N6AE07aPF01g
G540LeUA06mA@`1cDDH0JEE906]=?P1[DDL0KeM:06mDA`2BZkP04@1kNGTI0?ooo`80N7Yj00<0N7Ad
07QmO@1hNWX03`1hNWX06`1MEU`030L40=V_V`1kK5d0N71/07QXH01hL6P0N6QP07Q/I01hKVH0N6iT
07QZI01hJ5X0N5MH075MC@1^F4/0M5U@07AMD01^G580IU93071BB01YEd/0IThm06IAAP1[EDP0J514
08j[^00A07QjNQP0oooo0P1gMgT00`1gKg40MgMi07MgN@0?07MgN@0705I9DP080@40]iN<07][H01g
Kfd0MfMQ07M_J@0207MWH@0B07M[I@1gKfT0MfMU07MSEP1gD580KU1506I9@@1^D4P0Le]>06YKD@1Q
D4<0Ke1806]FB`1SC3`0Hdm506M?A@1SBD00QZ2_4@1gMgTI0?ooo`80IGEn00<0IFig06EbN`1UMGh0
3`1UMGh06`1<CUd060h>05ABF@1XJ6H0IFa/06EXJ01UK6`0IFQX06ESH`1UJFT0IFma06EUJ01UHe`0
IE9E05i:BP1EAD80Fe1:065JDP1KG5@0E59<05iBC@1NE4d0E4i205A>AP1DBT@0DTQ2069bN`0A06Ee
OR@0oooo000R0?ooo`80NgUi00<0NgAe07]eM@1kOWh03P1kNGT0201oOGd09QLB075LE@21KF@0NfUQ
07]]I@1kJF40NfeU0P1kJF401`1kKFD0Ng5Y07]UG@1gIED0O5EE07MLCP1^EDT00P1hG5002P1cG4`0
JE5907AAA@1_E4L0JU5206YAA@1VDDD0KeE908R@UP21SI8@07]iNAT0oooo0P1hNWX00`1hN7P0N7If
07QmO@0>07QjNP0M07n1P@0C3@T0NVAB0;JHP`1hJV80N6aV07QXH01hK6@0N6QP07QZHP1hK6@0N71X
07QVGP1aI5@0M5=B075MC@1[ETX0Le]?071IC@1^FDP0IU1606m@A01YDDD0JE1206aAAP1VDDD0KeM;
08N;S`1kQ8L0401hNWXH0?ooo`<0MgMi00<0Mg=e07MgN@1gMgT03@1gMgT02@20Oh8030@2085WC`3E
]Y/0MfMQ07MWI@1gHeh0MfMQ07MSGP0207MWH@0A07M[I@1gHeh0KUmB06i@C`1^Fd/0JUA906mGC01Z
E4T0JUA306I=@`1[C480ITa206]<@P1_CdL0Idm506mFB`21OX<04@1gMgTI0?ooo`80IGEn00<0IGR1
06EaNP1ULW/03P1UMGh01P1[O8H05a8>06iZF02PVhH0IFEU06ESIP<0IF=S01@0IFEU06ESH`1UIVL0
IFEU05iOFP1KEe@0GUYB05iFD01KDdh0F55;05]AAP1JD4P0Eda605M:A01MC4L0H4i905Y>A`1ME4d0
HEeO069XKa00IGEn903oool00280oooo0P1kNGT00`1kMGD0NgUi07]iN@0>07]iN@0503<Q6@1kKFD0
MV1E07]YF@1kJFD00P1kJF40101kJEd0NfUU07]YH@1kKFD207]YH@030795?`1gEe00Ldi40080Le56
00/0LfYD06mDA@1_E4L0Kda106]D@`1dDDL0Ke5506IA@@1dCdH0MFQM09:[^00;07]iN@0307]eM@1k
OWh0NgUi0080NgUi6@3oool207QjNP0307QdM01hNWX0N7em00h0N7Yj00D06a8=07EUFP2]SH00NfaM
07QZIP0207QZHP0F07QZF`1hJV@0N6YR07Q`J01hJV80N6QP06lk>01dAT@0KShi06i0>`1`@Cd0L5i>
06U@@P1YD4D0K4Xo06IC@@1_DDH0K55506=A@01aCD80Jea@08RNYP/0N7Yj00<0N7Ad07QmO@1hNWX0
0P1hNWXH0?ooo`80MgMi00<0Mfma07MgN@1gNgh03P1gMgT01@0<1080LUY?0=2^XP1kJf00MfMU0080
MfMQ0100MfMI07MWH@1gIf40MfmY07MWH@1gHeh0KS4c07<d>01Z;Rl0JRha06la<`1_D4H0ITU006I9
@P1[AC`0Hdln0P1[CdD0101SCch0KdPn06=<@P1kRI0;07MgN@0307M_L@1gMgT0MgMi0080MgMi6@3o
ool206EeOP0306E^M`1UMGh0IGR100h0IGEn00@03`/9069MFP2RWYX0J6QV0`1UIFD0301UIEh0IFES
06EUI@1UK6`0IFEU06ESH`1Q>3l0HBhh05/Z<@1K:340GRXb05i2@P80EdQ400P0FTI005A<@01HCTH0
FTi705M>@P1JASl0Ccdf05]RIP/0IGEn00<0IFig06EbN`1UMGh00P1UMGhT0?ooo`008P3oool207]i
N@0307]dM@1kNGT0NgUi00d0NgUi01l0Jf5Q02/S7021KF40NfUQ07]YF@1kJFD0NfUQ07]UF@1kJE`0
NfUP07]]J@1kKFD0NeaI07]XH01b>CL0Ld0h06ld;P1iBDH0Kc`d07UAB01UD440KeI606mA@@1[C440
M5A706mAA@1ZDD80KdTn06YHB`1nM6/0S:Jd00X0NgUi00<0NgAe07]iN@1kNGT00P1kNGTI0?ooo`80
N7Yj00<0N7Qh07QmO@1hNWX03@1hNWX07`1MEUH0B3hg0;>DQP1hJ600N6YI07QZIP1hJV80N6AF07QV
F01hIU/0N6aV07Q/I01hEU@0N5eI06le=01^?SD0IRlX07A5@P1Y>c<0M4U30615>`1XD4<0J55006I=
@@1aDdP0K55506UAA01_BD00JE]=07MWG022TIP02P1hNWX00`1hN7P0N7em07QjNP0207QjNQP0oooo
0`1gMgT00`1gNgh0MgMi07MgN@0<07MgN@0705I9C01^Ee80d:jR07MSGP1gIeT0MfMU07MWH@0207MO
DP0@07MOEP1gIf40MfMQ07M=C`1gD580KS4c06Xj<P1Q:B80Kcll06Hh<01_?c`0GSTe06=8?P1SCch0
Hd]106m?A`80Jdm500<0KdQ106]JCP1_ET/0301gMgT0101gNgh0MgMi07MgN@1gMgTI0?ooo`80IGEn
0P1UN84>06EeOP0504a>E`2:Qh/0W9FB06ESH`1UIF400P1UIFD0601UGeP0IEaF06ELEP1UHf00IF=S
06E@EP1UBU<0HD1405/k=P1D:bH0FcTi05Lh=01K=3L0E3<g0591?P1BCT80E4Y305Y<A`1JCTL0GDi9
05e:A@1ME4d0E40g05]HF@X0IGEn0P1UN84306EeOR@0oooo000R0?oooa80NgUi020091PE0=ZaV@21
KF@0NfUQ07]YG@1kJFD0NfUM07MMDP1lH5@0PG9T07]YI@1kHED0MdE707Q>A01dDTd0J2hS07eIC`1i
@400IB@N07Dh<01_BCl0IU1406]KB01[BCH0KeA907AAA`1_DDD0Kde206mDA`1_F4/0S9bQ07^3R0h0
NgUi6@3ooolB07QjNP0P014=2`2dSWH0OVaM07QZG@1hJU/0N6YV07QZF`1aG4l0M5]@07]aH`1hK6P0
N5i@074k?@1^?SD0ITY205L/801aIEH0MeUC060V7`1[<RX0JD8h06I;@01XFDP0J4Te06]EA@1_DDH0
K55506a@A01/EDP0K5M;08^IW01hOh8>07QjNQP0oooo4P1gMgT00`0810@0PFMB07]WEP0207MWF@0D
07MWI@1gIeT0KUQ;06iCB`1gJf00Mf]Y07MHB`1^<C<0IRhW05do>01;:Ad0IV]K07A]H`1N:240HbXS
06Hh<01W@c`0Ie=706M8=01WDd4306]?A@0306]CA`1[DdP0QXfA00l0MgMi6@3ooolB06EeOP0P01<A
4@0b<bl0IF=G06EUF`1UIEh0IFEU06EUGP1NFe@0Fe9>069RGP1UJ6P0IEUB05hh>@1E:RP0Cchi044`
9P1?I5P0GW9W05@a:`1?9R40Ec0]05Xk>P1GBTL0EdXi05A>?P1HCTH0FTi705Y@B@1JCTL0FU1:06EX
J@1UKgD>06EeOR@0oooo000R0?ooo`@0NgUi00<0NgEe07]nOP1kNGT02P1kNGT08P1JC4d0<BTQ09N3
L`1kJF40Mf5A085fK@1kIEd0Nf5A06iIB@1dCdH0S7Qa07=9@@176Ph0]h=h07<i=01aG5@0GdM106<]
8`1WETH0HS<Y070l>`1M:R00R3Xb06MQC@1_CcH0Ke1606mHB`1cEDH0JDY206mEB@1_DDD0OW5U08bL
X@1kPhP=07]iNAT0oooo101hNWX00`1hM7@0N7em07QjNP0:07QjNP0R04Hk?00f:Ql0`in707]/IP1a
GU00NgE^07QXHP1hGTh0J59206U6?@25JfT0JcPe02`>202@If00KT4i07AVG@1bLfh0LcL_05m7>P1B
=2H0Hda604X^8@1f<b/0HUM506]==01_CdL0KeU=07AKB@1YCT@0K5M;06aAA@1eI5P0PXR807QoPPd0
N7Yj603oool407MgN@0307M_L@1gMgT0MgMi00X0MgMi0240>R/]04L[7`3E[Y@0Nf]Y06iHC`1gKfd0
MfMU07MHB`1VBC/0HC`e07]KG`1V9bX06P<206I9A`1ZAch0Mf]S08JFU@22?cX0FcH^04Lc901GEdl0
>blS06<Z8`1OBS`0IdPb06m;AP1_ETh0M5e;06]?A@1[ET/0Jdm506]CB01gKfd03P1gMgTI0?ooo`@0
IGEn00<0IFig06EbN`1UMGh02P1UMGh08P0g<cX0GTY009>7N@1XJ6X0GUUG069VJP1UJ6X0IEUD05]<
@P1B?CP0GTQA05PX;`0J0`@0<Bd`05]@BP1XHUl0OjFY07A7A@1?;R/0?Sh_04AID@0`<bL0A2@P054h
=01DASP0GDQ305eBC@1RGDl0GU9905YDC@1JCTL0DT0i05]BD01UKgD=06EeOR@0oooo000R0?ooo`80
NgUi00<0NgEe07]nOP1kM7D0301kNGT08`0O4a80^Hme085]I@1kJEd0LUE;085jM@1kJF40NeU;06E2
<@1[Acd0DQTE0:2>Q@135aH0L51:0714@P1fD4T0Ng5X06d^9`1UBdX0DC@Y04`h=00l6a@0CR4E09A:
>01dID/0M4U107=PDP1cFDX0KE5306U=A@1_DDD0KeQ;07j8VP28Q7X0PH>300`0NgUi6@3oool207Qj
NP0407QdM01hOGd0N7Qh07QmO@/0N7Yj02<040`;0:j8K@2>O7@0N6YM06mDB01nMg80N6QP07QJB`1N
?Bd0Hclf03X@3`1kNg@0Gf5L09jIT@1hLG@0NgYi07^1N`1/@cL0LWik06]SGP1GD500=AdG03/N4`1g
@C00L5m8075;A01dHeD0M5]=06eFAP1YD4D0K51406aIC01eQ9h0Ngai07]oO`0<07QjNQP0oooo0P1g
MgT0101gKg40MgMi07MgN@1gNgh;07MgN@0R00`61P2ENV<0U8=n07MWG@1^D4D0Nfm/07MSGP1gF4/0
GCHY05hf<00W2@T0EV=P082SWP2ld/h0P9JQ082JY01kRHT0KUM8082WY@26Rhl0Hf=Y03DO6P0Y6Q40
EcDX06]E@`1_BdH0M65E07AJC`1_EdP0Jdm506]<@P1[ET/0Jg^L06i_MPd0MgMi6@3oool206EeOP04
06E^M`1ULW/0IGR106EhP@/0IGEn02<06aTH059GD@1eMgL0IFEQ065GD01UH600IF=S06ENF01G?SD0
DCLb01l8200]A4T0S<c;09W9b`1aZ[T0KZ:c06R0R01UOG40N:j_08BQ[01QL7L0>2dY01TJ4P0_9Ql0
E4Ho05Y<A`1RF580HUQD069JC`1ND4L0FTa605YBC01BH7T0EF5d069_N00<06EeOR@0oooo000R0?oo
o`80NgUi00<0NgAe07]iN@1kNGT02`1kNGT09@1_JG803@L40=neU@21KF@0NfUM07IKDP1kJFD0NfUQ
07=:?01N?RX0IR`S030?2@2XPWD0PX=d07a[I`21TY@0NfUQ07]bK01^DDX0PXR607=EB@1UJFT0<1hK
02XV900l6140VDhh07UOD01nI540Mf5H06iA@`1YCT<0KdTn06mHBP1[NH00MFa^08R8UP2<SH<02`1k
NGTI0?ooo`80N7Yj00<0N7Qh07QmO@1hNWX02`1hNWX09@1THFh010<20>6aT@1nKV<0N6YK07ESF01k
LF`0N6YR06]4=`1?>2D0EbHN02H<202]NV/0PfmO07AHDP1kPh80N6=D07QZF`1XAcl0NWam06]9?01_
JV@0CCH/04]7@00i71D0OT8`071EB@1jIE00MfIK06iFB01VD4H0K4Xo06aEB01VM7D0IemI07AeQ@22
Q7l02`1hNWXH0?ooo`<0MgMi00<0Mg]n07MgN@1gMgT02P1gMgT0901MEfT01P410<BPQ`1kJf00MfMI
07MWG@1kLg00MfMQ06Hm<`17<B00BalI02D:1`2RJed0PEM806i2?01gKfd0Me]807MOB`1V?3H0Lf]`
06Hl<01kIeh0Kd`m06iRF@0g7aT0Gc<X06M8@@1dHDh0MfMK06mGC01VD4P0JdPn06]?A@1SJVH0Fe15
065OL@`0MgMi6@3oool206EeOP80IGR1301UMGh00`1BFW40718B05]IEP0206EUGP0P06Q^J01XKVd0
IFEU05Q5@014>B/0?R8K02l@2P1R>SH0IChh05/k>01RF5T0IEe@06EJB`1KA480FeAM05Q2>`1eIEh0
OfeM07McJ`0]91h0<B4O04lk>@1KETX0IF=K065KEP1JE4l0FTY305Y:A01DETd0ATQ104I<G`1KJ7P;
06EeOR@0oooo000R0?ooo`l0NgUi02H0ASP`03/T8@1SB440UhQc07]YG@1kHED0NfUK07]aJ01kJF40
JCdd05i=?@1K=S80<Q4F070m@01bFD/0LeE=07e^I@22Ee00M6IE07A1>01iC440L4/n08>5L@1V?c@0
F4Y902/U7`113PH0YFmN07i[D@1lJEl0KU5306U=A@1[CD80M5E906YTF@1`NX@0G5EU09:GS@/0NgUi
6@3oool?07QjNP0V02dV7`0M4Q00FCda0<JVRP1kK5l0N5iB07QREP1hKV<0N6YM06Dm<`1UEdP0M5mH
06IOEP2NLFl0M65E06iBB`1cH5P0Md4m06I?A@1W<B`0KcP`06<d:`1dLV40FcD[05Y3A00h;2H0?0h6
08iPE01lJ500NVYP06]B@P1VCD80ITi206mIC01YHeH0OhF>06=NL02>U8T;07QjNQP0oooo3`1gMgT0
1@0O5A001P4105<a903J]Y/0Nf]P0080MeQ?01l0MfMM07MWF@1V?C<0KeeB08^2NP2JXi00_9ZH07MT
G@1ZCDT0JU1906h[:`1M=SD0GB8Q06HS7`1J7AT0IUY?05H/8`1O>ch0C38/03L=1P1_CTL0NF5>07MW
GP1ZD400ITU006=<@P1[FTh0JeeB08^9U01[HgT0QXV200/0MgMi6@3oool?06EeOP0V024N70010000
BCH_09J:O@1XJ6<0IEUD06EDD01UH5T0IFEK05i>AP1ZHUd0PIF<0:K9/@2IVYL0J5mQ05]=CP1E@3h0
F2T_04l[<`1>9BL0DAPG04`H6P1<>cX0CcD_05Xi?@1K@Sl0:Ph803/^<@1NDDX0HEiH05iFBP1JC4@0
E4i705QGC`1MDd`0N7j606=YN`1RKgP;06EeOR@0oooo000R0?ooo`D0NgUi00<0NgEe07]nOP1kNGT0
1P1kNGT0:01_IFT03@P502LE4@3EXY00NfUI07]UF@1kFED0MfUE085]H01kG5T0JDXj06M7=P2BS8@0
NfeQ07]GE@1fEe80L5IA071?BP1fAT<0Id4n06`m>P1X=2h0J3Pg06U?@`1^>cL0G3Xb04T^8@0^4`l0
KBhQ09N0IP22K5h0KUE306U:@P1VC440M5Q:06mKCP11<2P0_ko?07MfMP21Ph<:07]iNAT0oooo1@1h
NWX00`1hM7@0N7em07QjNP0607QjNP0X06AKH@030`80714>0>RcW`2;O6P0N6AH07QFEP1aJUT0Ng1S
07QGF01UAcX0G48a08^4OP1kLVX0N65N07EXGP1eKVH0N6QP07]SF01[FDd0M5I;06iD@`1^ED/0K5M8
074f=@1P=S00BbLL03HC3P1[:Ql0QFiI07eWF`1[E480IT]206=;@01aEDP0K5U<02TP6`2NVj@0OGii
07]oO`X0N7Yj603oool507MgN@0307M_L@1gMgT0MgMi00H0MgMi02L0GE1I0000000C30/0f[JV09B7
M@1gGeH0Me1F06iWG01gKf<0Me1F06I3>`1F>b`0P7Md07]cL01gIfD0Mg=Y07]oN020Ng@0P7]Z07=/
FP1mJEX0M6mF07A]F`1_FDX0M34c06La;@1C8AH0A1<>06<T6`1_F4X0MeiG06Y@@01VBD80HdPn06m?
A@1[DdP06A4?07McM@21P7X02`1gMgTI0?ooo`D0IGEn00<0IFig06EbN`1UMGh01P1UMGh0:01BE6<0
2PT800l=301bNGL0N7ad06EOFP1UE5d0GV5Q069XH`1UDUX0GTe<04`k<01NFU`0J6md06EaL01XNG@0
KXJ30764P@1^RW/0JgQW06ihJ@1XOVH0J7MT065BB01T=c`0H30_05@R6P1>6Q@0@AXE04Hf=P1NDU00
GU=:05Y>A`1GB480FTY405Y=B00F3P`0?T9106]gN@1RKgP:06EeOR@0oooo000R0?ooo`D0NgUi00<0
NgAe07]iN@1kNGT01P1kNGT0401ODel01@T0000;501lLVL0PFeP07]QE@1kH5d0MUUE07]fH01kFeT0
JDHm05ll<@28OG00PGIa07]]I@1kIEd207]]I@0E07]IDP1bG4/0MeaA06iEAP1cDDH0IDXl07Do?P1[
@3H0G2l/04PV901;9BL0M5Hj08=WG`1cFDH0JDY206I=?P1dDDL0KeQ;01TH602dYZ00S8fB00/0NgUi
6@3oool507QjNP0307QhN01hOGd0N7Yj00H0N7Yj02P0FeIU044k:@1hFDl0]YN107]/G@1hHUH0N6MO
07ELF01kLf40N6=L06E>@@1Q@SL0RGma07]`JP1hKVH0N6QP07Q/I01hKVH0N5IB06mGBP1dGE80JeI8
071BB01PC3`0JdM006=@?@1PAS`0GDLm06E4@P1mI4<0O6EI06iHA@1VBd80He0o075CB01/FD`05A/L
0;6SWP22QhT0Ngmo2P1hNWXH0?ooo`H0MgMi00<0Mg]n07MgN@1gMgT01@1gMgT03`1MEfT0QV]B0>6M
Q03H/9@0MfMI07MOEP1gJf00Me]I07][H01gIed0IUA406I5?026NFh0MfMQ07M[I@0207MWH@0G07M[
I@1gD580KU1807=KD@1ZE4T0Ke1805i<?01SBd40GU]306MIBP1dHU@0O5eK081ZB@1dGE80JUA306I9
@P1SCch0Ke=706]FB`0M7b00VYJD07MkOP1kP8802P1gMgTI0?ooo`D0IGEn0P1UN84706EeOP0X05YX
O02cYYD0kkfO0:6@O01RHe`0IF9M06E^H`1XG5l0J61Q06E^H`1NGe@0H51:06ENF01RGE/0IFUY06EX
J01UHf<0IFUY06EDG@1QDU80HEYD05iFDP1NDTd0E51304mBA@1AHT`0H6MG07AcH`1eJFH0HeY505QA
B01KDdX0FTi705M@@`1JD4L0FU9<03<c<P1?FE`0Ff]b06QkQ@X0IGEn903oool00280oooo3P1kNGT0
9`1ZEeH0NfUQ07IOE@1bGDh0O6UL085YG@1kJF40Ne]I07]]H@1kIET0KE5406Q3>P1dETT0R8=e085f
L@1kJ640NfEM07]aJ@1kEe80LU5807=AA@1cH4h0Jde106=<@@1`B3P0JdXm06]>?@1[Acd0IdPm07AH
B@1iG4l0LeE606E9?P1[D440KeA306mDBP0D4Q80ak_508J8OP0;07]iNAT0oooo3P1hNWX09`1_F4d0
PVYJ07EYHP1aIUP0MfQK07]ZG@1hK6H0N6=P07QgJP1hJ600K5I906Y;@01_DTD0OGMZ07]eKP1hK6@0
N6QP07QbJP1hGe@0KeM:06i=@@1^FdT0Hddm05I:?`1WASH0I4Di06A9>@1TA3T0HTPi07ANC01jHEH0
L5A60617?@1VCD00Je=206QCB00;3`l0aKO:08^ASP0;07QjNQP0oooo3P1gMgT09`1gEd@0QVMC07M_
K@1cJel0Lf=I07MWG@1gJfT0MfMU07MkL01gIfD0KUQ?06m@AP1[Bd40LfML07M_J@1gJfD0MfMQ07M_
J@1gHeH0KU];06Y6?@1ZE4<0GTTj04m5?01O@C@0Gchd05m1=01O?S@0Gd@d07=PCP1iHE/0Ke1605i2
?01SB3h0Idm106=?A@0;30d0[:S408^BV@0;07MgNAT0oooo3P1UMGh09`1_IED0KfEK06QeN@1UKFP0
GUmJ069UH@1UJ6X0IFi]06EeM01UJ6d0IF=O06AKD`1HA3h0F55=069VI01UK6`0IFQX06EYJ@1UKV<0
HF5F05]8@P1KCd@0DD`o04I6@01<@SP0Cc/e04ln=@1??CD0DD@e05eIC`1QFeP0GU1<05A6@P1DAD80
E4a2059<A00K5QD0EF=n06]oT@0;06EeOR@0oooo000R0?ooo`d0NgUi00H0Mg5b085PBP1gHET0N6=D
06m]L@2<JE8207]]I@0P07]XH@1kKFD0NfQQ07IAB`1]ED@0J4<j07a`H@21NWD0Ng5Y07]IE@1gMV@0
PFeP06i=A01cCT<0JdLh06]KBP1N@CH0Id/h06M5?01[C3H0HT8h06M4=01mHeL0LeQ;06mAA@1VBCh0
Jda106]DA@1_EDT01@H80<je/P2GWJ0;07]iNAT0oooo3@1hNWX0:01aKVh0Nea7075NE01^EdH0H69X
08EXEP1kKVP0N71Z07Q^IP1hL6P0N6aT07EBC`1_EdT0JTTn07e_H01nMG00N71X07QDDP1aK5/0NfYK
06Q<@P1^Cd<0Hd8e06=CA`1M?cD0IdTf06A8?P1[D3P0HTHi06A5=01oHUH0M5M;06U>@P1PB3d0J4e1
06QEAP1_Ed`00@H80<BZX`2>U90;07QjNQP0oooo3@1gMgT0201^IfT0MeM406iHC`1VBCP0EUAN07]S
F@1kJfT0Mfm]0P1gKfT07P1gJfD0Me1B07=GCP1_C480OFUM07][J@1gJfD0Mde?06iODP1gHeH0ITU1
06Y=@`1N>c80GTU205lk=01WA3@0HdLn06]@>01SAcP0Hd<b07eMD`1dDdP0ITU005i5?01WBd40Ie=7
06mFCP031PP0XI>>0825OP/0MgMi6@3oool=06EeOP0905iXL@1RH5`0GUUB05E5>@19CUT0GUmQ06QU
J01UK6l0IFm^0080IFa/01<0J5UQ06QLF`1TEDd0IEMB06EMGP1UIVL0IE9H05iDD@1RH5T0Fe=>05]B
B`1A>cH0DD=205Lo>@1G@SP0E4Q005Y>?01GBS/0E48e0080HU1:00P0EdY405A8@P1GBT<0Edi905eD
C`0B3Q00@DQ805]XJ@/0IGEn903oool00280oooo3@1kNGT0201fH5H0NfUQ06iA@`1_EDH0LW9^085L
F@1kMVT0Ng5Y0`1kKFD07P1kEe80MUE;06U:?@1hE4X0QX=m07]aJ@1kEeD0MVEI07]YG@1]CD@0KU53
06A0=`1ZDDD0GS`a06M7>01WBcl0Kdln06Y9>`1YCT00LeU=06m=@P1_DDD0JTe206I9?P1[E4<0KeA:
00861`1G?cL0h=cM07]nOPX0NgUi6@3oool=07QjNP0807EMC@1kIEX0J4i206I@@`1dLf`0R5]F07Qc
JP1hLVX307Q^IP0E07QOE01eGTl0J51007=CB021OWP0N79Z07QOFP1eKV80NfaT06a@B@1^ETP0HdLm
06aGB@1M?380I4Hi06A;?`1]D440K4]107AGB`1iHeH0JDi20080JE1400L0IT]006QE@P1[DdP000H7
04df;`2o^K/0N7em00X0N7Yj603oool=07MgN@0807MGA01kGe<0ITU10659@01gKfH0ReMB07M[J@1g
KfT307M[I@0D07MSEP1gHe80JUA306m?A@1kLg00MfmY07MSGP1gLfT0Nf]Y06i@C`1_Ed`0ITa206mH
C01O>c80Hd<h06=7?P1[CT<0Kd]607eMD`1mJ5d206I<@P0706]?A@1WBd40Ie=106M?A@061`L0>bXU
08n>U00;07MgNAT0oooo3@1UMGh01`1XH5D0J61K05]ACP1DBdP0J69H06mGF01UH6D0101UJFT07P1U
KV<0J6UM065MC`1KC4@0HUeN06EYJ@1UKVX0J75`06QXK@1UG5l0HEYF05eGC`1PEDd0Ed8k05A0>`1D
A3l0EdY7061<BP1]GET0If9K05M>A`1GC4H0GE1905Y<A@1GCT80E4a401`C400J5QH0>T9>06EbN`X0
IGEn903oool00280oooo3@1kNGT08@1kEd<0MfEM068l;P22MV/0NeaI07]YG@1kJFD0Ng5Y07]aK@1k
J5d0NfeU07]UF@1kH580JDXm07=A@`22MVh0PG5]07]YG@1kKFX0NfEM079EB`1ZBSl0Ke5506]AA@1V
@cT0ITHd0692>P1_DTH0N5E=07MLCP1^EDT0JE5706m>@`0206]=@P0606]A@P1_FDd03A@C01dH5`1A
@Sd0h>?T2P1kNGTI0?ooo`d0N7Yj0240N5Q3075TFP1E=2H0OGEX089QH@1kK5l0N75X07QbJP1hMG80
N6]R07Q^IP1hIU`0N6IH06E>@P1`ETH0OGU]07]^J01hJ5X0N71Z07QXH01_F4/0I4Tm06U>@P1VDDD0
HdHl06Q==P1RA3X0KE9507UIDP1kIEL0KUU=06IFBP1/E4P00P1VD4@01P1XDdD0KeeB02`X7@0i8A/0
@C@_0;2b/`X0N7Yj603oool=07MgN@0907MGA01^GeH0CR`O07M_H`26HVH0Nf]P07McJ@1gKfT0MgAe
0080Mf]U01H0Mf=N07MWG@1VD4L0KeM807MfJ@1gIf40Mf=F07M_J@1gIf40KUQ;0656>P1VBD00Hdm5
06=8?P1[D3P0Hd<h06]>@`1iFUD0OFUM06mJC`1VEd`0JeI;0P1SCdD01P1WDdL0KeeE05Lk9`1D:Al0
;b<P07MkOPX0MgMi6@3oool=06EeOP0Q06EUH@1NGeP0BCL/05iOF01_GVH0J6QS06E^J01UJFT0IG5g
06E/KP1UJFT0IFEX06E[J01NFUD0GUY?05iTFP1RH5h0IF=L06E/J@1UJ6P0HF5H05M<A01GBT@0E4i7
05M>A`1MDSh0Ed@i05M8@P1REeD0J6AO065JE01JFU@0FUUA0080E51900H0Ee1;05eJE@1mG3l0F2hR
01H?3`0Z=3d:06EeOR@0oooo000R0?ooo``0NgUi00X0NfUQ07=A@P1_A3X0IUI307UjKP2BI5d0NfUM
07]YI@1kLFT0Ng9]0P1kKFD07@1kIEd0MfEE079EB`1bG4h0NfUM07]YH@1gG5D0PGY/07]LG@1^GDH0
JDHn06]@@`1WC3l0Kdlk05i0=01`AcX0M5]?07UIC`1lH5@0KUE906UEB@1_DDD0JU5506IA@@1_C4<0
KfAE05`l;`0j;2T0;DMC00/0NgUi6@3oool<07QjNP0Z07QQEP1[@C80H30[05e8>`1cOG@0R6YO07Qa
G`1hJVH0N79Z07Q`JP1hJf80N6iV07QVGP1aI5@0KeQ=07AXF@1nLfL0NfaQ075GD01kLfD0N5IF06QD
?`1S@ST0ITe105m8>`1[CCH0ECda06M4>P1dH580NUmC07YSE@1[ETX0IUA806a>@P1YD4@0IU5006m;
@@1_HeD0GT0d05=0>P1hUYl0/;2`2P1hNWXH0?ooo``0MgMi02X0MeM<06Ha8`1F7Ad0FSTb06]iMP1k
Jf00Mg=P07MWI@1gKfT0Mf]U07MVGP1gJfD0Mf=N06iODP1^F4l0MfmS081gKP1kJf00KU1;07MWG@1g
CDl0ITTh064l=@1SB3h0Fd4h06M8<P1?>2h0Gchh07=PD`1iHED0Mf9D06YDB@1VD4H0JdU006]<@P1W
Cch0KdPn06mMDP1S@SX0Ke1:0;cGh@3@em`:07MgNAT0oooo301UMGh02@1UFUL0F3Pc04TL7`1A=cP0
DF1S05][H`1UKV<0IFEU06EYJ@0206EVI00O06EYJ@1UIFD0GUmJ065QF`1XKfX0Jg5/06QXH01NDU80
HUYG06E@D`1KBT80F4<m05A5@01?@3X0E4He04Di<P1<?CT0GEM?065ME01QG5@0GUI@05Y@BP1JBT@0
GDa605Y>@P1MB400GE=>05e>BP1iHUT0`=[O09nj`P0:06EeOR@0oooo000R0?ooo``0NgUi00T0Nde4
06To=01Q<R`0Jei=07MfJ`21KFD0NfeQ07]UG@1kLFT00P1kKFD07`1kJF40NfUM079QE@1kGE80LVUL
085]I@1kKF40MUMB07]YG@1kEDh0JE5306E3>@1WB3`0Hd@h06]:>01QACX0Ke5607=IC@1cG540O5aA
06iEB@1YDDH0Kde206m<A@1ZD480Jd`n07ATFP1R?2`0Ke9909Jg``1fM7D02P1kNGTI0?ooo``0N7Yj
00T0N4Q006Dh<01M<B`0J6=@07ekK@28L6P0N71X07QXHP1hLVX00P1hKVH07`1hJ600N6QJ06mRE01k
GU80LFYM07i^J01hL6P0MF5L07]aIP1hF4l0IEA40613>`1OB3/0Fd8f06=6>01OASd0Mee?07USE@1d
HED0NUmC06]FBP1VDTH0K4i206a;A@1YCD@0J4]006mUG@1M>BX0Je1509Vkb01eN7P02P1hNWXH0?oo
o``0MgMi00T0Md8n06Ha;@1N;b`0If9A085jK02;KfT0Mfm]07MWI@1gKfT00P1gJfD05`1gHeh0Mf=F
06iODP1kG580LfML07][J@1gKfd0MfMU07]cK01gF4l0IUA405i2?01KA3X0Echd05]1=P1OA3h0O6=F
07eXF`1dHUL0MeiD06YDB@1VD4H0Jda20080JdQ500D0IdQ106]QG@1K=RT0Id]109Bd``0;07MgNAT0
oooo301UMGh0201UDUP0GS`n05Lh=`1GDd/0JfMO06mXJ01UK780IFQZ0`1UJFT07`1UHf<0IF=L065R
FP1XGUP0IF9M06EUJ01UK780J75b06Q^L01UHET0GUQ@05A:A@1?A3d0C3lh04Tm>@1DAT80IUmG06MR
F@1RGUT0HEaG05iFD01JDT`0FTi705Y8A`1MADT0EdQ505QFE`1A?c@0E4Hn06]lQP1XN8402P1UMGhT
0?ooo`008P3oool;07]iN@0H07]]I@1kE4h0JCTd05df;01dGe@0QgY/07]YI@1kLFT0NfQQ07]YH@1k
KFD0MfUL085]I01kG5T0LVUE07aLD@1gJE/0PG5]07]]H01kJFD0NfUQ07]ECP1YCC`0HDTn0P1RACX0
4@1NBCh0Kddn07AHCP1iG4l0Mf1D07=IC@1cEDT0JEE906m9?P1_C4<0Jda306]A@@1dH5h0IC`^06IA
A@23SIP0TYNF00X0NgUi6@3oool;07QjNP0907QWG01hDdH0ID4f05Ll;@1aIUH0Rh1`07]/J01hLVX0
N6aT0080N6YR0200LFAF07]ZG@1hEeH0Kf9B07MICP1aIUT0OW1/07Q/G@1hJ680N6YR07QDD01UBC/0
GDHl05m6>P1RB3/0GTm3071E@P1dGE00Mee@07MQE@1`F4/0KU9606IDB01/B3d0K4]106I=@@1VDd00
LF=O06M0<`1XEd/0MX>=08:7Q`X0N7Yj603oool;07MgN@0[07MNDP1gD3h0ITHh05I1;P1_IeH0Rgia
07][J@1gKfT0Mf]U07MWH@1gHeh0KUa?07MSEP1gD580KUQ?07=CB`1^GeD0Nf]Y07MWF@1gHeh0MfMQ
07M@DP1V@cX0GT8j05m4>P1SAc`0Ge1606mHAP1cGE40M5Y?07MNE01_E4T0JTe306I@AP1[AC`0JdPn
06=;?P1SDch0Kf5M06]2=`1[F4l0Ig9n079bM@0:07MgNAT0oooo2`1UMGh0:`1UH5d0IEmA05iGB@1A
BSP0FUU=06][I@1XJ6P0IFUY06E/K01UIFD0IF1P05iJD`1RH5L0IE9H065CE01NE500GUQD06ESH`1U
He`0IF=P06EUI@1UEel0GTM605M6@01DASl0EdQ005=@B01JEdT0GEM>05iFD01UFU@0GU=>05]=B01J
D4X0FTQ205Y8@01DBT00E51205YHE01PCTP0GEE?04U?E`1EGfT02P1UMGhT0?ooo`008P3oool;07]i
N@0707==>P1`CD40F3/]07=6=P2=M6@0QWIX07]YI@0207]]I@0907]YG@1kIEd0LVEI07aPF01hG5@0
O65H07MUE@1gHED0PFeT00<0NfUQ01H0MeQB06i3>P1QAS`0HTDj06M8?01VCd<0JeA507QHC`1cG4d0
N5a@07=LD@1cDDH0JE5606m=@`1[BSl0JdTn06]@A@1dI5/0Ic4R07A_HP1VBT@0T[_72P1kNGTI0?oo
o`/0N7Yj02/0JdD`05`k<@0l:b40F3/_08QeI`28O6`0N6YV07Q/I01hJV80N6QJ07QTF01_I5H0Me]F
06iGCP1dH5H0M6QI07AXF`1nL6D0N6YR07QZI01hJV80LEeB06Q9?01MB3d0GdHj06A9?@1XD4@0KEE6
07UID`1dGDl0Le]?06iMDP1`ETX0IUA806aBAP1VD4@0IT]006Q?AP1aHed0Gb`M06mZG01VA3/0TJ^`
00X0N7Yj603oool;07MgN@0[06Hl:01>:B40:1/F044_9`1mL6H0QW]^07MWI@1gIf40Mf=N07MSEP1g
Ge80KUmB07=CDP1VD4P0KU]B07=WG01cJel0NfmS07MWH@1gIfD0MfMQ06iODP1VCCh0GTPn05m4>P1S
Ac`0Jdi306mCA`1iEUD0M5Y?06mGC01ZFe40KeM<06ICB01[DdP0He=706=;@@1WBdL0KeeM05/V6@1[
HED0Ic/b08^BU00:07MgNAT0oooo2`1UMGh0601HBSl0@BXU028M6P0]:bP0F5UG06Q[IP1UIFD0IF=S
06EPH01UHe`0IEmE065OF01NDU@0EE9<05]GE01QI640HFYS06EXH01UIFD0IFEX06EUI@1NIed0FeU=
05M<A@80E4Ho0140GDY305e>B@1RDU@0HUIB05]CCP1KFU@0GUYD05YDC@1JEdl0E5E=05A<A@1GB4T0
FU=F04l_8`1HCTP0FST_06ENG`0:06EeOR@0oooo000R0?ooo`/0NgUi00P0IC0M03@O501E=B/0ARXT
0;fCN026MVd0NfUQ07]YG@80NfUQ0240NfEI07IUF@1fFeD0KE5707=EC@1dHe40PW5S07a]H021KFT0
NfUQ07]YG@1bFE80JTXl0691?P1WBcH0Hd@j07ABAP1_F4/0M55707AKCP1iF4l0KeM807AKCP1[DDD0
KeA706]AA@1[BCh0Jda706mKC@1N<b<0M5M806m2?02B^l802P1kNGTI0?ooo`/0N7Yj02/0GRXI024F
3`0o:b@0>2@Q0:^8LP24Mg00N6YT07QZF`1hJUd0N6YR07QXH01eJV80N6EP06mGC`1`DT/0JEU907]X
F`1gJUd0NfaX07QZHP1hJU/0KeI?06A6>P1J?Sd0HTTe05i4>@1`DTD0Ke]=079AAP1/FD/0M5E?06UA
A01/EDT0Hdi206QAA@1VD4@0J4To06Q=B01[FDT0EcDR06aGA@1X?3P0TKg700X0N7Yj603oool;07Mg
N@0705dV5`0F3PX0;B4M02/N7P2;MfT0P7=`07MWI@0207MWF@0I07MWH@1gIfD0Mf]Y07][J@1cFeD0
Kde9065=@01cG580Lf=I07MWI@1gIf40MfMI06i@B`1Q@3P0ESTl05m4=01K@CH0Jdi306mJCP1_CdD0
IU=606m@C01VBD00ITe305i9@00206=<@P0706M8?P1WBdL0Ie=505<f8P1SDT40HcHc08^b`@0:07Mg
NAT0oooo2`1UMGh01@1G?SD071@>024M700P6ad0AT]<0080IFEX02@0IFEN06EUF`1UIFD0IFQ]06Q[
L01[LG80J65Q05i=CP1BA400Fe5>05iLF01RHf<0IFEU06EUGP1QE5@0EdM404hm@P1A@ST0CT0h05A8
@P1ME4d0FTi605A=AP1KCDh0EdI205A9A01ABT@0DTY405A<AP1GBT<0EdY705A:@P1<A340C4@f058k
>@1UMH4:06EeOR@0oooo000R0?ooo`X0NgUi02`0Ng5]06<a9@0P6Q<0;1lI03TT8@2mTgP0QWI/07MU
G@21KFD0NfUI06mID01nIe`0L5A907eQDP1iEe00NDe807QNBP1iGU00OW1Q08IfL@1kJF40NfUM079A
B`1TAcX0GSlf06M4=01NB3l0L4/o06]FB@1`D4<0NEQ:07ULDP1[BSl0M5Q;06YAAP1VCD80Je5506]9
?P1[C4L0JeA504/Z7@1U<R40Pe=009O0d@X0NgUi6@3oool:07QjNP0/07Q^I`1R<bP0;B@M034S700c
8b00`YAi08AgJP1aI5P0NfaT07QZF`1TDTT0K5U=05U3>01PBCd0GT@o06A1?P1^EdD0LUM907AUF021
Lfh0N6YR07QZH01_DTd0HDPj05Y1=01TAC40FdTo06a<?`1PDTD0H4]006eEB01bGE80Hde006mIC01Y
E4P0IU1406QAA@1XBCl0J4e806QEA@109A/0DRLL07A8=`2D_l/:07QjNQP0oooo2P1gMgT0301gIf40
ISH]04D^9`0g9Ah0<24O0;2<M@20LfL0KUmB07MWH@1gIed0GDU105e9?P80Ac4X00H0Ac4]058d=@1V
C400Jda206YGCP1kJfT207MWH@0=06i@C`1QASX0Fd4b06=3;P1KAch0IdXn05M;@@1CAC`0Hdm506]J
C`1NC400JeI;06]CB00206M?A@0706M8?P1WBdL0Ie=503/Q6@1271H0HcX]08^b_@0:07MgNAT0oooo
2P1UMGh06P1UJ6T0HUAD05m4>P0f9b00:R4P05iJE01UIEh0GUmE069SH`1UIF<0DTa604U3?00i;RT0
<RLS03@];00n<SH0DT=105A3?`1EBTP0HV1P06EUI@1UIFP0HEYK05Y>A`1DB3P0E48b0P1AASl04017
A3h0@D<o04a:A01DETh0DE1705QBC01ME4d0FU1905M>A`1GBT<0EdY705M>A`0j:2<0<1PF04@_9P1R
LWD:06EeOR@0oooo000R0?ooo`X0NgUi02`0MeU;06i:AP0G20D0:ATC03@P703JXXD0O6eP07]UF@1k
KF@0NfUM06MAA`1IAS/0EShb04Hd;`16;BL0JCDU08MEA01Z=BL0LT8`0:RNR`21LFd0NfUQ079EB`1T
@cX0GT8a06=9=P1N?SH0MEM:06EAAP1PCD<0JTe206]BBP1SD440OEa>06mEB@1VCD80Hda106]<@@1d
DDL0Je5503lS6`1B9Q`0ND@c09O:ePX0NgUi6@3oool:07QjNP0/075B@@1X@cd02PD301TC3`0Z7AT0
f::407Y^H01hI5P0NfiS07QZF`1XET/0E4Dk04Lh;@0b;BX0;28O04PX6`1ZAcL0DRPN05H_8P2BPg<0
NfiX07QZHP1_F4/0HDHj05Y3<P1NCCP0Echf07=HB`1/FD`0K5E9075BA@1XCTP0FDXm07MKC@1/EDT0
Hdi205];@01PBd00KE=806QCA@0l91`0E2PN07]3<`2GamD:07QjNQP0oooo2P1gMgT04@1^BCT0IS`f
00D30P0=30`081TG0;^FOP1gJel0MemF07][H01gIeT0KUQ?05=2>P0n<BT092@U01LG600Z6a80C3HY
0080?Q`E0140Mf=H07MWH@1gIf40KUQ;0656>P1K@C80Fdhh05<m=01_EDX0LeeA07QJCP1hDdL0IdQ5
05=2>P1_ET/0Je=806=<@P0205M8?P0606MCA`1WDdD0@RDM05HY7`1g@380SkO:2P1gMgTI0?ooo`X0
IGEn02`0GU=<05]9A00>1`H02@/<01HF5P1HFeH0HF9M06EOFP1XIEh0IFEN06QSG@1>B480>CH`01hT
9`0<51L04ADA02PV8@0]6AH0:A4@04Pi>01RH5h0IFEU065QF01JD4L0E4Hk04i>?018?SD0Edi806IK
D`1/Fe<0IU=;05M4A019@Cl0EDm:05YBC01GCTL0C4Q204M8@P1BD4L0Ee1704Td:`1;;B<0EcD^06E^
N`X0IGEn903oool00280oooo2@1kNGT0;P1oOGd0L4Dc06E3>`0730h0610=034J5@3J/I80NfUM07MQ
E@21KF00NfUM07IPFP1A?340EdU401LJ600Q5A80?b0E05U0>01c=RL0JTHm089fI`21LFh0NfeY079D
A01T@3L0ES/^06=8<P0m50`0U71H071@>01VBd40Gcd^089JC@1SCd<0NEQ606mDBP1[DDD0FTDj06=?
@`1dD4L0Hd`l03lS7@1R=2H0OTLo09K1b@1fM7D907]iNAT0oooo2@1hNWX0;P1oPH40LTPe0650>008
3a006a<?034I5@3T/i<0NfiQ07ATF01kKV40N6YM07EVH01F@cT0LEaF020Q7P0N4a40=adC04Tk=P1V
=RT0NUa>09><NP1nMg80N7Eb06mKB`1Q@ST0CST]05Y2<00^3PT0OUa:06=6<01C@3H0AS0U06]?@`1K
Cd40MEM406QAAP1VD4@0Ed@i061?@`1cCdP0FdPj03<O6`1K=BL0P4m609c=e`1eN7P907QjNQP0oooo
2@1gMgT08`20Oh80MdTi064l=@0F4a<07aDA030H503>Z8h0NfmS07=SF@1gJf00MfMM07MWI@1QBD00
RfUT038X8`0O4Pl0;aTA03Pc<P1G=BX0QF]K09VIQ`1kMg@0MgQi06iODP1Q@cX0BcD/05<j;@0T2@L0
HdHj05Lk9`15<b/0<R<L05=1>01GBch0Ke=10080Hda200P0Ed4h05m;@@1_BdL0Ed4h02lL6@1C<bP0
O5=<09W;fPX0MgMi6@3oool906EeOP0^06]lQP1[H5/0FTHo03HW900P5Q<09QHD06ERG@1XJfD0HFAO
069UH@1UIF40J6]]06IKE@24L6h0ACPa020E4`0P5Q8082LZ03/f<01_JE`0M7ec06E_KP1UMg`0HFYU
05Y@B@18>cD0ACH_02<;200g:2P0A3DW03L_:00U8Ad0=cHa04a8@01DC400DTY205A<AP1AA3d0DDQ2
05M8A`1<@3`0<RDS03lb:`1JC4P0KhJC06QhP@T0IGEn903oool00280oooo00@0NgYj07]nOP1kMGD0
Ngin1@1kNGT0;P0Z40`0gIAf06eEBP0I51@04a8F02DD3`3Y^IT0O6UL07]YG@1gIET0O6UL085]J@1W
D4<0Le5:030_;00M8B@08QdI03`f;P1VBSh0N5E;07aaH`21NWD0Ng9]079IB`1T@cX0E3T/05Dn<P0g
71P0GT]604Pb9`0E2@P0KSXZ05Y6>013:1d0OeA406e6<023ET<0GTm606=<@@1dC4<0CShb034L5`1G
;b@0XFQH09Jf``1fM7D907]iNAT0oooo00@0N7If07QmO@1hM7@0N7em1@1hNWX02@0D1`D0XV5;06QD
B00J6AL04a<H028D3`3Z^IP0MfQK07QZG@0207AVF@0S07]/J01XFD/0M5M=040l<`1HAch0FSd/06=8
=`23G4H0QF9E07ebH`1nNG@0N71Z06mFAP1Q@ST0EC//05M0=00n9Ah0HEI@03@]9`0:1PH0Cb`R04Pn
<`0[7QH0GD4g058i9`1aBCP0FDe2061?@`1cCD80AC`_02DJ5@18:b80V6YI09W0bP1bMGH02@1hNWXH
0?ooo`0307M_L@1gMgT0Mfma00H0MgMi02h01P00064^8@1VD4L09ahJ01LD6P0O4a00bZbA07=SF@1g
Ied0Lf=I06iOEP1gIfD0KUmB07AJC`1JASX0TVQF08aH?@24ESd0UVQ=08]ZF`1mKV40Ng=`07M[I@1^
D480HD0h05/k;01K?c@0C2dU061JE`0T9RL00P<402lN6P0g<bd05a<@03//:@0k:Ql0Gc//05M8?P1O
CT<0Kd]1048h;00P5a<0>RHO08EUEP2D_LP0LW9e2@1gMgTI0?ooo`0406E[M@1ULW/0IFig06EbN`D0
IGEn02d02P<301P;3`1LDdh0@C0Y01dI800H4a40F5mJ05iOFP1UIF40HF9M05]LF01RHf<0J6eV069M
E01aGE00XGiY091WBP1lEC`0NFA>06iRE`1UGUP0IFIW06EVI01QF580FTa605Y4=`1B@3P0E3hb04Q;
B`0M9bh00@<5014D5`0S9bL03Q4@01PL8@0W91h0@C4X04i6?`1AC4D0EdY203lk<`0T7aX09R4N04m>
B01[PhT02P1UMGhT0?ooo`008P3oool00`1kMGD0Ngin07]dM@0507]iN@0^02dH500W5Q80@``507]9
=`0R51T071@@02/H503O]ID0MfEI085]I@1ZBCl0NFYG08aoN@1fJ5d0L5=:0655?@1OAcX0FTHj05Y0
=01^FDH0MeUA07MUF021NWD0NfeU079AA`1TCT00GST[05U6=P1H<b`0DTe:034]:`021PP0B28G04@b
;@0Y7AP0JT4`06=3=01eE440GTDl05i?@`1dDD40;1hL034P5`148aX0Y5@o09g?f`X0NgUi6@3oool0
101hMWH0N7mo07QhN01hOGd407QjNP0_01H<2P0B2`T0=0T404`a9P0@3A80518?02/H4`3]^IP0M6II
07i^J01Q@3X0K5U;08EgLP1eKV@0MF5J06]DC@1VCD00I51306a@A01lIE00OF5H07MZG01nNgH0N6iV
06m@B01QD4@0FSh^05U=>@1R?S00J5aB04lk<@0620X0AR8G03/]:@0T71P0JD4`06Q5=P1nGTT0GdTo
05i?@`1cDd407aXI02DK500n8AP0WD`i09Bob`1eN7P02@1hNWXH0?ooo`0407McM@1gNgh0MgMi07Mk
OP@0MgMi02l0204100H10@0R1`<07aPE00D6300?3`d0:QLB0=R`U01cHeT0Nf]Y05df=@1QASh0Nf]Y
07M_J@1kJfT0MeiK06m?A@1_ET/0O5]A08M[F@21IEd0MfYN07]gM01gJfD0KTe8065@A`1K@C80Fe0j
06]6=01lIEH0KdHf00h;300o81H0<RLU028I5`1P?Bh0JT@f081RC`1SBT40Gd]106mC@@0K5QH07AHA
03LN5`28@340QZBd079bM@0907MgNAT0oooo00@0IG5j06EeOP1UN840IGR1101UMGh05P0>1`P030T9
00/40P001P/020T@00l?3P0R5a@0J6AO065RG@1UIFP0E3e104hk>`1NFU/0J6ma06ifN@1aJf`0IUA?
06UME`1bHU/0LFAH06]SG@1UHed206EYJ@0G065GF01JF5@0E4`o05AB?@1RCc`0Lf1@07QC@P0K4Q<0
9AXD02DP8@0Q71`0?C4Y05A0>01RFDd0FDY205=8@P1GD4<091dM01`H5@0Y71L0BBXU05]NJ@1RLW/0
2@1UMGhT0?ooo`008P3oool00`1kM7D0NgUi07]iN@0507]iN@0^00D0000_81P09Q8@038P6`0B2P/0
;1XE02dH503J[Xl0NfUL07MYH01`CTh0GdHj06];?`22JET0Le]=06M6?P1O=b/0JdDa07A6=@1fB3D0
Uge[089^H021LFd0NfeP079AB`1TEDT0GS``0697<P1SC3P0M5A90656?`096b40924O02hU8@0^:RD0
GDDj0656=01SD4H0Kddn065=A@1SC3h06Q<@02TH50148aT0SSLW0:?Ii0X0NgUi6@3oool00`1hNWX0
N7em07QjNP0507QjNP0^0000000`8QP0:ADB02hQ700=2@X0;1TD030H503T[Xh0NfQK07AXG@1bG5P0
I5I705Y0=@1SCT00Dd8f04@a;00m9al0BS<U05@e:01I=bT0OfaN07]_H@1nLVh0N6YK06m@AP1QETP0
FSdb0695<`1PCCT0L5U906=<@P0h>cL0JdXk058g;01>=RX0PeM507IC>`1SDdP0Je1006ICB01PCD00
4Q4?02<F4`108QP0Rc@U09kDg`X0N7Yj603oool207MkOPH0MgMi02h02041034R6@0]5a@0:B0L00X8
2@0Z61<0<QPD0<jRQ`1kHeT0Lf=I07MWH@1[HE80Bc<[04La:00j:B40:1dK024G500/8AT0>2<L03hU
7@1VEdl0Lf]O07]_K01gHeH0KTe2065DA`1K?3<0Hd4b05m;>01[F4P0Idm506mHC02WKED0LTHf06]0
;`2MHTh0QEa106=CB01WCd40JeE:05m;@@0D4@l081@A03/O601m<2<0Sl3?2P1gMgTI0?ooo`0306Ek
Q@1UN840IGEn00D0IGEn02h091LE02/Q6@0Y6aL07A/J00/92P0Q5Q@0:ALE06EKEP1XGeX0HEmH06]g
LP1SJEl0>blY02lQ7P0X8Ah06Q/K01@E5P0G5aH08A`I02LL6P10?Sh0Ff9L06EUI@1UH5T0HEM>05YF
CP1DAT00Eclg055:>`1DDT<0GEE;09EhI02TNf80LTdk06e5=020Fdd0LEY305A>A@1DD4D0GeE;055:
A@0S7AL07ADC02`M60189al0GV]e2P1UMGhT0?ooo`008P3oool807]iN@0E00H0000Q40`081DA02DE
4@0L4Pl07a@@03XU8@35T7@0S79T07IYG@1kJFD0JUM=054k<P1B=S40ASli0653>P0j;BH0AcT`04dc
:P1UAS`0MfeP0080NfUQ01L0NeaE079QCP1TDDH0GSTf04h/701P>bP0PVU:07ADB@1[DD<0IDY204hl
<@1<>C<0Kddn06=9>`1[C4D0He0n07AD@`1>?C@040d;020D4022CCd0DR4H0:kIi00:07]iNAT0oooo
201hNWX0;P0200007A0;01XC400P5100718?01hE4@0g9b<0b9Ag08E^H@1eK5l0NfaX06mQF01UEd/0
HdI104E1?`1]Bd@0Echb06=<?P1N@3@0NUQ;08b4L`22Lf`0NfaV07QGE01_GTl0HEA805Xh>0109QX0
BRhQ079L@P1]DdD0J55106U>A01MBc/0Fd]107QJAP1NCD00J4e9061?@01]Dd80ACX`00T;2P0J4a00
UEU5064Y7P2Zg>H:07QjNQP0oooo201gMgT0;P0<0`406`h:01DA3`0K4`l07A8?01dE400c9b@0/Xed
07]WG01gJf00Nf]Y07MWH@1mKf<0M5=?04Q1@`1hD4`0Ld/l07]JB@1^BC`0RFEF09VAP026Mg@0Nf]Y
07M@DP1^F4l0HEA905/f>P0h7aP0>24J05m;>01WCd40Idln06m?A@1_ED<0JeU=07aRC@1KCT<0Id]<
05m;@@1WCd40@SD/00L92@0E4@l0Uf1;06/`8`2Jc]`:07MgNAT0oooo201UMGh0;P0Z6aD060h;014@
3`0E4@l071<@01LD4@0V9B<0F5QB05iLF01XJ6<0J6QX06maLP1nQG`0KUiK04U4BP1XE5@0MEM907=M
D01SCT<0M6AI07]mL`1_LG80J6QZ06EBFP1QFEP0FUQB05A0A@0c8Qh0:1XH03hg;`1BC3h0Edi006=C
B@1]H4l0IV5D06=MCP1>CTT0EdY=0558A@1BC480?cTa014@3P0A4@l0He5505Te:01NMGh:06EeOR@0
oooo000R0?ooo`80NgUi00<0NgEe07]nOP1kNGT00`1kNGT0;`0:0@006``901dD400L51004@L702DF
4@0j:RD0YWIM09QjJ@21LF@0NfUU07]]I@1fI5T0IDQ504To@@1UB4D0FSlh05Y4?01D>cD0JTXo079Q
E@21LFh0Mf5E07aLF@1gGE80J5E:06=5A00n:2@0<Q/J04T`801<;b00U5Y408=RDP1[DCh0HDe106=<
@@1WB3`0GTLm07EBBP1[D3h0;1lH01H@3P0W81`0STPc058T6@1=BDH0fmkO00T0NgUi6@3oool207Qj
NP0307QdM01hOGd0N7Yj00<0N7Yj02l01`<101/=2P0N5A406a@@00h71`0R5A40>bXV0:=bFP2<Lf<0
Ng1S07QZIP1hL6P0MFaR06mPG01YJF@0R79X079YH01hL6P0MFUR08EaH@1hKV40OWE`075RE01dGeH0
LF9B06QGC@1[E4d0DT8f03TT8`0i:Ad0<20H06m5=`1fFTd0IU4o06=@@@1PCD40HTHk05I4>@1^D4P0
KDm001lJ5@0?3@`0:R8M0957<`188AL0=SPf0:f][P0907QjNQP0oooo0P1gMgT00`1gKg40MgMi07Mg
N@0307MgN@0;0186100O3PX07a@@01/C400=1PL07a<@03TY9@2?J5@0OFMK07M[H01gIfD00P1gKfT0
2@1kLg00Rhb30:>DQ`2;S8<0U9B?09B@R`2JSWl0OGIY07]cL00206iODP0F06iSDP1ZEdh0M5iD06]H
A`14:b/0:b4J01LB4@18;bT0Idm706=??P1WCd40Gd]105m1>P1??S@0Id]506m;@@0K51803P/:02`S
7`24@c40@Q`D028V9@X0MgMi6@3oool206EeOP0306E^M`1ULW/0IGEn00<0IGEn00h0<RDN024@300L
4a005a<@00/61`0H4A00:R<Q04U4?`1EDe00HV=N06EUI@1UK6`0J79d07F6QP80SijE01l0QIjK08bQ
X02?Y:80QYF;06]bJP1UK6`0GV9J05]UF01NHeP0HUaG06][G`1dKeh0B3De01hI6@0930h07ahQ04U3
@01DCT<0GE13055:@`1A@Sd0@Sde0556A01MB4D091/H01D?3P0V8Ql0AS4Y03XQ6@0B4140;C@m00T0
IGEn903oool00280oooo0P1kNGT00`1kM7D0NgUi07]iN@0307]iN@0>00d40P0S5Q<07Q8?01lD400D
3PX091@@03XZ9@2IIU00TWYZ085aI01kJFD0Ng5Y07]]I@1kLFd207]/I@0O07]XG@1kLFd0NfQM07]X
G@1fH580NfeT07IUF@1bGE80MeaA079QE@1bG580Ide703L/;@0[8b4071hK044U701<;b40LT8c05e8
>01Z@C00Hcl`07UID01[C440IdPl01@?3@0N4`l0:1/J03lD3@1I7Q80=3<`0=GIf`0907]iNAT0oooo
0P1hNWX00`1hN7P0N7em07QjNP0307QjNP0>00H40`0P61D07A<@01lD400D3`/09AHA03XZ9P2LITl0
TWUY07ibI@1hJVH0N79Z07Q^IP1hMG8207QbKP0O07Q[HP1hMG80N6]R07Q/HP1eIUP0NfiS07EVF01a
GU80M5U>075REP1dHUH0KUI@0517A01KACd0>S8[03lV700b8aX0CBlV03hg;P1><bL0CS@W07=ECP1c
D4@0HTPj00`=300I4Pl09QXJ03@A2`125`l0;34_0=oNg`0907QjNQP0oooo0`1gMgT00`1gNgh0MgMi
07MgN@0207MgN@0=00`61P0P6AL07Q@@01lC400F3`/09AHA03LY9@2?H4`0Rg9T07]_H`1gIfD0MfmY
07M[I@0307MdM@0O07M[I@1gM7D0Mf]U07M[I@1gIed0Nf]P07MSEP1cG580Le=;07=OE@1gHeP0Me]H
06mMFP29HUH0FT8j03/U7@0K5a80:Q`I02DU900e9Al0>bLO06]>BP1hD4H0Gd@h00d;2`0G40h09API
02L=2P0/4@`0:Bd/0<_Cf00907MgNAT0oooo0P1UMGh206EhP@@0IGEn00/09R<R020M6`0K5A8071<@
01H@300L5140:2<Q0554?@1QFeH0IFEQ06EUI@0206EYJ@0806EaM`1UM7`0IGAl06E/KP1ULGL0IFa^
06E/K`1XJfP206QUGP0H06ENF01QE500IEiH06QTG@1^I6<0OWMa099eJ`1VCTH0;B<M00/?3`0?4AD0
5A`P020P7P0X8ah0DDA406=>A`1AA3`071@C01LA400M5QP050X901P>300X9bP0J7R12@1UMGhT0?oo
o`008P3oool807]iN@0_00X5100_8b0050l=028D400M4`l09APH03PY8`25FD<0UgIU08ajK01kJF40
NfeY07]aJ@1kLVd0NgIf07]aK@1kK6D0Ng5]07]XG@1kKFD0NfQM07]UE@1kJEd0LUU>07MLDP1gG540
MfEH07MHE@1XFDh0I4Y304@f<P0/:BL0:BDR03lZ8`13=R`0GT8f04`o=P1`A4<0Ie9105i2=P0B3@d0
7Q<?01dD4@0K3`/0>AXE04@e<03EfM/02@1kNGTI0?ooo`P0N7Yj02l01`D503DV8`0E4@h08A@@01hC
400W6AT0>BXT089G@@2:L600QGMY07QZH01hK6H0N71X07Q`JP1hMG80N79^07Q`JP1hMG80N6UN07Q^
IP1hK680N6QJ07QZG@1_FTl0M61D07AMDP1dI5L0M5UF06QLCP1VDTL0DdHk04m3>@1?@CD0EST/04hk
;P1bBC/0H51407U;BP1ND400DD4e00`<300M4`l06a@A01L?2P0a6QD0?3Da0=cLg@0907QjNQP0oooo
201gMgT00`0B2@P0>bTU01PB3`0201lC400702PI6P0g:BD0LU0n07QTF01kKf<0MfMM07MWH@0207M[
I@<0Mfm]00@0MgAe07MVGP1gJfD0Mf]U0P1gIed0601^F4l0LemE07=KD@1cGeD0LeME06YKCP1[EdT0
Ie=507=IBP1dF4L0JT@d05Tn;`1oCSl0Lea?07a>C`1GBch0B3hd00h<300M4`l06Q<@01@>2P0W6AD0
=C<a0<K>d`T0MgMi6@3oool806EeOP0@038X9P0h:bT06ADB01XC400L51408APK02TT8`0o>c@0C4a8
05iPG01UIEh0IF=P06EVI`1UIV@0IFY/06E^LP80IG5g0P1UJFT06P1UK6l0IFQV06EUH@1QGUP0HF5K
065JE01QFeH0HEYH069LE01QGe@0KV9D07e[F`1jIE<0GdTi058l<01XBd00JeiD05m:C019AT80?T0i
01hF500K4a005A<@010?2`0G5aD09bX[2P1UMGhT0?ooo`008P3oool807]iN@0@00l6100a8AX07aPF
01hB3`0U40/0:AXF03HT6`1M@3<0X79M08enKP21KF00NfUU07]aJ@1kLFd0NfeU07]fMP80Ng5]01h0
NfQM07]]I@1kJEd0NfUQ07]UE@1bFDh0MfEH07MLDP1gG540MeaD06iIC@1]EDT0I55605a:?`1JBT00
BCTa04hl=01Q@cT0HDa506I6?P1NB3`0?bhS01XB4@0N4`l09aPD01LB3P0U5100?RPM0;BRY`2MYZD8
07]iNAT0oooo201hNWX040091@<0;B0G01hH5@0O4`l09A0;02XI5P0f91T0ES``09=YE`27NFX0NfaO
07QZIP1hLVX0N7Eb07Q^IP1hMG8207QbKP0N07QYGP1hKVH0N6QJ07QXH01hI5H0KeI;07ATE`1dH5@0
M5eB07AKDP1[F4X0KE9606IBAP1PCT80JEA7061;@01XDDD0Le1406Q@B@1[BT00Gd/k03LY7P0C3`l0
7A<?02PH500I4`l091DA03XV6`2VSi80Ri6@201hNWXH0?ooo`P0MgMi00l04PH402/M5@0P61D08A<@
02D?2`0Z61@0=B8H04Xe:`1lFdl0OFmS07MWG@1gIfD0MfmY07MdM@1gJfD00`1gKfd01P1gIUh0Mf]U
07MSEP1gHeh0MemF06i@B080LemE01D0Le]A07=GCP1ZE4L0Kde306]@AP1WCdD0N5Y>07QHC020HU@0
P5U=06m@C01_Bd40HdXj03DS6P0C3@d07A<?02XH500K4a008Q@@03<R6@27LgP02@1gMgTI0?ooo`P0
IGEn0100;b8K02HL5P0R6aP07A@A01l?300S5Q@0:AhG02dX9016@Cl0FeYF069SGP1UIFD0IFUY06Ea
M`1UJFT0IFY/0P1UKW8206EYJ@0L06ESG01UHf<0IEmM065DD01QFeH0HF5K065JE01QEe00GU=<069=
B01QDT`0Ge=;06mNE@1fI5T0NFUM06eJD@1RCTd0Gdi505U8?@0f9b007A@B01/C400T5aD06Q@A01XC
4@0S71H0?3Ll055HH`P0IGEn903oool00280oooo201kNGT04@0=1040=BPT02<H5@0U5Q805`h:02LE
4@0W5Q40CRlR07mB>02XSWh0PG5T07]YI@1kLFT0NgIf07]/I@1kKFD0NgIf00<0NfeU00H0NfEE07]Y
H@1gGE80MeaB07MLD@1gHE@207MLD@0D06iEB@1_DDH0KeE906YEBP1[CD80Ke5506IAA@1SBCh0Jda3
06]<@@1J?S809Q/G01L>2P0X6AT06A0?01T@2`0B20P0>1hG08MYH`2c`<8807]iNAT0oooo201hNWX0
4@060`40<bTV028I5P0V5Q<05Pl;028E4@0Q5A00ARXP0758<02HPG40OW1S07QZIP1hLVX0N7Qf07Q`
JP1hKVH0N7Eb0080N6]R00D0N6iV07QVEP1hJV00LEa?075NDP0207AMDP0F07AKD01dGE80JeI:06UB
AP1YEDT0JEU=06Q@A01/D4@0IU5505]9?`1PCD80H4e004/l<00H5aD03``:02DH6@0G41005Q0;00l7
1`0b6aH0OV5K0:Ze]@P0N7Yj603oool807MgN@0A00`40P0a:BL091XH02LF4`0E3`/07Q@@01dC3`0k
9Ad0G3/X085^H@1kJf00MfMU07M_J@1gM7D0Mfm]07M[I@1gKfd00P1gIUh01P1gJfD0Mf=F07MWG@1^
F4/0KUaB07=KD@80LeM>01D0Le]A06YDB@1VD4H0IU=806]JC`1WCdD0Jda206M?A@1GB3h0Ed]105M;
?P12>2h04A<C00/;2@0R5aT05@l@01<>2P0=1PL0:QPD06YCD02DX:80201gMgTI0?ooo`P0IGEn0140
9QhH02XX9`0R71/08aLE01<@300F4a005A4?02DM6@0b:1l0Cd]706ESGP1UIFD0IFUY06E^LP1ULGL0
IFUY06EZK00206EVI00:06EYJ@1UIF40IFEN05iKE01NGUP0HEYD065DD01QEe80HEYD05iFD080Ee9<
00D0GEYD05M@B@1JC4H0FTi704a:@`0204M:@P0:03Tk=00G6QX030d;01/F6@0B3a4040h;00/61`0K
51<0=S8d05QUK0P0IGEn903oool00280oooo201kNGT04P0:0`40;bDS02`Q7@0U61D08ADA01hC3`0Y
71P0?b/U05Lh:P2`OfT0S7Y[07]]J@1kKFD0NgIa07]fMP1kK6D0Ng5]07]XG@80NfeU00<0NfEI07MU
E@1gGE800`1gG5405P1cG540N5U=07=IC@1YDDH0KeE906mHB`1ZDDH0Jde206]AA@1JBCh0Jda105Y8
?00l;2D07A@A024I5P0C2`/06A0@01071`0H41009aD@079HD@2oaLL807]iNAT0oooo201hNWX04P07
0`40;bHS02`R7P0U6QH08aHC020D400Z7AT0@2hY04lh;02TN6D0QG=T07Q/J01hK6@0N7=/07QeLP1h
L6X0N7Eb07QYGP80N6iV00<0N6IL075TEP1aG5000P1dFe005`1dGE80KUeB071HB`1^F4/0IU9606aE
B@1/Ed/0JE9606Q@A01VDDD0EdTo06e=@@1KB3/0<RPR01HA3`0R6QH04`/;01H@400?1`L05a0@02HF
4@1]ETl0_<C700P0N7Yj603oool807MgN@0>0186100_9B<0;B8O02LK600W5a@08Q@@02XM6@0n;b/0
ACD/08UZGP1kIe`0MfMU07MWH@1gJfD207M_K@0707MdM@1gIUh0Mf]U07M[I@1gHeh0KUmF06iHC`02
07=GCP0507=KD@1ZFe40JUA906YDB@1VD4H00P1[DdP0401[D4H0Idm506=?A@1GB3h0Kd]105m4>P0_
8al05@h>02DJ5`0B2`/050h?00h71`0G3a009AHA05m?B`2X]kd807MgNAT0oooo201UMGh02`0b91d0
:B<Q02XT8P0S7A/09ATF01hD4@0S71X0;BXY02d];019AdH0GUMC0080IF=S00@0IF=R06EZK01ULGL0
IG5g0`1UJFT00`1UIFP0GUmM05iKEP02065GDP04065JE01KFU@0F5=>05]CCP80FU9<0140FU1:05eB
C01GD4T0E4i7055:@`1MBT<0ET@m034X9@0L4a8091/I010;300A3Pl030L801@?4@0K5140=3Lh05ib
N`0806EeOR@0oooo000R0?ooo`P0NgUi02l03PD203<V8`0c9R<0:QlL02DE4@0F3`/0<1/F044Z801E
>bd0S5]509:1L`21LFP0NfUU07]]I@1kMW40NgIf07]aK@1kK6D0NfQM07]]I@1kIEd0MVEE079ICP1c
F4h0N5U=07aLE01^G4d0LeE907=HC`1YEDH0KeE906mAA@1[E4L0Je5506M8?01VCd<0Hd@h04hj<P0d
8AT08ADB01P@300G3a0050/;01L?2`0H4100;1TD0:RVY@0907]iNAT0oooo201hNWX0<0071@@0<BPU
03@X900/8Qh09AHB01@?2`0^6QH0@RTO05/k;02@F400RGUZ07]`I@1hJV@0N6aT07QcK01hMG80N79^
07Q`JP1hJf80N6iV07QVGP1eJ5P0LEa@06iICP1`F4/0MeUC06]IB`1`DTH0L5E?06IDAP1/EDT0K514
06IAA@1VD4@0HTHj06I=@@1P@SH0?S@^02HL5P0L4a405A0;01@?3`0D2`/05a0;01TA4@0^6A@0eM7@
09jQXPP0N7Yj603oool807MgN@0<00l9200a:BL0=BTU02lS800W5Q<04`h:02XH50109Qd0GCTY08Q@
>P1mJUh0Mf]P0P1gIf40101gJfD0Mfm]07M_K@1gKfd207M[I@0<07MSGP1gIeT0LeaB06YGCP1ZE4T0
LeAA06YDB@1_CD<0Ke1<06I@AP1[DdP0Jda20P1SC4803P1O@CP0IdPn05ln=00e;2T081LC01/B400C
3PX04`h?01<;2`0G3`/06A4A02hI503Tj^h0/[c1201gMgTI0?ooo`P0IGEn0300:RPW02/Y:00^:BL0
;2HT02<H5P0B3``07aHD030Q6`17<RP0Ecd`05QAC01RHe`0IFES06ESH`1UHf80IFY/06E^LP1ULGL0
IFa^06EYJ@1UIFD0J6QS06EPF`1KFU@0F5=>05iADP1NDDh0GTe805i=CP1JD4`0FU9<05Y<AP1DBT@0
E4a60552?01JAT00DClh034];00R71T07QDC014>2`0B3Q0040/<01@@300E41408aLE09:Y/`2<Y[08
06EeOR@0oooo000R0?ooo`H0NgUi00l0NgEe07MfMP0=2@L0<bDQ03LY9@0_8Ql07A4>02DJ5`0Y6QL0
=B<M06Xo;@1nD3l0SGQX08IfJ01kJFD00P1kKFD04@1kMWH0Ng5]07]aK@1kJ5d0NfeU07MQE@21JE`0
LUU>079LD@1bFDd0LeE=07=IC@1cDDH0KeU?06mAAP1[C4D0KeA50080Je5500h0ITHk06=<@@1J>c00
Ac<Z02<I500U5Q<05a8>01/C400J4Pl05`l;01`D400^6AD0m?[k07IdM@P0NgUi6@3oool607QjNP0?
07QdM01aL7001PH5030T800e:BD0;B<O01/A3P0U71P0;1dI034S7@1U?bd0O55108QgJ@21MFL0N6YV
0080N71X0240N7Qf07QbKP1hLVh0N6UN07Q^IP1aH580NfIH06mFB`1aFe00M5a@071HC@1^FD/0L596
06UKD01YE4H0ITY406QBA01VDDD0J55506I8?@1NCd<0CcX_048c:@0P6A<08ADC01HC3`0K51006a<@
01L@2`0L5140;aTE0?ooo`1eN7P0201hNWXH0?ooo`H0MgMi00l0Mfma06iWJ@0<1PH0;B8O03<W900]
8Ql06Q0=02LL6@0^7QX0;B8N05Xk;01cCT40OG1V07]_H`1gIfD00P1gKfT06P1gM7D0Mfm]07M_K@1g
IUh0Mf]U06iLC`1gGe80KU1807=GCP1gFe40KeM<06YGB@1_D4H0IUY?06ICAP1SAD80Hda206=?A@1W
CdD0IdPn05]>@`18>2h0@S4W028H4P0P518061<?0P0L5100100H40/071@@02hI503VlOH907MgNAT0
oooo1P1UMGh03`1UKWL0GVE^02HP7`0V8B00:RHU02PS8@0I4a008a`J02DN6`0Q7ad0>C4Z04i2?01H
Ee@0HV9N06EUI@0206E/K0<0IFib0P1UJFT0501NGeP0HUaF065DD01UEe80J5aG05iHD01KETh0GU9<
05MHD01GE4`0E4I6059:AP1DCTL0Edi705Y<A@1>C4D0@3de044e:`0W7QL07aHD0P0H51401P0I5A40
5A0<01PD400R5aD0Jgb606QhP@P0IGEn903oool00280oooo1P1kNGT04@1kM7D0MVm`00P40`0l9Ad0
;bDS03DX900V71X09ATF02dP700a81P0G4@h06do;`2GKeh0R7i^085]J@1kKFD0Ng5Y00<0Ng9]01d0
NfUQ07MYG01gHED0O6UL07MEB`1cFDT0N5aC07=IB@1cFDl0LeE:06UEB@1_EDT0JTY206IAA@1[C440
Je1306=<@@1JA3P0DSHZ03TT800U5a8071@@01P@2`0I41005@`;00`81`0H3@`0ARTS0=_Xj@0907]i
NAT0oooo1P1hNWX04P1hN7P0MGQh00<40`0l9A`0;bDR03@X900Z81d09a`H02dQ700b8AP0FdHj064m
;`2:IUH0P7MX07]/J01hK6@0N71X07Q`JP80N6iV01h0N6EL075TEP1aG4l0MfQK075EB`1^F4H0L5U?
06iHAP1`FDl0L5Q<06IEB@1/E4P0JDa206ICA@1XBd00J4e105];@01?@SH0B38W02`O7@0K4a4061<?
01D?2`0G41004`/;00X71`0E30`0BBXT0>_`l01eN7P807QjNQP0oooo1`1gMgT03`1gNgh02PL603/S
6P0_8b00<bLT02lS800Z7AT0;B4M03<Q601DA3X0DcT]07QHC01gJel0MfMU07MWH@0207M[I@80MfIN
00P0MemG06iLC`1^E4P0Lf=I06iCB`1ZE4<0JUA906YD@`80KeM<00@0IU=806]@AP1[C480Ie=50P1W
B3h03P1GB3h0B3hd048/900T6QX05Q0?01DA3`0C3PX05Pl@018:2`091PL04P/;04LY9@3JiNX0LW9e
201gMgTI0?ooo`H0IGEn0180IGR106QoR00T81d0<28K02TR800[9bH0;bPV02DN6`0V81d0:b0I03Lh
=00f<bd0C44m05]GD`1RHf<0IF=S06EVI`1UIV@206ESG`0N06EPGP1NFU<0GUI@05iOFP1NFU@0Fe=8
05QABP1KDdP0GUI>05iHDP1JDT`0FU1:05e@A`1JD4L0EdQ205M5@01<B480@3lh03X`:@0R71d0618C
01<A400A3P/04Ph@00l:30081PL03PX;038T8`1_O8D0HW9k201UMGhT0?ooo`008P3oool807]iN@0@
00L30P0a7aH0=BTW03DX900[7a/09aLC03<S6P0a9200BcX^054[8@2DHDd0TXMe085]I01kJF40NfeY
07]]H080NfeT00/0NfUU07IUE@1bFDh0Mf1D07=EB@1cF4T0LeQ?07=LBP1cFDd0Le5506UHB`0206mA
A@0@06IAA@1[BCh0IdPl05I7>`1B>2`0>B@P034P600M4Pl06a@@01lC3`0F3a004`/;018;2`0Y61@0
UXf=07IdM@T0NgUi6@3oool807QjNP0@00D5100a81H0<bXW03DY9@0X7QX091HB03@R6@0a9B40B3X_
04LV7P25F4H0RH9a07i^H`1hJUd0N6aV07QZF`80N6YM00/0N6QR07EXF01aG500M5eB06i>@`1^E4H0
L5E@071KC01`FDl0L4i206IEB@0206a@A00@06=AA@1XBCl0HTPk04e4>018<bP0;1hL02HL5@0I4@h0
61<@020C400F41004`/;018;2`0_6QD0g=3=0:N][PT0N7Yj603oool807MgN@0?0189200a7aL0<BTW
03DY9@0W7AT091@A03<Q600a9B40@SL^03dQ6`1_Bcl0OGIY07][H01gIeT0MfMQ00<0Mf=F00/0Mf=N
07MWF@1cG580LeM>06Y6?P1ZCD<0Ke1?06mGC01_Edl0KdU006I@AP0206]<@P0@06=?A@1WB3h0Gd@j
04Pn=012;2@091PI01lH4`0G40d061<?024C400G3a004P/;01<;2`0c6aH0oooo0<KGg0T0MgMi6@3o
ool806EeOP0@03<Y9`0Z81T0:RLV02dX9P0S7Q`081HD02XN5`0Z9280;bdZ02/P7@0o=C80F5UF06EU
GP1UIE/0IF=P06EPF@80IF1G00/0IF=P06QXH`1UH5/0HEA@05]9A01KBdP0GTe@05iCDP1NEU80GTY4
05Y=B00205Y<AP0@05M>A`1GBT<0DD@m048m=P0j;bP08Q/M01hJ5P0G4Pl05A<@01`D4@0E414040/<
014;300Y6AH0//gC09bma@T0IGEn903oool00280oooo201kNGT03`0B2@P09Q/G03<U8@0l:BD0:QdF
02PM6`0[71L0=RLS03<T7P11:bH0O4Te09IfG@2=OW40O6UL085]I00207]YG@0M07MUF@1lJF00PFeP
079EB`1cEDT0LeU906m=A@1dF4h0M5Q;07UHB`1_CD80KeA706m<A@1[E4D0Je5106M5?01SB3`0CShb
03lT7@0/7aP08A@@01P@2`0I410091@@01H?400?1`L05@`<038K5@3amoL02P1kNGTI0?ooo`P0N7Yj
02l04@h<02LO6`0a9R80>bTU02/N5@0Y7a/0:A`H038W8`0^8Q`0>2PT06m6<`25JU80P7=V07AVF@1k
K640N6YK07QZG@1aI5P0M6IK07]/G@1_E4X0KU1506iHAP1YCT@0K5M<06aGB@1dEDT0JDe106UCAP1/
BT@0IU=506IA@01RA3X0FdPk04Lm<P0e8A/08a`E01/B3`0D3`/05a0@028D400E3a003PL701@<300b
6aH0moOg07EhN00907QjNQP0oooo201gMgT04@0O5A<0:b8O02lU8`0i9b@0;AdE02/O700W71T0;bDS
02TN6P0_92<0G40a06mHAP1cHeT0KUmF07MWG@1gIeT0MfMM0080KUmF01`0MfMI06i@B01ZBD00JUA3
06I<@P1VDdP0IU=606m@AP1VBD00ITm506]5@P1SCdD0Hdln05m1>01GA3X0ACX`02lL6@0O61<05a0=
014=2P0E3a008A<@01D?400>1`L04`/;02lJ5@3JiNX0LW9e2@1gMgTI0?ooo`P0IGEn01P0?S`l02`X
9P0W8b80;bHU02/O600W8Ad081/J02DR8@0P6a/08B8T03@b:`13?CD0EE5=05]LF01RHe`0IFEN06EU
H@1NGeX0FeaF069SG01QEe80Fd]605]CB01GCTH205A@B00C05]=B01GC4H0Eda605Y6AP1DC4L0E4i2
0554?01<A3d0@Sde02dQ7P0P6aH05A4?010=2`0B3Q006Q<@01@?400=1`P040/<024G5@02069bN`T0
IGEn903oool00280oooo201kNGT0;P0L4Pl0:AlN03<V8`0c9200<B8M02<G5`0Z7AP0<B<N03DX900a
81P0CRdQ08ENA`2BKed0Pf]L089aH`1lJE/0O6eP07MUF@1gHED0O6UK07=HCP1_BSl0M5M706mAA@1_
Cd<0KeQ:07ADA`1_DDD0Jda106m<@`1WC3l0Idlo05i4>01J>Rh0DCT[02XL5P0Q510071@@01L?2`0D
2``05``<00`8200<1`L0;1TE034L503Pk_<:07]iNAT0oooo201hNWX0;P0F4`h0:24N03@X900a9200
;B<N020F5`0X71L0;b8N03DY9@0a81L0ABPM071C@@1nHE<0MUe@07YXF`1dHUH0M6QK075TF01dH5@0
MfAG06]EB`1VBCh0K5=506U>A01/CD40K5=606mAA@1YD4@0IT]006Q;@@1OBC/0GTTk0551=P1:=BX0
A34V024I4`0I4Pl061<?01H?2`0C2``05@`;00X71`0;1`L0<1XF03TN5@3^loD:07QjNQP0oooo201g
MgT0400O5A00:b4O03DY9@0_8b00:b8O01lE600U6QL0;B4M03DY9@0a7aL0>B8I05I4>01WCdL0JTe4
07=LDP1^F4l206iOEP80LeaB00D0IU180656?@1VC480ITU206]8?P0206]<@P0<06I<@P1SB3h0HdPn
05]4>01G@CP0B3/d03l^9@0k:B407AHA01D@3@0E4@l05@l;0P0B2`/01@091PL02PL7034K5P0m7aD0
f^GZ00X0MgMi6@3oool806EeOP0^03Tf<@0]:2H0;RTW02LS8@0V8b8071HI01lI600S7Q`0;BPV02XO
600T71P0;Bl]044k>@1B@d00Fe5>05]DD01KFUH0GUmJ065KEP1NEU80F5E@05A<AP1DB4@0EdY605Y6
@01JAd80EdY405M<AP1DB480DTQ004m2>P19?SX0?Sdh03@_:00c:B8081/F01@@3`0C4A004`l<010;
300>2P/01`H700P71`0U6AH0<AhF06]hOPX0IGEn903oool00280oooo201kNGT09P0Z7Q/06Q8>03<X
900_8Ql0>B`X02HI500U5a@0=b/W02dP700h:2<0:QXF05a3<`1S@3<0S5E2099eH`1eFdd0OV]Q07UT
E`1iH4l0OVAH06]AA@1N@3@0M4/m07U@?@1dDTT0Ke1306m8>P1_ETT0Jd`h06M8@@1SA3P0GT<f0593
=P12:240?R<I02DH500N4`l05a0;0P0D2`/01P0@1`L02`L701@;2`0X5Q40SGYf0863P`X0NgUi6@3o
ool807QjNP0V03H`<`0R6QL0<bPT02dS7`0k;RX0:Q`E02HG4`0i;BP0;20L03DX900V6aL0CSd`04Xe
;01Z@cD0OFAE06I@A01_GeP0K5UB06aHBP1dGe<0H4]004`h;@1N@CD0JTHe06]>A01XCd80J48f06Q@
A01VBcD0HTPn05]2=P1G@3@0Bd0d03XU7`0b7QH071@B01/B3`0F40/201<;2`0600l71`0:1`L05@`<
02PF4@2j[:X0/kZl2P1hNWXH0?ooo`P0MgMi02h0CT9<030Q800c9b@0;B8O03/^:`0_7QH0:ALC03X/
:00[7a`0<bLT02@J600m=B`0<RPS04P_9`1VD4H0FT<j065@CP1QCD/0HDe406YGCP1J@cX0@BhW04/e
;01K>b`0HdPn06=;@@1S>c80HdPn06=8<P1OA3X0Echd05<j<018>S00=B4M02TH4`0H4A006Q4?01D?
2`0B2P/04P/;00l71`0:1`L05@`<02HF4@3>c]80d>7Z2P1gMgTI0?ooo`P0IGEn02h0JW2303``<@0]
9bH0:2<Q038];00_8QX091PD02hX9`0T7ad0:RLV01hK6P0R9bH06QlO02<R8@13>cT0BClk04a5B01>
Ad`0CTY805EBCP1?AD00>C8]03L`;014=B`0Cd@m0598@P1B>cD0DT4m05A8=P1AA3X0C3lh04Pi<`12
>C<0<BHS028H5@0I4Q806A8@01<?300?2P`040/<00d720091`P04@/<01/C402AZkH0W;[62P1UMGhT
0?ooo`008P3oool807]iN@0X05mEG@0A20L09Q`I03@U8@0e9b<0:AlI02DF5P0j9A/0;b@Q03`^:P0[
8Ah0=BLQ04@a:`1O>2/0LDPe0659@`1RBch0N4/j07MKBP1cEDH0G3lf05Pi:P1G=RP0KD@^07=4=`1_
CSX0MDLh0696>`1R?bh0Jd8c06=4=P1A>c80C30U03TP600]61@07a@@01P@2`0D2`/040L700`82080
30L700<07a@@02/H503VjNT02`1kNGTI0?ooo`P0N7Yj02L0JFQ/01LD3P0U7AX0<2@P038V8P0S7QT0
8AHG03LT6P0]9200?S0/02hU8@0e9b80?2hZ05@e:P1I?2d0A3Tg04@k<`1F>B/0G4Tk05Y6>P12<R`0
A2lS04P`901I?2T0Gc/`05i4<P1ZA3@0Ed8g050f:@1H=bd0ESda04@f<00m:B80;Q/D02DE4P0J4`l0
5@l;018;2`0?1`L00`0;1`L0100P5Q40;QTE0?Ocl`1kOgl:07QjNQP0oooo2@1gMgT09P0W7aH09AdI
02dR7`0_8b0081`H01lE600c8QT0;B8O03h`;00c9b@0<bHS03DY:016;bP0@BlU02`X:`0Z:RL0>2HM
04Df:`15=Rh0;R@R03DU7@0k:1l0AC<S04`a:01?>2T0Gch^04lm<P12;2@0B2`W04`d:`0k<Bd0<R8O
02LF4@0P4a405a4?01<>2P0A2P/03PL70P0:1`L01@0;1`L081HA02lJ5@3Tj^h0Nh2200X0MgMi6@3o
ool806EeOP0^07F<T@12@CL0920M02DQ800V8B007AdL01/G6P0V7AL0:28P038];00a:bT0:2<R02LU
:00/:BP09B<O01dQ9P0H8B<07QhJ02dZ9P0_;R/092@U02/V8@0]9Al0;B`R03@Z9@0k<BL0BCd`04<i
<@0d:RL0=bTV03h`:`0c<2l0:R8Q02@H500M51<05Q4@014>2`0?2P`030L800P71`081`P02@L801PD
4@0U6AH0KWn806QkQ@X0IGEn903oool00280oooo2@1kNGT0;00O5Q<06Q<?03DX900_9R<0;24M01PA
3P0g91h0?2hZ03T/:00j;RX0=BXW03lb:P14<RX0AC0V044[:011:Ql0BB/U05Xe:01I?S80?R/W04H]
9@1>:b00CRlN05<_9@1V@Bh0Hcd]05Lf:01H>2/0CbhQ05Dh;P17:b<0?2DM02TG4`0Z71P05Ph:01P@
2`0C2`/03`L700/71`0<1`L08A@@01L@401VBT<0[[^m2`1kNGTI0?ooo`T0N7Yj02H08R0R01hI5P0g
:RH0;bPT02dS7`0G4@h0<b@M03``;00k;RX0?34/03X`:`15>2h0ACH/03da9`0e9bH0=R@J03`T8017
;280AS<Z02lT8P0h9b<0@RLO04<Z7013:280DcX[050f:@12;b@0BS<W048Z7`14<b/0>BHO038Q6@0P
5A8091/H01<?2P0F40/04`/;00l71`802`L700@091DA01TA4@1kFE80d]WJ2`1hNWXH0?ooo`T0MgMi
02H0=2/c02LN7@0h:RL0;bTU02lS800H4@h0;R8M03/`;P0k;R/0?C4]040c;`1:>c40ACL]03H_:00[
8R<0;Q`E030L6`0e8Ad0=BHR02@L7@0[8B00=b8N03XT6@0e8Ah0@C4V03h]9@0b9Ql0?RdS03PV7@0e
;2H0;b0K02/L5P0K4a4081XH018>2P0E3`/04P/;00l71`802`L700@09QHA01XA4@24HUd0f^GZ2`1g
MgTI0?ooo`T0IGEn0280DUIW030Z:P0^:BL0:BTW02/U8`0G4a008AhL030];@0b;B`0=C4`03Xe<`0n
>S80>3L`02X_:`0R8B8091XF024I6`0Q6QX09AlO020M7`0P7b80:R4P02/P6P0T7Qd0:bTU02/Y900W
91l0<B/U02`V7P0W9bD0:1lL02HM600I51<071XI0P0B3``0200@2``03@L800T720091`P07aDA01H@
4@1MEEH0RIVQ2`1UMGhT0?ooo`008P3oool907]iN@0[04@kA00?2PL0;b@P034U8@0a92009QhK038V
8P0l;RX0?C0/03DX900j:bL0@BTS04P_900f9ah0<BDS02`L5`0j9b<0<1TD044]9`0e9B40<B4M038J
5@0d81X0=1/E03lO6013:A`0?RDK044W700g6aD0>AhH038L5P0`6aD071@@01/A300D2`/05@`;01@;
2`0;1`L030L7024D600Q50l0;28P0:jRX00<07]iNAT0oooo2@1hNWX0;01ACUL05Q4=02lT800_9200
<2@P02XQ7P0k;2L0?S0/03db;@0c9b@0=2PT03/T8013:B00<b<K02`S800U6QH0<RHR02PG4`0d:2@0
;2<P02XP6`0Y5a<0:1`H02PG500`6AD0<B8H02lP5`0a8AP0:1HC02`H5@0V5a<09ALC01HB3`0G40/0
4@X;01@;2`0C2`/02PL700/71`0T5AX091D@038W8`3OdLh0U9^M2`1hNWXH0?ooo`T0MgMi01T0IUiY
02LI5@0_8b00;B8O02lR7`0_8b00@2l[03h`;00m<Bd0<BHS02lT8@0e7ad0?b8M038N5`0Y7ah081PE
02/S8@0P51409b8P02DO7P0U7AT081@A01dH5P0M51808Q@A00808QTD00P08aXE01`A400P4a406a8@
01dD4@0C40h04`h:00l92P804P/;00L02PL700/71`0V5Q/09QHA03LY9@3^k^h0Xk:h00/0MgMi6@3o
ool906EeOP0J07B1S@0l<2h0:B<Q02LQ800X8R40;bLU03D]:`0b;B`0<c0_02XV9@0V8R80:AdM038O
7@0]7AT091lN01/H5`0P8B4061@C01XL7@0O7al07Q`K01LC4P0D5AH0518C01@@400E51<201LG5009
01D@4@0F4100510@01HB4P0B4@l03`h;00h:2`0?2P`040/<00802@L800D07aDK01lE4P0`:2D0U[2f
08:PZP0;06EeOR@0oooo000R0?ooo`T0NgUi02@0L6Y`01P=3@0K4a00<B@P03DX900_8Ql0@38^02/N
6`14<bh0:alK03X[9`14;RH0=B@Q03<R7@0a9200:1dI03`Y9P0N51@0;R@N02`I5@0Z6QD08A@@01lE
4@0U5100;QTE02`J5@0T5A009aHA02DD400^6AD08A@@02<D400G40/0610;01<;2`0D2`/200`71`04
01@;2`0^7Q/09AHB08N8R0d0NgUi6@3oool907QjNP0T079bMP0V92808A/H030T800e:BD0;b@P048e
<00X7QX0?S0/02HM6@0g:RH0Ac8X03<W900/8al0;B@Q02PN6P0o;2L07A@E02/T7P0X5a<09QLC01dC
3`0K51008A<@02/H500Y6A@07Q<@020D400O4a00:QPD01dC400P510050l;01L@2`0C2`/050/;0P0;
1`L01@0E30`0<R0K02PG4`33`/80/;2`00`0N7Yj603oool:07MgN@0B044j>@0[8Ql0;b<P03DY9@0_
8b00@SDa02LM6@0g:bP091XG03<W9017<bT0<BTU02LR800[8b40:AhJ040/:00O51H09b8N0P0T5140
1@0K4@h061<?01dB3`0W5a@09ALD00<06Q4?00L09ALD01/C3`0M4`l04`h:01H?2`0B2`/04`/;0080
2PL700D05@`<03<P6`0Z61<0i>[^0=3Gg00<07MgNAT0oooo2@1UMGh0601[OhD0HF]_03<]:`0X8b40
;BPV02TT8P0e<C008ahL02TV9P0Q71/0:2@T03Tc;00Z:RP08R<S02HS8P0V81d0<bTW01lG6P0N7Qd0
7A@B01hD4P0H4@l04a4?01HA3`807QHD00P05A0?01@@3`0E4@l07AHD01PC400G4Q004Ph;01<?3080
40/<0P091`P01@0A2``09AdI02DI5@2V_LD0Wk[200`0IGEn903oool00280oooo2P1kNGT05`16>cl0
4P`9030X900e:2@0;b8O02hT7`0l;2P0?C0/02PQ7P0_81`0ARXO02LM6P0a8ah0;b4M024H700d9Ah0
8aHG02XJ5@0Q51P07a@?01dD400H40/07a@@008081@@00h06A0;01H<300K4@`09aDA01P@2`0F30`0
6A0;01P@400C2`/030L701@;2`0I4`l09ATG02TH50l0NgUi6@3oool:07QjNP0<04e6C00G40d0<bTU
03DY9@0]8al0:28M03P[9`12=C00:B@Q02dP70109a`081TG0P0/81`0200L5Q/0;B<M01hE5P0Z6A@0
7Q<G01/D3`0J4a005Q0;0P0M51004@0K51005Pl;01<;2`0H40/08aDA01D?2`0C2`/05a0;01L@400C
2`/02`L701@;2`0M5A00;AhI02dI5@2f]KD0][Rh00d0N7Yj603oool:07MgN@0C05e@F@0T5180=BTU
03DY9@0]8Ql091hJ03DY9P15=c80:bHS02/O700i8QT07AHD02LM6@0Y7QX06Q@J02DO700L51D0:ALC
01dA5`0201PC3`0D01D?2`0K4a006Q<@01PC3`0C3PX04@X;01D?2`0O4a004`h:014:2`0E3`/05`l@
018;2`0:1`L04`/;020F4@0c81/0;aXE0=[Qi@3JiNX=07MgNAT0oooo2P1UMGh0:@1YKgd0>BPV02lX
9P0]:2H0:2<Q01`K6P0/:BT0>3@b02/Z:00S7ad0:1hI01`F5@0O6aX08QdK01LE700J6a/06QHG024F
500I4AP04a8@01@C400B3``05A<@01@C400B4Q0040h;00h:2`0@3P/05a8@014>2`0>2P/04Ph<01@?
4@0@2``02@L8010;300K5A80:b0L02HI5P2V`<T0Y/C<00d0IGEn903oool00280oooo2P1kNGT07`1Z
H6H050L702HL6P0g:BD0;b8O030V8P0c:BD0?2/W02/P700Y71P0<1hI024D400c91l09APH02<H6@0R
5A008Q@J01X@3`0F30`06Q4@01T@400D2`/06Q4@01D<2`0J4A0050/;01P@400L50l06A0@01@;2`0<
1`L00`0=20P01P0H41005`l;01D<300X4Pd0PWYk0863P`h0NgUi6@3oool:07QjNP0C06m^L00I5A80
9b0M03DY9@0]8al0<RPT03@[9`0f:BD09QhJ02DJ5P0[71P06a8?030S7P0R5aL08ALH024D3`0O4aP0
5a0?018;2`0201L@400C01<;2`0I4A404`/;01P@400C2`/05a0@01dE400H41004P/;00X71`0<20L0
2`L800/71`0H41006A0;01@<300U4@`0/jVZ0;Vm_00>07QjNQP0oooo2`1gMgT0300/91l0:b<P03<W
900]8Ql0=BTU03<Z9`0a9R<091XG02@H5@0U6QL05a0>02dQ7@8081DG00l07a<>01dA5`0D3Pl03`X:
01D?3`0F3a004PX;01L?400B2P/05Pl@018:2`0G3a007AD@01L?400A2P/0100:1`L01P0H41006Q4<
01<;2`0Q3`/0c/[>0=[UjPh0MgMi6@3oool:06EeOP0X06n5R`1:C4T0;2PV02XV9@0X8b40<2TW02XX
9`0V8b<08A/J01lH5`0L61L05A4?028M6`0L5QP07AHG01XA3`0H4AL040h@00`:2`0A3Pl04Ph@00l:
300B3Q003`X<018>400?2P`050lA01PD4@0C3a403`X<00P720081PL01`H700P61`0D41405Q4<010;
300G3@/0UjR`0:>maPh0IGEn903oool00280oooo2`1kNGT09P0h;B`03@L7028I5P0d9B40<bTU034X
900l;2P0:QlP02DF4@0Y7AT06Q8?02LF4P0M514091@A01@;2`0G30d06A0@01L?3`0D2`/06A0@01<;
2`0I41004`/;02XI5@091PL06a4A01dD400G3a002`L700`71`0@1`L05a0@01D>3P0H4100:APC02HL
5P13;bL0[/3<3`1kNGTI0?ooo`/0N7Yj0100DeAC02LR800U71P0<2@P034Z9P0_:2@0?2dY02/Q8P0T
5Q80:1`H01PB3`0S5A406A<@024D400A2`/050/<0P0G41005@0D2`/0610@01<;2`0I4A404`/;02hJ
5@091`L06Q4A01dE400F3a002PL700/71`0@1`L06A4A01L@400I4A40;1TD034Q601W@C40f>7W07]o
O`0>07QjNQP0oooo301gMgT06`17>cP0:AhJ02dR7`0_:BD0;BLT03/]:@0]8R@09ADB02LK600H4Pl0
7a<@01HA3P0N4`l040X:014:2`0E3`l05`l@01<;2`0G3a004P/;01P@400B2`/0;aXE00X71`0H4100
71@@01H?400200X71`0901071`0J4A406Q4A01XA4@0^6A@0>b@J085?>@3Tk_<0Nh2200h0MgMi6@3o
ool;06EeOP0408bV/01OG5X0:B8P02DQ80809bLV01H0<2`[02/U:00R5aD08AXH01HC400G4@l04a4>
01PB3`0>2P/03@X;018>3`0D414040/<01<?400@2``050l@010;300U61D02PL8018?400G4a0050l@
0P091`P02@0>1`P05Q0A01PA4P0F41409APF03LU701]CCX0SibM06QkQ@0>06EeOR@0oooo000R0?oo
o``0NgUi0100>2d/00T4100T7ad0;B0L03`_:`0i;2P0=2PV024I5P0]7Q/06a4E01P@3`0R5100610@
01/C3`0J4Pl05`l@0P0D2`/04P0E30`050/;01D<300L51006a0@02HT;00R7Q/06`lB018;2P0F3`l0
618>01PA3P0G3a00;B0L01lG5@0Y5a<0C30U08b8Pa00NgUi6@3oool<07QjNP0@05=DD`0T7A/0:RHR
02XP6`0l;b/0>bdY03DZ9`0Q71P0;B4L01/B5P0G40l08A@@01L@400J4a006a@@01L@40804`/;00X0
50`<01<;2`0D30`071@@01XA4@0Y:SH0;bXX01hB5P0A2`/05Q0@0P0L51001`0H4140<B<M02LK5`0/
61@0E3<X0;Vj^P2GXjT03`1hNWXH0?ooo`d0MgMi00<0AcDb034Z9`0Y7QX00P0k;BT02P0g:bP091hI
02dR7P0M4QP05Pl@01lC400F3a006Q<@01dE400H4102018;2`0:01<;2`0B2`/04`/;01`D400H4100
;Bdm03Tc=00R51T04PX;01L?408081HA00L06A4A03@T7`0^7QT0;QTD05Lc:@3@g>D0Z<3?00l0MgMi
6@3oool<06EeOP0@08bV/01QEU@0<Bh/02<N700`:BT0<R`[038]:`0S8Ql09R8O01`D6P0C3a406Q<@
01<?400G51406QDA01D@4@D040/<00L061@@018?4@0Y;Ch0=3Hj020F7P0@2``05A0A008071HB00L0
5A4A02XR7`0[81`09ATF048^:02E/l<0QJVi00l0IGEn903oool00280oooo3@1kNGT03P0i:BP02PL6
02LQ7P0]81`0>2dX04<b;P0/9280:Q`E024H600G4@l06A0@01@;2`0J4@`06A0@0P0D2`/04`0H4100
4`/;01P@400C2`/05P`<02lZ:P0Y72L0@3H^02XR8`0K5QP0:B<P01hH5@0G4@h09aXH02XM6@0e:2@0
>24K085jNP1kOWh0401kNGTI0?ooo`d0N7Yj00h0FEMF02DP7@0`:2@0;20L034Z9P10<bh0<BPU02lN
5P0R6AL061<?01P@400B2`/06A4;01L@40804`/;01<0610@01<;2`0H41004`/;01D<300a;Bh0;1hY
04<f;00g;2T0:B0Q03`_:P0Y7aX06A<?02XL6@0]7QT0=bXV04DW7`2i/[80XJf`0100N7Yj603oool=
07MgN@0C081oPP17=c@0>bdY02/O700[9R<0?C4]03L[:00c7aL09AXG01XC3`0G3a004@X;01L?2`0F
3a004PX;018;2`0H41004`/;01P@400201<;2`0>038_<@0^7R/0AC<Z04Dc;@0g:BP0C3Pb03@T7`0K
4a00;1dI02hN6@0h:RL0Cb`S0=[IgP2gc]P@07MgNAT0oooo3@1UMGh08`2D/[`0HEID03`c<@0T7ad0
8R8R030_;P0f;bh0;b4J02@L600I5A004`l@00l:300B3P/04Ph@00l:300@2``0510A014;300D4140
4@/<00l:300X:bl09AdX03L]:`14>c@0>S0`04Dj=P0c:2<06QDB02DM6P0T71T0;RTW04D^9P2S]kl0
Sk2l0100IGEn903oool00280oooo3@1kNGT04021OWh0>2PW018:200/:2L0;R@Q04<d;`0j;RX0=BPS
01lF4`0S6AH0:1lN01/H5P0K40d06A<@01H>3`0G3`l201@;2`0@01dE6@0F3Ph06a<?01dC500`9240
?2XU01/B4P0T61<09ATD01dB4P0R5100;1hJ034P601A>2d0H5QQ08b=R140NgUi6@3oool=07QjNP0S
07]mO@1@Cdh09Q/E03@^:P0c:2@0@cD`03X`:`0i;RT081PE02@K5`0a9B8091lK01lC3`0K51005Pl@
01L@400D2`/04`/;01dE6P0F3`l071@@01/B4P0[8Ad0>BTR01@>3`0J4`l07AD@01D?3`0N4`l0;AhJ
038Q601O?Rh0Rgn:0:fh^01hOGd0401hNWXH0?ooo`h0MgMi0280LW9e040/8`0m<Bd0>2XW048c;`0k
;b`0?C4]02@J600W6aP0>BTU02hT7`0S5A0071@@01L?400H41004`/;018;2`0M5AX05`l@01dE400H
41009AdH03<V7`0>2``04Ph<01D@3@0?2``06a4>02`M6@0c8AP0Icl^0:VMZ`2ldm`0Mg]n401gMgTI
0?ooo`d0IGEn00h0HW9k08VV/01EAC/0?CDb038[:@0c;bh0<c0_03Pe=00T7Q`091`J03@Z9P0]:2<0
8AHC01TD4@805A0A0P0@2``04@0H51X05A0B01TE4@0B3Ph071/G02@Q7@0<2P`030d<00h>300<2`d0
5a4?028K6@0[81T0D3P[08bCX028ZKT0IGR10100IGEn903oool00280oooo3`1kNGT07`0b7QP05Ph;
02@K600o;bX0C3dh03lg=00Y81h07aHC02PJ6P0Z6QD0;B8O01lK5`0D3@h050/;024H700L5AL09alK
01/D600b9R004`lC04Hf;P0Z7b008a`J02HN6`0R6aL09QhL038X8P0V71/0DSHX07E`L@1ZIF/04P1k
NGTI0?ooo`l0N7Yj0200D4a902XV800R6aP0>B`W04/m>@14?SX0<BPU028I5@0U61T09QLC030T800T
81/050h?01<;2`0Q6Ad081PL02`S7P0M5Q/0?2`V01HA5P1>?3<0;b<T02PP7@0a9B00:R0K030T8@13
=BX0;b<P06E0;`2]Z:/0TI^T08:7Q140N7Yj603oool@07MgN@0O04<k=00T6QL0<bLT04Tk>019@Sl0
>bl/02LK600R5QP091@A03<U8@0Z8al05Pl@018;2`0R6Al08aXP02lV800Q61d0@S0[01/C6@1A?SL0
<bDW02lS800k:RD0<R<O03TY9@1A?S40=bTU0716=03@d=X0[LGC08J>R`0A07MgNAT0oooo3`1UMGh0
802?/;`0EEE=02@O700V8R80>CHg0452@P0m>CL09QhL01/E5`0N51<0;BDS02TU8P0F4A8040/<01`H
7`0P6b<0:2@P01lJ800g;Rd071HM03`e=00_9bX0<2PV03L/:00_9B80=B/W04Ln=00d;2P0FD8f0:>g
`P2C^/H0KhF;4@1UMGhT0?ooo`008P3oool@07]iN@0M038X8P0>20P06A@@03X[9`14=C00@3/o03HX
8@0/9BH0;bPV02HK6`0X9RD0;bL^02HS7@0M5QX091lX02lR7P0b;CL0<2<K02<L7011<Bd0=2DS03@R
7`0d91`0;RHT03l^9P1>>2`091`H09fBS@1kM7D04`1kNGTI0?oooa00N7Yj01h0D55>04e:D@0^9R40
=bXV03T^:P0j>Cl0?c<]048g=@16?ST0;28S02PX:00l=3l0AShf02dR900Z92h0=2HS03dgA00h:B40
9b0N04He;P0d9B80>2@O03PT6`0a:2D0Ac@Z05lo;`0[7QP0`kfj09NQY`1hOGdB07QjNQP0oooo4@1g
MgT07@2=Q9H0ACLb03<W900`9R<0=SDn04Tk>01GAT80FTm903<W:@0Y:B/0Ace>069DC@0m;2`0<2Lb
03LW9`17?Dh0?RdW02dR7`17=Bh0=B@Q03/S7`0k8aX0=BTU04dg;01Z@S40=AlH0=3Gg02X`<l0Mg]n
0180MgMi6@3oool@06EeOP0N08nY]P2V//H0CDI402PT900T8B40;C<o04I4A@1ECDT0EEIB034/;`0V
:Bh0@T9D061LFP0m<C80;BTe02lW:`10?Th0=Bh]02lW8`0e;R/0<2HU03DT8@0e8a`0<BTV040e;P1G
?S40>BDM08bY]P25[K`0IGR14P1UMGhT0?ooo`008P3ooolA07]iN@0J06EKH@0V7Qd03`T903DZ8`0e
=3d0G4Y504<h=P12>C@0=Rd]03Dc=P0o=3H0@SPd02`S8P0e;2h0:QlQ03<U8P0f9b<0>B`X03DX9014
:200?bXT03`/9@0o<bh0>BDM065;B01IEDdE07]iNAT0oooo4@1hNWX06`1/Jfh0EUaH02XS:00j<2X0
<c@l05]<B016@400@S`g03/e<`18A4D0Ccll04Hj<`0/9280>c8_02hR8@0^8Qh0;b<M03T]:@0e:BD0
ABLO04H/9014<RP0CS`e040W7P1QC4d0Q96C0:Z`/`0D07QjNQP0oooo4P1gMgT06P2;TY00BC]5040c
;`0a<CX0Ed]:04Y4B013?CX0@c/h05U@DP1LAT40BCT`030T8P12=Bl0<B<Q02TN6@0Y7QP0>BdY03DY
9@159Qh0C2dT04`e:`1J@SX0AbLO05a9C`2X`<l0a]OQ501gMgTI0?oooa40IGEn01/0LXV>0:?3b@1L
F6D0>SDf02X^=@0oA4/0@TM?03/m?`12A480E5=F0517@P0n>3@0<R`Z03`e;`0]9RH081/G028M6P0`
;2/0;BPV03PV8012;BH0A3D^0591>P10:B80@ci909W0eP2I^/H0501UMGhT0?ooo`008P3oool00`1k
NWX0Ngin07]iN@0@07]iN@0G038X<00V7Qd06Q/T02TS9P1JC4H0DDeB03df;P13>CD0@cTf04Hj=P13
=SH0?cH`02lZ:`0h;R/0;2PS03ld=00o<c00>BXS04Ha:P0i9B40OVMX04Tl<@13<SH05P1kNGTI0?oo
o`0307QfMP1hOGd0N7Yj0100N7Yj01P0D55E079eL01UIg<0>c@k05]<B@1UGfX0DdQ504ho>P14>SD0
AS/h04hn@01B@c`0?cLe0591>`11=bl0CD0m0591?@14=Rd0ASXb03<V8`26M7`0OhB208F:SP2GWYdE
07QjNQP0oooo00<0Mfma07MgN@1gMgT04@1gMgT05`2g`;d0[:Ri04i2C`1JBT/0Mf]n06UFF`1I@Sh0
AcPd04Lk>01IA4P0Hda70512?`1ZD4T0E4@j05U8A@1SC4L0CT0f04I0>00`9R@0Q7R90:g0bP2ldm`0
Z;Nh01D0MgMi6@3oool00`1UJgD0IG9k06EeOP0@06EeOP0H08nY[@30i>P0^/[I055?HP19ATl0Jf^3
06IQK@1BADD0@3Xi03hl?01BBDl0Fdi>059:B01TEe<0DdY104i9AP1KD4h0B4Ho03]1>`0Z:2L0G6Ah
0:KAi02ci>h0QJ>Z5@1UMGhT0?ooo`008P3oool00`1kM7D0NgUi07]iN@0B07]iN@0C071ZL00b;CX0
BC`o05YAG@19>d80CT0c030X:P0a:RP0DD9404dj;`1:?3P0DClj04Hj=016>3@0Bc@[04@h<021NW/0
8ATH05mAE`0H07]iNAT0oooo00<0N7Yj07QmO@1hNWX04P1hNWX0501bLWH0EUaO08F2O@22Q8T0IF1X
07QdK@1HEF40?S]20517D016>S80A3/h04`n>P12>SD0A3Tf048`9`0k<b/0Y9jQ06mbM@2KVId0R8n<
5`1hNWXH0?ooo`80Mg]n501gMgT01P20QH80]kbd0:>^[`22Oh/0WZ2Q081mU080CTQK00/0@CPd044h
=P17>cP0@CPf04<g=P0j:R80=BdU0;Nf_`2g`<X0a]?H08nLV@0G07MgNAT0oooo00<0IG^506EhP@1U
MGh04P1UMGh02P1[OhD0UK2]0:c=c02E]kH0PiRZ09Vd``2:V;@0DUMa03m8G`0f>Sd203Ph>@0803Xj
?00i=SP0;BPT02d[9`2<WZX0`nSd0:WAe@1eSi@G06EeOR@0oooo000R0?oooaT0NgUi00<0L6Ye07]d
M@1UFfH00P0m=d@0200h;B`0>2/Z03Pb<00h;B`0<RPW02dN600]8ad0NgAe6P1kNGTI0?oooaT0N7Yj
00h0LW9h07j0NP1/KW<0HVQY07QjNP1eMFh0N7Ad07QmO@1hNWX0MGQh07EeL`1hOGd0Y:>W07QmOAT0
N7Yj603ooolJ07MgN@030825OP1gNgh0Ri:;0080[K:[00P0/[6g0;:l`@2b_<40/[c10;O0aP2lbM<0
_<G?07MkOQT0MgMi6@3ooolI06EeOP0>06]oP@1[PXD0LXb>09Jc[@2]b/<0/=7B0;?=e`2ce=l0/mOR
0;KKi@2mi?40`>Og09:`_01UN84I06EeOR@0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo00180?ooo`900000FP3oool2@00005H0oooo0T00001J0?ooo`900000
=P3oool004X0oooo00=000000?ooo`3oool0F@3oool00d000000oooo0?ooo`1E0?ooo`03@000003o
ool0oooo05T0oooo00=000000?ooo`3oool0<`3oool00380oooo00=000000?ooo`3oool02@3oool3
@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`0e0?ooo`=000000P3oool0
0d000000oooo0?ooo`0:0?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000003oool0
oooo0300oooo0T0000040?ooo`03@000003oool0oooo00X0oooo0d0000020?ooo`9000000`3oool3
@00000D0oooo00=000000?ooo`3oool0;@3oool5@00000030?oood000010000000@0oooo00=00000
0?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`0]
0?ooo`00<@3oool00d000000oooo@00000090?ooo`06@000003oool0oooo@000003ooom00000103o
ool014000000oooo0?oood00000n0?ooo`06@000003oool0oooo@000003ooom000002P3oool01T00
0000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000>P3oool01T000000oooo
0?oood000000oooo@00000X0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003o
ool0oooo@00003L0oooo00=000000?ooo`3oool00`3oool01T000000oooo0?oood000000oooo@000
00/0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0oooo@00003D0oooo
000a0?ooo`03@000003ooom0000000T0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo
00A000000?ooo`3ooom00000?03oool4@00000<0oooo00=000000?ooo`3oool0203oool01D000000
oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood00000i0?ooo`9000000P3oool0
0d000000oooo@000000:0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003o
ool0oooo@00003L0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`030?ooo`03@000
003oool0oooo00T0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A000000?ooo`3o
oom00000=@3oool00340oooo00=000000?oood0000002P3oool3@00000040?oood0000100000@000
00<0oooo0d00000l0?ooo`03@000003ooom000000080oooo0T00000<0?ooo`=0000000@0oooo@000
0400001000000`3oool3@00003P0oooo00=000000?oood0000000P3oool00d000000oooo@000000;
0?ooo`=0000000@0oooo@0000400001000000`3oool3@00003L0oooo00=000000?ooo`3oool00`3o
ool00d000000oooo0?ooo`02@00000d0oooo0d000000103ooom00000@000040000030?ooo`=00000
=@3oool00340oooo00=000000?oood000000303oool00d000000oooo0?ooo`150?ooo`9000000P3o
ool00d000000oooo0?ooo`0=0?ooo`03@000003oool0oooo0400oooo00=000000?oood0000000P3o
ool00d000000oooo@000000=0?ooo`03@000003oool0oooo03l0oooo00M000000?ooo`3oool0oooo
@000003ooom000000080oooo00=000000?ooo`3oool03P3oool00d000000oooo0?ooo`0m0?ooo`00
<P3oool00d000000oooo0?ooo`0:0?ooo`900000B03oool00d000000oooo0?ooo`03@00000`0oooo
0T0000130?ooo`9000000`3oool00d000000oooo0?ooo`0;0?ooo`900000@03oool2@00000@0oooo
00A000000?ooo`3oool0oooo0d00000=0?ooo`900000?`3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool008h0oooo0T00001Y0?ooo`900000U@3oool00900oooo
00=000000?ooo`3oool0J03oool00d000000oooo0?ooo`2B0?ooo`00PP3oool3@00000<0oooo0d00
00030?ooo`=000001@3oool00d000000oooo0?ooo`05@0000080oooo0d0000050?ooo`03@000003o
ool0oooo00P0oooo0T0000030?ooo`A000002@3oool3@00000<0oooo0T0000020?ooo`=000000`3o
ool2@0000080oooo0d00000=0?ooo`=0000000L0oooo@000003ooom000000?oood000000oooo00A0
00000P3oool3@0000080oooo0T0000020?ooo`900000S03oool008<0oooo00=000000?ooo`3oool0
0`3oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool00d000000
oooo0?ooo`030?ooo`03@000003oool0oooo0140oooo00E000000?ooo`3oool0oooo@00000020?oo
o`03@000003oool0oooo00H0oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood000002
0?ooo`05@000003oool0oooo0?oood0000000P3oool014000000oooo0?oood00000?0?ooo`09@000
003oool0oooo@000003ooom000000?oood000000oooo00=000000P3oool01T000000oooo0?oood00
0000oooo@00000H0oooo00=000000?ooo`3oool0R@3oool008<0oooo00=000000?ooo`3oool00`3o
ool01D000000oooo0?ooo`3ooom000000080oooo00=000000?ooo`3oool0203oool014000000oooo
0?ooo`3oool4@0000140oooo00=000000?ooo`3oool00P3oool014000000oooo0?oood0000080?oo
o`03@000003oool0oooo0080oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?ooo`3o
oom000000080oooo00A000000?ooo`3ooom000003`3oool024000000oooo0?oood000000oooo@000
003ooom000000`3oool014000000oooo0?oood0000020?ooo`03@000003ooom00000009000000`3o
ool00d000000oooo0?ooo`2:0?ooo`00P`3oool2@00000<0oooo0T0000040?ooo`=000002P3oool0
1d000000oooo0?ooo`3ooom000000?oood0000004`3oool01D000000oooo0?ooo`3ooom000000080
oooo00=000000?ooo`3oool01P3oool3@00000<0oooo0T0000030?ooo`03@000003oool0oooo0080
oooo0T0000020?ooo`A00000303oool2@0000080oooo0T0000000`3ooom000000?ooo`020?ooo`90
00000`3oool3@00000040?oood0000100000@00000<0oooo0T00002;0?ooo`00P`3oool014000000
oooo0?oood00000D0?ooo`03@000003oool0oooo0080oooo0T00000A0?ooo`03@000003ooom00000
00<0oooo00A000000?ooo`3ooom000004`3oool00d000000oooo0?ooo`2m0?ooo`00PP3oool5@000
0080oooo00=000000?ooo`3oool03P3oool2@00000D0oooo00=000000?ooo`3oool0403oool01400
0000oooo0?ooo`3oool4@00001<0oooo0T00000I0?ooo`03@000003oool0oooo0:<0oooo003o0?oo
oi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {194.313, 0}} -> {-0.309124, -0.0488477, 
  0.0115746, 0.0115746}, {{26.6875, 107.063}, {190.063, 
  109.688}} -> {-35.0999, -5.86462, 1.00336, 1.00336}, {{115.063, 195.438}, {
  190.063, 109.688}} -> {-123.772, -5.86462, 1.00336, 1.00336}, {{203.5, 
  283.875}, {190.063, 109.688}} -> {-212.507, -5.86462, 1.00336, 1.00336}, {{
  291.875, 372.25}, {190.063, 109.688}} -> {-301.179, -5.86462, 1.00336, 
  1.00336}, {{26.6875, 107.063}, {101.688, 21.3125}} -> {-35.0999, -94.5367, 
  1.00336, 1.00336}, {{115.063, 195.438}, {101.688, 
  21.3125}} -> {-123.772, -94.5367, 1.00336, 1.00336}, {{203.5, 283.875}, {
  101.688, 21.3125}} -> {-212.507, -94.5367, 1.00336, 1.00336}, {{291.875, 
  372.25}, {101.688, 21.3125}} -> {-301.179, -94.5367, 1.00336, 1.00336}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After setting a mouse cursor on a following image, twice clicking the left \
side button of mouse animates the facial changes depending on the lighting \
angles. This is only effective on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Do[Show[GraphicsArray[{color3DG[[i]]}]],{i,rotation}];", "Input",
  CellLabel->"In[85]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B797972503C
816D607B69657B71697B655D7B71697B6D657B6D657B6D657B655D7B6959726155775D526E5146\
73594D6951466F55496F55496F55496F55496F4D4266513E6B51476B513E6B5147
92ABB87B79797B79797B79797B79797B70717B7E7E7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B75757B7E7E7B79797B75757B7E7E7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B797976533F
7B69617B695D7B716E7B655D7B71697B6D657B695D7769607C69607C6558736054745D4F745549\
74584B6B514574584B6F55496F55496F51456F51456651426B51456B513E6B6160
92979C7B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B74757B75757B7E7E7B74757B79797B79797B75757B7E7E7B75757B7E7E7B79797B7979\
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B7979775440
816D647B69617B6D657B6D657B69617B6D657765556B615983605178584F6F5B4C6F5C4F6F554A\
6F554A6A4E436B51456F54476F54476F51456F51416B51476B51456B51427B8D96
7B79797B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B70717B7E7E7B79797B79797B79797B74757B79797B74757B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B797976503C
7B6D657B69617B69617B6D657B69617B695D76655D6560596D584B764D4E6351406D55496D584F\
6D584D694C426654456B51456B51456B51456B51426F5549664D426B514592ABB8
7B79797B79797B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B533F
7B69617B69617B69657B69617B69617B695D7B6D657B686176605577585272514B72554772554D\
6E4E4971554B5F433C6A50456A5D51664A3C6F51456F54476651456F594D8CA2AF
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B5743
7B695D7B69617B695D7B69657B69617B6D657B69617B6D657B6D65766055765B5272554B775852\
72554A73594D6D4A47694D436F544A6A59516B4A3C6F51456B51457C716D818D92
7B79797B79797B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79796F59518C7A68
7B69617B695D7B695D7B69657B6D657B69617B6D657B68617B6D657B655D7B695D765D4E765952\
72584E72594D6E4E496D5546694D426B574D6B51456F5145665145888D96818383
7B79797B79797B79797B79797B79797B79797B79797B74757B79797B79797B79797B75757B7A7A\
7B7E7E7B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B7979463830AD8775816D60
7B69657B695D7B695D7B69617B71697B655D7B6D607B716E7B69617B69617B695D7B655977554E\
775C4E7759516E55456F4D456F55496A4D4266514574594D6A4E43879DAA7B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B74757B7475\
7B79797B79797B7979
7B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79796B61651A0E09E1BCA37B6959
7B6D6A7B655D7B6D657B655D7B6D657B6D657B685D7B69617B695D7B5C5D7768547864557C6058\
775C517359516F51437351466955496B4D3E6B51476F574A6F544792ABB87B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B75757B7E7E7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797F7D7D261712715C55816D647B6961
7B6D657B69617B6D657B69617B69617B6D657B71697B655D7765557C5555775C4E6E5549785C50\
785C50735C4C6951497451456F54476A51426A51456651456F5549889096818D92
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B75757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79793321197B6D657660557B69597B6965
7B69617B69617B695D7B69657B69617B6D657B69617B696172453F775750734E44735146735146\
736A546F54456F54476F4C416B54437451476F5145665141744F4675685D92ABB8
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B75757B7E7E\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79796B61612B231C816D617B69617B69597B6965
7B69617B65597B695C7B69607B6D697B6D657B5C597B68607239377340386F342E7949466F3C34\
7951486550416F56466F51416B4C417454476F51456A51426F493E6A584B7E746B
8CA6B47B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B74757B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B7979241815DAB199816D647B69617B695D7B6965
7B695D775D527C60548172647B69657B6155774547784E4474524D682E237D594F79404065241E\
7538306F493F6650446B5B486B49366F54497451476F51456F4D426F54476F584B
8C9CA17B83887B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79795A4C4D3129219783737B696177615181766D7B655D
7B61516E5949744F468C7871734941471A0EB78378733934715C545F4741632D23675646623329\
703C3B5D2A20883A3267614D6F4F366F50466F584B735546694A426F55496F5145
7E71658C9CA17B83887B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B75757B7E7E7B74757B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79791F1312B98F75816D657B695D72554B817A757B6961
7B594B6542316B473D521915A08E8543171670504A7044427650497B71686D2E27654B4A513429\
4C38343C1B144E2115944A3874654B74494173605273594A6D5143694D456F5145
6F584B7E889A88847A8183837B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79796F69720D0704DFB595816D647B695D765B527B69657B6961
734A3C5E3E2A662C23300F09A882758283747C6B678192947B69617B726C6E514A828886735549\
656969301E1B2A26243C1811994E38795F507E64517761586E5143694E436F493E
6F584A6B7980756C6E8888968C8D837B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79794638303B24216348419788737B695D7B61557B695B7B71687B6961
693D345E4D3D5B3632321116703D4072594B73554D7D6E65825750746655744138794C41704B3E\
838571663F34584A492B251F410E06A56F5E7E6B517C695F6E5143694D456B4D42
7455496A6459707A845C556592978D7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B75757B7E7E7B79797B79797B79797B79797B79797B7979\
7B79796F65690D0805271511D5A2907B69597B65597B5955776955816D607B5C59
694A3A674736928C847B6D617B5755765752705651704F4A76464367413E6C3D3A68342E683837\
694F436E3B375C3A32492E212E130F6D2E21978066826C5E6E5543694A42664C41
74584A6F5B4E413028BFBFCF7776768183837B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B74757B79797B79797B79797B79797B79797B79797B7979\
7B79795F535F050900000B147C7267816D607B61557B605D7659557B76607B5B59
69463D5F3C31887D708176717B6D657B655D7B6D657B6D657B5952725C4B775C516E5546735146\
654A3C753F3E6B40365C2F2C4826244B252774563A83675F735946694A42664D3E
7451476F584B191818B4A6A08C8D927B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79796A57567B6961765F55725D4E7C695C81695D7B69617B5B597B6D617B6559
6D514468433A7456498883758176717B68617B655D7B71697B575272514873514573604E6B4D41\
634C417048386B4A3D6B4E3D6B473D67483D745849795C4F73554665493E6B5041
6F54436F544A141212C7BBC586887E7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
77717281604A7761597863546F6D718C69527B6D657B6D657B68617B6D657B6861
76514B6D554468433A7C7061817A757B71697B5955777664816D606E4D44734E436B47386B5B4A\
5E4136674B3867453C6B4C366242386744347D635773584B6F514566493E6B4C41
6B54456F5549050608CEB5B2979DA07B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7660567B69616E51436F554672726E815C597B76697B71697B6D657B6D657B6D65
7B575276554B694A3D78544A86837D7B71697B57557665597B695D6D4D446E51436440376A5145\
5E3C31674738674B3F6F4F3E6A493B694E4073594D6F4D426F51456A4D4266493E
6B54436F544A020607573F37E0DCDD7B7E7E7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B574377655D623C2E82766B7B5C597B695D7B69657B71697B716D7B685D7B6D65
7B65597B6052694A3D73514382766E81716D7B695D7B6D6A7B655D72554B6A4A3F6F51456B5145\
66433966463462423A6F524678554D775C4E6E55496951476F4E436B4D426B4D42
6B51426F594D0D14131D181751423DE0E3E47B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B6961\
7351426F443A665643797A6E92645D7B695D7B69657B71697B726D7B6D657B6D65
7B655D77655572554B725C4E7B695D7B6961775C55817A6C7B5C5D6E5D4669463E6B5043674C3F\
6F4F3B5E403470473A745B4F79594F7C60546E55496955496F51456A5145665141
6F4C436F64555C3C2F3A2C292D47537B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B4D44\
693F3461322C6B5E4D77766B816D657B6D617B655D7B71697B6D657B6D657B6961
7B695D7261557B5D5272695C816D657B6D617657527B695D7B554E69514365433967483C634438\
6B4A3861453A6F514673594D735C517C5C516E55496951466F4D426F4C456A5042
6B4C3E74645A623C2C6F524996B7C37674757B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B6D657B544E\
6939345D362C745F54877A6C7B69657B71697B68617B69617B6D6577695C816D64
7B5C597269557C5C5177695B81716D7B6D607B69657B69617B554E694D3C61493E62453A62453A\
5E493E6F4D3E74584E795C4F77605473594D7355496955496F493E6F4C436B4C43
6B514174605E653C2E665145838D989297967B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979734D3A704D41\
583B2D7346368D74648676687B69657B6D657B6D657B695D7B655D7265597C6058
785C547C6158776555776155816D647B69617B69617B69617758526E433A61463C62453A67483C\
664F436B544578584F735C4D785C50735C517351466951466F4D436B4A3F6B493E
6B504574645B673122746F62664A4492BBC77B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B797965301D341F14\
55352B462A24BD937886766D7B69617B695D7B69617B69617B6559766559765B55
6D514773554D7463518271637C6D60816D697B69617B695D7259526A4A3C62413E674B3663443A\
7452466F584B745147745B4E79584F6F5748745B4E6B51456F54476B51456B493E
6B4C476F5B4D5E33237457486F423C92BBC27B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B716D633125201A13\
2C1F19392421BD937886766C77655D816D657B69596F59507E675C7054497D6152
795750794D48785E4A795E507E70618676717B69617B695D72514B64473A5E3F366744345E483F\
704B3F6B564970504379584A795C526B4A3F74584B6A5146664D426B51456B493E
6B4C476B54454B2A1D65322183534097C0D17B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B797977594B6E4A46170805\
29191334201CDAA2857C6D607B65597B6D647B695D67514759463B563E3246342F
462D276935258755446A3527724230A89E8B81716D7B696172554B64433A5E42316349365E3E36\
75574A655146604D436A4D426B524A6350417D5C4E6F5549664D42634C416B4C41
7451476B51453F231B52261C79443397CAD67B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797F7D7D70453365433B070C0E\
18100D311A15DAB1927B695D776155816D607B695D76605A513C31574944171A18
2115123F20155940387336276A463D82766781716E7B6D69725444644037563B2E6348323D140C\
947058705038664B415F3D2E825A4D634F437958466F544A6B51455A453A634F43
745047634C3C3F231D6234267E473F96C1C97674757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B7A7A7B7E7E7B75757B7E7E7B79797B79797B79797B79797B79792A100CDD94766D554A191414\
13121625140FE9B9997C695C7B695D7765597C695C816D6967504373514A302F2C
1D2124221D193C362E664A3E78554B7C7163817A757B726D72594B64433A54392C553E32371C18\
5E4B464832271509086E3A2A5A463843281D7F54446D46308356435E4F46634C41
744C434E3E32311C17572F24A1685896B6C37674757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B75757B7E7E7B74757B79797B79797B79797B79797B79792D1814271612430C057B4937221419\
1C14102B1814DFB595776559816D656A493F796A578C7F7976685D70534A61453D
5F473A5A463A5A40346E5946775951776558817A757B6D65725147644E405E392B59463658332C\
524D4A312D2B02060848221744322D291D186A41306343347554415E453C5E4F43
7451412C1E1C31201744231AA4543F9DCFDB7B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B74757B79797B79797B79797B79797B79797B79797B79790500002F201826121032201B120A0B\
2C1A152D1814DAAE8F7B695C776960704E4E5F463A6B4B3F826959735B4D67463E
5F372B6B4531744635764835977D6B826E6081716D7B6D6072514B6455495E3C30624732634C38\
74544961463F091B2124211F2E25212E2A255D453A6146346350466F4D3E614D45
634C3E1A13102918144423198E3727A3D9E47B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B797906000021100C2015112515111C120F\
1F14103A2521C590748C726476695D7B69656A574D513B32523631463F3961433A
3A2D264739304D332A65463C776D607B69617B69617B5C5572614E6451465E39364E2C1C603B28\
82694A7454496B5143654A424E3C314C39336F4D3E63493B6B4C4563503E745443
4E3D34100D0B201410824D3D522118AED9E47B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B75757B7E7E7B79797B79797B79797B79790A01001B0C091D14101C1410110707\
2516113A2A25A6765D987A698171647B69657B6D65766459654845493F41654845
5A3F385A443C543B356A4A3F72615581716E7761557C5C59775D5268554A6345443E2824321B1A\
4930204C2F20945A448362526B513E614D41634C4167483C5E473D75524A6B503E
2C1F1816100E27201C8E48335224194D4946DBDEDF7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B74757B79797B79797B79797B79797B79790D04022316131E120F1F1410140E0A\
2414103A2A25996650927A6A8171647B69657B71697B6D657B716D7B6C657B6C65
7B685D7B716D7B685D7B685D7660527B6D64766559725D52775C51726155725C52674D47372C2D\
2B23211C1E1B41251C4C2F217242335D48386A4130633F307959506B4C4167483C
140F0D1E130F281B1A3F140D591E12343330D5D9DB7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790A05042F2320140F0D2214101D130F\
2518183829238559439776658C7A6C7B69617B6D697B71697B726D7B76767B716D
7B6C657B716D7B685D7B6D657B685D7B65557B695D72594E775C52775C5177655877585568594E\
644A434436322C29272925223F2A2343362C5E42364C3F367044436752415E4236
120D0D1E130F1D14111B0F0B391A15443530D5D9DB7B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790F060431211A1F18161E120F25100B\
291A1636241B5D4033A0725D8D7E6E816D607B69657B71697B716D7B6D657B7676
7B716D7B716D7B685D7B6D657B695D7B69617B655572594E776558775C52775C51775C546E594D\
6D55496451465C4A3F5A4A404939314E3C34614339614C4566463E5E483C3F2E23
1A12111E130F27181417120E2514103E281DB4A2A79DA6A57B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790D0401352824231815251612170E0A\
2715112716114E2F227F5238A88E7E8171647B69657B71697B76767B6C657B6D65
7B76767B6D657B6D657B6D657B65557B6961775D52775C52775C51776154775C51775C516E5549\
6F51466F55496A554A6B4D426F514566514563493E6B4C436B4C415A3E32261B17
170E0A28191919100F19100B120808381E17876963B3C0C27B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790A03012F25232C211D251815211511\
1E130F291C183F2B2557382AB07F698C7A6B7B6D697B6D657B76717B76767B6C65
7B716D7B685D7B6D657B6D657B6559776555775D52775C51775C51775C51735C5178594D73594D\
6951466F55496F584B6A51466B4D426B51455A493E6B4C415A483C3C2C251D1411
211916130B0B191010100707181010271510725851BFC5C77B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79790E05023326233326232A1F1C251511\
160F0B301B16412A20553B2D8C5B459281738171687B69657B6D657B76717B7676
7B716D7B6C657B685D7B6D657B655D76655572594E73584E78594D7C5C546E5C4D73554973584F\
6955466F55496F51456B54476B514567483C664F436344384E3A32342119211512
18100C170F10140B0B170F0B1810102C1914A8A6A57B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B75757776760D09073325213729252F221F1D110E\
251A17291A1735231D6A3F2D7E503F8D78688676687B69657B6D657B6D657B7676
7B716D7B716D7B685D7B6D6577615581695C72594E725C5172594D73554D73594D7351466F594F\
6F51466B4C456F54456B51456B514566463B634C415A3B3047332A231914251613
17120E1B13101A120F170F0B1C14102E1915F4FAFB7674757B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B7475766F700804033C251D2F2523352824261C1A\
2519162D201C3120185C44386D3F2F976F5E887E6E816D697B6D657B71697B726D
7B726D7B726D7B696177695C7761557C695C77554B735949785C5373594973594F73554A695549\
6F55496A4A426651456B4C416B5043634C415A443852362A3924202517121C1410
18100B191010150C0B0C0807180D0C462923DBE8E97B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B7979070302311F163529273528242B1F1B\
27171333231A3124204B3A2E512B2194614D928775816D647B69617B6D697B6D60
7B6D647B6D647B696576655572594E77605473554973584973584F735C4A73594D73514569584B\
6F51456F51456651456B493E67483C56473B52382C3924203120181D120F1B1410
1F130F160F10130B0B120B0B291814968D8D7674757B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B7979120908261B173325213C29252A1D16\
281D1B2B1C1736272333241E412B267C493596765D8D7E717C695C816D647B695D
7B695D7765597C6960816D6072554B7355497359496F4D4574584E74584B79584B6F4D426F5447\
6F4C456B54456B514167453C63483C4E3E323F241D2C1F1821141018100B191010
241410160F100F0707150C0C321B15F1F7F77B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79791C120F291F1E33262333242031221D\
2317172A1D1831231E3528243120184E2D21855E47926F5D836B5C8271637C695B
7C6D607765597761557C695B73584E6F4A3F7457476F51456F4F436F584A7454476F51456B4C41\
6F4C43674C3F674F3F5E44385A3A2E51392B2A1C162114101C1410170F0B140B0C
170C0C0C08080C07072C1915311C14E0EEF37B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79792A1E1B1A120E3328242F221F392C28\
261914251714372B272D201C3828232A1A165C43336340338C5542927563755B4D
7E6B6179645779604F7E64586B51455E4034744B3D79503D7452496F50436F483A6F56496B4C38\
6748416344385E43365243364228213E23192518141E130F17100B140B0B140B0B
1007070B0707140B0B2816118D7A768183837B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79795F555D110807261C19342521352723\
291F192516163A251B2F24213C2E2A2B211E35272144312B5F382B714835614943
624B3E784B3A775B4A7355465C3F3658392A5736286D442E7344376F4E3A75473862463B623F2E\
6B4233634436513B324C30253920182D18141F141018100B140B0B1007070C0808
0C07070C07071F14102B1814E6E9E97B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79791F16131A130F3528242F2623\
2C211D18110E37241E3C2E2A392C283A2E2A352A273F322A44322A453026412B28
412A1F492B255A3528593E323E2B27462D254E2B204E2F1E532F2566412E633D2D57362858382B\
4F2E2155382E472B233C251D2917132A1C18160E0A18100B130B0B0F07070B0707
0C0707211410171010664A43AEBBBD7B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979443B440F0A072F2420312521\
312420261E1B3226223C2E2A3D302C3528243A2B27412923482F2436271E312523
2C1C173A2723301914412D2735252131211D321A1534201A341B153F1F1843291C3E251B41271C\
371B15391E18321C16301B151C14101B110C140B0B150C0B140B0B0B07070C0707
21141821140F2C2220AEA2A07B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B7979706A70180D0D1B1310312420\
3528242F221F40322E2B1E1B44332E2B1F1B3A2B27442E2635242133221D312420
281D193C29261E14142E241E2C19152A1A152114101F15112514102E19152C1A15241510271611\
2514102E191521141023141017100B18100B130B0B140B0B0C07070C0707140B0B
2E1E1B2516128788887B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979463B3F120C09302824\
3528242F221F2E241F3C2C283D302C28211E2F201C462A1F271D1A31231E2F211D
21181C34251E2316172A1A152114181F140F1D141018100B1F141020141020141019100B160C0C\
1B110C27151118100B160C0C19100B181010130B0B0C0707140B0B19130F251917
2918147B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79796A6066140707261C1A\
3729252F221F3026223329253C2B272B201C291C18301E1921141033241F251818
23181922151022141A1A100F160C0C1A1110191010140B0B1A1110150C0B1A1110140B0B181010\
1C140F191010140B0B0C07070D08080D08080D0808181010170F0B150C0C28120D
827A7B8183837B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979382D2C0D0707\
2219163425213329253128243C2C282A1F20251611291D191A120F2716121D1411
241411140B0B170C0D191010170F0F140B0B191010130B0B191010130B0B2A19150906071B1111\
1D1410170F100B07070C0707100707171010150E0E181010291813261C16432F27
AEC0CC7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979382D2C\
090404241F1D2D201C3C2F2B392C283428262119162D1E1B1B111518100F221410
1810101B130F1A120F170F10140B0B140B0B150C0C140B0B150C0C1C14101B101026242C221E1B\
1B0F12120B0A160F0F18120E18110E170F102D201C1F17152917134C30258C8883
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
3929280A070627211E2D201C382D2843322E2C24222A1C1521181817110F191010
140B0B1A110C191010140B0B140B0B181010130B0B181010130B0B160C0C2F2A2A291C2740362E\
2A22231B16182923201E181517110E271A182A1D1935282438211B817A7A7B7E7E
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
817E7E382827120A082C28272E242143342F3A2E2A3528231F1613231916281F1E
1B18161B100D191310160E0F170F0F140B0B140B0B1D1519160E0E1B130F1D13143024213C2A25\
1B12122418132519141D12122214102C1E1A31201851382D6058618C8D887B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B7979321E18160E0B241B183F2F2A4C3D383F373429201E1F1613281A1A
2A1A152D221F1F1B17140D0E140B0B21181C1C1517271F1B1B1418322620130F1346362E2A1F20\
231C1A261E1B221B17261E1C322822261C1B5236287570716A656B7B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79793228220E08081914103A2B27443530403B3F3628212C2526
2F2826261B1B2826252F272E26231D1D161A241F282F221E322D3730231B231C1C41312D342523\
34221F34241C2E26243F2E264E382C241C189D928D7B74757B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B7979655B61261E1D0F0909352A2335343D5C4A45433836
423934362D2D3533363F34364238342C2322352C2E2A1F21332522362723392C28352824442820\
3F2A243C2C253F332E39251D614B4859554D7B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B7A7A7B7E7E7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B7979322830261E1D1A1B242923265A4C46
514D523D362E433935433936463A364336363F36302F2A2B382E2B2C28233F34343F3330392A23\
46312A3925217E6768493C314332367B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B7979706A70322D3A493C3F
5A515D493B424E403330282A312A285142444D3A2F4A3C38513F3A463A344638344B342B443830\
817A7B2119185F51577B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B7979706A757B7475655B663D37443D3744382D2C382B2A383230382D2C3228272D1E182D231D\
7B74757B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979
7B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B79797B7979\
7B79797B79797B7979
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH07]iN@@0LU0l1021
KF0407]YI@@0Ng5Y101kIEd307]aJ@`0NfeU101kIEd407]YF@@0LV5E0`1gGE8406iAAP@0LeU=101Y
DDH?06mEB@@0Kde2101VDCh406]AA`@0Je4n101[DDL309:[^100NgUi101kL74307]nOR<0NgUi5P3o
ool001@0ooooF01kNGT4079@?0@0PFeP101kJFD407]aJ@@0NfEM0`1kLFT<07]]I@@0NfEM101kJET4
079QE@<0MeeB101^DDH407=IC@@0JE563`1_EDT406m=@P@0IU4n101[DDL406]A?P@0Je570`2BZkP@
07]iN@@0Ng1a0`1kOWhS07]iNAH0oooo000D0?oooeP0NgUi101bD3`4085]H0@0NfUU101kLFT407]U
G@<0Ng5Y301kKFD407]UG@@0NfUI101bHED307MMDP@0KU56101cFDd406UAAPl0KeE9101_CD8406IA
?P@0Je57101[DCh406]AA`<0TZ^h401kNGT407]`L@<0Ngin8`1kNGTF0?ooo`00503ooomH07]iN@@0
LU0l1021KF0407]YI@@0Ng5Y101kIEd307]aJ@`0NfeU101kIEd407]YF@@0LV5E0`1gGE8406iAAP@0
LeU=101YDDH?06mEB@@0Kde2101VDCh406]AA`@0Je4n101[DDL309:[^100NgUi101kL74307]nOR<0
NgUi5P3oool001@0oooo101kNGT407]eM@@0Ngin0`1kNGT407]eM@@0Ngin8`1kNGT407]eM@<0Ngin
5`1kNGT407IC?`@0NfUQ101kJEd407]aKP@0NfEM0`1kLFT407]]I@@0NfUM101gJF0407aYH0@0O6EH
101cH5@307AMC`@0M5E9101dF4/406]AA@@0M5Q;1`1_EDT806mAA@@0IU52101[DDD406]A?P@0Jf5P
0`2BUi`@07]iN@@0NgAe9P1kNGTF0?ooo`00503oool407]iN@@0NgEe101kOWh307]iN@@0NgEe101k
OWhS07]iN@@0NgEe0`1kOWhG07]iN@@0MU<o101kJF4407]YG@@0Ng5^101kIEd307]aJ@@0NfeU101k
JEd407MYH0@0O6UP101lIEP407=PE0<0M5e?101dEDT407AHB`@0Je55101dF4/706mEB@P0Ke55101V
DD8406]AA@@0Je4n101[HF0309:GW100NgUi101kM7DV07]iNAH0oooo000D0?ooo`@0NgUi101kMGD4
07]nOP<0NgUi101kMGD407]nOR<0NgUi101kMGD307]nOQL0NgUi101fDcl407]YH@@0NfUM101kLFh4
07]UG@<0Ng5Y101kKFD407]YG@@0MfUP101lJF0407aUF0@0Lf1D0`1dGDl407AEB@@0M5Q;101[DDD4
07AHB`L0KeE9201_DDD406IA@P@0Je55101[DCh406]QH0<0TYNL401kNGT407]dMBH0NgUi5P3oool0
01@0oooo101kNGT407]eM@@0Ngin0`1kNGT407]eM@@0Ngin8`1kNGT407]eM@<0Ngin5`1kNGT407IC
?`@0NfUQ101kJEd407]aKP@0NfEM0`1kLFT407]]I@@0NfUM101gJF0407aYH0@0O6EH101cH5@307AM
C`@0M5E9101dF4/406]AA@@0M5Q;1`1_EDT806mAA@@0IU52101[DDD406]A?P@0Jf5P0`2BUi`@07]i
N@@0NgAe9P1kNGTF0?ooo`00503oool407]iN@@0NgAe101kMGD307]nOP@0NgAe201kNGT407]eM@@0
Ngin0`1kMGD407]nOQ00NgUi101kM7DJ07]iN@@0MeA01021KF@407]YH@P0NfeU0`1kJF4407]]I@@0
MfEE101[HET408=PD@@0N5Q?101_Fd`306mLC`P0KeE:101ZCT<406]AA@L0KeA7101_DDD406mA@@@0
Je57101[DDD406]A@P@0NhfF5`1kNGT307]eM@@0Ngin7`1kNGTF0?ooo`00503oool407]iN@@0NgAe
101kMGD307]nOP@0NgAe201kNGT407]eM@@0Ngin0`1kMGD407]nOQ00NgUi101kM7DJ07]iN@@0MeA0
1021KF@407]YH@P0NfeU0`1kJF4407]]I@@0MfEE101[HET408=PD@@0N5Q?101_Fd`306mLC`P0KeE:
101ZCT<406]AA@L0KeA7101_DDD406mA@@@0Je57101[DDD406]A@P@0NhfF5`1kNGT307]eM@@0Ngin
7`1kNGTF0?ooo`00503oool407]iN@@0NgAe101kMGD307]nOP@0NgAe201kNGT407]eM@@0Ngin0`1k
MGD407]nOQ00NgUi101kM7DJ07]iN@@0MeA01021KF@407]YH@P0NfeU0`1kJF4407]]I@@0MfEE101[
HET408=PD@@0N5Q?101_Fd`306mLC`P0KeE:101ZCT<406]AA@L0KeA7101_DDD406mA@@@0Je57101[
DDD406]A@P@0NhfF5`1kNGT307]eM@@0Ngin7`1kNGTF0?ooo`00503oool407]iN@@0NgAe101kMGD3
07]nOP@0NgAe201kNGT407]eM@@0Ngin0`1kMGD407]nOQ00NgUi101kM7DJ07]iN@@0MeA01021KF@4
07]YH@P0NfeU0`1kJF4407]]I@@0MfEE101[HET408=PD@@0N5Q?101_Fd`306mLC`P0KeE:101ZCT<4
06]AA@L0KeA7101_DDD406mA@@@0Je57101[DDD406]A@P@0NhfF5`1kNGT307]eM@@0Ngin7`1kNGTF
0?ooo`00503oool807]iN@@0Ng1a0`1kOWh<07]iN@@0NgAe101kNGT307]dMC80NgUi101fD3`407]]
I@P0NfUQ101kKFD307]YH@@0NfUM101fIEd406EPF@@0KEQ;101fCDh406=A@0<0KEE9101]F4l406eH
C@@0JDa2101VE4D;06]AA@@0Je52101_EDT406I=@P@0Je55102BZkPG07]iN@<0NgAe8`1kNGTF0?oo
o`00503oool807]iN@@0Ng1a0`1kOWh<07]iN@@0NgAe101kNGT307]dMC80NgUi101fD3`407]]I@P0
NfUQ101kKFD307]YH@@0NfUM101fIEd406EPF@@0KEQ;101fCDh406=A@0<0KEE9101]F4l406eHC@@0
JDa2101VE4D;06]AA@@0Je52101_EDT406I=@P@0Je55102BZkPG07]iN@<0NgAe8`1kNGTF0?ooo`00
503oool807]iN@@0Ng1a0`1kOWh<07]iN@@0NgAe101kNGT307]dMC80NgUi101fD3`407]]I@P0NfUQ
101kKFD307]YH@@0NfUM101fIEd406EPF@@0KEQ;101fCDh406=A@0<0KEE9101]F4l406eHC@@0JDa2
101VE4D;06]AA@@0Je52101_EDT406I=@P@0Je55102BZkPG07]iN@<0NgAe8`1kNGTF0?ooo`00503o
ool807]iN@@0NgAeC01kNGT407]C?`P0NfUQ101kJFD707]YH@@0NfUM101kKFD407]XH@@0MV1E101g
F584079AB`<0LUE7101bEDd406i>B@@0LEE;101O@c`406Y@A@<0JUeA101VBS`406mAA@@0KeA7101V
DDD406mIC@@0S::_?@1kNGTF0?ooo`00503oool807]iN@@0NgAeC01kNGT407]C?`P0NfUQ101kJFD7
07]YH@@0NfUM101kKFD407]XH@@0MV1E101gF584079AB`<0LUE7101bEDd406i>B@@0LEE;101O@c`4
06Y@A@<0JUeA101VBS`406mAA@@0KeA7101VDDD406mIC@@0S::_?@1kNGTF0?ooo`00503oool807]i
N@@0NgAeC01kNGT407]C?`P0NfUQ101kJFD707]YH@@0NfUM101kKFD407]XH@@0MV1E101gF584079A
B`<0LUE7101bEDd406i>B@@0LEE;101O@c`406Y@A@<0JUeA101VBS`406mAA@@0KeA7101VDDD406mI
C@@0S::_?@1kNGTF0?ooo`00503oool807]iN@@0NgAeC01kNGT407]C?`P0NfUQ101kJFD707]YH@@0
NfUM101kKFD407]XH@@0MV1E101gF584079AB`<0LUE7101bEDd406i>B@@0LEE;101O@c`406Y@A@<0
JUeA101VBS`406mAA@@0KeA7101VDDD406mIC@@0S::_?@1kNGTF0?ooo`00503ooomH07]iN@@0NeM3
101kJEd407]YH@@0NfUM101kJFD307]YH@@0NfeU101kJF4807]]I@@0MV1E101fFe83079EB`@0MeQB
101bEDX407=IC@@0KDY7101YCD<306mDBP@0JUUA101[BS`406mAA@@0Je55101lLFd4086=TQX0NgUi
101kMGD407]nOQ/0NgUi5P3oool001@0ooooF01kNGT407]G@`@0NfUM101kJF4407]YG@@0NfUU0`1k
JF4407]]I@@0NfUQ201kKFD407IPE@@0MU]B0`1bED/407MHDP@0LUE:101cFDd406e:A`@0JDe30`1_
E4X406YID@@0JdXl101_DDD406]AA@@0O75]1021SI8J07]iN@@0NgEe101kOWhK07]iNAH0oooo000D
0?oooeP0NgUi101kEd<407]YG@@0NfUQ101kJEd407]YI@<0NfUQ101kKFD407]YH@P0NfeU101fH5D4
07IKDP<0LUE;101gF584079EBP@0LeU=101]BTL406U=@`<0KeA:101ZFE4406]:?0@0Ke55101[DDD4
07aaK@@0PHfB6P1kNGT407]eM@@0Ngin6`1kNGTF0?ooo`00503ooomH07]iN@@0NeM3101kJEd407]Y
H@@0NfUM101kJFD307]YH@@0NfeU101kJF4807]]I@@0MV1E101fFe83079EB`@0MeQB101bEDX407=I
C@@0KDY7101YCD<306mDBP@0JUUA101[BS`406mAA@@0Je55101lLFd4086=TQX0NgUi101kMGD407]n
OQ/0NgUi5P3oool001@0ooooE@1kNGT306mID@@0S7YX101kJF4807]YG@@0NfUU0`1kKFD407]YH@@0
NfeU101kJ64407]]I@@0NfEM101kJEd307IMCP@0MUUB101bF4h4079IC@@0KTi9101]EDH306U=@P@0
JeM=101[DDD406mAA@@0IU551028SIH40863PaX0NgUi101kM7D<07]iN@@0NgEe0`1kNWX407]nOPP0
NgUi5P3oool001@0ooooE@1kNGT306mID@@0S7YX101kJF4807]YG@@0NfUU0`1kKFD407]YH@@0NfeU
101kJ64407]]I@@0NfEM101kJEd307IMCP@0MUUB101bF4h4079IC@@0KTi9101]EDH306U=@P@0JeM=
101[DDD406mAA@@0IU551028SIH40863PaX0NgUi101kM7D<07]iN@@0NgEe0`1kNWX407]nOPP0NgUi
5P3oool001@0ooooE@1kNGT306mID@@0S7YX101kJF4807]YG@@0NfUU0`1kKFD407]YH@@0NfeU101k
J64407]]I@@0NfEM101kJEd307IMCP@0MUUB101bF4h4079IC@@0KTi9101]EDH306U=@P@0JeM=101[
DDD406mAA@@0IU551028SIH40863PaX0NgUi101kM7D<07]iN@@0NgEe0`1kNWX407]nOPP0NgUi5P3o
ool001@0ooooE@1kNGT306mID@@0S7YX101kJF4807]YG@@0NfUU0`1kKFD407]YH@@0NfeU101kJ644
07]]I@@0NfEM101kJEd307IMCP@0MUUB101bF4h4079IC@@0KTi9101]EDH306U=@P@0JeM=101[DDD4
06mAA@@0IU551028SIH40863PaX0NgUi101kM7D<07]iN@@0NgEe0`1kNWX407]nOPP0NgUi5P3oool0
01@0ooooD@1kNGT404Hh<0<0[HMe1021KF0407]YI@P0NfUM101kJF4307]aJ@@0NfEM101kKF0407]a
KPP0NfUQ101kJEd307]UF@@0MeE>101gG4h407MID@@0KUE5101_CDD306mEB@@0JTe2101VDDD407AI
C@@0JTi31027WJX^07]iN@L0NgAe301kNGTF0?ooo`00503ooomA07]iN@@0ASP`0`2]QgD4085]H0@0
NfUU201kJEd407]YH@<0Ng5Y101kIEd407]]H0@0Ng5^201kJF4407]YG@<0NfEI101gEDh407MLCP@0
MeUA101^EDD406m=A@<0KeE9101ZCD8406IAA@@0M5U=101ZCT<408NMZRh0NgUi1`1kM7D<07]iNAH0
oooo000D0?oooe40NgUi1016>3030:f7M@@0PFeP101kJFD807]YG@@0NfUQ0`1kLFT407]UG@@0NfeP
101kLFh807]YH@@0NfUM0`1kIET407MECP@0Mea>101gFE4406iEA@@0Kde50`1_EDT406Y=@P@0IU55
101dFDd406Y>@`@0QifZ;P1kNGT707]dM@`0NgUi5P3oool001@0ooooD@1kNGT404Hh<0<0[HMe1021
KF0407]YI@P0NfUM101kJF4307]aJ@@0NfEM101kKF0407]aKPP0NfUQ101kJEd307]UF@@0MeE>101g
G4h407MID@@0KUE5101_CDD306mEB@@0JTe2101VDDD407AIC@@0JTi31027WJX^07]iN@L0NgAe301k
NGTF0?ooo`00503oool807]iN@@0NgEe0`1kOWhn07]iN@@0Jf5U100J3PT30>6lX`@0NfUI101kKFX4
07]UG@@0NfeU101kIEd707]]I@@0NfQM101kJF4407]YG@@0NeaM101gJ5@307QTE@@0O61H101gG544
07=ID@@0Ke53101cDDH306UEB@@0Jddn101[DDL406mGBP@0KeA7102BZkQ107]iNAH0oooo000D0?oo
o`P0NgUi101kMGD307]nOSh0NgUi101[HFD401X>2@<0hKbS101kJET407]]JP@0NfEM101kKFD407]U
G@L0NfeU101kJ5d407]YH@@0NfUM101kG5d407MXE0<0N6AE101lH5P407MLD@@0LeUA101_DD<407=A
AP<0JEE9101[CCh406]AA`@0KeM:101_E4L409:[^440NgUi5P3oool001@0oooo201kNGT407]eM@<0
Ngin?P1kNGT406]QI@@06Ph90`3Q_:<407]YF@@0NfeZ101kIEd407]]I@@0NfEM1`1kKFD407]XG@@0
NfUQ101kJEd407]LG@@0MfQD0`1hI5D407aPF0@0MeaA101cFE4406mA@`@0Le560`1YEDT406]=?P@0
Je57101_EdX406mDA`@0TZ^h@@1kNGTF0?ooo`00503oool807]iN@@0NgEe0`1kOWhn07]iN@@0Jf5U
100J3PT30>6lX`@0NfUI101kKFX407]UG@@0NfeU101kIEd707]]I@@0NfQM101kJF4407]YG@@0NeaM
101gJ5@307QTE@@0O61H101gG54407=ID@@0Ke53101cDDH306UEB@@0Jddn101[DDL406mGBP@0KeA7
102BZkQ107]iNAH0oooo000D0?ooo`P0NgUi101kM7D307]eM@@0Ngin=P1kNGT407mmO@@09QLB101a
G5D3085]I0@0NfUQ101kKFD407]YH@@0NfeU1`1kJF4407]]I@@0Ng5Y101kIEd407MUE@@0O5EE101g
G4h306iEB@P0N5a@101cG4`406UAB@@0M5550`1_E4L406YA@P@0JU55101VDDD406mEB@@0R92F1021
SI8m07]iNAH0oooo000D0?ooo`P0NgUi101kM7D307]eM@@0Ngin=P1kNGT407mmO@@09QLB101aG5D3
085]I0@0NfUQ101kKFD407]YH@@0NfeU1`1kJF4407]]I@@0Ng5Y101kIEd407MUE@@0O5EE101gG4h3
06iEB@P0N5a@101cG4`406UAB@@0M5550`1_E4L406YA@P@0JU55101VDDD406mEB@@0R92F1021SI8m
07]iNAH0oooo000D0?ooo`P0NgUi101kM7D307]eM@@0Ngin=P1kNGT407mmO@@09QLB101aG5D3085]
I0@0NfUQ101kKFD407]YH@@0NfeU1`1kJF4407]]I@@0Ng5Y101kIEd407MUE@@0O5EE101gG4h306iE
B@P0N5a@101cG4`406UAB@@0M5550`1_E4L406YA@P@0JU55101VDDD406mEB@@0R92F1021SI8m07]i
NAH0oooo000D0?ooo`P0NgUi101kMGDm07]iN@@0<b4I101kKFD407IPE@<0NfUI101kJFD807]YH@@0
NfUM101kJFD307]YH@@0NfeU201kJF440795?`@0MeM@101cCT@707=AAP@0LfYD101_E4D406mDA`@0
Kda10`1[E4<407AAA`@0Ke55101VDD4407A?AP@0MFQM102BZkPZ07]iN@@0NgEe0`1kOWh<07]iNAH0
oooo000D0?ooo`P0NgUi101kMGDm07]iN@@0<b4I101kKFD407IPE@<0NfUI101kJFD807]YH@@0NfUM
101kJFD307]YH@@0NfeU201kJF440795?`@0MeM@101cCT@707=AAP@0LfYD101_E4D406mDA`@0Kda1
0`1[E4<407AAA`@0Ke55101VDD4407A?AP@0MFQM102BZkPZ07]iN@@0NgEe0`1kOWh<07]iNAH0oooo
000D0?ooo`P0NgUi101kMGDm07]iN@@0<b4I101kKFD407IPE@<0NfUI101kJFD807]YH@@0NfUM101k
JFD307]YH@@0NfeU201kJF440795?`@0MeM@101cCT@707=AAP@0LfYD101_E4D406mDA`@0Kda10`1[
E4<407AAA`@0Ke55101VDD4407A?AP@0MFQM102BZkPZ07]iN@@0NgEe0`1kOWh<07]iNAH0oooo000D
0?ooo`P0NgUi101kMGDm07]iN@@0<b4I101kKFD407IPE@<0NfUI101kJFD807]YH@@0NfUM101kJFD3
07]YH@@0NfeU201kJF440795?`@0MeM@101cCT@707=AAP@0LfYD101_E4D406mDA`@0Kda10`1[E4<4
07AAA`@0Ke55101VDD4407A?AP@0MFQM102BZkPZ07]iN@@0NgEe0`1kOWh<07]iNAH0oooo000D0?oo
o`P0NgUi101kM7Di07]iN@@0Jf5Q100[8a`4085]H@@0NfUQ0`1kJET407]YI@@0NfUQ101kIET407]Y
G0@0NfUP0`1kKFT407]]I@@0NeaI101kJ604078i=`@0Ld0h101_=2h307U9AP@0Kc`d101iDDP406E@
@@@0KeI6101_DD4306]<@@@0M5A7101_DDD406YA@P@0KdTn101ZF4/407idJ`<0S:Jd9`1kNGT407]d
M@l0NgUi5P3oool001@0oooo201kNGT407]dMCT0NgUi101[HF4402/S70@0PFeQ101kJF4307]YF@@0
NfUU101kJF4407]UF@@0NfUL101kJF0307]]J@@0NfeU101kG5T407]XH0@0LSTg101c@3P406ld;P<0
NDU6101_?3@407UAB0@0IE11101_ETH406mA@@<0Jda1101dE4L406mAA@@0JU52101_BCh406YHB`@0
OWA[0`2<Y[@W07]iN@@0NgAe3`1kNGTF0?ooo`00503oool807]iN@@0NgAe>@1kNGT406]QH@@0:b<L
1021KF4407]YH@<0NfUI101kJFD407]YH@@0NfEI101kJE`407]YH0<0NfeY101kKFD407]LF@@0NfQP
101b>CL407=0>0@0Kc@^0`1iBDH406ll=0@0NE58101UD44406mFAP@0Ke510`1[C44407ADA`@0Ke55
101ZDD8406m9?P@0JUQ;101nM6/308bV]2L0NgUi101kM7D?07]iNAH0oooo000D0?ooo`P0NgUi101k
M7Di07]iN@@0Jf5Q100[8a`4085]H@@0NfUQ0`1kJET407]YI@@0NfUQ101kIET407]YG0@0NfUP0`1k
KFT407]]I@@0NeaI101kJ604078i=`@0Ld0h101_=2h307U9AP@0Kc`d101iDDP406E@@@@0KeI6101_
DD4306]<@@@0M5A7101_DDD406YA@P@0KdTn101ZF4/407idJ`<0S:Jd9`1kNGT407]dM@l0NgUi5P3o
ool001@0ooooA@1kNGT402@H5@@0f[6I1021KF@407]YH@<0NfUM101kJFD407]YG@@0MeeB101lH5@4
085bI0<0NfUU101kHED407M5A`@0N4i4101dDTd406P^8`@0OEU?0`1i@40406DT7P@0MCP`101_BCl4
06I@A0@0Je]80`1[BCH406mDB@@0M557101_DDD406m=@P@0KeA7101_F4/308bLX@@0Nh>8=P1kNGTF
0?ooo`00503ooom507]iN@@091PE103J/IT4085]I0@0NfUQ0`1kJEd407]YI@@0NfUM101gGE8407aP
E0@0PG9T0`1kJFD407]QE@@0MdE7101hCT@407ABC@@0J2hS101mFDl307U0@0@0IB@N101e>30406m9
?`@0IU14101[FdP306]9=P@0KeA9101dDDL406mAA@@0Kde2101_E4L406mHB`<0S9bQ101kPhPf07]i
NAH0oooo000D0?ooodD0NgUi100T61D40=ZaV@@0PFeT101kJF4307]YG@@0NfUU101kJEd407MMDP@0
O61D1021LV@307]YI@@0Nf5E101gADL407Q>A0@0M59=101X;R<407eIC`<0ND10101U91h407Dh<0@0
KdTo101VD4@406]KB0<0JdTf101_E4T407AAA`@0Ke55101_CD8406mDA`@0KeQ;0`2<W:4407^3R3H0
NgUi5P3oool001@0ooooA@1kNGT402@H5@@0f[6I1021KF@407]YH@<0NfUM101kJFD407]YG@@0MeeB
101lH5@4085bI0<0NfUU101kHED407M5A`@0N4i4101dDTd406P^8`@0OEU?0`1i@40406DT7P@0MCP`
101_BCl406I@A0@0Je]80`1[BCH406mDB@@0M557101_DDD406m=@P@0KeA7101_F4/308bLX@@0Nh>8
=P1kNGTF0?ooo`00503oool?07]iN@@0NgEe101kOWhZ07]iN@@0FTa=100a:B4409N3L`@0NfUQ101g
HE43085fK@@0NfEM101kHE4406iIB@@0M4m6102<N74307=9@@@0AaX>102gPgP407<i=0@0LEaD101O
Ad4406<]8`<0IeI6101R<bT4070l>`@0GBXP1028>S8406MQC@<0Kdlf101_D4H406mHB`@0LeE6101Y
BT8406mEB@@0Ke550`1nLFD408bLX@@0Nh>8<P1kNGTF0?ooo`00503oool?07]iN@@0NgEe101kOWhZ
07]iN@@0FTa=100a:B4409N3L`@0NfUQ101gHE43085fK@@0NfEM101kHE4406iIB@@0M4m6102<N743
07=9@@@0AaX>102gPgP407<i=0@0LEaD101OAd4406<]8`<0IeI6101R<bT4070l>`@0GBXP1028>S84
06MQC@<0Kdlf101_D4H406mHB`@0LeE6101YBT8406mEB@@0Ke550`1nLFD408bLX@@0Nh>8<P1kNGTF
0?ooo`00503oool?07]iN@@0NgEe101kOWhZ07]iN@@0FTa=100a:B4409N3L`@0NfUQ101gHE43085f
K@@0NfEM101kHE4406iIB@@0M4m6102<N74307=9@@@0AaX>102gPgP407<i=0@0LEaD101OAd4406<]
8`<0IeI6101R<bT4070l>`@0GBXP1028>S8406MQC@<0Kdlf101_D4H406mHB`@0LeE6101YBT8406mE
B@@0Ke550`1nLFD408bLX@@0Nh>8<P1kNGTF0?ooo`00503oool?07]iN@@0NgEe101kOWhZ07]iN@@0
FTa=100a:B4409N3L`@0NfUQ101gHE43085fK@@0NfEM101kHE4406iIB@@0M4m6102<N74307=9@@@0
AaX>102gPgP407<i=0@0LEaD101OAd4406<]8`<0IeI6101R<bT4070l>`@0GBXP1028>S8406MQC@<0
Kdlf101_D4H406mHB`@0LeE6101YBT8406mEB@@0Ke550`1nLFD408bLX@@0Nh>8<P1kNGTF0?ooo`00
503oool807]iN@@0NgEe0`1kOWh407]dMBh0NgUi100O4a840;V?M@@0PFeU101kJEd4079EB`<0PGYe
101kJF4407]IB`@0ID8a101[Acd4058I5@<0X8j510135aH4071@BP@0L4A2101fD4T407]aJ0@0KBhW
0`1UBdX4054d:@@0C3Pd100l6a@404hQ5@@0U4Xh0`1dID/407A9@@@0Lf1B101cFDX406eA@`@0JDe5
101_DDD306mHB`@0OXRJ1028Q7X40863Pbh0NgUi5P3oool001@0oooo201kNGT407]eM@<0Ngin101k
M7D^07]iN@@07a<B102iSgD4085]I@@0NfUM101bED/3085jM@@0NfUQ101kFD/406E2<@@0JdLm101B
6AD30:2>Q@@0@aLF101`D4X40714@P@0MU19101kLFP406d^9`<0ID]:101A=2T404`h=0@0?1/D101>
8AD409A:>0<0M6E;101dBD4407=PDP@0LeU:101]DD<406U=A@@0Ke550`1_F4/407j8VP@0R8Aj1021
Ph<^07]iNAH0oooo000D0?ooo`P0NgUi101kMGD307]nOP@0NgAe;P1kNGT401lC4P@0^Hme1021KFD4
07]YG@@0LUE;0`21NWD407]YH@@0NeU;101U@S4406]7?@@0DQTE0`2PSXD404<G5P@0L51:101`A484
07I@B@@0Ng5X101];RL306E;BP@0DC@Y101<>3@403`K50@0CR4E102DBSP307AUB`@0M4U1101cH584
07=IBP@0KE53101YCDD406mAA@<0KeQ;101nR9X408R4NP@0PH>3;P1kNGTF0?ooo`00503oool807]i
N@@0NgEe0`1kOWh407]dMBh0NgUi100O4a840;V?M@@0PFeU101kJEd4079EB`<0PGYe101kJF4407]I
B`@0ID8a101[Acd4058I5@<0X8j510135aH4071@BP@0L4A2101fD4T407]aJ0@0KBhW0`1UBdX4054d
:@@0C3Pd100l6a@404hQ5@@0U4Xh0`1dID/407A9@@@0Lf1B101cFDX406eA@`@0JDe5101_DDD306mH
B`@0OXRJ1028Q7X40863Pbh0NgUi5P3oool001@0oooo201kNGT407]dMC80NgUi0`1_JG8400d710@0
gkFE1021KF@407]YG@@0MU]B0`1kJFD407]YH@@0LdXl101N?RX406H/8`@0<0l90`2XPWD408:3M0@0
O6]W1021TY@407]YH@@0Ng9/101^DDX308:8QP@0LeE9101UJFT4030N6`@0:RHT100l614309U>>0@0
NEm@101nI54407MQF0@0KU53101YCT<406m9?P<0KeQ:101[NH0407E/KP@0R8RF102<SH<Z07]iNAH0
oooo000D0?ooo`P0NgUi101kM7Db07]iN@<0KfUb100=1`@40=neU@@0PFeT101kJEd407IKDP<0NfUU
101kJF4407=:?0@0GShZ101V;2<4030?2@<0Z89e1022Pg@407a[I`@0PI:D101kJF4407]bK0@0KU5:
0`22R8H407=EB@@0IFUY100`7Q/402XV90@0?1PA0`2ICSP407UOD0@0OVAA101gHEP406iA@`@0JDi3
101_BCh306mHBP@0JgV0101eK6h408R8UP@0S8f3:P1kNGTF0?ooo`00503oool807]iN@@0NgAe<P1k
NGT306mYLP@03@L4103O]ID4085]I0@0NfUM101fFe8307]YI@@0NfUQ101cBS`405hn:P@0IR`S100`
3`T30:R2M@@0PX=d101lJfL4086BU0@0NfUQ101kLV`406iABP<0PXR6101cEDT406EYJ@@0<1hK100Z
9R@403`H4@<0VDhh101iGe0407iTD@@0Mf5H101^DD<406U>@`@0KdTn0`1_F4X406]iP0@0MFa^1028
R9H408b=PbX0NgUi5P3oool001@0oooo201kNGT407]dMC80NgUi0`1_JG8400d710@0gkFE1021KF@4
07]YG@@0MU]B0`1kJFD407]YH@@0LdXl101N?RX406H/8`@0<0l90`2XPWD408:3M0@0O6]W1021TY@4
07]YH@@0Ng9/101^DDX308:8QP@0LeE9101UJFT4030N6`@0:RHT100l614309U>>0@0NEm@101nI544
07MQF0@0KU53101YCT<406m9?P<0KeQ:101[NH0407E/KP@0R8RF102<SH<Z07]iNAH0oooo000D0?oo
ocX0NgUi1016>30303/T8@@0HdQ1102GR7<407]YG@@0Nf5E101kJE/307]aJ0@0NfUQ101Y?C@405i=
?@@0FcHb100b4AH3070m@0@0LUU;101cEDd407e^I@@0PUM@101dIUD407A1>0<0NDa1101`Bch408>5
L@@0ISld101HBTT402/U7`<0@@h6102UKeh407i[D@@0O6UO101^DD<406U=A@@0Jde20`1dEDT406YT
F@@0L7Z4101LEFD409:GSBX0NgUi5P3oool001@0oooo>P1kNGT404Hh<0<0>b@Q101SB44409N8L`@0
NfUM101kHED407]YF`<0Ng5X101kJF4406Tm=0@0GTdm101K=S84038A5P<0L3e0101bFD/407=EC@@0
OFiU1022Ee0407AVE@@0M44h0`1iC444071;?P@0PhEa101V?c@405Q:B@@0:bDO0`113PH40:E_GP@0
OV]A101lJEl406iA@`@0JDe5101[CD8307AEB@@0JVAI101`NX@405aEI@@0TYN=:P1kNGTF0?ooo`00
503ooolj07]iN@@0ASP`0`0k924406=8@@@0UhQc101kJEd407]QE@@0NfUK0`1kLFP407]YH@@0JCdd
101NCCd405/f<P@0<Q4F0`1`?D04079IB`@0LeE=101mKVD4089GD0@0M6IE101d@CP307U<@@@0L4/n
1023QG4406Ho=0@0F4Y9100[9Al3044>1P@0YFmN101nJe4407aYG`@0KU53101YCDD406]=@P<0M5E9
101ZI5T4071jQ0@0G5EU102BUhdZ07]iNAH0oooo000D0?oooa<0NgUi101kMGD407]nOQ/0NgUi101_
IFT400d81@<09aDA103EXY0407]YF@@0NfEI101kFED407MYE@<0PFeP101kG5T406U:>P@0IdLf102B
S8@407]]H@<0NeME101fEe84071FD@@0L4m:101fAT<406M1?P@0K3dj0`1X=2h406Ph=`@0JDm3101^
>cL405`j<P@0BBhQ0`0^4`l406d^8@@0Uh1V1022K5h406iE@`@0JDY2101VC44307AHBP@0Ke]>1011
<2P40;noc`@0MgIf1021Ph<V07]iNAH0oooo000D0?oooa<0NgUi101kMGD407]nOQ/0NgUi101_IFT4
00d81@<09aDA103EXY0407]YF@@0NfEI101kFED407MYE@<0PFeP101kG5T406U:>P@0IdLf102BS8@4
07]]H@<0NeME101fEe84071FD@@0L4m:101fAT<406M1?P@0K3dj0`1X=2h406Ph=`@0JDm3101^>cL4
05`j<P@0BBhQ0`0^4`l406d^8@@0Uh1V1022K5h406iE@`@0JDY2101VC44307AHBP@0Ke]>1011<2P4
0;noc`@0MgIf1021Ph<V07]iNAH0oooo000D0?oooa<0NgUi101kMGD407]nOQ/0NgUi101_IFT400d8
1@<09aDA103EXY0407]YF@@0NfEI101kFED407MYE@<0PFeP101kG5T406U:>P@0IdLf102BS8@407]]
H@<0NeME101fEe84071FD@@0L4m:101fAT<406M1?P@0K3dj0`1X=2h406Ph=`@0JDm3101^>cL405`j
<P@0BBhQ0`0^4`l406d^8@@0Uh1V1022K5h406iE@`@0JDY2101VC44307AHBP@0Ke]>1011<2P40;no
c`@0MgIf1021Ph<V07]iNAH0oooo000D0?oooa<0NgUi101kMGD407]nOQ/0NgUi101_IFT400d81@<0
9aDA103EXY0407]YF@@0NfEI101kFED407MYE@<0PFeP101kG5T406U:>P@0IdLf102BS8@407]]H@<0
NeME101fEe84071FD@@0L4m:101fAT<406M1?P@0K3dj0`1X=2h406Ph=`@0JDm3101^>cL405`j<P@0
BBhQ0`0^4`l406d^8@@0Uh1V1022K5h406iE@`@0JDY2101VC44307AHBP@0Ke]>1011<2P40;noc`@0
MgIf1021Ph<V07]iNAH0oooo000D0?oooa<0NgUi101kM7DO07]iN@@0Ge=O10052@03000;50@0O79W
1021KF0407]QE@@0Nf1M101fFED307]fH0@0Ne]I101YASd405ll<@@0R7e`1021MW4307]]I@@0NfEM
201kKFD407]IDP@0LUa;101gG54306iEAP@0Le56101UBS`407Do?P@0Jd0f101L;b`304PV90@0BbDW
101dESX408=WG`@0LeU6101YBT8406I=?P<0M557101_F4/401TH60@0]:JP102<SI8Z07]iNAH0oooo
000D0?oooa<0NgUi101kM7DO07]iN@@0Ge=O10052@03000;50@0O79W1021KF0407]QE@@0Nf1M101f
FED307]fH0@0Ne]I101YASd405ll<@@0R7e`1021MW4307]]I@@0NfEM201kKFD407]IDP@0LUa;101g
G54306iEAP@0Le56101UBS`407Do?P@0Jd0f101L;b`304PV90@0BbDW101dESX408=WG`@0LeU6101Y
BT8406I=?P<0M557101_F4/401TH60@0]:JP102<SI8Z07]iNAH0oooo000D0?oooa<0NgUi101kM7DO
07]iN@@0Ge=O10052@03000;50@0O79W1021KF0407]QE@@0Nf1M101fFED307]fH0@0Ne]I101YASd4
05ll<@@0R7e`1021MW4307]]I@@0NfEM201kKFD407]IDP@0LUa;101gG54306iEAP@0Le56101UBS`4
07Do?P@0Jd0f101L;b`304PV90@0BbDW101dESX408=WG`@0LeU6101YBT8406I=?P<0M557101_F4/4
01TH60@0]:JP102<SI8Z07]iNAH0oooo000D0?oooa<0NgUi101kM7DO07]iN@@0Ge=O10052@03000;
50@0O79W1021KF0407]QE@@0Nf1M101fFED307]fH0@0Ne]I101YASd405ll<@@0R7e`1021MW4307]]
I@@0NfEM201kKFD407]IDP@0LUa;101gG54306iEAP@0Le56101UBS`407Do?P@0Jd0f101L;b`304PV
90@0BbDW101dESX408=WG`@0LeU6101YBT8406I=?P<0M557101_F4/401TH60@0]:JP102<SI8Z07]i
NAH0oooo000D0?ooocH0NgUi101ZEeH407]YH@<0MUmE101bGDh407aYG0@0PFUM101kJF4407]KF@<0
NfeQ101kIET406eAA0@0J4<j101dETT408R3M@<0PGIa101kJ64407]UG@@0Ng5Y101kEe84079AB0@0
Le550`1cH4h406]=@@@0Hda1101`B3P406]:?@@0Jdhm0`1[Acd406M8?@@0M5Q9101iG4l407=EAP@0
IDTn101[D44306mD@`@0KeA:100D4Q840<Nka@@0QXQn:P1kNGTF0?ooo`00503ooolf07]iN@@0JUMF
101kJF4307IOE@@0LUe>101lJE`4085YG@@0NfUQ101kFeT307]]H@@0NfEI101]DD@406Q3>P@0M5I9
1028PgD3085fL@@0NfQQ101kIEd407]aJ@@0NeMB101bDDP407=AA@<0Lf1>101[CD4406=<@@@0L4Ph
101[BSd406]>?@<0JdLm101WB3d407AHB@@0NEa?101cEDH406E9?P@0Je110`1_E4<406mDBP@0518B
1037^lD408J8ORX0NgUi5P3oool001@0oooo=P1kNGT406YGEP@0NfUQ0`1fGeD4079MCP@0O6UL1021
JEd407]YH@@0Ne]I0`1kKF4407]UF@@0KE54101X@cX407AFB@@0R8=e0`21MW4407]XH@@0NfEM101k
LFT407]GDP@0LU58101cDDD307=PCP@0Jde1101SC4440718>0@0JdXm101[CSd306]7?@@0IdPm101d
F4T407ULC`@0LeE6101UBCh406]@@@<0KeA3101_E4X401@B4P@0ak_51026R7hZ07]iNAH0oooo000D
0?ooocH0NgUi101ZEeH407]YH@<0MUmE101bGDh407aYG0@0PFUM101kJF4407]KF@<0NfeQ101kIET4
06eAA0@0J4<j101dETT408R3M@<0PGIa101kJ64407]UG@@0Ng5Y101kEe84079AB0@0Le550`1cH4h4
06]=@@@0Hda1101`B3P406]:?@@0Jdhm0`1[Acd406M8?@@0M5Q9101iG4l407=EAP@0IDTn101[D443
06mD@`@0KeA:100D4Q840<Nka@@0QXQn:P1kNGTF0?ooo`00503ooolb07]iN@@0Mg5b1021H4X407MQ
F@<0N6=D101_KG4408aYDPP0NfeU101kJ64307]]I@@0NfQQ101fDD/406eEA0@0J4<j101lL643085j
M@@0Ng5Y101kFED407MfI0@0PFeP101^CD@407=>@`<0JdLh101[FdX405i1=P@0Id/h101WAC`406]<
=P<0HT8h101WA3@407eSE`@0LeQ;101_DDD406I9?P@0Jda10`1[E4D406mEB@@01@H8103>]K8409NM
X2X0NgUi5P3oool001@0oooo<P1kNGT407MaLP@0PF1:101gHET307QSE0@0Kfea102<JE8807]]I@@0
NfQQ0`1kKFD407]XH@@0MU5;101]ED@406Q3>P@0O71Q0`21NWD407]aJ@@0NeUE101gMV@4085]H0@0
KTe4101cCT<306]7>0@0Je]:101N@CH406M;>0@0IdDl101[C3H30692>0@0Id@d101mHeL407=HB`@0
Ke55101VBCh406]<@@<0JeA5101_EDT400D620@0c[Fb102GWJ0Z07]iNAH0oooo000D0?oooc80NgUi
101gLG84085PBP@0Mf5I0`1hHe@406m]L@@0S6UB201kKFD407]XH@<0NfeU101kJ64407IAB`@0KEE4
101X@cX407a`H@<0PGYe101kLFT407]IE@@0MgIT1021KF0406i=A0@0Ldi30`1[AcP406]KBP@0GT4f
101WBcP406M5?0@0Jd`f0`1R@SP406M4=0@0OF=G101cF4/406mAA@@0ITTn101[C44306]DA@@0KeE9
10051PP40<je/P@0UifP:P1kNGTF0?ooo`00503ooolb07]iN@@0Mg5b1021H4X407MQF@<0N6=D101_
KG4408aYDPP0NfeU101kJ64307]]I@@0NfQQ101fDD/406eEA0@0J4<j101lL643085jM@@0Ng5Y101k
FED407MfI0@0PFeP101^CD@407=>@`<0JdLh101[FdX405i1=P@0Id/h101WAC`406]<=P<0HT8h101W
A3@407eSE`@0LeQ;101_DDD406I9?P@0Jda10`1[E4D406mEB@@01@H8103>]K8409NMX2X0NgUi5P3o
ool001@0oooo<P1kNGT407IPEP@0NfUQ101^DD<306mEAP@0LW9^1021G5T407]fJ@@0Ng5Y2`1kKFD4
07]GDP@0MUE;101YBSd407QDBP<0QX=m101kLFT407]GE@@0MVEI101kJEd406e=A0@0KU530`1T@3L4
06YAA@@0GS`a101WAcP406M;?`@0Kdln0`1ZBC/406U>@0@0LeU=101_CD8406mAA@@0JTe2101VBCh3
06]D@`@0KeA:10021PL405Lo=`@0h=cM101kOWhV07]iNAH0oooo000D0?oooc80NgUi101fH5H407]Y
H@@0KU530`1_EDH4079bKP@0PEaI101kMVT407]aJ@/0NfeU101kEe8407IEB`@0JDXm101hE4X308J3
O@@0Ng5Y101kEeD407IUF@@0NfUM101]CD@406iA@`<0I40g101ZDDD405hl<@@0IdLh101WBcl406m?
?P<0JTTk101YCT0407=IC@@0Kde2101_DDD406Y=@P@0ITTn0`1[E4<406mDBP@00PH7101G?cL40>3L
g@@0Ngin9P1kNGTF0?ooo`00503ooolb07]iN@@0MV1F101kJF4406iA@`<0KeE6101bLVh4085LF@@0
NgIY101kLFT;07]]I@@0NeMB101fED/406U:?@@0N5A:0`26Pgd407]aJ@@0NeME101fIET407]YG@@0
KDe4101^DD<306A0=`@0JU55101N?34406M7>0@0Id/o101_Cch306Y9>`@0JDi0101cFDd406m=@P@0
Ke55101ZCD8406I9?P<0JeA3101_E4X400861`@0Eclg103Pg=d407]nORH0NgUi5P3oool001@0oooo
<P1kNGT407IPEP@0NfUQ101^DD<306mEAP@0LW9^1021G5T407]fJ@@0Ng5Y2`1kKFD407]GDP@0MUE;
101YBSd407QDBP<0QX=m101kLFT407]GE@@0MVEI101kJEd406e=A0@0KU530`1T@3L406YAA@@0GS`a
101WAcP406M;?`@0Kdln0`1ZBC/406U>@0@0LeU=101_CD8406mAA@@0JTe2101VBCh306]D@`@0KeA:
10021PL405Lo=`@0h=cM101kOWhV07]iNAH0oooo000D0?oooc80NgUi101kEd<407MUG@@0HS`^0`22
MV/407]LF@@0NfUM101kJFD407]aJ@@0Ng5]0`1kJ5d407]]I@@0NfEI101kH58406U:?@@0Le530`22
MVh4085aK@@0NfUM101kKFX407]UG@@0LUE;101ZBSl306mAA@@0Je55101V@cT406I6=0@0HT8j101_
DTH307QEC@@0Mea>101^EDT406UAA`@0Kdi3201[CD8306]A@P@0KeU=100=51<401dH5`@0DD8m103P
hn@V07]iNAH0oooo000D0?oooc80NgUi101kEd<407MUG@@0HS`^0`22MV/407]LF@@0NfUM101kJFD4
07]aJ@@0Ng5]0`1kJ5d407]]I@@0NfEI101kH58406U:?@@0Le530`22MVh4085aK@@0NfUM101kKFX4
07]UG@@0LUE;101ZBSl306mAA@@0Je55101V@cT406I6=0@0HT8j101_DTH307QEC@@0Mea>101^EDT4
06UAA`@0Kdi3201[CD8306]A@P@0KeU=100=51<401dH5`@0DD8m103Phn@V07]iNAH0oooo000D0?oo
oc80NgUi101kEd<407MUG@@0HS`^0`22MV/407]LF@@0NfUM101kJFD407]aJ@@0Ng5]0`1kJ5d407]]
I@@0NfEI101kH58406U:?@@0Le530`22MVh4085aK@@0NfUM101kKFX407]UG@@0LUE;101ZBSl306mA
A@@0Je55101V@cT406I6=0@0HT8j101_DTH307QEC@@0Mea>101^EDT406UAA`@0Kdi3201[CD8306]A
@P@0KeU=100=51<401dH5`@0DD8m103Phn@V07]iNAH0oooo000D0?ooobh0NgUi101kJF4407=A@P@0
Kd@j101VET<307UjKP@0TVAM101kJEd407]YI@@0Ng5Y101kLVd707]]I@@0NfEM101gIED4079EB`@0
LUa>0`1kJEd407]YH@@0MeaE1021NV`407]LG@@0KUe6101YASh306]@@`@0Id`o101_Cc/405i0=0@0
L4Lj101dFdl307UIC`@0O61D101^EDT406UEB@@0Ke55101ZDDD406IA@@<0Kda3101_I5D405`l;`@0
>R`Y100]Ae<Z07]iNAH0oooo000D0?ooobh0NgUi101kJF4407=A@P@0Kd@j101VET<307UjKP@0TVAM
101kJEd407]YI@@0Ng5Y101kLVd707]]I@@0NfEM101gIED4079EB`@0LUa>0`1kJEd407]YH@@0MeaE
1021NV`407]LG@@0KUe6101YASh306]@@`@0Id`o101_Cc/405i0=0@0L4Lj101dFdl307UIC`@0O61D
101^EDT406UEB@@0Ke55101ZDDD406IA@@<0Kda3101_I5D405`l;`@0>R`Y100]Ae<Z07]iNAH0oooo
000D0?ooobh0NgUi101kJF4407=A@P@0Kd@j101VET<307UjKP@0TVAM101kJEd407]YI@@0Ng5Y101k
LVd707]]I@@0NfEM101gIED4079EB`@0LUa>0`1kJEd407]YH@@0MeaE1021NV`407]LG@@0KUe6101Y
ASh306]@@`@0Id`o101_Cc/405i0=0@0L4Lj101dFdl307UIC`@0O61D101^EDT406UEB@@0Ke55101Z
DDD406IA@@<0Kda3101_I5D405`l;`@0>R`Y100]Ae<Z07]iNAH0oooo000D0?ooobh0NgUi101kJF44
07=A@P@0Kd@j101VET<307UjKP@0TVAM101kJEd407]YI@@0Ng5Y101kLVd707]]I@@0NfEM101gIED4
079EB`@0LUa>0`1kJEd407]YH@@0MeaE1021NV`407]LG@@0KUe6101YASh306]@@`@0Id`o101_Cc/4
05i0=0@0L4Lj101dFdl307UIC`@0O61D101^EDT406UEB@@0Ke55101ZDDD406IA@@<0Kda3101_I5D4
05`l;`@0>R`Y100]Ae<Z07]iNAH0oooo000D0?ooobh0NgUi101kCD@406To=0@0HC8/101[GTd307Mf
J`@0PFeU101kKF4407]UG@@0Ng5Y1`1kKFD407]YH@@0NfUM101bHED407]MDP@0LVUL0`21KFD407]]
H@@0MUMB101kJEd407]ECP@0JE53101U@cT306M8?0@0Hd@h101[BSP40655>P@0Ke56101cFDd307=L
D@@0O5aA101^EDT406UAAP@0Kde2101_C4D406Y@@P<0Jd`n101dI5X4068l;0@0Ke99102F]l<407Id
MBH0NgUi5P3oool001@0oooo;P1kNGT407]=A0@0JCld101Q<R`406]NC@<0MgI[1021KFD407]]H@@0
NfEM101kLFT707]]I@@0NfUQ101kJEd4079QE@@0NeeB101bJE`3085]I@@0NfeQ101fEe8407]YG@@0
NeE>101YDD<406E3>@<0IdPl101SA3P406]:>0@0HDDj101_DDH407=IC@<0LeaA101lG54406iEB@@0
JE56101_CD8406m<A@@0JU120`1[C3h407ATFP@0HS`/101_DTT409Jg``@0MWAe9P1kNGTF0?ooo`00
503oool^07]iN@@0Nde4101Y?c@4064b;0@0Jei=0`1gMV/4085]I@@0NfeQ101kIEd407]aJ@L0NfeU
101kJF4407]YG@@0LV5E101kGE84079YG0<0PFeU101kKF4407IGDP@0NfUM101kEDh406UA@`@0ID<i
0`1WB3`406=4>0@0JdXh101QACX406mAAP@0LeU=0`1cG54407aLD@@0KUE9101YDDH406m=@P@0Kda5
101ZD48306]<?P@0M6AJ101R?2`406mBB@@0U[O3101fM7DV07]iNAH0oooo000D0?ooobh0NgUi101k
CD@406To=0@0HC8/101[GTd307MfJ`@0PFeU101kKF4407]UG@@0Ng5Y1`1kKFD407]YH@@0NfUM101b
HED407]MDP@0LVUL0`21KFD407]]H@@0MUMB101kJEd407]ECP@0JE53101U@cT306M8?0@0Hd@h101[
BSP40655>P@0Ke56101cFDd307=LD@@0O5aA101^EDT406UAAP@0Kde2101_C4D406Y@@P<0Jd`n101d
I5X4068l;0@0Ke99102F]l<407IdMBH0NgUi5P3oool001@0oooo:P1kNGT407]]I@@0NeA>101Y>C@4
05df;0@0M5mD0`27NV`407]YI@@0Ng5Y101kJ64407]YH@@0NfeU0`1gJE`4085]I0@0NeaI101bJED4
07aLD@@0MfUK0`21LFd407]]H0@0NfUU101kJF4407]ECP@0JDdl101QBCh70695>P@0GTTn101_CCh4
07AHCP@0NEa?0`1gH5@407=IC@@0LeE9101YEDT406m9?P@0Kda3101[C4<306]A@@@0M61N101U?2h4
06IAA@@0PhfH102BUiHV07]iNAH0oooo000D0?ooobX0NgUi101kKFD407]DCP@0JCTd101M=R`407AO
E0<0QgY/101kJFD407]aJ@@0NfQQ101kJF4407]]I@<0MfUL1021KF@407]LF@@0LVUE101lG54407MY
F`<0PG5]101kKF0407]YI@@0NfUQ101kEDh406U=?0@0HDTn1`1RACX405i9?P@0Kddn101dF4h407UL
C`<0Mf1D101cFDd407=EB@@0JEE9101_BCh406m<@`@0Jda30`1[DD4407APGP@0IC`^101VDDD408>=
V0@0TYNF9P1kNGTF0?ooo`00503ooolZ07]iN@@0NfeU101kE4h406Ti=0@0GCH/101dGe@308MjK0@0
NfUU101kLFT407]XH@@0NfUQ101kKFD307MYG0@0PFeT101kG5T4079YE@@0O5aA101gJE/3085aK@@0
NfeP101kJFD407]YH@@0NeE>101YCC`40659?PL0HTDj101NBCh406m=?P@0M5Q>101iG4l307MPE0@0
LeU=101cEDT406UEB@@0KdTn101_C4<406]<@`<0Je51101dH5h406Dl;P@0IU551023SIP409:GURH0
NgUi5P3oool001@0oooo:P1kNGT407]]I@@0NeA>101Y>C@405df;0@0M5mD0`27NV`407]YI@@0Ng5Y
101kJ64407]YH@@0NfeU0`1gJE`4085]I0@0NeaI101bJED407aLD@@0MfUK0`21LFd407]]H0@0NfUU
101kJF4407]ECP@0JDdl101QBCh70695>P@0GTTn101_CCh407AHCP@0NEa?0`1gH5@407=IC@@0LeE9
101YEDT406m9?P@0Kda3101[C4<306]A@@@0M61N101U?2h406IAA@@0PhfH102BUiHV07]iNAH0oooo
000D0?ooobX0NgUi101cCCX4071=@@@0F3/]101cASH408edI0<0QWIX101kJFD807]]I@@0NfUM101k
IEd3079UF@@0O61H101hG5@407aQF0@0MfEE101gHED3085]I0`0NfUQ101gF58406i3>P@0HDHl0`1R
ACX406M8?0@0ITm3101[E4D407QHC`@0Lea=0`1hG50407=LD@@0Le56101YDDH406m=@`@0JdXo101[
BCh306]@A@@0M6AK101W<B8407A_HP@0ITY4102B^lLV07]iNAH0oooo000D0?ooobX0NgUi101cCCX4
071=@@@0F3/]101cASH408edI0<0QWIX101kJFD807]]I@@0NfUM101kIEd3079UF@@0O61H101hG5@4
07aQF0@0MfEE101gHED3085]I0`0NfUQ101gF58406i3>P@0HDHl0`1RACX406M8?0@0ITm3101[E4D4
07QHC`@0Lea=0`1hG50407=LD@@0Le56101YDDH406m=@`@0JdXo101[BCh306]@A@@0M6AK101W<B84
07A_HP@0ITY4102B^lLV07]iNAH0oooo000D0?ooobX0NgUi101cCCX4071=@@@0F3/]101cASH408ed
I0<0QWIX101kJFD807]]I@@0NfUM101kIEd3079UF@@0O61H101hG5@407aQF0@0MfEE101gHED3085]
I0`0NfUQ101gF58406i3>P@0HDHl0`1RACX406M8?0@0ITm3101[E4D407QHC`@0Lea=0`1hG50407=L
D@@0Le56101YDDH406m=@`@0JdXo101[BCh306]@A@@0M6AK101W<B8407A_HP@0ITY4102B^lLV07]i
NAH0oooo000D0?ooobX0NgUi101cCCX4071=@@@0F3/]101cASH408edI0<0QWIX101kJFD807]]I@@0
NfUM101kIEd3079UF@@0O61H101hG5@407aQF0@0MfEE101gHED3085]I0`0NfUQ101gF58406i3>P@0
HDHl0`1RACX406M8?0@0ITm3101[E4D407QHC`@0Lea=0`1hG50407=LD@@0Le56101YDDH406m=@`@0
JdXo101[BCh306]@A@@0M6AK101W<B8407A_HP@0ITY4102B^lLV07]iNAH0oooo000D0?ooobX0NgUi
101U<1d403@O50@0ECD[1016:R@40;fCN0<0QWI]101kJF4407]YG@P0NfUQ101kIET307IUF@@0MU]E
101]DDL407=EC@@0M6=A1022LF<307a]H0@0PFeY101kJF4407]YG@@0LUUB101ZBS`40691?P<0Id/f
101SA3X407ABAP@0KeQ;101dDDL407AKCP<0NEQ?101_EdP407AKCP@0Je55101_E4L406]AA@@0JdTn
0`1[C4L406mKC@@0GS<S101dEdP406m2?0@0T[_29P1kNGTF0?ooo`00503ooolZ07]iN@@0IC0M100d
7a@405De:`@0ARXT102mTgP308IfK@@0NfUQ101kJEd807]YH@@0NfEI0`1fIET407IKE@@0KE57101c
EDd407ASD@@0PW5S0`1lKF04085]J@@0NfUQ101kJEd4079IDP@0JTXl101R@Ch306M;=P@0Hd@j101d
DTH406mHB`@0M557101dFdh307UHC`@0KeM8101dFdh406]AA@@0KeA7101[DDD406]9?P<0Jda7101_
Fdd405hc8`@0M5M8101_@S`409:k`RH0NgUi5P3oool001@0oooo:P1kNGT406D`7@@0=1lD101E=B/4
04HZ90@0_I=h0`26MVd407]YH@@0NfUM201kJF4407]UF@<0MVEI101fFeD406eAA`@0LeE=101dHe44
089aH`<0O6eP1021KFT407]YH@@0NfUM101bFE8406Y:?0@0HT4n0`1WBcH406=4>P@0M596101_F4/4
07AAA`@0M5]>0`1iF4l406mGB0@0M5]>101[DDD406mDA`@0Je55101[BCh306]<A`@0Ke]=101N<b<4
07AGB0@0Kd8l102B^l8V07]iNAH0oooo000D0?ooobX0NgUi101U<1d403@O50@0ECD[1016:R@40;fC
N0<0QWI]101kJF4407]YG@P0NfUQ101kIET307IUF@@0MU]E101]DDL407=EC@@0M6=A1022LF<307a]
H0@0PFeY101kJF4407]YG@@0LUUB101ZBS`40691?P<0Id/f101SA3X407ABAP@0KeQ;101dDDL407AK
CP<0NEQ?101_EdP407AKCP@0Je55101_E4L406]AA@@0JdTn0`1[C4L406mKC@@0GS<S101dEdP406m2
?0@0T[_29P1kNGTF0?ooo`00503ooolV07]iN@@0Ng5]101S<BD4020J4`@0;1lI100i92440;fCN0<0
QWI/101gIEd4085]I@@0NfUI101_FE0407iWG0<0L5A9101mHE8407UGD0@0NDe8101hGTX407UND0<0
OW1Q1026MW4407]YH@@0NfUM101bDD/406A7>P@0GSlf0`1WA3@405i8?`@0L4/o101[ETT4071@@`@0
NEQ:0`1iG58406]:?`@0M5Q;101ZDDH406I=@P@0Je55101[BCh306]<A`@0JeA5101;:Qd406Db8@@0
Pe=0102G`=4V07]iNAH0oooo000D0?ooobH0NgUi101kLFd406<a9@@081XC100/7aT403TT8@@0_I=h
0`26MV`407MUG@@0PFeU101kJET406mID0@0OVML0`1`E4T407eQDP@0NEM@101iCDP407QNBP@0NEi@
0`1nL64408IfL@@0NfUQ101kJEd4079AB`@0I4Lj101N?cH306M4=0@0GTPo101`Bcl406]FB@@0L513
101iF4X307ULDP@0JdXo101dF4/406YAAP@0ITe2101[DDD406]9?P<0Jda7101[E4D404/Z7@@0IC8Q
1023Dd0409O0dBH0NgUi5P3oool001@0oooo9P1kNGT407]aK@@0Hc4U100P6Q<402`O6@@0>B@Q102m
TgP308IfK0@0MfEM1021KFD407]YF@@0KeU@101nIe`3071DB@@0OF5B101iEe0407U=B0@0N5i:101i
GU0307i`H@@0QWIa101kJF4407]YG@@0LU5;101TAcX405ho=P<0Id@d101NB3l4071;?`@0JeI9101`
D4<407UHBP<0NEaB101[BSl407AHB`@0JU56101VCD8406]AA@@0JdTn0`1[C4L406]DA@@0BbXM101U
<R4408=C@0@0Ul3A9P1kNGTF0?ooo`00503ooolV07]iN@@0MeU;101^BTH401L81@@0:ATC100d81`4
0=ZRQ@<0O6eP101kIET407]]I0@0NfUM101WDDL405U6>`<0EShb1016=2l404H]9`@0JCDU1027ED@4
06Xe9`<0LT8`102XWX/4085aK@@0NfUQ101bED/406A3>P@0GT8a0`1SBCH405hn=P@0MEM:101UDDH4
061=@`@0JTe20`1[DTX406=@@@@0OEa>101_EDT406I=@P@0Hda1101[C44307AAA`@0Je55100o8a/4
058V70@0ND@c102Gb]HV07]iNAH0oooo000D0?ooobH0NgUi101gFD/406i:AP@05`P5100Y6A<403@P
70@0fZ:50`1lKF0407]UF@@0NfeT101kJEd406MAA`@0FDHk0`1F?S8404Hd;`@0ARdW101Y=BD408ME
A0@0JSDW0`1b@S040:RNR`@0PG5]101kJF44079EB`@0I4<j101N@S4306=9=P@0GShf101eEdX406EA
AP@0H4e3101ZCD8306]BBP@0He11101mG4h406mEB@@0ITe2101SC44406]<@@<0M557101[DDD403lS
6`@0DRHL101iA3<409O:eRH0NgUi5P3oool001@0oooo9P1kNGT407MIB`@0KTY6100G20D402TI4`@0
=20L103JXXD307a]H0@0NfEI101kKF@407]YG@@0Ie57101IAS/305Hn<P@0AS@_1016;BL406Te9@@0
QeE4101Z=BL30792<0@0Z9j;1021LFd407]YH@@0LUE;101T@cX405i2<@<0HdTf101N?SH407EGBP@0
IE56101PCD<406Y=@P<0Je9:101SD44407eLCP@0KeE9101VCD8406=<@@@0Jda10`1dDDL406]AA@@0
?b<K101B9Q`407U4<`@0Ul[F9P1kNGTF0?ooo`00503ooolV07]iN@@0MeU;101^BTH401L81@@0:ATC
100d81`40=ZRQ@<0O6eP101kIET407]]I0@0NfUM101WDDL405U6>`<0EShb1016=2l404H]9`@0JCDU
1027ED@406Xe9`<0LT8`102XWX/4085aK@@0NfUQ101bED/406A3>P@0GT8a0`1SBCH405hn=P@0MEM:
101UDDH4061=@`@0JTe20`1[DTX406=@@@@0OEa>101_EDT406I=@P@0Hda1101[C44307AAA`@0Je55
100o8a/4058V70@0ND@c102Gb]HV07]iNAH0oooo000D0?ooob<0NgUi0`1oOGd40715<`@0ID<k1007
30h401P@3@@0<AXE103J/I8307]YG@@0Mf5E1021KF0407]YG@@0MV1J101A?34305M9A0@05aXH100Q
5A8403lP5@@0FD0h101c=RL306Y6?@@0PWIW1021LFh407]]J@@0LUA4101T@3L405Hk;P<0HdPb100m
50`409A`F0@0L50h101VBd4405lm;P<0PUY=101SCd<407UHAP@0KeA:101[DDD405Y5>P@0Hdm30`1d
D4L406=<?0@0?b<M101R=2H407i7?`@0U/790`1fM7DS07]iNAH0oooo000D0?ooob<0NgUi0`1oOGd4
0715<`@0ID<k100730h401P@3@@0<AXE103J/I8307]YG@@0Mf5E1021KF0407]YG@@0MV1J101A?343
05M9A0@05aXH100Q5A8403lP5@@0FD0h101c=RL306Y6?@@0PWIW1021LFh407]]J@@0LUA4101T@3L4
05Hk;P<0HdPb100m50`409A`F0@0L50h101VBd4405lm;P<0PUY=101SCd<407UHAP@0KeA:101[DDD4
05Y5>P@0Hdm30`1dD4L406=<?0@0?b<M101R=2H407i7?`@0U/790`1fM7DS07]iNAH0oooo000D0?oo
ob<0NgUi0`1oOGd40715<`@0ID<k100730h401P@3@@0<AXE103J/I8307]YG@@0Mf5E1021KF0407]Y
G@@0MV1J101A?34305M9A0@05aXH100Q5A8403lP5@@0FD0h101c=RL306Y6?@@0PWIW1021LFh407]]
J@@0LUA4101T@3L405Hk;P<0HdPb100m50`409A`F0@0L50h101VBd4405lm;P<0PUY=101SCd<407UH
AP@0KeA:101[DDD405Y5>P@0Hdm30`1dD4L406=<?0@0?b<M101R=2H407i7?`@0U/790`1fM7DS07]i
NAH0oooo000D0?ooob<0NgUi0`1oOGd40715<`@0ID<k100730h401P@3@@0<AXE103J/I8307]YG@@0
Mf5E1021KF0407]YG@@0MV1J101A?34305M9A0@05aXH100Q5A8403lP5@@0FD0h101c=RL306Y6?@@0
PWIW1021LFh407]]J@@0LUA4101T@3L405Hk;P<0HdPb100m50`409A`F0@0L50h101VBd4405lm;P<0
PUY=101SCd<407UHAP@0KeA:101[DDD405Y5>P@0Hdm30`1dD4L406=<?0@0?b<M101R=2H407i7?`@0
U/790`1fM7DS07]iNAH0oooo000D0?ooo`@0NgYj101kOWh407]eM@<0Ngin501kNGT302X@30@0gIAf
101]EDX401TD50@04a8F100U50l40>ViV@<0O6UL101kJEd407MUF@@0O6UL1021KFT406M@@`<0Le5:
100`;b`401dQ90@08QdI100l=Rh406I:?P<0N5E;101lLF<4085jM@@0Ng9]101bFD/406A3>P@0E3T/
0`1E?S8403LL60@0GT]61018<RL401D920@0KSXZ0`1JASP404<X7@@0OeA4101]AS0408=F@`@0GTm6
101SC44307A<@`@0CShb100a71L405L_90@0XFQH102F]/<307IdMB<0NgUi5P3oool001@0oooo101k
NWX407]nOP@0NgEe0`1kOWhD07]iN@<0:Q0<103MU7H406eEBP@06A@D100C4QH402DD3`@0jKVI0`1l
JE`407]YG@@0MfEI101lJE`4085]J@@0Ie130`1cDDX4030_;0@07B4T100R7AT403`f;P@0ITXn0`1h
ED/407aaH`@0PGYe101kLVd4079IB`@0I4<j101D>B`305Dn<P@0=a`H101NBdH404Pb9`@05@T8101^
>RX305Y6>0@0@bPM101oE4@406e6<0@0PeI3101NCdH406=<@@<0M4a3101>?S84034L5`@0EblT102Q
J5P409Jf``<0MWAe8`1kNGTF0?ooo`00503oool407]jNP@0Ngin101kMGD307]nOQ@0NgUi0`0Z40`4
0=fDMP@0KEE:100I51@401<B5P@09A@?103Y^IT307aYG0@0NfUM101gIET407aYG0@0PFeY101WD4<3
07=ABP@0<2l/100M8B@4028M6@@0?3H^101VBSh307QEB`@0O75S1021NWD407]bK@@0LUU;101T@cX4
05@i;0<0EChb100g71P405i;AP@0B38W100E2@P406hj:P<0FTHh1013:1d407mDA0@0KDH`1023ET<4
05i?AP@0Hda10`1dC4<404hn<P@0<A`G101G;b@40:5XF0@0U[K30`1fM7DS07]iNAH0oooo000D0?oo
o`@0NgYj101kOWh407]eM@<0Ngin501kNGT302X@30@0gIAf101]EDX401TD50@04a8F100U50l40>Vi
V@<0O6UL101kJEd407MUF@@0O6UL1021KFT406M@@`<0Le5:100`;b`401dQ90@08QdI100l=Rh406I:
?P<0N5E;101lLF<4085jM@@0Ng9]101bFD/406A3>P@0E3T/0`1E?S8403LL60@0GT]61018<RL401D9
20@0KSXZ0`1JASP404<X7@@0OeA4101]AS0408=F@`@0GTm6101SC44307A<@`@0CShb100a71L405L_
90@0XFQH102F]/<307IdMB<0NgUi5P3oool001@0oooo101kMGD407]nOP@0NgAe4`1kNGT402dH50<0
9aHB101330D407]9=`@08Q@I100L510402/H50@0gkFE0`1gIET4085]I@@0JTTo101iJUL408aoN@@0
MVQM0`1`DdX40655?@@0GdLj101JASX405Y0=0@0KUU60`1gFE4407MUF0@0PGYe101kKFD4079AA`@0
I4i0101N>B/305U6=P@0F3</101BCDX4034]:`@00PH810188QL304@b;@@0:AdH101Z@C0406=3=0@0
MEA1101NAC`405i?@`<0M551100/7Q`4034P5`@0A2<J102TE3l409g?fbH0NgUi5P3oool001@0oooo
101kMGD407]nOP@0NgAe4`1kNGT402dH50<09aHB101330D407]9=`@08Q@I100L510402/H50@0gkFE
0`1gIET4085]I@@0JTTo101iJUL408aoN@@0MVQM0`1`DdX40655?@@0GdLj101JASX405Y0=0@0KUU6
0`1gFE4407MUF0@0PGYe101kKFD4079AA`@0I4i0101N>B/305U6=P@0F3</101BCDX4034]:`@00PH8
10188QL304@b;@@0:AdH101Z@C0406=3=0@0MEA1101NAC`405i?@`<0M551100/7Q`4034P5`@0A2<J
102TE3l409g?fbH0NgUi5P3oool001@0oooo101kMGD407]nOP@0NgAe4`1kNGT402dH50<09aHB1013
30D407]9=`@08Q@I100L510402/H50@0gkFE0`1gIET4085]I@@0JTTo101iJUL408aoN@@0MVQM0`1`
DdX40655?@@0GdLj101JASX405Y0=0@0KUU60`1gFE4407MUF0@0PGYe101kKFD4079AA`@0I4i0101N
>B/305U6=P@0F3</101BCDX4034]:`@00PH810188QL304@b;@@0:AdH101Z@C0406=3=0@0MEA1101N
AC`405i?@`<0M551100/7Q`4034P5`@0A2<J102TE3l409g?fbH0NgUi5P3oool001@0oooo101kMGD4
07]nOP@0NgAe4`1kNGT402dH50<09aHB101330D407]9=`@08Q@I100L510402/H50@0gkFE0`1gIET4
085]I@@0JTTo101iJUL408aoN@@0MVQM0`1`DdX40655?@@0GdLj101JASX405Y0=0@0KUU60`1gFE44
07MUF0@0PGYe101kKFD4079AA`@0I4i0101N>B/305U6=P@0F3</101BCDX4034]:`@00PH810188QL3
04@b;@@0:AdH101Z@C0406=3=0@0MEA1101NAC`405i?@`<0M551100/7Q`4034P5`@0A2<J102TE3l4
09g?fbH0NgUi5P3oool001@0oooo101kM7DK07]iN@@01@000`0_81P402HB40@0<R0K100B2P/402`J
5@@0;APD103J[Xl307]YG0@0MfUP101`CTh405m6>P@0Jd/o1022JET307=KC@@0IdHn101O=b/406]5
<@@0M4He101fB3D309MmJ`@0PViP1021LFd407]]H0@0LU5;101TEDT405hl<0<0HTLb101SC3P407AD
B@@0HDHo10096b4402@Q7`<0;RDQ100^:RD405e5>P@0HDHd101SD4H406m=?P@0HDe50`1SC3h401XC
40@0:APD10148aT408hg9`@0XmWT9P1kNGTF0?ooo`00503oool407]dMA/0NgUi1005000302lP60@0
9Q8@100b81/4018:2`@0;1XE100]61@40=Z^S`<0NfUL101gJF04071>CP@0GdHj101[Bcl4089YF@<0
Le]=101WASh405lg:`@0JdDa101dASD407I8=@<0Uge[1022KV04085aK@@0NfeP101bDD/406AEB@@0
GS``0`1RAc8406=<>0@0M5A9101QASl400TK8@@0924O0`0^9B4402hZ9@@0GDDj101QAS@406=@AP@0
Kddn101QCDD306=<?P@06Q<@100Y61@404@S6@@0SSLW102SfN@V07]iNAH0oooo000D0?ooo`@0NgAe
6`1kNGT400D000<0;b0H100V4Q04038P6`@04PX;100/6QD402dH50@0fZj?0`1kJE`407MYH0@0L4i>
101OASX406];?`@0PVUI0`1cFdd406M6?P@0GcL[101[AC4407A6=@@0MTPe0`2GOF/4089^H0@0PG5]
101kKF04079AB`@0I5E9101N?3030697<P@0Hd`h101dE4T40656?`@02A/Q100T8Al302hU8@@0;RXU
101MACX40656=0@0He16101_CCh4065=A@<0Hd`n100J4a0402TH50@0A2<I102>=bL40:?Ii2H0NgUi
5P3oool001@0oooo101kM7DK07]iN@@01@000`0_81P402HB40@0<R0K100B2P/402`J5@@0;APD103J
[Xl307]YG0@0MfUP101`CTh405m6>P@0Jd/o1022JET307=KC@@0IdHn101O=b/406]5<@@0M4He101f
B3D309MmJ`@0PViP1021LFd407]]H0@0LU5;101TEDT405hl<0<0HTLb101SC3P407ADB@@0HDHo1009
6b4402@Q7`<0;RDQ100^:RD405e5>P@0HDHd101SD4H406m=?P@0HDe50`1SC3h401XC40@0:APD1014
8aT408hg9`@0XmWT9P1kNGTF0?ooo`00503ooolO07]iN@@01P000`0Q40`4020E4@@09ADA100L4Pl4
01lD40@0>RDQ1035T7@308abI0@0MVUM101kJFD406YGC@@0DC/b101B=S4304Ho>@@0HD<j100j;BH4
04Li<0@0CC<Z101UAS`307M]H0P0NfUQ101kG5D4079QCP@0I556101N>CH304h/70@0H3/X1022JDX4
07ADB@@0Je53101UBT8304hl<@@0C3Tc101_CCh406=9>`@0Jda5101SD3h407AD@`<0CSdd100@3@/4
020D40@0PTdm101B8AP40:kIi2H0NgUi5P3oool001@0oooo7`1kNGT400H000<08A0<100P5A4402DE
4@@0718?100O510403XU8@@0aI1d0`2<LV@407IYG@@0NfUU101ZEdd4054k<P@0DSHa0`16?cT40653
>P@0>RdV1017>C0404dc:P@0IDHl0`1gKF0807]YH@@0NeaE101bHDh406AAAP@0GSTf0`1>;1`4060k
:0@0PVU:101dE4T406]A@`@0IDY20`1>?34404`i<`@0Kddn101SBC/406]<A@@0He0n101dE4<304hm
=0@040d;100P5104089=?@@0DR4H102^fN@V07]iNAH0oooo000D0?oooal0NgUi10060003024@30@0
81DA100U5A4401`B3`@07a@@100j9B440<F@M0<0S79T101fJEd407]YI@@0JUM=101A>c84058f<@<0
ASli101Q@cX403X]9P@0AcT`101=<bX406E6?0<0MfeP201kJF4407]LE@@0LV5>101TDDH405hi=P<0
CR`L101P>bP4089YBP@0M5A9101[DD<406E:@P<0CS`a101<>C<406m=?P@0HdTk101[C4D406=@?P@0
M5A30`1>?C@4010=2`@081@@1022CCd4058Q60@0[]WT9P1kNGTF0?ooo`00503ooolO07]iN@@01P00
0`0Q40`4020E4@@09ADA100L4Pl401lD40@0>RDQ1035T7@308abI0@0MVUM101kJFD406YGC@@0DC/b
101B=S4304Ho>@@0HD<j100j;BH404Li<0@0CC<Z101UAS`307M]H0P0NfUQ101kG5D4079QCP@0I556
101N>CH304h/70@0H3/X1022JDX407ADB@@0Je53101UBT8304hl<@@0C3Tc101_CCh406=9>`@0Jda5
101SD3h407AD@`<0CSdd100@3@/4020D40@0PTdm101B8AP40:kIi2H0NgUi5P3oool001@0oooo201k
NGT407]eM@<0Ngin401kNGT400X100<06``9100M510401`D40@04@L7100U5Q4403XZ9@@0YWIM0`2H
NVT4085aI0@0NfUU101kKFD407ITF@@0IDQ50`19?d4406E8A@@0FSlh101JA3`405@k=@@0JTXo0`1b
HED4085aKP@0Mf5E101lG5T407MMDP@0J5E:101SAD@303hX90@0<Q/J1019<20404`_80@0U5Y41023
HU8306]A?P@0HDe1101SC44406M8?0@0GTLm101eDTX406]@?P<0;1lH100F40h402LP70@0STPc101B
91T404e9AP<0fmkO8`1kNGTF0?ooo`00503oool807]iN@@0NgEe0`1kOWh@07]iN@@02P400`0K30T4
01dD40@071@@100A1`L402DF4@@0>RXU102VMUd309QjJ@@0PG5T101kJFD407]]I@@0MVAI101UB4D3
04To@@@0IDQ5101J?cP405Y4?0@0E3/e101ZBSl3079QE@@0PG5^101gHED407aLF@@0MeeB101XEDX4
06=5A0<0?RPT100b6aX404T`80@0C2lP102DFT@408=RDP<0Je4n101QCD4406=<@@@0IdPl101NAcd4
07EBBP@0Je0n0`0/7aP401H@3P@09b0L102>B3<4058T6@@0CDU60`3Kg]lS07]iNAH0oooo000D0?oo
o`P0NgUi101kMGD307]nOQ00NgUi100:0@0301/<2@@07A@@100L510401471`@09AHA100j:RD40:If
G@<0V7YY1021LF@407]YI@@0NfeU101fI5T406E8A@<0BCm1101UB4D405Xo>0@0FT@l101D>cD406Y:
?`<0LV5E1021LFh407MQE@@0O5aI101gGE8406QEBP@0HdE40`0n:2@4038K6P@0BC0P101<;b0409AJ
A0@0Pf9B0`1[DCh4065=@@@0Hda1101WB3`405i7?@@0ME9:101[D3h302`O60@05Q0>100W81`408i8
<`@0DR@I101=BDH30=_Ngb<0NgUi5P3oool001@0oooo201kNGT407]dMA<0NgUi100=108302<F4`@0
7Q8?100O510401@>2P@091@@100j:RD409UVD0<0TWYZ1021LF@407]YI@@0Ng5Y101kKFD407]aK@L0
NfaU101kJ5d407]aK@P0NfQM0`1fH58407]]I0@0MVEI101bGE8407MLD@@0LV5E101bG58306M=A`@0
=b`]100[8b4401`N6`@0@BDL101<;b430792<`@0GDPh101Z@C0406<o<0@0NEU@101[C44406M8?0<0
50l=100N4`l402PK6P@0?a@=101I7Q8403@c<0<0eMWK8`1kNGTF0?ooo`00503oool807]iN@@0NgAe
4`1kNGT400d40P<08aHC100N4Pl401lD40@050h:100T510403XZ9@@0VFI@0`2BNVX4085aI0@0NfUU
101kLFT407]]I@@0Ng5]1`1kK6D407]XG@@0Ng5]201kJ5d307IPDP@0NfeT101fIET4079MDP@0MeaA
101bHED4079LDP<0Ide7100g;2d402/S8@@071hK10119A`404`_8@<0LT8c101MB3P406Y1<0@0Hcl`
101iFE0406]<@@@0IdPl0`0D3`d401hC3`@0:1/J100o50d405TN4P@0=3<`0`3EfM/S07]iNAH0oooo
000D0?ooo`P0NgUi101kM7DC07]iN@@03@@20`0S5Q<401hB3`@07a@@100D3PX402@D40@0>RXU102I
IU03099jJP@0PG5T101kJFD407]aJ@@0NfeU101kLFd707]/I@@0NfQM101kLFd807]XG@<0MV1B101k
KF@407IUF@@0LUeB101gG544079QE@@0LUaB0`1WCDL403L/;@@0:b<Q100L7Q/4044U70@0C2lQ0`1b
@S<405e8>0@0JT4`101S?c0407UID0@0Jda1101WB3`301@?3@@07Q<?100X6aX403lD3@@0FAhB100d
<c030=GIfb<0NgUi5P3oool001@0oooo201kNGT407]dMA<0NgUi100=108302<F4`@07Q8?100O5104
01@>2P@091@@100j:RD409UVD0<0TWYZ1021LF@407]YI@@0Ng5Y101kKFD407]aK@L0NfaU101kJ5d4
07]aK@P0NfQM0`1fH58407]]I0@0MVEI101bGE8407MLD@@0LV5E101bG58306M=A`@0=b`]100[8b44
01`N6`@0@BDL101<;b430792<`@0GDPh101Z@C0406<o<0@0NEU@101[C44406M8?0<050l=100N4`l4
02PK6P@0?a@=101I7Q8403@c<0<0eMWK8`1kNGTF0?ooo`00503ooolO07]iN@@02PD40`0_8b0401@?
3@@08Q@@100M4`l402DH60@0>2TS1025FD<309MfI@@0S7Y/101kJF4407]]J@@0Ng5Y101kLVd307]f
MP@0Ng5]101kK6D407]aK@@0NfQM101kKFD307]XG@@0NfEE101kJEd4079ICP@0MeaB101gG54407MU
F0<0MeQE101XFDh406A:@`@0A3Hb100/:BL402TU8P<0?bXS1013=R`405i2=P@0C3lf101`A4<406MB
@@@0GT8f0`0B3@d401hC3`@07A@A100K3`/403TJ5@@0A3D`0`3EfM/S07]iNAH0oooo000D0?oooal0
NgUi100:1@@302lS80@050l=100R510401dC3`@09APH100h:B<408EI@`<0UgIU102<NV`407]YH@@0
NfeY101kLFT407]bK@<0NgIf101kLFd407]/I@@0Ng5]101kJ5d407]]I@<0NfQM101kIED407]YG@@0
LUU>101gG58407MLD@@0MfEH0`1gF5D406QICP@0I4Y31014=S8402`Y9`@0:BDR0`0o:R<404<f;0@0
GT8f101<?cH40714@`@0Ie91101N@SH3018=3@@07Q<?100M514401/?2`@0>AXE1014=C030=GIfb<0
NgUi5P3oool001@0oooo7`1kNGT400X510<0;b<P100D3`d4028D40@07A<?100U61P403PY8`@0QEU3
0`2GMVD408ajK0@0NfUQ101kKFT407]aJ@@0Ng9]0`1kMWH407]aK@@0NfaU101kLFd407]XG@@0NfeU
0`1kJ5d407]UE@@0NfUM101bFDh407MLDP@0MeaA101gIEP307MHE@@0J5U>101TBT<404@f<P@0;2TW
100Y9B8303lZ8`@0@cH/101N@SH404`o=P@0L4A3101WDT4405i2=P<04Pd=100N4`l401dD4@@06`l;
100i6QD404@e<0<0eMWK8`1kNGTF0?ooo`00503ooolO07]iN@@02PD40`0_8b0401@?3@@08Q@@100M
4`l402DH60@0>2TS1025FD<309MfI@@0S7Y/101kJF4407]]J@@0Ng5Y101kLVd307]fMP@0Ng5]101k
K6D407]aK@@0NfQM101kKFD307]XG@@0NfEE101kJEd4079ICP@0MeaB101gG54407MUF0<0MeQE101X
FDh406A:@`@0A3Hb100/:BL402TU8P<0?bXS1013=R`405i2=P@0C3lf101`A4<406MB@@@0GT8f0`0B
3@d401hC3`@07A@A100K3`/403TJ5@@0A3D`0`3EfM/S07]iNAH0oooo000D0?oooal0NgUi100?1P@3
034Q6P@07aPF100N4Pl402D@2`@0:AXF100f91/405e0<`<0X79M102=OVh4085]H0@0NfUU101kLFT4
07]aK@<0NfeU101kMWH807]aK@@0NfQM101kKFD307]YG@@0NfUQ101kIED4079ICP@0MfEH101gG584
07MLD@<0MeaD101^FDd406eEB@@0I556101LBSl405Y:@0<0BCTa101>?3@40653>@@0HDa5101VASh4
05i8?0@0?bhS0`0J4Q4401hC3`@09aPD100G4Ph402DD40@0?RPM0`2dXZL409fVYAl0NgUi5P3oool0
01@0oooo7`1kNGT400l610<0<B4J100O61H401hB3`@09A0;100Y6QH403HT6`@0GD0c0`2PLUd408en
KP@0PFeP101kJFD407]aJ@@0Ng5]0`1kKFD407]fMPP0Ng5]101kJ5d407]]I@<0NfUM101kJF4407]U
E@@0LUU>101gIEP407MLDP@0MeaA0`1gG5@406iIC@@0KEE9101TDDH405a:?`@0FTY00`19>C4404hl
=0@0HD<i101QC4D406I6?P@0GTPl100o;R<301XB4@@07Q<?100W61@401LB3P@09A@@100n:1d30;BR
Y`@0WJJU7`1kNGTF0?ooo`00503ooolO07]iN@@03`H40`0a8AX401lH5P@07Q8?100U40/402TJ5P@0
=R@K101M@3<30:1bG@@0SGi^1021KF0407]YI@@0Ng5Y101kLFd307]]I@@0NgIf201kLFd407]XG@@0
NfeU0`1kJEd407]YH@@0NfEE101bFDh407MUF0@0MeaB101gG54307MLE0@0KUU=101]EDT406AAAP@0
G4Xo101JBT0304Ti<@@0CS`d101Q@cT4065<A@@0ITHn101NB3`403l^8`<06Q8A100N4`l402LH50@0
5a8>100U510403hX7@<0]::W102MYZDO07]iNAH0oooo000D0?oooal0NgUi100?1P@3034Q6P@07aPF
100N4Pl402D@2`@0:AXF100f91/405e0<`<0X79M102=OVh4085]H0@0NfUU101kLFT407]aK@<0NfeU
101kMWH807]aK@@0NfQM101kKFD307]YG@@0NfUQ101kIED4079ICP@0MfEH101gG58407MLD@<0MeaD
101^FDd406eEB@@0I556101LBSl405Y:@0<0BCTa101>?3@40653>@@0HDa5101VASh405i8?0@0?bhS
0`0J4Q4401hC3`@09aPD100G4Ph402DD40@0?RPM0`2dXZL409fVYAl0NgUi5P3oool001@0oooo7`1k
NGT400d40@<0=BPT100S61D402DF4P@05`h:100W5A4402LF4@@0CRlR0`1oDSP40:R>OP@0PG5T101k
JFD407]aJ@@0NgIf0`1kK6D407]]I@@0NgIf301kKFD307]UE@@0NfUQ101gGE8407MLDP@0MeaA101g
HE@707MLD@@0KUE9101_DDH406mEB@@0JUE:101[CD8306mAA@@0IU55101SBCh406]<@`@0Jda1101J
?S8402HK5`<05`h:100X6AT401T@3`@06A0;100B20P403PN5`<0QfUS102c`<8O07]iNAH0oooo000D
0?oooal0NgUi100=104303DX90@08aPE100U5Q8401L>2P@09aDA100W5Q4404h_8P<0Oe8h102XSWh4
085aI0@0NfUU101kLFT407]fMP<0NfaU101kKFD407]fMP`0NfeU0`1kIED407]YH@@0MeeB101gG584
07MLD@@0Mf5D1`1gG54406iEB@@0Ke56101_EDT406YEBP@0Jde20`1_DDD406IAA@@0HdTn101[C4<4
06]<@@@0FShb100V6aL301L>2P@0:1TI100I40l401T@2`@04PP8100h7QL308MYH`@0/l327`1kNGTF
0?ooo`00503ooolO07]iN@@03@@10`0e:2@402<H5@@09AHB100G3PX402LE4@@09aHA101>;b8307mB
>0@0Z8in1021LF@407]YI@@0Ng5Y101kMWH307]/I@@0NfeU101kMWH<07]]I@<0NfEE101kJF4407MM
DP@0MeaB101gG54407MQE0L0MeaA101^EDT406mAAP@0KeE9101ZEDX406]=@P<0Ke55101VDDD406=9
?P@0Jda3101[C44405Xn<P@09Q/G0`0G3PX402PI6@@06A0?100I40/4018820@0>1hG0`27JF<40;?0
`Ql0NgUi5P3oool001@0oooo7`1kNGT400d40@<0=BPT100S61D402DF4P@05`h:100W5A4402LF4@@0
CRlR0`1oDSP40:R>OP@0PG5T101kJFD407]aJ@@0NgIf0`1kK6D407]]I@@0NgIf301kKFD307]UE@@0
NfUQ101gGE8407MLDP@0MeaA101gHE@707MLD@@0KUE9101_DDH406mEB@@0JUE:101[CD8306mAA@@0
IU55101SBCh406]<@`@0Jda1101J?S8402HK5`<05`h:100X6AT401T@3`@06A0;100B20P403PN5`<0
QfUS102c`<8O07]iNAH0oooo000D0?oooal0NgUi100:0`4302lU8`@0;24M100U61D4024E4@@07Q<?
100Y71P403l[9@<0EcPZ102`OfT408ajJ`@0NfeY101kKFD407]fL@<0NgIf101kK6D407]aK@@0NfQM
201kKFD307]UF@@0MfEE101gGE8<07MLD@@0LeaA0`1hFDd407=IC@@0JE56101_EDT406mHB`@0JU56
0`1[CD8406]AA@@0FTTn101[C44405Y8?0@0?2`U100M5143024I5P@04`/;100I410401071`@0610@
100W5A03079HD@@0_lG77`1kNGTF0?ooo`00503ooolO07]iN@@02P<10`0_9B<402`Q7@@09APE100Q
5A4401hC3`@0:A`H100o:bD305Lh:P@0/7mY102<NV/407]]J@@0NfeU101kMW4307]fMP@0NfaU101k
LFd407]XG@P0NfeU0`1kIET407MUE@@0MeeB301gG54407=LD@<0N5U=101cFDd406UAAP@0KeE9101_
F4/406YAAP<0Jde2101[DDD405Y9?P@0Jda1101JB3`403`/9@@07A@A0`0Q6AH401<;2`@06A0@100@
1`L401P@40@09aD@0`1bF5440;o5aal0NgUi5P3oool001@0oooo7`1kNGT400X30@<0;bDS100/8Ad4
02DH5@@08ADA100N4`l402TL60@0?b/U0`1G>2X40;1oJ@@0S7Y[101kKFT407]]I@@0NgIa0`1kMWH4
07]/I@@0Ng5]101kJ5d807]]I@<0NfEI101gIED407MMDP`0MeaA101cG54307QIC@@0LeU=101YDDH4
06mEB@@0KeQ;101ZDDH306]=@P@0Je55101JBCh406]<@@@0FTPl100l;2D401dD4@<08ATF100C2`/4
01T@40@040L7100H410402LE40<0LUQA102oaLLO07]iNAH0oooo000D0?oooal0NgUi100:0`4302lU
8`@0;24M100U61D4024E4@@07Q<?100Y71P403l[9@<0EcPZ102`OfT408ajJ`@0NfeY101kKFD407]f
L@<0NgIf101kK6D407]aK@@0NfQM201kKFD307]UF@@0MfEE101gGE8<07MLD@@0LeaA0`1hFDd407=I
C@@0JE56101_EDT406mHB`@0JU560`1[CD8406]AA@@0FTTn101[C44405Y8?0@0?2`U100M5143024I
5P@04`/;100I410401071`@0610@100W5A03079HD@@0_lG77`1kNGTF0?ooo`00503ooolO07]iN@@0
3PD21`0c9R<402XO70@09ADA100F3`/4030K5P@0@BXP0`1E>bd408aKA@@0TX5c1021LFP407]YI@@0
NfeU0`1kMW4407]fMP@0Ng5]101kK6D407]XG@@0NfeU0`1kIEd407IUE@@0LUU>101cF4h407QIC@@0
O5aD101^G4d307=EB@@0LeQ?101YEDH406mEB@@0Ke55101[E4L306]AA@@0IdPl101VCd<406=4>0@0
CSXb100d8AT4024E4P<0610<100G3a0401@;2`@05`l;100H410402`I50<0Z:JU8`1kNGTF0?ooo`00
503ooolO07]iN@@03PD21`0c9R<402XO70@09ADA100F3`/4030K5P@0@BXP0`1E>bd408aKA@@0TX5c
1021LFP407]YI@@0NfeU0`1kMW4407]fMP@0Ng5]101kK6D407]XG@@0NfeU0`1kIEd407IUE@@0LUU>
101cF4h407QIC@@0O5aD101^G4d307=EB@@0LeQ?101YEDH406mEB@@0Ke55101[E4L306]AA@@0IdPl
101VCd<406=4>0@0CSXb100d8AT4024E4P<0610<100G3a0401@;2`@05`l;100H410402`I50<0Z:JU
8`1kNGTF0?ooo`00503ooolO07]iN@@03PD21`0c9R<402XO70@09ADA100F3`/4030K5P@0@BXP0`1E
>bd408aKA@@0TX5c1021LFP407]YI@@0NfeU0`1kMW4407]fMP@0Ng5]101kK6D407]XG@@0NfeU0`1k
IEd407IUE@@0LUU>101cF4h407QIC@@0O5aD101^G4d307=EB@@0LeQ?101YEDH406mEB@@0Ke55101[
E4L306]AA@@0IdPl101VCd<406=4>0@0CSXb100d8AT4024E4P<0610<100G3a0401@;2`@05`l;100H
410402`I50<0Z:JU8`1kNGTF0?ooo`00503ooolG07]iN@@0NgEe101gMWH400d91`<0<bDQ100g:BD4
02lR7`@07A4>100U6QL402TJ5`@0=B<M0`1Z?bd407i@?`@0SGQX1026MVP407]YI@L0NfeU101kMWH8
07]aK@@0NfQM101kKFD307MQE@@0PFUL101bFDh4079LD@@0LUU=101cEDd407=IC@<0Le56101_FDl4
06mAAP@0Jda5101_E4D706]AA@@0ITHk101SC44405Xk<0@0Ac<Z100S6A@402DF4`<05a8>100K4a04
01XB3`@05`l;100L510402hI5@<0m?[k101fM7DO07]iNAH0oooo000D0?oooaL0NgUi101kMGD407Mf
MP@03@T70`0c9B4403LY9@@0;b8O100M4@h402DJ5`@0:AXG100e8ad306Xo;@@0OU0o102=N6P408If
J0@0NfUU1`1kKFD407]fMPP0Ng5]101kJ5d407]]I@<0Mf5E1021JE`4079ICP@0LUaA101bFDd407=E
C@@0LeU=0`1cDDH406mIC`@0Ke56101[C4D406mDA@L0Je55101VAS/406=<@@@0FS/`1017<bX402<I
50@09AHC0`0G4Ph401/C40@06Q8?100G3`/401`D40@0;QTE0`3dn_/407IdMAl0NgUi5P3oool001@0
oooo5`1kNGT407]eM@@0MgIf100=2@L303<U8@@0=bTU100_8Ql401dA3P@09AXG100Y6QL403DS7@<0
JSl]101nD3l408ehJ0@0QWIX101kJFD707]]I@@0NgIf201kLFd407]XG@@0NfeU0`1gHED4085YG0@0
LUU>101bG544079IC@@0LeE=101cFDd307=AAP@0KeU?101_DDH406]<A@@0KeA51`1[DDD406I6>`@0
Hda1101J>c0404Lc:P@08aTD100U5Q<301LB3P@06a<@100J4Pl401L?2`@071@@100^6AD30?Cjn`@0
MWAe7`1kNGTF0?ooo`00503ooolG07]iN@@0NgEe101gMWH400d91`<0<bDQ100g:BD402lR7`@07A4>
100U6QL402TJ5`@0=B<M0`1Z?bd407i@?`@0SGQX1026MVP407]YI@L0NfeU101kMWH807]aK@@0NfQM
101kKFD307MQE@@0PFUL101bFDh4079LD@@0LUU=101cEDd407=IC@<0Le56101_FDl406mAAP@0Jda5
101_E4D706]AA@@0ITHk101SC44405Xk<0@0Ac<Z100S6A@402DF4`<05a8>100K4a0401XB3`@05`l;
100L510402hI5@<0m?[k101fM7DO07]iNAH0oooo000D0?oooaL0NgUi101kM7D407I_L0@020@30`0l
9Ad402lU8`@0=BPT100V71X402DI5P@0;B0L100a81P305a4>0@0KCl_102GKeh408QnKP@0PFeY101k
KFD307]aJ@`0Ng9]101kJF4407MYG0<0Mf5E101lJE`407MEB`@0LeU9101hG5<407=IB@@0LeU?0`1c
EDX406UEB@@0KeE9101ZBT8406IAA@@0Jda10`1[D4<406=<@@@0FT@h101B=RX403TT80@09ALB100L
510301P@2`@06A0@100E30/400`81`@060d<1016:B<30=_XjB<0NgUi5P3oool001@0oooo5`1kNGT4
07]dM@@0MVm`100810<303`U7@@0;bDS100e:2@402HL6P@09ATF100]81`4034P60<0G4@h101]?bl4
09M_GP@0R7i^1021KFT407]]I@<0Ng5Y301kLVd407]YH@@0MfUL0`1gHED407aYG0@0MeE;101cFDT4
07QLD`@0LeU9101cFDl307=EBP@0JEE9101_EDT406Y:@P@0IU55101[C44306]@@`@0Hda1101JA3P4
058f:P@0>B@P100U5a8401`D40<0610;100I410401D<2`@030P7100H3@`404HY8`<0fnSY8`1kNGTF
0?ooo`00503ooolG07]iN@@0NgAe101fKg0400P40`<0?2DM100_9B<403DX90@09Q`J100U6AH402dP
70@0<B0H0`1LA3P406do;`@0UfmN1028OVh4085]J@@0NfeU0`1kLFT<07]bK@@0NfUQ101gJE`307MQ
E@@0O6UL101gED/407=IB@@0N5aC101cFDT407=IC`<0LeE:101YEDT406mEB@@0JTY2101VDDD406]<
@@<0Je13101SC44405Y4>0@0DSHZ100i920402DG4P@071@@0`0H40/401T@40@05@`;100<20L401P=
30@0ARTS0`3Kj>TS07]iNAH0oooo000D0?oooaL0NgUi101kM7D407I_L0@020@30`0l9Ad402lU8`@0
=BPT100V71X402DI5P@0;B0L100a81P305a4>0@0KCl_102GKeh408QnKP@0PFeY101kKFD307]aJ@`0
Ng9]101kJF4407MYG0<0Mf5E101lJE`407MEB`@0LeU9101hG5<407=IB@@0LeU?0`1cEDX406UEB@@0
KeE9101ZBT8406IAA@@0Jda10`1[D4<406=<@@@0FT@h101B=RX403TT80@09ALB100L510301P@2`@0
6A0@100E30/400`81`@060d<1016:B<30=_XjB<0NgUi5P3oool001@0oooo7`1kNGT400L30P<0<AlF
100e:BL403DX90@0:alK100W5a<403<S6P@0<B@P0`1;>Rh4054[8@@0U65=102BQgD4085]I0@0NfUQ
0`1kKFT407]]H0P0NfeT101kJFD407IUE@<0LUU>101gH5@407=EB@@0LeQ9101cF4l407=LBP@0LeU=
0`1cDDD406UHB`P0Ke55101VDDD406]9?P<0IdPl101FAc/4058h;0@0>B@P100a81P401dB3`@06a@@
0`0O4`l401H?40@04`/;100B2`/402TH50@0UXf=0`1fM7DS07]iNAH0oooo000D0?oooal0NgUi1007
0`83034O5P@0=BTW100e:2@402/O6`@09aLC100c8aX4034T80<0BcX^101A:b4409AQC@@0TXMe1021
KF@407]YH@<0NfeY101kKF0807]]I0@0NfUU101fIED3079ICP@0Mf1D101cEDT407=HB@@0LeQ?101c
G4X407=IC@<0Le55101YF4/806mAA@@0IU55101[BCh306M8?0@0ETLk101B>2`403TT80@0<B0H100M
4Pl401/D40<07a<?100F3a0401<;2`@04P/;100Y61@409J=S@<0MWAe8`1kNGTF0?ooo`00503ooolO
07]iN@@01`<20`0a7aH403DY9`@0=BPT100[7a/402LG4`@0<b<J100a920304/j;P@0DB/Q102DHDd4
09:7M@@0PFeT101kJF4307]]J@@0NfeP201kKF@407]YI@@0MVEE0`1bFDh407MPE0@0LeE9101cF4T4
07=HC`@0Lea:101cFDd307=AA@@0JEQ;201_DDD406IAA@@0JdTn0`1WB3`405I7>`@0DSP/100i9204
034P60@07A8?100K510301lC3`@05Pl@100C2`/4018;2`@0:APD102FSHd307IdMB<0NgUi5P3oool0
01@0oooo7`1kNGT400L30P<0<AlF100e:BL403DX90@0:alK100W5a<403<S6P@0<B@P0`1;>Rh4054[
8@@0U65=102BQgD4085]I0@0NfUQ0`1kKFT407]]H0P0NfeT101kJFD407IUE@<0LUU>101gH5@407=E
B@@0LeQ9101cF4l407=LBP@0LeU=0`1cDDD406UHB`P0Ke55101VDDD406]9?P<0IdPl101FAc/4058h
;0@0>B@P100a81P401dB3`@06a@@0`0O4`l401H?40@04`/;100B2`/402TH50@0UXf=0`1fM7DS07]i
NAH0oooo000D0?oooal0NgUi100B2@P302HK5`@0<bDQ100l:BD402XM5P@0:1dK100[71L403HW8`<0
<b@N1011:bH407a9=@@0UWIM102=OW4407aYG0<0PFeT201kJEd407MUF@@0O6UP1021KF03079EB`@0
LeE9101cFDT406m=A@@0M5Q>101dF4/407UHB`<0Kde2101_E4L406m<A@@0JeA5101[DD4406M5?0<0
HdPl101>?S8403lT7@@0;1lH100Q510401P@2`@06A0@0`0T510401H?40@03`L7100E30`4038K5@@0
lOOg9P1kNGTF0?ooo`00503ooolO07]iN@@04PT80`0V6aL403<U8@@0?2TU100Z7AH402PM6`@0:a`G
100f9b<303<T7P@0@B/V101lBCD409IfG@@0SGia101lJE`3085]I0P0NfUM101gIET407aYH0@0PFeP
0`1bED/407=EB@@0LeU9101_CDD407AHCP@0M5Q;101iF4/306m=@P@0KeA7101_C4D406]DA@@0Je51
101WAC`306=8?0@0CShb100o91d402`O60@08A@@100H40/401T@40<091@@100F3a0400l71`@05@`<
100b6aD40?7gmbH0NgUi5P3oool001@0oooo7`1kNGT4018920<09Q/G100c9B4403`Y9@@0:QdF100X
7A/402/L5`@0=RLS0`0c91h4044[9P@0O4Te102FMUd408enL@@0O6UL0`21KF@807]YG@@0MfEI101l
JF04085]H0<0LUE;101cEDT407=IB@@0Kde5101dF4h407AHB`@0NEQ;0`1_CD8406mDA`@0Kda5101[
E4D406]A@@@0IdDl0`1SB3`404hn<P@0?b@M100/7aP4024D40@0610;100I410302@D40@05Pl@100?
1`L401D<30@0<Q/E103amoLV07]iNAH0oooo000D0?oooal0NgUi100B2@P302HK5`@0<bDQ100l:BD4
02XM5P@0:1dK100[71L403HW8`<0<b@N1011:bH407a9=@@0UWIM102=OW4407aYG0<0PFeT201kJEd4
07MUF@@0O6UP1021KF03079EB`@0LeE9101cFDT406m=A@@0M5Q>101dF4/407UHB`<0Kde2101_E4L4
06m<A@@0JeA5101[DD4406M5?0<0HdPl101>?S8403lT7@@0;1lH100Q510401P@2`@06A0@0`0T5104
01H?40@03`L7100E30`4038K5@@0lOOg9P1kNGTF0?ooo`00503ooolO07]iN@@0718?0`0Y7ah403<V
8`@0<b@P100a8Qd402<G5`@0:QdH100a8ah303DX90@0<B0H101>;B4408ENA`@0TVmM1023Je`3089a
H`@0O6UK101lKF0407MUF@@0Mf5E101lJE/307=HCP@0KdXo101dEdL406mAA@@0Kdm3101_F4X407AD
A`<0Ke55101[C44406m<@`@0Id`o101WCcl405i4>0<0FSX^101A>B/402XL5P@08A@@100L510401L?
2`@050/<0`0G30`400`820@030L7100/6AD4034L50@0h>kc9P1kNGTF0?ooo`00503ooolO07]iN@@0
718?0`0Y7ah403<V8`@0<b@P100a8Qd402<G5`@0:QdH100a8ah303DX90@0<B0H101>;B4408ENA`@0
TVmM1023Je`3089aH`@0O6UK101lKF0407MUF@@0Mf5E101lJE/307=HCP@0KdXo101dEdL406mAA@@0
Kdm3101_F4X407ADA`<0Ke55101[C44406m<@`@0Id`o101WCcl405i4>0<0FSX^101A>B/402XL5P@0
8A@@100L510401L?2`@050/<0`0G30`400`820@030L7100/6AD4034L50@0h>kc9P1kNGTF0?ooo`00
503ooolO07]iN@@0718?0`0Y7ah403<V8`@0<b@P100a8Qd402<G5`@0:QdH100a8ah303DX90@0<B0H
101>;B4408ENA`@0TVmM1023Je`3089aH`@0O6UK101lKF0407MUF@@0Mf5E101lJE/307=HCP@0KdXo
101dEdL406mAA@@0Kdm3101_F4X407ADA`<0Ke55101[C44406m<@`@0Id`o101WCcl405i4>0<0FSX^
101A>B/402XL5P@08A@@100L510401L?2`@050/<0`0G30`400`820@030L7100/6AD4034L50@0h>kc
9P1kNGTF0?ooo`00503ooolO07]iN@@0718?0`0Y7ah403<V8`@0<b@P100a8Qd402<G5`@0:QdH100a
8ah303DX90@0<B0H101>;B4408ENA`@0TVmM1023Je`3089aH`@0O6UK101lKF0407MUF@@0Mf5E101l
JE/307=HCP@0KdXo101dEdL406mAA@@0Kdm3101_F4X407ADA`<0Ke55101[C44406m<@`@0Id`o101W
Ccl405i4>0<0FSX^101A>B/402XL5P@08A@@100L510401L?2`@050/<0`0G30`400`820@030L7100/
6AD4034L50@0h>kc9P1kNGTF0?ooo`00503ooolO07]iN@@0:QhK0`0J4Ph403<X90@0;b8O100i;2P4
02HI50@09ALD100g:bL302dP70@0>2PS100Z6QH405a3<`@0Hd0c102<ED83099eH`@0ME]=101nJf44
07UTE`@0NF1?101nI5P306]AA@@0GT0d101dBcd407U@?@@0M599101_D4<406m8>P<0KeI9101[C3P4
06M8@@@0Hd@h101N@cH40593=P<0@RPQ100n8aT402DH50@07Q<?100G40/801@;2`<040L7100;1`L4
01@;2`@0:1HA102=NWH40863PbH0NgUi5P3oool001@0oooo7`1kNGT402XN6`<06Q8>100c:2@402lR
7`@0>B`X100V6A@402DG50@0=b/W0`0]81`403PX8`@0:QXF101L@c<406=0<`@0S5E20`2BMF<407EK
C@@0OV]Q101iI5L407UPC`@0OVAH0`1[DDD405i0=0@0M4/m101iD3d407ABB@@0Ke13101_B3X306mF
B@@0Jd`h101WB44406=4>0@0GT<f101B@cH3048X8@@0?R<I100U61@401hC3`@05a0;200D2`/30107
1`@02`L7100D2`/402PF4@@0SGYf1021Ph<V07]iNAH0oooo000D0?oooal0NgUi100Z7Q/301XB3P@0
<bPT100_8Ql403T/:0@09QTD100U5a@403L[9`<0;B0L100h:2<402XJ5P@0G4<c101S@3<408aE@P<0
TWES101eFdd407i[H@@0NFAG101iH4l407iTF0<0Je55101N@3@407A;?@@0NE0m101dDTT406m@@`@0
KdPj0`1_ETT406]<>0@0IdQ1101SA3P405i3=P@0DT<f0`12:24403hS6@@09APD100N4`l401L@2`P0
50/;0`0@1`L400/71`@050/;100X5Q4408ejMP@0PH>39P1kNGTF0?ooo`00503ooolO07]iN@@0:QhK
0`0J4Ph403<X90@0;b8O100i;2P402HI50@09ALD100g:bL302dP70@0>2PS100Z6QH405a3<`@0Hd0c
102<ED83099eH`@0ME]=101nJf4407UTE`@0NF1?101nI5P306]AA@@0GT0d101dBcd407U@?@@0M599
101_D4<406m8>P<0KeI9101[C3P406M8@@@0Hd@h101N@cH40593=P<0@RPQ100n8aT402DH50@07Q<?
100G40/801@;2`<040L7100;1`L401@;2`@0:1HA102=NWH40863PbH0NgUi5P3oool001@0oooo7`1k
NGT405mEG@<04@P7100V71T403@U8@@0=BLS100Y7aT402DF5P@0>RDK0`0_924403`^:P@0:b4N100e
9b4404@a:`@0GcP[0`1aB3D40659@`@0HT/n101hBcX407MKBP@0LeE60`1L?cH405Pi:P@0EcHX101]
A2h407=4=`@0Kdhj101eAcP30696>`@0HSl^101[@S<406=4=P@0DC/b101<<2D303TP60@0;APD100O
510401P@2`@050/;100@1`L400`820L030L7100O510402/H50@0i^WY:P1kNGTF0?ooo`00503ooolO
07]iN@@0GeEM0`0A20L402HL6@@0=2DQ100e9b<402TO6@@09AHF100j9A/302lT8@@0?2hZ100[8Ah4
03DW8@@0A34[101O>2/30758=@@0HDU3101RBch407Q;>P@0Me]:101cEDH305`o=P@0F3TZ101G=RP4
06e4;P@0Ld@g101_CSX407E7>0<0HTHk101R?bh406]2<`@0Hd@f101A>c8404``9@<0>B0H100]61@4
01lD40@0610;100D2`/401071`@030P81`0<1`L401lD40@0:aPD103VjNTZ07]iNAH0oooo000D0?oo
oal0NgUi101OEEd301481`@09Q`I100d9B4403DW8`@0:AlI100U5QH403XU6`<0;b@Q100l;RX402/Q
7P@0=BLQ1014<B/405lh:`<0LDPe101QBD<4069;?P@0N4/j101gFdX407=EAP<0G3lf101H>BX405Lf
:0@0KD@^101cA3L406m>>P@0MDLh0`1RAS/4068o;P@0Jd8c101SA3H4054k<P@0C30U0`0i81P402dH
50@07a@@100H40/401@;2`@040L7100<20P700`71`@07a@@100[61@40>KYjBX0NgUi5P3oool001@0
oooo8`1kNGT301lF4`@06Q<?100e:2@402lV8`@0;24M100H4@h403LT7P<0?2hZ100i;2P403X^:P@0
=BXW100o<RX404@b:P<0AC0V1011:bP4044Z7`@0BB/U101J=BP405Tn<P<0?R/W1016;BD404h[80@0
CRlN101C;bD406I1;P@0Hcd]0`1G=RP405Ph:`@0CbhQ101E>2h404L[8`@0?2DM0`0Y5a<402XL60@0
5Ph:100H40/401<;2`@03`L7100;1`L300`71`@08A@@100G410406I:@`@0[[^m:P1kNGTF0?ooo`00
503ooolS07]iN@<07aHC100J4`l403DX90@0;bHS100/8Ad401PA3P@0=b@N0`0l;RX403T/:0@0>RhZ
100e:RL403lb:P@0A38Z0`15<2H4044[:0@0@BXO1019:bD405Xe:0@0FChb0`0n:bL404H]9@@0CR/P
101>;ah405<_9@@0IT4^101S?Bd305Lf:0@0F3P[101?;R4405Dh;P@0Ab/S100l9Ad302TG4`@0:Q`H
100F3PX401P@2`@04`/;100?1`L400/71`<030L7100Q510401L@40@0ITY3102^^kdZ07]iNAH0oooo
000D0?ooob<0NgUi0`0O5Q<401XC3`@0=BPT100_9R<402`Q7@@0614>100g91h303`^:P@0>B`X100j
;RX403DZ9`@0?c8Z1014<RX304D`9P@0@B/X1011:Ql404T[9@@0FSDX101I?S8303h[9`@0ARdU101>
:b0404h_7P@0DblU101V@Bh406<m;@<0EcHX101H>2/404l^8@@0ECP^1017:b<403`U7@<0:ALC100Z
71P401H>2P@0610;100C2`/400l71`@02`L70`0<1`L4024D40@05a0@101VBT<40:jk_BX0NgUi5P3o
ool001@0oooo8`1kNGT301lF4`@06Q<?100e:2@402lV8`@0;24M100H4@h403LT7P<0?2hZ100i;2P4
03X^:P@0=BXW100o<RX404@b:P<0AC0V1011:bP4044Z7`@0BB/U101J=BP405Tn<P<0?R/W1016;BD4
04h[80@0CRlN101C;bD406I1;P@0Hcd]0`1G=RP405Ph:`@0CbhQ101E>2h404L[8`@0?2DM0`0Y5a<4
02XL60@05Ph:100H40/401<;2`@03`L7100;1`L300`71`@08A@@100G410406I:@`@0[[^m:P1kNGTF
0?ooo`00503ooolS07]iN@<0A3]4100?2PL402lT80@0<BDQ100a920402HN6`@0<RHR0`0l;RX403d`
;0@0=BPT100j:bL4044Y8`@0B2lT0`0f9ah4034U8`@0;1`G100j9b<4030I50@0@BdW0`0e9B44034Q
7@@0<QXE100d81X403@K5@@0?alH1013:A`303hU6`@0@BLL100g6aD403TN60@0<Q`F100`6aD301`D
40@06a4<100D2`/401D<2`@050/;100;1`L400`71`<08A@H100Q50l402`R80@0[Z:P;P1kNGTF0?oo
o`00503ooolS07]iN@<0A3]4100?2PL402lT80@0<BDQ100a920402HN6`@0<RHR0`0l;RX403d`;0@0
=BPT100j:bL4044Y8`@0B2lT0`0f9ah4034U8`@0;1`G100j9b<4030I50@0@BdW0`0e9B44034Q7@@0
<QXE100d81X403@K5@@0?alH1013:A`303hU6`@0@BLL100g6aD403TN60@0<Q`F100`6aD301`D40@0
6a4<100D2`/401D<2`@050/;100;1`L400`71`<08A@H100Q50l402`R80@0[Z:P;P1kNGTF0?ooo`00
503ooolS07]iN@<0A3]4100?2PL402lT80@0<BDQ100a920402HN6`@0<RHR0`0l;RX403d`;0@0=BPT
100j:bL4044Y8`@0B2lT0`0f9ah4034U8`@0;1`G100j9b<4030I50@0@BdW0`0e9B44034Q7@@0<QXE
100d81X403@K5@@0?alH1013:A`303hU6`@0@BLL100g6aD403TN60@0<Q`F100`6aD301`D40@06a4<
100D2`/401D<2`@050/;100;1`L400`71`<08A@H100Q50l402`R80@0[Z:P;P1kNGTF0?ooo`00503o
oolS07]iN@<0A3]4100?2PL402lT80@0<BDQ100a920402HN6`@0<RHR0`0l;RX403d`;0@0=BPT100j
:bL4044Y8`@0B2lT0`0f9ah4034U8`@0;1`G100j9b<4030I50@0@BdW0`0e9B44034Q7@@0<QXE100d
81X403@K5@@0?alH1013:A`303hU6`@0@BLL100g6aD403TN60@0<Q`F100`6aD301`D40@06a4<100D
2`/401D<2`@050/;100;1`L400`71`<08A@H100Q50l402`R80@0[Z:P;P1kNGTF0?ooo`00503ooolS
07]iN@<0L6Y`100H3@d401/C40@0<B@P100e:2@402lR7`@0@38^0`0[7Q/404@c;P@0:alK100j:bL4
04@^9P@0=B@Q0`0c8Qd4034T80@0:1dI100l:BH401hD50@0;R@N0`0/6AD402XJ5@@08A@@100O5A44
02DD40@0;QTE100/6QD302@E40@09aHA100U510402hI5@@08A@@100S510301L@2`@0610;100C2`/4
01@;2`P030L7100D2`/302hN6`@09AHB1027R8Pb07]iNAH0oooo000D0?ooob<0NgUi0`1`JW0401P=
3@@06a<@100a920403DX90@0;b8O1010<Rh302/N6`@0A3<^100[7a/403X[9`@0A2hV100e924303<R
7@@0<B@P100X7AT403`Y9P@07Q@D100^91h302`I5@@0:QXE100Q510401lE4@@09A@@100^6AD402`J
5@<091D@100W5Q4402DD40@0;QTE100Q510402<D40<05a0;100H40/401<;2`@050/;200<1`L401@;
2`<0;QhK100U5Q8408N8R380NgUi5P3oool001@0oooo8`1kNGT3071ZL0@060d=100K4a04034T80@0
=BPT100_8Ql4040b;P<0:ahK1014<bh402/O6`@0>R/W1014;RH403DT8@<0<b8M100a920402PM6@@0
?2TV100N51@402hT7P<0;1TE100Z6QD4024D40@07aDA100U510402hI5@@0;1XE0`0T5A0402LF4@@0
9A@@100^6AD4024D40@08a@@0`0G40/401P@2`@04`/;100D2`/800`71`@050/;0`0^7Q/402DF4P@0
QhR8<P1kNGTF0?ooo`00503ooolS07]iN@<0L6Y`100H3@d401/C40@0<B@P100e:2@402lR7`@0@38^
0`0[7Q/404@c;P@0:alK100j:bL404@^9P@0=B@Q0`0c8Qd4034T80@0:1dI100l:BH401hD50@0;R@N
0`0/6AD402XJ5@@08A@@100O5A4402DD40@0;QTE100/6QD302@E40@09aHA100U510402hI5@@08A@@
100S510301L@2`@0610;100C2`/401@;2`P030L7100D2`/302hN6`@09AHB1027R8Pb07]iNAH0oooo
000D0?ooobH0NgUi1016>cl4018<2@@0<2PT100e:2@402lR7`@0;R@O0`0l;2P403d`;0@0:24N100_
81`404HZ7`@09adJ0`0a8ah402lQ7@@08APL100d9Ah402<F5`@0:QXE0`0Q51P401lD3`@07A@@100H
40/401lD40P081@@0`0I40/401H<30@06a4<100W5A4401P@2`@05P`<0`0I40/401P@40@04`/;100<
1`L401@;2`@06A<?100U6AL302TH53X0NgUi5P3oool001@0oooo9P1kNGT404Hk?`@04P`9100`:2@4
03DX90@0;b8O100^91l303`/:0@0?C0/100X8Ah402lP70@0ARXO100W7AX3034S7P@0;b4M100Q61`4
03@U7P@08aHG100Z6QD3024D60@07a@?100M510401P@2`@07a@@200P510301T@2`@05P`<100K4@`4
02LE4@@0610;100F30`301T@2`@0610@100C2`/400`71`@050/;100I4`l402DI5`<0:APD>P1kNGTF
0?ooo`00503ooolV07]iN@@0AS/o100B30T4030X90@0=BPT100_8Ql402hT7`<0?2`X100m<2`402PQ
7P@0;b0L1016:Ql402LM6P<0<B<N100_8Ad4024H70@0=2DN100S5QL402XJ5@<08A@H100O50l401dD
40@0610;100O5108020D40<06A0;100F30`401/A30@09aDA100H40/401H<30<06A0;100H410401<;
2`@030L7100D2`/401TC3`@09ATG0`0Y61@j07]iNAH0oooo000D0?ooobH0NgUi1016>cl4018<2@@0
<2PT100e:2@402lR7`@0;R@O0`0l;2P403d`;0@0:24N100_81`404HZ7`@09adJ0`0a8ah402lQ7@@0
8APL100d9Ah402<F5`@0:QXE0`0Q51P401lD3`@07A@@100H40/401lD40P081@@0`0I40/401H<30@0
6a4<100W5A4401P@2`@05P`<0`0I40/401P@40@04`/;100<1`L401@;2`@06A<?100U6AL302TH53X0
NgUi5P3oool001@0oooo9P1kNGT406YPIP@050L7100V71X403LY9@@0;b8O100`9R8303<Y9@@0?2/W
100[81`402TL60@0<1hI100Q510303<T7`@09APH100S61T4028E40@08Q@J100J40l301H<30@06Q4@
100I410401@;2`@06Q4@100E30/401XA40<050/;100H410401`D3`@06A0@100D2`/400`71`/03@P8
100H410401L?2`@05@`<100X4Pd3089jN`@0PH>3=P1kNGTF0?ooo`00503ooolV07]iN@@0JV1V100D
1`L402HL6P@0=bTU100_8Ql4030V8P<0<bTU100l:bL402/P70@0:A`H100`7QT4024D40<0<b@O100U
61P402<H6@@08QD@100R51X401X@3`<05P`<100J4A0401T@40@050/;100J4A0401D<2`@06Q4@0`0D
2`/401P@40@071@?100I410401@;2`@030L72`0=20P401P@40@05`l;100E30`402PB3@<0PWYk1021
Ph<f07]iNAH0oooo000D0?ooobH0NgUi101ZH6H401@71`@09Q`J100g:BD402lR7`@0<2HR0`0c:BD4
03`[9`@0:b0L100Y71P4030N6@@08A@@0`0c91l402DH60@08aPI100R5A04028D6P@06Q0?0`0F30`4
01XA40@06A0@100D2`/401XA40@05@`;100J4A0301@;2`@0610@100L50l401T@40@050/;100<1`L;
00d820@0610@100G3`/401D<30@0:18=0`22NW/40863PcH0NgUi5P3oool001@0oooo9P1kNGT406YP
IP@050L7100V71X403LY9@@0;b8O100`9R8303<Y9@@0?2/W100[81`402TL60@0<1hI100Q510303<T
7`@09APH100S61T4028E40@08Q@J100J40l301H<30@06Q4@100I410401@;2`@06Q4@100E30/401XA
40<050/;100H410401`D3`@06A0@100D2`/400`71`/03@P8100H410401L?2`@05@`<100X4Pd3089j
N`@0PH>3=P1kNGTF0?ooo`00503ooolZ07]iN@@0>2d/100=1`L4028I5P@0=2DQ100c:BD3034X90@0
?2`X100Z7b0402DF4@@0:AdI100J4Pl302LF4P@07A@A100T514401@;2`@05``=100I410301L?3`@0
50/;100I410401<;2`@06A0@100C2`/402XI5@<02@H7100K4A4401dD40@05`l@100;1`L400`71`<0
40L7100G410401D>3P@0610@100Y61<402HL5P@0@blW0`2^`<`j07]iNAH0oooo000D0?ooobX0NgUi
100h;B`400d71`@08QTF100d9B4403<Y9@<0<BPT100l;2P402XO80@09AHA100Y7AT401XB3`<09aHB
100M514402@D4@@050/;100G30d401T@40<05`l?100D2`/401T@40@04`/;100I410401<;2`@0:QTE
0`091PL401/A4@@07A@@100G3a0400/71`@030L70`0@1`L401L@40@05@h>100H410402TH4`@09Q`F
1013;bL30:k0c3X0NgUi5P3oool001@0oooo:P1kNGT403P];0@03@L7100R6AH403@U8@@0<bTU0`0a
:2@403`/:0@0:QlP100U5Q4402TM6@@06Q8?0`0W5Q8401dD4@@091@A100D2`/401L<3@@06A0@0`0G
3`l401@;2`@06A0@100C2`/401T@40@04`/;100Z6AD300T61`@06a4A100M510401L?40@02`L7100<
1`L301071`@05a0@100E3Ph401P@40@0:APC100V71H404<_9`<0[/3<>P1kNGTF0?ooo`00503oool^
07]iN@@0>2d/100910@402@O7@@0;B0L0`0l;b/403T/:0@0=2PV100Q6AH402dN6`@06a4E0`0H40l4
028D40@0610@100K4`l401XB3`@05`l@1`0D2`/401D<30@050/;100E30`401`D40@06a0@0`0V92`4
028N6`@06`lB100B2`X401H?3`@0618>0`0H4@h401L?40@0;B0L100O5aD402TG4`@0C30U102<R8<m
07]iNAH0oooo000D0?ooobh0NgUi100h;B`400T410@091lM100]81`303`_:`@0>B`X100d:2H4024I
5P@0;AhK100K4AD301P@3`@08Q@@100H410401/C3`@06Q8?100G3a0701@;2`@05@`<100D2`/401D<
30@071@@100K410302HT;0@08QhK100K3a84018;2P@05Pl?100H4Ph301PA3P@05`l@100]81`401lG
5@@0:ALC101<<2D408b8Pcd0NgUi5P3oool001@0oooo;P1kNGT403P];0@02@@4100T7ad402dP70<0
?2l[100i;2P403@X9P@08ATF100]7Q/401/A5@<0610?100R510401P@40@06a<?100J4Pl401L?40L0
50/;100E30`401@;2`@05@`<100L510401/@40<09R@/100R7Q/401/?4P@04P/:100F3`l401PB3P<0
614>100G3a0402dP70@07aLE100Y5a<404``9@@0S8R3?@1kNGTF0?ooo`00503oool^07]iN@@0>2d/
100910@402@O7@@0;B0L0`0l;b/403T/:0@0=2PV100Q6AH402dN6`@06a4E0`0H40l4028D40@0610@
100K4`l401XB3`@05`l@1`0D2`/401D<30@050/;100E30`401`D40@06a0@0`0V92`4028N6`@06`lB
100B2`X401H?3`@0618>0`0H4@h401L?40@0;B0L100O5aD402TG4`@0C30U102<R8<m07]iNAH0oooo
000D0?oooc80NgUi100i:BP400X71P@09b4N0`0]81`403P]:0@0@c8^100/928402XL5@@08APH0`0G
4@l401T@40@050/;100J4@`401T@40L050/;100H410401<;2`@0610@100C2`/401H<30@0;bXZ0`0Y
72L4040f;P@0:R8S100K5QP402TS80@07QPE0`0G4@h402LJ60@0:QdI100e:2@403PQ6`@0PGYj101k
OWhm07]iNAH0oooo000D0?oooc80NgUi100i:BP400X71P@09b4N0`0]81`403P]:0@0@c8^100/9284
02XL5@@08APH0`0G4@l401T@40@050/;100J4@`401T@40L050/;100H410401<;2`@0610@100C2`/4
01H<30@0;bXZ0`0Y72L4040f;P@0:R8S100K5QP402TS80@07QPE0`0G4@h402LJ60@0:QdI100e:2@4
03PQ6`@0PGYj101kOWhm07]iNAH0oooo000D0?oooc80NgUi100i:BP400X71P@09b4N0`0]81`403P]
:0@0@c8^100/928402XL5@@08APH0`0G4@l401T@40@050/;100J4@`401T@40L050/;100H410401<;
2`@0610@100C2`/401H<30@0;bXZ0`0Y72L4040f;P@0:R8S100K5QP402TS80@07QPE0`0G4@h402LJ
60@0:QdI100e:2@403PQ6`@0PGYj101kOWhm07]iNAH0oooo000D0?oooc80NgUi100i:BP400X71P@0
9b4N0`0]81`403P]:0@0@c8^100/928402XL5@@08APH0`0G4@l401T@40@050/;100J4@`401T@40L0
50/;100H410401<;2`@0610@100C2`/401H<30@0;bXZ0`0Y72L4040f;P@0:R8S100K5QP402TS80@0
7QPE0`0G4@h402LJ60@0:QdI100e:2@403PQ6`@0PGYj101kOWhm07]iNAH0oooo000D0?oooc80NgUi
1021OWh403PX9`@04PX80`0/:2L402hT8@@0@c@_100j;RX403DX8`@07aHC0`0S6AH402PO7P@06aPF
100K40d401TC40@05Ph?0`0G3`l801@;2`@07ADI100F3Ph401/C3`@07A<D0`0`924403`Z9@@06a8B
100T61<402DI50@07A8B0`0R510402`N6P@0<B0H101A>2d4061HH@@0S8f8@@1kNGTF0?ooo`00503o
oolb07]iN@@0PGin100h:2L4018:20<0;2PW100^924404<d;`@0>RhZ100e:2<401lF4`<08aTF100X
7ah401/H5P@06a0=100I4a0401H>3`<05`l?200D2`/401dE6@@05Ph>100K4`l401dC50<0<2@Q100l
:RD401/B4P@091PC100U6A@401dB4P<08Q@@100/7QX4034P60@0DCP]101PF64408b=R440NgUi5P3o
ool001@0oooo<P1kNGT4085nOP@0>2PW100B2PP302`X9`@0;R@Q1013=2l403X^:P@0=BPS100O5Q<3
02<I5P@0:1lN100K61H401/@3@@06A<@100F3Pl301L?3`P050/;100M5AT401H>3P@06a<?100M4a@3
030T8@@0?2XU100K4Q8402@H4`@09ATD100M4Q83028D40@0;1hJ100a81P4054h;@@0H5QQ102<SHQ1
07]iNAH0oooo000D0?oooc80NgUi1021OWh403PX9`@04PX80`0/:2L402hT8@@0@c@_100j;RX403DX
8`@07aHC0`0S6AH402PO7P@06aPF100K40d401TC40@05Ph?0`0G3`l801@;2`@07ADI100F3Ph401/C
3`@07A<D0`0`924403`Z9@@06a8B100T61<402DI50@07A8B0`0R510402`N6P@0<B0H101A>2d4061H
H@@0S8f8@@1kNGTF0?ooo`00503ooolj07]iN@@0<QhH0`0F3P/402@K60@0?blZ101<?CP403lg=0@0
:B0N0`0O5Q<402PJ6P@0:QXE100]8Ql401lK5`@050d>0`0D2`/4024H70@071DG100W7a/401/D60@0
<RHP100C3a<304Hf;P@0:QlP100S71X402HN6`@08Q/G100V7Q`3038X8P@09Q`K101B=RP407E`L@@0
JVE[A@1kNGTF0?ooo`00503ooolj07]iN@@0<QhH0`0F3P/402@K60@0?blZ101<?CP403lg=0@0:B0N
0`0O5Q<402PJ6P@0:QXE100]8Ql401lK5`@050d>0`0D2`/4024H70@071DG100W7a/401/D60@0<RHP
100C3a<304Hf;P@0:QlP100S71X402HN6`@08Q/G100V7Q`3038X8P@09Q`K101B=RP407E`L@@0JVE[
A@1kNGTF0?ooo`00503ooolj07]iN@@0<QhH0`0F3P/402@K60@0?blZ101<?CP403lg=0@0:B0N0`0O
5Q<402PJ6P@0:QXE100]8Ql401lK5`@050d>0`0D2`/4024H70@071DG100W7a/401/D60@0<RHP100C
3a<304Hf;P@0:QlP100S71X402HN6`@08Q/G100V7Q`3038X8P@09Q`K101B=RP407E`L@@0JVE[A@1k
NGTF0?ooo`00503ooolj07]iN@@0<QhH0`0F3P/402@K60@0?blZ101<?CP403lg=0@0:B0N0`0O5Q<4
02PJ6P@0:QXE100]8Ql401lK5`@050d>0`0D2`/4024H70@071DG100W7a/401/D60@0<RHP100C3a<3
04Hf;P@0:QlP100S71X402HN6`@08Q/G100V7Q`3038X8P@09Q`K101B=RP407E`L@@0JVE[A@1kNGTF
0?ooo`00503oooln07]iN@<0<RPR100>20P401TD40@0>R/W1014=C04040k?`<0=RPQ100/9BH402lX
9P@09Q/K100X9RD402lW;P<09R<M100M5QX402@O:0@0;b8N100b;CL4030S6`@08a`L0`11<Bd403@U
8`@0=28O100d91`402hV90@0?bhV0`1>>2`402@L60@0WI:=101kM7E907]iNAH0oooo000D0?oooch0
NgUi0`0b:28400h820@06A@@100j:bL404@e<0@0@3/o0`0f:24402`U9P@0;bPV100V6a/402PV9@@0
;bL^0`0V8ad401dF6P@091lX100_8Qh4038]=`@0<2<K100S71`3044a;@@0=2DS100d8Ql403@T70@0
;RHT100o;RH304hh;0@091`H102MTXd407]dMDT0NgUi5P3oool001@0oooo?P1kNGT3038X8P@03PP8
100I510403X[9`@0A3D`1010>cl303HX8@@0;2DV100_:2H402HK6`@0:2HU100_9bh302HS7@@07AHJ
100T7bP402lR7P@0<Rdg100`8a/402<L70<0@C4]100d9B<403@R7`@0=2@L100^9R@403l^9P<0CSP/
100T71P409fBS@@0NgAeB@1kNGTF0?ooo`00503oooln07]iN@<0<RPR100>20P401TD40@0>R/W1014
=C04040k?`<0=RPQ100/9BH402lX9P@09Q/K100X9RD402lW;P<09R<M100M5QX402@O:0@0;b8N100b
;CL4030S6`@08a`L0`11<Bd403@U8`@0=28O100d91`402hV90@0?bhV0`1>>2`402@L60@0WI:=101k
M7E907]iNAH0oooo000D0?oood40NgUi101UFf4402HN7@@03`T9100e:R<403Dd?@<0G4Y51013>3H4
048i=0@0=Rd]100e<cH403ld=P<0@SPd100/8b8403D/;P@0:QlQ100c9B8403HW8`@0>B`X0`0e:2@4
04@X80@0?bXT100l;2D403lc;P@0>BDM0`1QBdP405UECE40NgUi5P3oool001@0oooo@@1kNGT406EK
H@@09QhM100?2@T403DZ8`@0=C@m0`1LBTD404<h=P@0@STd100f;Bd403Dc=P@0?c@f0`12>3@402`S
8P@0=B`^100Z7b4403<U8P@0=RLS100i;2P303DX90@0A2PP100o:R@403`/9@@0?c<^100i9Ad3065;
B0@0FEE=D@1kNGTF0?ooo`00503ooom107]iN@@0IE]Q100V7Qd400l92@@0=BXS100e=3d305a:A@@0
@cPf1012>C@403H];@@0=C<f100o=3H3048h=0@0;2<R100e;2h402XO8@@0<bDR100f9b<403T/:0<0
=BPT1014:20403lZ90@0?2`U100o<bh403TU7@<0HD]8101IEDeA07]iNAH0oooo000D0?ooo`@0NgYj
101kOWi107]iN@@0<RP`100V7Qd401XK90<0:B<V101JC4H4055=DP@0?CH^1013>CD404<i=P<0ASXf
1013=SH403lf<0@0;bX[100h;R/402`X8`@0?c@d0`0o<c0403TZ8`@0AS4Z100i9B4407iWJ0@0BC`a
0`13<SIE07]iNAH0oooo000D0?ooo`@0NgYj101kOWi107]iN@@0<RP`100V7Qd401XK90<0:B<V101J
C4H4055=DP@0?CH^1013>CD404<i=P<0ASXf1013=SH403lf<0@0;bX[100h;R/402`X8`@0?c@d0`0o
<c0403TZ8`@0AS4Z100i9B4407iWJ0@0BC`a0`13<SIE07]iNAH0oooo000D0?ooo`@0NgYj101kOWi1
07]iN@@0<RP`100V7Qd401XK90<0:B<V101JC4H4055=DP@0?CH^1013>CD404<i=P<0ASXf1013=SH4
03lf<0@0;bX[100h;R/402`X8`@0?c@d0`0o<c0403TZ8`@0AS4Z100i9B4407iWJ0@0BC`a0`13<SIE
07]iNAH0oooo000D0?ooo`@0NgYj101kOWi107]iN@@0<RP`100V7Qd401XK90<0:B<V101JC4H4055=
DP@0?CH^1013>CD404<i=P<0ASXf1013=SH403lf<0@0;bX[100h;R/402`X8`@0?c@d0`0o<c0403TZ
8`@0AS4Z100i9B4407iWJ0@0BC`a0`13<SIE07]iNAH0oooo000D0?ooo`@0NgAeC@1kNGT4071ZL0<0
<Rdj1019?3l405YAG@@0BC]2101>@3<4030X:P<0<BXX101A@T@404dj;`@0BS`h101A?cX404Hj=0@0
ASPd0`1;=2/404@h<0@0PGYk100Q6AP405mAEe`0NgUi5P3oool001@0oooo101kM7E=07]iN@@0L6Y`
0`0b;CX404Tl?`@0FU5M1019>d8404i0<`@0<2PZ0`0a:RP40552A0@0CCX_101:?3P4054o>P@0ASXd
1016>3@304/d:`@0A3P`1021NW/4024I60@0Ge5GG01kNGTF0?ooo`00503oool407]dMDd0NgUi101`
JW03038]>P@0BC`o101JDEd404Tk@P@0CT0c100`:2X3034Z:0@0DD94101=>Rl404Xl>0@0DClj1016
>S@404Hh=0<0Bc@[1014>304085jN`@08ATH101ODEML07]iNAH0oooo000D0?ooo`@0NgAeC@1kNGT4
071ZL0<0<Rdj1019?3l405YAG@@0BC]2101>@3<4030X:P<0<BXX101A@T@404dj;`@0BS`h101A?cX4
04Hj=0@0ASPd0`1;=2/404@h<0@0PGYk100Q6AP405mAEe`0NgUi5P3oool001@0ooooH01kNGT4071Z
M@@0NgAe101UFfH703dgA0@0>2d/100h:bX403Pb<0@0>2d/100b:2L302dN60@0;B<M101kM7ET07]i
NAH0oooo000D0?ooof00NgUi101`JWD407]dM@@0IE]V1`0m=d@403P];0@0>2/Z100h<S0403P];0@0
<RPW0`0]7QP402dS7@@0NgAeI01kNGTF0?ooo`00503ooomP07]iN@@0L6Ye101kM7D406EKIPL0?CM4
100h;B`403P[:P@0>38`100h;B`4038X9`<0;AhH100]8ad407]dMF@0NgUi5P3oool001@0ooooH01k
NGT4071ZM@@0NgAe101UFfH703dgA0@0>2d/100h:bX403Pb<0@0>2d/100b:2L302dN60@0;B<M101k
M7ET07]iNAH0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo002E0?ooo`900000R@3oool009L0oooo00=000000?ooo`3o
ool0QP3oool007l0oooo00=000000?ooo`3oool02@3oool3@0000080oooo0T0000030?ooo`=00000
1@3oool00d000000oooo0?ooo`200?ooo`00OP3oool00d000000oooo@00000090?ooo`06@000003o
ool0oooo@000003ooom00000103oool014000000oooo0?oood0000280?ooo`00OP3oool00d000000
oooo@00000090?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo
@00008P0oooo001n0?ooo`03@000003ooom0000000X0oooo0d000000103ooom00000@00004000003
0?ooo`=00000R03oool007h0oooo00=000000?oood000000303oool00d000000oooo0?ooo`2@0?oo
o`00O`3oool00d000000oooo0?ooo`0:0?ooo`900000TP3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(45) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6F513D
7E6E61786A6678726A78665E78726A786E66786E66786E6678665E786A596F6256745E526B5247\
70594D6652466C55496C55496C55496C55496C4E4263513F68514868513F685148
91ADBA787A7A787A7A787A7A787A7A787172787F7F787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787474787D7D787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A755641
7B6C66786A5D78726C78665E78726A786E6678685A7164587464587460526B594E69564A695045\
6C5549634E426F574B6C55496C55496C50446C504463514468514668513F686A6C
91A3AB787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787878787676787D7D787878787D7D787A7A787474787D7D787474787D7D787A7A787A7A\
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A71533E
7B6C61786A62786C66786E66786A62786A627162525D5E58765B4E70504A66544669594D6C584C\
6C594D695246685145685145685145685044685140665146685145685144859EAB
85898C787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787172787F7F787A7A787A7A787A7A787878787D7D787878787D7D787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A75513D
7B6E68786A64786A62786C64786860786A5B7568606F68627861527B565868584770554970554F\
70554D6948416352446851456851456851456851446F574C66504468514591ADBA
787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A785641
786C61786A5D786A64786A62786A62786A6078706A786E6675665C745F566F574F745C4E745D53\
6E524B745D506448416C4D456C5F57664E416F51456F53466350446F5D508EA8B5
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A785843
786A5D786A64786A5D786A64786A62787068786A62786A62786E6675665C78655A715E50745B56\
715A4E705B4D6A4D486955486C5548695952684E41685145665145807B7A8599A2
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A644A41826A56
786A64786A5D786A5B786A66787068786A62786E66786E6678706878665E786A60756052785E54\
715B4E715C506E504B6D5546694E42665549664E416F514566514587949E7E898B
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787474787676\
787D7D787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A2D261F8F6C59857565
786A66786A60786A62786A6478726A78665E786C5D78706A786860786860786A5B78685A715650\
715B4E7458526B5644694E42695549695044665145715D506954488BA6B37B7F7F
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878787A7A\
787D7D787A7A787A7A
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A5D565C0C0704D9AF9B7B6C5D
78706C786860787068786860786C64786E66786E64786A6478685A785758715D4D6E584B745950\
745D506E5C5266524370524869574B664E3D6651466B55486850448EABB8787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787676787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A7F8181130D097A6452B69883786A62
786C66786860786C64786860786A62786C6478706878665E716454745352715D4D6B564A735B4F\
70594D6E59486650466F50446951456950426C51466651456F574B878B8F7B8487
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787474787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A1B120D75655AAD8D807B6C5D786A66
786A62786A62786A5B786A64786A62787068786A627868606F3B387446446E3E396E403B70413D\
705E4E6950426950456C4A3F6653416F51466C5145635140714D426B5C50889EA6
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787474787D7D\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A5D5656483E37B39486786860786A59786A66
786A6278645678665878665B786C66786C64785654785D596F35346E3E35662F28744542693B33\
74494360453B685043685140664D417153486C51456951446F4940695B4D77675C
829198787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787878787D7D\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A110D0BB48E767E6C5D786A5D786A5B786A66
786A5B715C4F745B507B7163786C68785E50713B3D6E3E35664A42572C2071655677595360261F\
6B322A694238664B406859486849356B55456F51466C51456C50446C55486C574B
8B999C787F82787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A463B3C362A1FC39F877B6C66715E507B756E786862
785E4E68524269463D856B696B38352C0E089067606E413974665D72736E73372F5F473A523426\
634C464A2E2176332B6257456B4D346F4F476F594D745B49694E446C574B6C5145
756458828888787F82787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787474787D7D787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A100C0BAE886D8E7C74786A5D6F54487E7772786860
785A4B5E3D2D633F363A100F7B7B745F615C9E99917871747B7A797B817B6C4337727E7B6B635E\
575050351D173B1E13774130705F48714B44746355745B4D6D56466950456C5044
6C594C75849E7B7C797B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A64616E040302E1B1917E6E63786A5B7563587B716C786A62
6B44374F382557261E260C08AD7A6B836F5F7458527B8382786354786A5B68473F7A7C7D6B493C\
6F6A644D362C4B4740391C157E42307055497A655077665B6E56486650466C4A3F
6C5548667475675F5974758582847F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A2D261F1D1210593D31C6A68A7B6C5F785E52786256786E63786A5D
653D33655748745F58665F569E716F7461556E524B73605877413D664F4567312C6F383063342B\
7472615B352B5A4344382C263C0E068E60547C68507A6A606B5242664D42664E42
6F594C6963567F858E635E708E9489787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A645B610303021C110EE8B39F8B7C68786458785656716A597B7063785758
65473A5C42318B847E7B726A78615E75685E756E667868607B63586B594D74564B6E54436E554B\
6C57487136356036304B271C36130E6B2A1F856E597D675B6B5442664B42634B40
7155486C594C29201B9E9BA47D7E797B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A5B5665413B2978594FB697817B6C5D78625678675F755C587B736178635C
654E41614237897F717B706A786E66786860786C64786E667856526F574A745D526B5648705248\
604C3C6B474063503D60463C5D473D6544427D64437C65596E5845664B4263503F
7153486C594C151B1CB1A39E8287897B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A6F584D826A5A75696271665877685B7B6A5D786C6678636078776A786860
6C56496A4B406F52457D776A7B756E786C6478686078726A785F546F574A6E4D416E5B49634D3D\
564A3F674636644539644939644439624839745E4C7A615670544660473D664D40
6B53426853480B0F0FC5B7CA8B918E787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
716E6E7B5C47715E546E57466062688568567B6E6878706A786E66787068786C64
75524F6F57496A493E7D6F607E7570787068785452716C5B7B6A5B684C426E4F43634235635347\
5D3F3567493664483E6B50386246396445347F625674574B694E4260483D684D41
6855466F574C010608C4AAA38E9490787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
755D4D7B655A684E4266504374736C885B5678736A78726A786E66786E66786E66
785F54755E4F685040735348817E7878726A785F5A756E627B6C646C50496E564863473D6C5749\
5D3C32644639644B3F6D50416C4B4174574B796356694E42695044695044664B40
6855426B53480006074D362FBFB9BB787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
78584371645A5534267D75688261617B6C5F78716878726A787572786B62786E66
78665C786658654E427056467D796D7B6E6878685A78706A7868606F584B64493D694E42665145\
63463C684D3662443A6D52457959527B65576E594D66564A6C5448665044665044
6853456F5D522C281D39211B41342FB0B2B3787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A786156\
6B413260302B5D483B737D74886A5F78715F786A6678726A78706A786B62786E66
78665E7164546F584D7468597E73677B6C617157507B736578565668543F634239664D415F483B\
6B4D36553D3167443A7460527A5F537A63556B564A6654486C4E42695044665140
6F4B416F63555E403453403A78969FB0B0B0787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A784840\
6538305D312C6863507D7B6D88706878706878686278726A786E66786E66786860
78685A6F62547B5E52716A5D7E6E6878706875615C7B716678584F65544460433B5F483B5B4236\
6346385F463D775D4F7963557461557A5F536B564A6652466C4E426C4B45694D44
684B406F655D5D392A6B504599BBC8757878787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A78675C785346\
654136573C2D7166568B80707B6C6878726A786C64786A62786A627164567B6A5D
7857566F625277594E7166597E706C786C5D786862786A6278545065493B5D463C5F463A62483B\
5E4F43705542745D50775D5077615570584B6E52466654486C483D6C4B41664D41
66534071635F67403368574B76838D828787787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6B45305C3B31\
3C2B21583B2F887567887C6C786A66786C64786A6278685A7864586F6456775B56
6E574E74605674685974685B7E7065786A62786A64786A62715D5268493C5D483D5F463A64493D\
6850446D5546795953745D4F735B4F6E5D5270564A6654486C5246665044664B40
684F4671635D5F2C1D6F6A5C66443B91ABB0787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A5E2A1921160F\
3F2B24382421AB8872847770786A64786A5B786A5D786A62786860756A62786560
6F574F70524B6959497B685B776A5D7B6C68786A62786A5B6F564F64463A5A3E3D6249355E4439\
7052456F5B4D7251466C594B74554F6951446C5549634E4268514566504468493F
684D486B59495735226C5745683C3891BDC7787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A786E676233282D241D\
31231C332320C2947984776A7164587B6C64786A5B6452496C594D59433860493D
5E443F64413E6E574572574974655881736E786A62786A606F524D61483A5A41346445315B493F\
6C4C3F605245604B406D5548725D52634D406F594C69544866504468514568493F
684D4868554540251B52271C74483794BFCB787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A71524168433D0A0503\
19130F2A1D19D8A2847A6E607864587B6E63786A5B68564B54453B47382D322D2A
2C221F48281B6A473752281E562F229283737B6E68786A626F584B61463A5A43325E4D38573E36\
73584B6C594C6C5549715245684E48594A3D775B4D6C5549634E425B4B40604B40
6D53486853453C241C54281E7B433397C7D5787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A7F8181724835614038080F10\
1B130F311915E4B3937B6E617464587B6E61786A5D756660564339715C5620211E
1E1311371D13493B366636297A5C4E938C7A7E77727875726F5B4B6142394E392D5A42302E0E09\
7E5C4A6346305340364630256B4F435B4F41755744685146665044574439604F43
734F485B483A331F1B5B3527804F469CCDD7757878787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787676787D7D787474787D7D787A7A787A7A787A7A787A7A787A7A140705A2614B6854481A1917\
13131822140FEAB99877685B786A5D7466597466597B6C6868594B74574D403C33
58473E5A3D2C634837835C468562557D72637E797478706A6F5646614239553B2C5740343E251E\
615650342D270A06064F2C22483E332B1E165D4137523927714938594D42604F43
734D42453C2F251A15482B22986A5999C0CA727576787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787676787F7F787878787D7D787A7A787A7A787A7A787A7A160C0A120B093409044C3126100D12\
14120F2B1813EDB9987466597E6E6861403A6C594B857772756E6475615A6B544D
664D406450436C50447C65507D6158776A5C7E7B76786E666F50486150445A3E2E594D39623E30\
685C524F3B3106080A4622173B2D29241C186941306845367E5E495F493F5E4F43
7353411F1A19251B143E21189D4C3994BFCB757878787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A0000003022182915122E211C0D090A\
2C1914301814E4AE8E7B685B74685D725C586456475A4035634E4053423644312C
3D271F4A33255435285937297F6C5E7B6F617E726E786A5B6F50466156485A3D32624533604D39\
705949634C42383B376B4A3B52372C4E362A83574576533B6353486B5040665348
604D4012110F2316134022188B34259ED4DF787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0200001D100B1A13102014101C120F\
1E1511372723C89477856E61756C5F7B6C686F615865574B63464145413F6D4B44
573E32634C3E5E40347A584B8C847382736C7B6C667857546F5E4F6154485A383840261A4A2E21\
725C426D5345685141694E445D4B3B5B4B41785A465E4D40684D49604F406D5342
453A30090B0A1A131095594561291EAADCE6787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787474787D7D787A7A787A7A787A7A787A7A0703011B0D0A1E15111B14100E0707\
2215113B2A26A3725A8C73637B7063786A66787068756C626F605C696964887268
726960787068756962857161786E617E7570716254745F5671625268574D6B544D524236392423\
39291D3020186F4537765A4D66513F635041604D4162463B5644396E50486D4F40
1F1A150F0D0C2A221D914733482117363836ADADAE787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787878787D7D787A7A787A7A787A7A787A7A0604032018151D13101F1410140F0B\
2516113A2A269C664F9279697E7265786A6678726A786E6678757278726E78726E
786B62787572786B62786C627566587B6E63756658715E5274594E7162567462566E5650504744\
5B453D3A322B3F261C32231A4D2F263E372E4E33274E342773554E73504462483A
0C0D0C19120F261A1A34110B42170F2C312FDFDEDF787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A07050535262315110E2114101E1310\
271919392A248257418A7060857769786A60786C6678706878706A78757278726E
78706A78757278695E786E66786C6278685A786A5D6F5A4F746054745D52746457745956685C4E\
66524753463B4F43394F413556392C4E3B2E72493B605044794B4A5E5040514135
0C0C0C1D130F1B1411170F0A311A153C3531DCDCDD787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0905032D20171E18151F130F25100B\
2A1916362419563C3093695787796A7B6C5F786A6678726A787572786E66787572
78726E78726E78695E786E6678685A7868607864566F564B746457746054745D52745B526B584A\
6D5246665246604E42695447604B406851457350446850496B4A405F4B3B37291E
130F0F1D130F28181419130F2415113A261BA68F928B9190787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A060301332926221916261613160F0B\
221511211510462A207148309881717E7063786A6678726A78787678706A786E66
787572786B62786B62786E66786656786A60715C4F715E52745D52745D52745B50745D526B564A\
69524669554969594D6850446C50446651455B493F604D42604D404B3C30181715
0F0C0A25181917101016100B0F0707321B167E615BAAB5B5787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0703012F26232C221E251A16231613\
2014102A1D19402E294F382CA47865857364786C68786C6478736C78757278706A
78757278695E786E66786E6678665C716456715C50745B50745B50745D526E5D5270584B6E584B\
6652466C55496C574B69524668504466514557493F6D4D415B483B32282216110F
221A16130B0B1610100F07071710102616116D564FBCC4C7787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A0705043128253428242C221E251612\
140F0B2E1A1642291F5B3B2C90584089796A7B7065786A64786C6478736C787572
78726E78706A786B62786E6678665E756858715C506E594E70584B7759536B594B70524670554F\
6654466C55496C504466514566504462463A664D416042363E342E261C161C1311
15100B140F0F140B0B17100B1911112E1914D5D1D09EA1A2787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A7874747170700606053024203529252D231F1B110E\
251C182C1D1931231D653F2D7C5141887769817567786A66787068787068787876
78726E78726E78695E786E667160527B66586F564B715B50745C5070584D6E594B705246695B50\
695446664A4468524466514568514566483D5E4F434F3A2F423329201913211513
16130F1B14101B131017100B1C14112F1915FFFFFF757878787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A7878787578780304033C251C2F25223428242A201D\
271C182D211C3221185B463A613D2F8A66568077687B6C68786C6478706878706A
786E66786E6678655C716456715C4F77685B71554B6E584670594F6E584670594F70584C665549\
6C5448694C42665345684B40684D415B4B404F42364832272C1F1D1B131118130F
150F0B171010130B0B0A0707150C0C492A24EBF0F0757878787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A050504312016332A27352925281E1A\
241612342219312521483A2F47261E8558468982717E6E63786A5D786C66786A5B
786A5D786A5D786862756858715C50745D526E4E436E5446705550705B4C70594F704E42665549\
6C50446C504463514568493F62483B4D44384833282C1E1C261C1519110E181310
201310161010130B0B120B0B2F1A15DCD0CDA7ADAE787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A110E0C271F1B3126223B29252B1E15\
291F1B291C183227232E221C3828246F4633856A528073667466597B6C61786A5B
786A5D71645874665B7B6C5D6F544A6E50456E5846694E446C574C6C5749745549694D41695346\
6C4A4466534566514062443A5B483B473D3235211B231C151B120F140F0B171010
221410150F100E0707140C0C321B16F7F7F7757878787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A16130E28211E3428243124202D231E\
201617281C172F221E35292531201745281D7053417E6153765D507A685B746256
74685B7164587460547764576B554B66493E6C5345694E446C4D416C53466F5145695044664B40\
684B415F493B5E493B5141364A352A44312621191319120F18130F160F0B130B0C
150C0B0A07070B0707301A16391E15EEF3F5787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A363033221A173328242D231F3B2E2A\
2A1C15261713392D282C201C352824261B174E3D304A352C6A43357D6455665044
6F5F586C59526C584A745F53604B404C382D5E41356A46356B4E44684F42684236685044664B35\
62483E5B42365740344B40343A251F321E161C14121B120F16100B130B0B130B0B
0F07070A0707150C0C281611BAACAAB3BABC787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A69686C17140E251D1A302420322622\
231E1921161737241A2D24203E302C2E25213527223C2E2A54352A593C2D443937
443B3356392B5C493B5A463A42322C442F23483024593C295F3B305E44326A4434574237503629\
58372D563D314436303D29222E1B142515121A130F150F0B120B0B0F07070B0707
0B07070B07072016112E1915F7F3F37B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A2220221E1916372A262F2824\
2D231F17110E33241D3C302C3B2E2A3C312C3A302B45382E45362C3D3127352726
36241A3C2420472C2246332A2F242238272342271F432A1C432822533A2B503629422F244A3327\
422A1F44332B39261F322119201512241B18130F0A16100B130B0B0F07070B0707
0B07072415111911117B5952D2D9DA787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A514E5716110D2F24202F2420\
3024202A211E3B2C273E302C3D322D3327243428243B242043292033231B2C2320
251A163226222817133428242C23202A201B291713281C182817143019153122182F2017312118\
2816132C181526171325171316120F17100B110A0B140B0B130B0B0A07070B0707
24151A241510322723DFD1CE949B9D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A727276262422211B18302420\
3529252F2420423530281E1A3E302C261D19372A264732283327242C231F2D2421
281E1A3F2C271D14152B241E2817132617131D130F1B14102113102B18142919141E1310201410\
1F13102A18141D1310201410140F0B17100B130B0B140B0B0B07070B0707150C0C
32201B281713C3C2C2B0B0B0787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A4D464C17100D332925\
3529252D231F28221D382B274235302924212D201C40271C2019172C201C2C201C
1C161B2D231D1E15162A19141E13171B140F1A131016100B1D14101D14101B1410160F0B130B0B\
18100B231511150F0B130B0B17100B171010130B0B0B0707140B0B1D15102D1E19
2D1915B6B5B5B6B8B8787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A6F6E7019151227201D\
3529252D231F322824342B27362925261E1A251A162B1C181B120F30231E221717
21171821140F1F131817100F120B0B171010171010130B0B191111130B0B181010130B0B171010\
1D1510181010120B0B0A07070C08070B07080B070718101019100B140C0C25110C
B3A9AAB9BDBC787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A535453272220\
251C18302420312A262F28243C2D292B2122241612281C1818120F231511191310
211410110B0B140B0C171010171010140B0B181010130B0B191111130B0B2E1A150907071A1111\
1D1510160F100A07070B07071007071911111710101911112C1914312118674131
D8E1E77B7F7F787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A535453\
241D1B2A26222A201B3C2F2B3B2D29352A27211C182D211C1B121617100F211410
1710101A13101B1410171010130B0B130B0B140C0C130B0B140C0C1C14101A1111292A362F2A28\
1E1216110B0B1610101C14101C141018101131231D271B172C1814543328B9BABA
97A3A9787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
59575625201D3028242C201C312A2640332E3128252F1E1622191718130F181010
120B0B19110B171010130B0B130B0B181010130B0B181010130B0B150C0C312D2E2C1E2943362C\
372C292920213C2F2A291F1A19130F2A1C192D1E19372A2645271FB9B2B2A1ADB0
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
7B7D7D504F4E261B15342E2A3328244335303A302B392E29201815241B17312522
241F1B1F130F1B1410160F10171010140B0B130B0B1D151A160F0F1C14101B12122B211D392922\
140E0F1A130F1D1510150F0F1E130F2D1E1A3221185F3E2E8B7F8AADB8B8787D7D
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A504C492A2620221B18392C274B3D39443E3A312825221915251819
26171330242024201B140E0F130B0B21191D20181C2C231E1D161B3C2C261611164E3C332F2324\
28201D3125202A201B30242143352A2F232065402FADA8AB919BA4828784787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A50514E4D4A512E2621372A26392E2A3A393F3F332D423735
463E392C22232828283C343F463E362D22242A242E3426233D374438292127201E46352E342522\
38241F38241B31282547342A5F3F2F2B1E18C3BDBA97A1A7787D7D787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A6C6B6E565C582A23283A302A33343C5B4C48464040
423C373B35334844454F3F3C463A332C24223B322F2E22212E221E2F231D392D2935292545271F\
462C244432284E3C3540271E614C4D849193AAB0B3787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787676787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A5051557275706567733B343B5B4C49
655F6A5348454E3F3A443A35463B384E3E4052433C3F373552413B41372F4D403D52413D44362D\
463A3233262386747C7F8482858A8E979E9D787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A727276565C5F85827D
82848965606878746D5855613E3B42504750463A32443B384C3E3A423A354439364230273B332B\
A49EA16F72759B999D888F8C787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A7272787E807A6C6E73626869787A7A75756E787474787D7D787A7A757878757573787D7D\
A4A3A7787D7D787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A
787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A787A7A\
787A7A787A7A787A7A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH07QjNP@0Ke4m101n
KV4407QZIP@0N79Z101hIUh307QbJP`0N6iV101hIUh407QZF@@0Kf9F0`1dGU8406]BA`@0L5U=101V
DTH?06aEB@@0K4i2101SDCl406QAB0@0J54o101XDDP3096]^Q00N7Yj101hLG8307QoOb<0N7Yj5P3o
ool001@0ooooF01hNWX406mA?@@0OViQ101hJVH407QbJP@0N6IN0`1hLVX<07Q^IP@0N6IN101hJUT4
06mREP<0M5iB101[DTL4071IC@@0IU963`1/EDT406a>@P@0He4o101XDDP406QA?`@0J5580`2A[KX@
07QjNP@0N75b0`1hOglS07QjNQH0oooo000D0?oooeP0N7Yj101_DCd407i^H@@0N6YV101hLVX407QV
GP<0N79Z301hKVH407QVGP@0N6YI101_HUH307ANDP@0Je97101`FDd406IBAPl0K5E9101/CT8406=A
?`@0J558101XDCl406QAB0<0TJfj401hNWX407QaLP<0N7mo8`1hNWXF0?ooo`00503ooomH07QjNP@0
Ke4m101nKV4407QZIP@0N79Z101hIUh307QbJP`0N6iV101hIUh407QZF@@0Kf9F0`1dGU8406]BA`@0
L5U=101VDTH?06aEB@@0K4i2101SDCl406QAB0@0J54o101XDDP3096]^Q00N7Yj101hLG8307QoOb<0
N7Yj5P3oool001@0oooo101hNWX407QdM0@0N7em0`1hNWX407QdM0@0N7em8`1hNWX407QdM0<0N7em
5`1hNWX407EF@@@0NfaV101hJUd407QbK0@0N6IN0`1hLVX407Q^IP@0N6QJ101aI5P407ATF0@0M61B
101[FDh306UFBP@0JE15101/EDT406=>@P@0KeM;1`1/EDT806a@A0@0He54101XDDH406QA?`@0J6Y/
0`2AXj/@07QjNP@0N7Qh0`1hOGdS07QjNQH0oooo000D0?ooo`@0N7Yj101hM7@407QmO@<0N7Yj101h
M7@407QmOB<0N7Yj101hM7@307QmOAL0N7Yj101eET4407]/IP@0N6YM101hLV`407QVGP<0N79Z101h
KVH407QXFP@0LFAH101dI5P407APDP@0JeU>0`1YETX406U@A@@0K5E9101SCT8406mGB`L0K5E9201/
D4@406=AA0@0J556101XDCl406QZK0<0TJ>[401hNWX407QhN0<0N7em8`1hNWXF0?ooo`00503oool4
07QjNP@0N7Ad101hOGd307QjNP@0N7Ad101hOGdS07QjNP@0N7Ad0`1hOGdG07QjNP@0MEI1101kK6H4
07QZG@@0N79/101hIUh307QbJP@0N6iV101hJ5X4075TF0@0M6AH101dH58406]ICP<0JEI:101YD4D4
06aEB@@0Hdi2101_Ed/706aEB@P0K514101SDD@406QAAP@0J54o101XJV`3096SZa00N7Yj101hN7P3
07QmOB<0N7Yj5P3oool001@0oooo101hNWX407QdM0@0N7em0`1hNWX407QdM0@0N7em8`1hNWX407Qd
M0<0N7em5`1hNWX407EF@@@0NfaV101hJUd407QbK0@0N6IN0`1hLVX407Q^IP@0N6QJ101aI5P407AT
F0@0M61B101[FDh306UFBP@0JE15101/EDT406=>@P@0KeM;1`1/EDT806a@A0@0He54101XDDH406QA
?`@0J6Y/0`2AXj/@07QjNP@0N7Qh0`1hOGdS07QjNQH0oooo000D0?ooo`@0N7Yj101hN7P407QfMP<0
N7em101hN7P407QmO@@0N7Yj101hM7@407QmO@<0N7Ad101hOGd@07QjNP@0N7Qh0`1hOGdG07QjNP@0
LE<n101kK64407QZHP@0N6aV101hKVH707QZHP@0LF9B101MGUP407IKCP@0L51:101VE4H306UIC@@0
K5Q<101/FDd406UBAP/0J555101XD4@406QA@0@0IU56101XDDD406QAA0@0QIj[0`25RH`D07QjNP<0
N7Ad101hOGdO07QjNQH0oooo000D0?ooo`@0N7Yj101hN7P407QfMP<0N7em101hN7P407QmO@@0N7Yj
101hM7@407QmO@<0N7Ad101hOGd@07QjNP@0N7Qh0`1hOGdG07QjNP@0LE<n101kK64407QZHP@0N6aV
101hKVH707QZHP@0LF9B101MGUP407IKCP@0L51:101VE4H306UIC@@0K5Q<101/FDd406UBAP/0J555
101XD4@406QA@0@0IU56101XDDD406QAA0@0QIj[0`25RH`D07QjNP<0N7Ad101hOGdO07QjNQH0oooo
000D0?ooo`@0N7Yj101hN7P407QfMP<0N7em101hN7P407QmO@@0N7Yj101hM7@407QmO@<0N7Ad101h
OGd@07QjNP@0N7Qh0`1hOGdG07QjNP@0LE<n101kK64407QZHP@0N6aV101hKVH707QZHP@0LF9B101M
GUP407IKCP@0L51:101VE4H306UIC@@0K5Q<101/FDd406UBAP/0J555101XD4@406QA@0@0IU56101X
DDD406QAA0@0QIj[0`25RH`D07QjNP<0N7Ad101hOGdO07QjNQH0oooo000D0?ooo`@0N7Yj101hN7P4
07QfMP<0N7em101hN7P407QmO@@0N7Yj101hM7@407QmO@<0N7Ad101hOGd@07QjNP@0N7Qh0`1hOGdG
07QjNP@0LE<n101kK64407QZHP@0N6aV101hKVH707QZHP@0LF9B101MGUP407IKCP@0L51:101VE4H3
06UIC@@0K5Q<101/FDd406UBAP/0J555101XD4@406QA@0@0IU56101XDDD406QAA0@0QIj[0`25RH`D
07QjNP<0N7Ad101hOGdO07QjNQH0oooo000D0?ooo`P0N7Yj101hLG8307QoO``0N7Yj101hN7P407Qm
O@<0N7Qh101hOGd^07QjNP@0ME4m101kKVP407QZI0@0N6YR101hK6@307QXH0@0N6YK101eJ60406mX
HP@0N65B101kEUP406QHA`<0L5E9101`EDl4071EC@@0JDQ1101SDT@;06QAA@@0J554101_Ed`406I@
A0@0J555102A[KXG07QjNP<0N7Qh101hOGdO07QjNQH0oooo000D0?ooo`P0N7Yj101hLG8307QoO``0
N7Yj101hN7P407QmO@<0N7Qh101hOGd^07QjNP@0ME4m101kKVP407QZI0@0N6YR101hK6@307QXH0@0
N6YK101eJ60406mXHP@0N65B101kEUP406QHA`<0L5E9101`EDl4071EC@@0JDQ1101SDT@;06QAA@@0
J554101_Ed`406I@A0@0J555102A[KXG07QjNP<0N7Qh101hOGdO07QjNQH0oooo000D0?ooo`P0N7Yj
101hLG8307QoO``0N7Yj101hN7P407QmO@<0N7Qh101hOGd^07QjNP@0ME4m101kKVP407QZI0@0N6YR
101hK6@307QXH0@0N6YK101eJ60406mXHP@0N65B101kEUP406QHA`<0L5E9101`EDl4071EC@@0JDQ1
101SDT@;06QAA@@0J554101_Ed`406I@A0@0J555102A[KXG07QjNP<0N7Qh101hOGdO07QjNQH0oooo
000D0?ooo`P0N7Yj101hN7P307QmODT0N7Yj101hET4407Q/H@@0N6YM101hJV@707QZHP@0N6YP101h
L6X407Q^IP@0MFIL101dGeH406mGC`<0M5a>101dGE<406iBB`@0M5e@101TB44406a=A@<0K5mG101V
CT4406mAA@@0Ke=6101SD4@406mMD0@0SZRe?@1hNWXF0?ooo`00503oool807QjNP@0N7Qh0`1hOGe9
07QjNP@0N5I1101hK64407QZG@@0N6YT1`1hJV8407QZH0@0N71Z101hKVH407EVG0@0M5mF101_Edl3
07ALCP@0M5eC101^DT/407AMD0@0I4Q1101/CDD306aOE`@0ITi1101_DDD406mCAP@0He14101_GE04
08jX]Cd0N7Yj5P3oool001@0oooo201hNWX407QhN0<0N7emB@1hNWX407QF@@@0N6aQ101hJUd407QZ
I0L0N6YR101hJV0407Q`JP@0N6iV101eIU`407AOEP@0KeM?0`1dG4h407AMD`@0KU9;101dGE0406A8
@@@0K4e50`1/GeL406I>@@@0Ke55101_DdH406=@A0@0Kee@102>Z;Dm07QjNQH0oooo000D0?ooo`P0
N7Yj101hN7P307QmODT0N7Yj101hET4407Q/H@@0N6YM101hJV@707QZHP@0N6YP101hL6X407Q^IP@0
MFIL101dGeH406mGC`<0M5a>101dGE<406iBB`@0M5e@101TB44406a=A@<0K5mG101VCT4406mAA@@0
Ke=6101SD4@406mMD0@0SZRe?@1hNWXF0?ooo`00503ooomH07QjNP@0N5Q3101hJUd407QZI0@0N6YM
101hJV@307QZHP@0N71X201hJV8407Q^IP@0MFIL101hIEX3075ND0@0M5]F101aFTh4071KC@@0JTe8
101YEDP306aEB0@0JEUB101XCT4406QAA@@0IU551020NgX408FIXQX0N7Yj101hM7@407QmOA/0N7Yj
5P3oool001@0ooooF01hNWX407QH@`@0N6YM101hJV@407QZG@@0N6YT0`1hJV8407Q`J0P0N6YR101h
KVH407EVG0@0N6EJ0`1aGU0407AKEP@0LEY>101`Fdd406Y=B0@0JEE80`1/EDP406UIDP@0J4i1101X
DDD406IAA@@0P7]j1025VJ8J07QjNP@0N7Ad101hOGdK07QjNQH0oooo000D0?oooeP0N7Yj101hF4<4
07QZG@@0N6YT101hJUd407QZI0<0N6YR101hL6P807QZHP@0N6iV101eIU`407QUFP<0LEi@101dFeH4
075JCP@0L5]=101ZCDP406UEB0<0K5E8101YFE8406Q>@@@0J555101VDDD4081kNP@0QIVR6P1hNWX4
07QdM0@0N7em6`1hNWXF0?ooo`00503ooomH07QjNP@0N5Q3101hJUd407QZI0@0N6YM101hJV@307QZ
HP@0N71X201hJV8407Q^IP@0MFIL101hIEX3075ND0@0M5]F101aFTh4071KC@@0JTe8101YEDP306aE
B0@0JEUB101XCT4406QAA@@0IU551020NgX408FIXQX0N7Yj101hM7@407QmOA/0N7Yj5P3oool001@0
ooooE@1hNWX306A:@@@0PVYF101hJV@407QZG@@0N6YK101hJVH307Q`J0@0N6YR201hKVH407Q`J0@0
N6IN101hJV0307EPDP@0N5iD101aFdh4075LD0@0KU1;101]EDH306U>@P@0IUE9101VCT4406mAA@@0
IU551027U9h407j9RaX0N7Yj101hN7P407QmO@P0N7Yj101hM7@307QfMP@0N7em201hNWXF0?ooo`00
503ooomE07QjNP<0I4Y11022JUH407QZI0@0N6YM101hJU/407QZIP<0N71X101hJV8807Q^IP@0N71X
101hIUh407QZH0<0MF1B101hGU@4075KCP@0LEa@101^D4/406eEAP<0JDi2101VEDT406I>@@@0Ke55
101VDDD408NDWP@0OXV;6P1hNWX407QhN0@0N7em201hNWX407QdM0<0N7If101hOGd807QjNQH0oooo
000D0?oooeD0N7Yj0`1TBT44089ZEP@0N6YT101hJUd407QZF`@0N6YV0`1hL6P407QZHPP0N6iV101h
L6P407QVGP@0N6YP0`1eH58407QNE0@0LE]>101aG50406i@B`@0KEE60`1YCT8406IEB@@0ITi1101_
DDD406IAA@@0QiBN101nRH/J07QjNP@0N7Qh101hOGd807QjNP@0N7Ad0`1hMWH407QmO@P0N7Yj5P3o
ool001@0ooooE@1hNWX306A:@@@0PVYF101hJV@407QZG@@0N6YK101hJVH307Q`J0@0N6YR201hKVH4
07Q`J0@0N6IN101hJV0307EPDP@0N5iD101aFdh4075LD0@0KU1;101]EDH306U>@P@0IUE9101VCT44
06mAA@@0IU551027U9h407j9RaX0N7Yj101hN7P407QmO@P0N7Yj101hM7@307QfMP@0N7em201hNWXF
0?ooo`00503ooomA07QjNP@0;BHO0`2?K5T408EeI@@0N6YV101hJV0407QZHP@0N6YT0`1hLVX407QV
GP@0N6aM101hL6X807QXH0@0N6YK0`1hJ5X4075FD0@0LE]>101dF58406]FA0@0JDi20`1YEDT406U@
A0@0IU55101aGE0406UDB0@0RjJc101kOglZ07QjNP@0N7Qh0`1hNWX407QmO@P0N7Yj5P3oool001@0
ooooD@1hNWX402dV7`<0SfaI1025MFD407QZIP@0N6YP101hJV8407QZI0<0N79Z101hIUh407Q/G@@0
N71Z201hJ60407QZF`<0N6QJ101aEU04075KCP@0M5QB101[ET@406U>@P<0JEE9101YD4@406IAA@@0
LEe@101YE4P408^V/`@0Ngmo:P1hNWX407QhN0<0N7Yj101hOGd807QjNQH0oooo000D0?oooe40N7Yj
100]9Ql308m/F@@0QGEU101hJVH407QZH0@0N6YR101hJV@307QbJP@0N6IN101hK5d407Q`JPP0N6QP
101hJU/307QXFP@0LEI@101aFdh407AHDP@0JeI4101YCT8306UEB@@0JE14101VDDD4075MD0@0JEA8
102;Y[<407]oObX0N7Yj101hN7P307QjNP@0N7em201hNWXF0?ooo`00503ooomA07QjNP@0;BHO0`2?
K5T408EeI@@0N6YV101hJV0407QZHP@0N6YT0`1hLVX407QVGP@0N6aM101hL6X807QXH0@0N6YK0`1h
J5X4075FD0@0LE]>101dF58406]FA0@0JDi20`1YEDT406U@A0@0IU55101aGE0406UDB0@0RjJc101k
OglZ07QjNP@0N7Qh0`1hNWX407QmO@P0N7Yj5P3oool001@0oooo201hNWX407QdM0<0N7em?P1hNWX4
05eFG0@030L40`3I[i/407]/G@@0N71/101hJ60407Q`J0@0N6QP0`1hK6@407Q^IP@0N6iT101hJV@4
07QXFP@0N5MH101aGDd306iHB`@0M5U@101dGE0406iLDP@0IU93101`DTP306UGB`@0IThm101VDDH4
06]EB0@0J514102>ZkQ107QjNQH0oooo000D0?ooo`P0N7Yj101hM7@307QmOCh0N7Yj101MEU`400`7
10<0fJnK101kK5d407Q`K0@0N6QP101hL6P407QXH0<0N6aT101hKVH407Q^I0@0N6YT101hJ5X407QG
F0@0LEe=0`1^F4/407AID0@0M5e@101^G58406IB@`@0L5980`1YEd/406I>?@@0IU56101[EDP406Q@
A0@0SZ^h@@1hNWXF0?ooo`00503oool807QjNP@0N7Ad0`1hOGdn07QjNP@0GEIL100<1`@30=V_V`@0
NfaM101hL6`407QXH0@0N71X101hJ60307Q/I0@0N6iV101hKV@407QZI0@0N6QJ101hEeP4075MC@<0
KUQ;101dFE0407AMD0@0KUaB101VDT<4071BB0<0JEM;101VCSd406IAAP@0JeE8101XD4@408j[^440
N7Yj5P3oool001@0oooo201hNWX407QdM0<0N7em?P1hNWX405eFG0@030L40`3I[i/407]/G@@0N71/
101hJ60407Q`J0@0N6QP0`1hK6@407Q^IP@0N6iT101hJV@407QXFP@0N5MH101aGDd306iHB`@0M5U@
101dGE0406iLDP@0IU93101`DTP306UGB`@0IThm101VDDH406]EB0@0J514102>ZkQ107QjNQH0oooo
000D0?ooo`P0N7Yj101hN7P307QfMP@0N7em=P1hNWX407n1P@@04`d9101jI5830;JHP`@0N6YR101h
K6H407QXH0@0N6aT101hJ60307QZHP@0N6aT101hL6P407QVGP@0LFAD101dDe84075MC@<0JeI:101c
Fdl4071IC@@0KUU8101VD4H406m@A0<0JE55101YD48406aAAP@0IU55101_Ed/408N;S`@0NhB7?@1h
NWXF0?ooo`00503oool807QjNP@0N7Qh0`1hMWH407QmOCH0N7Yj101oPH4401<=2@@0NVAB0`2fV8<4
07QZHP@0N6aV101hJ60407Q/I0@0N6QP0`1hJV8407Q/I0@0N71X101hIUh4075TE0@0M5=B101aGDd3
06]FBP@0Le]?101`FDd406iIB0@0IU16101_D4@306UAA@@0JE12101/DDH406IAA@@0KeM;1027Rhl4
07^4Qcd0N7Yj5P3oool001@0oooo201hNWX407QhN0<0N7If101hOGdf07QjNP@0Oh61100C3@T407YT
DP<0]YR3101hJV8407Q/IP@0N6QP101hK6@407QXH0<0N6YR101hK6@407Q`J0@0N6IN101aI5@407AC
DP@0LEe=0`1[ETX407=KC`@0L5U=101^FDP406I@AP@0Ke140`1YDDD406U@@P@0K556101VDDD406mG
B`@0Qh^?101kQ8Lm07QjNQH0oooo000D0?ooo`P0N7Yj101hM7@307QjNP@0N7em=P1hNWX401/B3@@0
MFEJ102]SH0307]/G@@0N6YV201hJV8407QZF`@0N6YT0`1hJV8407Q`J0@0N6YR101hJ60406lk>0@0
M4I4101^?ST306i0>`@0L44m101`GTh406U@@P@0JE15101/BSl306IC@@@0Ke56101/DDD406=A@0@0
LDe2101[G50408RNYRX0N7Yj101hM7@307QmO@`0N7Yj5P3oool001@0oooo201hNWX407QdM0<0N7Yj
101hOGdf07QjNP@06a8=101eIEX40:f=P0<0NfaM101hJVH807QZHP@0N6YK101hJV@307QZHP@0N71X
101hJV8407QXH0@0Kc/h101dAT@406hn>@<0KT0k101`@Cd4071NCP@0JE12101YD4D406a:?`<0IU=1
101_DDH406aAA@@0He50101aCD8406]LD0@0R9jV:P1hNWX407QdM0<0N7em301hNWXF0?ooo`00503o
ool807QjNP@0N7Ad0`1hNWX407QmOCH0N7Yj100K4Pd407EUFP@0[Hf00`1kK5d407QZIPP0N6YR101h
JU/407QZI0<0N6YR101hL6P407QZHP@0N6QP101_>cP407A6A0@0KShi0`1^@3/40711?@@0L5i>101Y
D48406U@A@@0K4Xo0`1VDd4406mAAP@0K555101SDD04075=@P@0Jea@1028WZHZ07QjNP@0N7Ad0`1h
OGd<07QjNQH0oooo000D0?ooo`P0N7Yj101hM7@307QjNP@0N7em=P1hNWX401/B3@@0MFEJ102]SH03
07]/G@@0N6YV201hJV8407QZF`@0N6YT0`1hJV8407Q`J0@0N6YR101hJ60406lk>0@0M4I4101^?ST3
06i0>`@0L44m101`GTh406U@@P@0JE15101/BSl306IC@@@0Ke56101/DDD406=A@0@0LDe2101[G504
08RNYRX0N7Yj101hM7@307QmO@`0N7Yj5P3oool001@0oooo201hNWX407QhN0<0N7em=P1hNWX405eF
EP@0B3hg102cU8H407QXH0<0N6YI101hJVH407QZHP@0N6AF101hIUP407QVF`<0N6aV101hK6@407QF
E0@0N5eI101_=C@406hn=@@0IRlX0`1dAD8406Tk<`@0M4U3101PAC/406Q@@`@0J5500`1VCD44075C
B0@0K555101YDD@406m9@0@0JE]=101gIe`308:AV2L0N7Yj101hN7P307QmO@`0N7Yj5P3oool001@0
oooo201hNWX407QhN0<0N7em=P1hNWX405eFEP@0B3hg102cU8H407QXH0<0N6YI101hJVH407QZHP@0
N6AF101hIUP407QVF`<0N6aV101hK6@407QFE0@0N5eI101_=C@406hn=@@0IRlX0`1dAD8406Tk<`@0
M4U3101PAC/406Q@@`@0J5500`1VCD44075CB0@0K555101YDD@406m9@0@0JE]=101gIe`308:AV2L0
N7Yj101hN7P307QmO@`0N7Yj5P3oool001@0oooo201hNWX407QhN0<0N7em=P1hNWX405eFEP@0B3hg
102cU8H407QXH0<0N6YI101hJVH407QZHP@0N6AF101hIUP407QVF`<0N6aV101hK6@407QFE0@0N5eI
101_=C@406hn=@@0IRlX0`1dAD8406Tk<`@0M4U3101PAC/406Q@@`@0J5500`1VCD44075CB0@0K555
101YDD@406m9@0@0JE]=101gIe`308:AV2L0N7Yj101hN7P307QmO@`0N7Yj5P3oool001@0oooo201h
NWX407QhN0<0N7em=P1hNWX405eFEP@0B3hg102cU8H407QXH0<0N6YI101hJVH407QZHP@0N6AF101h
IUP407QVF`<0N6aV101hK6@407QFE0@0N5eI101_=C@406hn=@@0IRlX0`1dAD8406Tk<`@0M4U3101P
AC/406Q@@`@0J5500`1VCD44075CB0@0K555101YDD@406m9@0@0JE]=101gIe`308:AV2L0N7Yj101h
N7P307QmO@`0N7Yj5P3oool001@0ooooA@1hNWX4014=2`@0]8if101nK5d407QZG@<0N6YK101hJVH4
07QZF`@0LEa?101dFe0407]aH`<0N6aX101hGU04074k?@@0KShe101VBT8405L/80@0LFEF0`1gFE<4
060V7`@0Jc8Z101Y@SP406I;@0@0J5U80`1XBCD406]EA@@0Ke56101/DDD406a@A0@0K5E8101/Ed/3
08^IW0@0N7n2=P1hNWXF0?ooo`00503ooom507QjNP@04@d;102dSWH407i/G@@0N6YM0`1hJU/407QZ
IP@0N6YK101aG4l407AKD0@0Ng5S0`1hK6P407QND0@0LC/m101^?SD406I:@P@0Eb`P101aIEH307MI
D`@0H2HO101[<RX406U2>0@0IT]0101XFDP306Q9=@@0JeE5101_DDH406aAA@@0K514101/EDP406aG
B`<0RiVL101hOh8f07QjNQH0oooo000D0?ooodD0N7Yj100A3@/40;B>MP@0OVaM101hJUd307QZF`@0
N6YV101hJU/4075LC`@0M5]@101kLF<307Q/J0@0N5i@101a>cd406hn=@@0ITY2101G;204075UEP<0
MeUC101P9Ql406/b:P@0JD8h101VBd0406QIB0<0J4Te101[EDD406mAAP@0K555101/D4@406aEB0@0
K5M;0`2;VI`407QoPSH0N7Yj5P3oool001@0ooooA@1hNWX4014=2`@0]8if101nK5d407QZG@<0N6YK
101hJVH407QZF`@0LEa?101dFe0407]aH`<0N6aX101hGU04074k?@@0KShe101VBT8405L/80@0LFEF
0`1gFE<4060V7`@0Jc8Z101Y@SP406I;@0@0J5U80`1XBCD406]EA@@0Ke56101/DDD406a@A0@0K5E8
101/Ed/308^IW0@0N7n2=P1hNWXF0?ooo`00503oool?07QjNP@0N7Ad101hOGdZ07QjNP@0AS/l100f
:Ql40<>OQ`@0NfaV101aGU0307]eKP@0N6QR101hGTh406QB@P@0JDHm1025JfT306/h=@@0;0h8102@
If0406i1>@@0M6IM101bLfh407<g;`<0GdLj101B=2H406=<AP@0BRhQ101f<b/4069GA@<0Jddd101_
CdL406mIC@@0M5]9101YCT@406aGB`@0K5550`1eI5P408:8R0@0N7n2<P1hNWXF0?ooo`00503oool?
07QjNP@0N7Ad101hOGdZ07QjNP@0AS/l100f:Ql40<>OQ`@0NfaV101aGU0307]eKP@0N6QR101hGTh4
06QB@P@0JDHm1025JfT306/h=@@0;0h8102@If0406i1>@@0M6IM101bLfh407<g;`<0GdLj101B=2H4
06=<AP@0BRhQ101f<b/4069GA@<0Jddd101_CdL406mIC@@0M5]9101YCT@406aGB`@0K5550`1eI5P4
08:8R0@0N7n2<P1hNWXF0?ooo`00503oool?07QjNP@0N7Ad101hOGdZ07QjNP@0AS/l100f:Ql40<>O
Q`@0NfaV101aGU0307]eKP@0N6QR101hGTh406QB@P@0JDHm1025JfT306/h=@@0;0h8102@If0406i1
>@@0M6IM101bLfh407<g;`<0GdLj101B=2H406=<AP@0BRhQ101f<b/4069GA@<0Jddd101_CdL406mI
C@@0M5]9101YCT@406aGB`@0K5550`1eI5P408:8R0@0N7n2<P1hNWXF0?ooo`00503oool?07QjNP@0
N7Ad101hOGdZ07QjNP@0AS/l100f:Ql40<>OQ`@0NfaV101aGU0307]eKP@0N6QR101hGTh406QB@P@0
JDHm1025JfT306/h=@@0;0h8102@If0406i1>@@0M6IM101bLfh407<g;`<0GdLj101B=2H406=<AP@0
BRhQ101f<b/4069GA@<0Jddd101_CdL406mIC@@0M5]9101YCT@406aGB`@0K5550`1eI5P408:8R0@0
N7n2<P1hNWXF0?ooo`00503oool807QjNP@0N7Ad0`1hOGd407QhN0@0N7em:P1hNWX4010<2`@0[XQ]
102>O7@407QZG@@0KeA80`1nMg8407QXH0@0N5Y;101N?Bd406<o=P@0>Q0?0`1kNg@405mQG0@0WYVA
101hLG@407]jN@@0Nh5k101/@cL3079nN`@0Jf=N101GD50403DM5`@0>ahC101g@C03071OB0@0LD]4
101dHeD407AKC@@0KEI6101YD4D406a@A0<0K5U<101eQ9h407]lN@@0Ngmo;P1hNWXF0?ooo`00503o
ool807QjNP@0N7Ad0`1hOGd407QhN0@0N7em:P1hNWX4010<2`@0[XQ]102>O7@407QZG@@0KeA80`1n
Mg8407QXH0@0N5Y;101N?Bd406<o=P@0>Q0?0`1kNg@405mQG0@0WYVA101hLG@407]jN@@0Nh5k101/
@cL3079nN`@0Jf=N101GD50403DM5`@0>ahC101g@C03071OB0@0LD]4101dHeD407AKC@@0KEI6101Y
D4D406a@A0<0K5U<101eQ9h407]lN@@0Ngmo;P1hNWXF0?ooo`00503oool807QjNP@0N7Ad0`1hOGd4
07QhN0@0N7em:P1hNWX4010<2`@0[XQ]102>O7@407QZG@@0KeA80`1nMg8407QXH0@0N5Y;101N?Bd4
06<o=P@0>Q0?0`1kNg@405mQG0@0WYVA101hLG@407]jN@@0Nh5k101/@cL3079nN`@0Jf=N101GD504
03DM5`@0>ahC101g@C03071OB0@0LD]4101dHeD407AKC@@0KEI6101YD4D406a@A0<0K5U<101eQ9h4
07]lN@@0Ngmo;P1hNWXF0?ooo`00503oool807QjNP@0N7Ad0`1hOGd407QhN0@0N7em:P1hNWX4010<
2`@0[XQ]102>O7@407QZG@@0KeA80`1nMg8407QXH0@0N5Y;101N?Bd406<o=P@0>Q0?0`1kNg@405mQ
G0@0WYVA101hLG@407]jN@@0Nh5k101/@cL3079nN`@0Jf=N101GD50403DM5`@0>ahC101g@C03071O
B0@0LD]4101dHeD407AKC@@0KEI6101YD4D406a@A0<0K5U<101eQ9h407]lN@@0Ngmo;P1hNWXF0?oo
o`00503oool807QjNP@0N7Qh0`1hOGd_07QjNP<0I65^10040`840>6aT@@0OViS101hJU/407ESF0<0
Ng5/101hJV8406]4=`@0CcPU101G9Qh402H<20<0[GY[1023Kel407AHDP@0Nh>2101hHe@407QZF`@0
J4Lo0`1jO7d406]9?0@0KfYT101==R`404]7@0@0>A`E0`1n@S04071EB@@0NVE@101gIU/406iFB0@0
IU16101/BSl306aEB0@0IWAe101WGeT407AeQ@@0PXAo:P1hNWXF0?ooo`00503oool807QjNP@0N7Qh
0`1hOGd_07QjNP<0I65^10040`840>6aT@@0OViS101hJU/407ESF0<0Ng5/101hJV8406]4=`@0CcPU
101G9Qh402H<20<0[GY[1023Kel407AHDP@0Nh>2101hHe@407QZF`@0J4Lo0`1jO7d406]9?0@0KfYT
101==R`404]7@0@0>A`E0`1n@S04071EB@@0NVE@101gIU/406iFB0@0IU16101/BSl306aEB0@0IWAe
101WGeT407AeQ@@0PXAo:P1hNWXF0?ooo`00503oool807QjNP@0N7Qh0`1hOGd_07QjNP<0I65^1004
0`840>6aT@@0OViS101hJU/407ESF0<0Ng5/101hJV8406]4=`@0CcPU101G9Qh402H<20<0[GY[1023
Kel407AHDP@0Nh>2101hHe@407QZF`@0J4Lo0`1jO7d406]9?0@0KfYT101==R`404]7@0@0>A`E0`1n
@S04071EB@@0NVE@101gIU/406iFB0@0IU16101/BSl306aEB0@0IWAe101WGeT407AeQ@@0PXAo:P1h
NWXF0?ooo`00503oool807QjNP@0N7Qh0`1hOGd_07QjNP<0I65^10040`840>6aT@@0OViS101hJU/4
07ESF0<0Ng5/101hJV8406]4=`@0CcPU101G9Qh402H<20<0[GY[1023Kel407AHDP@0Nh>2101hHe@4
07QZF`@0J4Lo0`1jO7d406]9?0@0KfYT101==R`404]7@0@0>A`E0`1n@S04071EB@@0NVE@101gIU/4
06iFB0@0IU16101/BSl306aEB0@0IWAe101WGeT407AeQ@@0PXAo:P1hNWXF0?ooo`00503ooolj07Qj
NP@0;BHO0`0M4Q0405Tm<@@0aZJ:101kK5l407QNDP@0N69F0`1hKV<407QZG@@0ICdc101UEdP407AO
F0@0IUmF0`2NLFl407AQE@@0KU9;101cH5P407M1?@@0ITm5101W<B`306lh<0@0Hc@[101dLV4405/e
:`@0FT=4100h;2H303`>1P@0SV1D101lJ50407YZH0@0Je92101VCD8406I>@P<0KeU<101YHeH407n5
SP@0Hei`102>U8TZ07QjNQH0oooo000D0?ooocX0N7Yj100]9Ql301dB40@0FCda1036YXX407]/G`@0
N5iB101hHUH307Q^H`@0N6YM101U?C<406EGB0@0M5mH101VGeH309iaK`@0M65E101^DT/407=PF0@0
Md4m101VCdD406La;0<0KcP`101S=2/407AbH@@0FcD[101J@d@403P/9P<0?0h6102>H5@407aXD0@0
NVYP101[DT8406I=@P@0ITi20`1_FD`406USEP@0OhF>101SGW0408jDRBX0N7Yj5P3oool001@0oooo
>P1hNWX402dV7`<07A8@101I?C440<JVRP@0NfaO101hGU8407QREP<0N6iS101hJUd406Dm<`@0IEM8
101dGeP406IOEP<0WW5_101dHED406iBB`@0Lf1H101g@Cd406I?A@@0Ic4/0`1_>30406<d:`@0M79Q
101K=B/405Y3A0@0>2`V0`0l3PH408iPE0@0O6Q@101jJV0406]B@P@0ITe2101VCT8306mIC0@0JF=F
101oQHh406=NL0@0SYB9:P1hNWXF0?ooo`00503ooolC07QjNP@0N7Ad101hOGdK07QjNP@0I5]Q1003
0`8301`A3P@0j;>O102;O6P407QTF0@0N5IF101aJUT307]`H`@0N5MH101UAcX405a2<@@0RhAn101k
LVX307QQGP@0MFQN101eKVH407QXH0@0Nf=H101[FDd407AFB`<0KUA3101^ED/406aGB0@0LCHe101P
=S0404/W70<0=Q<>101[:Ql408E^F@@0OFMK101[E48406I;@P@0Hd]00`1aEDP406aIC0@0:B0K102N
Vj@407enN@@0Ngmo9P1hNWXF0?ooo`00503ooolC07QjNP@0N7Ad101hOGdK07QjNP@0I5]Q10030`83
01`A3P@0j;>O102;O6P407QTF0@0N5IF101aJUT307]`H`@0N5MH101UAcX405a2<@@0RhAn101kLVX3
07QQGP@0MFQN101eKVH407QXH0@0Nf=H101[FDd407AFB`<0KUA3101^ED/406aGB0@0LCHe101P=S04
04/W70<0=Q<>101[:Ql408E^F@@0OFMK101[E48406I;@P@0Hd]00`1aEDP406aIC0@0:B0K102NVj@4
07enN@@0Ngmo9P1hNWXF0?ooo`00503ooolC07QjNP@0N7Ad101hOGdK07QjNP@0I5]Q10030`8301`A
3P@0j;>O102;O6P407QTF0@0N5IF101aJUT307]`H`@0N5MH101UAcX405a2<@@0RhAn101kLVX307QQ
GP@0MFQN101eKVH407QXH0@0Nf=H101[FDd407AFB`<0KUA3101^ED/406aGB0@0LCHe101P=S0404/W
70<0=Q<>101[:Ql408E^F@@0OFMK101[E48406I;@P@0Hd]00`1aEDP406aIC0@0:B0K102NVj@407en
N@@0Ngmo9P1hNWXF0?ooo`00503ooolC07QjNP@0N7Ad101hOGdK07QjNP@0I5]Q10030`8301`A3P@0
j;>O102;O6P407QTF0@0N5IF101aJUT307]`H`@0N5MH101UAcX405a2<@@0RhAn101kLVX307QQGP@0
MFQN101eKVH407QXH0@0Nf=H101[FDd407AFB`<0KUA3101^ED/406aGB0@0LCHe101P=S0404/W70<0
=Q<>101[:Ql408E^F@@0OFMK101[E48406I;@P@0Hd]00`1aEDP406aIC0@0:B0K102NVj@407enN@@0
Ngmo9P1hNWXF0?ooo`00503ooolC07QjNP@0N7Qh101hOGdK07QjNP@0FeIU1011>bT307QIC`@0]YN1
101kK5d407QREP@0N6MO101eG5P307]cH@@0N6=L101UCT440652=`@0RGma101kL6X307Q^IP@0N6QP
101hK6@407Q^IP@0N5IB101_EdX407AMDP<0JeI8101`DTP4061<?0@0JdM0101SD3d40616?0<0GDLm
101UA48407eT@`@0O6EI101^F4D406I;@P@0He0o0`1aDdP406aIC0@05A/L102aXih408:7R@@0Ngmo
9P1hNWXF0?ooo`00503ooolC07QjNP@0N7Qh101hOGdK07QjNP@0FeIU1011>bT307QIC`@0]YN1101k
K5d407QREP@0N6MO101eG5P307]cH@@0N6=L101UCT440652=`@0RGma101kL6X307Q^IP@0N6QP101h
K6@407Q^IP@0N5IB101_EdX407AMDP<0JeI8101`DTP4061<?0@0JdM0101SD3d40616?0<0GDLm101U
A48407eT@`@0O6EI101^F4D406I;@P@0He0o0`1aDdP406aIC0@05A/L102aXih408:7R@@0Ngmo9P1h
NWXF0?ooo`00503ooolC07QjNP@0N7Qh101hOGdK07QjNP@0FeIU1011>bT307QIC`@0]YN1101kK5d4
07QREP@0N6MO101eG5P307]cH@@0N6=L101UCT440652=`@0RGma101kL6X307Q^IP@0N6QP101hK6@4
07Q^IP@0N5IB101_EdX407AMDP<0JeI8101`DTP4061<?0@0JdM0101SD3d40616?0<0GDLm101UA484
07eT@`@0O6EI101^F4D406I;@P@0He0o0`1aDdP406aIC0@05A/L102aXih408:7R@@0Ngmo9P1hNWXF
0?ooo`00503ooolC07QjNP@0N7Qh101hOGdK07QjNP@0FeIU1011>bT307QIC`@0]YN1101kK5d407QR
EP@0N6MO101eG5P307]cH@@0N6=L101UCT440652=`@0RGma101kL6X307Q^IP@0N6QP101hK6@407Q^
IP@0N5IB101_EdX407AMDP<0JeI8101`DTP4061<?0@0JdM0101SD3d40616?0<0GDLm101UA48407eT
@`@0O6EI101^F4D406I;@P@0He0o0`1aDdP406aIC0@05A/L102aXih408:7R@@0Ngmo9P1hNWXF0?oo
o`00503ooolf07QjNP@0KeQ=1022JUX307EYHP@0LFIH101gJ5/407]ZG@@0N6aV101hHf0307QgJP@0
N6QP101/ETT406Y;@0@0Ke95101mMfX307]eKP@0N6aT101hJ60407QbJP@0N5mD101_EdX406i=@@<0
KU]9101SCCd405I:?`@0IdHf101TACT406A9>@<0I4@i101RB3T407ANC0@0NV5F101`E4H40617?@@0
ITe00`1[Dd8406QCB0@02`l?1035]lX408^ASRX0N7Yj5P3oool001@0oooo=P1hNWX406mHC@@0PVYJ
0`1eJF84075VF0@0MfQK101kJUd407Q/IP@0N6=P0`1hMfX407QXH0@0K5I9101ZBd0406mBA@@0OGMZ
0`1kMFh407Q/I0@0N6QP101hLVX407QOE0@0KeM:101^CD4306iKB@@0Hddm101FBSl406M6=P@0I4Di
101TBCT306A4>@@0HTPi101dGT`407YQEP@0L5A6101PAcd406I=@0<0Je=2101XDdP400/?3`@0aKO:
102;THhZ07QjNQH0oooo000D0?ooocH0N7Yj101_F4d4089ZFP<0MFUR101aIUP407MXF`@0NfYM101h
K6H407QSH0<0N7MZ101hJ60406aFB@@0JT]0101_DTD407egJP<0NgE^101hK6@407QXH0@0N79Z101h
Ge@406mGBP@0KTe10`1^FdT406==?@@0ETXo101WASH406A5>@@0I4Ti0`1TA3T40698>@@0M5i<101j
HEH4071DAP@0H4Lm101VCD0306]C@P@0J5=8100;3`l40<FgbP@0Ri6>:P1hNWXF0?ooo`00503ooolf
07QjNP@0KeQ=1022JUX307EYHP@0LFIH101gJ5/407]ZG@@0N6aV101hHf0307QgJP@0N6QP101/ETT4
06Y;@0@0Ke95101mMfX307]eKP@0N6aT101hJ60407QbJP@0N5mD101_EdX406i=@@<0KU]9101SCCd4
05I:?`@0IdHf101TACT406A9>@<0I4@i101RB3T407ANC0@0NV5F101`E4H40617?@@0ITe00`1[Dd84
06QCB0@02`l?1035]lX408^ASRX0N7Yj5P3oool001@0oooo<P1hNWX4075^KP@0Nea7101aGU@306iG
AP@0H69X1025J5H407]^J0@0N71Z101hKVH307Q`J0@0N6aT101eDTl406mGB@@0JTTn101mKf0307ie
L0@0N71X101hE584075/F`@0NfYK101XC48406i?@`<0Hd8e101SDdL405do=@@0IdTf101TB3h406]@
>0<0HTHi101TAC@407mREP@0M5M;101YCT840618?@@0J4e10`1XEDH406mGC0@00@H81034ZZ<408jD
T2X0N7Yj5P3oool001@0oooo<P1hNWX4075^KP@0Nea7101aGU@306iGAP@0H69X1025J5H407]^J0@0
N71Z101hKVH307Q`J0@0N6aT101eDTl406mGB@@0JTTn101mKf0307ieL0@0N71X101hE584075/F`@0
NfYK101XC48406i?@`<0Hd8e101SDdL405do=@@0IdTf101TB3h406]@>0<0HTHi101TAC@407mREP@0
M5M;101YCT840618?@@0J4e10`1XEDH406mGC0@00@H81034ZZ<408jDT2X0N7Yj5P3oool001@0oooo
<P1hNWX4075^KP@0Nea7101aGU@306iGAP@0H69X1025J5H407]^J0@0N71Z101hKVH307Q`J0@0N6aT
101eDTl406mGB@@0JTTn101mKf0307ieL0@0N71X101hE584075/F`@0NfYK101XC48406i?@`<0Hd8e
101SDdL405do=@@0IdTf101TB3h406]@>0<0HTHi101TAC@407mREP@0M5M;101YCT840618?@@0J4e1
0`1XEDH406mGC0@00@H81034ZZ<408jDT2X0N7Yj5P3oool001@0oooo<P1hNWX4075^KP@0Nea7101a
GU@306iGAP@0H69X1025J5H407]^J0@0N71Z101hKVH307Q`J0@0N6aT101eDTl406mGB@@0JTTn101m
Kf0307ieL0@0N71X101hE584075/F`@0NfYK101XC48406i?@`<0Hd8e101SDdL405do=@@0IdTf101T
B3h406]@>0<0HTHi101TAC@407mREP@0M5M;101YCT840618?@@0J4e10`1XEDH406mGC0@00@H81034
ZZ<408jDT2X0N7Yj5P3oool001@0oooo<P1hNWX407EMC@@0NfEJ101XCT8306I@@`@0M7=/1028FeH4
07QcJP@0N79Z2`1hKVH407QOE0@0MEi?101XD40407=CB0<0PGih101hLVX407QOFP@0MFiR101kK6@4
06a@B@@0KUI80`1SAcd406aGB@@0GC`b101TAST406A;?`@0KE110`1/Bd4407AGB`@0NF=F101YCT88
06U@A0@0IT]00`1XED8406]CB0@000H7101==Rl40;ni^`@0N7em9P1hNWXF0?ooo`00503ooolb07Qj
NP@0MEe=101kIEX406Q>@P<0IU13101dLf`408QKEP@0N7=Z101hLVX;07Q^IP@0N5mD101eGTl406Q@
@0@0Le=80`21OWP407QbJP@0N5mJ101eKV8407]/I0@0K519101^ETP306=7?@@0K5M9101M?38406A6
>@@0I4/o101]D44306a;@@@0M5M;101iHeH406U>@PP0JE14101VBd0306QE@P@0Je=810001PL404df
;`@0_kVk101hOGdV07QjNQH0oooo000D0?oooc80N7Yj101eGDd407]UFP@0J4i20`1VD4<407AcK0@0
R5]F101hLfX407QbJP/0N6iV101hGe@407ENC`@0J510101cDdP3085nN0@0N79Z101hGeX407E^HP@0
NfaT101/D4T406iFB0<0HdLm101/EdT405dl<P@0I4Hi101TBcl406e@@@<0K4]1101dEd/407USEP@0
JDi2201YD4@406I;@0<0J5E2101[DdP400061`@0CCH_102o^K/407QmOBH0N7Yj5P3oool001@0oooo
<P1hNWX407EMC@@0NfEJ101XCT8306I@@`@0M7=/1028FeH407QcJP@0N79Z2`1hKVH407QOE0@0MEi?
101XD40407=CB0<0PGih101hLVX407QOFP@0MFiR101kK6@406a@B@@0KUI80`1SAcd406aGB@@0GC`b
101TAST406A;?`@0KE110`1/Bd4407AGB`@0NF=F101YCT8806U@A0@0IT]00`1XED8406]CB0@000H7
101==Rl40;ni^`@0N7em9P1hNWXF0?ooo`00503ooolb07QjNP@0N5Q3101aI5X405Dd9P<0OGEX1022
HF4407]/G`@0N75X101hLVX407QeLP<0N6]R101hKVH407QVG0@0N6IH101UCT84071FAP<0OGU]101k
KVP407QXFP@0N71Z101hJ60406mHB`@0I4Tm0`1YCT8406IAA@@0HdHl101XCCH40694>P@0KE950`1i
FE8407]UE`@0KUU=101VETX406aDB0P0IU140`1XDdD406mMDP@0;2PM100i8A/4044d;`@0/;:c9P1h
NWXF0?ooo`00503ooolb07QjNP@0N5Q3101aI5X405Dd9P<0OGEX1022HF4407]/G`@0N75X101hLVX4
07QeLP<0N6]R101hKVH407QVG0@0N6IH101UCT84071FAP<0OGU]101kKVP407QXFP@0N71Z101hJ604
06mHB`@0I4Tm0`1YCT8406IAA@@0HdHl101XCCH40694>P@0KE950`1iFE8407]UE`@0KUU=101VETX4
06aDB0P0IU140`1XDdD406mMDP@0;2PM100i8A/4044d;`@0/;:c9P1hNWXF0?ooo`00503ooolb07Qj
NP@0N5Q3101aI5X405Dd9P<0OGEX1022HF4407]/G`@0N75X101hLVX407QeLP<0N6]R101hKVH407QV
G0@0N6IH101UCT84071FAP<0OGU]101kKVP407QXFP@0N71Z101hJ60406mHB`@0I4Tm0`1YCT8406IA
A@@0HdHl101XCCH40694>P@0KE950`1iFE8407]UE`@0KUU=101VETX406aDB0P0IU140`1XDdD406mM
DP@0;2PM100i8A/4044d;`@0/;:c9P1hNWXF0?ooo`00503oool^07QjNP@0N65F101[@C84060`:`@0
GDPk0`1cOG@408QZG`@0N75O101hJVH407QbJP@0N71Z0`1hJf8407Q^IP@0N6IN101aI5@406mHC@@0
M6QI0`1nLfL407]/H@@0LEM@101kLfD407QFEP@0J5@o101S@ST306I=@@@0GdPk101[CCH405Dm<@@0
Id@j101dH58307YOD`@0NV=E101[ETX406IDB0@0K4i2101YD4@406IA@0<0Kd]1101_HeD405i0=0@0
Dd0j101hUYl40;2`/2H0N7Yj5P3oool001@0oooo;P1hNWX407QQEP@0Jd4b101P<2/405e8>`<0Lged
1028JUl407QaG`@0N6YV101hLVX407Q`JP<0N6]R101hKVH407QVGP@0LFAD101_F4d407AXF@<0OW=W
101kK644075GD0@0Ng=U101hEUH406QD?`@0Hd8i0`1VCD4405m8>`@0Jddf101E?C4406M4>P@0M61B
0`1jGe<407YSE@@0JeI:101VE4P406a>@P@0JE14101VDD0306m;@@@0Kf=E101N@3@405=0>P@0N9JO
102`/;0V07QjNQH0oooo000D0?ooobh0N7Yj101hHEH406]1<P@0H30[101MB3/307=mM0@0R6YO101h
LEl407QZIP@0N79Z101hL6X307Q[HP@0N6iV101hIUh4075TE0@0KeQ=101dJ5T307icI`@0NfaQ101a
Ee0407]cI@@0N5IF101XE3l406=2>@<0ITe1101OB3/406]==P@0ECda101WA3X407APDP<0NUmC101j
HeD406]FBP@0IUA8101/CT8406U@A0@0IU500`1_Bd4406mSE@@0GT0d101C@3X407RFW`@0/;2`9P1h
NWXF0?ooo`00503oool^07QjNP@0N65F101[@C84060`:`@0GDPk0`1cOG@408QZG`@0N75O101hJVH4
07QbJP@0N71Z0`1hJf8407Q^IP@0N6IN101aI5@406mHC@@0M6QI0`1nLfL407]/H@@0LEM@101kLfD4
07QFEP@0J5@o101S@ST306I=@@@0GdPk101[CCH405Dm<@@0Id@j101dH58307YOD`@0NV=E101[ETX4
06IDB0@0K4i2101YD4@406IA@0<0Kd]1101_HeD405i0=0@0Dd0j101hUYl40;2`/2H0N7Yj5P3oool0
01@0oooo;P1hNWX407Q8@0@0ICP`101M<B`406QSD0<0OG]]1028L6P407Q`J0@0N6QR101hLVX707Q^
IP@0N6QP101hJ5X406mRE0@0NeiB101aJUd307i^J0@0N71X101eHE`407]aIP@0N5Q?101UE4@40613
>`<0GdPk101K@SH406=6>0@0GdHm101gGDl407USE@<0M65E101jGe<406]FBP@0IU96101/CT8406a;
A@@0JDe40`1XBd0406mUG@@0GCTZ101[D4D409Vkb0@0MGQh9P1hNWXF0?ooo`00503oool^07QjNP@0
N4Q0101U>30405da;0@0J6=@0`1mNfd408Q`J0@0N71X101hJ68407QbJPL0N6iV101hJ60407QXFP@0
Kf9D101kGU84075ZG@<0OViX101hL6P407EQG0@0Ng5V101hF4l406EDA0@0H4<k0`1OB3/405]2=P@0
HdHh101OASd407MMC`@0NF=E0`1dHED407YOD`@0JeI:101VDTH406a>@P@0K4]5101YCD@306Q;@0@0
KfEM101M>BX406]@A@@0VK_8101eN7PV07QjNQH0oooo000D0?ooobh0N7Yj101hB40406Dh<0@0GC4/
101XHe0307ekK@@0R71X101hL6P407QXHP@0N79Z1`1hKVH407QXH0@0N6QJ101_HU@407]NDP@0LFYM
0`1nKVP407Q`J0@0MF5L101kLFH407QHC`@0IEA4101P@c/305m8>`@0Fd8f101SASP405m6?@@0Mee?
101iHeD307AQE@@0NUmC101[ETX406IBAP@0K4i2101/BdD406U=A0<0J4]0101_IEd405di:P@0Je15
102I^lP407EhN2H0N7Yj5P3oool001@0oooo;P1hNWX407Q8@0@0ICP`101M<B`406QSD0<0OG]]1028
L6P407Q`J0@0N6QR101hLVX707Q^IP@0N6QP101hJ5X406mRE0@0NeiB101aJUd307i^J0@0N71X101e
HE`407]aIP@0N5Q?101UE4@40613>`<0GdPk101K@SH406=6>0@0GdHm101gGDl407USE@<0M65E101j
Ge<406]FBP@0IU96101/CT8406a;A@@0JDe40`1XBd0406mUG@@0GCTZ101[D4D409Vkb0@0MGQh9P1h
NWXF0?ooo`00503ooolZ07QjNP@0N6ML101hDdH406E1=P@0Ec`]101aIUH308^0L0@0NfaX101hLVX4
07Q/I0P0N6YR0`1aI5H407]ZG@@0N5MF101_HU8407MICP@0LFII0`1nL6`407Q/G@@0N6QR101hJV84
07QDD0@0IDTk101MAS`305m6>P@0HTPk101NCd<4071E@P@0M5e@101gGE0307MQE@@0L5Q;101^DTH4
06IDB0@0K4Pm101/Bd4406I=@@<0IU=0101aHel406M0<`@0J5M;101fPhd408:7QbH0N7Yj5P3oool0
01@0oooo:P1hNWX407QWG0@0N5=6101U@CH405Ll;@@0LFIF0`2;P70407]/J0@0N79Z101hK6@807QZ
HP<0LFAF101kJUd407QGEP@0Kf9B101gFDh4075VF@<0OW1/101hK5d407QXHP@0N6YR101hE50406E9
>`@0GDHl0`1OASX40698>`@0GTm3101`ED8407AMD0@0Mee@0`1gHED4071HB`@0KU96101VE4P406a8
?@@0K4]1101VCD4306IC@0@0LF=O101W@3<406QGB`@0MX>=1022QhLV07QjNQH0oooo000D0?ooobX0
N7Yj101hIe`407QCAP@0ID4f101G?2d4075VEP<0Rh1`101kK6P407QbJP@0N6aT201hJV83075TEP@0
NfYM101hEeH406mRDP@0MeU>101aIUT307i`K0@0N6aM101hJ68407QZHP@0N5A@101UBC/405e6?0<0
GdHj101RB3/405i?@`@0L5E2101dGE0407MMD0<0Mf5E101`F4/406iBAP@0IUA8101/B3d406a;@@@0
ITe10`1VDd04075SG`@0Id0c101XEd/407J3S@@0PXN79P1hNWXF0?ooo`00503ooolZ07QjNP@0N6ML
101hDdH406E1=P@0Ec`]101aIUH308^0L0@0NfaX101hLVX407Q/I0P0N6YR0`1aI5H407]ZG@@0N5MF
101_HU8407MICP@0LFII0`1nL6`407Q/G@@0N6QR101hJV8407QDD0@0IDTk101MAS`305m6>P@0HTPk
101NCd<4071E@P@0M5e@101gGE0307MQE@@0L5Q;101^DTH406IDB0@0K4Pm101/Bd4406I=@@<0IU=0
101aHel406M0<`@0J5M;101fPhd408:7QbH0N7Yj5P3oool001@0oooo:P1hNWX406]5<0@0G3/a100l
:b4405Pk;`@0R7EW0`28O6`407QZIP@0N6aT101hJV8407QXFP@0N6AH0`1_I5H407MKEP@0KUM>101d
H5H407AXF@@0M6QK0`1nL6D407QZHP@0N6YT101hJV84075MDP@0J4Tl101MB3d305m6>P@0I4Tm101X
D4@406eEAP@0NEUC101dGDl307=KC`@0KUeB101`ETX406IDB0@0K596101VD4@406I;@0<0J4m6101a
Hed405l/7@@0KfYL101VA3/4096[/2H0N7Yj5P3oool001@0oooo:P1hNWX406]5<0@0G3/a100l:b44
05Pk;`@0R7EW0`28O6`407QZIP@0N6aT101hJV8407QXFP@0N6AH0`1_I5H407MKEP@0KUM>101dH5H4
07AXF@@0M6QK0`1nL6D407QZHP@0N6YT101hJV84075MDP@0J4Tl101MB3d305m6>P@0I4Tm101XD4@4
06eEAP@0NEUC101dGDl307=KC`@0KUeB101`ETX406IDB0@0K596101VD4@406I;@0<0J4m6101aHed4
05l/7@@0KfYL101VA3/4096[/2H0N7Yj5P3oool001@0oooo:P1hNWX406]5<0@0G3/a100l:b4405Pk
;`@0R7EW0`28O6`407QZIP@0N6aT101hJV8407QXFP@0N6AH0`1_I5H407MKEP@0KUM>101dH5H407AX
F@@0M6QK0`1nL6D407QZHP@0N6YT101hJV84075MDP@0J4Tl101MB3d305m6>P@0I4Tm101XD4@406eE
AP@0NEUC101dGDl307=KC`@0KUeB101`ETX406IDB0@0K596101VD4@406I;@0<0J4m6101aHed405l/
7@@0KfYL101VA3/4096[/2H0N7Yj5P3oool001@0oooo:P1hNWX406]5<0@0G3/a100l:b4405Pk;`@0
R7EW0`28O6`407QZIP@0N6aT101hJV8407QXFP@0N6AH0`1_I5H407MKEP@0KUM>101dH5H407AXF@@0
M6QK0`1nL6D407QZHP@0N6YT101hJV84075MDP@0J4Tl101MB3d305m6>P@0I4Tm101XD4@406eEAP@0
NEUC101dGDl307=KC`@0KUeB101`ETX406IDB0@0K596101VD4@406I;@0<0J4m6101aHed405l/7@@0
KfYL101VA3/4096[/2H0N7Yj5P3oool001@0oooo:P1hNWX405hZ6@@08AH?100o:b@403PT8@@0ZhQb
0`24Mg0407QZI0@0N6YK101hJUd407QZHP@0N6QP0`1eJV8407QUH0@0KeM?101`DT/406UIB@@0NfQK
0`1gJUd407]/J0@0N6YR101hJU/406mFC`@0I4Hj101J?Sd30699=@@0GT@i101`DTD406mKC@@0LU56
101/FD/307AEC`@0JE54101/EDT406=>@P@0J555101VD4@406Q9?`<0J4e8101[FDT405Le8P@0K5M5
101X?3P4096mabH0N7Yj5P3oool001@0oooo:P1hNWX405hZ6@@08AH?100o:b@403PT8@@0ZhQb0`24
Mg0407QZI0@0N6YK101hJUd407QZHP@0N6QP0`1eJV8407QUH0@0KeM?101`DT/406UIB@@0NfQK0`1g
JUd407]/J0@0N6YR101hJU/406mFC`@0I4Hj101J?Sd30699=@@0GT@i101`DTD406mKC@@0LU56101/
FD/307AEC`@0JE54101/EDT406=>@P@0J555101VD4@406Q9?`<0J4e8101[FDT405Le8P@0K5M5101X
?3P4096mabH0N7Yj5P3oool001@0oooo:P1hNWX405hZ6@@08AH?100o:b@403PT8@@0ZhQb0`24Mg04
07QZI0@0N6YK101hJUd407QZHP@0N6QP0`1eJV8407QUH0@0KeM?101`DT/406UIB@@0NfQK0`1gJUd4
07]/J0@0N6YR101hJU/406mFC`@0I4Hj101J?Sd30699=@@0GT@i101`DTD406mKC@@0LU56101/FD/3
07AEC`@0JE54101/EDT406=>@P@0J555101VD4@406Q9?`<0J4e8101[FDT405Le8P@0K5M5101X?3P4
096mabH0N7Yj5P3oool001@0oooo:P1hNWX405hZ6@@08AH?100o:b@403PT8@@0ZhQb0`24Mg0407QZ
I0@0N6YK101hJUd407QZHP@0N6QP0`1eJV8407QUH0@0KeM?101`DT/406UIB@@0NfQK0`1gJUd407]/
J0@0N6YR101hJU/406mFC`@0I4Hj101J?Sd30699=@@0GT@i101`DTD406mKC@@0LU56101/FD/307AE
C`@0JE54101/EDT406=>@P@0J555101VD4@406Q9?`<0J4e8101[FDT405Le8P@0K5M5101X?3P4096m
abH0N7Yj5P3oool001@0oooo9P1hNWX407Q^I`@0HS<X100]91d4034S70@0<b<P1032U7T308AgJP@0
LFAH101kK6@407QZF`@0I599101/FDd305U3>0@0H4Tm101NA3l406A1?P@0KUM5101bEdT307AUF0@0
PG=^101hJV8407QZH0@0Ke9=101QB3X405Y1=0<0I4Da101KBCl406a<?`@0H595101PBd0406eEB0<0
LUeB101SCD0406mIC0@0JEA8101VD4@406QAA@@0J4To0`1XCDP406QEA@@0@2DK101B9a`407A8=`@0
U;o;9P1hNWXF0?ooo`00503ooolV07QjNP@0N6iW101R<bP402dT7@@0<B<L100c8b040<:DN@<0Q7MZ
101aI5P407]/I0@0N6YK101TDTT406aIC@<0FD<h101PBCd405i4?`@0I44n101^EdD4079GB@<0M6EH
1021Lfh407QZHP@0N6YP101_DTd40658>P@0FT4d0`1TAC4405]9?`@0K4`o101PDTD4061;@0@0KEE8
0`1bGE8406==@0@0KeU<101YE4P406I@A0@0J555101XBCl306Q=B0@0J5E510109A/4058W70@0M4Pg
102D_l/V07QjNQH0oooo000D0?ooobH0N7Yj101hKVL4068c:0@0;B@M100a8a`403<S80@0`YAi0`24
MfX4075TF0@0NfaT101hJU/406ABB@@0K5U=0`1I@cP40619?@@0GT@o101T@Ch406iGA@@0LUM90`1d
IEP4085cKP@0N6YR101hJV0406mBC@@0HDPj101J@C@306A5<@@0FdTo101/C3l4061BA@@0H4]0101]
EDP3079MDP@0Hde0101_FD`406UDB0@0IU14101XDDD406Q9?`<0J4e8101XEDD4040U6`@0DRLL101d
B3L409BobbH0N7Yj5P3oool001@0oooo9P1hNWX4075B@@@0J4<m100:1@<401TC3`@0:QdI103HXX@3
07Y^H0@0N6AH101kKV<407QZF`@0J5I;101DAC/304Lh;@@0<RdZ100/8Ql404PX6`@0JTLg101B:1h3
05H_8P@0TX=c101kKVP407QZHP@0KeQ;101QASX405Y3<P<0GTdh101G?SH407=HB`@0K5U<101/EDT4
075BA@<0J4i8101IBSd407MKC@@0K5E9101SCT8405];@0@0H4]00`1]DdP406QCA@@0?2@L101D:1h4
07]3<`@0UlOE9P1hNWXF0?ooo`00503ooolV07QjNP@0LE91101X@cd400X50`@06A<?100Z7AT40=RR
Q0<0NViP101hI5P407]^H`@0N6YK101XET/405A5>`<0AcP]100b;BX402`R7`@0B2PK101ZAcL4058X
7P<0ERlR102BPg<407]^J0@0N6YR101_F4/40656>P@0FT<b0`1NCCP405Ln=P@0LeQ;101/FD`406aE
B@@0LE950`1XCTP405U:?@@0Me]=101/EDT406=>@P@0Fd]0101PBd0306eCB0@0J5=5100l91`405@X
7P@0Nd<c102GamDV07QjNQH0oooo000D0?ooobH0N7Yj101aDT4406Q3?@@02PD3100I4`l402XM6@@0
f::40`1jKV0407QTF0@0NfiS101hJU/406QFB`@0E4Dk0`17>2d4038]:P@0;28O1018:1/406Y7=`@0
DRPN0`1F;b8409:3L`@0NfiX101hJV8406mHB`@0HDHj101J@c8305i=>0@0Echf101cF4/406aIC0@0
K5E9101aDTD306Q>B0@0FDXm101gFdd406aEB@@0Hdi2101KBd04061;@0<0KE=8101XDdD403`T70@0
E2PN101k@c<409O7eBH0N7Yj5P3oool001@0oooo9P1hNWX4075B@@@0J4<m100:1@<401TC3`@0:QdI
103HXX@307Y^H0@0N6AH101kKV<407QZF`@0J5I;101DAC/304Lh;@@0<RdZ100/8Ql404PX6`@0JTLg
101B:1h305H_8P@0TX=c101kKVP407QZHP@0KeQ;101QASX405Y3<P<0GTdh101G?SH407=HB`@0K5U<
101/EDT4075BA@<0J4i8101IBSd407MKC@@0K5E9101SCT8405];@0@0H4]00`1]DdP406QCA@@0?2@L
101D:1h407]3<`@0UlOE9P1hNWXF0?ooo`00503ooolS07QjNP<0Oh61101bB3D40650>0@020l@100K
4`l4034I5@@0i;>C0`1kKV4407ATF0@0NfiQ101hJUd407EVH0@0ET<i0`1aG5H4020Q7P@07Q<A100g
7A<404Tk=P@0ISHY0`1jG4h409><NP@0OWMb101hMG8406mKB`@0HD8i101>>Bd305Y2<0@0;Ph9101n
G4X406=6<0@0Dd0f1016<2D306]?@`@0Fdm1101eEd@406QAAP@0IU14101GA3T4061?@`<0Ldm8101K
B3X403<O6`@0FcDW1020CdH409c=e`<0MGQh8`1hNWXF0?ooo`00503ooolS07QjNP<0Oh61101bB3D4
0650>0@020l@100K4`l4034I5@@0i;>C0`1kKV4407ATF0@0NfiQ101hJUd407EVH0@0ET<i0`1aG5H4
020Q7P@07Q<A100g7A<404Tk=P@0ISHY0`1jG4h409><NP@0OWMb101hMG8406mKB`@0HD8i101>>Bd3
05Y2<0@0;Ph9101nG4X406=6<0@0Dd0f1016<2D306]?@`@0Fdm1101eEd@406QAAP@0IU14101GA3T4
061?@`<0Ldm8101KB3X403<O6`@0FcDW1020CdH409c=e`<0MGQh8`1hNWXF0?ooo`00503ooolS07Qj
NP<0Oh61101bB3D40650>0@020l@100K4`l4034I5@@0i;>C0`1kKV4407ATF0@0NfiQ101hJUd407EV
H0@0ET<i0`1aG5H4020Q7P@07Q<A100g7A<404Tk=P@0ISHY0`1jG4h409><NP@0OWMb101hMG8406mK
B`@0HD8i101>>Bd305Y2<0@0;Ph9101nG4X406=6<0@0Dd0f1016<2D306]?@`@0Fdm1101eEd@406QA
AP@0IU14101GA3T4061?@`<0Ldm8101KB3X403<O6`@0FcDW1020CdH409c=e`<0MGQh8`1hNWXF0?oo
o`00503ooolS07QjNP<0Oh61101bB3D40650>0@020l@100K4`l4034I5@@0i;>C0`1kKV4407ATF0@0
NfiQ101hJUd407EVH0@0ET<i0`1aG5H4020Q7P@07Q<A100g7A<404Tk=P@0ISHY0`1jG4h409><NP@0
OWMb101hMG8406mKB`@0HD8i101>>Bd305Y2<0@0;Ph9101nG4X406=6<0@0Dd0f1016<2D306]?@`@0
Fdm1101eEd@406QAAP@0IU14101GA3T4061?@`<0Ldm8101KB3X403<O6`@0FcDW1020CdH409c=e`<0
MGQh8`1hNWXF0?ooo`00503oool407QfMP@0N7em101hM7@307QmOA@0N7Yj0`0D1`D40:9QB`@0J5A8
100J6AL401<C60@08Q@?103Z^IP307MXF`@0N6YM201dIUT407]/J0@0J5U;0`1dEdd4040l<`@0F4Ln
101J?B`406=8=`@0Pea60`25HUD407ebH`@0OWUd101hL6X406mFAP@0HD8i101E>b`305M0=0@0?RDN
101QEU0403@]9`@02PH6101?;28304Pn<`@0:ahF101M@CL4058i9`@0LDTh101ICD84061?@`<0Lde2
1015?2l402DJ5@@0B2/R102HJUT409W0bP<0LWEf8`1hNWXF0?ooo`00503oool407QfMP@0N7em101h
M7@307QmOA@0N7Yj0`0D1`D40:9QB`@0J5A8100J6AL401<C60@08Q@?103Z^IP307MXF`@0N6YM201d
IUT407]/J0@0J5U;0`1dEdd4040l<`@0F4Ln101J?B`406=8=`@0Pea60`25HUD407ebH`@0OWUd101h
L6X406mFAP@0HD8i101E>b`305M0=0@0?RDN101QEU0403@]9`@02PH6101?;28304Pn<`@0:ahF101M
@CL4058i9`@0LDTh101ICD84061?@`<0Lde21015?2l402DJ5@@0B2/R102HJUT409W0bP<0LWEf8`1h
NWXF0?ooo`00503oool407QfMP@0N7em101hM7@307QmOA@0N7Yj0`0D1`D40:9QB`@0J5A8100J6AL4
01<C60@08Q@?103Z^IP307MXF`@0N6YM201dIUT407]/J0@0J5U;0`1dEdd4040l<`@0F4Ln101J?B`4
06=8=`@0Pea60`25HUD407ebH`@0OWUd101hL6X406mFAP@0HD8i101E>b`305M0=0@0?RDN101QEU04
03@]9`@02PH6101?;28304Pn<`@0:ahF101M@CL4058i9`@0LDTh101ICD84061?@`<0Lde21015?2l4
02DJ5@@0B2/R102HJUT409W0bP<0LWEf8`1hNWXF0?ooo`00503oool407QfMP@0N7em101hM7@307Qm
OA@0N7Yj0`0D1`D40:9QB`@0J5A8100J6AL401<C60@08Q@?103Z^IP307MXF`@0N6YM201dIUT407]/
J0@0J5U;0`1dEdd4040l<`@0F4Ln101J?B`406=8=`@0Pea60`25HUD407ebH`@0OWUd101hL6X406mF
AP@0HD8i101E>b`305M0=0@0?RDN101QEU0403@]9`@02PH6101?;28304Pn<`@0:ahF101M@CL4058i
9`@0LDTh101ICD84061?@`<0Lde21015?2l402DJ5@@0B2/R102HJUT409W0bP<0LWEf8`1hNWXF0?oo
o`00503oool407QfMP@0N7mo101hN7P307QmOA00N7Yj100F30X3018;2@@0=0T4101<<BH4010=4P@0
518?100[61<40>fiV0<0M6II101nKVP40650>P@0K5U;1025Mg8407E^I0<0MF5J101[E4d406I=@0@0
I513101/D4@407aUD0<0OF5H101gJU`407ikMP@0N6iV101_D4P4065@A0@0FSh^0`1ICCT4068n<0@0
J5aB101?>c4400H82P@0AR8G0`0k;BT402@L60@0JD4`101XACH407iNB@@0GdTo101NCd<307=C@@@0
7aXI100U6a@403hQ60@0WD`i102D_l/307EhN2<0N7Yj5P3oool001@0oooo101hMWH407QoO`@0N7Qh
0`1hOGd@07QjNP@05P`:0`0B2`T403@910@0C34V100@3A8401@B3`@0:aPC103]^IP307AVF@@0OViX
101Q@3X406aIB`@0QGMb101eKV@307EQFP@0JeA=101VCD0406A@@`@0K514101lIE0307eQF0@0MfYL
101nNgH407Q^IP@0Ke18101QD4@405Xn;P<0FDdi101R?S0406QLDP@0Cc/a100620X404HR5`<0>bdY
100T71P406U1<0@0J4Df101nGTT405m9?`@0GTm30`1cDd4401lJ6@@09A/D100n8AP409e<>@@0U;o;
0`1eN7PS07QjNQH0oooo000D0?ooo`@0N7If101hOgl407QhN0<0N7em401hNWX401H<2P<04P/9100d
2@@404`a9P@040dB100D4Pl402/H4`@0kKVH0`1dIUT407i^J0@0HD0j101/FD/408EgLP@0MFiT0`1e
HEX406]DC@@0ITe0101TD4<406a@A0@0O6E@0`1mHEP407MZG0@0OW]f101hKVH406m@B0@0HE14101J
?Rh305U=>@@0HSh`101XG58404lk<@@01PP:10168QL303/]:@@091`H101Y@C0406Q5=P@0OUi9101O
BCl405i?@`<0Le=1100O6QT402DK50@0?R4H102MC3T409Bob`<0MGQh8`1hNWXF0?ooo`00503oool4
07QfMP@0N7mo101hN7P307QmOA00N7Yj100F30X3018;2@@0=0T4101<<BH4010=4P@0518?100[61<4
0>fiV0<0M6II101nKVP40650>P@0K5U;1025Mg8407E^I0<0MF5J101[E4d406I=@0@0I513101/D4@4
07aUD0<0OF5H101gJU`407ikMP@0N6iV101_D4P4065@A0@0FSh^0`1ICCT4068n<0@0J5aB101?>c44
00H82P@0AR8G0`0k;BT402@L60@0JD4`101XACH407iNB@@0GdTo101NCd<307=C@@@07aXI100U6a@4
03hQ60@0WD`i102D_l/307EhN2<0N7Yj5P3oool001@0oooo101hNWX407QmOAL0N7Yj10000003030R
60@0:ADB100^8A`400d92P@0;1TD100`61@40>B^SP<0NfQK101dJ5d4079LF0@0I5I7101J@3D406=>
@0<0Dd8f1014<B`403dW7`@0BS<U101D=BP405Tg:@<0OfaN101kKf4407ibKP@0N6YK101_D4H4065F
B0@0FSdb0`1RAC<4061=>@@0L5U9101SC48403Pk=`@0JdXk0`1B=b`404hf:P@0PeM5101fDc/406=C
B0@0Je10101VDdP3061=@0@04Q4?100S5Q<4040R60@0Rc@U102Ne=lV07QjNQH0oooo000D0?ooo`@0
N7Yj101hOGdG07QjNP@000000`0`8QP402TE4P@0;R4L100=2@X402`I50@0<1PD103T[Xh307]XF`@0
M6QM101bG5P406AFA`@0FT0e101SCT0305=2=P@0A34/100m9al404Xc9@@0E3DX101I=bT307m/GP@0
NfmQ101nLVh407QZF`@0Ke16101QETP405Xm<P<0HTDc101PCCT4071IB@@0Hda2100h>cL406]:>`<0
DSL/101>=RX408=GA@@0MU<k101SDdP406]@@0@0IU=80`1PCD04018A3`@08aHC10108QP408/d9@@0
W]CO9P1hNWXF0?ooo`00503oool407QjNP@0N7em5`1hNWX4000000<0<28H100Y5A8402hQ70@03@T:
100/6A@4030H50@0i:j>0`1kJ5/407AXG@@0LUaH101TETL405Y0=@@0Hdi00`1C@SH404@a;0@0?BLO
101:<bD405@e:0@0FCLY0`1oK5h407]_H@@0OW9^101hJU/406m@AP@0HEI8101J?C830695<`@0H4di
101`FDT406=<@P@0>3/g101[BS/3058g;0@0CSHZ1023EdD407IC>`@0He=8101[D40406ICB0<0H4e0
100B4@l402<F4`@0@28H102;=2D409kDgbH0N7Yj5P3oool001@0oooo101hNWX407QmOAL0N7Yj1000
0003030R60@0:ADB100^8A`400d92P@0;1TD100`61@40>B^SP<0NfQK101dJ5d4079LF0@0I5I7101J
@3D406=>@0<0Dd8f1014<B`403dW7`@0BS<U101D=BP405Tg:@<0OfaN101kKf4407ibKP@0N6YK101_
D4H4065FB0@0FSdb0`1RAC<4061=>@@0L5U9101SC48403Pk=`@0JdXk0`1B=b`404hf:P@0PeM5101f
Dc/406=CB0@0Je10101VDdP3061=@0@04Q4?100S5Q<4040R60@0Rc@U102Ne=lV07QjNQH0oooo000D
0?oooal0N7Yj1002000301d@2`@06Q<@100P510401`B3`@07QDA100g9b<40<RDM`<0QFiQ101eK5l4
07]/J0@0Kf5H101UEd/406=6@@<0AD4o101]Bd@405Ln<P@0Hd`n101N@3@407YHB`<0S8Ac1022Lf`4
07]/IP@0N5MD101_GTl4065DB0@0FSPh0`109QX404X^8@@0LUa2101]DdD406QA@@@0JDi40`1MBc/4
05];@@@0N5Y6101NCD0406Q=B@@0H4m0101]Dd8304Dj<0@02@/:100J4a0409EIA@@0HBTN102Zg>HV
07QjNQH0oooo000D0?oooal0N7Yj1002000301d@2`@06Q<@100P510401`B3`@07QDA100g9b<40<RD
M`<0QFiQ101eK5l407]/J0@0Kf5H101UEd/406=6@@<0AD4o101]Bd@405Ln<P@0Hd`n101N@3@407YH
B`<0S8Ac1022Lf`407]/IP@0N5MD101_GTl4065DB0@0FSPh0`109QX404X^8@@0LUa2101]DdD406QA
@@@0JDi40`1MBc/405];@@@0N5Y6101NCD0406Q=B@@0H4m0101]Dd8304Dj<0@02@/:100J4a0409EI
A@@0HBTN102Zg>HV07QjNQH0oooo000D0?oooal0N7Yj1002000301d@2`@06Q<@100P510401`B3`@0
7QDA100g9b<40<RDM`<0QFiQ101eK5l407]/J0@0Kf5H101UEd/406=6@@<0AD4o101]Bd@405Ln<P@0
Hd`n101N@3@407YHB`<0S8Ac1022Lf`407]/IP@0N5MD101_GTl4065DB0@0FSPh0`109QX404X^8@@0
LUa2101]DdD406QA@@@0JDi40`1MBc/405];@@@0N5Y6101NCD0406Q=B@@0H4m0101]Dd8304Dj<0@0
2@/:100J4a0409EIA@@0HBTN102Zg>HV07QjNQH0oooo000D0?oooal0N7Yj1002000301d@2`@06Q<@
100P510401`B3`@07QDA100g9b<40<RDM`<0QFiQ101eK5l407]/J0@0Kf5H101UEd/406=6@@<0AD4o
101]Bd@405Ln<P@0Hd`n101N@3@407YHB`<0S8Ac1022Lf`407]/IP@0N5MD101_GTl4065DB0@0FSPh
0`109QX404X^8@@0LUa2101]DdD406QA@@@0JDi40`1MBc/405];@@@0N5Y6101NCD0406Q=B@@0H4m0
101]Dd8304Dj<0@02@/:100J4a0409EIA@@0HBTN102Zg>HV07QjNQH0oooo000D0?ooo`P0N7Yj101h
M7@307QmOA00N7Yj10070`4301/=2P@07QDA100K510400h71`@08QDA100k:RH40:=bFP<0S7=S101k
L6<407QZIP@0N71X101eK68406mPG0<0JFUT1028LVP4079YH0@0N71X101eJF8408EaH@<0N6iQ101n
MG04075RE0@0M5mF101aHU8406QGC@@0JeA=0`1B@SH403TT8`@0>BTM100`81P406m5=`@0MUY=0`1V
DCl406=@@@@0H4e1101RAS/405I4>@@0KU18101]Cd0301lJ5@@03`d<100Z8Qd40957<`@0B24G100f
>3H30:f][R<0N7Yj5P3oool001@0oooo201hNWX407QdM0<0N7em401hNWX400L30@<06`d:100N5A44
01/D40@03PL7100R5A4403/Z9P@0Xg9J0`2<Lf<407]`H`@0N6YV101hL6P407E/HP@0Kf1L0`1YJF@4
08QbJ0@0LVUP101hL6P407EYHP@0QG5Q0`1hKV4407ieL0@0LF9D101dGeH4075RDP@0J5M=101[E4d3
0592=P@0>B@S100i:Ad4030P60@0KdDg101fFTd306IA?`@0He11101PCD440696>`@0ET@i101^D4P4
06e?@0<07aXE100?3@`402XR7@@0TDLc10188AL403Hh=P<0[Jf^8`1hNWXF0?ooo`00503oool807Qj
NP@0N7Ad0`1hOGd@07QjNP@01`<10`0K3@X401hE4@@06a@@100>1`L4028E4@@0>bXV102SLUX308ac
H`@0Ng1S101hJVH407Q`J0@0MFaR101_H5`306UYI0@0R79X101bJF0407Q`J0@0MFUR1025LF4307Q^
H@@0OWE`101aHU@407AOEP@0LF9B101XEdd406]DC@<0DT8f100i92<403TY7@@0<20H101_ACL407IJ
C@<0IU4o101SD444061=@@@0HTHk101FA3T406i@B0@0KDm00`0O6QD400l=30@0:R8M102AAc<404PQ
5`@0=SPf0`2][JhS07QjNQH0oooo000D0?ooo`P0N7Yj101hN7P307QmOA00N7Yj100610<3020H5@@0
7A<@100O510401@?2`@09AHA100j:RH409aVC`<0TWUY101nLVD407QZIP@0N79Z101hKVH407QeLPL0
N79^101hJf8407QeLP@0N6]R101hK68307EVF0@0NfiS101eIUP4075NDP@0M5U>101aHUH407AREP<0
KUI@101@Ad@405]5?@@0>S8[100o9Q`4038S6P<0CBlV100n=bh404hc9`@0CS@W101cEDh407=@A0@0
HTPj0`0<3@`401TB3`@09QXJ100d4@/4048G3`@0;34_0`3Og]lS07QjNQH0oooo000D0?ooo`P0N7Yj
101hN7P307QmOA00N7Yj100610<3020H5@@07A<@100O510401@?2`@09AHA100j:RH409aVC`<0TWUY
101nLVD407QZIP@0N79Z101hKVH407QeLPL0N79^101hJf8407QeLP@0N6]R101hK68307EVF0@0NfiS
101eIUP4075NDP@0M5U>101aHUH407AREP<0KUI@101@Ad@405]5?@@0>S8[100o9Q`4038S6P<0CBlV
100n=bh404hc9`@0CS@W101cEDh407=@A0@0HTPj0`0<3@`401TB3`@09QXJ100d4@/4048G3`@0;34_
0`3Og]lS07QjNQH0oooo000D0?ooo`P0N7Yj101hN7P307QmOA00N7Yj100610<3020H5@@07A<@100O
510401@?2`@09AHA100j:RH409aVC`<0TWUY101nLVD407QZIP@0N79Z101hKVH407QeLPL0N79^101h
Jf8407QeLP@0N6]R101hK68307EVF0@0NfiS101eIUP4075NDP@0M5U>101aHUH407AREP<0KUI@101@
Ad@405]5?@@0>S8[100o9Q`4038S6P<0CBlV100n=bh404hc9`@0CS@W101cEDh407=@A0@0HTPj0`0<
3@`401TB3`@09QXJ100d4@/4048G3`@0;34_0`3Og]lS07QjNQH0oooo000D0?ooo`P0N7Yj101hN7P3
07QmOA00N7Yj100610<3020H5@@07A<@100O510401@?2`@09AHA100j:RH409aVC`<0TWUY101nLVD4
07QZIP@0N79Z101hKVH407QeLPL0N79^101hJf8407QeLP@0N6]R101hK68307EVF0@0NfiS101eIUP4
075NDP@0M5U>101aHUH407AREP<0KUI@101@Ad@405]5?@@0>S8[100o9Q`4038S6P<0CBlV100n=bh4
04hc9`@0CS@W101cEDh407=@A0@0HTPj0`0<3@`401TB3`@09QXJ100d4@/4048G3`@0;34_0`3Og]lS
07QjNQH0oooo000D0?oooal0N7Yj10071@D303DV8`@05A4>100Q510401hC40@09aTI100i:R@4089G
@@<0RW1P1025MfT407QZH0@0N6aV101hL6P407Q`JP<0N7Eb101hLVh407Q`JP@0N7Eb101hJEh407Q^
IP<0N6aR101hJ5X407QZG@@0KeY?101dH5@407AMDP@0M6AG0`1dFEH406QLCP@0IU97101CAS/404m3
>@@0Cd4e0`1F>B`404hk;P@0LTTk101PD4@407U;BP@0GU10101A@CD300`<30@07A<?100K514401L?
2P@0<AXE100l=C430=cLgB<0N7Yj5P3oool001@0oooo7`1hNWX400L51@<0=BHS100E4@h4024D40@0
7Q<@100W6AT403TZ90@0PUM10`2:L60408EgJ@@0N6YP101hK6H407Q`J0@0N71Z0`1hMG8407QbKP@0
N71Z101hMG8407QYGP@0N6iV0`1hK68407QXFP@0N6YM101_FTl407APE0@0M5eB101dI5L307AIEP@0
J5a>101VDTL405=6>`@0Cd<i101?@CD305Hi;0@0CS/^101bBC/4061@A0@0ND]:101ND4040551=@<0
30`<100M4`l401/D4@@05`l:100a6QD403`e<@<0g=cM8`1hNWXF0?ooo`00503ooolO07QjNP@01`D5
0`0e9R<401DA3P@08A@@100N4a0402LI6@@0>BXT1022Ed4308Y`H0@0QGMY101hJV0407Q/IP@0N71X
101hL6X307QeLP@0N79^101hL6X407QeLP@0N6UN101hKVH307Q/HP@0N6QJ101hJUd406mJC`@0M61D
101dGE8407ATE`<0M5UF101XG4h406IBA`@0DdHk101?@cT404m1=@<0EST/101>>bh40799>`@0H514
101iBdX405i@@0@0DD4e0`0<30`401dC3`@06a@A100G3`X4034J5@@0?3Da0`3Lg=dS07QjNQH0oooo
000D0?oooal0N7Yj10071@D303DV8`@05A4>100Q510401hC40@09aTI100i:R@4089G@@<0RW1P1025
MfT407QZH0@0N6aV101hL6P407Q`JP<0N7Eb101hLVh407Q`JP@0N7Eb101hJEh407Q^IP<0N6aR101h
J5X407QZG@@0KeY?101dH5@407AMDP@0M6AG0`1dFEH406QLCP@0IU97101CAS/404m3>@@0Cd4e0`1F
>B`404hk;P@0LTTk101PD4@407U;BP@0GU10101A@CD300`<30@07A<?100K514401L?2P@0<AXE100l
=C430=cLgB<0N7Yj5P3oool001@0oooo7`1hNWX400T50`<0;B0G100N61D401lC3`@09A0;100Z6AH4
03HT6@@0ES``0`2CJEL408MiJP@0NfaO101hJVH407QbJP@0N7Eb0`1hKVH407QeLPP0N79^101hJEh4
07Q^IP<0N6QJ101hJ60407QTEP@0KeI;101dI5L407APE0@0M5eB0`1dFe8406]HBP@0KE96101VDTH4
061>@P@0JEA70`1PBd0406QAA@@0Le14101XD4T406]:@0@0Gd/k100g:Ah301<?3`@07A<?100X61@4
01TC3`@091DA100j9Q/30:J?TP@0Ri6@7`1hNWXF0?ooo`00503ooolO07QjNP@02@D30`0]81L401hH
5@@07a<?100U40/402XI5P@0=R@I101F?30309=YE`@0QgUZ101kK5l407QZIP@0N79Z101hMG8307Q^
IP@0N7Eb201hLVh407QYGP@0N6iV0`1hJ5X407QXH0@0N6AF101_ET/407ATE`@0M61D101dGE8307AK
DP@0JeQ:101]DTH406IBAP@0H4i2101YE4L3061;@0@0J555101cD4@406Q@B@@0JdY0101OBc/403LY
7P<04`l?100M4`l402PH50@06A<?100T5A4403XV6`<0YXnB102;TI0O07QjNQH0oooo000D0?oooal0
N7Yj10091@<302dP5`@07QPE100O4`l402D@2`@0:QTF100f91T405Hl<0<0TfUG1027NFX407]/G`@0
N6YV101hLVX407QeLP<0N6iV101hMG8807QbKP@0N6UN101hKVH307QXFP@0N6QP101hI5H406mFB`@0
M6AG101dH5@407AMDP<0M5]B101[F4X406eBAP@0IU96101PCT8406UDA`<0H4]0101XDDD407=@A0@0
J519101[BT0405m;>`@0=bTN0`0C3`l401dC3`@0:1PD100I4`l402@E4@@0>RHK0`2VSi8408^AT1l0
N7Yj5P3oool001@0oooo7`1hNWX400T50`<0;B0G100N61D401lC3`@09A0;100Z6AH403HT6@@0ES``
0`2CJEL408MiJP@0NfaO101hJVH407QbJP@0N7Eb0`1hKVH407QeLPP0N79^101hJEh407Q^IP<0N6QJ
101hJ60407QTEP@0KeI;101dI5L407APE0@0M5eB0`1dFe8406]HBP@0KE96101VDTH4061>@P@0JEA7
0`1PBd0406QAA@@0Le14101XD4T406]:@0@0Gd/k100g:Ah301<?3`@07A<?100X61@401TC3`@091DA
100j9Q/30:J?TP@0Ri6@7`1hNWXF0?ooo`00503ooolO07QjNP@01P<10`0c:BH4028I5P@09QHC100F
3`/4028E4@@08AD@1016:R030758<0@0V85a101nL6<407QZIP@0N79Z101hN7H307Q`JP@0N6iV101h
MG8807Q[HP@0N6iV0`1hIUH407QZH0@0LEa?101aGU8807AMDP@0M5]@0`1dGE8406]FBP@0JE96101Y
EDT406UIC@@0J5140`1/D4@406IAA@@0FdTo101PCD84061=@0@0Bc``100H5aD300l<2P@09API100G
410401H@2`@03`L7100b6aH307iQF`@0Z[Fe7`1hNWXF0?ooo`00503ooolO07QjNP@01P<10`0c:BH4
028I5P@09QHC100F3`/4028E4@@08AD@1016:R030758<0@0V85a101nL6<407QZIP@0N79Z101hN7H3
07Q`JP@0N6iV101hMG8807Q[HP@0N6iV0`1hIUH407QZH0@0LEa?101aGU8807AMDP@0M5]@0`1dGE84
06]FBP@0JE96101YEDT406UIC@@0J5140`1/D4@406IAA@@0FdTo101PCD84061=@0@0Bc``100H5aD3
00l<2P@09API100G410401H@2`@03`L7100b6aH307iQF`@0Z[Fe7`1hNWXF0?ooo`00503ooolO07Qj
NP@01P<10`0c:BH4028I5P@09QHC100F3`/4028E4@@08AD@1016:R030758<0@0V85a101nL6<407QZ
IP@0N79Z101hN7H307Q`JP@0N6iV101hMG8807Q[HP@0N6iV0`1hIUH407QZH0@0LEa?101aGU8807AM
DP@0M5]@0`1dGE8406]FBP@0JE96101YEDT406UIC@@0J5140`1/D4@406IAA@@0FdTo101PCD84061=
@0@0Bc``100H5aD300l<2P@09API100G410401H@2`@03`L7100b6aH307iQF`@0Z[Fe7`1hNWXF0?oo
o`00503ooolO07QjNP@01P<10`0c:BH4028I5P@09QHC100F3`/4028E4@@08AD@1016:R030758<0@0
V85a101nL6<407QZIP@0N79Z101hN7H307Q`JP@0N6iV101hMG8807Q[HP@0N6iV0`1hIUH407QZH0@0
LEa?101aGU8807AMDP@0M5]@0`1dGE8406]FBP@0JE96101YEDT406UIC@@0J5140`1/D4@406IAA@@0
FdTo101PCD84061=@0@0Bc``100H5aD300l<2P@09API100G410401H@2`@03`L7100b6aH307iQF`@0
Z[Fe7`1hNWXF0?ooo`00503ooolO07QjNP@01`<10`0_9R<402`R7P@09AXF100S5Q<4020D40@0:QdI
1010;RT304lh;0@0Y7QU1025Lf@407Q/J0@0N6aT101hLf`307QeLP@0N71Z101hMG8407QYGPP0N6iV
0`1hIU`4075TEP@0LEa@201dFe0407AMDP@0KUeB0`1`F4/406iHB`@0IU96101/EDT406aGB`@0JE96
0`1XD4@406IAA@@0EdTo101]CD4405]8>`@0<RPR100F4@l3028J5P@04`/;100F410400l71`@05a0@
100V5Q4306eFC`@0_<C77`1hNWXF0?ooo`00503ooolO07QjNP@01`<10`0_9R<402`R7P@09AXF100S
5Q<4020D40@0:QdI1010;RT304lh;0@0Y7QU1025Lf@407Q/J0@0N6aT101hLf`307QeLP@0N71Z101h
MG8407QYGPP0N6iV0`1hIU`4075TEP@0LEa@201dFe0407AMDP@0KUeB0`1`F4/406iHB`@0IU96101/
EDT406aGB`@0JE960`1XD4@406IAA@@0EdTo101]CD4405]8>`@0<RPR100F4@l3028J5P@04`/;100F
410400l71`@05a0@100V5Q4306eFC`@0_<C77`1hNWXF0?ooo`00503ooolO07QjNP@01`<10`0_9R<4
02`R7P@09AXF100S5Q<4020D40@0:QdI1010;RT304lh;0@0Y7QU1025Lf@407Q/J0@0N6aT101hLf`3
07QeLP@0N71Z101hMG8407QYGPP0N6iV0`1hIU`4075TEP@0LEa@201dFe0407AMDP@0KUeB0`1`F4/4
06iHB`@0IU96101/EDT406aGB`@0JE960`1XD4@406IAA@@0EdTo101]CD4405]8>`@0<RPR100F4@l3
028J5P@04`/;100F410400l71`@05a0@100V5Q4306eFC`@0_<C77`1hNWXF0?ooo`00503ooolO07Qj
NP@01`<10`0_9R<402`R7P@09AXF100S5Q<4020D40@0:QdI1010;RT304lh;0@0Y7QU1025Lf@407Q/
J0@0N6aT101hLf`307QeLP@0N71Z101hMG8407QYGPP0N6iV0`1hIU`4075TEP@0LEa@201dFe0407AM
DP@0KUeB0`1`F4/406iHB`@0IU96101/EDT406aGB`@0JE960`1XD4@406IAA@@0EdTo101]CD4405]8
>`@0<RPR100F4@l3028J5P@04`/;100F410400l71`@05a0@100V5Q4306eFC`@0_<C77`1hNWXF0?oo
o`00503ooolO07QjNP@01`D40`0a:2D403@X90@0;28N100U5Q8401@?2`@0;QXF1012:Al305/k;0@0
T5Q01029NFX407]`I@@0N6YT101hK6@307QcK0@0N7Eb101hLVh407Q`JP@0N6]R101hKVH307QVGP@0
MFQH101aG50406iICP@0L5Q;101gFE<406]IB`<0L596101`EDl406IDAP@0K5E9101/D4@406IAA@<0
IU14101RASX406I=@@@0H48f100n=2h402HL5P@071<A0`0E40/401@?3`@050/;100G40/401TA4@@0
;QTD0`3EdM0409jQXQl0N7Yj5P3oool001@0oooo7`1hNWX400L510<0<BPU100d:2@402`R7P@09AHB
100D3`/402hJ5P@0@RTO0`1K>b`4091H@0@0RGUZ101kL6D407QZI0@0N6aT0`1hLf`407QeLP@0N79^
101hL6X407Q[HP@0N6iV0`1hIUh407EXF0@0LEa@101^FDh4071HB`@0MeUC101[FD/3071BAP@0L5E?
101VE4H406aEB@@0K514101VDDD306I@A0@0HTHj101VCD440612=P@0?S@^100V71H401`C4@<05A0;
100D3`l401@;2`@05a0;100I4A4402hI50<0eM7@102NXJ8O07QjNQH0oooo000D0?oooal0N7Yj1007
1@@3034X9@@0=2PT100/8Qh402DF4P@050l;100^6QH4048Y7`<0Fc//102@F40408UiJP@0Ng1U101h
JV@407Q/I0<0N7=/101hMG8407QbKP@0N71Z101hJf8407Q^IP<0N6IN101eJ5P4075LD0@0KUU>101`
F4/407MID`@0JeU;0`1`DTH4071EC`@0IUA6101/EDT406a@A0@0IU550`1VD4@40696>P@0ITe1101P
@SH403hd;P@09Q`F100L4a4301D@2`@050l?100D2`/401L@2`@06A4A100^6A@30=GAd0@0WZ6R7`1h
NWXF0?ooo`00503ooolG07QjNP@0N7Ad101aL70400H61@<0<2@P100e:BD402dS7`@06a4>100U71P4
02`M6@@0<B<M0`1U?bd407aA@@@0R7MY1021MFL407QZIPL0N71X101hN7H807QbKP@0N6UN101hKVH3
075PDP@0NfIH101_ET/4075KD0@0M5a@101`F4d406iIB`<0L596101YFe0406UDAP@0ITY4101XDT@4
06IAA@<0J555101VB3d405i?@`@0CcX_1012<bT4020I4`@08ADC0`0F4`l401/D40@06a<@100G40/4
01`D4@@0;aTE0`3oool407EhN1l0N7Yj5P3oool001@0oooo5`1hNWX407QdM0@0LG1`10061PD3030T
80@0=BTU100]8al401/A3P@09A`H100/7AT4034S7@<0ICl]101lDD4408QgJ@@0PGEW101hJVH707Q`
J0@0N7Qf201hLVh407QYGP@0N6iV0`1aH58407]VF0@0KeI;101aFe0407ALD0@0L5Q=101^FD/3071B
AP@0JE]@101YE4H406I:A0@0J594101VDDD306QAA@@0ITPm101NCd<404lj;`@0@S<Y100P6A<4024E
4`<05Q<?100K510401/C40@05a0;100L514402lI5@<0oooo101eN7PO07QjNQH0oooo000D0?oooaL0
N7Yj101hM7@4075`L0@01PH50`0`920403DY9@@0;B<O100K4@h402DL60@0;1dI100a8ad306Do;@@0
O5511028MfT4085eI`@0N6YV1`1hL6P407QhMPP0N79^101hJEh407Q^IP<0LF1B101kIUP406mFB`@0
LE]@101dG504071HC@@0KUU;0`1`DTH406UKD0@0JEA6101VBT@406QBA0@0IU550`1XDDD406I8?@@0
GTm3101?>Rl4048c:@@081TC100Q5A<301HC3`@06a@@100K4a0401L@2`@071@A100_6AD30?ooo`@0
MGQh7`1hNWXF0?ooo`00503ooolG07QjNP@0N7Ad101aL70400H61@<0<2@P100e:BD402dS7`@06a4>
100U71P402`M6@@0<B<M0`1U?bd407aA@@@0R7MY1021MFL407QZIPL0N71X101hN7H807QbKP@0N6UN
101hKVH3075PDP@0NfIH101_ET/4075KD0@0M5a@101`F4d406iIB`<0L596101YFe0406UDAP@0ITY4
101XDT@406IAA@<0J555101VB3d405i?@`@0CcX_1012<bT4020I4`@08ADC0`0F4`l401/D40@06a<@
100G40/401`D4@@0;aTE0`3oool407EhN1l0N7Yj5P3oool001@0oooo5`1hNWX407QhN0@0MGQh1003
10<303`U70@0;bDR100d:2@402XP7@@09a`H100]8A`4038Q60<0FdHj101Q?Bl408YVEP@0P7MX101k
K6P407Q/I0<0N71X101hL6X807Q^IP@0N6EL101aI5H3075LC`@0MfQK101aED/406iHAP@0L5U?101^
F4H4071IC`<0L5Q<101VEDT406aDB0@0JDa2101VDdD406Q;@0<0J4e1101KBd0404m2=P@0B38W100/
7ad401/C4@@061<?0`0E3`/401L@40@04`/;100:1`L401D<30@0BBXT0`3[l?0407EhN1l0N7Yj5P3o
ool001@0oooo5`1hNWX407QhN0@0MGQh100310<303`U70@0;bDR100d:2@402XP7@@09a`H100]8A`4
038Q60<0FdHj101Q?Bl408YVEP@0P7MX101kK6P407Q/I0<0N71X101hL6X807Q^IP@0N6EL101aI5H3
075LC`@0MfQK101aED/406iHAP@0L5U?101^F4H4071IC`<0L5Q<101VEDT406aDB0@0JDa2101VDdD4
06Q;@0<0J4e1101KBd0404m2=P@0B38W100/7ad401/C4@@061<?0`0E3`/401L@40@04`/;100:1`L4
01D<30@0BBXT0`3[l?0407EhN1l0N7Yj5P3oool001@0oooo5`1hNWX407QhN0@0MGQh100310<303`U
70@0;bDR100d:2@402XP7@@09a`H100]8A`4038Q60<0FdHj101Q?Bl408YVEP@0P7MX101kK6P407Q/
I0<0N71X101hL6X807Q^IP@0N6EL101aI5H3075LC`@0MfQK101aED/406iHAP@0L5U?101^F4H4071I
C`<0L5Q<101VEDT406aDB0@0JDa2101VDdD406Q;@0<0J4e1101KBd0404m2=P@0B38W100/7ad401/C
4@@061<?0`0E3`/401L@40@04`/;100:1`L401D<30@0BBXT0`3[l?0407EhN1l0N7Yj5P3oool001@0
oooo5`1hNWX407QhN0@0MGQh100310<303`U70@0;bDR100d:2@402XP7@@09a`H100]8A`4038Q60<0
FdHj101Q?Bl408YVEP@0P7MX101kK6P407Q/I0<0N71X101hL6X807Q^IP@0N6EL101aI5H3075LC`@0
MfQK101aED/406iHAP@0L5U?101^F4H4071IC`<0L5Q<101VEDT406aDB0@0JDa2101VDdD406Q;@0<0
J4e1101KBd0404m2=P@0B38W100/7ad401/C4@@061<?0`0E3`/401L@40@04`/;100:1`L401D<30@0
BBXT0`3[l?0407EhN1l0N7Yj5P3oool001@0oooo7`1hNWX400D510<0<B0F100c:RL403DY9@@0:1hJ
100T5Q8403@R6@@0<BDQ0`18>Rl404LV7P@0QEQ61029PW4407i^H`@0N6YM0`1hK6H407QZF`P0N6YM
101hJ68407EXF0<0LEa@101dGE8406i>@`@0KUA6101`EE04071KC0@0L5U?0`1`CT8406IEB@P0K514
101SDDD406Q9?`<0HTPk101=A3P404Pc:0@0;1hL100V71D401TA3P@061<@0`0P4a0401H@40@04`/;
100B2`/402lJ5@@0g=3=0`2W[JhS07QjNQH0oooo000D0?oooal0N7Yj10051@@3034P5P@0<bXW100e
:BD402PN6P@091HB100d8QT4034U8@<0B3X_10179Qh408EHAP@0RH9a101nKV<407QZG@<0N6aV101h
JU/807QZG@@0N6QR101eJ5P3075LD0@0M5eB101^CT<406iDAP@0L5E@101`Fd`4071IC`<0L4i2101V
EDT806a@A0@0He55101XBCl30698>`@0CD@h1018<bP402`N70@09Q`E100I4@h401PC40<081<@100F
410401<;2`@04P/;100_6QD40=c@c@<0Yjf^8`1hNWXF0?ooo`00503ooolO07QjNP@01@D40`0a81H4
03<Z9`@0=BTU100X7QX402@F4P@0=28I100a9B4304Pj;`@0AbHN1025F4H408V2L@@0OViS101hJUd3
07Q/IP@0N6YK201hJUd407QXHP@0MFQH0`1aG50407AMDP@0KTi3101^E4H4071ED0@0L5]<101`FDl3
071>@P@0IUE9201/D4@406=AA@@0J4To0`1RB3/404e4>0@0B3<X100/7Q`402HL5@@06A4>100H4a03
020C40@05Q0@100C2`/4018;2`@0;aXE103Ld<d30:N][R<0N7Yj5P3oool001@0oooo7`1hNWX400D5
10<0<B0F100c:RL403DY9@@0:1hJ100T5Q8403@R6@@0<BDQ0`18>Rl404LV7P@0QEQ61029PW4407i^
H`@0N6YM0`1hK6H407QZF`P0N6YM101hJ68407EXF0<0LEa@101dGE8406i>@`@0KUA6101`EE04071K
C0@0L5U?0`1`CT8406IEB@P0K514101SDDD406Q9?`<0HTPk101=A3P404Pc:0@0;1hL100V71D401TA
3P@061<@0`0P4a0401H@40@04`/;100B2`/402lJ5@@0g=3=0`2W[JhS07QjNQH0oooo000D0?oooal0
N7Yj100A3P`302LO6`@0<BHR100k:BD402/N5@@0:AlK100Y71P4038W8`<0;R8L100h:2@406m6<`@0
QFYB1020LfH407AVF@<0NfaQ101hJU/407QZG@@0LFAH101dIU/407]/G@<0KeA:101^D4D406iHAP@0
JDi4101/Ed`406aGB@@0M5E90`1YCD4406UCAP@0K4Y4101VDdD406IA@0@0HT@j0`1KB3/404Lm<P@0
=B4K100S71D401/B3`@050l;100G4103028D40@05@l@100>1`L401@<30@0<Q/F103gmoL307EhN2<0
N7Yj5P3oool001@0oooo7`1hNWX4014>30<09alK100a9R8403/Y9@@0:ahE100Y7a/402TL60@0<RLS
0`0^8Q`403PX90@0KdHc1025JU84081cIP@0M6II0`1kK64407QZF`@0N6YM101aI5P407AVF`@0NfaM
0`1_E4X406i@A@@0KUQ6101YCT@406aGC0@0K5M9101dEDT306U=@@@0JE=6101/BT@406ICA@@0IU50
101RA3X305]8>`@0Acdb100e8A/402<L5@@06a8?100D3`/401L@40<08Q@@100E3a0400h71`@050`<
100b6aH40?Ogm`<0MGQh8`1hNWXF0?ooo`00503ooolO07QjNP@04@h<0`0W7a/4034V8P@0>bTU100[
7QD402TO6`@0:A`H100b9b<302hR70@0>2PT101_AS<408EZDP@0P7=V101dIUT307]/H@@0N6YK101h
JUd4075TF0@0M6IK101kK5d306mDBP@0KU15101^F4H406U>A0@0K5M<101/EdT407AEB@<0JDe1101Y
DdH406a:A0@0IU=5101VDD040694>P<0FdPk1017?C8403DQ6`@08a`E100K4Pl401@?2`@05a0@0`0R
510401D?40@03PL7100D30`4038K5P@0moOg0`1eN7PS07QjNQH0oooo000D0?oooal0N7Yj100A3P`3
02LO6`@0<BHR100k:BD402/N5@@0:AlK100Y71P4038W8`<0;R8L100h:2@406m6<`@0QFYB1020LfH4
07AVF@<0NfaQ101hJU/407QZG@@0LFAH101dIU/407]/G@<0KeA:101^D4D406iHAP@0JDi4101/Ed`4
06aGB@@0M5E90`1YCD4406UCAP@0K4Y4101VDdD406IA@0@0HT@j0`1KB3/404Lm<P@0=B4K100S71D4
01/B3`@050l;100G4103028D40@05@l@100>1`L401@<30@0<Q/F103gmoL307EhN2<0N7Yj5P3oool0
01@0oooo7`1hNWX401HC3P<0:24N100d:2@4034T80@0;B<N100P5QL402PL5`@0;b8N0`0e:BD4034P
5`@0ABPM101`Dd4407iQD`@0MUe@0`1jJ5/407AREP@0M6QK101aI5P407APE0@0MfAG0`1[ED/406I9
?P@0K5=5101YCT@406a=@@@0K5=6101_DDD306U@A0@0IT]0101XBd4405m9>`@0GTTk101A@CH304Xe
:P@0A34V100Q6A<401TB3`@061<?100F3`/401<;30<05@`;100:1`L400/71`@0<1XF100i7QD40>kc
mBH0N7Yj5P3oool001@0oooo7`1hNWX401HC3P<0:24N100d:2@4034T80@0;B<N100P5QL402PL5`@0
;b8N0`0e:BD4034P5`@0ABPM101`Dd4407iQD`@0MUe@0`1jJ5/407AREP@0M6QK101aI5P407APE0@0
MfAG0`1[ED/406I9?P@0K5=5101YCT@406a=@@@0K5=6101_DDD306U@A0@0IT]0101XBd4405m9>`@0
GTTk101A@CH304Xe:P@0A34V100Q6A<401TB3`@061<?100F3`/401<;30<05@`;100:1`L400/71`@0
<1XF100i7QD40>kcmBH0N7Yj5P3oool001@0oooo7`1hNWX401HC3P<0:24N100d:2@4034T80@0;B<N
100P5QL402PL5`@0;b8N0`0e:BD4034P5`@0ABPM101`Dd4407iQD`@0MUe@0`1jJ5/407AREP@0M6QK
101aI5P407APE0@0MfAG0`1[ED/406I9?P@0K5=5101YCT@406a=@@@0K5=6101_DDD306U@A0@0IT]0
101XBd4405m9>`@0GTTk101A@CH304Xe:P@0A34V100Q6A<401TB3`@061<?100F3`/401<;30<05@`;
100:1`L400/71`@0<1XF100i7QD40>kcmBH0N7Yj5P3oool001@0oooo7`1hNWX401HC3P<0:24N100d
:2@4034T80@0;B<N100P5QL402PL5`@0;b8N0`0e:BD4034P5`@0ABPM101`Dd4407iQD`@0MUe@0`1j
J5/407AREP@0M6QK101aI5P407APE0@0MfAG0`1[ED/406I9?P@0K5=5101YCT@406a=@@@0K5=6101_
DDD306U@A0@0IT]0101XBd4405m9>`@0GTTk101A@CH304Xe:P@0A34V100Q6A<401TB3`@061<?100F
3`/401<;30<05@`;100:1`L400/71`@0<1XF100i7QD40>kcmBH0N7Yj5P3oool001@0oooo7`1hNWX4
03H`<`<08QXG100c:2@402dS7`@0>bhZ100Z71D402HG4`@0>BdX0`0/81`403DX90@09Q/G101>?C04
04Xe;0@0JT<e0`1mI5D406I@A0@0KemH101/FE8406aHBP@0M5mC0`1PBd0404`h;@@0GT4e101ZASD4
06]>A0@0J4m2101X@SH306Q@A0@0IT/e101RB3h405]2=P@0Ed0d101;@3@303XU7`@0<QhF100L5184
01/B3`@05Q0;200C2`/300l71`@02PL7100E30`402PF4@@0^ZbZ102c^[`V07QjNQH0oooo000D0?oo
oal0N7Yj100f<3<3028J5`@0<bPT100]8al403/^:P@0:Q`E100V5a<403T]:0<0;20L100e:2@402HK
5`@0CSd`101:=B`406Y3=@<0OFAE101VD4@406mOF0@0K5UB101/F4X407AOD`<0H4]0101<>2d405i1
=@@0JTHe101[CT@406Q?@P@0J48f0`1XD4@406I;=@@0HTPn101K@SH405M0=0@0Bd0d0`0j9Al4038N
5P@071@B100K4Pl401H@2`P04`/;0`0?1`L400X71`@05@`<100X5Q440;Z/ZP@0/kZl9P1hNWXF0?oo
o`00503ooolO07QjNP@0=S0c0`0R6QL403<X90@0;B<O100k;RX402XL5@@09QLC100i;BP302`P70@0
=BPT100V6aL404hm<0@0BSD/101Z@cD307eTE@@0IU14101_GeP406aIDP@0K5Q:101dGe<3061;@0@0
C3P]101N@CD406Y6=@@0Jdi4101XCd8406Q2=P<0J514101VBcD40698?P@0Fd8f101G@3@404]0=0<0
>RDO100b7QH401`D4P@06a8?100F40/801<;2`<03`L7100:1`L401D<30@0:1HA102j[:X40;>j_2H0
N7Yj5P3oool001@0oooo7`1hNWX403H`<`<08QXG100c:2@402dS7`@0>bhZ100Z71D402HG4`@0>BdX
0`0/81`403DX90@09Q/G101>?C0404Xe;0@0JT<e0`1mI5D406I@A0@0KemH101/FE8406aHBP@0M5mC
0`1PBd0404`h;@@0GT4e101ZASD406]>A0@0J4m2101X@SH306Q@A0@0IT/e101RB3h405]2=P@0Ed0d
101;@3@303XU7`@0<QhF100L518401/B3`@05Q0;200C2`/300l71`@02PL7100E30`402PF4@@0^ZbZ
102c^[`V07QjNQH0oooo000D0?oooal0N7Yj101YJ6`301LD3P@09AdJ100`9204038V8P@08ahI100Q
5QL403LT6P<0;B@P100n<2`402hU8@@0=BLR100l;RX405@e:P<0FC`]1014>CL404@k<`@0EST[101L
BC/405Y6>P<0@S8/1014;b<404P`90@0FC`Y101O>c0405i4<P@0JT@d0`1G@SL4050f:@@0F3L]101F
?C4404@f<0@0?BTR0`0^6a@402DE4P@06Q<?100E3`/4018;2`@03`L72`0;1`L4020F4@@0;QTE103g
lo<407]oObH0N7Yj5P3oool001@0oooo7`1hNWX406UXK0<05a@>100U7AX4030T80@0<RHR100S7QT4
024F5`@0=b@J0`0]920403h`;0@0;RDQ100e9b8403`^:P@0E3DZ0`1I?2d404@i=`@0A3/c101F>B/4
05a9>`@0FTHj0`12<R`404@_8`@0B30T101I?2T405lk<0@0GT@b101ZA3@305M2=`@0D3HY101H=bd4
05Hm<@@0A3H`100m:B8302hK50@09ADB100J4`l401D?2`@04P/;100?1`L;00/71`@081HA100^6AD4
0?Ocl`@0Ngmo9P1hNWXF0?ooo`00503ooolO07QjNP@0JFQ/0`0G50h402DM6P@0<2@P100b9R8402<N
6@@08AHG100g91X302dT80@0?S0/100^9B4403DW8P@0?2hZ101D=BX305Tl;@@0A3Tg1014>c<405Hi
:`@0G4Tk101JASX3048b;0@0A2lS1018<2@405Tl:@@0Gc/`101NA38406Y4=0<0Ed8g101@=RT405Pg
;@@0ESda1014=S0403dY8P<0;Q/D100U5A8401XC3`@05@l;100B2`/400l71`/02`L7100P5Q4402hI
5@@0mo?c101kOglV07QjNQH0oooo000D0?ooob<0N7Yj0`0R828401hI5P@0=bXV100_:2@402dS7`@0
5a4>100c91d303``;0@0>bhZ100l<B`403X`:`@0ACP^1015=R`303da9`@0=BLV100f91X403`T80@0
Ab`R1016<bX302lT8P@0>2LS10129al404<Z70@0@bPR101C>R/4050f:@<0@RlT101:<bL4048Z7`@0
A3<[100i9Ql4038Q6@<081DB100T6aP401<?2P@05Q0;100C2`/400l71`L02`L7100T5A4401TA4@@0
NeUB103BfMXZ07QjNQH0oooo000D0?ooob<0N7Yj0`0R828401hI5P@0=bXV100_:2@402dS7`@05a4>
100c91d303``;0@0>bhZ100l<B`403X`:`@0ACP^1015=R`303da9`@0=BLV100f91X403`T80@0Ab`R
1016<bX302lT8P@0>2LS10129al404<Z70@0@bPR101C>R/4050f:@<0@RlT101:<bL4048Z7`@0A3<[
100i9Ql4038Q6@<081DB100T6aP401<?2P@05Q0;100C2`/400l71`L02`L7100T5A4401TA4@@0NeUB
103BfMXZ07QjNQH0oooo000D0?ooob<0N7Yj0`0R828401hI5P@0=bXV100_:2@402dS7`@05a4>100c
91d303``;0@0>bhZ100l<B`403X`:`@0ACP^1015=R`303da9`@0=BLV100f91X403`T80@0Ab`R1016
<bX302lT8P@0>2LS10129al404<Z70@0@bPR101C>R/4050f:@<0@RlT101:<bL4048Z7`@0A3<[100i
9Ql4038Q6@<081DB100T6aP401<?2P@05Q0;100C2`/400l71`L02`L7100T5A4401TA4@@0NeUB103B
fMXZ07QjNQH0oooo000D0?ooob<0N7Yj0`0R828401hI5P@0=bXV100_:2@402dS7`@05a4>100c91d3
03``;0@0>bhZ100l<B`403X`:`@0ACP^1015=R`303da9`@0=BLV100f91X403`T80@0Ab`R1016<bX3
02lT8P@0>2LS10129al404<Z70@0@bPR101C>R/4050f:@<0@RlT101:<bL4048Z7`@0A3<[100i9Ql4
038Q6@<081DB100T6aP401<?2P@05Q0;100C2`/400l71`L02`L7100T5A4401TA4@@0NeUB103BfMXZ
07QjNQH0oooo000D0?ooob<0N7Yj0`1ACUL401HA3@P0;b@P100`920402XQ7P@0>b`W0`0n<2`403db
;@@0<bLT100d:2@403/T80@0@bTP0`0c8a/402`S80@09AXF100b9R8402PG4`@0=2PT0`0/8b0402XP
6`@0:ALC100X71P402PG50@0<1TE100a8QP302lP5`@0<B4H100X5Q<402`H5@@09QLC100U5a<301HB
3`@05a0;100A2P/401@;2`@04`/;100:1`L400/71`<091DJ100T5A04038W8`@0gm7>102DVidZ07Qj
NQH0oooo000D0?ooob<0N7Yj0`1ACUL401HA3@P0;b@P100`920402XQ7P@0>b`W0`0n<2`403db;@@0
<bLT100d:2@403/T80@0@bTP0`0c8a/402`S80@09AXF100b9R8402PG4`@0=2PT0`0/8b0402XP6`@0
:ALC100X71P402PG50@0<1TE100a8QP302lP5`@0<B4H100X5Q<402`H5@@09QLC100U5a<301HB3`@0
5a0;100A2P/401@;2`@04`/;100:1`L400/71`<091DJ100T5A04038W8`@0gm7>102DVidZ07QjNQH0
oooo000D0?ooob<0N7Yj0`1ACUL401HA3@P0;b@P100`920402XQ7P@0>b`W0`0n<2`403db;@@0<bLT
100d:2@403/T80@0@bTP0`0c8a/402`S80@09AXF100b9R8402PG4`@0=2PT0`0/8b0402XP6`@0:ALC
100X71P402PG50@0<1TE100a8QP302lP5`@0<B4H100X5Q<402`H5@@09QLC100U5a<301HB3`@05a0;
100A2P/401@;2`@04`/;100:1`L400/71`<091DJ100T5A04038W8`@0gm7>102DVidZ07QjNQH0oooo
000D0?ooob<0N7Yj0`1ACUL401HA3@P0;b@P100`920402XQ7P@0>b`W0`0n<2`403db;@@0<bLT100d
:2@403/T80@0@bTP0`0c8a/402`S80@09AXF100b9R8402PG4`@0=2PT0`0/8b0402XP6`@0:ALC100X
71P402PG50@0<1TE100a8QP302lP5`@0<B4H100X5Q<402`H5@@09QLC100U5a<301HB3`@05a0;100A
2P/401@;2`@04`/;100:1`L400/71`<091DJ100T5A04038W8`@0gm7>102DVidZ07QjNQH0oooo000D
0?ooob<0N7Yj0`1bLWH402HT8P@08A/H100`920403DY9@@0;b@P1012=C0302PN6P@0?S0/100V7AT4
03LZ9P@0Ac8X100c9b@302`S7`@0;B@Q100X7QX403l/9`@07A@E100[91h302PG4`@09QLC100M4`l4
01/D40@08A<@100[61@402TI50<07Q<@100P510401lC40@0:QPD100M4a04020D40<050l;100G40/4
01<;2`@050/;200;1`L401D<30<0<R0K100X5a<40<?2`P@0/;2`;P1hNWXF0?ooo`00503ooolS07Qj
NP<0LW9f100V9284024K60@0<2@P100e:BD402lT80@0@SD`0`0X7QX403h`;0@09QdI100g:RH404Lb
:0@0<bLT0`0/8al402dT8@@0:1hJ100o;2L401dD5@@0:b@N0`0X5a<402HG4`@07A<?100K5104024C
40@0:aPD100Y6A@301hC40@081@@100O4a0402XH50@07A<@100P510301@?2`@05a0;100C2`/401@;
2`P02`L7100E30`3038P6`@0:1LC1033`/840;2`/2h0N7Yj5P3oool001@0oooo8`1hNWX3079bMP@0
9R@R100Q6aP4030T80@0=BTU100_9204048e<0<0:1hJ100n<2`402HM6@@0=bXV1017<RP403<W90<0
;2<O100]924402PN6P@0?b`W100M51D402/T7P<0:1LC100V5a<401dC3`@06a@@100Q4a0402/H50@0
:ATD0`0N4a04020D40@07a<@100Z61@401dC40@081@@0`0D3`/401L@2`@04`/;100D2`/800/71`@0
5@`<0`0b81/402PG4`@0`l;2102`/;0^07QjNQH0oooo000D0?ooob<0N7Yj0`1bLWH402HT8P@08A/H
100`920403DY9@@0;b@P1012=C0302PN6P@0?S0/100V7AT403LZ9P@0Ac8X100c9b@302`S7`@0;B@Q
100X7QX403l/9`@07A@E100[91h302PG4`@09QLC100M4`l401/D40@08A<@100[61@402TI50<07Q<@
100P510401lC40@0:QPD100M4a04020D40<050l;100G40/401<;2`@050/;200;1`L401D<30<0<R0K
100X5a<40<?2`P@0/;2`;P1hNWXF0?ooo`00503ooolV07QjNP@0CDI<100G40d403<Y9@@0=BTU100]
8al402PR7@<0>2/W1012=C0402TT8@@0;B0L10109a`4020I5`L0;20L100L5Q/402dS7@@07QDF100Z
6A@301hC5`@06a@?100J4a0401H@2`P07A@@100K510301H?2`@04`/;100H40/402<E4@@05@l;100C
2`/301L@2`@05a0@100C2`/400/71`@050/;100M5A0402dN6@<0;ATE102f]KD40;Jh^380N7Yj5P3o
ool001@0oooo9P1hNWX404e6C0@05a0=100c:BD403DY9@@0;B<O100X8Qd303P[9`@0@SD`100Y9244
02dP70@0@2LL100P6AL702`P70@071HK100]8ad401hE5P@0:QTD0`0N4aL401/D3`@06Q<@100F40/8
01dD40@06a@@0`0F3`/401<;2`@0610;100S5A4401D?2`@04`/;0`0G40/401L@40@04`/;100;1`L4
01@;2`@07AD@100]7QT302dI5@@0][Fe102f^;Pb07QjNQH0oooo000D0?ooobH0N7Yj101=AT`401L@
3@@0<bTU100e:BD402dS7`@0:28M0`0h:bL4048e<0@0:B@Q100]81`4040W70@081TG1`0/81`401`F
6`@0;B<M100N5AH402XI50<07Q<G100K50l401XC40@05Q0;200M510401/D40<05Pl;100C2`/401P@
2`@08aDA100E3`/401<;2`<05a0;100G410401<;2`@02`L7100D2`/401dE40@0;AhI0`0]6AD40;Je
]@@0][Rh<P1hNWXF0?ooo`00503ooolV07QjNP@0CDI<100G40d403<Y9@@0=BTU100]8al402PR7@<0
>2/W1012=C0402TT8@@0;B0L10109a`4020I5`L0;20L100L5Q/402dS7@@07QDF100Z6A@301hC5`@0
6a@?100J4a0401H@2`P07A@@100K510301H?2`@04`/;100H40/402<E4@@05@l;100C2`/301L@2`@0
5a0@100C2`/400/71`@050/;100M5A0402dN6@<0;ATE102f]KD40;Jh^380N7Yj5P3oool001@0oooo
9P1hNWX406m^L0@06ADB100W81d403DY9@@0;B<O100b:2@303@[9`@0=RTU100V7QX402DJ5P@0:a`H
100K4Pl3030S7P@08QLG100Q5aP4024D3`@07a<H100G40l3018;2`P05a0@100C2`/401TA4@@04`/;
100H410301<;2`@05a0@100M5A0401P@40@04P/;100:1`L300`81`@02`L8100;1`L401P@40@06A0;
100D30`402DA30<0/jVZ102i_K`f07QjNQH0oooo000D0?ooobH0N7Yj101_KW0401TE4P@09b0M100e
:BD402dS7`@0<RPT0`0d:bL403HY9@@09QhJ100U6QH402/L60@06a8?0`0`8ah4028G5`@08ALH100Q
50l401lC60@05a0?0`0B2`/801L@40@04`/;100I4A4401<;2`@0610@0`0C2`/401L@40@07AD@100H
4104018;2`@02PL70`0<20L400/720@02`L7100H410401T@2`@050`<100U4@`30;>YZP@0^Kfl=P1h
NWXF0?ooo`00503ooolV07QjNP@0Kfi`100I5A8402LP7@@0=BTU100]8al4038X90<0=2/W100f:BD4
02HN6P@09AXF100[71P401/B3`<0<2<N100R5aL4024G60@08A@?100O4aP401L@3`<04P/;200G4104
01<;2`@06A4A100C2`/401P@40<04`/;100G410401dE40@0610@100B2`/400X71`<030P7100;1`P4
00/71`@0610@100I40/401@<30@09A4<0`2cZJX40;Vm_3H0N7Yj5P3oool001@0oooo9P1hNWX406m^
L0@06ADB100W81d403DY9@@0;B<O100b:2@303@[9`@0=RTU100V7QX402DJ5P@0:a`H100K4Pl3030S
7P@08QLG100Q5aP4024D3`@07a<H100G40l3018;2`P05a0@100C2`/401TA4@@04`/;100H410301<;
2`@05a0@100M5A0401P@40@04P/;100:1`L300`81`@02`L8100;1`L401P@40@06A0;100D30`402DA
30<0/jVZ102i_K`f07QjNQH0oooo000D0?ooobX0N7Yj101CE5<402LR80@09A`H100`9204034Z9P<0
;bPT100l;BT402/Q8P@091HB100X71P401PB3`<08aDA100I4a04024D40@04@/;100D2``701L@40@0
50/;100H410401<;2`@06A4A100C2`/402hJ5@<02@L7100J4A4401dE40@05Pl@100:1`L400/71`<0
40L7100I4A4401L@40@06A4A100/6A@4034Q60@0Id4a0`3HhNL407]oOcH0N7Yj5P3oool001@0oooo
:P1hNWX405=DD`@09b8P100U71P4030T80@0<BXV0`0_:2@403`]:@@0:b4R100T5Q8402PL60@0618?
0`0S5A4401TC40@08A@@100A2`/401@;30L05a0@100D2`/401P@40@04`/;100I4A4401<;2`@0;QXE
0`091`L401XA4@@07AD@100F3a0400X71`@02`L70`0@1`L401TA4@@05a0@100I4A4402`I50@0<B4H
101W@C430=SQi`@0Ngmo=P1hNWXF0?ooo`00503ooolZ07QjNP@0DeAC100W8R0402DL60@0<2@P100a
:RH302lX90@0?2dY100[8B8402@F4P@0:1`H100H4Pl302<E4@@06A<@100Q5104014;2`@050/<1`0G
410401@;2`@0610@100C2`/401TA4@@04`/;100^6QD300T71`@06Q4A100M5A0401H?40@02PL7100;
1`L301071`@06A4A100G410401TA4@@0;1TD100a8AP406M1<@<0f>7W101kOglf07QjNQH0oooo000D
0?ooobh0N7Yj101CE5<402@M6`@0:RHR100Z81/303`_:`@0>bdY100e:RL4024L60@0;B4L100K4QH3
01L@3`@08A@@100G410401XC40@06a@@100G410701<;2`@050`<100C2`/401@<30@071@@100J4A43
02TZ=P@0;bXX100N4QH4014;2`@05Q0@1`0L510401P@4@@0<B<M100W6aL402`H50@0E3<X102i^[X3
09NSZCX0N7Yj5P3oool001@0oooo;P1hNWX405=DD`@091dK100Z9R8402XP6`<0?2l[100k;BT403DZ
9`@08A`H100]8A`401/B5P<05a0?100Q510401L@40@06Q<@100K510401L@40L04`/;100D30`401<;
2`@050`<100L510401XA4@<0:BXf100_:RP401hB5P@04@/;100F410701`D40@0610A100a8ad402LK
5`@0;1PD101D<bP40;Vj^P<0Uj>Y>P1hNWXF0?ooo`00503oool^07QjNP@0DeAC100T7A/402XV8P@0
:R0K0`0l;b/403/]:@@0=BXW100Q71P402dQ70@06a8F0`0G40l4024D40@05a0@100J4a0401/D40@0
5a0@1`0C2`/401@<30@04`/;100D30`401`D40@06Q4A0`0Y:SH402lZ:0@07Q8F100A2`/401H@40L0
71@@100H4144034S7@@09a/G100/61@405@c:0@0^KZj0`2GXjTj07QjNQH0oooo000D0?ooobh0N7Yj
101CE5<402@M6`@0:RHR100Z81/303`_:`@0>bdY100e:RL4024L60@0;B4L100K4QH301L@3`@08A@@
100G410401XC40@06a@@100G410701<;2`@050`<100C2`/401@<30@071@@100J4A4302TZ=P@0;bXX
100N4QH4014;2`@05Q0@1`0L510401P@4@@0<B<M100W6aL402`H50@0E3<X102i^[X309NSZCX0N7Yj
5P3oool001@0oooo<P1hNWX405UGEP@09B0M100`:2@302`P70@0<BXV1010<bh4034X9@@0;ahF100R
6AL301PC3`@0610@100B2`/401TA2`@05a0@1`0C2`/401P@40@04`/;100H410401<;2`@05@`<100a
;Bh302`N:@@0@cH/100g;2T402TP8@@0?2lZ100Y7aX301TC3`@0:Q`I100]7QT403LZ9P@0ABLO102i
/[840:6]/3d0N7Yj5P3oool001@0oooo<P1hNWX405UGEP@09B0M100`:2@302`P70@0<BXV1010<bh4
034X9@@0;ahF100R6AL301PC3`@0610@100B2`/401TA2`@05a0@1`0C2`/401P@40@04`/;100H4104
01<;2`@05@`<100a;Bh302`N:@@0@cH/100g;2T402TP8@@0?2lZ100Y7aX301TC3`@0:Q`I100]7QT4
03LZ9P@0ABLO102i/[840:6]/3d0N7Yj5P3oool001@0oooo<P1hNWX405UGEP@09B0M100`:2@302`P
70@0<BXV1010<bh4034X9@@0;ahF100R6AL301PC3`@0610@100B2`/401TA2`@05a0@1`0C2`/401P@
40@04`/;100H410401<;2`@05@`<100a;Bh302`N:@@0@cH/100g;2T402TP8@@0?2lZ100Y7aX301TC
3`@0:Q`I100]7QT403LZ9P@0ABLO102i/[840:6]/3d0N7Yj5P3oool001@0oooo<P1hNWX405UGEP@0
9B0M100`:2@302`P70@0<BXV1010<bh4034X9@@0;ahF100R6AL301PC3`@0610@100B2`/401TA2`@0
5a0@1`0C2`/401P@40@04`/;100H410401<;2`@05@`<100a;Bh302`N:@@0@cH/100g;2T402TP8@@0
?2lZ100Y7aX301TC3`@0:Q`I100]7QT403LZ9P@0ABLO102i/[840:6]/3d0N7Yj5P3oool001@0oooo
<P1hNWX407]mO@@0D4m>100V6aD303@^:P@0<bPT1013=C0403X`:`@0>BhY100P61D302@K5`@0<BDR
100T7a/401lC3`@06a@@100F3a0301L@40@050/;100C2`/401dE6P@05Pl?100L510401/B4P<0:b4M
100i:B8401@>3`@06Q<?100M5A0401D?3`<07Q<?100]7QX4038Q60@0Gch^102;OhX40:fh^0@0N7em
?@1hNWXF0?ooo`00503ooolb07QjNP@0Ngem101@Cdh402HK5@<0=2hZ100c:2@404<e<0@0>S0[100i
;RT4020H5@<091/G100a9B8402@O6`@07a<?100K510401H?40<05a0@100D2`/401<;2`@07ADJ100F
3`l401`D40@06a8B0`0[8Ad403TY8P@050h?100J4`l401dE40@05@l?0`0N4`l402dN6P@0<R4H101O
?Rh408]oRP@0[KRh101hOGdm07QjNQH0oooo000D0?oooc80N7Yj101kOGd4051?CP@09Q/E0`0d;RX4
03<X90@0@cD`100j<2/403T^:@@081PE0`0T6aL4034U8P@091lK100O4`l401/D40@05Pl@0`0G4104
01@;2`@04`/;100M5AX401H?3`@071@@100K4Q8302/Q7@@0>BTR100D3Pl401XC3`@07AD@100E3`l3
01hC3`@0;AhJ100b8AP405ln;P@0Rgn:102]^;P407QmOCd0N7Yj5P3oool001@0oooo<P1hNWX407]m
O@@0D4m>100V6aD303@^:P@0<bPT1013=C0403X`:`@0>BhY100P61D302@K5`@0<BDR100T7a/401lC
3`@06a@@100F3a0301L@40@050/;100C2`/401dE6P@05Pl?100L510401/B4P<0:b4M100i:B8401@>
3`@06Q<?100M5A0401D?3`<07Q<?100]7QX4038Q60@0Gch^102;OhX40:fh^0@0N7em?@1hNWXF0?oo
o`00503ooolj07QjNP@0D4a90`0Z9R04028K60@0>B`W101;?CT404@n>P@0<BPU0`0R6AD402DH6@@0
9QLC100`920402@P6`@050h?0`0C2`/4024I7@@081PL100/8ah401dF6`@0?2`V100F4AH304hl<`@0
;b<T100X81d4034U80@0:R0K100`924304<e:P@0;b<P101U@2l40:fXZ`@0TI^T1022QhA107QjNQH0
oooo000D0?ooocX0N7Yj101@C4T302XV80@08Q/H100i;2L404/m>@@0A3hj100a:2D3028I5@@09API
100V5a<4030T80@0920K100D3Pl301<;2`@08ATM100P61`402`S7P@07AHK100l;2H401HA5P<0CS`c
100_8b@402PP7@@0<BDP100Z81/4030T8@<0@cDZ100_8b0406E0;`@0[JR[102AVj@408:7Q440N7Yj
5P3oool001@0oooo>P1hNWX4051<B@<0:RHP100R6aP403T/9`@0Bcdi1014?SX4034X9@<08QTE100U
61T402HG4`@0<2@P100T81/401@>3`<04`/;100Q6Ad4020H70@0;2<N100M5Q/403`/9P@05Q4F0`1>
?3<402lS90@0:20M100a9B0402XP6`@0<2@Q0`13=BX402lS80@0ID0_102]Z:/4096KY0@0PXN4@@1h
NWXF0?ooo`00503ooolj07QjNP@0D4a90`0Z9R04028K60@0>B`W101;?CT404@n>P@0<BPU0`0R6AD4
02DH6@@09QLC100`920402@P6`@050h?0`0C2`/4024I7@@081PL100/8ah401dF6`@0?2`V100F4AH3
04hl<`@0;b<T100X81d4034U80@0:R0K100`924304<e:P@0;b<P101U@2l40:fXZ`@0TI^T1022QhA1
07QjNQH0oooo000D0?oooch0N7Yj0`1@DDh404e:D@@0;RHQ100g:RH403T^:P@0>STo0`0o<bd4048g
=@@0AShi100/8R<402PX:0@0?3@o0`16?SH402dR90@0:R@^100d9R<403dgA0@0>2TQ100W81h304He
;P@0=2DR100h91l403PT6`@0<BPU1017=2X305lo;`@0:ahH1033_KX409NQY`@0N7emA@1hNWXF0?oo
o`00503oooln07QjNP<0D55>101=BU4402hV8@@0=bXV100i;RX403Xi?`<0?c<]1012=cD404Hn>@@0
;28S100X:2P403`d?`<0AShf100]8R@402XT;P@0=2HS100m=d@403PY8@@09b0N0`16=Bh403@U8P@0
>2@O100h91/4034X9@@0Ac@Z0`1O?bl402/N60@0`kfj102GXJL407QmODD0N7Yj5P3oool001@0oooo
?P1hNWX3051ACP@0CDYA100^9R4403LZ9P@0>BhZ100j>Cl303lc;@@0@SLe1016?ST402`R8`@0:2PX
100l=3l304Hn=P@0;B8T100Z92h403@V8`@0?CM4100h:B4402LP7P<0ASD^100d9B8403PT7`@0>2@K
100a:2D404Ld:P<0Gcl_100[7QP40<>m^P@0Uj6W101hOGe507QjNQH0oooo000D0?oooch0N7Yj0`1@
DDh404e:D@@0;RHQ100g:RH403T^:P@0>STo0`0o<bd4048g=@@0AShi100/8R<402PX:0@0?3@o0`16
?SH402dR90@0:R@^100d9R<403dgA0@0>2TQ100W81h304He;P@0=2DR100h91l403PT6`@0<BPU1017
=2X305lo;`@0:ahH1033_KX409NQY`@0N7emA@1hNWXF0?ooo`00503ooom107QjNP@0K6]^101FG5P4
02XS:0@0>S0Z100c=3`305]<B0@0AT101012?3L403/e<`@0B4A5101??c`304Hj<`@0;2@R100k<Rl4
02hR8@@0;R8N100_8ad403T]:@<0=BTU10159al404H/90@0A38X101>?3D4040W7P<0HDa=1024TI<4
0:Z`/dd0N7Yj5P3oool001@0oooo@@1hNWX406a[KP@0EUaH100Z8bP403X`:P@0<c@l0`1KC4P404I0
@0@0@S`g100k=C<404Q4A@@0Ccll0`16>S<402`T8P@0>c8_100^8R4402hR7P@0;b<M100i;BT303DY
9@@0ABLO1016;2@404@b:0@0CS`e10109ah3065<C@@0Q96C102Z/;==07QjNQH0oooo000D0?oood40
N7Yj101/Jfh405ILF0@0:R<X100j<2X403<d?0<0Fda81016@404048l=`@0>cDc1018A4D404lo?0<0
ASXc100/928403/b;`@0;R8Q100^8Qh402lS7@@0>BdY0`0e:BD404DW7`@0AR`T1014<RP404hl=@@0
@2LN0`1QC4d408BAT`@0Z[2cC@1hNWXF0?ooo`00503oool407QfMP@0N7em@@1hNWX4051AE@@0LWE`
101UIg<303/d>`@0Fda9101UGfX405=8A@@0CSlj1014>SD304Hk>0@0CSi0101B@c`403lg=@@0DT4k
1011=bl404e0?@<0DT4m1014=Rd404Hj<P@0<bHS1026M7`407n4PP<0QHZ>102GWYeA07QjNQH0oooo
000D0?ooo`@0N7If101hOGe107QjNP@0D55E101bMG0406EWL`<0>c@k101KC4T406EOJP@0DdQ5101>
?cX404@j=@<0AS/h101>?T040593?0@0?cLe101B@C/4044g;`@0CD0m0`1B@Cd404@f;@@0ASXb100c
9R<408IdO0@0OhB20`25RXh409NNWE40N7Yj5P3oool001@0oooo101hMWH407QmOD40N7Yj101@DED4
079eL0@0IFMc0`0k=3/405]<B@@0IEmZ101CB4D404ho>P@0A3Xe0`16>cP404hn@0@0DT<l100o=cD4
0591>`@0@CL_101=@3d30591?@@0A3H]1016>S8403<V8`@0QWAl101oQ88308F:SP@0UijMD@1hNWXF
0?ooo`00503oool407QfMP@0N7em@@1hNWX4051AE@@0LWE`101UIg<303/d>`@0Fda9101UGfX405=8
A@@0CSlj1014>SD304Hk>0@0CSi0101B@c`403lg=@@0DT4k1011=bl404e0?@<0DT4m1014=Rd404Hj
<P@0<bHS1026M7`407n4PP<0QHZ>102GWYeA07QjNQH0oooo000D0?ooo`@0N7Yj101hOGe907QjNP@0
LW9f0`1FG5l408F2O@@0PXB9101UH6P407QdK@@0F5EQ0`0n>d840517D0@0ASXb1014>cP404`n>P@0
@SXe1014>CH3048`9`@0>c<[102TWZ4406mbM@@0ViVM1028ShaH07QjNQH0oooo000D0?ooo`@0N7Yj
101hOGe907QjNP@0LW9f0`1FG5l408F2O@@0PXB9101UH6P407QdK@@0F5EQ0`0n>d840517D0@0ASXb
1014>cP404`n>P@0@SXe1014>CH3048`9`@0>c<[102TWZ4406mbM@@0ViVM1028ShaH07QjNQH0oooo
000D0?ooo`@0N7Yj101hOGe907QjNP@0LW9f0`1FG5l408F2O@@0PXB9101UH6P407QdK@@0F5EQ0`0n
>d840517D0@0ASXb1014>cP404`n>P@0@SXe1014>CH3048`9`@0>c<[102TWZ4406mbM@@0ViVM1028
ShaH07QjNQH0oooo000D0?ooo`@0N7Yj101hOGe907QjNP@0LW9f0`1FG5l408F2O@@0PXB9101UH6P4
07QdK@@0F5EQ0`0n>d840517D0@0ASXb1014>cP404`n>P@0@SXe1014>CH3048`9`@0>c<[102TWZ44
06mbM@@0ViVM1028ShaH07QjNQH0oooo000D0?ooof00N7Yj101bLWP407j0NP@0K6ic0`1RJ6T407Qj
NP@0MGE^101hM7@407QmO@@0N7Yj101eN7P307EeL`@0N7em102TXjL407QmOF00N7Yj5P3oool001@0
ooooH01hNWX4079bN0@0OX1j101/KW<3069XJ@@0N7Yj101eMFh407QdM0@0N7em101hNWX407EhN0<0
MGEc101hOGd40:BSY`@0N7emH01hNWXF0?ooo`00503ooomP07QjNP@0LW9h101nP7X406a^L`<0HVQY
101hNWX407EeKP@0N7Ad101hOGd407QjNP@0MGQh0`1eMG<407QmO@@0Y:>W101hOGeP07QjNQH0oooo
000D0?ooof00N7Yj101bLWP407j0NP@0K6ic0`1RJ6T407QjNP@0MGE^101hM7@407QmO@@0N7Yj101e
N7P307EeL`@0N7em102TXjL407QmOF00N7Yj5P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool009P0oooo0T0000260?oo
o`00VP3oool00d000000oooo0?ooo`230?ooo`00O03oool3@0000080oooo00=000000?ooo`3oool0
2P3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`1m0?ooo`00O@3o
ool01T000000oooo0?oood000000oooo@00000X0oooo00I000000?ooo`3ooom000000?oood000004
0?ooo`04@000003oool0oooo@00008D0oooo001k0?ooo`A000000`3oool00d000000oooo0?ooo`08
0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@00008D0oooo
001k0?ooo`03@000003ooom000000080oooo0T00000<0?ooo`=0000000@0oooo@000040000100000
0`3oool3@00008D0oooo001l0?ooo`9000000P3oool00d000000oooo0?ooo`0=0?ooo`03@000003o
ool0oooo08d0oooo001m0?ooo`03@000003oool0oooo00=00000303oool2@00008l0oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(90) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777797777797777797777797777796E503E
7B6B60776765776F6977635E776F69776B65776B65776B6577635E7767596E5F56735C526A5047\
6F574C6650466B53486B53486B53486B53486B4C42634F3E674F47674F3E674F47
8BA4B4777779777779777779777779776F71777B7E777779777779777779777779777779777779\
777779777779777779
777779776F71777779777779776F71777779777779777779777779777779777779777779777779\
777779777779776F71777779777779777779777779777779777779777779775744
7B6B6977675D776F6977635E776F69776B657763566E5C4F6E5C4F6E584B665048614D44614940\
6650465E49406B53486B53486B53486B4C426B4C42634F45674F47674F3E676E75
8BA4B4777779777779777779777779777779777B7E777779777779777779777779777779777779\
777779777779777779
777779777779777375777779777779777B7E777779776F71777779776F71777779777779777779\
777779777779777779777B7E7777797777797777797777797777797777796E503E
77675D776761776765776B6577676177635E6E5C4F5658566A534B6A46446149406654496B574C\
6B5A4F6B5348674F45634C42634C42634C42634F3E634F45674F45674F458BA4B8
8B9299777779777779777779777779777779776F71777779777779777779777779777779777779\
777779777779777779
777779777779776F71777B7E777779777779777779777779777B7E777779777B7E777779777779\
77777977777977777977777977777977777977777977777977777977777977503E
7B6B6977676577676177676177635E7767597767617B6B69816759805B5F6F5A4C74534874504C\
74504C6B4240634C42674F45674F45674F45674F456F564E674F45674F458BA4B4
777779777779777779777779777779777779777779777B7E777779777779777779777779777779\
777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779777779775744
776B60776759776761776761776761776761776F6D776F697767617363596E5B52775E54776257\
6F534C7762546B4B456F48456F5D5A674F456F4F456F4F45634C426F5D528BA4B4
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779777779775744
77675D77676577675D776761776761776F6977676177635E776B657767617B6B60736355735B58\
735B516F5A4C6A4D496B5A4B6B53456B5751674F45634F45634F45817E83869CAB
777779777779777779777779777779777779777779776F71777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777797777797777797777795D3C33775744
77676577675D776759776765776F69776761776B65776F69776F6977635E776761775F567B5F55\
735B4E735B516F504C6F53466B4C42634F4563493D6F4F45674F458191A07B8990
777779777779777779777779777779777779777779777779777B7E777779777779776F71776F71\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777797777797777791F15106E503E867767
776765776761776765776765776F6977635E776759776B6577635E77635E7767597767596E5352\
6E574E7354516A5443664C406653486B4F45674F456F5D526B564B8BA4B47B8082
777779777779777779777779777779777779777779777779777779777779777779777779777B7E\
777B7E777779777779
777779777779776F71777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779564952080101B7978C7B6B60
776F6D776761776F69776761776761776B65776F697767657763567750526E50456649416E5048\
735B4E6A5B516150436F50486B564B634C3C634F45674F4563494086A0AF777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777375777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779807F820C040281674FD5B69B776761
77676577635E77676177635E776761776761776B6577635E6E5F526E504F6E5B4B6A54496F574C\
6A54496A5443664D436B4C42664C426B4C426F4F47674F456F564B817E83777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779776F71777779777B7E777779777779777779777779777779777779777779777779\
7777797777797777797777797777797777790C0402725A4FD0AEA27B6B60776765
776761776761776759776761776761776F6977676177635E6E31337334386A2E2F6A2E316F3133\
6F50466649406649426B453C634F3E6B4F456B4F45634F3E6F483E634C427B8990
777779777779777779777779777779777779777779777779777779777779777779776F71777779\
777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779777779\
77777977777977777977777977777956494C6E5752D0AEA277635E776759776765
776761775F52775F52775F56776761776761774D4F7750526E31336A3A326129226F3F3C663830\
6F3F3C5E393563483E634F3E634B416F4F476B4F456B4F456F48416B5A4E6F564B
777779777779777779777779777779777779777779777779777779777779777779777779777B7E\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777790804048167527B6756776759776759776765
7767596E584B6E534B776B60776B6977584B6E3133662E275D3F384B291D666B5B746D635E2821\
632A2366383067433C6753476748346753416B4F456B4F456B4F456B53476B5348
868D91777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779776F71777779777779777779777779777779777779777779777779\
7777797777797777797777793A2B2D472B1FD5AE947B6B696E584F776F6D776765
77584B66493B613C357B5B5F66272A1A03026649476A473E776B63869695823F3A5B362E473324\
57574F3B2F23632A235F4A3C6748326F4B466F564E745D4B6B4F456B564B6B4F45
6B5348776F6D777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779776F71777779777779777B7E777779777779777779777779777779777779777779\
7777797777797777797777790C0606957A6394837E77675D6E50457B6F6C77635E
77584B5D36295E363027090956636080A39EBCD2CE8096A1809AA47B89896E574880A7A5868B8F\
636369351F1A291A115735286B55436F4B46746155745A4F6F57486B4F456B4C42
6B564B6B7B9C6E6F76777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777B7E777779777779777779777779777779777779777779777779777779\
7777797777797777795D5769060101C4A0877B6B6077675977675D7B7370776761
663D334731204B1F19250A07A26B5D8157486E423C776F6D775B48775F4B663C36736B70663C30\
7B675E6F4C3D6E6259371F195F332867484174614E77675B6F574C6650486B483E
6B4F45636A665B5045615F71777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777791F1510060101533124DAB69B7B6B6077584F77584F77675D776759
663D336F5D528B827A9AA390BC9A9877645D6A4D496A50496E2B2B5D36355D222166231F5A1D19\
665A4F562C235F3B3E4C322C370D066F4E4779614E77675E6A5040664940634C42
6B5A4E6B5D528B89946B6379868982777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779776F71777779777779777779777779777779777779777779\
7777795D5059000000130C0BDAB6A6948775775F567750566E675C776F63775056
66433B563B2C8077747B73707767657773697B7F78807B74807B6A736C5A7D695A746F56746D5B\
6F594A74313367312D53211644130E63241B6F584A775E576A504066494263483E
6F4F456B534819110F77737581807A777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777B7E777779777779777779777779777779777779\
7777795D5769866B52E19D84D8B094776759775F56776B60775B597B6B6077675D
66544466453C86796E776761776B65776761776761776B657750526E5048735B516A54496F5048\
5E4C3C634B415E5B4367594A7462547C5D5B806A49745D526A5443664942634F3E
6F53476B564B1D1F209A9694777B7E7B8082777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779775744866753776F6D736B5F73635977675D776B69776765777B70776765
6E584F6F50466B4B4173675C776F69776B65776761776F697763566E5B4B6A463D6A54435E493A\
4F453C5F41345F3E345F41345F3E345F443473604E79615B6F50465E423C63483E
674F41634F450B0C0DACA8C48B9299777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
6E67697757446E584F66493856545E7B63597B6B69776F6D776F69776F69776B65
77505273574E6F4C427D695D7B6B69776B65774D4F6E5F527763566649416A4D435E3B325E4942\
5F3B3467443463473E6B50386347386343327D5D537453486649405E453C674B41
6753476F564E030608A1938E80857E777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7757447B5F53664941614940776F668B5752776B69776F69776B65776B65776B65
7763567763526A54436F4F457B7370776F6977635E7773697B6B696E504F6F574C664C426F584C\
5F3B3263433863473E6B4E436F4B467D5D537D685D664C42664C426B4F45674B41
675341674F450607073B2A258F8E94777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7757446E5F564E2C1F776F638662667B6B60777369776F69777475776B65776B65
77635E77675D6650476F5748777669776761776356776F697767616E584B61463A664940634F45\
63483E6B50386343386B4E43795A557D695D6F5A4F66574C6B564B634F45634F45
6753476F5D55573B2754291F2F2320777B7E777779777779777779777779777779777779777779\
777779777779777779
77777977777977777977777977777977777977777977777977777977777977777977777977574C\
663123561D1D5A39326B79767B6B60777360776765776F69776B6577665E776B65
77635E6E5F526E584F776F6380776E7B6B606E504B77675D774D4F664938613C3563483E5B4138\
6748324F382E5F3E387360537961557762546A54496650466B49406B4C42674F3E
6F483E6F5D5263423A6F504ABCD7E1D0D7DC777779777779777779777779777779777779777779\
777779777779777779
77777977777977777977777977777977777977777977777977777977777977777977777977423E\
66312D5E2F2C676251817A6C8B6F69776F6D776765776F69776B65776B6577635E
7763566E5F527B5C5273675C7B6B69776F6D7767657B736C77584F6654445E423C5B443A573E34\
5B41365F443E7C63567D685B746257775E546A54496650466B4C426B48456B4845
6748416B615D5B3629674B4194B4C3777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779775E5277503E\
66463856412E6F67568B7E717B6B69776F69776B6577676177635E6E5C4F776356
7750526E584F73534B6E5F557B6B6977675977635E77676177505266433A5E423A5F443A63473C\
5F50466F5846735D51745A4F775E546F54496A4D436650466B453C6B483E634B3E
63533E6F615D6B42376B584F67727E727275777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779663C284E2921\
281B16412F277D7066867B6E77676577676177635E776356775F526E5F52735352
6650486E5B5273675C736B5F7B6F637767617767657767616E5F52664D3E5E483E5F443A63473C\
6B4E436F5347795655745A4F6F574C6A5B516F574C6653486B5348635347634B41
674B476F5D5D5B26196B6155673B328B9294777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777797777795D2617160E0A\
2D211D2B1E1E8B7769807370776765776759776759776761776765776B697B6B69
735B556F4D49614D40735C527363597767657767617767596E504B61403856393C5F44345B4136\
6B4E436F5A4E6F4F456653466F504C664940664D435E4940634C42634C4267483E
674B476753455336226352416336338BB2C1777779777779777779777779777779777779777779\
777779777779777779
77777977777977777977777977777977777977777977777977777977777977676166362D452E27\
37251E30211FB08C758073676E5F5277676177675D5D49415D493E473128473128
47312D523435664C406B4C426A574E7B6B697767617767616E504F61463A5B413263432E5B473E\
674A3E574B4153453C634F456B5A4F5E4C406B564B6B5348674F45674F4567483E
674B476753453B2119421C16633A2D8BB2BD777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777796E4939663C36050302\
0D0C0C201917BB967E776B5F775F567B6B607767596E584F53423A3E3129242425
1717182A1B124C36293E1C153E1C157763587767617767616E584B61463A5B41325B4E38533D34\
6F554A735D51785A4E78534767484553423A6F564B6B5348634C4257483E57483E
67534767534542251D56291F7740328FB7CA777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779807F82774939613C35161313\
1F1511301814CEA88E7B6F63736359776B6077675D7767656149408B6964322823
1F120F2F191138333257352A856B5B9999877B77747778796E5F5261433A4B352C533A2D240907\
63463A573B2745332B32231C534138574B3E6F5341634C42634C425741385F4B41
6F4B475741382F1C195333287C534C99CBDA777779777779777779777779777779777779777779\
777779777779777779
776F71777779776F71777779777779777779777779777779777779060000612E21665047271E1A\
17141A1F1310CAAC9173635977675D7363596E5F567767656E5F52745A4F5A463A
9268568C583D84563D96684D8B6A5B7D6E617B7370776B656E50426140385B3B2C5B3F344C2D25\
605A572426270203042F1E1A37332D1713103B2C293B2A1F5F3B2C57483E5F4E43
6F4B4142382C2017133A261F85655694BDC8727275777779777779777779777779777779777779\
777779777779777779
777375777B7E777779777B7E7777797777797777797777790801010601012207031F181505060C\
0F0F0D2A1712D8B0947363597B6B695D363561463E7B6B69776F697B6B69775E5B
6F4F456F564B7C5B51876B5981655D776A5E7B7774776B656E4D486150475B41325B503A6B4634\
7C65566F46360E0B0C3F2016322725221917603D2E6A443680624F634A415F4B41
6F53411B16161D1611371E1788403186A4B4727275777779777779777779777779777779777779\
777779777779777779
777B7E777B7E7777797777797777797777797777797777790801013122192D171429201C0A0809\
2A1813321814CEA2877B63597363597767616B61524B332B4731283A2921281D1B
2117142C211938231C3E251D66574F736B5F7B6F6C7763566E4D426154475B3C336341325F4B38\
6B5848674F456F584CA76D557246366B402F9D624E855C41635348674F416B554A
5F4B4114110F2014113B1F187D30238FC0CF777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777790C03011B0E0A15110F1B130F1D120F\
1D1510332724B28D747B675C776B607B6B697767617D6F6374534F48414378504C
734B3C7B5A496E493C8965569991808677747B6B697750526E584F6154495B363A381F1838211A\
5F4B38674F41674F3E6F4F456F55436B594D7C624D5B4E43674B4C5F4B41674F41
42352C07090915110F97604B6B30239ACEDC777779777779777779777779777779777779777779\
777779777779777779
777779777779776F717777797777797777797777797777791206041F0E0A1F14101B13100D0607\
1F13103929258F68547D675B776B60776765776F69776F697B73708B8C83A39487
8B8C8394948F94908B9A8E7F7D76697B73706E5F526E5F526E63526A574E745E546B5847442B2B\
2B211A171211482F29674F47634F3E674F415F4B415F413A4F3E34674B456F4B41
1B14120E0B0A2C231F844331421C14222625777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777B7E7777797777797777797777790C06062019171E14101F1310160F0B\
2516113729258F604C8B72647B6F63776765776F69776B65777475777475777475
776B65777475776B65776B6577675D7B6B60776356735C5273534B735F55776358775B586F5D5A\
8962565A423A3B251D1B17122A1C1925252435251F3B271F6B4E4A7850465F4438
0D0B0B17100E251819270D0A2C110C292D2CCBD3D8777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791209083B292518120F1F13101F1310\
28191A37292572503E7864587B6F6377675D776761776B65776B65776F6D776F6D
776F6D77747577665E776B65776B6577675D77675D6E584F735F55735B51735F557357556A5B4E\
6B574967534573594A7458476A4434593E2F7F4E3F735C4F7C4E4F574B3E483E34
0E0C0C1D130F1A1310140E0A271915353331C6CED3777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791206042B1D15201815211310250F0B\
2A18143522184A352B7C5B4F7D6F6377675D776765776F69777475776B65776F6D
776F6D776F6D77665E776B6577635677635E775F566E5048735F55735F55735B5173574E6A5447\
6F4D436B5046674F45785A4E78584C80625480594D6F504C6F4B41634A3A35231A
130D0D1D130F2A18141B1310221410332219877378777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777790C0402312927241A18271613150F0B\
1E14101D130F3B251D5C3B28816E617B6B60776765776F69777475776F6D776B65
776F6D77665E77665E776B6577635677675D6E584B6E5C52735B5173574E73574E735B516A5449\
6650466653486B5A4F674F456B4C42674F4557483E574B41574B3E42382E111313
0B0B09221719150F10130E0A0D06072A18146A535094A0A2777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791206042F25232D221F271B18271714\
2214102A1D193E2F2B45352C896A5E7B675C776765776761776B65776F6D776F6D
77747577665E776B65776B6577635E6E5F566E584F73574E73574E735B516A5B516A54496A5449\
6650466B53486B53486B5046674F45634F4557483E6F4B415F443A2F231F150E0E
251A17120B0B140E0F0E0707170F102516115F4F4BA8B7BD777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777790F09083129273529252F2320271613\
130E0A2A181440261D5D392988503A7D6A5E776B60776761776761776B65776F6D
776F6D776F6D776B65776B6577635E776759735C526A574E6A54497354516A54496F4D436F504C\
6650466B53486B4C42634C42634C425F413867483E5F3E34352C292017131B1210
130E0A130E0F130B0B170F0B1911112E1914E4EAEEB2BCC1777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779776F716E67690C06062D221F3327242D221F1A100D\
271C192E1E1A2D221E5A3B2C734E417D70667B6F63776765776F69776F69777475
776F6D776F6D77665E776B656E5C4F775F526E504873574E775B516F574C6A57496F5046665A4F\
665346634542634C42634F45674F4567483E5B4E4348382E423127221812201412
18130F1C14101C141018100B1C14102E1914E6F1F6777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777B7E0A07063B231A2F23203327242F2320\
2A1D192D211D33211854443A53392D78584C776B5F776765776761776B65776B65
77665E77665E775F576E5C4F6E54487363596E534B6A54436A54496A54436F574C6F574C665348\
6B50466B4C4267534567483E67483E57483E483E34422C24241A1A16100F15110F
130E0A160F10120A0B090607120B0B472925DAE5EA727275777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779120908311F17312927352925271D19\
24141133211831252142372E3D211B6F4B3F7D76697B6B60776759776761776356
77635677635677635E776759735C5273574E6A463E6A4D436F504F6F574C6F574F6F4940665046\
6B4C426B4C42634F4567483E5F443A483E34422C242418191F181317100D18130F
211310170F10120B0B130B0B331B16FFFFFFC6D7DC777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791F15132B221F2F25233927242D1D15\
2B1F1C271C192F2523291E1A2F24235C40316F58467363596E5F5677675D776759
77675D6E5F566E5F567767596E50486A49406A5443664C426653486653466F5046664940664F45\
6B4542634F45634F3E5F413857443A453A302F1C191F181317100D110D0A150F10
211310150F100E0707130B0B2F1A15DAE5EA727275777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777791F15102B211F3529252F23202B221F\
1F1518251A172D211D352925311F17392219564438674F476A4D44735C526E584F
6E5F566E5F56735C52735C5266504861463D664C426649426B483E6B4C426B4C42664C4263483E\
63483E5B4438574138483B343F2E253B29211D161115100D15110F150F0B120B0B
120B0B0906070A0707311B163D1F15DAE5EA777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777794E424C3021203327242D221F3B2E2B\
2F1E162917133A2C282B1F1C332724241A183D352C322823482F276650465A433A
61504E614D4B614D446A574E5A433A412E274B352C5B3B2C63483E634B41633B3263483E634832\
5F443A573E34533A30483A3035211D2918131811101A110F150F0B120A0B120B0B
0F07070A0707150C0C261611CECED2D0E1EA777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779271F16251D192D221F2F2320\
201C181F15183322192D221F3E302C332724332623352928462F28412F252C282B
2A2A2738261D45362B45362E2E242235251D3B281F4533234C31284F38295F3E2E4F3D32422C24\
482C274C342B3B312D32221F27161120131117110F130E0A110A0B0E07070A0707
0A07070B07072016112F1A15E4EAEE7B8082777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779342B33271E1D382A272F2925\
2F232018110E2E221D3B302E3B2E2B3D312D40332F4A3B3145372D362F282B2223
2E1C15301C1B35211D352622241C1D2B212037221E3A241935211E4131263E2D2532261F3E2D23\
38261D352C262F201B2B1C161B1311201A18120E0A150F0B120B0B0F07070B0707
0B07072616111A111184625DDAE5EA777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779665E692719152F23202D221F\
2F221F2F2320402F2B3E302C3D312D3126232F2421351F1D3F221D321E17291F1E
2018152B2321201411272220251F1E251D192014111D18161D1412221411221914221914231A15\
1C11102013111B12101D141113100E130E0A0F090A120B0B120B0B0A07070B0707
26161B261611372925EEEEEEA3B2B8777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779413A392B221F2F2320\
3529252F2320423531271D19372B28241A173327244733293129252722202B2321
291E1A402C281F141627221E2414112414111B110E18130F1D120F2717142517141A110F1A110F\
1A110F2517141B130F1D130F130E0A160F0B120B0B130B0B0A07070A0707150C0C
33201B2A1813E4EAEED0D7DC777779777779777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777795D5059241412352925\
3529252D221F241E1A3529264537322B26232B1F1C3922191D1614271D19291E1A
1A141A251F1C1C14152917131D111718130F18130F150F0B1B13101A131018130F130E0A110A0B\
150F0B1F1310130E0A110A0B150F0B170F10120B0B0A0707130B0B20161133201B
2F1A15DAE1E5DAE5EA777779777779777779777779777779777779777779777779777779777779\
777779777779777779
7777797777797777797777797777797777797777797777797777797777797777792C241F2B2320\
3327242D221F352925332A27312623241A17241815251A1717100E2D211D201517
2015171F130E1D1117140E0F0F0A0A150F0F160F10120A0B170F10120A0B160F10120A0B170F10\
1D1510170F10110A0B0A07070A07070A07070A07071810101A110C130B0B210F0B
CECACEDAE5EA777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779473B38\
291E1A2D221F2F29252D27243B2D292D2224251512271B1818120F1F131016110E
1E130F100A0A110A0B150F0F170F10130B0B170F10120B0B181010120B0B2F1A150A0707181010\
1C1410160F100A07070A07071007071A11111A11111A11112E19143B241A814F39
E4EEF37B8082777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
473532312A27291E1A3B2D293B2D29372B28241E192D221E1D1218160F101F1310
160F101A13101D1510181010120B0B120B0B130B0B120B0B130B0B1C14101810102D2D3D393334\
221419120A0B170F1020161120161119111134241F2E1E192E1914573329D0DCE5
A8C0CF777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
807F824737343B2D292B1F1C2B26233D312D372B28331F17251A171A130F170F10
110A0B170F0B160F10120A0B120B0B181010130B0B181010130B0B130B0B322F312E1E2B45332A\
45332D3729284C383234241F1B13102C1D192E1E19382A274F2C23DAD9DEB7CED8
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779727275402C233D312D382A2742332F3B2F2C3D312D241A18271B18392925
2E241F2315101C1410170F10181010130B0B120B0B1D151A170F101D1510181010251D1833261F\
0E0B0C120E0C15100D0F0B0C1B110E2C1D19332118673F2EA99DABBCD3DC777B7E
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779433B34241A17332724493B3849423F3B2F2C271B18221618
2414113325212A231F160F10120B0B22191F231A202F262021181D42302B1B1319513E37332527\
2F23203B2A2532231F392925513E31372925704634D0D0DAADC5D3868E8B777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777798D849645373233272430262336353E493B38574642
5A4F4933272929292B473D4E62544D3D2C2C302732372727473D4E3E2D272D221F47352E352421\
3B231F3B231A3529254D372C6A4231351F18D0D7DCA8C0CF777B7E777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
7777797777797777797777797777798B9290493B4540332F31313A574B4A4A4448
433D3A433B385950525C464149393030242242352F312321291E19291E18392D2935292545261E\
4C2D244C352B5A423A47271F5C494FA8C0CFC6D7E1777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
776F71777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779B7C0BDACA8B94E424F5A4A4B
776B7E69565B59423E473834473B38594448634C4750423F6A504954443A594845634C474E4036\
464038302624847889ADC0CABCD3DCA8B7B8777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777B7E777B7E777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779808582B7BCB4
A3AEAF827F8B9EA0A1807D944E485B4E485B413834413836473B384138364337363A2A22352D25\
B7B6BFB7C0CAC6D3D88F9C99777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779777779777779777779777779777779777779777779777779
77777977777980857E777B7E8B928BADB2ABADB2ABB2B1B7B2BCC1B2BCC1B2BCC1B7C0C6BCC9D3\
BCC5CF777B7E777779777779777779777779777779777779777779777779777779
777779777779777779777779777779777779777779777779777779777779777779777779777779\
777779777779777779
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH07MgN@@0KU0n101k
Jf0407MWI@@0MfmY101gHeh307M_J@`0Mf]U101gHeh407MWF@@0KUmF0`1cG58406Y@A`@0KeM<101V
D4H?06]CB0@0Jda2101SCch406M?A`@0Idln101WCdL308^T]100MgMi101gKg4307MkOR<0MgMi5P3o
ool001@0ooooF01gMgT406i@?P@0Nf]P101gIfD407M_J@@0Mf=N0`1gKfT<07M[I@@0Mf=N101gIeT4
06iOEP<0LeaB101ZD4L406mGC0@0IU163`1[DdP406]<@P@0Hdln101WCdL406M??P@0Idm70`2;Y;@@
07MgN@@0Mfma0`1gNghS07MgNAH0oooo000D0?oooeP0MgMi101^D3h407][H0@0MfMU101gKfT407MS
GP<0MfmY301gJfD407MSGP@0MfMI101^GeH307=LDP@0JU17101_Ed`406I@APl0Je=8101[C48406=?
?P@0Idm7101WCch406M?A`<0RjBd401gMgT407M_L@<0Mg]n8`1gMgTF0?ooo`00503ooomH07MgN@@0
KU0n101kJf0407MWI@@0MfmY101gHeh307M_J@`0Mf]U101gHeh407MWF@@0KUmF0`1cG58406Y@A`@0
KeM<101VD4H?06]CB0@0Jda2101SCch406M?A`@0Idln101WCdL308^T]100MgMi101gKg4307MkOR<0
MgMi5P3oool001@0oooo101gMgT407M_L@L0MgMi101gKg4W07MgN@@0Mfma6P1gMgT407MGA0@0Nf]Y
101gIed407M_J@@0Mf=N0`1gKfT407M[I@@0Mf=F201^G4l406iHB`@0IU180`1QCD@40659@0@0IU16
101NBD0;06]CB0P0Jda2101SCdD406M?A`@0Idln101WKWD308^T]1@0MgMi0`1gNghS07MgNAH0oooo
000D0?ooo`@0MgMi101gKg4707MgN@@0Mfma9`1gMgT407M_LAX0MgMi101gEd@407][J@@0MfMM101g
KfT407MSGP<0MfmY101gJfD407MSEPP0KUa?101^F4/406I@B0<0HDe4101QBD0406I@AP@0GTU02`1[
DdP806]<@P@0Hdm5101WCdL406M??P@0Ifie0`2;Y;@D07MgN@<0Mg]n8`1gMgTF0?ooo`00503oool4
07MgN@@0Mfma1`1gMgT407M_LBL0MgMi101gKg4J07MgN@@0MeM4101kJfT407MWG@@0MfmY101gHeh3
07M_J@@0Mf]U101gHeH806iLC`@0KUQ;101VD4P3065=A0@0HDU0101VD4H405i9@0/0Je=8201[C484
06=?A@@0Idm7101WCch406M^M@<0RjBd501gMgT307MkOR<0MgMi5P3oool001@0oooo101gMgT407M_
L@L0MgMi101gKg4W07MgN@@0Mfma6P1gMgT407MGA0@0Nf]Y101gIed407M_J@@0Mf=N0`1gKfT407M[
I@@0Mf=F201^G4l406iHB`@0IU180`1QCD@40659@0@0IU16101NBD0;06]CB0P0Jda2101SCdD406M?
A`@0Idln101WKWD308^T]1@0MgMi0`1gNghS07MgNAH0oooo000D0?ooo`P0MgMi101gLgD707MgN@@0
Mg]n101gMgT407M_L@@0MgMi0`1gKg4H07MgN@<0Mg]n5`1gMgT406i@?P@0MfMM101gIf4407MWI@@0
Mf]U0`1gIf4407MSGP@0KUa?101FF5H406YCB`@0JTI4101QBD0306IDB@@0JeM<101[FTl406]CB0@0
Idm52`1SC48406=??P@0Hdm5201WCdD408^T^0<0Ri:I501gMgT307M_LB<0MgMi5P3oool001@0oooo
201gMgT407McM@L0MgMi101gNgh407MgN@@0Mfma101gMgT307M_LAP0MgMi0`1gNghG07MgN@@0KU0n
101gIed407MWH@@0MfMU101gJfD307MWH@@0Mf=N101^G4l405IHEP@0JU=;101ZAT@40659@0<0IUA9
101[Ed`406]JC`@0Je=8101WCdD;06=<@P@0Hdln101SCdD806M?A@@0RjBh0`2;TYTD07MgN@<0Mfma
8`1gMgTF0?ooo`00503oool807MgN@@0Mg=e1`1gMgT407MkOP@0MgMi101gKg4407MgN@<0Mfma601g
MgT307MkOQL0MgMi101^D3h407MWG@@0MfMQ101gIfD407M[I@<0MfMQ101gHeh406iLC`@0EUQF101Z
Dd/406Y6A0@0HDU00`1VE4T406]GC0@0JeY?101[DdP406M?A@/0Hda2101SCch406=?A@P0Idm5102;
Y;P308^BVA@0MgMi0`1gKg4S07MgNAH0oooo000D0?ooo`P0MgMi101gLgD707MgN@@0Mg]n101gMgT4
07M_L@@0MgMi0`1gKg4H07MgN@<0Mg]n5`1gMgT406i@?P@0MfMM101gIf4407MWI@@0Mf]U0`1gIf44
07MSGP@0KUa?101FF5H406YCB`@0JTI4101QBD0306IDB@@0JeM<101[FTl406]CB0@0Idm52`1SC484
06=??P@0Hdm5201WCdD408^T^0<0Ri:I501gMgT307M_LB<0MgMi5P3oool001@0oooo201gMgT407M_
L@<0Mg]n401gMgT407MkOP<0MgMi101gNgh^07MgN@@0Me0n101kJfT407MWI@P0MfMQ0`1gHeh407MW
F@@0MfMQ101kJfT4085WF@@0P5]O101_FT`307ACB0P0M51<101[@T0406=<@Pl0Idm5101_ETh806M?
A@@0RjBd6P1gMgT407MkOQl0MgMi5P3oool001@0oooo201gMgT407M_L@<0Mg]n401gMgT407MkOP<0
MgMi101gNgh^07MgN@@0Me0n101kJfT407MWI@P0MfMQ0`1gHeh407MWF@@0MfMQ101kJfT4085WF@@0
P5]O101_FT`307ACB0P0M51<101[@T0406=<@Pl0Idm5101_ETh806M?A@@0RjBd6P1gMgT407MkOQl0
MgMi5P3oool001@0oooo201gMgT407M_L@<0Mg]n401gMgT407MkOP<0MgMi101gNgh^07MgN@@0Me0n
101kJfT407MWI@P0MfMQ0`1gHeh407MWF@@0MfMQ101kJfT4085WF@@0P5]O101_FT`307ACB0P0M51<
101[@T0406=<@Pl0Idm5101_ETh806M?A@@0RjBd6P1gMgT407MkOQl0MgMi5P3oool001@0oooo301g
MgT307MkOTT0MgMi101gEd@407M[H0@0MfMI3`1gIf4407M_K@@0MfmY101gIf4407=SF@@0KU]B0`1g
GU@407MRE`@0Ke=<101gHU@406];A@@0KdQ50`1_GEX406M?A@P0Kdm5101SC48406mMDP@0RjBd?@1g
MgTF0?ooo`00503oool<07MgN@<0Mg]nB@1gMgT407MGA0@0Mf]P101gIeT?07MWH@@0Mfm]101gKfT4
07MWH@@0Lf=I101^Fe8307MNE0@0Mf9G101_Dd`407MRE0@0Jd]5101_B4D306mMFP@0Idm5201_CdD4
06=<@P@0KeeB102;Y;@m07MgNAH0oooo000D0?ooo``0MgMi0`1gNgi907MgN@@0MeM4101gJf0407MW
F@l0MfMQ101gKfd407M_J@@0MfMQ101cHeT406iKDP<0MeiD101gHUL406mCC0@0Mf9D101[BdD406m8
A@<0KeeJ101WCdD806m?A@@0Hda2101_GE8408^T]3d0MgMi5P3oool001@0oooo301gMgT307MkOTT0
MgMi101gEd@407M[H0@0MfMI3`1gIf4407M_K@@0MfmY101gIf4407=SF@@0KU]B0`1gGU@407MRE`@0
Ke=<101gHU@406];A@@0KdQ50`1_GEX406M?A@P0Kdm5101SC48406mMDP@0RjBd?@1gMgTF0?ooo`00
503ooomH07MgN@@0MeM4101gIed407MWI@@0MfMM1`1gIf4407M_J@@0MfMQ101gHeh407M[I@@0MfMQ
101kJf0307=SE@@0Le]H101cFe4406mJC0@0JTe9101[FT/306]CA@@0JeMA101WCdD806=?A@@0PGj3
1026W:/J07MgN@@0Mfma7`1gMgTF0?ooo`00503ooomH07MgN@@0MeM4101gIed407MWI@@0MfMM1`1g
If4407M_J@@0MfMQ101gHeh407M[I@@0MfMQ101kJf0307=SE@@0Le]H101cFe4406mJC0@0JTe9101[
FT/306]CA@@0JeMA101WCdD806=?A@@0PGj31026W:/J07MgN@@0Mfma7`1gMgTF0?ooo`00503ooomH
07MgN@@0MeM4101gIed407MWI@@0MfMM1`1gIf4407M_J@@0MfMQ101gHeh407M[I@@0MfMQ101kJf03
07=SE@@0Le]H101cFe4406mJC0@0JTe9101[FT/306]CA@@0JeMA101WCdD806=?A@@0PGj31026W:/J
07MgN@@0Mfma7`1gMgTF0?ooo`00503ooomH07MgN@@0MeM4101gIed407MWI@@0MfMM1`1gIf4407M_
J@@0MfMQ101gHeh407M[I@@0MfMQ101kJf0307=SE@@0Le]H101cFe4406mJC0@0JTe9101[FT/306]C
A@@0JeMA101WCdD806=?A@@0PGj31026W:/J07MgN@@0Mfma7`1gMgTF0?ooo`00503ooomE07MgN@<0
GC`c101gEd@407MWI@@0MfMM101gIeT407MWI@<0MfmY101gIf4407M[I@P0MfmY101gHeh407MWH@<0
MemF101kGeD407=KCP@0Le]A101_D4`406mCAP<0Jda2101SCdD406=9?@@0Kdm5101WCdD4086AX0@0
NhV@7P1gMgT407MkOPP0MgMi1`1gKg4<07MgNAH0oooo000D0?oooeD0MgMi0`1M?3<407MGA0@0MfMU
101gIed407MWF@@0MfMU0`1gKfT407MWH@@0Mf]U201gKfT407MSGP@0MfMQ0`1gGeH407]OE@@0Le]>
101cFe4406m@C0@0Ke=60`1[C48406=?A@@0HdTm101_CdD406M?A@@0PI6P101kRI0N07MgN@@0Mg]n
201gMgT707M_L@`0MgMi5P3oool001@0ooooE@1gMgT305dl<`@0MeM4101gIfD407MWG@@0MfMI101g
IfD307M_J@@0MfMQ101gJfD807M_J@@0Mf=N101gIf4307MOEP@0NemE101cFdh407=KD@@0Ke1<101_
DdH306]<@P@0Hdm5101SBCd406m?A@@0Idm51021TJ0407^9T1h0MgMi101gNgh807MgN@L0Mfma301g
MgTF0?ooo`00503ooomE07MgN@<0GC`c101gEd@407MWI@@0MfMM101gIeT407MWI@<0MfmY101gIf44
07M[I@P0MfmY101gHeh407MWH@<0MemF101kGeD407=KCP@0Le]A101_D4`406mCAP<0Jda2101SCdD4
06=9?@@0Kdm5101WCdD4086AX0@0NhV@7P1gMgT407MkOPP0MgMi1`1gKg4<07MgNAH0oooo000D0?oo
oe40MgMi100O5A0306i@?P@0QWMW101gIfD407MWH@P0MfMU0`1gKfT407MSGP@0MfMI101gJfD807MS
GPL0MfMI101^De8406iGCP@0LeAA101ZE4<406I<@0<0IU=8101[CdD406M?A@@0KeeB101[ET/408^T
]0@0Nh22;P1gMgT707MkOPP0MgMi5P3oool001@0ooooD@1gMgT401lE40<0KU0n1026MfL407MWI@@0
MfMQ201gIfD307M_J@@0Mf=N101gIeT407M[I@P0Mf=N1`1gIeT406iCDP@0KUM>101cE54406YD@`@0
ITa00`1VDdP406]?A@@0Idm5101_GE8406]FB`@0RjBd101kP88^07MgN@L0Mg]n201gMgTF0?ooo`00
503ooomA07MgN@@07aD@0`1^D3h408IgI`@0MfMU101gIf4807MWI@<0MfmY101gHeh407MWF@@0Mf]U
201gHeh707MWF@@0KU=B101^Edh407=DD@@0JUA3101VC40306ICB0@0Jdm5101WCdD406mMDP@0JeI;
102;Y;@407^0PRh0MgMi1`1gNgh807MgNAH0oooo000D0?oooe40MgMi100O5A0306i@?P@0QWMW101g
IfD407MWH@P0MfMU0`1gKfT407MSGP@0MfMI101gJfD807MSGPL0MfMI101^De8406iGCP@0LeAA101Z
E4<406I<@0<0IU=8101[CdD406M?A@@0KeeB101[ET/408^T]0@0Nh22;P1gMgT707MkOPP0MgMi5P3o
ool001@0oooo201gMgT407M_LD40MgMi101FBE8400P10@<0]iN<101kJf0407M_K@@0MfMQ101gKfT7
07MWH@@0Mf]U101gKfT407MWI@@0Mf=F101gD58406i@A@<0ITU1101^D4P407=KCP@0JU]A101QD4<4
06m@B0<0JeI;101SC3`406=?A@@0Idm5101SBD0408JP[d40MgMi5P3oool001@0oooo201gMgT407M_
LD40MgMi101FBE8400P10@<0]iN<101kJf0407M_K@@0MfMQ101gKfT707MWH@@0Mf]U101gKfT407MW
I@@0Mf=F101gD58406i@A@<0ITU1101^D4P407=KCP@0JU]A101QD4<406m@B0<0JeI;101SC3`406=?
A@@0Idm5101SBD0408JP[d40MgMi5P3oool001@0oooo201gMgT407M_LD40MgMi101FBE8400P10@<0
]iN<101kJf0407M_K@@0MfMQ101gKfT707MWH@@0Mf]U101gKfT407MWI@@0Mf=F101gD58406i@A@<0
ITU1101^D4P407=KCP@0JU]A101QD4<406m@B0<0JeI;101SC3`406=?A@@0Idm5101SBD0408JP[d40
MgMi5P3oool001@0oooo201gMgT407M_LD40MgMi101FBE8400P10@<0]iN<101kJf0407M_K@@0MfMQ
101gKfT707MWH@@0Mf]U101gKfT407MWI@@0Mf=F101gD58406i@A@<0ITU1101^D4P407=KCP@0JU]A
101QD4<406m@B0<0JeI;101SC3`406=?A@@0Idm5101SBD0408JP[d40MgMi5P3oool001@0oooo301g
MgT307McMCX0MgMi1020Oh8400`40P@0PFM?0`3E]Y/407MWH@@0MfMU101gHeh407MWH@@0Mf=N1`1g
If4407M[I@@0Mf=N101^Ge8406i@C`@0KU];0`1ZE4T406mGC0@0JUA9101ZE4<406I=@`@0Jda20`1V
C48406]<@P@0Kdm7101WCdD406mFB`@0PGj3@@1gMgTF0?ooo`00503oool<07MgN@<0Mg=e>P1gMgT4
081oPP@030@21021Idl30=FfV`@0MfMQ101gIfD407MSGP@0MfMQ101gHeh707MWH@@0Mf]U101gHeh4
06iODP@0KU1?101^Fd/306YDB@@0KeM<101ZE4T406YD@`@0ITe3101[C48306I<@P@0Jda2101_CdL4
06M?A@@0KeI;1021OX=107MgNAH0oooo000D0?ooo``0MgMi0`1gLgDj07MgN@@0P7n2100<1084085W
C`<0eKJK101gIf4407MWI@@0Mf=N101gIf4407MSGPL0MfMQ101gJfD407MSGP@0KUmB101^D4l406iK
B`<0JUA9101_Ed`406YDB@@0JUA3101VCD<406]<@P<0ITa2101[C48406m?A`@0Idm5101_ET/4085n
Pd40MgMi5P3oool001@0oooo201gMgT407M_L@<0MgMi101gNghf07MgN@@030@2101bFTl40=2^XP<0
Nf]P101gIfD807MWH@@0MfMI1`1gIf4407M_J@@0MfMQ101gHeh406ha<`@0Lc@h101Z;Rl306X^<@@0
Kc4c101_D4H406I9@0@0ITU2101[AC`306=??PP0Jdm5101SCch406m8?P@0Hda2101kRI0Z07MgN@@0
Mfma3`1gMgTF0?ooo`00503oool807MgN@@0Mfma0`1gMgT407MkOSH0MgMi100<1084079JC`@0d:jR
0`1kJf0407MWI@P0MfMQ101gIeT707MWH@@0MfmY101gIf4407MSGP@0KS4c101c=3P406X^;`<0JRha
101_<C<406m@AP@0ITU0101VBD8406]5?0<0Hdln201[CdD406=??P@0KdPn101SC48407^9T2X0MgMi
101gKg4?07MgNAH0oooo000D0?ooo`P0MgMi101gKg4307MgN@@0Mg]n=P1gMgT400`40P@0LUY?103@
[Z8307][H0@0MfMU201gIf4407MWF@L0MfMQ101gKfT407MWH@@0Mf=N101^<C<407<d>0@0JRh_0`1Z
;S4406la<`@0Ke16101VBD0406I9@P@0JdDl0`1SCch806]?A@@0Hdln101_B3h406=<@P@0NhV@:P1g
MgT407M_L@l0MgMi5P3oool001@0oooo201gMgT407M_L@<0MgMi101gNghf07MgN@@030@2101bFTl4
0=2^XP<0Nf]P101gIfD807MWH@@0MfMI1`1gIf4407M_J@@0MfMQ101gHeh406ha<`@0Lc@h101Z;Rl3
06X^<@@0Kc4c101_D4H406I9@0@0ITU2101[AC`306=??PP0Jdm5101SCch406m8?P@0Hda2101kRI0Z
07MgN@@0Mfma3`1gMgTF0?ooo`00503oool<07MgN@<0Mg]n=P1gMgT405I9C0@0KUMB103@[Z8407MS
GP<0MfMI101gIfD407MWH@P0MemB101gGeH707MWH@@0Mde?101gD58406ha<`@0JSXb101Q:B8306lo
?0@0ISP`101_?c`405hi=@@0HdPn101SCch306=;@@@0Kdm7201[CdD406m8@@@0JeY>101_ET/^07Mg
N@<0Mg]n301gMgTF0?ooo`00503oool<07MgN@<0Mg]n=P1gMgT405I9C0@0KUMB103@[Z8407MSGP<0
MfMI101gIfD407MWH@P0MemB101gGeH707MWH@@0Mde?101gD58406ha<`@0JSXb101Q:B8306lo?0@0
ISP`101_?c`405hi=@@0HdPn101SCch306=;@@@0Kdm7201[CdD406m8@@@0JeY>101_ET/^07MgN@<0
Mg]n301gMgTF0?ooo`00503oool<07MgN@<0Mg]n=P1gMgT405I9C0@0KUMB103@[Z8407MSGP<0MfMI
101gIfD407MWH@P0MemB101gGeH707MWH@@0Mde?101gD58406ha<`@0JSXb101Q:B8306lo?0@0ISP`
101_?c`405hi=@@0HdPn101SCch306=;@@@0Kdm7201[CdD406m8@@@0JeY>101_ET/^07MgN@<0Mg]n
301gMgTF0?ooo`00503oool<07MgN@<0Mg]n=P1gMgT405I9C0@0KUMB103@[Z8407MSGP<0MfMI101g
IfD407MWH@P0MemB101gGeH707MWH@@0Mde?101gD58406ha<`@0JSXb101Q:B8306lo?0@0ISP`101_
?c`405hi=@@0HdPn101SCch306=;@@@0Kdm7201[CdD406m8@@@0JeY>101_ET/^07MgN@<0Mg]n301g
MgTF0?ooo`00503ooom507MgN@@020@41021Ie8407]WEPL0MfMI101gIfD407MWF@@0KUQ;101^Dd/4
07M[H0<0Mf]Y101gF4/406ha<`@0IRhW101M?cP404/Y7@@0IV]K0`1dKF<405hX8@@0HbXS101V>304
06M3?0@0Ie=70`1WB3@406MC@@`0Jdm5101[DdL406]CB0<0QXfA>P1gMgTF0?ooo`00503ooom507Mg
N@@020@41021Ie8407]WEPL0MfMI101gIfD407MWF@@0KUQ;101^Dd/407M[H0<0Mf]Y101gF4/406ha
<`@0IRhW101M?cP404/Y7@@0IV]K0`1dKF<405hX8@@0HbXS101V>30406M3?0@0Ie=70`1WB3@406MC
@@`0Jdm5101[DdL406]CB0<0QXfA>P1gMgTF0?ooo`00503ooom507MgN@@020@41021Ie8407]WEPL0
MfMI101gIfD407MWF@@0KUQ;101^Dd/407M[H0<0Mf]Y101gF4/406ha<`@0IRhW101M?cP404/Y7@@0
IV]K0`1dKF<405hX8@@0HbXS101V>30406M3?0@0Ie=70`1WB3@406MC@@`0Jdm5101[DdL406]CB0<0
QXfA>P1gMgTF0?ooo`00503ooom507MgN@@020@41021Ie8407]WEPL0MfMI101gIfD407MWF@@0KUQ;
101^Dd/407M[H0<0Mf]Y101gF4/406ha<`@0IRhW101M?cP404/Y7@@0IV]K0`1dKF<405hX8@@0HbXS
101V>30406M3?0@0Ie=70`1WB3@406MC@@`0Jdm5101[DdL406]CB0<0QXfA>P1gMgTF0?ooo`00503o
ool?07MgN@@0Mfma;P1gMgT403X[;@@0Ab/O103E[Y@407][J@@0KUQ?0`1gKfd407MWI@@0MeQ;101V
BC/4064l=@@0Ne]O0`1V9bX401X30P@0ITU7101ZAch407M[H`@0QYJE1022?cX305/f;P@0Ac<T101G
Edl403/_8`@0HbXS101OBS`306M8<P@0Kd]6101_ETh407AMB`@0Jdm5101[ET/406]?A@<0Je=8101g
Kfdf07MgNAH0oooo000D0?ooo`l0MgMi101gKg4^07MgN@@0>R/]1017:al40=F^U0@0Nf]Y101^F4l3
07M_K@@0MfMU101gF4/406I9>`@0HC`e101kFel306HW:P@06P<2101VBDL406Y7?P@0Mf]S1026UYD4
088o>P<0FcH^1017<b@405MGC`@0>blS101S:R<405m:?0<0IdPb101_BdH406mFCP@0M5e;101[CdD4
06]FB`@0Jdm50`1[DdP407M_KCH0MgMi5P3oool001@0oooo3`1gMgT407M_LBh0MgMi100j:bd404L[
7`@0eJjD101kJfT406iHC`<0Mfm]101gIfD407MHB`@0ITTk101Q?3D407]KG`<0IRLZ100J0`8406I9
A`@0JTLn101gJf<408JFU@@0PSlj0`1K=Rh404Lc90@0EeM?100k;b<406<Z8`@0GdXl0`1WB38406m;
AP@0KeI>101dGD/406]?A@@0JeI;101[CdD306]CB0@0Mfm]=P1gMgTF0?ooo`00503oool?07MgN@@0
Mfma;P1gMgT403X[;@@0Ab/O103E[Y@407][J@@0KUQ?0`1gKfd407MWI@@0MeQ;101VBC/4064l=@@0
Ne]O0`1V9bX401X30P@0ITU7101ZAch407M[H`@0QYJE1022?cX305/f;P@0Ac<T101GEdl403/_8`@0
HbXS101OBS`306M8<P@0Kd]6101_ETh407AMB`@0Jdm5101[ET/406]?A@<0Je=8101gKfdf07MgNAH0
oooo000D0?ooo`P0MgMi101gKg4707MgN@@0Mg]n:P1gMgT400`61P@0UGYS102DPgh407MWG@@0KU15
0`1kKf`407MSGP@0MeQ;101M=RT405hf<0@09`T90`1FHf04082SWP@0_=;>1020UZ44082JY0@0NhV9
101^EdP3082WY@@0QX^?101SHfT403DO6P@0:AXA101G=BP306]E@`@0Kd]6101dHED407AJC`@0KeM8
101[CdD406]<@P<0JeI;101[Ni`406i_MS80MgMi5P3oool001@0oooo201gMgT407M_L@L0MgMi101g
NghZ07MgN@@030H6102ENV<409B3OP@0MfMM101^D4D307]_K0@0Mf=N101gF4/405df:@@0GSH`100W
2@T305ISH0@0P:>N102ld/h4082FX@@0P9ZT101kRHT406iGB0<0P:NU1026Rhl406=SJ@@0=AlJ100Y
6Q4405Le:0<0JeE3101_BdH407AQE@@0M5Y?101_EdP406]?A@@0Jda20`1[ET/406]kW0@0KVmf<P1g
MgTF0?ooo`00503oool807MgN@@0Mfma1`1gMgT407MkORX0MgMi100<1PH409EjH`@0U8=n101gIed4
06i@A@<0Nfm/101gHeh407MHB`@0GCHY101N=S0402L92@<0EV=P1020Xih40;cBcP@0P9JQ1020VZ@4
07^9R@@0KUM80`20YjD408J;S`@0Hf=Y100e7aX402TJ4@@0EcDX0`1[ED<406m;AP@0M65E101dFTl4
06mGB0@0Jdm5101[C48306]FB`@0Jg^L101^KgHb07MgNAH0oooo000D0?ooo`P0MgMi101gKg4707Mg
N@@0Mg]n:P1gMgT400`61P@0UGYS102DPgh407MWG@@0KU150`1kKf`407MSGP@0MeQ;101M=RT405hf
<0@09`T90`1FHf04082SWP@0_=;>1020UZ44082JY0@0NhV9101^EdP3082WY@@0QX^?101SHfT403DO
6P@0:AXA101G=BP306]E@`@0Kd]6101dHED407AJC`@0KeM8101[CdD406]<@P<0JeI;101[Ni`406i_
MS80MgMi5P3oool001@0oooo301gMgT307MkORl0MgMi0`1MEfT400H10@@0a:27101kJf0407MWF@@0
MfMM0`1kLg0407MWH@@0ISdc1017<B0404/O6@@09@X70`2RJed4085GB0@0KT8l101gKfd407MKB0@0
Mem;101V?3H307=[L0@0IS``101kIeh406m<?@@0KV9I100g7aT305lc:0@0IdQ1101dHDh407MWF`@0
KeM<101VD4P406]8?P<0Jdm5101SJVH405]@A@@0HEma;P1gMgTF0?ooo`00503oool<07MgN@<0Mg]n
;`1gMgT305eGJ@@01P411034X8L407][H0@0MfMI101gIed307]cL0@0MfMQ101V?C<404La80@0BalI
100U2PL30:9[G@@0PEM8101^@S`407M_K@@0Me]8101gGd/406Hl=P<0Lf]`101V?30407]WGP@0Kd`m
101^HUT403LO6@<0Gc<X101WB44407AQCP@0MfMK101_Ed`406I@B0@0JdPn0`1[CdD406=ZIP@0Fe15
101QGg4^07MgNAH0oooo000D0?ooo``0MgMi0`1gNgh_07MgN@<0GEMY10060@440<BPQ`@0Nf]P101g
IeT407MWG@<0Ng=`101gIf4406Hm<`@0Ac4P101;7aT402D:1`<0XV]M1021EdP406i2?0@0Mfm]101g
FdP407MOB`@0IS`f0`1cJg0406Hl<0@0NfMN101_C3d406iRF@@0=alI0`1O<bP406M8@@@0M65>101g
Ie/406mGC0@0IU18101[B3h306]?A@@0HfYV101KD4D4065OLBh0MgMi5P3oool001@0oooo301gMgT3
07MkORl0MgMi0`1MEfT400H10@@0a:27101kJf0407MWF@@0MfMM0`1kLg0407MWH@@0ISdc1017<B04
04/O6@@09@X70`2RJed4085GB0@0KT8l101gKfd407MKB0@0Mem;101V?3H307=[L0@0IS``101kIeh4
06m<?@@0KV9I100g7aT305lc:0@0IdQ1101dHDh407MWF`@0KeM<101VD4P406]8?P<0Jdm5101SJVH4
05]@A@@0HEma;P1gMgTF0?ooo`00503ooolj07MgN@@07aD@0`060@4405<a90@0f[JK101kJf0807MH
C`<0MfMM101gIeT406Hm<`@0KeeB102;PWX409ZST0<0_9ZH101gI5d406Y=B@@0JU19101^:b/405df
=@@0GB8Q0`1V8al405XM6@@0IUY?101F;2<405lk?P@0C38/0`0g3@H406m>A`@0NF5>101gIeh406Y@
@0@0ITU0101SC48306]JCP@0JeeB102;RI@406]SN@@0QXV2:P1gMgTF0?ooo`00503ooolj07MgN@@0
7aD@0`060@4405<a90@0f[JK101kJf0807MHC`<0MfMM101gIeT406Hm<`@0KeeB102;PWX409ZST0<0
_9ZH101gI5d406Y=B@@0JU19101^:b/405df=@@0GB8Q0`1V8al405XM6@@0IUY?101F;2<405lk?P@0
C38/0`0g3@H406m>A`@0NF5>101gIeh406Y@@0@0ITU0101SC48306]JCP@0JeeB102;RI@406]SN@@0
QXV2:P1gMgTF0?ooo`00503ooolj07MgN@@07aD@0`060@4405<a90@0f[JK101kJf0807MHC`<0MfMM
101gIeT406Hm<`@0KeeB102;PWX409ZST0<0_9ZH101gI5d406Y=B@@0JU19101^:b/405df=@@0GB8Q
0`1V8al405XM6@@0IUY?101F;2<405lk?P@0C38/0`0g3@H406m>A`@0NF5>101gIeh406Y@@0@0ITU0
101SC48306]JCP@0JeeB102;RI@406]SN@@0QXV2:P1gMgTF0?ooo`00503ooolC07MgN@@0Mfma7`1g
MgT405e@F@@000000`0C30/40=ZfYP@0U8Me101gGeH407M@EP@0KVML0`1gKf<407M@EP@0IT<k101F
>b`4081gM0@0Ng=`0`1gIfD407McJ@@0Ngmh1020Ng@4081kJP@0LfaJ101mJEX307A_EP@0M6eK101_
FDX407@a<`@0Ic4]101C8AH304@C3P@0Hb@K101_F4X407MNE`@0JU10101VBD8406=8?P<0Kdm5101[
DdP401TA3`@0Mg=e1021P7XZ07MgNAH0oooo000D0?oooa<0MgMi101gKg4O07MgN@@0GE1I10000003
01<<2`@0f[JV102DQgD407MOEP@0Me1F101^Ie`307M_H`@0Me1F101V@c/405Hk;0@0P7Md101kLg03
07MWI@@0Mg=Y101kOgP4081kM0@0P7]Z101cK5X407eYFP<0M6mF101dKE/406mIBP@0M34c101W<Bd4
05<Q5P<0A1<>101S91/406mHBP@0MeiG101ZD40406I9@P@0HdPn0`1_CdD406]CB0@06A4?101gLgD4
0860NRX0MgMi5P3oool001@0oooo4`1gMgT407M_LAl0MgMi101MD5T4000000<04``;103J]ZH409B7
M@@0MemF101gD5H406iWG0<0MfmS101gD5H406I3>`@0ES//1020Mg@407]cL0<0MfMU101gLfT407]o
N0@0P7]d1020NfX407=/FP@0OFUJ0`1dKeH407A]F`@0KeU:101d<C<406La;@@0Db4F0`144`h406<T
6`@0KeQ:101gGUL406Y@@0@0ITU2101SB3h306m?A@@0Je=8100I4@l407McM@@0PH1j:P1gMgTF0?oo
o`00503ooolC07MgN@@0Mfma7`1gMgT405e@F@@000000`0C30/40=ZfYP@0U8Me101gGeH407M@EP@0
KVML0`1gKf<407M@EP@0IT<k101F>b`4081gM0@0Ng=`0`1gIfD407McJ@@0Ngmh1020Ng@4081kJP@0
LfaJ101mJEX307A_EP@0M6eK101_FDX407@a<`@0Ic4]101C8AH304@C3P@0Hb@K101_F4X407MNE`@0
JU10101VBD8406=8?P<0Kdm5101[DdP401TA3`@0Mg=e1021P7XZ07MgNAH0oooo000D0?oooaL0MgMi
101gNghK07MgN@@0GEMY1026Je830>6MQ0@0f;2D101gIeT407MOEP@0Mf]P101gFeT307][H0@0MfMM
101VE4@406I5?0@0QWU^101gIf4307M[I@P0MfMQ101gJfD407M@DP@0KU18101cFe4306YDB@@0Ke18
101NC3`406=;@@@0GU]3101WFDX307ARE0@0O5eK1020JTT407AMDP@0JUA3101VBD8406=??P<0Ke=7
101[ET/401dO80@0VYJD101gNgh407^0PRH0MgMi5P3oool001@0oooo5`1gMgT407MkOQ/0MgMi101M
EfT408I[DP<0hIf4103H/9@407MWF@@0MemF101gJf0407MKF@<0Nf]P101gIed406IDA0@0ITDl1026
NFh407MWH@<0Mf]U201gIf4407M[I@@0Me1B101^D4P407=KD@<0JUA9101_D4P405i<?0@0Hd]1101N
Fd<406MIBP<0M69D101lGE/4081ZB@@0M5eB101ZE4<406I9@P@0Hdln0`1_DdL406]FB`@07AlP102J
UY@407MkOP@0Nh229P1gMgTF0?ooo`00503ooolG07MgN@@0Mg]n6`1gMgT405eGJ@@0QV]B0`3QWH@4
0=R`U0@0MfMI101gGeH407M[H0@0Me]I0`1kJf0407MWG@@0IUA4101VAC`408IiKP@0MfMQ0`1gJfD8
07MWH@@0Mf]U101gD58406i@B0@0Le]A0`1ZE4T406m@B0@0GT`l101SBd4405iK@`@0IeU:0`1dHU@4
07aMF`@0P6Y9101dGE8406YD@`@0ITU2101SCch306mCA`@0JeI;100M7b0409ZFU0@0Mg]n101kP88V
07MgNAH0oooo000D0?oooaL0MgMi101gNghK07MgN@@0GEMY1026Je830>6MQ0@0f;2D101gIeT407MO
EP@0Mf]P101gFeT307][H0@0MfMM101VE4@406I5?0@0QWU^101gIf4307M[I@P0MfMQ101gJfD407M@
DP@0KU18101cFe4306YDB@@0Ke18101NC3`406=;@@@0GU]3101WFDX307ARE0@0O5eK1020JTT407AM
DP@0JUA3101VBD8406=??P<0Ke=7101[ET/401dO80@0VYJD101gNgh407^0PRH0MgMi5P3oool001@0
oooo=P1gMgT407MGA0@0QVMC0`1gKfd407=[G`@0Lf=I101gIed407M[J@@0MfMU0`1gNg0407MWI@@0
KUQ?101_D4H406];@@@0LfML0`1gKfT407M[I@@0MfMQ101gKfT407MSEP@0KU];101ZASd306YD@`@0
GTTj101?AC`405m1=0@0Gchd101O@C@305ln=0@0Gd@d101cH4h407UQF`@0Ke16101N@S`406=8?P<0
Idm1101SCdD400/<3@@0[:S4102;TYTZ07MgNAH0oooo000D0?ooocH0MgMi101gEd@408IWD`<0Mfm]
101cJel407=SF@@0MfMM101gJfT407MWI@<0Mg]`101gIfD406iHC`@0Ke16101[Bd4407=WG0<0MfmY
101gJfD407MWH@@0MfmY101gHeH406iKB`@0JTHm0`1ZE4<405i9>P@0CdDl101O@C@405ln=0@0Gd4d
0`1O?S@405m4=0@0Lf1>101iHE/406m@AP@0GT8l101SB3h306M?@@@0Hdm5100;30d40:bXa0@0Ri:I
:P1gMgTF0?ooo`00503ooolf07MgN@@0MeM41026Ie<307M_K@@0Lf]O101cHeT407MWG@@0Mf]Y101g
IfD307MkL0@0MfMU101^F4l406m@AP@0Jd]1101cIe`307M_J@@0Mf]U101gIf4407M_J@@0Mf=F101^
Fd/406Y6?@<0JUA3101NBCX404m5?0@0Gd4d101O?S@405m1=0<0Gchd101OA3@407=PCP@0NF5K101_
D4H405i2?0@0HdPn0`1WCd4406=?A@@02``=102/Z<@408^BVBX0MgMi5P3oool001@0oooo=P1gMgT4
07MGA0@0QVMC0`1gKfd407=[G`@0Lf=I101gIed407M[J@@0MfMU0`1gNg0407MWI@@0KUQ?101_D4H4
06];@@@0LfML0`1gKfT407M[I@@0MfMQ101gKfT407MSEP@0KU];101ZASd306YD@`@0GTTj101?AC`4
05m1=0@0Gchd101O@C@305ln=0@0Gd@d101cH4h407UQF`@0Ke16101N@S`406=8?P<0Idm1101SCdD4
00/<3@@0[:S4102;TYTZ07MgNAH0oooo000D0?oooc80MgMi101^IfT407MGA0@0KUQ?0`1VBCP405ID
GP@0Nf=I101kJfT407M_K@L0MfmY101gJfD407M@DP@0LeM>101_C48407eYG@<0Nf]Y101gJfD407M=
C`@0KUmB101gHeH406I9@@@0JTe30`1N>c8405i9@P@0Gc/d101WA3@406=7?P@0Je0h0`1SAcP406=3
<P@0OEeC101dDdP406I9@0@0GTDl101WBd4306MCA`@0KeI>10031PP40:6CSP@0P8En:P1gMgTF0?oo
o`00503ooolb07MgN@@0KVMY101gEd@406iHC`<0ITTh101FE5h407]SF@@0Nf]Y101gKfd707M_J@@0
Mf]U101gD58407=GCP@0Kda2101mJEd307][J@@0Mf]U101gCDl406iODP@0Mf=F101VBD4406Y=@`<0
GS/b101NBD8405lk=0@0Id@d101SAch406]@>0<0HdLh101S@c8407eMD`@0M5=8101VBD0405i5?0@0
Id]10`1WDdL406mFCP@00`H8102QThh40825ORX0MgMi5P3oool001@0oooo<P1gMgT406iWJ@@0MeM4
101^F4l306I9>0@0EUAN101kHeT407][J@@0Mfm]1`1gKfT407M[I@@0Me1B101cEdh406m<@P@0OFUM
0`1kJfT407M[I@@0Mde?101^Ge8407MSEP@0ITU1101ZCD<305hk<P@0GTU2101O>c@406M4=0@0HdLn
101[D3P306=7>0@0Hd<b101mGE<407ACB0@0ITU0101NAC`406M;@@<0Ie=7101_ETh400<620@0XI>>
1020QGhZ07MgNAH0oooo000D0?oooc80MgMi101^IfT407MGA0@0KUQ?0`1VBCP405IDGP@0Nf=I101k
JfT407M_K@L0MfmY101gJfD407M@DP@0LeM>101_C48407eYG@<0Nf]Y101gJfD407M=C`@0KUmB101g
HeH406I9@@@0JTe30`1N>c8405i9@P@0Gc/d101WA3@406=7?P@0Je0h0`1SAcP406=3<P@0OEeC101d
DdP406I9@0@0GTDl101WBd4306MCA`@0KeI>10031PP40:6CSP@0P8En:P1gMgTF0?ooo`00503ooolb
07MgN@@0MeM4101kGe<406I9@@<0HDU0101gKfH408]GDP@0Mf]Y101gKfT;07M[I@@0Mf=F101gHe84
06YD@`@0Kdm50`1kLg0407M_J@@0Mf=N101gLfT407][J@@0KU1?101_Ed`306I<@P@0KeQ<101O>c84
06=3>0@0HdLn101[CT<306m;AP@0OEeC101mJ5d806I<@P@0Jdm5101WBd4306MC@@@0Idm510061`L4
03/Z9@@0ShjD:P1gMgTF0?ooo`00503ooolb07MgN@@0MeM4101kGe<406I9@@<0HDU0101gKfH408]G
DP@0Mf]Y101gKfT;07M[I@@0Mf=F101gHe8406YD@`@0Kdm50`1kLg0407M_J@@0Mf=N101gLfT407][
J@@0KU1?101_Ed`306I<@P@0KeQ<101O>c8406=3>0@0HdLn101[CT<306m;AP@0OEeC101mJ5d806I<
@P@0Jdm5101WBd4306MC@@@0Idm510061`L403/Z9@@0ShjD:P1gMgTF0?ooo`00503ooolb07MgN@@0
MeM4101kGe<406I9@@<0HDU0101gKfH408]GDP@0Mf]Y101gKfT;07M[I@@0Mf=F101gHe8406YD@`@0
Kdm50`1kLg0407M_J@@0Mf=N101gLfT407][J@@0KU1?101_Ed`306I<@P@0KeQ<101O>c8406=3>0@0
HdLn101[CT<306m;AP@0OEeC101mJ5d806I<@P@0Jdm5101WBd4306MC@@@0Idm510061`L403/Z9@@0
ShjD:P1gMgTF0?ooo`00503ooolb07MgN@@0MeM4101kGe<406I9@@<0HDU0101gKfH408]GDP@0Mf]Y
101gKfT;07M[I@@0Mf=F101gHe8406YD@`@0Kdm50`1kLg0407M_J@@0Mf=N101gLfT407][J@@0KU1?
101_Ed`306I<@P@0KeQ<101O>c8406=3>0@0HdLn101[CT<306m;AP@0OEeC101mJ5d806I<@P@0Jdm5
101WBd4306MC@@@0Idm510061`L403/Z9@@0ShjD:P1gMgTF0?ooo`00503ooolb07MgN@@0MeM4101^
GeH404h/7`<0MfmS1026HVH407][H0@0Mg=Y101gKfT407MdM@L0Mf]U101gHeh407MWG@@0IU17101_
EdP307MfJ@@0MfMQ101gHeH407M_J@@0MfMQ101^F4/40656>P<0ITU0101SCdD406=8?P@0Je0h101S
@cP406]>@`<0NEYE101mJEd406mJC`@0IUM<101[ET/806=?A@<0Ie=7101_GED405Lk9`@0E2TO100_
8b0407MkORH0MgMi5P3oool001@0oooo<P1gMgT407MGA0@0KUmF101>;1l307M_H`@0QV9V101kJf04
07McJ@@0MfmY101gM7D707M[I@@0Mf=N101gIed406I@A`@0KeM80`1gMVT407MWH@@0Mf=F101gKfT4
07MWH@@0KUQ;101QASX306I9@0@0Hdm5101SB3h406]@>0@0Hd<h101[CT<307UJE@@0OFUM101_FTl4
06IGC0@0JeI;201SCdD306MCA`@0KeeE101G>bL405@Y7`@0;b<P101gNghV07MgNAH0oooo000D0?oo
oc80MgMi101gEd@406iOEP@0CR`O0`1gKf<408IRIP@0Nf]P101gLfT407M_J@@0MgAe1`1gJfD407MS
GP@0MfMM101VD4L406mGB0<0MgIY101gIf4407MSEP@0MfmY101gIf4406iHB`@0HDHj0`1VBD0406=?
A@@0HdPn101[D3P406=3>0@0Jdi30`1iFUD407eYG@@0KeY?101VEd`406]FB`P0Hdm50`1WDdL406mM
E@@0Ec/W101D:Al402lS80@0Mg]n9P1gMgTF0?ooo`00503oool^07MgN@@0MeM<101V<B<405HM7@@0
FSTb0`1[NGH407][H0@0Mg=P101gIfD407M_J@@0Mf]U0`1gIUh407M[I@@0Mf=N101^Ge8406iHC`@0
MfmS0`20Mfh407][H0@0KU1;101gIed407M=C`@0ITTh101Q?3D306=8?P@0Fd4h101WB38404lh;P@0
Gchh101cH5<307UQE@@0Mf9D101ZE4T406I@AP@0JdU0101[C48406M??P<0KdPn101_GE8406=2>P@0
Ke1:102len440=3Gg2H0MgMi5P3oool001@0oooo;P1gMgT407MGC0@0IS4S101F7Ad405Xi<P<0JgUf
101kJf0407McH0@0MfMU101gKfT407M[I@<0MfIN101gJfD407MSGP@0KUmB101^F4l407M_H`<0P7M^
101kJf0406i@B`@0MfMM101gCDl406I9>0@0HC`e0`1SB3h405]1>0@0IdPb101?>2h405ln>0@0Lf1C
0`1iHED407MRE0@0JUA9101VD4H406]9@0@0Jda2101WCch306m8?P@0KeeB101S@SX406m@BP@0_=OQ
103@em`V07MgNAH0oooo000D0?ooobh0MgMi101gEd`406Ha8`@0EQdM101J>C8306]iMP@0Nf]P101g
Lf0407MWI@@0MfmY101gJfD307MVGP@0Mf]U101gHeh406iODP@0KUQ?101gKf<3081gKP@0Nf]P101^
D4/407MWG@@0Mde?101VBCP4064l=@<0HdPn101K@CP406M8<P@0CcP^101O?SP407=PD`<0NF5E101g
HU@406YDB@@0IU16101[BD0406]<@P@0Idln0`1_B3h406mMDP@0Hd8j101_D4X40;cGh@@0d=OL9P1g
MgTF0?ooo`00503oool^07MgN@@0MeM<101V<B<405HM7@@0FSTb0`1[NGH407][H0@0Mg=P101gIfD4
07M_J@@0Mf]U0`1gIUh407M[I@@0Mf=N101^Ge8406iHC`@0MfmS0`20Mfh407][H0@0KU1;101gIed4
07M=C`@0ITTh101Q?3D306=8?P@0Fd4h101WB38404lh;P@0Gchh101cH5<307UQE@@0Mf9D101ZE4T4
06I@AP@0JdU0101[C48406M??P<0KdPn101_GE8406=2>P@0Ke1:102len440=3Gg2H0MgMi5P3oool0
01@0oooo;P1gMgT407M2?P@0IS4]101N;b`406MRD@<0PGY/102;KfT407M_K@@0MfMU101gKfT707M[
I@@0Mf=N101gHeH406iODP@0NeaB101cIe`307][J@@0Mfm]101gIfD407]cK0@0MeQ?101VE4@405i2
?0<0Fd@j101G?S@405]1=P@0Gd@n101lHeH407eXF`<0M69G101gGU@406YDB@@0IU16101[C48806]8
A@<0IdQ1101[HEd405/f:@@0Id]1102D]<<Z07MgNAH0oooo000D0?ooobh0MgMi101g@Sh406Ha;@@0
GRl/101WHU43085jK0@0RfmY101gKfd407MWI@@0MfmY1`1gJfD407MSGP@0Mf=F101^Ge8407]LDP@0
LfML0`1kJfT407M_K@@0MfMU101kLf`407MHC`@0IUA4101N@S`305]4>P@0Echd101K@CH405m4?P@0
O6=F101mJ5/307ARE`@0MeiD101ZE4T406I@AP@0Jda2201[B4D306M8@@@0Jf5M101K=RT406M;@@@0
U;C3:P1gMgTF0?ooo`00503oool^07MgN@@0Md8n101V<Bd405h_;0@0If9A0`21NV`408]_J@@0Mfm]
101gIfD407M_J@L0Mf]U101gHeh407MSEP@0KUmB101kG58407=WG0<0Nf]Y101gKfd407MWI@@0Ng=/
101gF4l406IDA0@0GT8l0`1KA3X405Ln=0@0Fd4f101OA3h407aSEP@0OFQK0`1dHUL407MNE0@0JUA9
101VD4H406]<@PP0JdQ50`1WB44406]QG@@0FcHY101WBd4409Bd`bX0MgMi5P3oool001@0oooo;P1g
MgT407M2?P@0IS4]101N;b`406MRD@<0PGY/102;KfT407M_K@@0MfMU101gKfT707M[I@@0Mf=N101g
HeH406iODP@0NeaB101cIe`307][J@@0Mfm]101gIfD407]cK0@0MeQ?101VE4@405i2?0<0Fd@j101G
?S@405]1=P@0Gd@n101lHeH407eXF`<0M69G101gGU@406YDB@@0IU16101[C48806]8A@<0IdQ1101[
HEd405/f:@@0Id]1102D]<<Z07MgNAH0oooo000D0?ooobX0MgMi101gGU8407M@?P@0ITHh101F@Bh4
06mWEP<0Rgia101kJfT407M_J@@0Mf]U101gIf4407MSGP<0KUa?101gHeH407M@DP@0KUQ?101cDd/4
06iOE@<0Nf]Y101gIeT407MSGP@0MfMQ101gD58406I3>P@0GT8j0`1OA3X406=7?0@0Ge16101_F4H4
07=MD@@0M5Y?0`1gGU@406mDB@@0JTe3101VD4H406]5?0@0JdPn101SBch306=C?P@0Kf5M101[@SL4
06]HC`@0Ig9n101bLWDV07MgNAH0oooo000D0?ooobX0MgMi101gGU8407M@?P@0ITHh101F@Bh406mW
EP<0Rgia101kJfT407M_J@@0Mf]U101gIf4407MSGP<0KUa?101gHeH407M@DP@0KUQ?101cDd/406iO
E@<0Nf]Y101gIeT407MSGP@0MfMQ101gD58406I3>P@0GT8j0`1OA3X406=7?0@0Ge16101_F4H407=M
D@@0M5Y?0`1gGU@406mDB@@0JTe3101VD4H406]5?0@0JdPn101SBch306=C?P@0Kf5M101[@SL406]H
C`@0Ig9n101bLWDV07MgNAH0oooo000D0?ooobX0MgMi101gGU8407M@?P@0ITHh101F@Bh406mWEP<0
Rgia101kJfT407M_J@@0Mf]U101gIf4407MSGP<0KUa?101gHeH407M@DP@0KUQ?101cDd/406iOE@<0
Nf]Y101gIeT407MSGP@0MfMQ101gD58406I3>P@0GT8j0`1OA3X406=7?0@0Ge16101_F4H407=MD@@0
M5Y?0`1gGU@406mDB@@0JTe3101VD4H406]5?0@0JdPn101SBch306=C?P@0Kf5M101[@SL406]HC`@0
Ig9n101bLWDV07MgNAH0oooo000D0?ooobX0MgMi101gGU8407M@?P@0ITHh101F@Bh406mWEP<0Rgia
101kJfT407M_J@@0Mf]U101gIf4407MSGP<0KUa?101gHeH407M@DP@0KUQ?101cDd/406iOE@<0Nf]Y
101gIeT407MSGP@0MfMQ101gD58406I3>P@0GT8j0`1OA3X406=7?0@0Ge16101_F4H407=MD@@0M5Y?
0`1gGU@406mDB@@0JTe3101VD4H406]5?0@0JdPn101SBch306=C?P@0Kf5M101[@SL406]HC`@0Ig9n
101bLWDV07MgNAH0oooo000D0?ooobX0MgMi101V?2P404hY8@@0:1/F1011;bL407e`IP<0QW]^101g
IfD407MWH@@0Mf=N101gHeH407MODP<0KUmB101cDe8406I@B0@0KU]B101cIe`407=[G`<0NfmS101g
If4407MWI@@0MfMQ101^Ge8406I=?P@0GTPn0`1OA3X406=7?0@0Jdi3101_DdL407UFE@@0M5Y?0`1_
Ed`406YKD@@0KeM<101VDdP406]CB0@0He=7101SBd4306M;A`@0KeeM101K9QT406]QE@@0Ic/b102;
TY@V07MgNAH0oooo000D0?ooobX0MgMi101V?2P404hY8@@0:1/F1011;bL407e`IP<0QW]^101gIfD4
07MWH@@0Mf=N101gHeH407MODP<0KUmB101cDe8406I@B0@0KU]B101cIe`407=[G`<0NfmS101gIf44
07MWI@@0MfMQ101^Ge8406I=?P@0GTPn0`1OA3X406=7?0@0Jdi3101_DdL407UFE@@0M5Y?0`1_Ed`4
06YKD@@0KeM<101VDdP406]CB0@0He=7101SBd4306M;A`@0KeeM101K9QT406]QE@@0Ic/b102;TY@V
07MgNAH0oooo000D0?ooobX0MgMi101V?2P404hY8@@0:1/F1011;bL407e`IP<0QW]^101gIfD407MW
H@@0Mf=N101gHeH407MODP<0KUmB101cDe8406I@B0@0KU]B101cIe`407=[G`<0NfmS101gIf4407MW
I@@0MfMQ101^Ge8406I=?P@0GTPn0`1OA3X406=7?0@0Jdi3101_DdL407UFE@@0M5Y?0`1_Ed`406YK
D@@0KeM<101VDdP406]CB0@0He=7101SBd4306M;A`@0KeeM101K9QT406]QE@@0Ic/b102;TY@V07Mg
NAH0oooo000D0?ooobX0MgMi101V?2P404hY8@@0:1/F1011;bL407e`IP<0QW]^101gIfD407MWH@@0
Mf=N101gHeH407MODP<0KUmB101cDe8406I@B0@0KU]B101cIe`407=[G`<0NfmS101gIf4407MWI@@0
MfMQ101^Ge8406I=?P@0GTPn0`1OA3X406=7?0@0Jdi3101_DdL407UFE@@0M5Y?0`1_Ed`406YKD@@0
KeM<101VDdP406]CB0@0He=7101SBd4306M;A`@0KeeM101K9QT406]QE@@0Ic/b102;TY@V07MgNAH0
oooo000D0?ooobX0MgMi101M9QL401H>2P@0;B4M100[7Qh408]gJ@<0P7=`101gIfD807MWF@@0MfMQ
101gIfD307M[J@@0Nf]Y101cFeD406m=B@@0HDe0101cG58307=SF@@0MfMU101gIf4407MWF@@0KU1;
101Q@3P405Hi?0<0Gd@d101K@CH406]>@`@0KeY>101_CdD406ICAP<0Ke1<101VBD0406I=@`@0GTU0
201SC48406M8?P<0Id]7101WDdD405<f8P@0He91101S=S<408^b`BH0MgMi5P3oool001@0oooo:P1g
MgT405dV5`@05Ph:100]8Ad402/N7P@0RgMY0`20Lg0407MWI@P0MfMI101gIf4407MWI@<0Mf]Y101k
JfT407=KE@@0Kde9101QCD0407=LDP<0Lf=I101gIfD407MWH@@0MfMI101^D4/40650>0@0ESTl0`1O
A3@405]1=P@0Jdi3101_FTh406m?A@@0IU=60`1_D4`406I9@0@0ITe3101NBD0806=<@P@0IdPn0`1W
BdL406MCA@@0DcHR101SDT4406<f<`@0Rk;19P1gMgTF0?ooo`00503ooolZ07MgN@@0GBHG100F3PX4
02dQ7@@0:ahN102;MfT3081cL0@0MfMU201gIeT407MWH@@0MfMU0`1gJfT407][J@@0Le]E101_CDT4
065=@0@0LeaB0`1cHeT407MWI@@0MfMQ101gIeT406i@B`@0HD0h101F>C`305m4=0@0Fd4f101[CT<4
06mJCP@0Kdm5101VDdH306m@C0@0ITU0101VCD<405i9@0P0Hda2101WB3h306M;A`@0Ie=5101C=R84
06=B@@@0HcHc102;//4V07MgNAH0oooo000D0?ooobX0MgMi101M9QL401H>2P@0;B4M100[7Qh408]g
J@<0P7=`101gIfD807MWF@@0MfMQ101gIfD307M[J@@0Nf]Y101cFeD406m=B@@0HDe0101cG58307=S
F@@0MfMU101gIf4407MWF@@0KU1;101Q@3P405Hi?0<0Gd@d101K@CH406]>@`@0KeY>101_CdD406IC
AP<0Ke1<101VBD0406I=@`@0GTU0201SC48406M8?P<0Id]7101WDdD405<f8P@0He91101S=S<408^b
`BH0MgMi5P3oool001@0oooo9P1gMgT407MWH@@0ISH]1015;RL403LU7P@0<24O102`S7D3081cI`@0
KUmB101gIf4407MWG@@0GDU1101MBCh704La:0@0Ac4]101B=3D406I<@0@0Jda20`1ZEdh407][J@P0
MfMQ101^D4l40656>P@0Fd4b0`1S@bh405]7?P@0IdXn101GBd4405=5?0@0Hdm50`1[FTl405i<@0@0
JeI;101[DdP806M?A@@0IdPn0`1WBdL406MCA@@0>b4I101271H406<j;@@0Rk:m9P1gMgTF0?ooo`00
503ooolV07MgN@@0MfMQ101V=Rd404D^9`@0=bDN100`8Al40;2<M@<0P7=W101^Ge8407MWH@@0MfMM
101MBD4405e9?PL0Ac4X1017<Bd4058d=@@0ITa0101[C48306YGCP@0Nf]Y201gIf4406i@C`@0HDHj
101K@C8306=3;P@0FdLn101WBSh405M;@@@0DdDl101SCdD306]JC`@0GTa0101[ET/406]CB0P0Idm5
101WB3h306M;A`@0Ie=5100k8AT4048L5P@0HcX]102;/[dV07MgNAH0oooo000D0?ooobH0MgMi101g
If4406Hf;@@0ABhW100g9Ah4030Q7`@0/8ae0`20LfL406iODP@0MfMQ101gIed405e9@@@0GDTn1`17
<BP404La;@@0DS@e101VC40406]<@P<0JUM>101kJfT807MWH@@0KU1?101QASX405]1<P<0Hd<^101K
Ach406M:?P@0Ed]1101CAC`406=?A@<0JeY?101NC40406]FB`@0Je=8201WCdD406M8?P<0Id]7101W
DdD403/Q6@@0@Q`F101S>Rd408^b_BH0MgMi5P3oool001@0oooo9P1gMgT406i9>@@0IS`f10050`84
00d<30@081TG102kUWh307M[G`@0MemF101kJf0407MWF@@0KUQ?101C@SX303ha:@@092@U100G5aP4
02XK4P@0C3HY1`0n71D407MSF0P0MfMQ101^F4/40656>P@0Fd4b0`1KCSP405<m=0@0KeE:101cGE44
07QJCP@0N5=70`1WB4D405=2>P@0KeI;101[DdP406=<@PP0EdPn0`1WDdL406MCA@@0@RDM101F:Al4
07M0<P@0SkO:9P1gMgTF0?ooo`00503ooolV07MgN@@0KTTi101V?3H400D30P@03@`<100P6AL40;^F
OP<0Mf]O101gGeH407][H0@0MfMI101^F4l405=2>P<0?S4Y100T92D401LG60@0:Q/B101<=RT703hL
5@@0Mf=H201gIf4406iHB`@0HDHj101K@C8305]>>0@0Dcdd101_EDX407=MD@@0N5Y>101hDdL306M8
A@@0Dd8j101_ET/406]CB0@0Hda2201GB3h306MCA`@0Ie=510129Ad405HY7`@0Md0b102?]lXV07Mg
NAH0oooo000D0?ooobH0MgMi101^BCT406Hl=P@01@<2100=30`4020I5`@0^iIn0`1gJel407MOEP@0
Nf]P101gIeT406iHC`@0Dd8j0`0n<BT402@T9@@05aLH100Z6a8404`f:@L0?Q`E101gHeP807MWH@@0
KUQ;101QASX405]1<P<0Fdhh101C?C@406mEBP@0LeeA101hFTh407QCA`<0IdQ5101C@SX406mFB`@0
Je=8101SC48805M8?P<0Ie=7101WDdD4048U7@@0ERTO101g@38408ngbRH0MgMi5P3oool001@0oooo
9P1gMgT406i9>@@0IS`f10050`8400d<30@081TG102kUWh307M[G`@0MemF101kJf0407MWF@@0KUQ?
101C@SX303ha:@@092@U100G5aP402XK4P@0C3HY1`0n71D407MSF0P0MfMQ101^F4/40656>P@0Fd4b
0`1KCSP405<m=0@0KeE:101cGE4407QJCP@0N5=70`1WB4D405=2>P@0KeI;101[DdP406=<@PP0EdPn
0`1WDdL406MCA@@0@RDM101F:Al407M0<P@0SkO:9P1gMgTF0?ooo`00503ooolS07MgN@<0P7n2101g
BCT4064l=@@05Q<C100O5A44030H50@0cZR>0`1kKf<407=SF@@0Mf]P101gIed407MWI@@0HDU00`2;
JF@4038X8`@07a8?100_6A4403Pc<P@0EcDZ0`25Je/409VIQ`@0NgMd101gN7T406iODP@0HD<j101;
=B`305<j;@@090T7101SASX405Lk9`@0AC<[100b8a`305=1>0@0Ed/n101_Dd4806=<@P@0Ed4h101O
Bd4306m;A`@0Ed4h100_71T405<c:0@0O5=<102IbmXV07MgNAH0oooo000D0?ooob<0MgMi0`20Oh84
07M9>@@0HC`e100F4a<401lE4@@0<1PD103>Z8h307]_H`@0Lf=I101gJf0407MWG@@0MfMU101QBD03
08]YI0@0<RPS100O4Pl402lI4@@0>3<b101G=BX308E[F`@0VIV7101kMg@407MhN@@0KUmB101Q@cX4
04/e;0<0DcX]100T2@L406=6>P@0Ec/W1015<b/4038S70<0Dd4h101GBch406mC@@P0Hda2101G@CP4
05m;@@<0Kd]7101G@CP402lL6@@0Dc<X101lDd`409W;fRH0MgMi5P3oool001@0oooo8`1gMgT3081o
PP@0MdTi101Q?3D401HC4`@07aDA100`61@40<jXSP<0NfmS101cHeT407M[H0@0MfMM101gIfD40659
@0<0RfUT100b:2<401lB3`@0;aTA100h<c8405Le:P<0QF]K102IVHL407]gM0@0MgQi101^Ge840653
>P@0BcD/0`1C>Rd402@91`@0HdHj101G>bL404Dc:`@0<R<L0`1C@CP405M;?P@0Ke=1201SC48405M1
>0@0Gd]10`1_BdL405M1>0@0;a`I101C<bP407aCC0@0VL_J9P1gMgTF0?ooo`00503ooolS07MgN@<0
P7n2101gBCT4064l=@@05Q<C100O5A44030H50@0cZR>0`1kKf<407=SF@@0Mf]P101gIed407MWI@@0
HDU00`2;JF@4038X8`@07a8?100_6A4403Pc<P@0EcDZ0`25Je/409VIQ`@0NgMd101gN7T406iODP@0
HD<j101;=B`305<j;@@090T7101SASX405Lk9`@0AC<[100b8a`305=1>0@0Ed/n101_Dd4806=<@P@0
Ed4h101OBd4306m;A`@0Ed4h100_71T405<c:0@0O5=<102IbmXV07MgNAH0oooo000D0?ooo`@0Mfma
101gMgT407M_LAL0MgMi0`060004064^8@@0IU17100W7QX401LD6P@07a<@103:[94307=SF@@0MfMM
101cHeT406iOEP@0MfMU101^Ge8307AJC`@0FTHj102BJ5H408aH?@@0Q5Hm102FJ4d308]ZF`@0OFiQ
101kLg0407M[I@@0KU12101Q@3P405/k;0<0Fcld101<;BD4061JE`@092HW10020`@402lN6P<0=c<]
100G4a0403//:@@0>bXO101O>b`405M8?P@0Gdi30`1_Bd44048h;0@081LC100j9Ql408EUEP@0U;g8
0`1bLWDS07MgNAH0oooo000D0?ooo`@0Mfma101gMgT407M_LAL0MgMi0`060004064^8@@0IU17100W
7QX401LD6P@07a<@103:[94307=SF@@0MfMM101cHeT406iOEP@0MfMU101^Ge8307AJC`@0FTHj102B
J5H408aH?@@0Q5Hm102FJ4d308]ZF`@0OFiQ101kLg0407M[I@@0KU12101Q@3P405/k;0<0Fcld101<
;BD4061JE`@092HW10020`@402lN6P<0=c<]100G4a0403//:@@0>bXO101O>b`405M8?P@0Gdi30`1_
Bd44048h;0@081LC100j9Ql408EUEP@0U;g80`1bLWDS07MgNAH0oooo000D0?ooo`@0Mfma101gMgT4
07M_LAL0MgMi0`060004064^8@@0IU17100W7QX401LD6P@07a<@103:[94307=SF@@0MfMM101cHeT4
06iOEP@0MfMU101^Ge8307AJC`@0FTHj102BJ5H408aH?@@0Q5Hm102FJ4d308]ZF`@0OFiQ101kLg04
07M[I@@0KU12101Q@3P405/k;0<0Fcld101<;BD4061JE`@092HW10020`@402lN6P<0=c<]100G4a04
03//:@@0>bXO101O>b`405M8?P@0Gdi30`1_Bd44048h;0@081LC100j9Ql408EUEP@0U;g80`1bLWDS
07MgNAH0oooo000D0?ooo`@0Mfma101gMgT407M_LAL0MgMi0`060004064^8@@0IU17100W7QX401LD
6P@07a<@103:[94307=SF@@0MfMM101cHeT406iOEP@0MfMU101^Ge8307AJC`@0FTHj102BJ5H408aH
?@@0Q5Hm102FJ4d308]ZF`@0OFiQ101kLg0407M[I@@0KU12101Q@3P405/k;0<0Fcld101<;BD4061J
E`@092HW10020`@402lN6P<0=c<]100G4a0403//:@@0>bXO101O>b`405M8?P@0Gdi30`1_Bd44048h
;0@081LC100j9Ql408EUEP@0U;g80`1bLWDS07MgNAH0oooo000D0?ooo`@0Mg=e101gNgh407MgN@<0
Mg]n401gMgT400P10@<01P41100R1`<401lH5@@01@H<100?3`d402XG4P@0f;2D0`1cHeT407][J@@0
GCHe101QASh407][J@@0MfmY0`1kJfT407MNF`@0Kdm5101_ET/407aKD@@0Qf]I0`21IEd407MZGP@0
NgMd101gJfD406i=B0@0HE17101K@C8305]@>P@0JdHd101lIEH406m6=P@03P/<100o81H3038W9@@0
8QTG101P?Bh406Y4=P@0P69?101SBT4405m;@@<0Ke=1100K5QH401dF4@@0=ahG1028@34408JT]0<0
LW9e8`1gMgTF0?ooo`00503oool407McM@@0Mg]n101gMgT307MkOQ00MgMi10080@4300H10@@08PL3
100O61D400D630@03`l=100Z5a840=R`U0<0Lf=I101kJfT405df=@@0HDHn101kJfT407M_J@<0Nf]Y
101gGU/406m?A@@0KeI;101lFe4408M[F@<0PFEM101gJUh407]gM0@0Mf]U101^CDP4065@A`@0Fd4b
0`1KD3X406]6=0@0O6EF101_ASH400h;30@0?b0F0`0b9bD4028I5`@0H3d^101ZA3H4081RC`@0HdY1
101OBd4306mC@@@06aHF100M5Q4403LN5`@0R40a1026Y;@3079bMB<0MgMi5P3oool001@0oooo101g
LgD407MkOP@0MgMi0`1gNgh@07MgN@@020410`060@4402870`@07aPE10051P`400l?3@@0:QLB103H
/9@307=SF@@0Nf]Y101M=SD40656?P@0Nf]Y101gKfT307][J@@0MeiK101_CdD406mFB`@0O5]A1027
JeT3085UG@@0MfYN101kMg@407M[I@@0KTe8101QD4L405]1<P<0Fe0j101[AS@407aUEP@0KdHf100>
2``403lP5P<0<RLU100R6AL4060m;P@0JT@f1020HTl406=:@@@0Gd]10`1_Dd4401/F5P@07AHA100g
7QL408Q0<@@0QZBd0`1bLWDS07MgNAH0oooo000D0?ooo`@0Mg=e101gNgh407MgN@<0Mg]n401gMgT4
00P10@<01P41100R1`<401lH5@@01@H<100?3`d402XG4P@0f;2D0`1cHeT407][J@@0GCHe101QASh4
07][J@@0MfmY0`1kJfT407MNF`@0Kdm5101_ET/407aKD@@0Qf]I0`21IEd407MZGP@0NgMd101gJfD4
06i=B0@0HE17101K@C8305]@>P@0JdHd101lIEH406m6=P@03P/<100o81H3038W9@@08QTG101P?Bh4
06Y4=P@0P69?101SBT4405m;@@<0Ke=1100K5QH401dF4@@0=ahG1028@34408JT]0<0LW9e8`1gMgTF
0?ooo`00503oool807MkOQL0MgMi10080@43034R6@@0;ALD100Y81`400X82@@0:QPC100b61@40<jR
Q`<0Nf=I101cHeT407MWH@@0Jf5B101;<b/404La:0<0>RTQ100X7A/4024G50@0;24I100h8a`403hU
7@<0IUM?101cJel407]_K0@0Mf=F101^CD84065DA`@0Fc`c0`1S@C8405m;>0@0JeQ8101WCdD406mH
C0@0YfeE0`1bASH406]0;`@0WF9>1025G44406=CB0@0Idm1101[EDX305m;@@@0514?100P514403/O
60@0OC0S102?`<lV07MgNAH0oooo000D0?ooo`P0Mg]n5`1gMgT400P10@<0<B8I100]5a@402TP70@0
2PP9100Z61<4038H50@0cZ:70`1kHeT407=SF@@0MfMQ101[HE8404/c:`@0Ac4X0`0j:B4402PM6`@0
8ALD100/8AT403PS70@0?RDM0`1VEdl407=[G`@0Nfm/101gHeH406i=@P@0HEA7101K?3<306=1<P@0
Gd/h101[F4P406M?A@@0KeQ<102WKED30796=P@0Jd0_102MHTh408EL@@@0He=8101WCd4406]EBP<0
Gd]1100D4@l4020D4@@0>alH101m<2<408o0cbH0MgMi5P3oool001@0oooo201gNghG07MgN@@02041
0`0a8QT402dG50@0:B0L100:20T402XH4`@0<QPD103>XXL307]SF@@0Lf=I101gIf4406]QDP@0Bc<[
1017<BP303XY8@@0:1dK100Q5a@402`Q6@@0>2<L100n9Ad306IGC`@0Lf]O101kKf`407MSEP@0KTe2
101QE4L405/l<`<0Hd4b101OBcP406]HB0@0Idm5101_F4`40:M]E@<0LTHf101[@2l409eRCP@0QEa1
101SDdP406M?@@@0JeE:0`1OBd4401@A3`@081@A100k7aP407d`8`@0Sl3?9P1gMgTF0?ooo`00503o
ool807MkOQL0MgMi10080@43034R6@@0;ALD100Y81`400X82@@0:QPC100b61@40<jRQ`<0Nf=I101c
HeT407MWH@@0Jf5B101;<b/404La:0<0>RTQ100X7A/4024G50@0;24I100h8a`403hU7@<0IUM?101c
Jel407]_K0@0Mf=F101^CD84065DA`@0Fc`c0`1S@C8405m;>0@0JeQ8101WCdD406mHC0@0YfeE0`1b
ASH406]0;`@0WF9>1025G44406=CB0@0Idm1101[EDX305m;@@@0514?100P514403/O60@0OC0S102?
`<lV07MgNAH0oooo000D0?oooal0MgMi100<0`4301/>2P@05A4?100K4`l401dB3`@07AD@100c9b@4
0;:=M0<0NfML101gJf0407][J@@0MfMQ101mKf<407ACC`<0B453101hD4`407=;?0@0NeY9101^BC`4
08UUEP<0VI601026Mg@407][J@@0Me1B101^F4l4065DB@@0FcHj0`0h7aP403PQ6P@0Gd/h101WCd44
06M??P@0Kdm50`1_ED<406]IC@@0O69=101KCT<406M;C0@0Gd]1101WCd43048e;0@01`T9100E4@l4
09MPB`@0Jc0S102Jc]`V07MgNAH0oooo000D0?oooal0MgMi100<0`4301/>2P@05A4?100K4`l401dB
3`@07AD@100c9b@40;:=M0<0NfML101gJf0407][J@@0MfMQ101mKf<407ACC`<0B453101hD4`407=;
?0@0NeY9101^BC`408UUEP<0VI601026Mg@407][J@@0Me1B101^F4l4065DB@@0FcHj0`0h7aP403PQ
6P@0Gd/h101WCd4406M??P@0Kdm50`1_ED<406]IC@@0O69=101KCT<406M;C0@0Gd]1101WCd43048e
;0@01`T9100E4@l409MPB`@0Jc0S102Jc]`V07MgNAH0oooo000D0?oooal0MgMi100<0`4301/>2P@0
5A4?100K4`l401dB3`@07AD@100c9b@40;:=M0<0NfML101gJf0407][J@@0MfMQ101mKf<407ACC`<0
B453101hD4`407=;?0@0NeY9101^BC`408UUEP<0VI601026Mg@407][J@@0Me1B101^F4l4065DB@@0
FcHj0`0h7aP403PQ6P@0Gd/h101WCd4406M??P@0Kdm50`1_ED<406]IC@@0O69=101KCT<406M;C0@0
Gd]1101WCd43048e;0@01`T9100E4@l409MPB`@0Jc0S102Jc]`V07MgNAH0oooo000D0?oooal0MgMi
100<0`4301/>2P@05A4?100K4`l401dB3`@07AD@100c9b@40;:=M0<0NfML101gJf0407][J@@0MfMQ
101mKf<407ACC`<0B453101hD4`407=;?0@0NeY9101^BC`408UUEP<0VI601026Mg@407][J@@0Me1B
101^F4l4065DB@@0FcHj0`0h7aP403PQ6P@0Gd/h101WCd4406M??P@0Kdm50`1_ED<406]IC@@0O69=
101KCT<406M;C0@0Gd]1101WCd43048e;0@01`T9100E4@l409MPB`@0Jc0S102Jc]`V07MgNAH0oooo
000D0?ooo`P0MgMi101gKg4C07MgN@@04PH40`0O3PX401lD40@06a<@100=1PL401lC40@0>BTU102?
J5@307eWF`@0Mf]P101gIfD807M_J@@0Ng=`0`2;S8<40:>DQ`@0Rhb3102DU8l409B@R`@0VXio0`1m
MVT407]cL0P0KUmB101^He8406YGCP@0M5iD0`1[F4L404@[:`@0:b4J100G4Q4404P_:@@0Idm70`1S
Cch406M?@@@0Gd]1101O@CX404ln=0@0Id]5101_Bd4301/D4P@03P/:100/8al408A3<@@0@Q`D100R
9RDV07MgNAH0oooo000D0?ooo`P0MgMi101gKg4C07MgN@@04PH40`0O3PX401lD40@06a<@100=1PL4
01lC40@0>BTU102?J5@307eWF`@0Mf]P101gIfD807M_J@@0Ng=`0`2;S8<40:>DQ`@0Rhb3102DU8l4
09B@R`@0VXio0`1mMVT407]cL0P0KUmB101^He8406YGCP@0M5iD0`1[F4L404@[:`@0:b4J100G4Q44
04P_:@@0Idm70`1SCch406M?@@@0Gd]1101O@CX404ln=0@0Id]5101_Bd4301/D4P@03P/:100/8al4
08A3<@@0@Q`D100R9RDV07MgNAH0oooo000D0?ooo`P0MgMi101gKg4C07MgN@@04PH40`0O3PX401lD
40@06a<@100=1PL401lC40@0>BTU102?J5@307eWF`@0Mf]P101gIfD807M_J@@0Ng=`0`2;S8<40:>D
Q`@0Rhb3102DU8l409B@R`@0VXio0`1mMVT407]cL0P0KUmB101^He8406YGCP@0M5iD0`1[F4L404@[
:`@0:b4J100G4Q4404P_:@@0Idm70`1SCch406M?@@@0Gd]1101O@CX404ln=0@0Id]5101_Bd4301/D
4P@03P/:100/8al408A3<@@0@Q`D100R9RDV07MgNAH0oooo000D0?ooo``0MgMi0`1gNgh@07MgN@@0
30H60`0P6AL401hD40@07a<@100F3`/402DF4@@0=bTU102?H4`308]bI0@0NfmS101gIfD407M_J@@0
Mf]U2`1gM7D407M[I@@0MgAe201gJfD307MWG@@0Nf]P101gHeH407=LDP@0Le=;101cGeD407MSF0<0
Me]H101_GEX408UREP@0FT8j100k9Ad401/G4P<0:Q`I100U9B@403DU7`@0>bLO101[CTX407Q@AP@0
Gd@h0`0=2`/401L@3P@09API100W3@X402`A30@0:Bd/0`3;dmPS07MgNAH0oooo000D0?ooo``0MgMi
0`1gNgh@07MgN@@030H60`0P6AL401hD40@07a<@100F3`/402DF4@@0=bTU102?H4`308]bI0@0NfmS
101gIfD407M_J@@0Mf]U2`1gM7D407M[I@@0MgAe201gJfD307MWG@@0Nf]P101gHeH407=LDP@0Le=;
101cGeD407MSF0<0Me]H101_GEX408UREP@0FT8j100k9Ad401/G4P<0:Q`I100U9B@403DU7`@0>bLO
101[CTX407Q@AP@0Gd@h0`0=2`/401L@3P@09API100W3@X402`A30@0:Bd/0`3;dmPS07MgNAH0oooo
000D0?ooo``0MgMi0`1gNgh@07MgN@@030H60`0P6AL401hD40@07a<@100F3`/402DF4@@0=bTU102?
H4`308]bI0@0NfmS101gIfD407M_J@@0Mf]U2`1gM7D407M[I@@0MgAe201gJfD307MWG@@0Nf]P101g
HeH407=LDP@0Le=;101cGeD407MSF0<0Me]H101_GEX408UREP@0FT8j100k9Ad401/G4P<0:Q`I100U
9B@403DU7`@0>bLO101[CTX407Q@AP@0Gd@h0`0=2`/401L@3P@09API100W3@X402`A30@0:Bd/0`3;
dmPS07MgNAH0oooo000D0?ooo``0MgMi0`1gNgh@07MgN@@030H60`0P6AL401hD40@07a<@100F3`/4
02DF4@@0=bTU102?H4`308]bI0@0NfmS101gIfD407M_J@@0Mf]U2`1gM7D407M[I@@0MgAe201gJfD3
07MWG@@0Nf]P101gHeH407=LDP@0Le=;101cGeD407MSF0<0Me]H101_GEX408UREP@0FT8j100k9Ad4
01/G4P<0:Q`I100U9B@403DU7`@0>bLO101[CTX407Q@AP@0Gd@h0`0=2`/401L@3P@09API100W3@X4
02`A30@0:Bd/0`3;dmPS07MgNAH0oooo000D0?oooal0MgMi100B2@P303/Y9@@0618?200O4a0402PI
6P@0=bTU101bD3h307QTF0@0NfmS101gIed407MWH@P0Mf]U2`1gKfd407MdM@@0MfIN1`1gJfD807MW
G@@0KUQ?101cGeD407=KD@@0LemE0`1cEeD406YKCP@0JeM9101WDdD407=IBP@0M5Q70`1ZA3@405Tn
;`@0Odho101cG4l407a>C`@0Ed/n1018?S@300h<30@07A<?100J4a0401@>2P@09aTE100e<c430<K>
db<0MgMi5P3oool001@0oooo7`1gMgT4018920<0>bTU100H4Pl801lC40@0:1TJ100g:BD4079@?P<0
N6AH101kKf<407MWG@@0MfMQ201gJfD;07M_K@@0MgAe101gIUh707M[I@P0MfMM101^F4l407=OE@@0
Le]A101cGeD307=GE@@0JU]>101[EdT406MCA@@0LeU:101dF4L306Y4=0@0FCh_101oCSl407=LC`@0
O4i?101GBch404Pn=0<03P`<100M4`l401XC40@050h:100W6AD403Dc<@<0a/kC8`1gMgTF0?ooo`00
503ooolO07MgN@@04PT80`0k:BD401PB3`P07a<@100X6AX403LY9@@0LU0n0`1hI5P407]_H`@0MfMM
101gIf4807M[I@/0Mfm]101gM7D407MVGPL0Mf]U201gIed406iHC`@0LemE101cFe4407=OE@<0LeME
101ZFdh406]GB@@0Ie=5101cFDX407AHA`<0JT@d101I?Rl407m>?`@0Lea?101lCTl405M;?P@0B3hd
0`0>30`401dC3`@06Q<@100D3PX402LI5@@0=C<a0`36c]<S07MgNAH0oooo000D0?oooal0MgMi100B
2@P303/Y9@@0618?200O4a0402PI6P@0=bTU101bD3h307QTF0@0NfmS101gIed407MWH@P0Mf]U2`1g
Kfd407MdM@@0MfIN1`1gJfD807MWG@@0KUQ?101cGeD407=KD@@0LemE0`1cEeD406YKCP@0JeM9101W
DdD407=IBP@0M5Q70`1ZA3@405Tn;`@0Odho101cG4l407a>C`@0Ed/n1018?S@300h<30@07A<?100J
4a0401@>2P@09aTE100e<c430<K>db<0MgMi5P3oool001@0oooo7`1gMgT4018610<0:adE100P61D4
024C40@09@l;100Z61@403DR60@0BSD[0`1lFdl407e_H`@0MfMM101gIfD407M_J@@0MgAe0`1gJfD<
07M_K@@0MfIN101gJfD307MSEP@0Mf=N101gGeH406i@B0P0LemE101cFe4307=GCP@0JUA7101_CD<4
06]@AP@0Idm5101hFTh307QHC0@0P69D1020FDd406m@C0@0Kd]1101SBSX403DS6P<04`d=100M4`l4
02XH50@06a<@100R510403<R6@<0Qg=h8`1gMgTF0?ooo`00503ooolO07MgN@@04PH40`0[7AD4020H
5@@08A<@100U3`/402XH50@0=B8H101:=B/307aKC`@0OFmS101gIed407MWI@@0MfmY101gM7D307M[
I@`0Mfm]101gIUh407M[I@<0Mf=F101gHeh407MOEP@0KU18201cGeD407=KD@<0LeM>101ZE4L406m=
@`@0Je16101WCdD407QJCP<0N5Q<1020HU@4081IC@@0Ke1<101_Bd4406=:>P@0=B<J0`0C3@d401dC
3`@0:QPD100K4a04028D40@0<b8I0`27LgPS07MgNAH0oooo000D0?oooal0MgMi100B1P@302/M5@@0
81PE100Q4a0402D?2`@0:QPD100e8QP404Xe:`<0O5]?101mKf<407MWG@@0MfMU101gKfT407MdM@<0
Mf]U301gKfd407MVGP@0Mf]U0`1gHeH407MSGP@0MemF101^D4P807=OE@@0Le]A0`1cEdh406YDA`@0
Kde3101[D4H406M?A@@0N5Y>0`1hF4`4081RE0@0P5U=101_D4`406m;@@@0HdXj100e8aX301<=3@@0
7A<?100Z61@401/C40@08Q@@100c8QT308McN2<0MgMi5P3oool001@0oooo7`1gMgT4018610<0:adE
100P61D4024C40@09@l;100Z61@403DR60@0BSD[0`1lFdl407e_H`@0MfMM101gIfD407M_J@@0MgAe
0`1gJfD<07M_K@@0MfIN101gJfD307MSEP@0Mf=N101gGeH406i@B0P0LemE101cFe4307=GCP@0JUA7
101_CD<406]@AP@0Idm5101hFTh307QHC0@0P69D1020FDd406m@C0@0Kd]1101SBSX403DS6P<04`d=
100M4`l402XH50@06a<@100R510403<R6@<0Qg=h8`1gMgTF0?ooo`00503ooolO07MgN@@030@20`0a
:BL402@J60@09aHC100E3`/401hD40@07A<?100k9Ad305`k:0@0PFiQ101kJf0407MWI@@0MfmY101g
M7D307M_K@@0Mf]U101gKfd807MVGP@0Mf]U0`1gHeH407MWG@@0KUQ;101^G58407=KD@P0LeM>0`1c
Fe4406YDB@@0IU16101VDdP406]JC`@0Idm50`1[C48406M?A@@0EdPn101GBd4405M;?P@0@SP^100A
4a<300/;2@@08QLI100E3a0401<>2P@03@H7100Z61@306YCD0@0U:2R7`1gMgTF0?ooo`00503ooolO
07MgN@@030@20`0a:BL402@J60@09aHC100E3`/401hD40@07A<?100k9Ad305`k:0@0PFiQ101kJf04
07MWI@@0MfmY101gM7D307M_K@@0Mf]U101gKfd807MVGP@0Mf]U0`1gHeH407MWG@@0KUQ;101^G584
07=KD@P0LeM>0`1cFe4406YDB@@0IU16101VDdP406]JC`@0Idm50`1[C48406M?A@@0EdPn101GBd44
05M;?P@0@SP^100A4a<300/;2@@08QLI100E3a0401<>2P@03@H7100Z61@306YCD0@0U:2R7`1gMgTF
0?ooo`00503ooolO07MgN@@030@20`0a:BL402@J60@09aHC100E3`/401hD40@07A<?100k9Ad305`k
:0@0PFiQ101kJf0407MWI@@0MfmY101gM7D307M_K@@0Mf]U101gKfd807MVGP@0Mf]U0`1gHeH407MW
G@@0KUQ;101^G58407=KD@P0LeM>0`1cFe4406YDB@@0IU16101VDdP406]JC`@0Idm50`1[C48406M?
A@@0EdPn101GBd4405M;?P@0@SP^100A4a<300/;2@@08QLI100E3a0401<>2P@03@H7100Z61@306YC
D0@0U:2R7`1gMgTF0?ooo`00503ooolO07MgN@@030@20`0a:BL402@J60@09aHC100E3`/401hD40@0
7A<?100k9Ad305`k:0@0PFiQ101kJf0407MWI@@0MfmY101gM7D307M_K@@0Mf]U101gKfd807MVGP@0
Mf]U0`1gHeH407MWG@@0KUQ;101^G58407=KD@P0LeM>0`1cFe4406YDB@@0IU16101VDdP406]JC`@0
Idm50`1[C48406M?A@@0EdPn101GBd4405M;?P@0@SP^100A4a<300/;2@@08QLI100E3a0401<>2P@0
3@H7100Z61@306YCD0@0U:2R7`1gMgTF0?ooo`00503ooolO07MgN@@04PH40`0_9B<402dR7`@09a/H
100W5a@4028D40@0:QdI100n;b/304De;0@0RFYN101kIe`407MWI@@0MfMQ101gJfD707M_K@@0MgAe
101gIUh807M[I@<0Mf=N101^GeH406iHC`P0LeM>101cFe4406YKD@L0JUA9101VD4H806]CB0@0Je16
0`1WCdD406=?A@@0EdPn101_Bd4405m4>P@0;b<O100E3Ph302DJ5`@04P/;100D3Pl400h71`@05`l@
100U5Q4305m?B`@0Z;Nm7`1gMgTF0?ooo`00503ooolO07MgN@@04PH40`0_9B<402dR7`@09a/H100W
5a@4028D40@0:QdI100n;b/304De;0@0RFYN101kIe`407MWI@@0MfMQ101gJfD707M_K@@0MgAe101g
IUh807M[I@<0Mf=N101^GeH406iHC`P0LeM>101cFe4406YKD@L0JUA9101VD4H806]CB0@0Je160`1W
CdD406=?A@@0EdPn101_Bd4405m4>P@0;b<O100E3Ph302DJ5`@04P/;100D3Pl400h71`@05`l@100U
5Q4305m?B`@0Z;Nm7`1gMgTF0?ooo`00503ooolO07MgN@@04PH40`0_9B<402dR7`@09a/H100W5a@4
028D40@0:QdI100n;b/304De;0@0RFYN101kIe`407MWI@@0MfMQ101gJfD707M_K@@0MgAe101gIUh8
07M[I@<0Mf=N101^GeH406iHC`P0LeM>101cFe4406YKD@L0JUA9101VD4H806]CB0@0Je160`1WCdD4
06=?A@@0EdPn101_Bd4405m4>P@0;b<O100E3Ph302DJ5`@04P/;100D3Pl400h71`@05`l@100U5Q43
05m?B`@0Z;Nm7`1gMgTF0?ooo`00503ooolO07MgN@@04PH40`0_9B<402dR7`@09a/H100W5a@4028D
40@0:QdI100n;b/304De;0@0RFYN101kIe`407MWI@@0MfMQ101gJfD707M_K@@0MgAe101gIUh807M[
I@<0Mf=N101^GeH406iHC`P0LeM>101cFe4406YKD@L0JUA9101VD4H806]CB0@0Je160`1WCdD406=?
A@@0EdPn101_Bd4405m4>P@0;b<O100E3Ph302DJ5`@04P/;100D3Pl400h71`@05`l@100U5Q4305m?
B`@0Z;Nm7`1gMgTF0?ooo`00503ooolO07MgN@@03`T80`0a:BL403DY9@@0;b<P100W5Q<401<>2P@0
:QPD10109Qd305di:@@0R50j101mJUh407M[H0P0MfMQ0`1gJfD<07M_K@P0Mf]U0`1gHeh407MWF@@0
LeaB101ZEdh406YDB@@0LeAA101ZE4T306m=@`@0Ke1<101VD4H406]CB0@0Jda21`1SC48405m1>0@0
IdPn101O?S@403D/:@@081LC100K4Q0301<>2P@04`h?100C2`/401L?2`@06A4A100^6A@30>CZkP@0
/[c17`1gMgTF0?ooo`00503ooolO07MgN@@03`T80`0a:BL403DY9@@0;b<P100W5Q<401<>2P@0:QPD
10109Qd305di:@@0R50j101mJUh407M[H0P0MfMQ0`1gJfD<07M_K@P0Mf]U0`1gHeh407MWF@@0LeaB
101ZEdh406YDB@@0LeAA101ZE4T306m=@`@0Ke1<101VD4H406]CB0@0Jda21`1SC48405m1>0@0IdPn
101O?S@403D/:@@081LC100K4Q0301<>2P@04`h?100C2`/401L?2`@06A4A100^6A@30>CZkP@0/[c1
7`1gMgTF0?ooo`00503ooolO07MgN@@03`T80`0a:BL403DY9@@0;b<P100W5Q<401<>2P@0:QPD1010
9Qd305di:@@0R50j101mJUh407M[H0P0MfMQ0`1gJfD<07M_K@P0Mf]U0`1gHeh407MWF@@0LeaB101Z
Edh406YDB@@0LeAA101ZE4T306m=@`@0Ke1<101VD4H406]CB0@0Jda21`1SC48405m1>0@0IdPn101O
?S@403D/:@@081LC100K4Q0301<>2P@04`h?100C2`/401L?2`@06A4A100^6A@30>CZkP@0/[c17`1g
MgTF0?ooo`00503ooolG07MgN@@0Mfma101^IfT400`61P<0;B8O100c9b@402dR7`@06Q0=100W71T4
02hN6P@0;B8N0`1J>b`407=>@@@0OG1V101kKf<407MWI@L0MfmY101gM7D807M_K@@0MfIN101gJfD3
06iLC`@0MemB101^D4P407=GCP@0Me]A101_Ed`406YGB@<0Ke16101VFTl406ICAP@0HdE2101SC484
06=?A@<0Idm5101WB3h405]>@`@0B3P^1012<BL4028H4P@081@B0`0H4`l801`D40@0610;100L5104
02hI50<0i_7f8`1gMgTF0?ooo`00503ooolG07MgN@@0Mfma101^IfT400`61P<0;B8O100c9b@402dR
7`@06Q0=100W71T402hN6P@0;B8N0`1J>b`407=>@@@0OG1V101kKf<407MWI@L0MfmY101gM7D807M_
K@@0MfIN101gJfD306iLC`@0MemB101^D4P407=GCP@0Me]A101_Ed`406YGB@<0Ke16101VFTl406IC
AP@0HdE2101SC48406=?A@<0Idm5101WB3h405]>@`@0B3P^1012<BL4028H4P@081@B0`0H4`l801`D
40@0610;100L510402hI50<0i_7f8`1gMgTF0?ooo`00503ooolG07MgN@@0Mfma101^IfT400`61P<0
;B8O100c9b@402dR7`@06Q0=100W71T402hN6P@0;B8N0`1J>b`407=>@@@0OG1V101kKf<407MWI@L0
MfmY101gM7D807M_K@@0MfIN101gJfD306iLC`@0MemB101^D4P407=GCP@0Me]A101_Ed`406YGB@<0
Ke16101VFTl406ICAP@0HdE2101SC48406=?A@<0Idm5101WB3h405]>@`@0B3P^1012<BL4028H4P@0
81@B0`0H4`l801`D40@0610;100L510402hI50<0i_7f8`1gMgTF0?ooo`00503ooolG07MgN@@0Mfma
101^IfT400`61P<0;B8O100c9b@402dR7`@06Q0=100W71T402hN6P@0;B8N0`1J>b`407=>@@@0OG1V
101kKf<407MWI@L0MfmY101gM7D807M_K@@0MfIN101gJfD306iLC`@0MemB101^D4P407=GCP@0Me]A
101_Ed`406YGB@<0Ke16101VFTl406ICAP@0HdE2101SC48406=?A@<0Idm5101WB3h405]>@`@0B3P^
1012<BL4028H4P@081@B0`0H4`l801`D40@0610;100L510402hI50<0i_7f8`1gMgTF0?ooo`00503o
oolK07MgN@@0Mg]n100:1`H303/S6P@0;b<P100c9b@402lS80@0:QdI100]8Ad403<Q60<0E4@j101C
>Bd407QHC0@0Mf]O101gIfD407MWH@L0Mf]U201gIUh407MOE`@0KUa?0`1^E4P407=SF@@0KU=;101Z
E4<406YDB@@0JUA31`1_Ed`406ICB0@0Je16101[C48406MCA@L0IdPn101GB3h404Pn=0@0@R`T100T
6QX401H@3`@05A4?0`0C3PX401H?40@04PX;10091PL4018;2`@0AbTU0`3JiNX4079bMAl0MgMi5P3o
ool001@0oooo6`1gMgT407MkOP@02PL60`0k8aX402lS80@0<bLT100_8b0402XM6@@0;B4M100c8AP3
05A4>P@0DcT]101hF4`407M[G`@0MfMU101gIf4707M[I@P0MfIN101gGeL406iLC`<0KUA8101cHeT4
06iCB`@0JUA3101ZE4T406YD@`L0KeM<101VDdP406]@AP@0Jda2101WDdD706M8?P@0EdPn1018?S@4
048/90@091XJ100F40l401DA3`<04`h:100F3a04018:2`@02@H7100B2`/404LY9@<0f^GZ101bLWDO
07MgNAH0oooo000D0?oooa/0MgMi101gNgh400X71P<0>b<J100_8b0403<W90@0;b<P100Z7AT402dQ
7@@0<b4H0`1DA3X405<i;@@0N5Q<101gJel407MWI@@0MfMQ1`1gJfD807MVGP@0MemG101^G4l306iD
B0@0Lf=I101^Dd/406YD@`@0JUA9101ZE4<706mGC0@0IU=8101[D4H406]<@P@0Ie=51`1WB3h405M8
?P@0B3hd1012;2@402@J6P@05Q0?100E4@l301<>2P@05Pl@100B2P/400T61`@04P/;1017:BD30=[U
jP@0LW9e7`1gMgTF0?ooo`00503ooolK07MgN@@0Mg]n100:1`H303/S6P@0;b<P100c9b@402lS80@0
:QdI100]8Ad403<Q60<0E4@j101C>Bd407QHC0@0Mf]O101gIfD407MWH@L0Mf]U201gIUh407MOE`@0
KUa?0`1^E4P407=SF@@0KU=;101ZE4<406YDB@@0JUA31`1_Ed`406ICB0@0Je16101[C48406MCA@L0
IdPn101GB3h404Pn=0@0@R`T100T6QX401H@3`@05A4?0`0C3PX401H?40@04PX;10091PL4018;2`@0
AbTU0`3JiNX4079bMAl0MgMi5P3oool001@0oooo7`1gMgT4018920<0<AlG100a:BL403DY9@@09adI
100T514403<Q60@0<BDQ0`12=bh403dQ6`@0Kd/o101mMVT407][H0@0MfMI0`1gIf4<07MSEP@0Mf=N
101gIeT307=LDP@0LeM>101ZASh406Y=@`@0Ke1?101_Ed`406mGC`<0KdU0101VD4H806]<@P@0Hdm5
101WB3h305m4>P@0B3hd1012;2@402@H6@@07aPC100G40d401PC3`<08A<@100G3a04018;2`@04`/;
100c6aH40?ooo`<0a]OL8`1gMgTF0?ooo`00503ooolO07MgN@@04PT80`0a7aL4034Y9`@0=BTU100W
7AT402@D4@@0<b4H100a9B43048g;P@0?B4K101_Bcl407efJ@@0Nf]P101gIeT307MWH@`0Mf=F101g
Heh407MWF@<0LeaB101cEdh406Y6?P@0JTe3101_D4l406mGC0@0KeM?0`1_BD0406I@APP0Jda2101S
CdD406M8?P<0Gd@j1018?S@4048/90@091PI100O61<401L@3@@061<?0`0Q4a0401L?40@04P/;100C
2`/403<K5P@0oooo0`36em`S07MgNAH0oooo000D0?oooal0MgMi100B2@P3034O5`@0<BTW100e:BD4
02LM6@@091@A100c8AP4034U8@<0@SL^100m8A/406m;?`@0OGIY101kJf0407MWF@<0MfMQ301gHeH4
07MSGP@0MfMI0`1cG58407=GCP@0JTHn101ZCD<406m@C`@0KeM<101_Edl306m9@0@0IU16201[C484
06=?A@@0IdPn0`1OA3X404Pn=0@0@R`T100T61T401lH4`@05a0=100H4`l3024C40@05`l@100B2`/4
01<;2`@0<a/F103oool30<KGg2<0MgMi5P3oool001@0oooo7`1gMgT4018920<0<AlG100a:BL403DY
9@@09adI100T514403<Q60@0<BDQ0`12=bh403dQ6`@0Kd/o101mMVT407][H0@0MfMI0`1gIf4<07MS
EP@0Mf=N101gIeT307=LDP@0LeM>101ZASh406Y=@`@0Ke1?101_Ed`406mGC`<0KdU0101VD4H806]<
@P@0Hdm5101WB3h305m4>P@0B3hd1012;2@402@H6@@07aPC100G40d401PC3`<08A<@100G3a04018;
2`@04`/;100c6aH40?ooo`<0a]OL8`1gMgTF0?ooo`00503ooolO07MgN@@07aDC0`0[8Ql402lU8`@0
>BLT100]7AD402/O70@09a`I100_9B<302TN6P@0;b@S101L@34406mHAP@0Lf=I101^GeH307MWG@@0
MfMI101gIed806iOEP@0MfMI0`1^D4P406Y9@0@0JUA3101VC48406ICB0@0IU=6101_D4H306I9@0@0
ITm5101[AD8406=?A@@0Hdln101O@CP305M4>P@0ACX`100_71T401lH4`@05a0=100A3@X401D?40<0
8A<@100E3a0400h71`@04`/;100_6QD40=[UjP<0LW9e8`1gMgTF0?ooo`00503ooolO07MgN@@07aDC
0`0[8Ql402lU8`@0>BLT100]7AD402/O70@09a`I100_9B<302TN6P@0;b@S101L@34406mHAP@0Lf=I
101^GeH307MWG@@0MfMI101gIed806iOEP@0MfMI0`1^D4P406Y9@0@0JUA3101VC48406ICB0@0IU=6
101_D4H306I9@0@0ITm5101[AD8406=?A@@0Hdln101O@CP305M4>P@0ACX`100_71T401lH4`@05a0=
100A3@X401D?40<08A<@100E3a0400h71`@04`/;100_6QD40=[UjP<0LW9e8`1gMgTF0?ooo`00503o
oolO07MgN@@07aDC0`0[8Ql402lU8`@0>BLT100]7AD402/O70@09a`I100_9B<302TN6P@0;b@S101L
@34406mHAP@0Lf=I101^GeH307MWG@@0MfMI101gIed806iOEP@0MfMI0`1^D4P406Y9@0@0JUA3101V
C48406ICB0@0IU=6101_D4H306I9@0@0ITm5101[AD8406=?A@@0Hdln101O@CP305M4>P@0ACX`100_
71T401lH4`@05a0=100A3@X401D?40<08A<@100E3a0400h71`@04`/;100_6QD40=[UjP<0LW9e8`1g
MgTF0?ooo`00503ooolO07MgN@@07aDC0`0[8Ql402lU8`@0>BLT100]7AD402/O70@09a`I100_9B<3
02TN6P@0;b@S101L@34406mHAP@0Lf=I101^GeH307MWG@@0MfMI101gIed806iOEP@0MfMI0`1^D4P4
06Y9@0@0JUA3101VC48406ICB0@0IU=6101_D4H306I9@0@0ITm5101[AD8406=?A@@0Hdln101O@CP3
05M4>P@0ACX`100_71T401lH4`@05a0=100A3@X401D?40<08A<@100E3a0400h71`@04`/;100_6QD4
0=[UjP<0LW9e8`1gMgTF0?ooo`00503ooolO07MgN@@07aD@0`0[8Al403DY9@@0;b<P100[8Ql401lE
60@09AXG100]8Ad303DY9@@0<AlG100i8QT405I4>0@0Idm7101ZCD@307=LDP@0KUQ?201^GeH807=L
DP<0IU18101QASd406I<@P@0ITU2101[B3h806]<@P<0ITa2201SB3h405]4>0@0Ed4h1018>c@303l^
9@@0>bTQ100M5Q4401D@3@@05A4?100E3`/7018;2`@02@H7100:1`L4034K5P@0?AlE103JiNXV07Mg
NAH0oooo000D0?oooal0MgMi100O5A0302/Q7`@0=BTU100_8b0402/R7`@07aDH100U6QL402dQ7@<0
=BTU100a7aL403TR6@@0ET@h101WCdL406Y=A0<0LeaB101^F4l806iOEPP0LeaB0`1VD4P40656?@@0
ITa2101VBD8406]8?PP0Jda20`1VC48806=8?P@0Fd@h101G@CP404Pk=0<0?bhU100k:B4401dF4@@0
5A0=100E4@l401D?2`L04P/;10091PL400X71`@0<A/F100m7aD40=[UjRH0MgMi5P3oool001@0oooo
7`1gMgT401lE40<0:b4O100e:BD402lS80@0:b8O100O5AP402DJ5`@0;B4M0`0e:BD4034O5`@0>B8I
101FA3P406M?A`@0JTe40`1cG58406iHC`P0KUmF201cG58306I@B0@0HDHm101VC48406I9@P@0JdPn
201[C48306I<@PP0HdPn101KA3P405M1>0@0B3/d0`0o;RD403/Y8@@07AHA100E40d401DA3`@05@l;
1`0B2`/400T61`@02PL7100a6aH403dO5@@0f^GZ9P1gMgTF0?ooo`00503ooolO07MgN@@07aD@0`0[
8Al403DY9@@0;b<P100[8Ql401lE60@09AXG100]8Ad303DY9@@0<AlG100i8QT405I4>0@0Idm7101Z
CD@307=LDP@0KUQ?201^GeH807=LDP<0IU18101QASd406I<@P@0ITU2101[B3h806]<@P<0ITa2201S
B3h405]4>0@0Ed4h1018>c@303l^9@@0>bTQ100M5Q4401D@3@@05A4?100E3`/7018;2`@02@H7100:
1`L4034K5P@0?AlE103JiNXV07MgNAH0oooo000D0?oooal0MgMi101>@T`3030Q80@0<bLT100]8Ql4
03/^:`@0;ahF100Y5a<403X/:0<0:alL100c9b@402@J60@0?CD/100b:2<404P_9`<0IU16101J@cX4
065@CP@0HDe;101QCD@406YGCP<0FT<j1011;RL404/e;0@0Fc//101SB3h406=;@@@0Hc/b0`1SB3h4
06=8<P@0Gd@j101G?S@405<j<0@0B3X`0`0e8Ad402TH4`@0614@100J4@l401D?2`@04PX;100B2`/3
00l71`@02PL7100E30`402HF4@@0c/kB103@hNXV07MgNAH0oooo000D0?oooal0MgMi101>@T`3030Q
80@0<bLT100]8Ql403/^:`@0;ahF100Y5a<403X/:0<0:alL100c9b@402@J60@0?CD/100b:2<404P_
9`<0IU16101J@cX4065@CP@0HDe;101QCD@406YGCP<0FT<j1011;RL404/e;0@0Fc//101SB3h406=;
@@@0Hc/b0`1SB3h406=8<P@0Gd@j101G?S@405<j<0@0B3X`0`0e8Ad402TH4`@0614@100J4@l401D?
2`@04PX;100B2`/300l71`@02PL7100E30`402HF4@@0c/kB103@hNXV07MgNAH0oooo000D0?oooal0
MgMi101>@T`3030Q80@0<bLT100]8Ql403/^:`@0;ahF100Y5a<403X/:0<0:alL100c9b@402@J60@0
?CD/100b:2<404P_9`<0IU16101J@cX4065@CP@0HDe;101QCD@406YGCP<0FT<j1011;RL404/e;0@0
Fc//101SB3h406=;@@@0Hc/b0`1SB3h406=8<P@0Gd@j101G?S@405<j<0@0B3X`0`0e8Ad402TH4`@0
614@100J4@l401D?2`@04PX;100B2`/300l71`@02PL7100E30`402HF4@@0c/kB103@hNXV07MgNAH0
oooo000D0?oooal0MgMi101>@T`3030Q80@0<bLT100]8Ql403/^:`@0;ahF100Y5a<403X/:0<0:alL
100c9b@402@J60@0?CD/100b:2<404P_9`<0IU16101J@cX4065@CP@0HDe;101QCD@406YGCP<0FT<j
1011;RL404/e;0@0Fc//101SB3h406=;@@@0Hc/b0`1SB3h406=8<P@0Gd@j101G?S@405<j<0@0B3X`
0`0e8Ad402TH4`@0614@100J4@l401D?2`@04PX;100B2`/300l71`@02PL7100E30`402HF4@@0c/kB
103@hNXV07MgNAH0oooo000D0?ooob<0MgMi0`0W7aH402DM6@@0;B8O100_8b04020L60@07aDH100c
8QT302dR7`@0?S0/100c9b@403<V8`@0=BTX1016;bP3044_9@@0;2P[100Z:RL403PV7@@0ACH[1015
=Rh302hT8P@0=BDM100k:1l404Dc8`@0C34X101?>2T405ln;P<0Ccdb1012;2@404P/9`@0C3@[100k
<Bd4038R7`<09aHA100P4a4401LA3`@04`h:100A2P/400h71`L02PL7100;1`L4020F4@@0;aXE103T
j^h407^0PRH0MgMi5P3oool001@0oooo8`1gMgT302LO5P@09AdI100]8Ql402lS80@081`H100O5AP4
03<R6@<0;B8O100n<2`403<W90@0<bHS100e:BP404H_:0<0@BlU100/:2/402XZ9`@0>2HM1015=R/4
04Df;P<0;R@R100e9Ad403/X7`@0AC<S101<<BP404lh:@@0Gch^0`1??C84048/90@0B2`W101<=2/4
03/a;@@0<R8O0`0W5Q44020C4@@05a4?100C3PX4014:2`@03PL71`0:1`L400/71`@081HA100_6QD4
0>CZkP@0Nh229P1gMgTF0?ooo`00503ooolS07MgN@<09alF100U7AT402dR7`@0;b<P100P71P401lE
60@0<b8I0`0]8Ql403h`;0@0<bLT100c9R<403DY:0@0ARlX0`11;bD402`X:`@0:RXW100h9Qd404Df
:`@0ACH^0`0^928403DU7@@0>bPO1015<b<404`a:0@0CcPY101O?Rh304lm<P@0@R`T1018;2L404`d
:`@0>c4]100b8Ql302LF4@@081<A100G4@l401<>2P@04@X;100>1`L700X71`@02`L7100P5Q4402lJ
5@@0i>[^101kP88V07MgNAH0oooo000D0?ooob<0MgMi0`0d:c<402LN7@@0>2XW100_:BD402lS80@0
614>100^8Qd303/`;P@0>bh[100m<Bd4040c;`@0BS/a1015=bd303H_:0@0:b8S100^71D4030L6`@0
=B4M100e9R8302@L7@@0:b4P100g8Qh403XT6@@0=B4N1011<BH403h]9@<0<RHO100n;B<403PV7@@0
=B`V100_81/402/L5P<06a<A100P6QP4018>2P@05@l;100B2`/400l71`L02`L7100V5Q4401XA4@@0
Q69M103JiNXZ07MgNAH0oooo000D0?ooob<0MgMi0`0d:c<402LN7@@0>2XW100_:BD402lS80@0614>
100^8Qd303/`;P@0>bh[100m<Bd4040c;`@0BS/a1015=bd303H_:0@0:b8S100^71D4030L6`@0=B4M
100e9R8302@L7@@0:b4P100g8Qh403XT6@@0=B4N1011<BH403h]9@<0<RHO100n;B<403PV7@@0=B`V
100_81/402/L5P<06a<A100P6QP4018>2P@05@l;100B2`/400l71`L02`L7100V5Q4401XA4@@0Q69M
103JiNXZ07MgNAH0oooo000D0?ooob<0MgMi0`0d:c<402LN7@@0>2XW100_:BD402lS80@0614>100^
8Qd303/`;P@0>bh[100m<Bd4040c;`@0BS/a1015=bd303H_:0@0:b8S100^71D4030L6`@0=B4M100e
9R8302@L7@@0:b4P100g8Qh403XT6@@0=B4N1011<BH403h]9@<0<RHO100n;B<403PV7@@0=B`V100_
81/402/L5P<06a<A100P6QP4018>2P@05@l;100B2`/400l71`L02`L7100V5Q4401XA4@@0Q69M103J
iNXZ07MgNAH0oooo000D0?ooob<0MgMi0`0d:c<402LN7@@0>2XW100_:BD402lS80@0614>100^8Qd3
03/`;P@0>bh[100m<Bd4040c;`@0BS/a1015=bd303H_:0@0:b8S100^71D4030L6`@0=B4M100e9R83
02@L7@@0:b4P100g8Qh403XT6@@0=B4N1011<BH403h]9@<0<RHO100n;B<403PV7@@0=B`V100_81/4
02/L5P<06a<A100P6QP4018>2P@05@l;100B2`/400l71`L02`L7100V5Q4401XA4@@0Q69M103JiNXZ
07MgNAH0oooo000D0?ooob<0MgMi0`1VGVT402LI5@@0;b<P100]8Ql402lR7`@0;b<P1010;b/303h`
;0@0?C4]100a9R<402lT8@@0=AlM100o8Qd3038N5`@0:AlN100P61D402/S8@@081@A100W8R0302DO
7P@09AdI100P514401dH5P@07A@B100R5147028I50@08aXE100L4A04020C4@@06a8@100M514301<@
3P@04`h:100?2@X8018;2`@02PL7100;1`L302HF6`@09QHA100g:BD40>k^kP@0Xk:h:P1gMgTF0?oo
o`00503ooolS07MgN@<0IUiY100W6AD402lS80@0;B8O100_8Ql402lS80@0@2l[0`0n<2`403da;@@0
<BHS100_924403DO7@@0?b8M0`0b7QL402TO7P@081PE100[8b44020D4@@09b8P0`0U7ah402DM6@@0
81@A100M61H401dD4P@08Q@A1`0R6A@402<J5@@0714@100P4a4401/B40@07A@A0`0C40h401<>2P@0
3`T:200B2`/400X71`@02`L70`0V5Q/402HF4@@0=bTU103^k^h40:>b^2X0MgMi5P3oool001@0oooo
8`1gMgT306INJ@@09aTE100_8b0402dR7`@0;b8O100_8b04040_:`<0?S0/100m<Bd4034V8`@0;b@Q
100e7ad403lR7@<0<QhG100Y7ah4020H5@@0:b<Q100P514402LR80<09AlN100U7AT4020D4@@07APF
100M5184028D4@L08QTD100S6QD401`A40@081<A100K4Q0401dD4@<04a0>100C3PX400l92PP04P/;
100:1`L400/71`<09QHK100V5Q4403LY9@@0k^k^102S/[PZ07MgNAH0oooo000D0?ooob<0MgMi0`1V
GVT402LI5@@0;b<P100]8Ql402lR7`@0;b<P1010;b/303h`;0@0?C4]100a9R<402lT8@@0=AlM100o
8Qd3038N5`@0:AlN100P61D402/S8@@081@A100W8R0302DO7P@09AdI100P514401dH5P@07A@B100R
5147028I50@08aXE100L4A04020C4@@06a8@100M514301<@3P@04`h:100?2@X8018;2`@02PL7100;
1`L302HF6`@09QHA100g:BD40>k^kP@0Xk:h:P1gMgTF0?ooo`00503ooolV07MgN@@0@CXi100[8Ql4
02lS80@0=BTU100_8b04048e<@<09adI100g:bP402@J5`@0<bLT1017<bT4034Y9@<09b8P100[8b44
02TN6P@0@2`X100O51H402LR7PL091@A100K4@h401PC3`@07A8?100W5a@402DG50/06Q4?100U5a@4
01/C3`@07A<?0`0C3PX401H?2`@04P/;100C2`/800X71`@05@`<0`0c81/402XH4`@0i>[^103@em`^
07MgNAH0oooo000D0?ooobH0MgMi1011>ST402/R7`@0;b<P100e:BD402lS80@0@SDa0`0W7AT403L[
:0@091XG100c9b@404Lc:@@0<BTU0`0W8R0402/S8@@0:AhJ1010;2P401lD5P@09b8N1`0T514401/A
3P@061<?100M4Pl402LG50@09ALD2`0J4@l402DG50@06a<?100M4`l301<>2P@05Pl;100B2`/401<;
2`P02PL7100E30`303<P6`@0:QPC103Tj^h40=3Gg2h0MgMi5P3oool001@0oooo9P1gMgT4044j>@@0
:b8O100_8b0403DY9@@0;b<P1012=C4302LM6@@0=b/X100T6QL403<W90@0Ac<Y100a:BD302LR80@0
:b<Q100Y7QX4040/:0@07a@F100W8Qh702@D4@@06a4>100H4`l401dB3`@09aLD100U5a@;01XA3`@0
9ALD100K4`l401dC3`<04`h:100F3`/4018;2`@04`/;200:1`L401D<30<0<b0K100Z61<40>CZkP@0
d=OL;P1gMgTF0?ooo`00503ooolV07MgN@@0@CXi100[8Ql402lS80@0=BTU100_8b04048e<@<09adI
100g:bP402@J5`@0<bLT1017<bT4034Y9@<09b8P100[8b4402TN6P@0@2`X100O51H402LR7PL091@A
100K4@h401PC3`@07A8?100W5a@402DG50/06Q4?100U5a@401/C3`@07A<?0`0C3PX401H?2`@04P/;
100C2`/800X71`@05@`<0`0c81/402XH4`@0i>[^103@em`^07MgNAH0oooo000D0?ooobH0MgMi101M
D5T402@D4PP0=BTU100]8Ql402@N6P<0=BTV1015=c8402/V8`@0:alL100i8QT401dF50<09adI100Y
7QX401XD6P@09AlL100L51D402TG4`<07A4G200H4`l401D?2`@06a<@100J4a0401PC3`<04`h:100A
2P/401D?2`@07a<@100C3PX4014:2`<05@l;100G3a04018;2`@02PL7100C2`/4020F4@@0<b0K0`0_
6QD40=[Qi@@0f^GZ<P1gMgTF0?ooo`00503ooolV07MgN@@0GE1I100T518803DY9@@0;B8O100T7QX3
03DY9P@0ACLb100[9R<402/O70@0>B8I100M5Q@302LM6@@0:AhJ100J51X402DO70@071@E100Y5a<3
01dA5`P061<?100E3`/401/C40@06Q<@100H4`l301<>2P@04@X;100E3`/401lC40@04`h:100A2P/3
01D?2`@05`l@100B2`/400X71`@04`/;100P5Q4403<P6`<0;aXE103JhND40=[UjS80MgMi5P3oool0
01@0oooo9P1gMgT405e@F@@091@B200e:BD402dR7`@091hJ0`0e:BH404Dg<P@0:bHS100[7a`403TR
6@@07AHD0`0W7AT402TN6P@06Q@J100U7a`401`D5@@0:ALC0`0M4AL801PC3`@05@l;100K4a0401XC
40@061<?0`0C3PX4014:2`@05@l;100O4a0401<>2P@04@X;0`0E3`/401L?40@04P/;100:1`L401<;
2`@081HA100c81/302lJ5@@0f^7U103JiNXb07MgNAH0oooo000D0?ooobH0MgMi101MD5T402@D4PP0
=BTU100]8Ql402@N6P<0=BTV1015=c8402/V8`@0:alL100i8QT401dF50<09adI100Y7QX401XD6P@0
9AlL100L51D402TG4`<07A4G200H4`l401D?2`@06a<@100J4a0401PC3`<04`h:100A2P/401D?2`@0
7a<@100C3PX4014:2`<05@l;100G3a04018;2`@02PL7100C2`/4020F4@@0<b0K0`0_6QD40=[Qi@@0
f^GZ<P1gMgTF0?ooo`00503ooolZ07MgN@@0;2@O100[8b0403<W90@0;B8O100e:BD303<Z9`@0<BHS
100T6QL402@H5@@09AXG100G40h302dQ7@P081DG100O4`h401dA5`@050h?0`0?2PX401D?3`@05Pl@
100B2P/401L?40@04PX;100F3a03018:2`@05`l@100M5A0401L?40@04@X;3`0:1`L401P@40@06Q4<
100C2`/4024?2`<0c/[>103JiNXf07MgNAH0oooo000D0?ooobX0MgMi100/91l402/S80@0<bLT100]
8Ql403DY9@<0<bXW100a9R<402@J5`@091PE100U6QL401L@3P<0;B4M200P5AL401lC3P@07A4G100D
3Pl300l:2P@05@l?100F3a04018:2`@05`l@100B2P/401H?40<04PX;100G3a0401dE40@05`l@100A
2P/?00X71`@0610@100J4@`401<;2`@08@l;0`3>b/h40=[UjSH0MgMi5P3oool001@0oooo:P1gMgT4
02`T7`@0:b<P100c9b@402dR7`@0=BTU0`0c:RL4034V8`@091XG100T61D402DJ5`@05a0>0`0]8Ad8
020E5`@07a<>100M4AL401@>3`<03`X:100E3`l401H?40@04PX;100G3a04018:2`@05Pl@0`0B2P/4
01L?40@07AD@100G3a04014:2`l02PL7100H410401XA30@04`/;100Q3`/30<k:cP@0f^GZ=P1gMgTF
0?ooo`00503ooolZ07MgN@@0;2@O100[8b0403<W90@0;B8O100e:BD303<Z9`@0<BHS100T6QL402@H
5@@09AXG100G40h302dQ7@P081DG100O4`h401dA5`@050h?0`0?2PX401D?3`@05Pl@100B2P/401L?
40@04PX;100F3a03018:2`@05`l@100M5A0401L?40@04@X;3`0:1`L401P@40@06Q4<100C2`/4024?
2`<0c/[>103JiNXf07MgNAH0oooo000D0?ooobh0MgMi1017>cP402TN6P@0;B8O100_:BD302dW90@0
>bdY100]8R@402DE4P@09a/H100H4Pl301lC40@05Q4>100N4`l4010:2P@04@X;100E3`l301L?40@0
4`/;100G3a04018;2`@0610@100B2`/402lJ5@<02PL7100H410401`D40@05Pl@200:1`L301071``0
6Q4A100^6A@403/T6P@0PDli0`3Tk_<407^0PSH0MgMi5P3oool001@0oooo;P1gMgT404Lk>0@0:AhJ
100]8Ql402lY9@<0;BLT100k;BT402dR90@09ADB100W6aP401PB3`<07a<@100F4@h401hC3`@040X:
100A2P/401D?3`<05`l@100C2`/401L?40@04P/;100H4104018;2`@0;aXE0`0:1`L401P@40@071@@
100F3a0800X71`<040L7300J4A4402hI50@0>b@J1021CcT30>C^l`@0Nh22=P1gMgTF0?ooo`00503o
ool^07MgN@@0Ac/h100Y7QX402dR7`@0;bTU0`0]9b@403/]:@@0;B8T100U5A8402LK60@0618?0`0O
4a0401HA3P@07Q<?100@2PX4014:2`@05@l?0`0G3a0401<;2`@05`l@100B2`/401P@40@04P/;100_
6QD300X71`@0610@100L510401H?40P02PL70`0@1`L<01XA4@@0;QTD100k91X4085?>@<0i>kc101k
P88f07MgNAH0oooo000D0?oooc80MgMi1017=C84034Z9`@0:AhJ1`0k;BT403L[:0@091hI100]8Qh4
01dB60<05Pl@100O4a0401H?40@06Q<@100M5A0401P@40L04P/;100C2`/4018;2`@04`/;100L5104
01P@40<0;Bdm100i<c@4028D6@@04PX;100G3a07020F4@@06A4A100d91l402hN6@@0;QTD101G<bT4
0=3Li@<0Z<3?>P1gMgTF0?ooo`00503ooolb07MgN@@0AcDb100a:RL402TN6PL0>bdY100g:bP402@N
6@@0;B8N100M4QP301H?40@07a<@100F3a0401XC40@07AD@100H4107018;2`@04`/;100B2`/401<;
2`@071@@100H410302d]?@@0>C<d100R51T4018:2`@05`l@1`0P5Q4401TA4@@0=2@O100^7QT402hI
50@0Ec<Y103@g>D30:S0ccX0MgMi5P3oool001@0oooo<P1gMgT404Le<P@0<BXW100Y7QX703/]:@@0
=b/X100T7QT402dR7P@07A8H0`0F3a0401lC40@05Pl@100J4a0401dE40@0610@1`0B2`/401<;2`@0
4P/;100C2`/401`D40@0610@0`0];Cd403Tc=0@08Q@I100B2P/401L?40L081HA100I4A4403@T7`@0
;QhI100^6A@405Lc:@@0d=cU0`2X`<lj07MgNAH0oooo000D0?oooc80MgMi1017=C84034Z9`@0:AhJ
1`0k;BT403L[:0@091hI100]8Qh401dB60<05Pl@100O4a0401H?40@06Q<@100M5A0401P@40L04P/;
100C2`/4018;2`@04`/;100L510401P@40<0;Bdm100i<c@4028D6@@04PX;100G3a07020F4@@06A4A
100d91l402hN6@@0;QTD101G<bT40=3Li@<0Z<3?>P1gMgTF0?ooo`00503ooolb07MgN@@0P7n21017
=c@403/]:@<0:alL100[9R<403da;@@0=b/X100c7aL402DJ5`<06Q<?100G3a04014:2`@05`l;100F
3a04018:2`<04P/;100H410401<;2`@0610@200C2`/4038_<@<0;Qh[1015<bX404Dc;@@0=bTX101<
>38403@T7`<06a<@100/7AT402hN6@@0>2XW101?;2<40=[IgP@0]lkH?@1gMgTF0?ooo`00503ooolb
07MgN@@0P7n21017=c@403/]:@<0:alL100[9R<403da;@@0=b/X100c7aL402DJ5`<06Q<?100G3a04
014:2`@05`l;100F3a04018:2`<04P/;100H410401<;2`@0610@200C2`/4038_<@<0;Qh[1015<bX4
04Dc;@@0=bTX101<>38403@T7`<06a<@100/7AT402hN6@@0>2XW101?;2<40=[IgP@0]lkH?@1gMgTF
0?ooo`00503ooolb07MgN@@0P7n21017=c@403/]:@<0:alL100[9R<403da;@@0=b/X100c7aL402DJ
5`<06Q<?100G3a04014:2`@05`l;100F3a04018:2`<04P/;100H410401<;2`@0610@200C2`/4038_
<@<0;Qh[1015<bX404Dc;@@0=bTX101<>38403@T7`<06a<@100/7AT402hN6@@0>2XW101?;2<40=[I
gP@0]lkH?@1gMgTF0?ooo`00503ooolb07MgN@@0P7n21017=c@403/]:@<0:alL100[9R<403da;@@0
=b/X100c7aL402DJ5`<06Q<?100G3a04014:2`@05`l;100F3a04018:2`<04P/;100H410401<;2`@0
610@200C2`/4038_<@<0;Qh[1015<bX404Dc;@@0=bTX101<>38403@T7`<06a<@100/7AT402hN6@@0
>2XW101?;2<40=[IgP@0]lkH?@1gMgTF0?ooo`00503ooolf07MgN@@0LW9e1010;2<303da;@@0>2XW
1012<bl403/_;0@0?C4]100T6QP302LK60@0>BTU100^91l402<E40@071@@100G3a0301P@40@04`/;
100B2`/401dE6P@05`l@100M5A0401P@40<09AdH100c9Ql400h;30@04Ph<100E40d400l;30<06a4>
100/7AT403<Q60@0Icl^102YWJ/40;cCg0@0Mg]n?@1gMgTF0?ooo`00503ooolf07MgN@@0LW9e1010
;2<303da;@@0>2XW1012<bl403/_;0@0?C4]100T6QP302LK60@0>BTU100^91l402<E40@071@@100G
3a0301P@40@04`/;100B2`/401dE6P@05`l@100M5A0401P@40<09AdH100c9Ql400h;30@04Ph<100E
40d400l;30<06a4>100/7AT403<Q60@0Icl^102YWJ/40;cCg0@0Mg]n?@1gMgTF0?ooo`00503ooolf
07MgN@@0LW9e1010;2<303da;@@0>2XW1012<bl403/_;0@0?C4]100T6QP302LK60@0>BTU100^91l4
02<E40@071@@100G3a0301P@40@04`/;100B2`/401dE6P@05`l@100M5A0401P@40<09AdH100c9Ql4
00h;30@04Ph<100E40d400l;30<06a4>100/7AT403<Q60@0Icl^102YWJ/40;cCg0@0Mg]n?@1gMgTF
0?ooo`00503ooolf07MgN@@0LW9e1010;2<303da;@@0>2XW1012<bl403/_;0@0?C4]100T6QP302LK
60@0>BTU100^91l402<E40@071@@100G3a0301P@40@04`/;100B2`/401dE6P@05`l@100M5A0401P@
40<09AdH100c9Ql400h;30@04Ph<100E40d400l;30<06a4>100/7AT403<Q60@0Icl^102YWJ/40;cC
g0@0Mg]n?@1gMgTF0?ooo`00503oooln07MgN@<0@c/d100T6QL403<W90@0BC/h1019@Sl403/_;0<0
9a/H100R5QP402@D4@@0<bDQ100Z8al401H?40<04P/;100R6Al402<J80@0;bHP100Q61d4048`:`@0
6a<I0`1A?SL403<U9`@0;b<P100k:RD4038S7`@0>BTU0`1A?S4403LY9@@0L4Hd103@d=X40:g5d`@0
QXj;@@1gMgTF0?ooo`00503oooln07MgN@<0@c/d100T6QL403<W90@0BC/h1019@Sl403/_;0<09a/H
100R5QP402@D4@@0<bDQ100Z8al401H?40<04P/;100R6Al402<J80@0;bHP100Q61d4048`:`@06a<I
0`1A?SL403<U9`@0;b<P100k:RD4038S7`@0>BTU0`1A?S4403LY9@@0L4Hd103@d=X40:g5d`@0QXj;
@@1gMgTF0?ooo`00503oooln07MgN@<0@c/d100T6QL403<W90@0BC/h1019@Sl403/_;0<09a/H100R
5QP402@D4@@0<bDQ100Z8al401H?40<04P/;100R6Al402<J80@0;bHP100Q61d4048`:`@06a<I0`1A
?SL403<U9`@0;b<P100k:RD4038S7`@0>BTU0`1A?S4403LY9@@0L4Hd103@d=X40:g5d`@0QXj;@@1g
MgTF0?ooo`00503oooln07MgN@<0@c/d100T6QL403<W90@0BC/h1019@Sl403/_;0<09a/H100R5QP4
02@D4@@0<bDQ100Z8al401H?40<04P/;100R6Al402<J80@0;bHP100Q61d4048`:`@06a<I0`1A?SL4
03<U9`@0;b<P100k:RD4038S7`@0>BTU0`1A?S4403LY9@@0L4Hd103@d=X40:g5d`@0QXj;@@1gMgTF
0?ooo`00503ooom107MgN@@0SHBF1015=c8403<W90@0<2HS100f=Ch304Tk>0@0EdI2101JCdT403<W
:@@0:BT[1017?Dh3069DC@@0?B`/100`9c8403LW9`@0Ace>100n;BL402dR7`<0AcD^100e924403/S
7`@0>b<J100e:BD404dg;0<0JT8a100e7aP40=3Gg0@0Z<3?101gNgi507MgNAH0oooo000D0?oood40
MgMi102=Q9H404Dg<P@0<bLT100`9R<403He?P<0BC/h101GAT8405Y?B@@0<bLY100Y:B/404LmCP<0
HUA=100m;2`4030W<P@0=bLW1017?Dh403h]9`@0;B8O0`17=Bh403DT8@@0>b<O100k8aX403DY9@@0
CCL/0`1Z@S4403DO60@0d=OL102X`<l407MkOTD0MgMi5P3oool001@0oooo@@1gMgT408f4UP@0ACLb
100c9b@4030V8`@0=SDn0`19>cP405M6@P@0FTm9100c9bT402TY:`@0Ace>0`1RE4d403d/;0@0<2Lb
100g9bL404LmCP@0?RdW100]8Ql304Le;P@0=B@Q100k8al403/S6P@0=BTU101==b`306Y2<@@0=AlH
103@em`40:S0c`@0Mg]nA@1gMgTF0?ooo`00503ooom107MgN@@0SHBF1015=c8403<W90@0<2HS100f
=Ch304Tk>0@0EdI2101JCdT403<W:@@0:BT[1017?Dh3069DC@@0?B`/100`9c8403LW9`@0Ace>100n
;BL402dR7`<0AcD^100e924403/S7`@0>b<J100e:BD404dg;0<0JT8a100e7aP40=3Gg0@0Z<3?101g
Ngi507MgNAH0oooo000D0?ooodD0MgMi102;TY0404TkA@@0@3<_100a<CX305M;BP@0BTA81013?CX4
04<k>0@0FE1B101LAT4304Ti<0@0<2@R1012=Bl4034S8@@0:AhI100Y7QP403T]:@<0=BTU10159Qh4
04`]90@0C3D[101J@SX404LW7`<0G4U?102X`<l40<KGhDd0MgMi5P3oool001@0ooooA@1gMgT408^B
T0@0BC]51010<bl4034a>P<0Ed]:101:A4P404<m>P@0@c/h101ID58405a6@@<0BCT`100`9284048e
;`@0<B<Q100Y7QT402TN60@0>BdY0`0e:BD404DV7P@0C2dT101<=B/405Y2>P@0AbLO0`1LBDl40:S0
c`@0a]OQC@1gMgTF0?ooo`00503ooom507MgN@@0Ri:@1019>dD4040c;`@0<C4j0`1GBdX404Y4B0@0
@cdj1013>cP405U@DP@0G4I10`19>C04030T8P@0@SD_100a8b4402TN6@@0:AhH100i;BT303DY9@@0
ABHN101<;B@404`e:`@0FT8j10179al305a9C`@0Z<3?1036en5=07MgNAH0oooo000D0?ooo`@0Mfma
B@1gMgT40;O0_@@0[:Ri0`1>@Tl405Y:B`@0Mf]n101YEU/405U2?P@0AcPd0`17>cP405U4B0@0Hda7
101@@Sl406Y@B@@0E4@j101IB4D306=<A`@0CT0f1016@3P4030V90@0Q7R9102]`<X30;cCg0@0Z;Nh
D@1gMgTF0?ooo`00503oool407M_LDT0MgMi102g`;d40:bX^@<0CT9?101JBT/407M[OP@0JEIK101I
@Sh404Lh=0<0Ac/h101IA4P406=<A`@0D48o101ZD4T405A4>P@0FDQ50`1SC4L404i0=P@0AT0h100`
9R@408AhR@@0[L3:0`2ldm`40:Rg^540MgMi5P3oool001@0oooo101gKg5907MgN@@0]l2m102/Z;T3
04i2C`@0FTY;101gJgh406UFF`@0FD8n1017>3@304Lk>0@0FDA8101SC4L40512?`@0JU19101DA3X4
05U8A@<0Hda7101>@3H404I0>0@0<2HT1024N8T40:g0bP<0_=?L102X]kQA07MgNAH0oooo000D0?oo
o`@0MfmaB@1gMgT40;O0_@@0[:Ri0`1>@Tl405Y:B`@0Mf]n101YEU/405U2?P@0AcPd0`17>cP405U4
B0@0Hda7101@@Sl406Y@B@@0E4@j101IB4D306=<A`@0CT0f1016@3P4030V90@0Q7R9102]`<X30;cC
g0@0Z;NhD@1gMgTF0?ooo`00503oool807MkOTd0MgMi0`20QH840;Nl]0@0Xjj_1022Oh/409jPX@@0
P7fD1`1>B5/4044h=0@0@CPf1017>cP4044h=P@0@cLf0`0j:R8403D]9@@0]kJo102g`<X40<KCf0@0
SibIF01gMgTF0?ooo`00503oool807MkOTd0MgMi0`20QH840;Nl]0@0Xjj_1022Oh/409jPX@@0P7fD
1`1>B5/4044h=0@0@CPf1017>cP4044h=P@0@cLf0`0j:R8403D]9@@0]kJo102g`<X40<KCf0@0SibI
F01gMgTF0?ooo`00503oool807MkOTd0MgMi0`20QH840;Nl]0@0Xjj_1022Oh/409jPX@@0P7fD1`1>
B5/4044h=0@0@CPf1017>cP4044h=P@0@cLf0`0j:R8403D]9@@0]kJo102g`<X40<KCf0@0SibIF01g
MgTF0?ooo`00503oool807MkOTd0MgMi0`20QH840;Nl]0@0Xjj_1022Oh/409jPX@@0P7fD1`1>B5/4
044h=0@0@CPf1017>cP4044h=P@0@cLf0`0j:R8403D]9@@0]kJo102g`<X40<KCf0@0SibIF01gMgTF
0?ooo`00503ooomT07MgN@@0P8En101gNgh308^BR`P0[K:[102b/KL<0;:l`@<0]l36102lbM<40;c5
c`@0Mg]nH01gMgTF0?ooo`00503ooomT07MgN@@0P8En101gNgh308^BR`P0[K:[102b/KL<0;:l`@<0
]l36102lbM<40;c5c`@0Mg]nH01gMgTF0?ooo`00503ooomT07MgN@@0P8En101gNgh308^BR`P0[K:[
102b/KL<0;:l`@<0]l36102lbM<40;c5c`@0Mg]nH01gMgTF0?ooo`00503ooomT07MgN@@0P8En101g
Ngh308^BR`P0[K:[102b/KL<0;:l`@<0]l36102lbM<40;c5c`@0Mg]nH01gMgTF0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00V03oool2@00008H0oooo002J0?ooo`03@000003oool0oooo08<0oooo001k0?ooo`900000
103oool00d000000oooo0?ooo`0:0?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000
003oool0oooo07d0oooo001m0?ooo`06@000003oool0oooo@000003ooom000002P3oool01T000000
oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000Q@3oool007`0oooo0T000002
0?ooo`03@000003ooom0000000X0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A0
00000?ooo`3ooom00000Q@3oool007/0oooo00=000000?oood0000000P3oool00d000000oooo@000
000;0?ooo`=0000000@0oooo@0000400001000000`3oool3@00008D0oooo001k0?ooo`03@000003o
oom000000080oooo00=000000?oood0000003@3oool00d000000oooo0?ooo`2=0?ooo`00O03oool2
@00000<0oooo00=000000?ooo`3oool02`3oool2@00008l0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(135) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E61625D
65656165656565696965656565696965696965696965696965656565656161625D615E585E5650\
5E56505A524C5A524C5A524C5A524C5A524C5A4E47574E43574E47574E43574E47
65757E65757E65757E65757E65757E65717A65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E656E7765727B65757E656E7765727B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E686863
68686A65656165696765656565696965696965635C5E5A515B5A515B565058504C524C48514B46\
544D48514A4458504A5A524C5A524C5A4C465A4C46574E49574E49574E4357686F
65829165757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65788165717A65727B65788165788165757E656E7765727B656E7765727B65757E65757E\
65757E65757E65788165788165757E65757E65757E65757E65757E65757E5E5F5A
62635C6565656563666569696565656560605E5C584C595A52525058464854474457514C5A5852\
5A5A545D564F574E47524A44524A44524C46524E42544E46574E47574E49728997
72899465757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65717A65757E65757E65757E65757E65788165788165788165788165757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E68625D
68656865656865656565636365636365655E686868756E70716D666E6468675D5865524C654D4E\
654D505E4446574A46574E47574E47574E47574E495D544F5A5049574E4765757E
65757E65757E65757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656863
65686065655B656563656565656565656568656C6F656F6E686B6D616A6161615D68615D68635B\
61565268645B63504D60454760585B5A524D5D4E475D4C46574C465D5A54687B85
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656561
656561656568656561656563656565656C6C656565656060656969686B6D6B716A65695F615C5D\
655E595E58505F54515E5B515A4E445D565457524D524E47544E476871796B8291
65757E65757E65757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E5243405B4F49
65656865656165655E656565656C6C656565656969656F6E656C6C6565656565686864616B635B\
655C54655C5761545262524C5E4E47544A42544A425D4E475A4E4761747F657C88
65757E65757E65757E65757E65757E65757E65757E65788165788165757E65757E656E77656B75\
65727B65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E211E1C3F3E386B6E65
65656565656865656B65656865696965656565635C65666465636365636365655E6568605E595B\
5E57546153545E564A574E4457524C5D50495A4E475A5A545D59516B7F88687B85
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E657881657B85\
65788165757E65757E
65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E4C4E5D180E0E545259686866
656C6C656868656C6C656868656363656969656F7165656865635C6552555E4A4A5545425B504A\
615A525B5C5454524C5E524D5E544D544E42544E46544A4452484262727B65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165717A65727B65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E6B7C8617120E6E6A58A09B86656565
6563666563636563636563636565656563636566676565655E5F5A5B57545E5A525E56505B534E\
58514B5B51465A5048574C46574A445D4C47604E495A4E475D544D615D5F62686F
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E656E7765757E65788165757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E0F0B09625D5AA29E9A686866656565
65656565656565655E656563656565656C6C65656565636361383F612E385B2A315B28315E2A32\
5E42425748445748445A4640544C40584E465A4E47574E425A463F4F3D365B6266
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E656E7765727B\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E4C4E578A878B9C9592656363656561656565
656565655F58655C56655C56656360656363655056654A536140445B3B36542B265B3939573834\
5B343754333752413E524E42544A435A4C475A4E475D4E495D4A455D544D544037
5B585965757E65757E65757E65757E65757E65757E65757E65757E65757E65757E657881657881\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E13111132332F65635765655B65655E656565
65655E5E5B545B524E62625E6568686559525E3839552A284F3E394130264F64585E726754312B\
4F262157302D5A3B3A574A47574A39544E3E584E465A4E475A50495A4E475A504A
656869656F7565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E37333A5E4A4093877968686A5E595762666A65686A
6559545B4C42523D385E485158282F1A0304312D305B504A68625F7FA5A97447454F2E2B3E3E2F\
4459513033274424205138345446385D48435D524D625D4F5E52495A544D5A4E47
5240395B5250656F7565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E656E7765727B65788165788165757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E1B1918525751757777656561615750656060656363
655E58573E355137321F08082D44498CCCCB99C9CB71AAB96EA2B3688088657D7178AEAF84A1AC\
617077382D29191A122F261F54463F5A4C47625852625854625A4F5E50475A4C46
5A524C526079556174626F7865757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E525A711C12125B595665655E65655E686E68686E6D656565
58454044392B3E221B2F100A623A36653E385B3B38625859655D50655A4B5B44425B545D58423B\
75655E7F6D5D77736B2D241E31211F4F3B395B564A65635B615B565A544F5A4A43
5A4A4454564D464841464C5F5B687865757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E211E1C01000049362F968A7D68686365595465545065605965655B
5E4E466A625D81958CA6C9B1999A97685F615B4D4E55403E58292F4F2B334E25275118174C181A\
4C3B3A4F352F5A393D5B423F2A0E083B2E315E514A615E585E564A5A4C44544E47
58574F5D534C787E8663697B626F7865757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E656E7765727B65757E65757E65757E65757E65757E65757E\
65757E5254630A09080F0D0C727977787C74655F5A65545D5E616162686365525A
5E4D4C4C3B305E5A5C686F746571706879746E86837184816E8A7B6B78676E7869687E66687764\
61524864373C60302F54221A4E1A14411A154636365E52505E534A5A4E47574842
5A4A445A4D48160E0C3E42416B7779626F7865757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65788165788165757E65757E65757E65757E65757E65757E\
65757E5A687CB3A695EFBD9FA1907C62635C65625D656E63685C5F686061656E63
5E5F5460504A655E58625D5B65696965686865636365696965545D615252615A545E56525E524D\
5450434F524551624C606757747363756966635A455851485B534A5A4E47575043
5A50475A524C3333324F595C5B6B72687B8565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E6F65556F655B687579656D685E5F5A62656165686A656E6D65757465686D
65635F645B5358443E58514D626664656C6C656868656969656E636161565B48425B4F44514C3F\
4646404C42384F3B354F3E354F3D355144355D594F615B585E504C544642544542
544C42524C441B161555637E6B7F9165757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
5E687162605C5E5952554539494E595E5F61686568656C6F656F6E656C6C656C6C
685961685C5B64554D655752655D5E6566676552585E54516260595B534E5B524B513B36514342\
573F395742385448405A4E3C574A3B54423562504A62504A574A44544842574A43
574E495D544F120E104148485B686965757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
68605568605B5B514E544B486862586F5758656065656969656969656969656969
656E6368695D615D4F5B4C44625D5E656969656E6A68717068686D655C5F615A565D574F60554D\
57423B54403B54443F574A47604C4A6D5D5967625B574E47574C465D50495A4C45
574E42544C441C13101A16163A424E65727B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
6565615E5F5849372C5E5F586F5E66686863656E68656969657177656C6E656969
656568656B685E5A555E5A4F5E645A62605E65635C656C69656868616158574C44574A44544E47\
574E475D523E57443957484262575568645F615A545A5A545A5951545049545049
57504B5D5A557D5C3F582E22160F0F2A343D65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E655A57\
583833491C1F5137385160635B6B63656E63656565656969656664656664656969
6565655E5F5A61615B686F6A6B716C6868605E5252625A576550535B4A4258433D5445404F403A\
5446354539324C3D395D574F615D54615C545E56505A504A5A4A445D4C465A4E42
5D48405D534E5D4E4A796259C0DADF9FBAC265757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E655258\
5E3C3E57383757534B6B675F6F6868656C7265686A656969656969656969656363
65635C61625A685E5865625D656568656C72687172686E706561595E5850544A454F443D4C3F38\
493D39544642665F57676259625E59615C575E56505A524C5A4E475A48475D4549
574845585657513F3454463E6B7C8668788165757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65605D655F51\
5E5749514A385A594D6B6B65686868656969656C6C6565656560605E5A53626057
6552586153545E54505E585465636365635C65636065656565575F5E474657464054463F574840\
5350485A57495D574E5E5650655A545E534E5B4D485A504A5A48425A4840544A40
5450425A5854604E485D554F494F57555F6965757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E584A3F412A25\
221D1A2D2B28585957686B6665656565636365606065635C655F55615F585E5254
55524C5B5754616461616A636568606565656565686565655E675D5B594D574C4554463F54463F\
5D4A435D4E496252546256525B534E5B5A545E5A545A544D5A574F54554D544C45
5748495A53564F2F23584E485A392F655E5F65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E573E351C140E\
211D1C201B1D464B4C65656865656865655E65655B65656565686D686B706B7172
6861615E4D4E5244405B514E5E5C5862636365656565655E6154545747444E3D425142394E4038\
5448425D544D5A4E46544D465B4D4E574642544944514A44524A44544C46574A43
574A47544A424C44314C4436523B3965758165757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E6568696254545F443A\
3627202A21205E5A5465655E5E5F55626363656563524C4649433C392E29322723
342D2C3E323652434154433F554A48626060656565656568615A5B5A4E4754483854423251463F\
51463F47443E41433F4C4A4454564E51504758524C5D544D5A5049574E47574A43
574A47574E473A2823301816442F2662727565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E5E534C5B49440E0706\
090B0C161616585B5661625D655F5A68655E65655E68635D4E48423936301E2427
0C14171115112826212D191629111048393862605E6565656161585A504754463B4E4E3C483E35\
574E48665B536C5B5366534B57444449413F554F4A5A524C574E474C4842474842
52504757504749342B4B2D2357352E656E7B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E6B7C866B605B5A463F362724\
20161326161465625D686B6561645F626561656561686B6D665B5584706E453831
20151320161220272A3B36306F695C747D73656F6E65777C616A655A5049483B3545362F230B08\
372828443527372F2825211D3736314C4840544C40524A42544C4651443D514842
5748474C403C3225233F322B5A4C486F869368788165757E65757E65757E65757E65757E65757E\
65757E65757E65757E
656B7565727B656E7765727B65757E65757E65757E65757E65757E0A0303180B0F5C534E413029\
1D1920181311585F5A5E5F5A65656161625D5B5C58626363686D66625D54715D50
A17E6990674A7C553C79644E6E6257655E586566676566646158525A4C465A4437524038543E32\
484B4B1D272E0103051114172327270E1110181C2127241E4131284E463F514C45
574A423F3B33241F1A26211E4F4E486B838965757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65717A65757E65788165788165757E65757E65757E65757E0E07080C09090B040200060B080910\
0F0F0E22171468645F61625D656568543D414E3B3B5E5A5B686F716E7679716B6C
66544F695D5772625B7164586B635D65635D6569696569696157585A5854544C3F54523D624F3C\
7360507853421B1213251A14252021211C1C3D312954403862594D594A42534842
575043241D1D1C1815291C17492A255B5E6962727B65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
657B8565788165757E65757E65757E65757E65757E65757E2417152B2119291B171D1B1A0B090A\
211614291715655B56685F5A615F586B777263695F3B2F292F211E28211E1A1B1B
141516171716211C19271C1A403E3E5B625C65656565605961574E5A564E544640573F37514A3B\
5452435D554B957864A47B62724D3B6D4534805B4D715A43544E455450455F554B
514A45231D171D15132C1D1848271F5E6B7565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2A1B15180E0B11100F15110F1C1310\
1714112625235858525E5C586868636868686F71727E857C6E5E5B49444A685454
755749735D50634E437464597B7D736F717268686A65525A6159585A585254404533221E281A18\
3E372F524C3E574E406353496D604F666154635D4E4E4E49574A4D514845524C42
3F393111100E11110F6351455935285E757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E656E7765727B65757E65757E65757E65757E32251E21100C1C13101713100B0607\
1811102A232149443F55535062635E656565656C6C6872747586868F9E958F9E95
859E9B8CA1A08FA4A286958B6B726A656C6C5E625A5B65585E6358625C576B6B5F746F5E483535\
1E1919090C0E1F1E21494340544E435D5043514A4351423D423D355146445D4845
241B18150F0E26221F4631293A21191210112D343D65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65788165788165757E65757E65757E65757E262322201D1B1B15121C131016100C\
1C141128232151443D615B5665656165656565696965696965717765747C65747C
656C6E657177656C6E656C6F686B6868655E68655E655E58615450655E5868645D6E64637E7771\
92756B664E462D231D0B0F0F0F1115151C2020201E28231E514444634E4751443C
1C14131711101D1618140A09180E0C28272868788165757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E322826382B291915121A13101C1411\
21181B2924233F3B344C4C485E605C65655E656360656667656664656A6C656E72
657177657177656969656969656C6F656866656561615E5861615B615A54615B56615A58625C54\
615F546E62547D6B5B7A65535F4939523C30684B406B5E545F4A4C4946423E4039
1E16141B1310151310100F0B171715272A2B65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2F221B261C16221B181D14111F0F0C\
231614291E172D282446413F5B5A5662635E656565656969657177656969656A6C
656E72656E7265696965696965635C656363655F5D615450615B5661615B615A546157505E534C\
624D4861524C5F534B6F5E5576645979695D6D5A51624E4D5F4E4559483D362720
1D14121B13102417151A14111A1311231C163C373C51586365757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E261E182A2827221C1B23171513100C\
16131015110F251D1932281F4F4B4765635E656565656969656E72657177656969
656A6C65666465666465696965656165655E5E5B545E5E58615A54615450615752615A545E5650\
57524C57524C5D5A545750495A4C465A4E474C4A43474A42474A42393B34171A1A
0C0D0B1B1619120F11100E0B0B06071B141336323458656C65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E32241D2923212A2422231D1B251916\
1E1411231C1A2D2A292D2D2C4947465E5753656363656363656362656A6C657177
6571776569696569696569696565685E5F5D5E5B56615752615752615A545B5A5458534E5B534E\
5A524C5A524C5A504A5D524C575049544E47514A435D4A4356443D3128251C1312
241B19100B0C110E0F0C0708140F111B14113437385E727B65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E2A28272B29282E29272C2624231816\
120F0C1F161430211B473228573D3058514C62635C656563656363656362656A6C
656E72657177656C6E65696965656568686365605B5B5A5458534E5E51525E514E5E4D485E4D4E\
5A504C5A524C5A4C46544A44544C4651423C5A4640513F38312D2C221C191E1513
110E0B120E10100B0C14100C15101123171592A9B38CA6B065757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E656E775E656E26201F2621202A2625282321191310\
231C1A251E1B211F1D39312A4E423C58575462625E656565656C6C656C6C656E72
656E72656E726569696569695E5F58625C56615450655752685C575E58505B564E5E524C575850\
57544C544646524A46544E47574E475A4C454E4C45403D3541352B271E171F1614
18141118141119151115100C1814102217156B7C8668788165757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E657881687F8824201D30221B2922202B27262F2826\
251E1B26201D2B201937383436332D4C413D5B5753626363656363656667656664
65635F65635F65605E5E5A535E56505E5F5A5E5A545B534858514A5B53485E564E5E58525A524C\
5A504A5D50475A50475748425745404C4842403F383A3029221C1D181213131110
110E0B120E100F0A0C0806070E0A0B3224236F7C8562727B65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3329272A20192A27262D2826231E1C\
2016142A1E172A24222F2D2A2B201D3F353258595665655E65655B656360656059
65605765605765636068686365605B6154505B49445B4B485E4D505E53525E56525E4A445A4D48\
5A4C465A4C46574E47574A4351443D423D363A2F28221B1D1E1A1617120F151310
1C1411151011100B0C110B0C291916B2CDD39CBDC565757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3E3C3C2C28262723222F26252B1F18\
27211D201B1A252221201B1B21222434322B433D3555514D5B5C5862635C65655E
6565615E5F5A5B5C5662635C6157525B4B465B5348574E465450485450485B4D48574C46574C46\
5A4646544C47544E4251443C4C443D423D352D211E201B1615110F100D0B120E10
1A1310140F100D0708100B0C21171562727B62727B65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E3936312D28262E2927272321262322\
1C16191F1918231E1C2D28262A1F18241C182D2F2D413B395243405B514E5B5450
5B5A565E5F5A615B565E5652585550544C46544844574A465A46405A4742574A44574C46544842\
5248404F423A493E3A3E3D38342F28332922201B1614100F131110130F0C100B0C
0E0A0B070607080707251916311E166B787E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E6A70833C30312D2726282321322D2C\
2F221A2418142E2827241F1D2A27261E1B1A2227261A1F1F232221433B39493F3B
4C45484E474C4E4A4855524E4F454039322D37302C44352C4F443D524842523B3552413D544836\
51443A4C3F38483933423933312623221815191212191210130F0C0F0A0C100B0C
0D0708090708110B0C1B131091ABB69CBAC665757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E758C9142413724201D252120262120\
1D1D1C1B171A261D17282220322D2C312B292823222725282C292825231F1D2126
1821231E1E1A2D2A262F2E2B2424252B26212D251F2D2C22342A253B3127493D30433931342A27\
3729263E302B33302F2A22212418141D1413161110110E0B0F0A0C0C0708080707
0807080907081814112519166E7F88687B8565757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E525667302A2A2E2927292927\
2B2523171310211E1C302D2D322D2C3531303A35333E3A323837302A2F2B222122
241A1621191B211A1A251F1F201D1F201F222A21202B201A241E1D2B29252B292427241F312B25\
2C261E272725281F1C261D181914131C1A19120F0C120F0C100B0C0D0708090708
0907081F15111610115D55568999A165757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E74818D3C302E292321272120\
2822212F2725352D2B322D2C33302F2A2625262222291D1D321F1D2D1D19241F1E
1B18172021211814131A1C1D1F1F1F1E1C1B171312141516141213141010151413171714171714\
15101116101014101016121212110F0F0E0B0E0A0B0F0A0C100B0C090708090708
1F151B1F151230282596B0B682A0AA65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E6B7F85616B6F332D2B282321\
2D2826292422353130231E1C292626211C1B28242439332C2A2A28222323262322
26201D3329271F171A1E1E1D1D14121E141218110F13110F16110F1E16141E161415100F14100F\
15110F1D1614181310171210120E0B130F0C100B0C100B0C090708090708110B0C
251D19251915A6BDC59FBAC265757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E696F7D3928262F2826\
2D28262823211C1B1A2C29293834322B2A28231F1D281E191C16151F1B1A221D1B
17151C1A1B1B1A1617211614191118131210141310120F0C151310141310121210100E0B0E0A0B\
100E0B171210110E0B0E0A0B120E0C140F11100B0C090708100B0C1B15122B201C
261916A6C0C9A6C4CC65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E6F858B4A4C492C2826\
2A26252823213029272A2827262323211B1A1F18171C181715110F221D1B1C1618
1D16171A110F181117100E100C0A0B110E0F120E100F0A0C120E100F0A0C120E100F0A0C140F11\
181411130F110F0A0C08070808060707060708060714101116110C100B0C170D0B
97A8B0A3BDC665757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E8CA6B05F5C5A\
292220252120272726272726302C2B2B2528221715211A1816131017110F13110E
18120F0E0A0B0D0A0B120E0F141011100B0C130F10100B0C140F10100B0C2518150A0708120F10\
171310140F100907080907080E070816101118111216101125181637251C6D4D3A
8F9C9D687B8565757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E8CA6B0\
615654312E2C231E1C302929322C2B322D2B23221F26221F1C141A130F111A1310
130F101714111A1511151011100B0C100B0C100B0C100B0C100B0C181410120F11292D3E34363A\
20161E100B0C1510111C16121C16121511112A221F2B201C251916422E2895B3C3
85A9B965757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
94B2BC6156543C3331241F1D222222302F2E362F2E2F211A241C18191510130F10
0F0A0C120E0B120E100F0A0C100B0C141011110B0C141011110B0C0F0A0C282B2F251D28372D2B\
443B343A3030453A363328231A1512251D1A241C192E2927452E26A3B7BF8FB0BC
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
62727B89A6B055453B3D3532322B29332F2E33302F383534241E1C241C1A342A26
2D2823211613191411151011151011100B0C100B0C18141A151012191511120E0E1C1B1724211D\
0C0A0C0C0D0C0E0E0C0C0B0D17110F221B192B201950382B8C93A088A9B9657881
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E8FB0BC55554D241F1C2622223936374142423D3937261E1C1B1517
1E14132D2523292522161112100B0C1C181F201B232824201F1A20372E2D1C161D3C35342F272A\
302826372C282F2522352B27473E34342C28594236A3B7C293BAC66F858B65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E8FA9B6A6B2C64D46442824242421212D333F464445554D49
555652312C2F26292E424254605C5A3D31322D29352F272B403E4E352E2D2F2723352E2B302625\
35242135231C31292640352E573E3139251D8CA9B685ADBC65788165757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E72898EA3C3C95C58653A35362A2E353F444B42474F
3B3D3F4244425453565047423E3834322C2A3C352F2D2626201B17221D1A302C2B2D2826382620\
422D2644352E52413A402922433E4999C0D699BAC665757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
656B7565727B65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E8FA9ADC0E4E8BACAD9514F6249464F
6B6B8366616D524545403A393E3C3C52494F5B4E4E524A48645753534A414E49465B504E48463F\
3B413B2A28275C6478A6D1E4B3E4EE85A3AA65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
657B8565788165757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E6B7F8595B0ADACCDCC
95B7B68398AA99B4C38A98B45257713F485F363A3D3838393838393A3A3C3936382D28242D2B27\
8C9EAAC3E8F4A9D1D5758F9465757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E6B7F816B8285728C8E96B3ADADCAC3B0D1D2B3CDD7B3D4DFB3D7E2B6DBE5BDE4F1C0E7F7\
92B0BC65788165757E65757E65757E65757E65757E65757E65757E65757E65757E
65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E65757E\
65757E65757E65757E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH06EeOP@0HF9M101U
IF4406EUI@@0IFUY101UIFD?06EYJ@@0IFEU101UIF44065RG@<0HEiH201NEU0C05YBC0@0FTi7101G
CT<405M>A`@0Edi3101GCTLC06EeOP@0IG5j9P1UMGhF0?ooo`00503ooomH06EeOP@0HF9M101UIF44
06EUI@@0IFUY101UIFD?06EYJ@@0IFEU101UIF44065RG@<0HEiH201NEU0C05YBC0@0FTi7101GCT<4
05M>A`@0Edi3101GCTLC06EeOP@0IG5j9P1UMGhF0?ooo`00503ooomH06EeOP@0HF9M101UIF4406EU
I@@0IFUY101UIFD?06EYJ@@0IFEU101UIF44065RG@<0HEiH201NEU0C05YBC0@0FTi7101GCT<405M>
A`@0Edi3101GCTLC06EeOP@0IG5j9P1UMGhF0?ooo`00503ooomH06EeOP@0HF9M101UIF4406EUI@@0
IFUY101UIFD?06EYJ@@0IFEU101UIF44065RG@<0HEiH201NEU0C05YBC0@0FTi7101GCT<405M>A`@0
Edi3101GCTLC06EeOP@0IG5j9P1UMGhF0?ooo`00503oool406EeOP@0IFig101ULW/306EeOP@0IFig
101ULW/S06EeOP@0IFig0`1ULW/G06EeOP@0J6QS101XJ6X406EUH@@0IFUW101UIFD706EYJ@@0IF=L
101NFU4405]JD@@0FeI@101HD4`3059<B0@0DD]6101DCDP4055:A0@0F51:1`1JDT`805Y<APP0Edi9
101GCT<405MXK`<0IH:A401UMGh706EhPB<0IGEn5P3oool001@0oooo101UMGh406E^M`@0IG9k0`1U
MGh406E^M`@0IG9k8`1UMGh406E^M`<0IG9k5`1UMGh406QXH`@0J6QZ101UIF4406EYI`@0IFEU1`1U
JFT406ESG0@0GUYA101KFU4405]FD0@0F51<0`1BC4P4055;AP@0E4e8101ABT@405Q@BPL0FU9<201J
C4H805M>B@@0Edi3101GJ6l306F2TA00IGEn1`1UN84S06EeOQH0oooo000D0?ooo`@0IGEn101UKWL4
06EbN`<0IGEn101UKWL406EbNb<0IGEn101UKWL306EbNaL0IGEn101XJ6<406QXJP@0IFEQ101UJFL4
06EUI@L0IFUY101UHe`405iJD@@0FeYA101KEU0405Q@C0<0DTa8101ABdH405A=B0@0DDY4101HD4X7
05YBC0P0FTa6201GCTT405M>@`@0EfQ_0`1UPY4@06EeOPL0IGR18`1UMGhF0?ooo`00503oool406Ee
OP@0IFig101ULW/306EeOP@0IFig101ULW/S06EeOP@0IFig0`1ULW/G06EeOP@0J6QS101XJ6X406EU
H@@0IFUW101UIFD706EYJ@@0IF=L101NFU4405]JD@@0FeI@101HD4`3059<B0@0DD]6101DCDP4055:
A0@0F51:1`1JDT`805Y<APP0Edi9101GCT<405MXK`<0IH:A401UMGh706EhPB<0IGEn5P3oool001@0
oooo101UMGh406EhP@@0IG5j0`1ULW/806EhP@@0IGEn101UKWL406EbN`<0IFig101ULW/@06EeOPL0
IGR15`1UMGh405iOFP@0HV=L101UIFD406ESIP@0IFUY0`1UIFD406EPH0@0GUaH101<FEX4059BD0@0
F4I8101DAd@305MAC0@0FUQB101JFU@405eFC`@0Edi71`1BBT@4059<AP@0DTi2101DCTH405M>A`@0
Edi9101bRIL307:9U1@0IGEn0`1UKWL406EbNal0IGEn5P3oool001@0oooo101UMGh406EhP@@0IG5j
0`1ULW/806EhP@@0IGEn101UKWL406EbN`<0IFig101ULW/@06EeOPL0IGR15`1UMGh405iOFP@0HV=L
101UIFD406ESIP@0IFUY0`1UIFD406EPH0@0GUaH101<FEX4059BD0@0F4I8101DAd@305MAC0@0FUQB
101JFU@405eFC`@0Edi71`1BBT@4059<AP@0DTi2101DCTH405M>A`@0Edi9101bRIL307:9U1@0IGEn
0`1UKWL406EbNal0IGEn5P3oool001@0oooo101UMGh406EhP@@0IG5j0`1ULW/806EhP@@0IGEn101U
KWL406EbN`<0IFig101ULW/@06EeOPL0IGR15`1UMGh405iOFP@0HV=L101UIFD406ESIP@0IFUY0`1U
IFD406EPH0@0GUaH101<FEX4059BD0@0F4I8101DAd@305MAC0@0FUQB101JFU@405eFC`@0Edi71`1B
BT@4059<AP@0DTi2101DCTH405M>A`@0Edi9101bRIL307:9U1@0IGEn0`1UKWL406EbNal0IGEn5P3o
ool001@0oooo101UMGh406EhP@@0IG5j0`1ULW/806EhP@@0IGEn101UKWL406EbN`<0IFig101ULW/@
06EeOPL0IGR15`1UMGh405iOFP@0HV=L101UIFD406ESIP@0IFUY0`1UIFD406EPH0@0GUaH101<FEX4
059BD0@0F4I8101DAd@305MAC0@0FUQB101JFU@405eFC`@0Edi71`1BBT@4059<AP@0DTi2101DCTH4
05M>A`@0Edi9101bRIL307:9U1@0IGEn0`1UKWL406EbNal0IGEn5P3oool001@0oooo201UMGh406Ea
NPl0IGEn3`1UN84^06EeOP@0J69M101XIFP406EUJ0@0IFEU1`1UHf<406EUGP@0J6QX101eKW04075]
IP@0KVAX101WGEP306EBC0@0IDe>101UCE0405i4AP@0EdY62`1GCTL405M>B@@0GEA?101JD4T405M>
Aa/0IGEn1`1UN84O06EeOQH0oooo000D0?ooo`P0IGEn101ULGX?06EeOPl0IGR1;P1UMGh406QRG@@0
J6EX101UIFP406EUI@L0IF=S101UIEh406QXJ0@0MFi`101aKFH406iTJ0@0IeeH0`1UDT`406E=CP@0
IDe@101NA4H405M:AP/0Edi7101GCTT405eDC`@0FU19101GCTLK06EeOPL0IGR17`1UMGhF0?ooo`00
503oool806EeOP@0IG5j3`1UMGh?06EhPBh0IGEn101XHUd406QUJ0@0IFEX101UIFD706ESH`@0IFEN
101XJ6P407E^L0@0LFeV101^I6P406MMF0<0IE9<101UCDh406E=D0@0GTA6101GBTH;05M>A`@0Edi9
101ME4l405Y@B@@0Edi76`1UMGh706EhPAl0IGEn5P3oool001@0oooo201UMGh706EhPDT0IGEn101U
J6<406EXH0@0IFEK101UIF<706EUI@@0IFEX101UK6l406E_KP@0J6]]101QJV44065QG@<0J65M101X
He/4065FDP@0J6AK101SD4d40615A`<0H5QK101JDTd405e>A`@0GDa6101GC4H405eJE0@0J7^5?@1U
MGhF0?ooo`00503oool806EeOPL0IGR1B@1UMGh406EXH`@0IFQP101UIE/406EUH`L0IFEU101UIFP4
06E/K`@0IFm^101XJfd4065ZH@@0HF5M0`1XHEd406QSF`@0HEIB101XI5/406=@C@@0H4E70`1PF5/4
05YBC@@0GDi7101MC4H405M<AP@0GEYD101XNhDm06EeOQH0oooo000D0?ooo`P0IGEn1`1UN85906Ee
OP@0IFQS101UJ60406EUF`@0IFES1`1UIFD406EUJ0@0IFa_101UKfh406Q[K@@0HFYQ101QHEd306QQ
G@@0J6=K101QEU8406QTF`@0He1=101PADL3061HF`@0FU9=101MCTL405e<AP@0Eda6101MFU@406Qk
QCd0IGEn5P3oool001@0oooo201UMGh706EhPDT0IGEn101UJ6<406EXH0@0IFEK101UIF<706EUI@@0
IFEX101UK6l406E_KP@0J6]]101QJV44065QG@<0J65M101XHe/4065FDP@0J6AK101SD4d40615A`<0
H5QK101JDTd405e>A`@0GDa6101GC4H405eJE0@0J7^5?@1UMGhF0?ooo`00503ooomH06EeOPP0IFEQ
101UIFP406EUH@@0IFES0`1UIFD406E/K0@0IFEU101UH60406EYJ@@0J6]]101[LFX306EYG`@0HEaM
101UGUT405iHD0@0GeAA101NFe4305Y>A0@0GEID101GDTd4059>A`@0E4i7101XLGT406^2TAX0IGEn
101UKWL406EbNa/0IGEn5P3oool001@0ooooF01UMGh806EUH@@0IFEX101UIF4406EUH`<0IFEU101U
K6`406EUI@@0IF1P101UJFT406Q[K@@0Jg5Z0`1UJEl4065LG@@0IEiI101NF50405mDD@@0GU]A0`1J
CT@405eFE0@0Ee9=101BCTL405A>A`@0J75i101[PY4J06EeOP@0IFig101ULW/K06EeOQH0oooo000D
0?oooeP0IGEn201UIF4406EUJ0@0IFEQ101UIF<306EUI@@0IFa/101UIFD406EPH0@0IFUY101XJfd4
06]aJP<0IFUO101QG5d406ENF@@0GUQ@101OE54405iKD@<0FTi4101MEU@405MBC@@0DTi7101DCTL4
06QaN@@0Jh:A6P1UMGh406E^M`@0IG9k6`1UMGhF0?ooo`00503ooomH06EeOPP0IFEQ101UIFP406EU
H@@0IFES0`1UIFD406E/K0@0IFEU101UH60406EYJ@@0J6]]101[LFX306EYG`@0HEaM101UGUT405iH
D0@0GeAA101NFe4305Y>A0@0GEID101GDTd4059>A`@0E4i7101XLGT406^2TAX0IGEn101UKWL406Eb
Na/0IGEn5P3oool001@0ooooE@1UMGh30593@0@0Fdm9101UIFP406EUH@@0IFEN101UIFD306E/K0@0
IFEU101UJFT406E_KP@0IFa/101UIFD406EUJ0<0J6AQ101[He/406ELE0@0IEaG101QE584069BC0<0
GTi7201DBT8405e>A`@0FTi7101QM7l406ElR1X0IGEn201UN84806EeOP@0IFig0`1UJgD406EbN`P0
IGEn5P3oool001@0ooooE@1UMGh30593@0@0Fdm9101UIFP406EUH@@0IFEN101UIFD306E/K0@0IFEU
101UJFT406E_KP@0IFa/101UIFD406EUJ0<0J6AQ101[He/406ELE0@0IEaG101QE584069BC0<0GTi7
201DBT8405e>A`@0FTi7101QM7l406ElR1X0IGEn201UN84806EeOP@0IFig0`1UJgD406EbN`P0IGEn
5P3oool001@0ooooE@1UMGh30593@0@0Fdm9101UIFP406EUH@@0IFEN101UIFD306E/K0@0IFEU101U
JFT406E_KP@0IFa/101UIFD406EUJ0<0J6AQ101[He/406ELE0@0IEaG101QE584069BC0<0GTi7201D
BT8405e>A`@0FTi7101QM7l406ElR1X0IGEn201UN84806EeOP@0IFig0`1UJgD406EbN`P0IGEn5P3o
ool001@0ooooE@1UMGh30593@0@0Fdm9101UIFP406EUH@@0IFEN101UIFD306E/K0@0IFEU101UJFT4
06E_KP@0IFa/101UIFD406EUJ0<0J6AQ101[He/406ELE0@0IEaG101QE584069BC0<0GTi7201DBT84
05e>A`@0FTi7101QM7l406ElR1X0IGEn201UN84806EeOP@0IFig0`1UJgD406EbN`P0IGEn5P3oool0
01@0ooooD@1UMGh4024N70<0?chh101[KVD406EUI@@0IFEX101UIF/406EUJ0<0IFUY101UIFD406ES
G0@0IFIT201UHf<406EUGP<0IFQP101NFE/405iGE0@0HE=D101NETX405M>A0<0Ee9<101MD4T405Y>
A`@0FUYD101MFE4406]oR0@0J7^5:P1UMGh406EhP@<0IG^5101UN84806EeOQH0oooo000D0?oooe40
IGEn100Q7Q`303ln>0@0JfiU101UIFD406EUJ0@0IFE[101UIFP306EYJ@@0IFEU101UHe`406EVI0P0
IF=S101UIEh306EXH0@0GUUK101NEe@4065CE0@0GUI:101GCT@305MBC0@0GE19101JCTL405YJE0@0
GEUA101[OhP406QkQBX0IGEn101UN84306EkQ@@0IGR1201UMGhF0?ooo`00503ooomA06EeOP@08AhL
0`0o?SP406]^I@@0IFEU101UIFP406EUJ`@0IFEX0`1UJFT406EUI@@0IF=L101UIV@806ESH`@0IFEN
0`1UJ60405iIF`@0GUMD101QDe@405iFBP@0Edi40`1GDT`405e@B@@0FTi7101JFU@405eID@@0Jgn8
101XNhDZ06EeOP@0IGR10`1UNhD406EhP@P0IGEn5P3oool001@0ooooD@1UMGh4024N70<0?chh101[
KVD406EUI@@0IFEX101UIF/406EUJ0<0IFUY101UIFD406ESG0@0IFIT201UHf<406EUGP<0IFQP101N
FE/405iGE0@0HE=D101NETX405M>A0<0Ee9<101MD4T405Y>A`@0FUYD101MFE4406]oR0@0J7^5:P1U
MGh406EhP@<0IG^5101UN84806EeOQH0oooo000D0?ooo`P0IGEn101UKWL306EbNch0IGEn101<CUd4
01P>3P<0E59I101XJ6H406E/K0@0IFQX101UK6`406EXJ0<0IF=S101UJFT406E_L@@0IFEX101UHe`4
06EBE@@0GTY:0`1EAD8405]@BP@0HEYB101KG5@405ABC0@0GU9=0`1NE4d405A>@P@0E4i6101DBT@4
0598@P@0HW9k@@1UMGhF0?ooo`00503oool806EeOP@0IFig0`1ULW/n06EeOP@0C4iM100H3Ph305AB
F@@0J6QV101UK6`406EXJ0@0IFa/101UJ6P306ESH`@0IFUY101UKg4406EUJ0@0IF=L101UDUD405i:
BP<0EDE2101KD4X4065JDP@0FeaD101DDT`405iBC@<0GUA=101DCT8405A>AP@0E4Y4101BB484069b
Nd40IGEn5P3oool001@0oooo201UMGh406E^M`<0IG9k?P1UMGh404a>G@@060h>0`1DDUT406QXIP@0
IFa/101UJ6P406E/K0@0IFQX0`1UHf<406EYJ@@0IFma101UIFP406ESG0@0IE9E101NBTX305E5@P@0
Fe1:101QFU8405]LE0@0E59<101NDTd305iDC@@0E4i2101DCTH405A:A0@0DTQ2101RLW]106EeOQH0
oooo000D0?ooo`P0IGEn101UKWL306EbNch0IGEn101<CUd401P>3P<0E59I101XJ6H406E/K0@0IFQX
101UK6`406EXJ0<0IF=S101UJFT406E_L@@0IFEX101UHe`406EBE@@0GTY:0`1EAD8405]@BP@0HEYB
101KG5@405ABC0@0GU9=0`1NE4d405A>@P@0E4i6101DBT@40598@P@0HW9k@@1UMGhF0?ooo`00503o
ool806EeOP@0IGR10`1ULGX406EbNcH0IGEn101[O8H401LB3P@0KVYH0`2PVhH406EUI@@0IF=V301U
Hf<306EUI@@0IF=S101UIVL406EUI@@0GUmJ101KEe@405iJDP<0GUI@101KDdh405QAB`@0Fe56101J
D4P405M<AP<0EdY4101MC4L4061>B@@0FTi7101ME4d4065MG`@0HVQ_?@1UMGhF0?ooo`00503oool8
06EeOP@0IGR10`1ULGX406EbNcH0IGEn101[O8H401LB3P@0KVYH0`2PVhH406EUI@@0IF=V301UHf<3
06EUI@@0IF=S101UIVL406EUI@@0GUmJ101KEe@405iJDP<0GUI@101KDdh405QAB`@0Fe56101JD4P4
05M<AP<0EdY4101MC4L4061>B@@0FTi7101ME4d4065MG`@0HVQ_?@1UMGhF0?ooo`00503oool806Ee
OP@0IGR10`1ULGX406EbNcH0IGEn101[O8H401LB3P@0KVYH0`2PVhH406EUI@@0IF=V301UHf<306EU
I@@0IF=S101UIVL406EUI@@0GUmJ101KEe@405iJDP<0GUI@101KDdh405QAB`@0Fe56101JD4P405M<
AP<0EdY4101MC4L4061>B@@0FTi7101ME4d4065MG`@0HVQ_?@1UMGhF0?ooo`00503oool806EeOP@0
IFig0`1UMGh406EhPCH0IGEn100?2`T4069MFP@0XYjJ0`1XJ6H<06EUI@@0IFEN101UIF<306EUI@@0
IFa/101UIFD406ESH`@0HCPo101Q;SP405/Z<@<0FbPa101N:S8405i2@PP0EdQ4101JAT0305A<@0@0
F4i6101JCTL405M>@P@0FTHo101??CH405]RIRX0IGEn101UKWL306EbN``0IGEn5P3oool001@0oooo
201UMGh406E^M`<0IGEn101UN84f06EeOP@03`/9101RGEX40::NVP<0J6QV301UIFD406EUGP@0IFES
0`1UIFD406E/K0@0IFEU101UHf<4064h?`@0HBhh101K:S4305/X<@@0GRXb101N@T8805M8A0@0FTI0
0`1DC40405Q>AP@0FTi7101GCT8405Y6?`@0Ccdf101KHVHZ06EeOP@0IFig0`1ULW/<06EeOQH0oooo
000D0?ooo`P0IGEn101UKWL306EeOP@0IGR1=P1UMGh400l;2@@0HUeJ102RWYX306QXIP`0IFEU101U
IEh406EUH`<0IFEU101UK6`406EUI@@0IF=S101Q>3l4064^>0@0FbXa0`1K:34405hZ<P@0GT92201G
B4@405Y6@0<0E4a0101HCTH405Y>A`@0Edi2101JASl404lm=P@0Ff9V:P1UMGh406E^M`<0IG9k301U
MGhF0?ooo`00503oool806EeOP@0IFig0`1UMGh406EhPCH0IGEn100?2`T4069MFP@0XYjJ0`1XJ6H<
06EUI@@0IFEN101UIF<306EUI@@0IFa/101UIFD406ESH`@0HCPo101Q;SP405/Z<@<0FbPa101N:S84
05i2@PP0EdQ4101JAT0305A<@0@0F4i6101JCTL405M>@P@0FTHo101??CH405]RIRX0IGEn101UKWL3
06EbN``0IGEn5P3oool001@0oooo201UMGh706EhPCH0IGEn101<CUL408Z7R`@0W9FB101UHf<306EU
H@P0IFEU101UGeP806ELEP<0IF=P101UHf<406E@EP@0IDYC101Q@4@405/k=P@0E2/V0`1K>CT405Lh
=0@0Fc@g101D<cL40591?P@0DTi20`1DBT<405Y<A`@0FTi7101MCTT405e:A@@0GEA=101D@3L305]H
FBL0IGEn1`1UN84<06EeOQH0oooo000D0?ooo`P0IGEn1`1UN84f06EeOP@0C4iG102:Qh/409bETP@0
IF=S0`1UIF4806EUI@@0IEmH201UG5H306ESH0@0IF=S101UD5H406E:D`@0HD14101K>cH405@[9P<0
FcTi101G>3@405/d=`@0E3<g101B@Ch4059>@P<0E4Y3101JC4L405Y>A`@0GDi9101MBTD405eDC@@0
E40g0`1KF5TW06EeOPL0IGR1301UMGhF0?ooo`00503oool806EeOPL0IGR1=P1UMGh404a>E`@0RXN;
102LUI8406ESH`<0IFEQ201UIFD406EOF0P0IEaF0`1UHf0406ESH`@0IE1F101UBU<40650A0@0Fc/f
101D:bH305/i>@@0EcPd101K=3L405@c=`@0DT4n101BCT8305A:@`@0FTa7101JCTL405e>B@@0GDY5
101ME4d405A0=`<0FeQI9`1UMGh706EhP@`0IGEn5P3oool001@0oooo201UMGh706EhPCH0IGEn101<
CUL408Z7R`@0W9FB101UHf<306EUH@P0IFEU101UGeP806ELEP<0IF=P101UHf<406E@EP@0IDYC101Q
@4@405/k=P@0E2/V0`1K>CT405Lh=0@0Fc@g101D<cL40591?P@0DTi20`1DBT<405Y<A`@0FTi7101M
CTT405e:A@@0GEA=101D@3L305]HFBL0IGEn1`1UN84<06EeOQH0oooo000D0?ooodD0IGEn100C4A44
038c;`@0IF=G101UIE/306EUGP@0IFEU101UIEh405iKE0@0Fe9>101RHUh306EXJ0@0IEUB101N>3T4
05DZ:0@0Cchi1011<2H404mTF0<0GW9W101D<B/404lV8@@0Ec0]101J>cX405M:A`<0EdXi101DCSh4
05Q>AP@0FTi7101JD4T405Y>A`@0FU1:0`1UJ6T406E_MCH0IGEn5P3oool001@0ooooA@1UMGh401<A
4@@0<S<_101UHeL406EUF`<0IFEN101UIFD406EUGP@0GU]D101KDTh4069RGP<0IFQX101UFE8405hh
>@@0EBXX101??ST4044`9P@0CfAH0`1NLVL405@a:`@0CbHQ101G<2d405Xk>P@0EdY70`1GBST405A>
?P@0F4i6101JCTL405Y@B@@0FTi7101JD4X306EXJ@@0IFme=P1UMGhF0?ooo`00503ooom506EeOP@0
4a4A100b<bl406ESE`@0IFEK0`1UIEh406EUI@@0IFEN101NFe@405]BCP@0HV9N0`1UJ6P406EIDP@0
GSPi101E:RP404ln>@@0@C0V101?I5P305ibI`@0E34[101?9R4405L`;@@0FS/j101GBTL305M:>@@0
E4hn101HCTH405Y>A`@0FU19101JCTL405Y@BP<0IFQY101UKgDf06EeOQH0oooo000D0?ooodD0IGEn
100C4A44038c;`@0IF=G101UIE/306EUGP@0IFEU101UIEh405iKE0@0Fe9>101RHUh306EXJ0@0IEUB
101N>3T405DZ:0@0Cchi1011<2H404mTF0<0GW9W101D<B/404lV8@@0Ec0]101J>cX405M:A`<0EdXi
101DCSh405Q>AP@0FTi7101JD4T405Y>A`@0FU1:0`1UJ6T406E_MCH0IGEn5P3oool001@0oooo3`1U
MGh406E^M`@0IG9k:P1UMGh403Lc>P@0GTY0102CQgT406QXJP@0GUUG0`1RIVX406EXJP@0IEUD101K
C484058m>0@0GTQA0`1H:2l401X310@0<Bd`101KD4X406QRG`@0OjFY101dAdD304l^:`@0?Sh_1014
FE44030c9`@0A2@P101A>3@305A6>0@0GDQ3101MDTd4069MC`@0GU99101JE4d405Y>A`<0DT0i101K
DU0406E_MC80IGEn5P3oool001@0oooo3`1UMGh406E^M`@0IG9k:P1UMGh403Lc>P@0GTY0102CQgT4
06QXJP@0GUUG0`1RIVX406EXJP@0IEUD101KC484058m>0@0GTQA0`1H:2l401X310@0<Bd`101KD4X4
06QRG`@0OjFY101dAdD304l^:`@0?Sh_1014FE44030c9`@0A2@P101A>3@305A6>0@0GDQ3101MDTd4
069MC`@0GU99101JE4d405Y>A`<0DT0i101KDU0406E_MC80IGEn5P3oool001@0oooo3`1UMGh406E^
M`@0IG9k:P1UMGh403Lc>P@0GTY0102CQgT406QXJP@0GUUG0`1RIVX406EXJP@0IEUD101KC484058m
>0@0GTQA0`1H:2l401X310@0<Bd`101KD4X406QRG`@0OjFY101dAdD304l^:`@0?Sh_1014FE44030c
9`@0A2@P101A>3@305A6>0@0GDQ3101MDTd4069MC`@0GU99101JE4d405Y>A`<0DT0i101KDU0406E_
MC80IGEn5P3oool001@0oooo3`1UMGh406E^M`@0IG9k:P1UMGh403Lc>P@0GTY0102CQgT406QXJP@0
GUUG0`1RIVX406EXJP@0IEUD101KC484058m>0@0GTQA0`1H:2l401X310@0<Bd`101KD4X406QRG`@0
OjFY101dAdD304l^:`@0?Sh_1014FE44030c9`@0A2@P101A>3@305A6>0@0GDQ3101MDTd4069MC`@0
GU99101JE4d405Y>A`<0DT0i101KDU0406E_MC80IGEn5P3oool001@0oooo201UMGh406E^M`<0IG9k
201UN84Z06EeOP@06aTH101BEe4407EgM`@0IFEQ101QEe0306EPH0@0IF=S101UGUP405Ln=@@0DCLb
100O20P302e4B@@0S<c;102IbL/4076Z^@@0KZ:c101XP8P406EmL@<0N:j_1024XJ`4065`M`@0>2dY
100I6Q8402lV7`<0E4Ho101JC4L4069HDP@0HUQD101RFTl405i@A`@0FTa60`1JDT`4059PN@@0EF5d
101RKgP^06EeOQH0oooo000D0?ooo`P0IGEn101UKWL306EbN`P0IGR1:P1UMGh401/I60@0DUMA101e
MgL406EUH@@0HEM@0`1UH60406ESH`@0IEiH101G?SD4054g<P@07`P80`0]A4T408c<b`@0VLW;101a
Z[T406jR/`@0J828101UOG4307R^[`@0Q:6/101QL7L403P]:@@06AXB100_9Ql305A6?`@0FTa7101R
F584069HE0@0HUY?101ND4L405Y<AP<0FU9<101BH7T405EQM0@0HVmh;P1UMGhF0?ooo`00503oool8
06EeOP@0IFig0`1ULW/806EhPBX0IGEn100K6AP4059GD@@0MGMg101UIF44065GD0<0IF1P101UHf<4
06ENF0@0Eche101A=c8401l820<0;DA9102<c</409W9b`@0LJZi101^X[<406R0R0@0IGea0`1h[Zl4
08BQ[0@0HG1g100h;BT401TJ4P@0;bHO0`1DASl405Y<A`@0HUQB101RF5@4069JC`@0GU17101JC4H3
05YBC0@0DV1i101EHG@4069_N2h0IGEn5P3oool001@0oooo201UMGh406E^M`<0IG9k201UN84Z06Ee
OP@06aTH101BEe4407EgM`@0IFEQ101QEe0306EPH0@0IF=S101UGUP405Ln=@@0DCLb100O20P302e4
B@@0S<c;102IbL/4076Z^@@0KZ:c101XP8P406EmL@<0N:j_1024XJ`4065`M`@0>2dY100I6Q8402lV
7`<0E4Ho101JC4L4069HDP@0HUQD101RFTl405i@A`@0FTa60`1JDT`4059PN@@0EF5d101RKgP^06Ee
OQH0oooo000D0?ooo`P0IGEn1`1UN84_06EeOP<0DUYa100L4Q8405]IEPP0IFEN101XKVP306Q^K@@0
IFEU101HAD0404@i:`@0?R8K100_40X3068j=P@0IChh101K>cP4069HF@@0IEe@101UFT/405]4@P<0
FeAM101H@S/407EUGP@0OfeM101gLf/402dT7P<0<B4O101?>cT405]FBP@0IF=K101QFeH405YDC`@0
FTY30`1JBT@405AFC@@0ATQ11016C5l405]XN2X0IGEn5P3oool001@0oooo201UMGh706EhPBl0IGEn
0`1BFW4401`B4P@0FeUF201UIEh406Q^J0<0J6i]101UIFD405Q5@0@0A3T[100n8Q/402l@2P<0HSXf
101U?SP405/k>0@0HUQI101UGE0406EJB`@0FdA20`1KE5d405Q2>`@0MFEN101oKEd407McJ`@0;B@N
0`0a8Al404lk>@@0FeI:101UHe/4065KEP@0FUA?101JBT<305Y:A0@0E5I=1016B44404I<G`@0FfQh
:P1UMGhF0?ooo`00503oool806EeOPL0IGR1;`1UMGh3059JL@@0718B101KFEH806EUGP@0J6iX0`1X
KVd406EUI@@0F4E01014>B/403hR6`@0;a0:0`1R>SH406Dn>0@0Fc/h101RF5T406EMD0@0IEY;101K
A48305]DG@@0F48k101eIEh407m]G@@0Mg=[100]91h3034Q7`@0Cc/i101KETX406ESF`@0HE]F101J
E4l405Y:@`<0FTY4101DETd404I8@@@0ATaO101KJ7PZ06EeOQH0oooo000D0?ooo`P0IGEn1`1UN84_
06EeOP<0DUYa100L4Q8405]IEPP0IFEN101XKVP306Q^K@@0IFEU101HAD0404@i:`@0?R8K100_40X3
068j=P@0IChh101K>cP4069HF@@0IEe@101UFT/405]4@P<0FeAM101H@S/407EUGP@0OfeM101gLf/4
02dT7P<0<B4O101?>cT405]FBP@0IF=K101QFeH405YDC`@0FTY30`1JBT@405AFC@@0ATQ11016C5l4
05]XN2X0IGEn5P3oool001@0oooo>P1UMGh4024N70<00@001019=Rl409J:O@@0J6QS101UFE@406ED
D0<0IF1I101UIE/405i>AP@0JV9M1021UH`40:K9/@<0VIZG101XGf4405]=CP@0ED0n101H:Bl404l[
<`@0CRDW0`1A61L404`H6P@0C3/j101?=Bl405Xi?@@0Fd8o0`0Z3PP403/^<@@0GU5:101QGUP405iF
BP@0FTa4101DCTL305QGC`@0GE=<101hOXH406=YN`@0HVmh:P1UMGhF0?ooo`00503ooolj06EeOP@0
8AhL0`01000404Tf;`@0UXYm101XJ6<406EIE0@0IEA@0`1UH5T406EUF`@0GTi6101ZHUd4086ES0@0
Y/Va0`2IVYL406QOH@@0Fde>101E@3h405PY;`@0Cb/c101>9BL3054H5`@0C1PJ101<>cX404le;`@0
FSTm101K@Sl302X>20@0>bha101NDDX4065NF0@0GUI:101JC4@405A>A`<0F5M?101MDd`407QnQP@0
HfUk101RKgPZ06EeOQH0oooo000D0?ooocX0IGEn100Q7Q`3004000@0BCH_102FRWd406QXH`@0IEUD
101UE50306EPF@@0IFEK101NCTH406YRG@@0PIF<102VbK4309VJU`@0J5mQ101KCDh405E0?P@0F2T_
101?:c<404hU9`<0DAPG101<61X404`k>P@0CcD_101J>Cd405]2?`<0:Ph8100k;S4405iABP@0HEiH
101NETX405Y<A0@0E4i70`1HEdl405eCC0@0N7j6101SJG/4069_N2X0IGEn5P3oool001@0oooo4`1U
MGh406E^M`@0IG9k6`1UMGh4059DH`@02PT80`0?3@`4079iM`@0N7ad101UGeX406EDG@@0GV5Q0`1R
J6<406EBFP@0GTe<101<>c0405iJG0@0J6md0`1ULG0406QiM0@0KXJ3101aQ84406j:N`@0JgQW101^
N6T306QnIP@0J7MT101QDTP406@g?0@0H30_101D8QX304hJ50@0@AXE1016=SH405iBD0@0GU=:101J
CTL405M8@P<0FTY4101JCDP401H>30@0?T91101[MgT4069_N2H0IGEn5P3oool001@0oooo4`1UMGh4
06E^M`@0IG9k6`1UMGh4059DH`@02PT80`0?3@`4079iM`@0N7ad101UGeX406EDG@@0GV5Q0`1RJ6<4
06EBFP@0GTe<101<>c0405iJG0@0J6md0`1ULG0406QiM0@0KXJ3101aQ84406j:N`@0JgQW101^N6T3
06QnIP@0J7MT101QDTP406@g?0@0H30_101D8QX304hJ50@0@AXE1016=SH405iBD0@0GU=:101JCTL4
05M8@P<0FTY4101JCDP401H>30@0?T91101[MgT4069_N2H0IGEn5P3oool001@0oooo4`1UMGh406E^
M`@0IG9k6`1UMGh4059DH`@02PT80`0?3@`4079iM`@0N7ad101UGeX406EDG@@0GV5Q0`1RJ6<406EB
FP@0GTe<101<>c0405iJG0@0J6md0`1ULG0406QiM0@0KXJ3101aQ84406j:N`@0JgQW101^N6T306Qn
IP@0J7MT101QDTP406@g?0@0H30_101D8QX304hJ50@0@AXE1016=SH405iBD0@0GU=:101JCTL405M8
@P<0FTY4101JCDP401H>30@0?T91101[MgT4069_N2H0IGEn5P3oool001@0oooo4`1UMGh406E^M`@0
IG9k6`1UMGh4059DH`@02PT80`0?3@`4079iM`@0N7ad101UGeX406EDG@@0GV5Q0`1RJ6<406EBFP@0
GTe<101<>c0405iJG0@0J6md0`1ULG0406QiM0@0KXJ3101aQ84406j:N`@0JgQW101^N6T306QnIP@0
J7MT101QDTP406@g?0@0H30_101D8QX304hJ50@0@AXE1016=SH405iBD0@0GU=:101JCTL405M8@P<0
FTY4101JCDP401H>30@0?T91101[MgT4069_N2H0IGEn5P3oool001@0oooo4`1UMGh806EhPA/0IGEn
101JJ7`40;>VU@<0kkfO102QT7`4069SG0@0IF9M101UKV<406QLG`<0J61Q101UKV<405iOE0@0H51:
101UGUP4069MF`<0IFUY101UJ6P406ESH`@0IFUY101UE5d4065BDP@0HEYD0`1NEU8405iBC@@0E513
101?DTD4055RC0@0H6MG0`1dLf<407EYIP@0HeY5101HDDP405]CBP@0FTi7101GD4<305Y@A`@0FU9<
100c<c8404mIG0@0Ff]b101XNhDV06EeOQH0oooo000D0?oooa<0IGEn201UN84K06EeOP@0FVQl102c
YYD30>nmW`@0XI1l101RHe`406ERG@@0IFiS101XG5l306QPH@@0IFiS101NGe@4061@BP@0IEiH101R
GE/306EYJ@@0IFQX101UHf<406EYJ@@0IEAM101QDU84065JE0<0GUIB101NDTd405A@@`@0Ce95101A
HT`4061WE`<0M7=S101eJFH406=JA@@0F558101KDdX405Y>A`@0Ee130`1JD4L405YBC0@0<c<b101?
FE`405][LP@0J7^59P1UMGhF0?ooo`00503ooolC06EeOPP0IGR16`1UMGh405YXO0@0/jJE0`3__Il4
0:6@O0@0HV=L101UHUd406E^H`@0J5aO0`1XH64406E^H`@0GUmD101PD4X406ENF0@0HUeK0`1UJFT4
06EXJ0@0IF=S101UJFT406EDG@@0HE9B101QFU@305iFDP@0GU9=101DD4<404mBA@@0DF9<101PIeL3
07AcH`@0MFUV101SFTD405QAB0@0Fe=:101JCTL405M@@`<0FU17101JDT`403<c<P@0CeUL101KJg84
06QkQBH0IGEn5P3oool001@0oooo4`1UMGh806EhPA/0IGEn101JJ7`40;>VU@<0kkfO102QT7`4069S
G0@0IF9M101UKV<406QLG`<0J61Q101UKV<405iOE0@0H51:101UGUP4069MF`<0IFUY101UJ6P406ES
H`@0IFUY101UE5d4065BDP@0HEYD0`1NEU8405iBC@@0E513101?DTD4055RC0@0H6MG0`1dLf<407EY
IP@0HeY5101HDDP405]CBP@0FTi7101GD4<305Y@A`@0FU9<100c<c8404mIG0@0Ff]b101XNhDV06Ee
OQH0oooo000D0?ooocH0IGEn101_IED406mUF`<0J7Ei101UKFP405iOFP@0HVEQ101UJ6X406E^K@<0
IGEd101UJ6d406ESG`@0I5]C101HA3h405QAC@<0HVIT101UK6`406EXJ0@0IFUY101UKV<4065QEP@0
FdQ20`1KCd@4055<?`@0ATI0101<@SP404lk=@@0Cche0`1??CD40554=@@0GEU?101QFeP405i@C0@0
E4I2101DAD8305A<@P@0DTa4100K5QD405ESOP@0JgnA:P1UMGhF0?ooo`00503ooolf06EeOP@0KfEE
101_IE/306QeN@@0IFeX101NGeX4069UH@@0IFQZ101UKVd306EeM0@0IFQ]101UHel406AKD`@0F4@n
101HDDd3069VI0@0IFa/101UJ6P406EYJ@@0IFiS101QHEH405]8@P<0Fdm4101AC3l404I6@0@0C48h
101?>cD404ln=@<0Ccde101AA3D405eIC`@0HE]H101ND4`405A6@P@0E4E20`1DC484059<A0@06aHE
101EHgh406]oTBX0IGEn5P3oool001@0oooo=P1UMGh406mUE@@0KfEK0`1XMGT406E]J0@0GUmJ101R
IF4406EXJP@0IFi]0`1UMG@406EXK@@0IF=O101TFe<405Q4?P@0F55=0`1RIV@406E/K0@0IFQX101U
JFT406E^H`@0HF5F101KB48305]?A0@0DD`o1016AT0404a2>0@0Cc/e101??SD304lm=@@0DD@e101M
FDl4065KF0@0GU1<101DAT8405A5@P<0E4a2101BC4@401/F5@@0EF=n101[Oi4Z06EeOQH0oooo000D
0?ooocH0IGEn101_IED406mUF`<0J7Ei101UKFP405iOFP@0HVEQ101UJ6X406E^K@<0IGEd101UJ6d4
06ESG`@0I5]C101HA3h405QAC@<0HVIT101UK6`406EXJ0@0IFUY101UKV<4065QEP@0FdQ20`1KCd@4
055<?`@0ATI0101<@SP404lk=@@0Cche0`1??CD40554=@@0GEU?101QFeP405i@C0@0E4I2101DAD83
05A<@P@0DTa4100K5QD405ESOP@0JgnA:P1UMGhF0?ooo`00503ooolb06EeOP@0GVQa101RH5`405iI
DP<0EDDi1019CUT405iOH@@0J6EX101UK6l406E_KPL0IFa/101XFF4406QLF`@0I5E=101UEe8306EM
GP@0IFIW101UDUP405iDD@@0HV1I101KDdh405]BB`<0DC/f101A@d8405Lo>@@0Ed8h101DB40405Y>
?0<0EdXk101D@SD8069@BP@0EdY4101DB48405M:@`<0Edi9101ME4l4018>40@0@DQ8101KJ6TZ06Ee
OQH0oooo000D0?oooc80IGEn101NJ744069PG0@0GUUB0`1EACT404U>F@@0GUmQ101XIFP406E/K`@0
IFm^1`1UK6`406QIH@@0J5aK101TEDd406EGDP<0IEeN101UIVL406EBF0@0GUAA101RH5T405]CCP@0
Fe9;0`1A>cH40553@P@0Ecli101G@SP405A8@0@0FThl0`1GBS/405A2=@P0HU1:101GBT@405A8@P@0
EdY30`1GCTT405eDC`@04Ph@1011B4P405]XJBX0IGEn5P3oool001@0oooo<P1UMGh405iXL@@0HV1L
101NFE8305E5>@@0BDiI101NGf4406QUJ0@0IFa_101UKfh706E/K0@0J5UQ101XG5/406AEC@@0IEMB
0`1UGEh406EVI`@0IE9H101NE544069PF@@0Fe=>101KDT/3054k=P@0DD=2101G?cT405M2>0@0E4Q0
101JCS`305M:>`@0E48e201RD4X405M:A0@0E4Q2101GBT<305M>B@@0GEA?100B3Q040458B0@0FfQY
:P1UMGhF0?ooo`00503ooolb06EeOP@0GVQa101RH5`405iIDP<0EDDi1019CUT405iOH@@0J6EX101U
K6l406E_KPL0IFa/101XFF4406QLF`@0I5E=101UEe8306EMGP@0IFIW101UDUP405iDD@@0HV1I101K
Ddh405]BB`<0DC/f101A@d8405Lo>@@0Ed8h101DB40405Y>?0<0EdXk101D@SD8069@BP@0EdY4101D
B48405M:@`<0Edi9101ME4l4018>40@0@DQ8101KJ6TZ06EeOQH0oooo000D0?oooc80IGEn101XH5D4
06QPF`@0Fe5>0`1DBdP406QRF0@0KeMH101UH6D?06EYJ@@0IFiS101XJEd4065MC`@0Fda40`1RGEh4
06EYJ@@0IFiZ101XLG0406QXK@@0IEaO101QFUH305eGC`@0H5E=101G@S/405A0>`@0E4@o101GBTL3
061<BP@0KEeI101WHU/405M>A`@0Eda6101MD4T405Y<A@<0Edi2101DC4@401`C40@06QHF100j@Th4
06EbNbH0IGEn5P3oool001@0oooo<P1UMGh406QPE@@0J61K101KDDh305A;B0@0J69H101_EeP406EP
I@l0IFUY101UKV<406QYG@@0HEe?101KC4@3069MGP@0IFUY101UKVX406QaL0@0J6Q]101UG5l4065J
EP<0GEM?101PEDd405M2>`@0E40k101DA3l405M:A`<0H4a:101]GET406MRF`@0Edi7101GC4H405e@
B@@0FTa50`1GCT8405A<A0@071<@100J5QH403Y2CP@0IG9k9P1UMGhF0?ooo`00503ooolb06EeOP@0
J61E101XH5/405]ACP<0E4]8101XHUP406mGF0@0IF1U3`1UJFT406E^H`@0J6UM101QGDl405]<A0<0
HUeN101UJFT406E^JP@0J75`101XJ6d406ELG`@0HEYF0`1MEdl4061EC@@0Ed8k101D@3/405A4?`@0
EdY70`1PC4X406eMF@@0If9K101GCTL405M<AP@0GE19101JC4D305M>@P@0E4a4100L4a0401XF5P@0
>T9>101ULW/V06EeOQH0oooo000D0?oooc80IGEn101XH5D406QPF`@0Fe5>0`1DBdP406QRF0@0KeMH
101UH6D?06EYJ@@0IFiS101XJEd4065MC`@0Fda40`1RGEh406EYJ@@0IFiZ101XLG0406QXK@@0IEaO
101QFUH305eGC`@0H5E=101G@S/405A0>`@0E4@o101GBTL3061<BP@0KEeI101WHU/405M>A`@0Eda6
101MD4T405Y<A@<0Edi2101DC4@401`C40@06QHF100j@Th406EbNbH0IGEn5P3oool001@0oooo<P1U
MGh406EUH@@0GUmH1019=b`305iOF0@0KeiV101XJ6<406E^J0@0IFUY101ULGL306E/KP@0IFUY101U
IFP406E[J0@0GUYE101NFTl305iTFP@0HV1N101UHe`406E/J@@0IFQX101QHEP405M<A0<0EdY4101D
CTL405M>A`@0GE8n101GA3T405M8@P<0HUME101XI5l4065JE0@0FUYD101JFE4805A@B@<0Ee1;101M
FUD407eL?`@0F2hR100F3`l402Xd?BH0IGEn5P3oool001@0oooo<P1UMGh406EUH@@0GUmH1019=b`3
05iOF0@0KeiV101XJ6<406E^J0@0IFUY101ULGL306E/KP@0IFUY101UIFP406E[J0@0GUYE101NFTl3
05iTFP@0HV1N101UHe`406E/J@@0IFQX101QHEP405M<A0<0EdY4101DCTL405M>A`@0GE8n101GA3T4
05M8@P<0HUME101XI5l4065JE0@0FUYD101JFE4805A@B@<0Ee1;101MFUD407eL?`@0F2hR100F3`l4
02Xd?BH0IGEn5P3oool001@0oooo<P1UMGh406EUH@@0GUmH1019=b`305iOF0@0KeiV101XJ6<406E^
J0@0IFUY101ULGL306E/KP@0IFUY101UIFP406E[J0@0GUYE101NFTl305iTFP@0HV1N101UHe`406E/
J@@0IFQX101QHEP405M<A0<0EdY4101DCTL405M>A`@0GE8n101GA3T405M8@P<0HUME101XI5l4065J
E0@0FUYD101JFE4805A@B@<0Ee1;101MFUD407eL?`@0F2hR100F3`l402Xd?BH0IGEn5P3oool001@0
oooo;P1UMGh406EJE`@0F3Pc101971l4054g>0<0DF1S101KJf<406E^H`@0IFEU101UJFT706EVI0@0
IFUY101UIFD405iOFP@0HF5K101XKfX306]aK0@0J6QP101NDU84069JE`@0IE1C101KBT8405Q3?@<0
E4E0101?@3X405A6=@@0ACTb101<?CT405eGC`<0HEeD101QG5@405iFD0@0FU1:101JBT@405e<AP@0
FTi20`1MB40405eCCP@0GDi:101iHUT40<3Jg`@0Wk[29P1UMGhF0?ooo`00503oool^06EeOP@0IEYG
101H>3<404TL7`@0DCLh0`1AH6<405][H`@0IFiS101UIFD406EYJ@L0IFIT101UJFT406EUI@@0GUmJ
101QHE/406Q_JP<0Jg5/101XJ60405iBDP@0HUYG101UD5<405]:@P@0F4<m0`1DAD0404m0>P@0E4He
1015>C8404`m>@@0GEM?0`1QGE@4065LE0@0GUI@101JD4X405Y:A0@0GDa6101JCT8305e8@0@0GE=>
101MCTX407URF@@0`=[O102O^/8V06EeOQH0oooo000D0?ooobh0IGEn101UFUL405Ph<`@0BA`O101A
=cP3055PH`@0Ff]S101UKV<406EUI@@0IFUY1`1UIV@406EYJ@@0IFEU101NGeX4065QF`@0J6mZ0`1[
LF`406QXH0@0GU9B101RFUL406E@D`@0FdY2101H@cd305A5@0@0Cd0j101DASD404Di<P@0C3di101M
Edl3065ME0@0HEaD101NEU0405Y@BP@0FTY4101MC4H405Y>@P<0GDQ0101MDdh405e>BP@0NF9I1030
f]l409nj`RH0IGEn5P3oool001@0oooo;P1UMGh406EJE`@0F3Pc101971l4054g>0<0DF1S101KJf<4
06E^H`@0IFEU101UJFT706EVI0@0IFUY101UIFD405iOFP@0HF5K101XKfX306]aK0@0J6QP101NDU84
069JE`@0IE1C101KBT8405Q3?@<0E4E0101?@3X405A6=@@0ACTb101<?CT405eGC`<0HEeD101QG5@4
05iFD0@0FU1:101JBT@405e<AP@0FTi20`1MB40405eCCP@0GDi:101iHUT40<3Jg`@0Wk[29P1UMGhF
0?ooo`00503oool^06EeOP@0IE9H101N?3h405Lh=`@0Ee=;0`1[Iel406mXJ0@0IFab101UJ6X;06EY
J@@0IF=S101UHe`4065RFP@0J5iH101UHUd306EUJ0@0IFab101XLG8406Q^L0@0IF5I101NF50405A:
A@<0Cd@m101<?cP404Tm>@@0E4I2101VGeL406MRF@<0HUiI101QG5L405iFD0@0FU9<101JCTL405Y8
A`@0GDE90`1GB4D405QFE`@0DCld101DASh406]lQP@0J7R19P1UMGhF0?ooo`00503oool^06EeOP@0
IE9H101N?3h405Lh=`@0Ee=;0`1[Iel406mXJ0@0IFab101UJ6X;06EYJ@@0IF=S101UHe`4065RFP@0
J5iH101UHUd306EUJ0@0IFab101XLG8406Q^L0@0IF5I101NF50405A:A@<0Cd@m101<?cP404Tm>@@0
E4I2101VGeL406MRF@<0HUiI101QG5L405iFD0@0FU9<101JCTL405Y8A`@0GDE90`1GB4D405QFE`@0
DCld101DASh406]lQP@0J7R19P1UMGhF0?ooo`00503oool^06EeOP@0IE9H101N?3h405Lh=`@0Ee=;
0`1[Iel406mXJ0@0IFab101UJ6X;06EYJ@@0IF=S101UHe`4065RFP@0J5iH101UHUd306EUJ0@0IFab
101XLG8406Q^L0@0IF5I101NF50405A:A@<0Cd@m101<?cP404Tm>@@0E4I2101VGeL406MRF@<0HUiI
101QG5L405iFD0@0FU9<101JCTL405Y8A`@0GDE90`1GB4D405QFE`@0DCld101DASh406]lQP@0J7R1
9P1UMGhF0?ooo`00503oool^06EeOP@0IE9H101N?3h405Lh=`@0Ee=;0`1[Iel406mXJ0@0IFab101U
J6X;06EYJ@@0IF=S101UHe`4065RFP@0J5iH101UHUd306EUJ0@0IFab101XLG8406Q^L0@0IF5I101N
F50405A:A@<0Cd@m101<?cP404Tm>@@0E4I2101VGeL406MRF@<0HUiI101QG5L405iFD0@0FU9<101J
CTL405Y8A`@0GDE90`1GB4D405QFE`@0DCld101DASh406]lQP@0J7R19P1UMGhF0?ooo`00503ooolZ
06EeOP@0IF1M101UGe4405iGB@@0DDXh101JFDd306][I@@0J6QX101UJFT406E/K0@0IFEU101UH603
05iJD`@0HV1G101UDUP4065CE0@0GUA@101NF5@306ESH`@0IF=L101UHf0406EUI@@0IEMO101NAdH4
05M6@0<0E4Ho101GB40405=@B0@0FUM9101MEdh405iFD0<0IEYD101NDdh405]=B0@0FU1:101JB484
05Y8@0@0E4Y00`1DD48405YHE0@0H4i8101MEDl404U?E`@0EEmY9P1UMGhF0?ooo`00503ooolZ06Ee
OP@0IF1M101UGe4405iGB@@0DDXh101JFDd306][I@@0J6QX101UJFT406E/K0@0IFEU101UH60305iJ
D`@0HV1G101UDUP4065CE0@0GUA@101NF5@306ESH`@0IF=L101UHf0406EUI@@0IEMO101NAdH405M6
@0<0E4Ho101GB40405=@B0@0FUM9101MEdh405iFD0<0IEYD101NDdh405]=B0@0FU1:101JB48405Y8
@0@0E4Y00`1DD48405YHE0@0H4i8101MEDl404U?E`@0EEmY9P1UMGhF0?ooo`00503ooolZ06EeOP@0
IF1M101UGe4405iGB@@0DDXh101JFDd306][I@@0J6QX101UJFT406E/K0@0IFEU101UH60305iJD`@0
HV1G101UDUP4065CE0@0GUA@101NF5@306ESH`@0IF=L101UHf0406EUI@@0IEMO101NAdH405M6@0<0
E4Ho101GB40405=@B0@0FUM9101MEdh405iFD0<0IEYD101NDdh405]=B0@0FU1:101JB48405Y8@0@0
E4Y00`1DD48405YHE0@0H4i8101MEDl404U?E`@0EEmY9P1UMGhF0?ooo`00503ooolZ06EeOP@0IF1M
101UGe4405iGB@@0DDXh101JFDd306][I@@0J6QX101UJFT406E/K0@0IFEU101UH60305iJD`@0HV1G
101UDUP4065CE0@0GUA@101NF5@306ESH`@0IF=L101UHf0406EUI@@0IEMO101NAdH405M6@0<0E4Ho
101GB40405=@B0@0FUM9101MEdh405iFD0<0IEYD101NDdh405]=B0@0FU1:101JB48405Y8@0@0E4Y0
0`1DD48405YHE0@0H4i8101MEDl404U?E`@0EEmY9P1UMGhF0?ooo`00503ooolZ06EeOP@0F4Xo1011
:RD4028M6P@0;B/X101HFEL306Q[IP@0IFEU101UHf<406EPH0@0IF=L101UGeD3065OF0@0GU9D101E
DT`405]GE0@0HFAQ101QJV<306EXH0@0IFEU101UIFP406EUI@@0GVMM101KFDd405M<A@L0E4Ho101M
BT<405e>B@@0HU9D101REU8305]CCP@0FeYD101NFU@405YDC@@0FUM?101DEDd405A<A@<0EdQ9101J
DeH404l_8`@0F4i8101J>Bl406ENGbH0IGEn5P3oool001@0oooo:P1UMGh405Q:?`@0@BXU100R7AX4
02d[:0@0F5UG0`1XJfH406EUI@@0IF=S101UH60406ESG0@0IEmE0`1QGeP405iBE0@0EE9<101KEe@4
065TH@@0HFYS0`1UJ60406EUI@@0IFEX101UIFD405iWG@@0FeU=101GC4D705A6?`@0GDY3101MCTT4
069BE0@0HUIB0`1KDdh405]JE0@0GUYD101JE4d405YGC`@0E5E=101DC4D305M8B@@0FU=F101?;b<4
05Q>B0@0FST_101UGUlV06EeOQH0oooo000D0?ooobX0IGEn101HBSl4044Z9@@08QdJ100]:bP405QI
E`<0J6]V101UIFD406ESH`@0IF1P101UHe`406EOE@<0HEmH101NDU@405EBC0@0FeMD101QI644065Z
H`<0IFQP101UIFD406EUJ0@0IFEU101NIed405]IC@@0Eda51`1DASl405e:@`@0GDi9101RDU@4069F
DP<0Fe=>101KFU@405iJE0@0FUA=101JEdl405AEC@@0E4a50`1GB4T405YCEP@0CblS101HCTP405Xi
;`@0IEiO9P1UMGhF0?ooo`00503ooolZ06EeOP@0F4Xo1011:RD4028M6P@0;B/X101HFEL306Q[IP@0
IFEU101UHf<406EPH0@0IF=L101UGeD3065OF0@0GU9D101EDT`405]GE0@0HFAQ101QJV<306EXH0@0
IFEU101UIFP406EUI@@0GVMM101KFDd405M<A@L0E4Ho101MBT<405e>B@@0HU9D101REU8305]CCP@0
FeYD101NFU@405YDC@@0FUM?101DEDd405A<A@<0EdQ9101JDeH404l_8`@0F4i8101J>Bl406ENGbH0
IGEn5P3oool001@0oooo:P1UMGh405Ln=@@071@>100Q7A`4020K7@@0AT]<1`1UIFP406EUGP@0IFEK
101UIFD406EXK@<0J6]`101[LG8406QQH@@0GTe>101BA40405]ACP<0GUaH101RHf<406EUI@@0IFEN
101QE5@405M7A0@0CSe20`1A@ST404i0>0@0E4Q2101ME4d405Y>AP@0E4e60`1KCDh405M6@P@0E4U4
101ABT@4059:A0@0E4a6101GBT<305M:A`@0E4Y2101<A34404a4=P@0DS/i101UMH4V06EeOQH0oooo
000D0?ooobX0IGEn101G?SD401`D3P@08AdL100P6ad404I;C0L0IFEX101UIEh406EUF`@0IFEU101U
J6d306Q[L0@0Jg5b101XHF4405i=CP@0DTA0101KDDh305iLF0@0HV=S101UIFD406EUGP@0HEAD101G
Ad@404hm@P<0DD8i101>@3P405A8@P@0GEA=101JCTH405A=AP<0Fde>101GAT8405A9A0@0DDY4101B
BT@405A<AP@0EdY30`1GBTL405A:@P@0C4@a101<A3H4058k>@@0IGF19P1UMGhF0?ooo`00503ooolZ
06EeOP@0Eche100L50h4024M70@081/M1016Bd`706EUJ0@0IFEN101UIE/406EUI@@0IFQ]0`1XJg04
06]aLP@0J65Q101NCDh40594@0@0Fe5>0`1NG5P4069SH`@0IFEU101UIEh4065DE0@0EdM4101>?D83
0552>@@0CT0h101DB48405eDC@@0FTi6101DCDH305]=CP@0EdI2101DBD@4055:A0@0DTY4101DC4H4
05M:@`<0EdY7101DBT8404a4<@@0C4@f101B>cT406EePBH0IGEn5P3oool001@0oooo:P1UMGh405Ln
=@@071@>100Q7A`4020K7@@0AT]<1`1UIFP406EUGP@0IFEK101UIFD406EXK@<0J6]`101[LG8406QQ
H@@0GTe>101BA40405]ACP<0GUaH101RHf<406EUI@@0IFEN101QE5@405M7A0@0CSe20`1A@ST404i0
>0@0E4Q2101ME4d405Y>AP@0E4e60`1KCDh405M6@P@0E4U4101ABT@4059:A0@0E4a6101GBT<305M:
A`@0E4Y2101<A34404a4=P@0DS/i101UMH4V06EeOQH0oooo000D0?ooobH0IGEn101UJ6T4069DE0@0
Gd@j100f9b0402XQ80@0GUYD0`1UIEh405iOE@@0HV=S101UIF<4059<AP@0BD<l0`0i;RT4038W8`@0
=2d/100n<SH40593@@@0E4<o0`1EBTP4069PH0@0IFEU101UIFP4065JF`@0FTi7101DB3P305A2<PP0
DDHo1017A3h40453?`@0C4Y40`1DETh4055@A`@0F59<101ME4d405Y@B@@0Edi7101GBT<305M:A`@0
Edi7100j:2<4030H5P@0A2lV101RLWDV06EeOQH0oooo000D0?ooobH0IGEn101UJ6T4069DE0@0Gd@j
100f9b0402XQ80@0GUYD0`1UIEh405iOE@@0HV=S101UIF<4059<AP@0BD<l0`0i;RT4038W8`@0=2d/
100n<SH40593@@@0E4<o0`1EBTP4069PH0@0IFEU101UIFP4065JF`@0FTi7101DB3P305A2<PP0DDHo
1017A3h40453?`@0C4Y40`1DETh4055@A`@0F59<101ME4d405Y@B@@0Edi7101GBT<305M:A`@0Edi7
100j:2<4030H5P@0A2lV101RLWDV06EeOQH0oooo000D0?ooobH0IGEn101UJ6T4069DE0@0Gd@j100f
9b0402XQ80@0GUYD0`1UIEh405iOE@@0HV=S101UIF<4059<AP@0BD<l0`0i;RT4038W8`@0=2d/100n
<SH40593@@@0E4<o0`1EBTP4069PH0@0IFEU101UIFP4065JF`@0FTi7101DB3P305A2<PP0DDHo1017
A3h40453?`@0C4Y40`1DETh4055@A`@0F59<101ME4d405Y@B@@0Edi7101GBT<305M:A`@0Edi7100j
:2<4030H5P@0A2lV101RLWDV06EeOQH0oooo000D0?ooobH0IGEn101NDd`405]9A0@03PL610092``4
01HF5P@0F5]F0`1QHUd406EOFP@0J6EN101UIEh406QSG@@0CTQ20`0i=S0401hT9`@031@G100A5A44
02PV8@@0;ATF0`0Y4A0404Pi>0@0HV1N101UIFD4065QF0@0FU17101DAS/304i>?0@0B3he101GCTP4
06IKD`@0K5]C101VDd/305M4A0@0BD4o101ECdX405YBC0@0Edi7101<B48404M8@P<0DU17101GD4L4
04Td:`@0BbdS101G=Bh406E^NbH0IGEn5P3oool001@0oooo9P1UMGh405iCC0@0FdU4100>1`H400T;
30@05QHF101HFeH3065RG@@0IEmJ101XIEh406EUGP@0J6=M101>B48303Tf<0@07R@W100<51L4014E
4@@0:2HQ100]6AH302TA40@0B3Th101RH5h406EUI@@0HF5H101JD4L405A6>`<0CThl1018?SD405M>
B0@0IU]C101/Fe<406ICB`<0EdA41019@Cl405E?BP@0FU9<101GCTL404a8@P@0AdQ20`1BD4L405M@
A`@0BC@[101;;B<405Le;P@0IFik9P1UMGhF0?ooo`00503ooolV06EeOP@0GU=<101KBD@400h71P@0
2@/<100F5QH405QKEP<0HF9M101UGeX406QUGP@0IFEN101XHed404i8@P<0>CH`100N92L400`D5`@0
4ADA100X9R4402dI5P<0:A4@1018>CP4069PGP@0IFEU101QHEP405Y@A`@0E4Hk0`1>CS`404Pn=@@0
Edi8101VFe<406aKD`@0IU=;0`1GA4@404U1?`@0EDm:101JDT`405M>A`@0C4Q21017B483059@A`@0
Ee171019=2/404/]8`@0EcD^101UKW/V06EeOQH0oooo000D0?ooobH0IGEn101NDd`405]9A0@03PL6
10092``401HF5P@0F5]F0`1QHUd406EOFP@0J6EN101UIEh406QSG@@0CTQ20`0i=S0401hT9`@031@G
100A5A4402PV8@@0;ATF0`0Y4A0404Pi>0@0HV1N101UIFD4065QF0@0FU17101DAS/304i>?0@0B3he
101GCTP406IKD`@0K5]C101VDd/305M4A0@0BD4o101ECdX405YBC0@0Edi7101<B48404M8@P<0DU17
101GD4L404Td:`@0BbdS101G=Bh406E^NbH0IGEn5P3oool001@0oooo8`1UMGh306]lQP@0Jf1K101J
ASl403HW90@081HC100V5Q@406ERG@<0J6]U101QI5l4069UH@@0IFEQ101XJfd406IKE@<0Q71^1015
>344020E4`@081HB100P9bX403/f<0<0KfUL101dOG<406E_KP@0IGMl101QJVD405Y@B@@0B3/e0`15
=Rl402<;20@0=bPX1014=BL403L_:0@09B4M0`0g=S4404a8@0@0E4a0101BBT8405A<AP@0DD@m101A
B48305M8A`@0C40l100b9B<403lb:`@0FTa8101_QY<306QhPB<0IGEn5P3oool001@0oooo8`1UMGh3
06]lQP@0Jf1K101JASl403HW90@081HC100V5Q@406ERG@<0J6]U101QI5l4069UH@@0IFEQ101XJfd4
06IKE@<0Q71^1015>344020E4`@081HB100P9bX403/f<0<0KfUL101dOG<406E_KP@0IGMl101QJVD4
05Y@B@@0B3/e0`15=Rl402<;20@0=bPX1014=BL403L_:0@09B4M0`0g=S4404a8@0@0E4a0101BBT84
05A<AP@0DD@m101AB48305M8A`@0C40l100b9B<403lb:`@0FTa8101_QY<306QhPB<0IGEn5P3oool0
01@0oooo8`1UMGh306]lQP@0Jf1K101JASl403HW90@081HC100V5Q@406ERG@<0J6]U101QI5l4069U
H@@0IFEQ101XJfd406IKE@<0Q71^1015>344020E4`@081HB100P9bX403/f<0<0KfUL101dOG<406E_
KP@0IGMl101QJVD405Y@B@@0B3/e0`15=Rl402<;20@0=bPX1014=BL403L_:0@09B4M0`0g=S4404a8
@0@0E4a0101BBT8405A<AP@0DD@m101AB48305M8A`@0C40l100b9B<403lb:`@0FTa8101_QY<306Qh
PB<0IGEn5P3oool001@0oooo8`1UMGh306]lQP@0Jf1K101JASl403HW90@081HC100V5Q@406ERG@<0
J6]U101QI5l4069UH@@0IFEQ101XJfd406IKE@<0Q71^1015>344020E4`@081HB100P9bX403/f<0<0
KfUL101dOG<406E_KP@0IGMl101QJVD405Y@B@@0B3/e0`15=Rl402<;20@0=bPX1014=BL403L_:0@0
9B4M0`0g=S4404a8@0@0E4a0101BBT8405A<AP@0DD@m101AB48305M8A`@0C40l100b9B<403lb:`@0
FTa8101_QY<306QhPB<0IGEn5P3oool001@0oooo101UJgD406EbN`@0IFig0`1ULW/D06EeOP<02P<3
100H2`l405aCCP@0@C0Y100M6B0401PC4@@0F5mJ0`1NGeX406EUH@@0HF9M101KG5P4069SH`@0J6eV
0`1RGE@4075MD0@0XGiY102@IdX407aE?0@0NFA>0`1^HUL406ENF0@0IFIW101UIV@4065HDP@0FTa6
101JA3L30590>0@0E3hb1018Bd/401dW;P@00@<5100A51L302<W9`@03Q4@100H724402LT7P@0@C4X
101>ASl4055<A@<0EdY2100o>c<402@O6P@09R4N101?CTP406^3RBH0IGEn5P3oool001@0oooo101U
JgD406EbN`@0IFig0`1ULW/D06EeOP<02P<3100H2`l405aCCP@0@C0Y100M6B0401PC4@@0F5mJ0`1N
GeX406EUH@@0HF9M101KG5P4069SH`@0J6eV0`1RGE@4075MD0@0XGiY102@IdX407aE?0@0NFA>0`1^
HUL406ENF0@0IFIW101UIV@4065HDP@0FTa6101JA3L30590>0@0E3hb1018Bd/401dW;P@00@<5100A
51L302<W9`@03Q4@100H724402LT7P@0@C4X101>ASl4055<A@<0EdY2100o>c<402@O6P@09R4N101?
CTP406^3RBH0IGEn5P3oool001@0oooo101UJgD406EbN`@0IFig0`1ULW/D06EeOP<02P<3100H2`l4
05aCCP@0@C0Y100M6B0401PC4@@0F5mJ0`1NGeX406EUH@@0HF9M101KG5P4069SH`@0J6eV0`1RGE@4
075MD0@0XGiY102@IdX407aE?0@0NFA>0`1^HUL406ENF0@0IFIW101UIV@4065HDP@0FTa6101JA3L3
0590>0@0E3hb1018Bd/401dW;P@00@<5100A51L302<W9`@03Q4@100H724402LT7P@0@C4X101>ASl4
055<A@<0EdY2100o>c<402@O6P@09R4N101?CTP406^3RBH0IGEn5P3oool001@0oooo101UJgD406Eb
N`@0IFig0`1ULW/D06EeOP<02P<3100H2`l405aCCP@0@C0Y100M6B0401PC4@@0F5mJ0`1NGeX406EU
H@@0HF9M101KG5P4069SH`@0J6eV0`1RGE@4075MD0@0XGiY102@IdX407aE?0@0NFA>0`1^HUL406EN
F0@0IFIW101UIV@4065HDP@0FTa6101JA3L30590>0@0E3hb1018Bd/401dW;P@00@<5100A51L302<W
9`@03Q4@100H724402LT7P@0@C4X101>ASl4055<A@<0EdY2100o>c<402@O6P@09R4N101?CTP406^3
RBH0IGEn5P3oool001@0oooo101ULGX406EeOPL0IGR1401UMGh400h720<030T9100;108400062`@0
20T@100?3`h4028G50@0J6AO0`1QHUd406EUJ0@0E3e1101>>c/405iJF`@0J6ma0`1^MWT4075[K0@0
IUA?101YGEL4079RF`@0LFAH0`1[Hed406ESG@P0IFUY101QEeP405YHE0@0E4`o0`1DDSd4069??0@0
Lf1@101hDd8401/B4`@09AXD0`0U8244024L70@0?C4Y101D@3P4069IC@@0FDY2101CB48305M@@`@0
91dM100L61D402TL5`@0BBXU101KGVT3069bNb<0IGEn5P3oool001@0oooo101ULGX406EeOPL0IGR1
401UMGh400h720<030T9100;108400062`@020T@100?3`h4028G50@0J6AO0`1QHUd406EUJ0@0E3e1
101>>c/405iJF`@0J6ma0`1^MWT4075[K0@0IUA?101YGEL4079RF`@0LFAH0`1[Hed406ESG@P0IFUY
101QEeP405YHE0@0E4`o0`1DDSd4069??0@0Lf1@101hDd8401/B4`@09AXD0`0U8244024L70@0?C4Y
101D@3P4069IC@@0FDY2101CB48305M@@`@091dM100L61D402TL5`@0BBXU101KGVT3069bNb<0IGEn
5P3oool001@0oooo101ULGX406EeOPL0IGR1401UMGh400h720<030T9100;108400062`@020T@100?
3`h4028G50@0J6AO0`1QHUd406EUJ0@0E3e1101>>c/405iJF`@0J6ma0`1^MWT4075[K0@0IUA?101Y
GEL4079RF`@0LFAH0`1[Hed406ESG@P0IFUY101QEeP405YHE0@0E4`o0`1DDSd4069??0@0Lf1@101h
Dd8401/B4`@09AXD0`0U8244024L70@0?C4Y101D@3P4069IC@@0FDY2101CB48305M@@`@091dM100L
61D402TL5`@0BBXU101KGVT3069bNb<0IGEn5P3oool001@0oooo101ULGX406EeOPL0IGR1401UMGh4
00h720<030T9100;108400062`@020T@100?3`h4028G50@0J6AO0`1QHUd406EUJ0@0E3e1101>>c/4
05iJF`@0J6ma0`1^MWT4075[K0@0IUA?101YGEL4079RF`@0LFAH0`1[Hed406ESG@P0IFUY101QEeP4
05YHE0@0E4`o0`1DDSd4069??0@0Lf1@101hDd8401/B4`@09AXD0`0U8244024L70@0?C4Y101D@3P4
069IC@@0FDY2101CB48305M@@`@091dM100L61D402TL5`@0BBXU101KGVT3069bNb<0IGEn5P3oool0
01@0oooo101UNhD406EhPAL0IGEn100T5aD302/Q6@@0:A/G100M6aX400/92P@08AHD100Y5aD406EK
EP<0J5mJ101QGeP406]gLP@0HfUO100k;bT402lQ7P<0:24N100J6a/401@E5P@05aLF100Q71T402LL
6P<0@3hn101KHU`406EUI@@0IF1I101QEdh405YFCP@0E4I00`1G?cL4055:>`@0E593101MED/409Eh
I0@0Y7]R0`1bCC/406e5=0@0P5]=101aFT<405A>A@@0E515101OED/3055:A@@08adG100M5A<402`M
60@0B2LO101NJgDV06EeOQH0oooo000D0?ooo`@0IG^5101UN84G06EeOP@091LE0`0[8AT402TK5`@0
7A/J100;2@X4024F50@0:ALE101UFeH306QOFP@0HEmH101[Mg8406=YG`@0>blY100_8Ah302PQ7P@0
6Q/K100D5AH401LG5P@08A`I100W71X3040n?P@0Ff9L101UIFD406EPF@@0HEM>101JETh405A6@0<0
Eclg101ABS/405AB@`@0GEE;102EN6@40:AkHP<0LTdk101]AC@4081KC@@0LEY3101DCTD405A@A@@0
GeE;0`1ABTD402<M5`@07ADC100/7AP404PW7`@0GV]e9P1UMGhF0?ooo`00503oool406EkQ@@0IGR1
5`1UMGh402@G5@<0:b4I100Y6aL401dK6P@02`T:100Q5Q@402TG5@@0IE]F0`1XGeX4065OF0@0JgMb
101SJEl403/_:@@0;b4N0`0X8Ah401XK6`@051DF100G5aH4024L6@@09a`J0`10?Sh405]RG0@0IFEU
101UH5T4065GCP@0FUI>101DAT0305Lo=`@0DDXk101DDT<405eEB`@0UGQT102TNf83079=>`@0KDDd
1020Fdd4075J@`@0E4i5101DD4D405mEB`<0DDY5100S7AL401dE4`@0;1dH10189al405i[MBH0IGEn
5P3oool001@0oooo101UNhD406EhPAL0IGEn100T5aD302/Q6@@0:A/G100M6aX400/92P@08AHD100Y
5aD406EKEP<0J5mJ101QGeP406]gLP@0HfUO100k;bT402lQ7P<0:24N100J6a/401@E5P@05aLF100Q
71T402LL6P<0@3hn101KHU`406EUI@@0IF1I101QEdh405YFCP@0E4I00`1G?cL4055:>`@0E593101M
ED/409EhI0@0Y7]R0`1bCC/406e5=0@0P5]=101aFT<405A>A@@0E515101OED/3055:A@@08adG100M
5A<402`M60@0B2LO101NJgDV06EeOQH0oooo000D0?oooal0IGEn100Z6aD301P>2`@04A0?100E4@l4
01`C40@05a@A100V9B<405QHDP<0GUaH101XJ6<406QXJ0@0Kg5b101nQG`406iNF`<0BDA:101XE5@4
07EGB@@0Lee@101SCT<407ATF@<0Ngec101_LG8406QXJP@0IE9J101QFEP405YHDP@0E4150`0c8Qh4
02PJ60@0?SL_101BC3h405M>@0@0He=90`1]H4l406IQE0@0Hee>101>CTT405M:C@@0DDQ5101BC483
03li<@@04A0>100A4@l406=AA@@0FCDX101NMGhV06EeOQH0oooo000D0?oooal0IGEn100Z6aD301P>
2`@04A0?100E4@l401`C40@05a@A100V9B<405QHDP<0GUaH101XJ6<406QXJ0@0Kg5b101nQG`406iN
F`<0BDA:101XE5@407EGB@@0Lee@101SCT<407ATF@<0Ngec101_LG8406QXJP@0IE9J101QFEP405YH
DP@0E4150`0c8Qh402PJ60@0?SL_101BC3h405M>@0@0He=90`1]H4l406IQE0@0Hee>101>CTT405M:
C@@0DDQ5101BC48303li<@@04A0>100A4@l406=AA@@0FCDX101NMGhV06EeOQH0oooo000D0?oooal0
IGEn100Z6aD301P>2`@04A0?100E4@l401`C40@05a@A100V9B<405QHDP<0GUaH101XJ6<406QXJ0@0
Kg5b101nQG`406iNF`<0BDA:101XE5@407EGB@@0Lee@101SCT<407ATF@<0Ngec101_LG8406QXJP@0
IE9J101QFEP405YHDP@0E4150`0c8Qh402PJ60@0?SL_101BC3h405M>@0@0He=90`1]H4l406IQE0@0
Hee>101>CTT405M:C@@0DDQ5101BC48303li<@@04A0>100A4@l406=AA@@0FCDX101NMGhV06EeOQH0
oooo000D0?oooal0IGEn100Z6aD301P>2`@04A0?100E4@l401`C40@05a@A100V9B<405QHDP<0GUaH
101XJ6<406QXJ0@0Kg5b101nQG`406iNF`<0BDA:101XE5@407EGB@@0Lee@101SCT<407ATF@<0Ngec
101_LG8406QXJP@0IE9J101QFEP405YHDP@0E4150`0c8Qh402PJ60@0?SL_101BC3h405M>@0@0He=9
0`1]H4l406IQE0@0Hee>101>CTT405M:C@@0DDQ5101BC48303li<@@04A0>100A4@l406=AA@@0FCDX
101NMGhV06EeOQH0oooo000D0?ooo`P0IGEn101UKWL306EbNa00IGEn100b9Ah3024@30@071<@100G
4a0400/61`@0614@100Z8b4404U4?`<0EE=@101RHeh406EUI@@0IFa/101XLW@407F6QPL0SijE1025
WY/408bQX0@0SjBR1026UH/306]bJP@0IFa/101NHUX405]UF0@0GV=H101RG5L406][G`<0M6mN1018
=CD401hI6@@02@`>100O7R4404U3@0<0E4i3101MD4<4055:@`@0DD8m1012?CD40556A0@0GDQ50`0T
6aP401D?3P@09R8O1016<BT403XQ6@@04Q0A0`0]=3dS06EeOQH0oooo000D0?ooo`P0IGEn101UKWL3
06EbNa00IGEn100b9Ah3024@30@071<@100G4a0400/61`@0614@100Z8b4404U4?`<0EE=@101RHeh4
06EUI@@0IFa/101XLW@407F6QPL0SijE1025WY/408bQX0@0SjBR1026UH/306]bJP@0IFa/101NHUX4
05]UF0@0GV=H101RG5L406][G`<0M6mN1018=CD401hI6@@02@`>100O7R4404U3@0<0E4i3101MD4<4
055:@`@0DD8m1012?CD40556A0@0GDQ50`0T6aP401D?3P@09R8O1016<BT403XQ6@@04Q0A0`0]=3dS
06EeOQH0oooo000D0?ooo`P0IGEn101UKWL306EbNa00IGEn100b9Ah3024@30@071<@100G4a0400/6
1`@0614@100Z8b4404U4?`<0EE=@101RHeh406EUI@@0IFa/101XLW@407F6QPL0SijE1025WY/408bQ
X0@0SjBR1026UH/306]bJP@0IFa/101NHUX405]UF0@0GV=H101RG5L406][G`<0M6mN1018=CD401hI
6@@02@`>100O7R4404U3@0<0E4i3101MD4<4055:@`@0DD8m1012?CD40556A0@0GDQ50`0T6aP401D?
3P@09R8O1016<BT403XQ6@@04Q0A0`0]=3dS06EeOQH0oooo000D0?ooo`P0IGEn1`1UN84@06EeOP@0
9R<R0`0P7A/401/E4P@071<@100F40`401`D4@@0:2<Q101AA3d3065KEP@0IFEQ101UIFD806EYJ@@0
IG5g1`1UM7`406E/KP@0IG5g101UK6h406E/K`<0J6]X201XIEh406ENF0@0HEA@101UGUP406QTG@<0
KVAS101nMg44099eJ`@0ITi6100]8ad400/?3`<03a4E100E7204020P7P@0:2<N101AA4@406=>A`@0
DD@l0`0L51<401LA40@07AHH100D2PT401P>30@0:2LX0`1XN84S06EeOQH0oooo000D0?ooo`P0IGEn
1`1UN84@06EeOP@09R<R0`0P7A/401/E4P@071<@100F40`401`D4@@0:2<Q101AA3d3065KEP@0IFEQ
101UIFD806EYJ@@0IG5g1`1UM7`406E/KP@0IG5g101UK6h406E/K`<0J6]X201XIEh406ENF0@0HEA@
101UGUP406QTG@<0KVAS101nMg44099eJ`@0ITi6100]8ad400/?3`<03a4E100E7204020P7P@0:2<N
101AA4@406=>A`@0DD@l0`0L51<401LA40@07AHH100D2PT401P>30@0:2LX0`1XN84S06EeOQH0oooo
000D0?ooo`P0IGEn1`1UN84@06EeOP@09R<R0`0P7A/401/E4P@071<@100F40`401`D4@@0:2<Q101A
A3d3065KEP@0IFEQ101UIFD806EYJ@@0IG5g1`1UM7`406E/KP@0IG5g101UK6h406E/K`<0J6]X201X
IEh406ENF0@0HEA@101UGUP406QTG@<0KVAS101nMg44099eJ`@0ITi6100]8ad400/?3`<03a4E100E
7204020P7P@0:2<N101AA4@406=>A`@0DD@l0`0L51<401LA40@07AHH100D2PT401P>30@0:2LX0`1X
N84S06EeOQH0oooo000D0?ooo`P0IGEn1`1UN84@06EeOP@09R<R0`0P7A/401/E4P@071<@100F40`4
01`D4@@0:2<Q101AA3d3065KEP@0IFEQ101UIFD806EYJ@@0IG5g1`1UM7`406E/KP@0IG5g101UK6h4
06E/K`<0J6]X201XIEh406ENF0@0HEA@101UGUP406QTG@<0KVAS101nMg44099eJ`@0ITi6100]8ad4
00/?3`<03a4E100E7204020P7P@0:2<N101AA4@406=>A`@0DD@l0`0L51<401LA40@07AHH100D2PT4
01P>30@0:2LX0`1XN84S06EeOQH0oooo000D0?oooal0IGEn100b:2H303P[:@@06ADB100J4a0401`D
4@@08APK100Y92<403lk=0<0C4a8101NH5`406EUGP@0IF=P101UIVL406EVI0<0IFY/101UKW8806Ea
M`P0IFUY0`1UK6l406EXIP@0IFEQ101QGUP4065QF`@0HEYD101QFeH3065JF0@0HUaD101QGe@406iR
E0@0OF]K101jIE<305m9>@@0DS``101XBd0406]NE0@0GdY<1019AT8403i0>@<07QHD100K4a0401DC
40@040l;100G5aD402LZ:bH0IGEn5P3oool001@0oooo7`1UMGh4038X9P<0>2/Y100I5A8401XC40@0
71@A100Q61/402TT8`@0?c/d0`1<C4P405iPG0@0IFEN101UHf0406EVI`@0IFIT0`1UJV`406E^LPP0
IG5g201UJFT306E/K`@0IFQV101UIF44065NF0@0HF5K101QFU@4065KEP<0HEYH101RG5@4065OE0@0
KV9D101mJe/407YUD`<0GdTi101B?30406Q;@0@0JeiD101OBT`404U6@P@0?T0i0`0N5Q@401/C40@0
5A<@100@3`/401LG5@@09bX[9P1UMGhF0?ooo`00503ooolO06EeOP@0<RPV0`0h:bT401TE4P@06Q<@
100L5144024H6`@0:B@S100o>c@304a<B0@0GV1L101UIEh406ESH0@0IFIW101UIV@306EZK0@0IFib
201ULGL806EYJ@<0IFa_101UJ6H406EUH@@0HEiH101QHE/4065JE0@0HE]F0`1QFUP4069LE0@0HEmD
101^HU@407e[F`@0NVEC0`1OBCT4058l<0@0J4]0101[GU@405m:C0@0BDI2100n@3T301hF50@06a<@
100E4a04010?2`@05aLE100W:R/V06EeOQH0oooo000D0?oooal0IGEn100b:2H303P[:@@06ADB100J
4a0401`D4@@08APK100Y92<403lk=0<0C4a8101NH5`406EUGP@0IF=P101UIVL406EVI0<0IFY/101U
KW8806EaM`P0IFUY0`1UK6l406EXIP@0IFEQ101QGUP4065QF`@0HEYD101QFeH3065JF0@0HUaD101Q
Ge@406iRE0@0OF]K101jIE<305m9>@@0DS``101XBd0406]NE0@0GdY<1019AT8403i0>@<07QHD100K
4a0401DC40@040l;100G5aD402LZ:bH0IGEn5P3oool001@0oooo7`1UMGh402lR6`<09Q`F100R6aP4
01dD4@@07`l<100S5Q@402TN5`@0;BPT0`16@Cl405]JEP@0HV=N101UIFD406EYJ@@0IG5g0`1UJFT4
06EZK0P0IFib201UJFT306ESG0@0IF=S101UGed4065DD0@0HE]F101QHE/4065JE0<0HEM@101NDd`4
069=B0@0HE9<101ODd/406mNE@<0MVAI101iJEd406eJD@@0HTi=101OCTD405U8?@@0=RLP0`0M5184
01/C40@091LE100J514401XC4@@08a`F0`0l=c`4055HHal0IGEn5P3oool001@0oooo7`1UMGh402lR
6`<09Q`F100R6aP401dD4@@07`l<100S5Q@402TN5`@0;BPT0`16@Cl405]JEP@0HV=N101UIFD406EY
J@@0IG5g0`1UJFT406EZK0P0IFib201UJFT306ESG0@0IF=S101UGed4065DD0@0HE]F101QHE/4065J
E0<0HEM@101NDd`4069=B0@0HE9<101ODd/406mNE@<0MVAI101iJEd406eJD@@0HTi=101OCTD405U8
?@@0=RLP0`0M518401/C40@091LE100J514401XC4@@08a`F0`0l=c`4055HHal0IGEn5P3oool001@0
oooo7`1UMGh402lR6`<09Q`F100R6aP401dD4@@07`l<100S5Q@402TN5`@0;BPT0`16@Cl405]JEP@0
HV=N101UIFD406EYJ@@0IG5g0`1UJFT406EZK0P0IFib201UJFT306ESG0@0IF=S101UGed4065DD0@0
HE]F101QHE/4065JE0<0HEM@101NDd`4069=B0@0HE9<101ODd/406mNE@<0MVAI101iJEd406eJD@@0
HTi=101OCTD405U8?@@0=RLP0`0M518401/C40@091LE100J514401XC4@@08a`F0`0l=c`4055HHal0
IGEn5P3oool001@0oooo7`1UMGh402lR6`<09Q`F100R6aP401dD4@@07`l<100S5Q@402TN5`@0;BPT
0`16@Cl405]JEP@0HV=N101UIFD406EYJ@@0IG5g0`1UJFT406EZK0P0IFib201UJFT306ESG0@0IF=S
101UGed4065DD0@0HE]F101QHE/4065JE0<0HEM@101NDd`4069=B0@0HE9<101ODd/406mNE@<0MVAI
101iJEd406eJD@@0HTi=101OCTD405U8?@@0=RLP0`0M518401/C40@091LE100J514401XC4@@08a`F
0`0l=c`4055HHal0IGEn5P3oool001@0oooo7`1UMGh402HN60<0:RPW100R71/402<G5@@04a0<100F
4a0401DA3`@09AdI0`0b:1l404m;A`@0IF=N101UIFD406EYJ@@0IFib0`1ULGL406EYJ@@0IFY/201U
IV@406EYJ@<0IFEQ101UIEh405iKE0@0GUiH101QFU@4065DD0@0HEMB0`1QFU@405iFD0P0Ee9<101M
FU@405M@B@<0FTa6101JCTL404a:@`P0AdY2100i>c@401LJ6P<030d;100K5QT4018?4@@040h;100;
1PL401/D4`<0=S8d101HIF`O06EeOQH0oooo000D0?oooal0IGEn100V7QP302XX9`@08Q`K100S5aD4
01<@30@05Q<@100E4@l402DM6@<0<RPO101?BdL406ESGP@0IFEU101UJFT406E^LP<0IG5g101UJFT4
06EZK0P0IFIT101UJFT306EUH@@0IFEN101NFe@405iNF0@0HEYD101QE504065GDP<0HEYD101NEU08
05MBC0@0GEYD101GD4T305Y<AP@0FTi7101<BT<804M:@P@0>C/d100G6QX300`=2`@06aHI100B3a44
010>2`@02`H7100K51<303Hb=0@0F6E/7`1UMGhF0?ooo`00503ooolO06EeOP@09QhH0`0Z:2L4028L
6`@08aLE100C40`401HC40@05A4?100U7AT3038X7`@0Cd]7101UHeh406EUI@@0IFUY101UKW8306Ea
M`@0IFUY101UJV`806EVI0@0IFUY0`1UIF4406EUGP@0GU]D101NGUP4065JE0@0HEA@101QEe83065J
E0@0GUI@201GDT`405eJE0@0Ee190`1JC4H405Y>A`@0C4Y32017BT8403Tk=0@05aXJ0`0<3@/401/F
6@@04PlA100@3P/400/61`@06a@C0`0f<S@405QUK1l0IGEn5P3oool001@0oooo7`1UMGh402HN60<0
:RPW100R71/402<G5@@04a0<100F4a0401DA3`@09AdI0`0b:1l404m;A`@0IF=N101UIFD406EYJ@@0
IFib0`1ULGL406EYJ@@0IFY/201UIV@406EYJ@<0IFEQ101UIEh405iKE0@0GUiH101QFU@4065DD0@0
HEMB0`1QFU@405iFD0P0Ee9<101MFU@405M@B@<0FTa6101JCTL404a:@`P0AdY2100i>c@401LJ6P<0
30d;100K5QT4018?4@@040h;100;1PL401/D4`<0=S8d101HIF`O06EeOQH0oooo000D0?oooal0IGEn
100b91d302TS8@@0:R@R100S7A/402DI5P@07Q@A100S71X402dZ:@<0;Bd/1019AdH405iGD`P0IF=S
101UHf8306EZK0P0IG5g301UJFT306EUJ0@0GUmM101NFeH8065GDP@0HEYD101KFU@305QCCP@0Fe=>
201JDT`405Y@BP@0GE9<0`1GD4T405A>A`@0DDY3101MBT<405I4?@@0<BPU100L4a8302@K6@@040/<
100A3Pl400`720@050lA100K514303@g>0@0GW9k7`1UMGhF0?ooo`00503ooolO06EeOP@0<R@M0`0Y
8b4402XT8P@08adK100U6AH401hD4@@08a`J100]:RT302d];0@0BDM6101NEe<806ESH`@0IF=R0`1U
JV`806EaM``0IFUY0`1UIFP405iOG@@0GU]F201QEe84065JE0@0FeYD0`1HDdh405]CCPP0FU9<101J
D4X405eBC0<0Ee19101DCTL4055:@`@0GDY3101FA3d4034X9@@071<B0`0T6aT4010;30@04@h?100<
1`P401@?4@@06a@A0`0d=cP405ibNal0IGEn5P3oool001@0oooo7`1UMGh4038T7@<0:B<Q100Z9284
02<M6`@09ATF100N514402<L6P@0;BXY0`0];B`404U7AP@0GUMC201UHf<406ESHP<0IFY/201ULGL<
06EYJ@<0IFEX101NGed405iKEPP0HEMB101QFU@405]JE0<0F5=>101KDdh805YBC0@0FU1:101MDT`3
05M@B@@0E4i7101ABT<405e:@`@0ET@m100a:2D401`C4P<091/I100@2``4014>3`@030L8100D3a44
01/D4@<0=3Lh101NLW/O06EeOQH0oooo000D0?oooal0IGEn100b91d302TS8@@0:R@R100S7A/402DI
5P@07Q@A100S71X402dZ:@<0;Bd/1019AdH405iGD`P0IF=S101UHf8306EZK0P0IG5g301UJFT306EU
J0@0GUmM101NFeH8065GDP@0HEYD101KFU@305QCCP@0Fe=>201JDT`405Y@BP@0GE9<0`1GD4T405A>
A`@0DDY3101MBT<405I4?@@0<BPU100L4a8302@K6@@040/<100A3Pl400`720@050lA100K514303@g
>0@0GW9k7`1UMGhF0?ooo`00503ooolO06EeOP@0:RPW0`0[:BP402hY9`@0;2HT100S61H4018?30@0
7aHD100`8A/304Lb:0@0Ecd`101HDD`4069SG0@0IFES101UHf<306ESHP@0IFY/101UKW8406EaM`@0
IFa^101UJFT306EUI@@0J6QS101UH5/405]JE0@0F5=>101NDE8405iACP<0GTe8101NCDh405Y@C0@0
FU9<101JC4H405A:A0<0E4a6101A@S`405Y6@0@0DClh100a;B`4028L6@@07QDC0`0A3P/4018>40@0
40/<100D40`401D@4@@08aLE0`2BZK<408bV/1l0IGEn5P3oool001@0oooo7`1UMGh402XX9`<0:bTX
100^:BL402`V90@08aPF100B3``401lF50@0<24K0`17<RP405Lm<0@0F55<101RHe`406EUH`@0IF=S
0`1UHf8406EZK0@0IFib101ULGL406E/KP@0IFUY0`1UIFD406QXH`@0IF1K101KFU@405QCCP@0GU5B
101NDDh305i=B0@0GTe>101JD4`405YBC0@0FTa6101DBT@305A<AP@0DD8l101JAT04054o>0@0<Bd/
100R71T401hE4`<04@h;100B3Q04010;30@0510<100E414402<G5@<0TZVc102<Y[0O06EeOQH0oooo
000D0?oooal0IGEn100Z:2L302/Y:0@0;RTW100/9R@402<H5P@04Pl<100O5Q@4030Q6`<0Ac8X101G
?C0405QAC0@0HV=L101UIF<406ESH`<0IF=R101UJV`406E^LP@0IG5g101UK6h406EYJ@<0IFEU101X
J6<406EPF`@0FeYD101HDdh405iADP@0GU5>0`1NCDP405i=CP@0FU1<101JDT`405Y<AP@0E4Y40`1D
C4H40552?0@0FTI0101A?cP4034];0@08Q`I100N5A<3014>2`@04Ph@100@2``401@@30@05A0A100S
5aD309:Y/`@0S:J`7`1UMGhF0?ooo`00503ooolG06EeOP@0IFig101NIFh402HP7`<09R4P100Z9RD4
02PS8@@06A<@100S71X402DN6`@08AlM0`0i<BX404i2?0@0F5MD101RHUh406EUI@L0IFa/301UKW88
06EYJ@<0GUmH101RG5H4065DD0@0IEMB101XG5L405iHD0@0FeI>0`1NDT`405MHD0@0EeA<101DATH4
059:AP@0E4i70`1GCTL405Y<A@@0CTa51010?CD4044e:`@09ahG100O5Q@701PD4@@06ADA100E40`4
01PD40@08QLE0`1[O8H406QhPAl0IGEn5P3oool001@0oooo5`1UMGh406E^M`@0GVE^100V81l302HQ
80@0:RHU100X8b4401TC40@08a`J100U7Q/4024O7@<0>C4Z101>@S`405QGE0@0HV9N101UIFD706E/
K0`0IFib201UJFT305iOF0@0HUaF101QE50406EGDP@0J5aG101NF50405]FCP<0GU9<101GF50405MD
C0@0E4I6101BBTH405A>A`<0Edi7101JC4D404i<A@@0@3de1011=B/402LN5`@07aHD1`0H514401TE
4@@05A0<100H5104028G5@<0Jgb6101XN84O06EeOQH0oooo000D0?oooaL0IGEn101UKWL405iUKP@0
9R0O0`0V8B0402XV9@@0:2<Q100I4a0402<L6P@09AhK100Q7ad303Ta:P@0CT8l101HEe@4069RGP@0
IFEU1`1UK6`<06E^LPP0IFUY0`1NGeP4069LEP@0HEA@101UEe8406QLE`@0GUQ@101KETh305iBC0@0
EeQ@101GE4`405A6AP@0DTY6101DCTL305M>A`@0FTa5101>C4D4040m=@@0@CD[100W7QL401lF50L0
61@A100I5A4401D@30@061@@100R5aD306]lQP@0J7R17`1UMGhF0?ooo`00503ooolG06EeOP@0IFig
101NIFh402HP7`<09R4P100Z9RD402PS8@@06A<@100S71X402DN6`@08AlM0`0i<BX404i2?0@0F5MD
101RHUh406EUI@L0IFa/301UKW8806EYJ@<0GUmH101RG5H4065DD0@0IEMB101XG5L405iHD0@0FeI>
0`1NDT`405MHD0@0EeA<101DATH4059:AP@0E4i70`1GCTL405Y<A@@0CTa51010?CD4044e:`@09ahG
100O5Q@701PD4@@06ADA100E40`401PD40@08QLE0`1[O8H406QhPAl0IGEn5P3oool001@0oooo5`1U
MGh406EhP@@0J7n8100T81d3030R6`@0:B8P100[9bH402lX9P@09AhK100V81d402/P6@<0=cPd100f
<bd404a1?@@0FeMC101RHf<406ESH`<0IFIW101UIV@806ESG`@0IF1N101NFU<305iFD0@0GUmJ101N
FU@405]CB0@0F55:101KDdP405iFCP<0GUQB101JDT`405Y@BP@0GE17101JD4L405M8@P<0EdE0101<
B484040o>0@0>S0Y100R71d401PB4`@04a4@0`0A3P/4018>40@03`X<10081PL400h:2`@0<R@S0`1_
O8D4069bNal0IGEn5P3oool001@0oooo5`1UMGh406EhP@@0J7n8100T81d3030R6`@0:B8P100[9bH4
02lX9P@09AhK100V81d402/P6@<0=cPd100f<bd404a1?@@0FeMC101RHf<406ESH`<0IFIW101UIV@8
06ESG`@0IF1N101NFU<305iFD0@0GUmJ101NFU@405]CB0@0F55:101KDdP405iFCP<0GUQB101JDT`4
05Y@BP@0GE17101JD4L405M8@P<0EdE0101<B484040o>0@0>S0Y100R71d401PB4`@04a4@0`0A3P/4
018>40@03`X<10081PL400h:2`@0<R@S0`1_O8D4069bNal0IGEn5P3oool001@0oooo5`1UMGh406Eh
P@@0J7n8100T81d3030R6`@0:B8P100[9bH402lX9P@09AhK100V81d402/P6@<0=cPd100f<bd404a1
?@@0FeMC101RHf<406ESH`<0IFIW101UIV@806ESG`@0IF1N101NFU<305iFD0@0GUmJ101NFU@405]C
B0@0F55:101KDdP405iFCP<0GUQB101JDT`405Y@BP@0GE17101JD4L405M8@P<0EdE0101<B484040o
>0@0>S0Y100R71d401PB4`@04a4@0`0A3P/4018>40@03`X<10081PL400h:2`@0<R@S0`1_O8D4069b
Nal0IGEn5P3oool001@0oooo5`1UMGh406EhP@@0J7n8100T81d3030R6`@0:B8P100[9bH402lX9P@0
9AhK100V81d402/P6@<0=cPd100f<bd404a1?@@0FeMC101RHf<406ESH`<0IFIW101UIV@806ESG`@0
IF1N101NFU<305iFD0@0GUmJ101NFU@405]CB0@0F55:101KDdP405iFCP<0GUQB101JDT`405Y@BP@0
GE17101JD4L405M8@P<0EdE0101<B484040o>0@0>S0Y100R71d401PB4`@04a4@0`0A3P/4018>40@0
3`X<10081PL400h:2`@0<R@S0`1_O8D4069bNal0IGEn5P3oool001@0oooo7`1UMGh403<Y9`<0:R0I
100Z9bH402dX9P@08ahL100P5Q@402XN5`@0:R@R0`0_;BX402/P7@@0?cDb101HFEH406EUGP@0IFEK
0`1UHf0406EPF@P0IF1G101UHf0406QXH`<0IF1K101QE50405]9A0@0Fd]8101NCE0405iCDP@0GUIB
0`1NBT@405Y=B0P0FTa6101GCTL405M:@`<0DD@m1012?CH403X_:0@08Q/M100N6QH401LB3`@05A<@
0`0L514401D@4@@040/<100A2``402TI5P@0//gC0`2L_LDS06EeOQH0oooo000D0?oooal0IGEn100c
:BL302XP6@@0:RLV100]:2H402<N70@081HD100Z7QL402XT8P<0;bdZ100[81d403le<P@0F5UF101U
IEh406EUF`<0IF=P101UH5T806EPE`@0IF=P101XJ6<306EPF`@0HEA@101KBD@405];B0@0GTe@101N
De8405iFDP<0GTY4101JCDP805Y<AP@0Edi7101GBT<30554?@@0@Sdf100j;bP4028K7@@07QXF100G
4Pl401DC40<071@A100E4144010;30@04@/<100Y6AH40;;=d`<0W;g58`1UMGhF0?ooo`00503ooolO
06EeOP@0<bTW0`0Z81T402XW9P@0;BPV100S7Q`4020F50@0:QhG100Z928302l]:P@0:b0M100o=C84
05QIEP@0IFEN101UIE/306ESH0@0IF1I201UH5L406ESH0@0J6QS0`1UH5/4065DD0@0FdU4101KBdP4
05i=D0@0GU=B101NEU8305i:A0@0FTe8201JC4H405M>A`@0EdY30`1AA3d4048m=P@0>RlX100R6ad4
01hJ5P@05a8?100E4a0301`D4@@05A0A100@2``4014;30@0:ATF102bcM<309bmaB<0IGEn5P3oool0
01@0oooo7`1UMGh403<Y9`<0:R0I100Z9bH402dX9P@08ahL100P5Q@402XN5`@0:R@R0`0_;BX402/P
7@@0?cDb101HFEH406EUGP@0IFEK0`1UHf0406EPF@P0IF1G101UHf0406QXH`<0IF1K101QE50405]9
A0@0Fd]8101NCE0405iCDP@0GUIB0`1NBT@405Y=B0P0FTa6101GCTL405M:@`<0DD@m1012?CH403X_
:0@08Q/M100N6QH401LB3`@05A<@0`0L514401D@4@@040/<100A2``402TI5P@0//gC0`2L_LDS06Ee
OQH0oooo000D0?oooal0IGEn100n?3`302`X9P@09b<R100_9RD402/O60@09b4M100P6aX402DR8@<0
81/K100Q8R@403@b:`@0@cde101EDDd405]LF0<0HV=L101UIEh406EUH@@0GUmJ101KG5H4069SG0<0
HEMB101KBdH405]CB0@0Edi6201DD4P405]=B0L0Eda6101JATH405A<A`@0E4i2101AA3`304a4?@@0
@Sde100]8Ah4020K5P@05A4?100@3@/4018>40<06Q<@100D3a0400d720@040/<100Q5aD7069bNb<0
IGEn5P3oool001@0oooo7`1UMGh403hl?0<0;2PV100W8b8402lV9@@0:alH100W8Ad4020K6P@09B8Q
0`0P6a/4024R90@0=38[1013?CD405EAC@@0FeaH0`1RHe`406EUGP@0IFEQ101NGeX405]LEP@0HV=L
0`1QEe8405];AP@0Fe=8101GCTH805A@B0@0Fde81`1GC4H405Y6AP@0E4a7101DCT840554?0<0C4@m
1012?CD402dQ7P@081/F100E4@l4010=2`@04Ph@0`0J4a0401@?40@03@L8100@2``4024G5@L0HW9k
8`1UMGhF0?ooo`00503ooolO06EeOP@0?S`l0`0/:2H402LS8P@0;bHU100[7aP402LQ7@@081/J100U
8R43020K6`@08B8T100d<R/404<m=@@0EE5=101KG5P3069SG0@0IFEN101UIF4405iOFP@0FeaF101R
He`3065GDP@0Fd]6101KDdP405M>APP0E518101KCDP705M<AP@0FTI6101DC4L405A>@P@0DD@l0`1<
A3d4048m=@@0;B4N100P6aH401DA3`@040d;100B3Q0301XC40@050l@100=1`P4010;30@08ALE1`1R
LW/S06EeOQH0oooo000D0?oooal0IGEn100n?3`302`X9P@09b<R100_9RD402/O60@09b4M100P6aX4
02DR8@<081/K100Q8R@403@b:`@0@cde101EDDd405]LF0<0HV=L101UIEh406EUH@@0GUmJ101KG5H4
069SG0<0HEMB101KBdH405]CB0@0Edi6201DD4P405]=B0L0Eda6101JATH405A<A`@0E4i2101AA3`3
04a4?@@0@Sde100]8Ah4020K5P@05A4?100@3@/4018>40<06Q<@100D3a0400d720@040/<100Q5aD7
069bNb<0IGEn5P3oool001@0oooo7`1UMGh403Tf<@<0;BPV100^:BL402LS8@@09R<R100L5QT401lI
60@08ahL0`0]:2H402XO60@091`H100];bd4044k>@@0DT=00`1KDDh405]DD0@0FeYF101NGeX4065K
EP@0GUIB0`1HEE0405A<AP@0E4Q4101GBTH405Y6@0@0FTM2101GBT@305M<AP@0E4Q2101BB40404m2
>P@0BChj100n?CP303@_:0@0<bTR100P6aH401@@3`@04a4@100C3``4010;30<03PX;10071PL400P7
1`@09ATF100a7QH406]hORH0IGEn5P3oool001@0oooo7`1UMGh403Tf<@<0;BPV100^:BL402LS8@@0
9R<R100L5QT401lI60@08ahL0`0]:2H402XO60@091`H100];bd4044k>@@0DT=00`1KDDh405]DD0@0
FeYF101NGeX4065KEP@0GUIB0`1HEE0405A<AP@0E4Q4101GBTH405Y6@0@0FTM2101GBT@305M<AP@0
E4Q2101BB40404m2>P@0BChj100n?CP303@_:0@0<bTR100P6aH401@@3`@04a4@100C3``4010;30<0
3PX;10071PL400P71`@09ATF100a7QH406]hORH0IGEn5P3oool001@0oooo7`1UMGh403Tf<@<0;BPV
100^:BL402LS8@@09R<R100L5QT401lI60@08ahL0`0]:2H402XO60@091`H100];bd4044k>@@0DT=0
0`1KDDh405]DD0@0FeYF101NGeX4065KEP@0GUIB0`1HEE0405A<AP@0E4Q4101GBTH405Y6@0@0FTM2
101GBT@305M<AP@0E4Q2101BB40404m2>P@0BChj100n?CP303@_:0@0<bTR100P6aH401@@3`@04a4@
100C3``4010;30<03PX;10071PL400P71`@09ATF100a7QH406]hORH0IGEn5P3oool001@0oooo7`1U
MGh403Tf<@<0;BPV100^:BL402LS8@@09R<R100L5QT401lI60@08ahL0`0]:2H402XO60@091`H100]
;bd4044k>@@0DT=00`1KDDh405]DD0@0FeYF101NGeX4065KEP@0GUIB0`1HEE0405A<AP@0E4Q4101G
BTH405Y6@0@0FTM2101GBT@305M<AP@0E4Q2101BB40404m2>P@0BChj100n?CP303@_:0@0<bTR100P
6aH401@@3`@04a4@100C3``4010;30<03PX;10071PL400P71`@09ATF100a7QH406]hORH0IGEn5P3o
ool001@0oooo7`1UMGh406Y`P`<0?30a100]9bH402PS8@@0<Rd/100_8QX402@H50@0;RPW0`0T7ad4
02XW9P@07Q/J100R9bH401XO7`@08b8Q0`13>cT404To>`@0C4E8101>Ad`404i:B0@0EE9>0`1?AD04
03Tb;@@0=c0/1014=B`404m4?@@0DTQ2101B>cD30591?@@0E4Pf101AA3X404`o>0@0B3Tc1012>C<3
034V8`@08QPE100I4Q8401TB40@04`l<100?2P`4010;30<03@L810091`P4014;30@06a<@102AZkH4
09bjaRH0IGEn5P3oool001@0oooo7`1UMGh406Y`P`<0?30a100]9bH402PS8@@0<Rd/100_8QX402@H
50@0;RPW0`0T7ad402XW9P@07Q/J100R9bH401XO7`@08b8Q0`13>cT404To>`@0C4E8101>Ad`404i:
B0@0EE9>0`1?AD0403Tb;@@0=c0/1014=B`404m4?@@0DTQ2101B>cD30591?@@0E4Pf101AA3X404`o
>0@0B3Tc1012>C<3034V8`@08QPE100I4Q8401TB40@04`l<100?2P`4010;30<03@L810091`P4014;
30@06a<@102AZkH409bjaRH0IGEn5P3oool001@0oooo7`1UMGh406Y`P`<0?30a100]9bH402PS8@@0
<Rd/100_8QX402@H50@0;RPW0`0T7ad402XW9P@07Q/J100R9bH401XO7`@08b8Q0`13>cT404To>`@0
C4E8101>Ad`404i:B0@0EE9>0`1?AD0403Tb;@@0=c0/1014=B`404m4?@@0DTQ2101B>cD30591?@@0
E4Pf101AA3X404`o>0@0B3Tc1012>C<3034V8`@08QPE100I4Q8401TB40@04`l<100?2P`4010;30<0
3@L810091`P4014;30@06a<@102AZkH409bjaRH0IGEn5P3oool001@0oooo7`1UMGh406Y`P`<0?30a
100]9bH402PS8@@0<Rd/100_8QX402@H50@0;RPW0`0T7ad402XW9P@07Q/J100R9bH401XO7`@08b8Q
0`13>cT404To>`@0C4E8101>Ad`404i:B0@0EE9>0`1?AD0403Tb;@@0=c0/1014=B`404m4?@@0DTQ2
101B>cD30591?@@0E4Pf101AA3X404`o>0@0B3Tc1012>C<3034V8`@08QPE100I4Q8401TB40@04`l<
100?2P`4010;30<03@L810091`P4014;30@06a<@102AZkH409bjaRH0IGEn5P3oool001@0oooo7`1U
MGh407F<T@<0@T4g100T81d402DQ80@09R4P100M7A`401/G6P@09QdG0`0X8R04038];0@0<B/Y100X
8b8402LU:0@0;2TX0`0U8al401dQ9P@0624S100N7QX402dZ9P@0;bh[0`0T92D402/V8@@0;BDO100]
;28403@Z9@@0>c4W1019?C0304<i<@@0=2XW100g:BH403h`:`@0<c0_100Z8R4302@H50@07A@C100F
4A04014>2`@03`X<100<1`P400P71`<020L810091`P401PD4@@09ATF101^OhP406QkQBH0IGEn5P3o
ool001@0oooo7`1UMGh407F<T@<0@T4g100T81d402DQ80@09R4P100M7A`401/G6P@09QdG0`0X8R04
038];0@0<B/Y100X8b8402LU:0@0;2TX0`0U8al401dQ9P@0624S100N7QX402dZ9P@0;bh[0`0T92D4
02/V8@@0;BDO100];28403@Z9@@0>c4W1019?C0304<i<@@0=2XW100g:BH403h`:`@0<c0_100Z8R43
02@H50@07A@C100F4A04014>2`@03`X<100<1`P400P71`<020L810091`P401PD4@@09ATF101^OhP4
06QkQBH0IGEn5P3oool001@0oooo7`1UMGh407F<T@<0@T4g100T81d402DQ80@09R4P100M7A`401/G
6P@09QdG0`0X8R04038];0@0<B/Y100X8b8402LU:0@0;2TX0`0U8al401dQ9P@0624S100N7QX402dZ
9P@0;bh[0`0T92D402/V8@@0;BDO100];28403@Z9@@0>c4W1019?C0304<i<@@0=2XW100g:BH403h`
:`@0<c0_100Z8R4302@H50@07A@C100F4A04014>2`@03`X<100<1`P400P71`<020L810091`P401PD
4@@09ATF101^OhP406QkQBH0IGEn5P3oool001@0oooo8`1UMGh3059FI`@0<2XZ100^:BL402TY9`@0
:bDS100G4a04024N70<0<2d]100b;B`403Da<0@0>SDc100n>S8403Pg<0<0:Rl[100R8B8402@J5P@0
8ATK100Q6QX402DO7`<081dO100P7b8402XQ80@0:b0J100T7Qd402/Y9@@0:bTT0`0W91l4034[9@@0
;2HN100W9bD402PO70@09QdH0`0I51<401`J6@P04Pl<100@2``400d720L02@L8100O5A4401H@4@@0
GEEF1029VJ4Z06EeOQH0oooo000D0?ooob<0IGEn0`1BEVL4030Z:P@0;RTW100Y:BL402/U8`@05a<@
100Q7Q`3030];@@0<Rd/100e<C0403Xe<`@0?SXb100h=c0302X_:`@08R4R100T6QH4024I6`@08AXJ
100U7al3020M7`@081lR100Z8B0402/P6P@091hM100[:BD402/Y90<09b@O100a:bD402`V7P@09bLU
100X7a`402HM60<06A@C100L6QT8018?30@040/<100=1`P700T720@07aDA100F414405eEEP@0RIVQ
:P1UMGhF0?ooo`00503ooolS06EeOP<0DUIW100`:RX402hY9`@0:BTW100[9B<401LC40@08AhL0`0`
;Bd4038];0@0=C4`100j=C<403hj<P@0>3L`0`0Z;b/4028Q8P@091XF100Q6A/4024J6P@09AlO0`0P
7Al4020O8P@0:R4P100[81X402@N7@@0:bTU100[:B@302LT7`@0<B/U100/9Qh402LW9@@0:1lL100V
7AP301TD4`@071XI200B3``4010;30@03@L81`091`P401lE4@@05Q0A101MEEH408VIXBX0IGEn5P3o
ool001@0oooo8`1UMGh3059FI`@0<2XZ100^:BL402TY9`@0:bDS100G4a04024N70<0<2d]100b;B`4
03Da<0@0>SDc100n>S8403Pg<0<0:Rl[100R8B8402@J5P@08ATK100Q6QX402DO7`<081dO100P7b84
02XQ80@0:b0J100T7Qd402/Y9@@0:bTT0`0W91l4034[9@@0;2HN100W9bD402PO70@09QdH0`0I51<4
01`J6@P04Pl<100@2``400d720L02@L8100O5A4401H@4@@0GEEF1029VJ4Z06EeOQH0oooo000D0?oo
ob<0IGEn0`1dPHd403``;P@0:B<Q100W8B0402PR8@@0;bLU100e;B/3038];0@0<c0_100Z9RD402HR
8P@0:AdM100b7ad302dM6@@091lN100K61L4020Q8@@061@C100J71d301lO7`@07Q`K100G4a8401@E
5P@0518C100D410401DD4`L05aLD100E414401H@40@0510@100F4Q83018A3`@03`h;100>2P/400l:
30@040/<20091`P301lE6`@07aDB100`:2D409J`]P@0PZ2Z:P1UMGhF0?ooo`00503ooolS06EeOP<0
M86=100l<2h402TS8@@09b4P100X8R4402lW9@@0=Bd[0`0b;B`403<`;`@0:RHU100V8R8402TM7@@0
<QlM0`0]7AT402@O7P@06aPG100P8B4401PD4`@06Q`M0`0O7al401hL6`@05a<B100D5AH401@B4`@0
510@100E51<701LG50@05A0A100F410401@@40@05Q8B0`0B4@l400l>2`@03PX;100?2P`4010;30P0
2@L80`0O5A/401lE4P@0<2PU102F/;H408:PZRX0IGEn5P3oool001@0oooo8`1UMGh307B1S@@0?30^
100Y8b4402LQ80@0:28Q100_9bD403D]:`<0<Rd/100c<2l402XV9@@09R8R100Y7Ad4038O7@<0;AdI
100T7ah401/H5`@0824Q100H51<401XL7@<07alO100N71/401LC4P@051DF100D4Q<401@@40@05A@C
1`0G5a@401D@4@@05Q0@100D410401HB4P<04Q4?100?3P/400h:2`@03`X<100@2``800T720<07aDK
100O5A84030X9@@0U[2f1022X:XZ06EeOQH0oooo000D0?ooob<0IGEn0`1dPHd403``;P@0:B<Q100W
8B0402PR8@@0;bLU100e;B/3038];0@0<c0_100Z9RD402HR8P@0:AdM100b7ad302dM6@@091lN100K
61L4020Q8@@061@C100J71d301lO7`@07Q`K100G4a8401@E5P@0518C100D410401DD4`L05aLD100E
414401H@40@0510@100F4Q83018A3`@03`h;100>2P/400l:30@040/<20091`P301lE6`@07aDB100`
:2D409J`]P@0PZ2Z:P1UMGhF0?ooo`00503ooolS06EeOP<0Jgn5101QJfl403<]:`@0:2<Q100]:2H4
02TT8P@0=C4`0`0S7Q`402TV9P@08A`K100X92@403Tc;0@0:RXX0`0R8b<402HS8P@09R0M100c:BL4
01lG6P@07QhM0`0M518401hD4P@0614?100C4@l401HA3`P07QHD0`0E40l401@@3`@05A4?100M5Q@4
01PC40@05a8@0`0B3P/401<?30P040/<20091`P4014;30<09AdI100U6AD40:Jma@@0Wk[2;P1UMGhF
0?ooo`00503ooolS06EeOP<0Jgn5101QJfl403<]:`@0:2<Q100]:2H402TT8P@0=C4`0`0S7Q`402TV
9P@08A`K100X92@403Tc;0@0:RXX0`0R8b<402HS8P@09R0M100c:BL401lG6P@07QhM0`0M518401hD
4P@0614?100C4@l401HA3`P07QHD0`0E40l401@@3`@05A4?100M5Q@401PC40@05a8@0`0B3P/401<?
30P040/<20091`P4014;30<09AdI100U6AD40:Jma@@0Wk[2;P1UMGhF0?ooo`00503ooolS06EeOP<0
Jgn5101QJfl403<]:`@0:2<Q100]:2H402TT8P@0=C4`0`0S7Q`402TV9P@08A`K100X92@403Tc;0@0
:RXX0`0R8b<402HS8P@09R0M100c:BL401lG6P@07QhM0`0M518401hD4P@0614?100C4@l401HA3`P0
7QHD0`0E40l401@@3`@05A4?100M5Q@401PC40@05a8@0`0B3P/401<?30P040/<20091`P4014;30<0
9AdI100U6AD40:Jma@@0Wk[2;P1UMGhF0?ooo`00503ooolS06EeOP<0Jgn5101QJfl403<]:`@0:2<Q
100]:2H402TT8P@0=C4`0`0S7Q`402TV9P@08A`K100X92@403Tc;0@0:RXX0`0R8b<402HS8P@09R0M
100c:BL401lG6P@07QhM0`0M518401hD4P@0614?100C4@l401HA3`P07QHD0`0E40l401@@3`@05A4?
100M5Q@401PC40@05a8@0`0B3P/401<?30P040/<20091`P4014;30<09AdI100U6AD40:Jma@@0Wk[2
;P1UMGhF0?ooo`00503ooolV06EeOP@0JFmm100i:2H402lX9P@0;BPV100X8b4401`K6P<0;2TY100h
=38402/Z:0@08alM100X7QT401`F5@<07a/J100R7A/401LE70@06Q/K100J5QL4024F50<06A4H100C
4Q0401@C40@04Pl<100E4a0401@C40@04Q8@0`0@3P/400h:2`@040h;100G4Q04014>2`@03PX;0`0B
3P`401@?4@@040/<10091`P4010;30@06aDB100[81`302HI5P@0Y/39102Va<`b06EeOQH0oooo000D
0?ooobH0IGEn101YKgd403TX9P@0;bPV100]:2H402PS8@@071/J0`0/:BT403Pd<P@0:bXX100S7ad4
02PN6@@071HE0`0O6aX4028M6`@05aDL100J6a/401XF5`@08AHD0`0I4AP401<B40@051<@100B3``4
01DC40@051<@100B4Q03010>2`@03PX;100@3P/401LB40@04@h;100>2P/3018>30@050lA100@2``4
00T720@040/<100K5A8402/P70<09QTF102V`<T40:K4c380IGEn5P3oool001@0oooo9P1UMGh406U_
O@@0>BPV100_:2H402dX9P@0:2<Q100L6aX302`Y:@@0>3@b100[:RP402<O7@@0:1hI100L5QD301lK
6P@08QdK100G5A`401XK6`@06QHG100Q5Q@301TA60@04a8@100D4a04018?30@05A<@100D4a04018B
40<040h;100>2P/4010>2`@05a8@100A3P/400h:2`<04Ph<100D3a44010;30@02@L8100@2``401/E
4P@0:b0L0`0V6AH40:K0b@@0Y/C<<P1UMGhF0?ooo`00503ooolV06EeOP@0JFmm100i:2H402lX9P@0
;BPV100X8b4401`K6P<0;2TY100h=38402/Z:0@08alM100X7QT401`F5@<07a/J100R7A/401LE70@0
6Q/K100J5QL4024F50<06A4H100C4Q0401@C40@04Pl<100E4a0401@C40@04Q8@0`0@3P/400h:2`@0
40h;100G4Q04014>2`@03PX;0`0B3P`401@?4@@040/<10091`P4010;30@06aDB100[81`302HI5P@0
Y/39102Va<`b06EeOQH0oooo000D0?ooobH0IGEn101_QH/404Y<B@@0;2PV100Z9RD402PS8@@0<2TW
0`0Z:2L402HS8`@08A/J100O61L401`H5`@05A4?0`0R7A/401`F60@07AHG100J4@l401PA5`@040h@
0`0<2P/4014>3`@04Ph@100?2P`4018>40@03`X<100B3Q0300l:30@050lA100H514401<?4@@03`X<
10081`P300P61`@01`H710081PL401@@4@@05Q4<100@2``401L=2`<0UjR`102S_LHf06EeOQH0oooo
000D0?ooobH0IGEn101_QH/404Y<B@@0;2PV100Z9RD402PS8@@0<2TW0`0Z:2L402HS8`@08A/J100O
61L401`H5`@05A4?0`0R7A/401`F60@07AHG100J4@l401PA5`@040h@0`0<2P/4014>3`@04Ph@100?
2P`4018>40@03`X<100B3Q0300l:30@050lA100H514401<?4@@03`X<10081`P300P61`@01`H71008
1PL401@@4@@05Q4<100@2``401L=2`<0UjR`102S_LHf06EeOQH0oooo000D0?ooobH0IGEn101_QH/4
04Y<B@@0;2PV100Z9RD402PS8@@0<2TW0`0Z:2L402HS8`@08A/J100O61L401`H5`@05A4?0`0R7A/4
01`F60@07AHG100J4@l401PA5`@040h@0`0<2P/4014>3`@04Ph@100?2P`4018>40@03`X<100B3Q03
00l:30@050lA100H514401<?4@@03`X<10081`P300P61`@01`H710081PL401@@4@@05Q4<100@2``4
01L=2`<0UjR`102S_LHf06EeOQH0oooo000D0?ooobH0IGEn101_QH/404Y<B@@0;2PV100Z9RD402PS
8@@0<2TW0`0Z:2L402HS8`@08A/J100O61L401`H5`@05A4?0`0R7A/401`F60@07AHG100J4@l401PA
5`@040h@0`0<2P/4014>3`@04Ph@100?2P`4018>40@03`X<100B3Q0300l:30@050lA100H514401<?
4@@03`X<10081`P300P61`@01`H710081PL401@@4@@05Q4<100@2``401L=2`<0UjR`102S_LHf06Ee
OQH0oooo000D0?ooobX0IGEn102<Y[0405mLFP@0:B8P100U8B0702LW9P@0<2`[100[9BP4028G5@@0
8AXH100F4a0301LA3`@04a4>100H4Pl400h:2`@03@X;100B3Pl301@@4@@040/<100C3a04010;30@0
50l@100@2``402DH5@<02PL8100B3a0401LC40@050l@20091`P300h720@05Q0A100H4A8401H@4@@0
9APF100g9A`406e=>P<0SibM101XNhDf06EeOQH0oooo000D0?ooobX0IGEn102<Y[0405mLFP@0:B8P
100U8B0702LW9P@0<2`[100[9BP4028G5@@08AXH100F4a0301LA3`@04a4>100H4Pl400h:2`@03@X;
100B3Pl301@@4@@040/<100C3a04010;30@050l@100@2``402DH5@<02PL8100B3a0401LC40@050l@
20091`P300h720@05Q0A100H4A8401H@4@@09APF100g9A`406e=>P<0SibM101XNhDf06EeOQH0oooo
000D0?ooobX0IGEn102<Y[0405mLFP@0:B8P100U8B0702LW9P@0<2`[100[9BP4028G5@@08AXH100F
4a0301LA3`@04a4>100H4Pl400h:2`@03@X;100B3Pl301@@4@@040/<100C3a04010;30@050l@100@
2``402DH5@<02PL8100B3a0401LC40@050l@20091`P300h720@05Q0A100H4A8401H@4@@09APF100g
9A`406e=>P<0SibM101XNhDf06EeOQH0oooo000D0?ooobh0IGEn102<Y[04065FE0@0<Bh/100S7Q`3
030Y:@@0<R`[100b;B/402<R7`@09R8O100L51X301<?4@@06Q<@100C3a0401LD4@@06QDA100E414C
010;30@061@@100B3a4302T]?P@0=3Hj100P5Qh4010;30@05A0A1`0L5Q8401DA4@@0:R8O100[81`4
02DI5P@0@RhX102E/l<308FY^CX0IGEn5P3oool001@0oooo;P1UMGh408bV/0@0HEID100a;R`402<N
70<0<2TY100b;2/4038]:`@08b8O100V8Ql401`D6P<04`lA100J4a0401<?40@05a@A100J5A4401D@
4A<040/<100H5104018?4@<0:Bdn100d=SX4020F7P@040/<100E414701`F4P@05A4A100Z8Ql402/P
70@09ATF1012;RP409Fc``<0QJVi>P1UMGhF0?ooo`00503oool^06EeOP@0S:J`101QEU@4034^;0@0
8ahL0`0`:BT4038/:`@0<Rd[100S8Ql402HR7`@071@J0`0C3a4401XC40@04`l@100G514401XE4@@0
5A0A4`0@2``401PD40@04PlA0`0Y;Ch403@f>P@081HN100@2``401D@4@L071HB100E4A4402XR7`@0
:b0L100U6AH4048^:0@0UK?30`25ZKTj06EeOQH0oooo000D0?ooobh0IGEn102<Y[04065FE0@0<Bh/
100S7Q`3030Y:@@0<R`[100b;B/402<R7`@09R8O100L51X301<?4@@06Q<@100C3a0401LD4@@06QDA
100E414C010;30@061@@100B3a4302T]?P@0=3Hj100P5Qh4010;30@05A0A1`0L5Q8401DA4@@0:R8O
100[81`402DI5P@0@RhX102E/l<308FY^CX0IGEn5P3oool001@0oooo<P1UMGh409Bb_0@0HEID100l
<c4302@O7@@08R8R100`;bh403H_;P@0;b4J100T71P301TE40@04`l@100?2P`4018>2`@04Ph@100?
2P`3010;30@0510A100A2``401@@4@@04@/<100?2P`402P[;`<09AdX100g;B/404@k=0@0>S0`1015
>SH403<X8`<06QDB100U7AX402@L6@@0;RTW1015;RH40:>g_`@0Sk2l?@1UMGhF0?ooo`00503ooolb
06EeOP@0U;:l101QEU@403`c<@<091lM100R8R84030_;P@0=Rl^100_8AX402@L60<06AD@100C3a04
00l:30@04Ph;100B3Q0400l:30<040/<100D4144014;30@0510A100A2``400l:30@0:2/_0`0U7BP4
03L]:`@0A3/d100j<30404Dj=P@0<bPS0`0J5A8402DM6P@091`I100^:BL404D^9P@0XkNo102?/;`m
06EeOQH0oooo000D0?oooc80IGEn102D/[`4065FE0@0?3<a0`0T7ad4028R8P@0<2l^100f;bh402lQ
6P@091`H0`0I5A0401<?40@03`X<100B3P/4018>40@03`X<0`0@2``401@@4@@04@/<100D4144014;
30@03`X<100X:bl302DM:0@0=bd[1014>c@403X`<0@0ACXf100c:2<301XE4P@09AdJ100T71T402hY
9`@0ABhV102S]kl408n`_3d0IGEn5P3oool001@0oooo<P1UMGh409Bb_0@0HEID100l<c4302@O7@@0
8R8R100`;bh403H_;P@0;b4J100T71P301TE40@04`l@100?2P`4018>2`@04Ph@100?2P`3010;30@0
510A100A2``401@@4@@04@/<100?2P`402P[;`<09AdX100g;B/404@k=0@0>S0`1015>SH403<X8`<0
6QDB100U7AX402@L6@@0;RTW1015;RH40:>g_`@0Sk2l?@1UMGhF0?ooo`00503ooolb06EeOP@0HW9k
1029Y[0405E5>`<0?CDb100b:bT403<_;P@0<c0_100h=C@402@N70<091`J100d:RH402dX8`@08AHC
100I514701D@4@P040/<100H51X401D@4P@06ADA100B3Ph301`K5`@0924M100<2P`400`=30@03Ph<
100<2`d301LA3`@08Q/I100[81T4050h:`@0S9>P1028ZKT406EhPCd0IGEn5P3oool001@0oooo<P1U
MGh4069bN`@0RJJ`101EAC/303de<P@0<R/Y100c;bh403<`;`@0>3Dd100T7Q`302@L6P@0=2XV100]
:2<4024F4`@06A@A1`0E4148010;30@061@J100E418401TE4@@04Ph>0`0L6aL402@Q7@@030X<100<
3@`400h>30@030/=0`0G4@l4028K6@@0:b0I101@>2/408bCX0@0R:Vi101UN84m06EeOQH0oooo000D
0?oooc80IGEn101RLW/408VV/0@0EDDk0`0m=C84038[:@@0<bl^100c<2l403Pe=0@091hL0`0T71X4
03@Z9P@0;BPS100Q5Q<401TD4@L05A0A200@2``401PD6P@05A0B100I5A44018>3P<071/G100T8Ad4
00`:30@030d<100>3P`400`;3@<05a4?100R6aT402/P6@@0D3P[102<Tj0408RY^@@0IGR1?@1UMGhF
0?ooo`00503ooolb06EeOP@0HW9k1029Y[0405E5>`<0?CDb100b:bT403<_;P@0<c0_100h=C@402@N
70<091`J100d:RH402dX8`@08AHC100I514701D@4@P040/<100H51X401D@4P@06ADA100B3Ph301`K
5`@0924M100<2P`400`=30@03Ph<100<2`d301LA3`@08Q/I100[81T4050h:`@0S9>P1028ZKT406Eh
PCd0IGEn5P3oool001@0oooo>P1UMGh408n`_0<0EEE=100T7a`402HR8P@0>CHg1011@T8403di=`<0
9QhL100K5AL401hD4`@0;BDS100Y9B8401HA4P<040/<100L61l4020K8`@0:2@P100O6R0403L^;@@0
71HM0`0l=C@402lW:P@0<2PV100g;2P402lU8P@0=B/W0`17?S@403@/:0@0FD8f102S]l8409>jaP@0
KhF;@@1UMGhF0?ooo`00503ooolj06EeOP@0Sk2l0`1EEDd402@O70@09R8R100i=SL40452@P@0?CTg
0`0V7Q`401/E5`@07Q@C100]9B<402TU8P@05Q4B0`0@2``401`H7`@081/S100X920401lJ80@0=bh]
100L5Qd303`e=0@0;bLZ100`:2H403L/:0@0;bDR100e:bL304Ln=0@0=2`X101I@SH40:>g`P@0Tk[6
101_QH]106EeOQH0oooo000D0?ooocX0IGEn102?/;`305EEC@@091lL100V8R8403Tf=`@0@D92100m
>CL302HN70@06aDG100N51<402dU8`@0:BDR100F4A83010;30@071PO100P6b<402PT80@07aXP100g
;Rd401`F7@<0?3Dd100_9bX4030X9P@0=b`X100_9B8403D[9`<0Achd100d;2P405U2=P@0XkO2102C
^/H406n5Rd40IGEn5P3oool001@0oooo>P1UMGh408n`_0<0EEE=100T7a`402HR8P@0>CHg1011@T84
03di=`<09QhL100K5AL401hD4`@0;BDS100Y9B8401HA4P<040/<100L61l4020K8`@0:2@P100O6R04
03L^;@@071HM0`0l=C@402lW:P@0<2PV100g;2P402lU8P@0=B/W0`17?S@403@/:0@0FD8f102S]l84
09>jaP@0KhF;@@1UMGhF0?ooo`00503oooln06EeOP<0SjVf102V//H404e6A0@0:2@T100T8B4402dc
?`<0ATA5101ECDT405EFDP@0<B`_100V:Bh40492E0<0H5aJ100m<C8402dY=@@0;bL[1010?Th403D^
;@@0;bLS0`0e;R/4030V9@@0=B@Q100e8a`4034Y9P@0@3D^0`1G?S4403TU7@@0S:Vf1025[K`406Eh
PDD0IGEn5P3oool001@0oooo?P1UMGh308nY]P@0Y[;6101=AT@402PT90@0924Q100]<cl304I4A@@0
EDe9101EEU84034/;`@09RT^1012@U@3061LFP@0?C4b100]:CD402lW:`@0@3i>100e;Rd402lW8`<0
=Bh[100`9RD403DT8@@0=B<L100a:BH4040e;P<0Echa100i9Ad408bY]P@0QJfl101UN85506EeOQH0
oooo000D0?oooch0IGEn0`2?ZKH40:JbaP@0CDI4100X92@402@Q8@@0;C<o0`16A4D405E=B@@0EEIB
100a;2l402HY;P@0@T9D0`1PG5X403da<P@0;BTe100_9b/4040nCP@0=Bh]100_9b<303D^:`@0<2HU
100e924403DS70@0<BTV1010=Bh305Ln<@@0>BDM102<ZKH408F]_0@0IGR1A@1UMGhF0?ooo`00503o
ooln06EeOP<0SjVf102V//H404e6A0@0:2@T100T8B4402dc?`<0ATA5101ECDT405EFDP@0<B`_100V
:Bh40492E0<0H5aJ100m<C8402dY=@@0;bL[1010?Th403D^;@@0;bLS0`0e;R/4030V9@@0=B@Q100e
8a`4034Y9P@0@3D^0`1G?S4403TU7@@0S:Vf1025[K`406EhPDD0IGEn5P3oool001@0oooo@@1UMGh4
07:9SP@0Xl?9101LF6D403Xe=P@0:Rhe0`0oA4/40497C`@0>cdo1012A48405ACEP@0D4M20`0n>3@4
038/:P@0?3D_100]9RH4020K5`@08QdJ100`;2/302dX9P@0>2HP1012;BH404@e;P@0DT4j1010:B83
04<nB@@0VL3F102I^/I=06EeOQH0oooo000D0?oood40IGEn101bRHh40:?3b@@0G5QU100j=CH402X^
=@<0?dA;1012Adl403/m?`@0@TA2101DDeH40517@P<0?SPd100b;2X403`e;`@0;BHV100P6aL4028M
6P@0<2`[0`0]:2H403PV80@0@RdV1014=Bh40591>P@0@2TR0`13?TT409W0eP@0VK[6C@1UMGhF0?oo
o`00503ooom106EeOP@0LXV>102S`lT405aHI@@0>SDf100Z;SD303m4B`@0@TM?100k?Cl40494@P@0
E5=F101@Ad8303hh=0@0<R`Z100l=Bl402dV9P@081/G100R7AX4030/:`<0;BPV100h9R04048]9P@0
A3D^101B@CX4040Y8P<0@ci9102I`=H409VjaTd0IGEn5P3oool001@0oooo101UJgD406EbNd40IGEn
102?ZJd40<3Tj0@0^/[I0`1ACf8404U6C`@0Jf^3101VHFd40595A@@0@3Xi0`0n?3`40599C`@0Fdi>
101BBTP406AGD`@0DdY1101>BDH305]@CP@0B4Ho100k@C/402XX9`@0G6Ah102VdN@30;?TkP@0QJ>Z
D@1UMGhF0?ooo`00503oool406E[M@@0IG9k@@1UMGh408nY[@@0`>CX102jb]T3055?HP@0BDI?101[
Jh<406IQK@@0DTE51010>ST303hl?0@0DTU?101KCTh4059:B0@0I5MC101CBT4404i9AP<0Fe1>1018
ASl403]1>`@0:RPW101LI7P40:KAi0<0/nC^1025XjYA06EeOQH0oooo000D0?ooo`@0IF]e101ULW]1
06EeOP@0SjV]1030i>P40;[:f@<0DDmR1019ATl406][P`@0IV5]101BADD4040j>@<0?S`l101BBDl4
05]>CP@0DTY8101TEe<405=:@@@0CTU60`1KD4h404Q6?`@0>d4k100Z:2L405aTN0@0Y]7T0`2ci>h4
08FSZU40IGEn5P3oool001@0oooo101UJgD406EbNd40IGEn102?ZJd40<3Tj0@0^/[I0`1ACf8404U6
C`@0Jf^3101VHFd40595A@@0@3Xi0`0n?3`40599C`@0Fdi>101BBTP406AGD`@0DdY1101>BDH305]@
CP@0B4Ho100k@C/402XX9`@0G6Ah102VdN@30;?TkP@0QJ>ZD@1UMGhF0?ooo`00503oool406EkQ@@0
IGR1B@1UMGh406]oQ@<0UK2]102/cL`409Fg]P@0PiRZ102I]<<408ZH]0<0DUMa100oB5l403Hj?@P0
>3Pi100j>S`403Tf>0<0;BPT100]:bL408bNZP@0`nSd102YdMD407F?U5P0IGEn5P3oool001@0oooo
101UNhD406EhPDT0IGEn101[OhD309F`[@@0[<g<102E]kH408>HZP@0VKC3102:V;@3059GL@@0?dQO
100f>Sd803Ph>@@0>SXl100i=SP302dX90@0;B/W102<WZX40<?Xm0@0ZM7E101eSiAH06EeOQH0oooo
000D0?ooo`@0IG^5101UN85906EeOP@0Jgn50`2E/:d40:c=c0@0UKNf1023V:X409Vd``@0RYRd0`1B
Eg4403m8G`@0=SXm200h>3T403Xj?0@0>CHh0`0]:2@402d[9`@0S9jZ1033j?@40:WAe@@0MHnDF01U
MGhF0?ooo`00503oool406EkQ@@0IGR1B@1UMGh406]oQ@<0UK2]102/cL`409Fg]P@0PiRZ102I]<<4
08ZH]0<0DUMa100oB5l403Hj?@P0>3Pi100j>S`403Tf>0<0;BPT100]:bL408bNZP@0`nSd102YdMD4
07F?U5P0IGEn5P3oool001@0ooooH01UMGh406]oP@@0Jh:5101bS8h309Jc[@@0[L[3102`dM840;?=
e`@0/mCO102cen840;KKi@<0_NCa1030ioL409:`_0@0IGR1H01UMGhF0?ooo`00503ooomP06EeOP@0
Jgn1101[PXD407:<SP<0U[>]102]b/<40;3AdP@0/lgG102ce=l40;?GhP@0]]_U0`2mi?440<3Wm`@0
T[2l101UN85P06EeOQH0oooo000D0?ooof00IGEn101[Oh4406^2Q@@0LXb>0`2F/jd40:g:``@0/=7B
102ccML40;?Dg`@0/mOR102ffnD30;gTl@@0`>Og102B/;`406EhPF00IGEn5P3oool001@0ooooH01U
MGh406]oP@@0Jh:5101bS8h309Jc[@@0[L[3102`dM840;?=e`@0/mCO102cen840;KKi@<0_NCa1030
ioL409:`_0@0IGR1H01UMGhF0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00V`3oool2@00008<0oooo002M0?ooo`03
@000003oool0oooo0800oooo001g0?ooo`E0000000<0oooo@00004000000103oool00d000000oooo
0?ooo`0;0?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000003oool0oooo07X0oooo
001i0?ooo`03@000003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oood00000;0?ooo`06
@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood0000220?ooo`00N@3oool0
0d000000oooo0?ooo`020?ooo`03@000003oool0oooo00<0oooo00=000000?ooo`3oool02@3oool0
1D000000oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood0000220?ooo`00N@3o
ool00d000000oooo0?ooo`030?ooo`03@000003oool0oooo009000003@3oool3@00000040?oood00
00100000@00000<0oooo0d0000220?ooo`00N@3oool01d000000oooo0?ooo`3ooom000000?oood00
00000P3oool00d000000oooo0?ooo`0>0?ooo`03@000003oool0oooo08X0oooo001h0?ooo`900000
103oool014000000oooo0?ooo`3oool3@00000d0oooo0T00002<0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7D7E78
76695C7C6D607C6D657C71687C6D657C71697C71697C71697C71687C6D647D6D5F78695B796455\
745C4F755B4E6F584B6F584B6F584B6F584B6F574A7054456B54446B54456B5444
654C3F7C7E7E7C7E7E7C7E7E7C7E7E7C7F7E7C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7A797C79797C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E81837E
7C6D657C6D607C6D607C71687C6D657C71697C6D60786555736555736154745C516A584C6A584B\
6A55486B54476A55486F584B6F584B6F54476F544770544A6B54476B54456B655C
65605B7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C83827C7A797C79797C83827C7E7E7C7E7E7C7A797C79797C7A797C79797C7E7E7C7E7E\
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E787A75
7669587C6D657C69617C71697C6D657C69617869606B655C645C546F544C6F51486F594C6F6052\
6F6052745F516B54476651446651446654476654436B54446B54476B544A7C6A61
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7F7E7C79797C7E7E7C7E7E7C7E7E7C83827C7E7E7C83827C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E817E78
7C69617C6D657C6D657C69617C6D657C6D6081716892766D82766A81706784635B7A584B7A554C\
7A554F754F4A7050476B54476B54476B54476B544A6F584B70574A6B5447654C3F
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C837E
7C6D5C7C6D5C7C6D607C6D657C6D657C6D697C71697C766D8176707876637D6C627D685E7D6857\
795F527E685A7F594F744C47745854705B4F6F54476F51447054476F5C4F6B5548
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7F7A
7C6D607C6D657C6D607C6D607C6D657C71697C6D657C69617C7169817670817A6B7D716278645B\
7D685A745C4F7A6355755F516F5141745C546B5B4F6654476B5447736561766A65
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6F5C546B5B55
7C6D657C6D607C6D607C6D607C71697C6D657C71697C766D7C71697C71687C6D69817167816D5B\
7D64577D6457795F527A584E75574A6B4D3F6B54476F5447705447675A51767474
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7A797C7575\
7C79797C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E463A3242473F76695C
7C6D607C6D697C6D697C6D657C6D657C71687C695C7C6D607C6D657C6D657C6D607C716478685E\
786057785C5479604E6F57476F584B74574A7054476A5C4F745F51705A4D7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C8382\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B65693F231F161A227C6D64
7C71647C71687C71697C71687C69617C71697C76717C6D657C6D607C60587855516F5146735C4D\
7860547464546F5B51745B4E75584B6B57456B5444664D42665144654C3F7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8082823D2B1E7E725F7669587C6D65
7C69617C6D657C69617C6D657C6D657C69617C6D657C71687869607368587860577960526F594C\
6F594C745948755B4B6A54476F514474544A7454477054476F584B674638766A65
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E2F20187C71698176707C6D647C6D60
7C6D657C6D657C6D607C6D607C6D657C71697C6D657C6D657D4E4D783C3C743637743335743335\
74433F6F51476F51446F4F436B50406A54446F54477054436A4C3E613C2E654C3F
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C7979\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B6565C4B3B27669657C6D657C6D647C6D60
7C6D657C695C7C65587C65557C695D7C69617C605C7C55557D5A5574433A6F362C6E3B356F3E36\
6E3332713C3966463E6654436B4F436A50446F544774544A6F5345745448603828
6B51437C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E352923151D1C7669587C6D5C7C6D607C6D60
7C6D6078695B735C517664597C6D607C6558784F446F362F6A493F5E3D2E615C4C6E6D5B713E33\
612A216F322C703C376B4A446B533C66503B6A54446F54476F584A6F51446F5548
6B4B3C7C746F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E5B4F4F95726260524A7C6D6578655B7668617C7168
7C655B795C4B6A4C3E6B4543743B393C0E092F2A24745A507E595198A09D844E4767362D5A513A\
55574848382A4E282067332D664C3C6F4C3E6F544874604E755B4A6F584B6F5447
603C2E6B4B3C7C746F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E433630363F3F7669617C6D607D685A765B517C6D65
7C6D627952416B4436390F0B353837B4D0C887979487ABAD81979E7C767682A08E929C949EA2A5\
7A7471583E352420143120196240386A5343745549745C527A63517557476F5447
6F5548604E4D67636D7674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E6F6D75452A2510191F7669587C6D60817A6B7C6D607C6D65
745B4F684D38562E1F54190E3F120F6D393073493D76544A7C6D5C7C6451795B526D4E4874584B\
926D5DA6877092766837291F2D1C195D3C33695143786554796458755F516F5245
6F4D426B4D35595146564E516B6A747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E463A32160D08634B43604E4A7C6D607C65587C5D517C65557C6D5C
7E685789675E949883C5C5A7877F747D5C5A74584F6A3F376D3C3C6A36376A3932651E18662824\
5B302A704D3F75423B82554B311209311C1C694A42735C4D7964517557476B584A
6A584B74514387756B7A717165606A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E6F696D2318121B130F2234367C6D647C695C7C645F78645F76695C7C605C
7E6259674434654A427C716D7C7F70817F7487887D87877C81907A887B67837F6B7F81657F745C\
754C407948437A3830742C206E251938140F4725266D5147796051755B4A704F43
6A4D426F51453119103830207871717674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7F8388F2CDBDEFB191735C4E76695C7C6D5F7C766081645F7C605C7C7A64
7E6F5E7F5F5267483D7660557C71697C71687C69617C71697C64637D605A786054796055745B4E\
715B48615C466B654D7A6C588E766083665D624638644D3D745C4E755B4A705845
6A54446F5548624B4122201D6B6A657C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E8D7F677C6D65817F797D7167736558766D607C6D657C7A6D7C716D7C716D
8275697F6A596A463B674B3F76685C7C766D7C71687C6D657C7F6B7D6C5D7454477455456B5743\
634F435E4B3A634136634536634436674B366A554B6E594C74584E7152456B4C43
6650406651423D261E1F232A716F797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7876757676737865546F513F6659556B65637C69617C71697C766D7C71697C766D
816C6A8268617F6152734D44765B517C6D657C645F78585176695C796758745F516B443A6B4A41\
704A3C67483A674E3E6B4F3C6C513A6747366A4A3D7455486F54477053456B4F43
6B50476F584B2B1A18000703605A577C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
8176677C6D657963586F584E7D5C4676605C7C605D7C6D657C71697C71697C7169
7C7F6B8171627E6B576F51417153497C6D657C7F7081716D7C6D698270697963587A6555745447\
70504167443A67483C664C457452487E5F54745C4F6F574A6F544774584A705345
6B50406651423F22190B0A0A1713127C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7F7A7869586C503C6D584A7C605C7C6D607C6D607C6D657C76717C76707C7169
7C716D7C766B7E6B5E7463516D58467665597C6D607C71647C71687D7162745B4D6F54476B5447\
70594B70563F6C4A3866493E6F584F7860577960527563556F5F516B574A6B584A
6B544A6F5C4FB9784F6632211207051714137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C6D65\
74544A662F287046405C4C476572607C6D607C6D607C6D657C6C617C71697C7169
7C71687869607D71627D72677C6D607C6D5C786058765B517C605879584E7556456B4C4067483C\
664C385F43365E44386A51456E5C4C735C5079605275584B6F5447745447705443
6F4F406F5146795F559C6F5ACAB0A47C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7071\
7E545075493F6B463F78584A7669617C716D7C71687C6D657C71697C71697C6D65
7C6D607D6D5F7C695B7D65587669617C716D817F747C6D697C715F7E645871594A674B3E63473A\
5A423A6C4E416F5B4E745C4F746054736054796052755B4E6F574A6F4F47744C4A
6B4F456A514A6C503F66493B69483C8183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C71697C7A67\
7E6C5771563F6A4D3F705B517C6D607C6D657C766D7C6D657C6961786558766958
7C605C7D5C58736054785C517665597C695C7C6D607C6D657C68677E574F7553456C4E416C4E41\
6852456657466A55456E594C785C50745C4F74584B75584B6F52456F4F406B4F40
6B54436A5547795F5570544753392E6560617C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7467595E3E31\
43302442342C5A49407160557C6D607C69617C69617C6D607C69587D695C735C54
6F6051735C5478695F786D5F7669587C6D657C6D657C6D65787663796A597556486C4E41674B3E\
704C406B50476F554C74594F6F594C746054746355755B4E6F5F516B5B4C6B5345
6B4C476A514A6742306A463A70412F653C307C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7964553E2314\
36241E2C1F1D2A2A2D7160597C6D657C6D607C6D5C7C6D657C716D81716D817A70
826C6574584F6A4A426D554A73615576695D7C6D657C6D607D645B745B4F6C4A4567483D634738\
62493E6F54486A54446A51456E554C6F4D446A51456B54476651446B54476B5345
6B4F44664A3F6859405A3C2B664A3E653C357C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7671847C77955946\
462A1F3925202A2A2D7160517869587669617C6D646F5C4C604D3F553F32483328
4D3C33543E3B65464265463C694D447160557C6D657C6D697D6C627A5E5270543C674736684B3C\
5E483C5A463B564C405D4D426559496B5B4C6A5548745B4E70574A6B54476B5345
6B4F446B50475A382C401F174B30226037267C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E786D627963552A0F0A\
180F0D1E18151524287361557C695C7C69587C6D608875656C5648574638352E2A
1D1C1B1B1C142E251E43241B3B17124728217665597C6D657D71627A615270524163523C5F4634\
614D42795C4E7E5F5174574A6B4942634C436151456F584B70574A634F435A4F43
6254446B54476E48365A3325542E26602D217C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E80828287817A7959486B3E33\
2A1813291713151D237C6D60786D5F76695C7C6D6081766C8D71629874696C483A
301C16241813222221423D33745E4F6D584E766D607C7A757D7A717A655567493C5A3B303D140B\
311C1A563C2A4F382A3C2D2343392D634C405D4D3E6651426B54476C4F41634C40
624C4463483E54372C4B362B58443C693E368183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C75757C79797C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E27100B0A10157A6052734635\
2E1F221C141205141C7365587C6D6078695C73655876695D887E71746452A67660
B984689B6649814E34705B466F584873554A7664587C6C617D6D627A61527A533F684638764E3A\
4738353230330B06071517172A25211F19141C1E1E382C214B3627684C3E634F43
624F405E4638412D212D231D3D3C3469493C8183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7A797C79797C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E2D19142B1B1606030209080A1F1418\
1C141027191410191F78695C76696174524D65433D6B574D81767187837C8E7770
7F5E52846659846557795C4E7864547860547664587C71697D6C657A675B705A486C563C75583F\
835742955E482F1B181B16112F1F1D3124203229215A4036615143704F3E684C40
625443462B2531211A2F1F172A1E1A5A281C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E543129342119331F181F1816160D0C\
2517142D191415181E7C65587865558788787F6F6252382B432A21423026352C24
2C221E281E1831251C37231C4737306D60557665597C695C7D6C5A7A605270574A6C4438634F3A\
62503B755E4DCD8A6BA2735B7E4D387E4835714E4175563F634C3E665746755847
634F45482F202919142F1E182F231B541E137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E5C392921100B18130F1C130F251611\
1A14102824201924276B5C51816D607C6D608D7F789E938383665A664D4B755952
8C5E4C7F5A4A705141795E4F7861557C6D657C6D657C60607D655E7A645570534D4E2E253C1F19\
43322862503B6B5440795B4A8868537A63506657466353486B4F47634C45625040
5E4636281B15181410433E365B3929491E137C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7A797C79797C7E7E7C7E7E7C7E7E7C7E7E6848392F140E2414101C14100F0808\
1C120F281F1C202627574C447665597C6D607C7169817A75929689AE9E8D929689
9D9E959D9A91A3A3998D8B7E7D6D5F766D60786D5F73725C78695B7F685A847761987D68623E38\
29191816121021201E5343396B5445755843634F43674B3E5744366149416B4C45
462A202B18122B211D1F231E532D1F1D08041C19187C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E55453F2E221D2416122214101D120D\
1E1410281F1C2D2D2B5D4C437665597C6D607C6D657C71697C76717C7B797C7B79
7C76707C76717C76707C767181766B7C69588171647D695B7860547D65587D695B887065A78978\
AB796B80544831241D16120F191717272221322921382B215C433C6B4F43674B3E
3D221B241511211616120C0A21130E3E2621221E1C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E684D45442F2A2419141F1410241511\
2519192A211F272B28473E376B5B517C6D5C7C695D7C6D657C6C617C71687C7671
7C7B797C76717C76707C71697C76717C71687C6D607D6D5E78695B7860547860547864587F6457\
7A6B58926F5A99735D8C6651654936623D2D684A3C7A5C4D5E47405F4943574A3D
3F241C2415111B140F15110C1817142F2421221E1C7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E63443431201732201A24161225100C\
2917122D1D1627221E36322E62504776695C7C6D607C6D657C76717C71697C7168
7C76717C76717C76707C71697C6D607C6D657C69607D645778605478695B786054786051795C4F\
7A584B7A5B4E795B4C8463548D6C5A88685875594B754F47705645704B3E543427
381F182415112B19142116121C1410241913120A065A51527C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E553E2F3529252E201B2C1B1619120D\
1B130F1B120F241B1625201947382F7665597C6D607C6D657C71687C7B797C7169
7C71687C71697C71697C71697C71687C6D5C78695B78695B786054785C51786054786054796052\
6F5B4E6F584B7460526B574A6F54477054476353455A4F405A4F43534638332721
19120D21181717101117100C0F07071A12111E1A184437357C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E68473834241F3629242D201B301C17\
241511291D192C26242D2A282E2D2B6B544A7C695D7C69617C685D7C71687C7B79
7C76717C76707C71697C71697C716D78696078695B7860547860547860547460546F5C4F745C4F\
755B4E6F584B6F5548745B4E6B574A6B54476C53456B4F436C4B3E50362C341D17
301F1A150C0C1710101008081810101B13102123223832307C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E5C4D47382B27382B27382A252D1C17\
1A110C211612311F184730244230255D44397665557C6D607C69617C685D7C7168
7C76717C7B797C76707C71697C71688171687D6D5E7464576F5C4F73595079594F74584B74554C\
75584E6F584B6F54476B51446B5447674B3E704C4063473A4E38303E281F301C16
18100B191110140C0C19110C1810102518144F51527C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7A7978717155413A2F2420332824342722241712\
2D1E1A291E19251E1C322B24483C335A453D7160557C6D607C71697C71697C7168
7C76717C76717C76707C7169786D5F7665587D64577D60547D645774604F745C4F745B4E6F5C4C\
6F5B4E6B4F476650476B54476B5447705648634F435B483A5E3F2F3F281C2D1B15
2116121D15101F161119110C1C14102318140B05048183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C8382818887523E3537241B34241F3529253D2D28\
2D1F1A2D211D312119302F2A38332A47362E67504776695D7C69617C6D657C6C61
7C6C617C6C617C6D6578655878655873655878685A745C4B6F5949745C4B745C4C74605275584B\
6F584B745B4A7054476B4F436B4C40634F435B473A533D2F3925212C1A161C1410
18100C171010130B0C0B0708100A0B2C211F1C0F0E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6B4E4731231A3528223529252F231E\
2B1A152F1E173125212F2823332620322A265D473F7669587C6D5C7C695D7C695C
7C69587C69587C6D608171687D6D5E785C5174584B74554B74554C745952745C4F745447755548\
6F54476F54477054476B5345674B3E5F4438533A2D3925213121192416111E1410
2215111A1110150C0C160C0C2919146972728183827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E796A623D2E2A2F242037282438241A\
31241E271D192D221F271D1A292624292A253F2F266250437365587669587C6D60
7C6D6078695C73655576695C7D685A74584B745C4B6F57476A55456A55486E55486F574A6F5144\
6F4F476B50476B5443674F3E634B3E5F4638452D2436231921141018100C171010
1E14101A1110110808130B0B1F16130600007C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E6F605341322B382B272F2521312724\
271A1A271C19291E1A352925312119241C1727252344362E644A406D554A735D51
73615578695C786558735D517464576F5B4D6A4D446F54476F4C406F4D426A51446F54476B4F43\
664F4067483C5F453C57473A4B382C4B322638251A2114101C141019110C140C0B
110B0B0B07070B0808251814311D141709047C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EA49EAA593F3B382925342722392E29\
3D281C2D1A143326222D211D332927271E1A1E201E21221E2925214C3831614A3F
604A4465514D65554C69584D6B544757433649382E543C2E62493B664C4066443866463B6B4F3A\
674B3963473A5F40345A4034493128341E182C191424151119100C140C0C140C0C
1008080C0808140C0C19120F626D717674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E98A29A72625333251F2F24202D221F\
29231F251B1A281C16342520372C283F302B2D22202F28262C2A262B231C322A27
2928242D281F3E302842362C40332C4332283C2C21382F23422F234D36285944325A3E304B342C\
4A312652372C4B38303F2A243921192D191422141018100C140C0C1008080B0707
0B08080C08081A1410271914110E0E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8E8691483632352925342B27\
362824201712221D1A372C28392E2940342F46383345392F3F382F35322B312621
311F19291E1C2A1C193324203426222C242436262136231A30231C352923382D243C2C21433226\
3C2C20362A233C261F37241C291A15271D191A120D18100C150C0C1108080C0808
0C0808211410191010474240493C3A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EA3A3A3634842342521312420\
3125213D2B26382B27372C283D322D35292531262231211F3C231D3C221A31241F
251D1A28221F211814211C1B2D242029201C1F17141D18171D16131A12101F1814241C16221B15\
2316132012101F15122116131C1410150F0B140C0C130B0C140C0C0C08080C0808
2114192114123627214955577C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E878D879D9898483631312521\
3529253427223B302C2F231E2F26232F231E3026223F342B352D282F2724312521
31241F3728242C1D1C231D1A2518142717132114101A130F1C14102318142517141E13101B120F\
1C14102318142114101E141019100C18100C150C0C140C0C0C08080C0808140C0C
231A162C1B16706F6F7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E989397613E383A2925\
352925342722231D19372E293D322D3A302B2B211D2C1F192B1C17291E1A2B201B
21191D1E1C1A261B192717142114191A14111B141018100C1A141018141018141017100C120B0B\
150F0B1B130F18100C120B0B17100C181010150C0C0C0808140C0C1F15112C1F1A
2919147C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E8D979180736C3D2D28\
3328243427223A2B272F28242E26222F211D291D19211A18211410271D19251919
2619181F13101F1417161011120B0B160F10171010140C0C160F10130B0C160F10140C0C181010\
1C1411171010140C0C0C08080A07070A07070A070718101019110C130B0B190E0A
6D6D6C7674747C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EBFCACB87736C\
3728222F24202F2824312925372E29382A2A2D1B17291C181F16121B120E1B140F
1E140F140C0C110B0A171010191111140C0C171010150C0C171010150C0C2717140E0908150F0F\
1B14101911100C08080C08081008081910101C12121810102919153D251A624433
49372A7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EBFCACB\
8A6E673F322C2D211D372A26392E293E312B3028222D231E27171B1810121F1410
1810101D15111F1611191110140C0C140C0C130B0B140C0C130B0B1C1410151010332D36373336\
27191E160C0D1A11112016122017121911102D211D32211B291A153F2A246B6F74
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
C6D6D78A6C644C39332D211D2A252138302C46353038251B302019211712171010
140C0C160F0B171010140C0C140C0C181010150C0C181010150C0C120B0B2B2828291D223B2C2C\
5140364833314937313B29232117122B1E19271B183529254B30267675757C7979
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
767979BFCFD079594A4E3A333C2D28382E2A40342F463A3632231D2E1F1A3A2A24
3629222718131F15101A1211191111140C0C140C0C1B14171A12121D1511140D0C211D17261F1C\
150E0E14100D130F0C140E0E1F1410251A173121194B32247E76756B6A6F7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7EC5D9DF7665573527202C231F4036324D433F51423C32231D211717
2717143627223227211D1312140C0C21191D251C212B231E271D20382B2925191D352C2C382A29\
3F2D283D2B263727213D2B25493A303D2D26533D31827F7E8D928C7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7EC5CFD5C8BEC6624F4A3026222F24213B383C564B49604D45
5C534C3D2E2E312B2D4B434D66585546332F352A3134272B493D433A2F2E3F2D253228253E2D27\
3E27223E251D3D2B2545342B573A2D4E2D205A656A7C83827C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E929C96D1D9DA7C6A71463836352E2E404247514B4D
49413F564D455E514D54463D493A3646373046362C382A28271C162D221F392E293529253F2921\
4D2F2550362D5C3F344B2D2443383B9EA2AA7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C75757C79797C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7EC5CFC7D1D9DACDC3C263586553484E
75677478666E624B4551413C4D413C624E4D664E4B6550486D564F604B3F54463F65514A53493F\
464238392D28504D55AEBBC6B4C5C17C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E878D87C5CABDAEBBB8
9DA69A9EA3ADA9AFBCA69EAC6A61744A4A584641434A3E3A433C384D413F463A36392E263F322A\
767574D6DEDF98A6A07C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E878D827C8382929C91BAC0B3BAC0B3BFCACBBFC3C5BFC5C7BFCACBC5CFD0CAD9DFCAD4DA\
7C83827C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E
7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E7C7E7E\
7C7E7E7C7E7E7C7E7E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH07anOP@0OGih101f
JE`407a]H0@0O6eU101lLFP307a]I@`0O75Y101lLFP407a]I0@0OFeO0`1hJE/407UTE@@0M5a?101e
Fdh?06mHB`@0KeM:101`E4D406]DA0@0JeA5101[E4@306E<?a00O7in101lOgh307aiNB<0O7in5P3o
ool001@0ooooF01lOWh407enN0@0MVUL101lKF0407a]I@@0O75X0`1lKFD<07aaJ@@0O75X101lKF@4
07e]G`<0N6UK101iI5D407ALC`@0ME]>3`1_F4/406mGBP@0L5A5101[E4@406]DA@@0JeA40`1UC3l@
07anOP@0O7mn0`1lNGTS07anOQH0oooo000D0?oooeP0O7in101mOWP407IYG0@0O6eP101lKFD407aa
J0<0O6eU301lLFT407aaJ0@0O6eT101mKEl307QYF`@0NFAE101dG4l407EKCPl0KeQ;101_EdX4071D
A@@0JeA4101[E4D406]DA0<0ID`o401lOWh407aoOP<0O7Ui8`1lOWhF0?ooo`00503ooomH07anOP@0
OGih101fJE`407a]H0@0O6eU101lLFP307a]I@`0O75Y101lLFP407a]I0@0OFeO0`1hJE/407UTE@@0
M5a?101eFdh?06mHB`@0KeM:101`E4D406]DA0@0JeA5101[E4@306E<?a00O7in101lOgh307aiNB<0
O7in5P3oool001@0oooo101lOWh407ajN@@0O7Ui0`1lOWh407ajN@@0O7Ui8`1lOWh407ajN@<0O7Ui
5`1lOWh40863OP@0O6eU201lKF0407aaJ0<0O6eU101lLFT407a]H0@0N6EE101cIED407=QE0@0M5aA
0`1ZF4`406YHB`@0JUE8101[E4L406YEB0L0KeQ;201_E4L4071DBP@0JeA7101[E4D406]UG0<0IF1K
401lOWh407b3PRH0O7in5P3oool001@0oooo101lOWh407ajN@@0O7Ui0`1lOWh407ajN@@0O7Ui8`1l
OWh407ajN@<0O7Ui5`1lOWh40863OP@0O6eU201lKF0407aaJ0<0O6eU101lLFT407a]H0@0N6EE101c
IED407=QE0@0M5aA0`1ZF4`406YHB`@0JUE8101[E4L406YEB0L0KeQ;201_E4L4071DBP@0JeA7101[
E4D406]UG0<0IF1K401lOWh407b3PRH0O7in5P3oool001@0oooo101lOWh407ajN@@0O7Ui0`1lOWh4
07ajN@@0O7Ui8`1lOWh407ajN@<0O7Ui5`1lOWh40863OP@0O6eU201lKF0407aaJ0<0O6eU101lLFT4
07a]H0@0N6EE101cIED407=QE0@0M5aA0`1ZF4`406YHB`@0JUE8101[E4L406YEB0L0KeQ;201_E4L4
071DBP@0JeA7101[E4D406]UG0<0IF1K401lOWh407b3PRH0O7in5P3oool001@0oooo101lOWh407aj
N@@0O7Ui0`1lOWh407ajN@@0O7Ui8`1lOWh407ajN@<0O7Ui5`1lOWh40863OP@0O6eU201lKF0407aa
J0<0O6eU101lLFT407a]H0@0N6EE101cIED407=QE0@0M5aA0`1ZF4`406YHB`@0JUE8101[E4L406YE
B0L0KeQ;201_E4L4071DBP@0JeA7101[E4D406]UG0<0IF1K401lOWh407b3PRH0O7in5P3oool001@0
oooo101lOWh407b3PP@0O7Yi0`1lNGT407b3PPP0O7in101lNWT407aiN@<0O7Yi101lNGT@07anOP@0
O8>26P1lOWh407QjM@@0MVUH101lKFD407aYH@@0O75Y0`1lKFD407aYH@@0N6UP101[IE`406ALE0@0
KeA<101_DDP306mIC0P0Kf1B101dGe4406]DA`L0IU54101VE4L406ID@`@0JeA4101[E4L406]DBP@0
O6YQ5`1lOWh307ajN@@0O7Ui7`1lOWhF0?ooo`00503oool407anOP@0O8>2101lNWT307aiN@@0O8>2
201lOWh407ajN@@0O7Ui0`1lNWT407aiNA00O7in101lPh8J07anOP@0N7Ye101fJEP407a]I@@0O6UQ
101lLFT307a]I@@0O6UQ101hJF0406]UG0@0I5aD101_E4`406mAB0<0KeU<201_H58407AOD@@0JeA7
1`1VDD@406IDA`@0IUA3101[E4@406]DA`@0JeA:101lJV4G07anOP<0O7Yi101lNGTO07anOQH0oooo
000D0?ooo`@0O7in101lPh8407ajN@<0O7Ui101lPh8807anOP@0O7Yi101lNGT307ajN@@0O7Ui401l
OWh407b3PQX0O7in101hNWD407IYF0@0O6eU101lJF4407aaJ@<0O6eU101lJF4407QYH0@0JfEL101T
G5@406mDC0@0Ke580`1_FD`806mPDP@0M5mA101[E4L706IAA0@0IUA7101VE4<406]DA0@0JeA7101[
E4X407aZHAL0O7in0`1lNWT407aiNAl0O7in5P3oool001@0oooo101lOWh407b3PP@0O7Yi0`1lNGT4
07b3PPP0O7in101lNWT407aiN@<0O7Yi101lNGT@07anOP@0O8>26P1lOWh407QjM@@0MVUH101lKFD4
07aYH@@0O75Y0`1lKFD407aYH@@0N6UP101[IE`406ALE0@0KeA<101_DDP306mIC0P0Kf1B101dGe44
06]DA`L0IU54101VE4L406ID@`@0JeA4101[E4L406]DBP@0O6YQ5`1lOWh307ajN@@0O7Ui7`1lOWhF
0?ooo`00503oool807anOP@0O7mn0`1lNGT<07anOP@0O8>2101lOWh307b3PS80O7in1021OWP407aY
H@P0O6eU101lJF4307a]I@@0O6eP1021LFP4099fK@@0PWIZ1021L6L408ASF`<0NUQ;101jED`407YE
C`@0MDm:101`D4L;06]DA`@0JeA:101_F4/4071GBP@0JeA7101UC3lG07anOP<0O8>28`1lOWhF0?oo
o`00503oool807anOP@0O7mn0`1lNGT<07anOP@0O8>2101lOWh307b3PS80O7in1021OWP407aYH@P0
O6eU101lJF4307a]I@@0O6eP1021LFP4099fK@@0PWIZ1021L6L408ASF`<0NUQ;101jED`407YEC`@0
MDm:101`D4L;06]DA`@0JeA:101_F4/4071GBP@0JeA7101UC3lG07anOP<0O8>28`1lOWhF0?ooo`00
503oool807anOP@0O7mn0`1lNGT<07anOP@0O8>2101lOWh307b3PS80O7in1021OWP407aYH@P0O6eU
101lJF4307a]I@@0O6eP1021LFP4099fK@@0PWIZ1021L6L408ASF`<0NUQ;101jED`407YEC`@0MDm:
101`D4L;06]DA`@0JeA:101_F4/4071GBP@0JeA7101UC3lG07anOP<0O8>28`1lOWhF0?ooo`00503o
ool807anOP@0O8>2C01lOWh407b3OPP0O6eL101lKF0707a]I@@0O6eY101lLFT407afK@@0PGI`101h
MV<407e/HP<0OFQN101mJ5L407UODP@0OVQJ101oFDl407A<A`<0M5QD101`Fdl406mDA`@0Ke54101`
E4L406mLC`@0JeE8?@1lOWhF0?ooo`00503oool807anOP@0O8>2C01lOWh407b3OPP0O6eL101lKF07
07a]I@@0O6eY101lLFT407afK@@0PGI`101hMV<407e/HP<0OFQN101mJ5L407UODP@0OVQJ101oFDl4
07A<A`<0M5QD101`Fdl406mDA`@0Ke54101`E4L406mLC`@0JeE8?@1lOWhF0?ooo`00503oool807an
OP@0O8>2C01lOWh407b3OPP0O6eL101lKF0707a]I@@0O6eY101lLFT407afK@@0PGI`101hMV<407e/
HP<0OFQN101mJ5L407UODP@0OVQJ101oFDl407A<A`<0M5QD101`Fdl406mDA`@0Ke54101`E4L406mL
C`@0JeE8?@1lOWhF0?ooo`00503oool807anOP@0O8>2C01lOWh407b3OPP0O6eL101lKF0707a]I@@0
O6eY101lLFT407afK@@0PGI`101hMV<407e/HP<0OFQN101mJ5L407UODP@0OVQJ101oFDl407A<A`<0
M5QD101`Fdl406mDA`@0Ke54101`E4L406mLC`@0JeE8?@1lOWhF0?ooo`00503ooomH07anOP@0O7mj
101lKF0407a]I@P0O6eP0`1lKFD407aaJ@@0O6eU101lJF4407aaJ@@0PGI`1021NV/307eaHP@0N6AK
101mJ5X407ALC`@0NV=E101eGe4306mA@@@0M5aD101[Fdl406IDA`@0JeA7101cIF4407IZIAX0O7in
101lNWT407aiNA/0O7in5P3oool001@0ooooF01lOWh407aoNP@0O6eP101lKFD807a]H0<0O6eU101l
LFT407a]I@@0O6UQ101lLFT4085fL0@0PGY[0`1mLF8407QTF`@0OFQJ101dG4l407YSE@@0MEmA0`1_
DD4407ALE0@0Je]?101VE4L406]DA`@0LfEQ101fJVDJ07anOP@0O7Yi101lNGTK07anOQH0oooo000D
0?oooeP0O7in101lOgX407a]H0@0O6eU201lKF0307a]I@@0O75Y101lKFD407aYH@@0O75Y1021MW04
085jJ`<0OG5R101hI5/407eXFP@0M5a?101jHeD407EOD@<0Ke51101dG5@406]KC`@0IUA7101[E4L4
07=UH@@0MVYU6P1lOWh407ajN@@0O7Ui6`1lOWhF0?ooo`00503ooomH07anOP@0O7mj101lKF0407a]
I@P0O6eP0`1lKFD407aaJ@@0O6eU101lJF4407aaJ@@0PGI`1021NV/307eaHP@0N6AK101mJ5X407AL
C`@0NV=E101eGe4306mA@@@0M5aD101[Fdl406IDA`@0JeA7101cIF4407IZIAX0O7in101lNWT407ai
NA/0O7in5P3oool001@0ooooE@1lOWh306mLE0@0Je]E101lKFD<07a]H0<0O75Y101lKFD407aaJ@@0
O7I]101lLFT407aaJ0@0O6eY0`21LFL4085]F`P0OFAG101iGe8407YHCP<0MEM:101[CCl406]DA`@0
KeA7101`E4L406MJD@@0MWAd6P1lOWh407b3PP`0O7in101lNWT307aeM@@0O7Ui201lOWhF0?ooo`00
503ooomE07anOP<0KeaD101[FeD407a]I@`0O6eP0`1lLFT407a]I@@0O75Y101lMVd407aaJ@@0O75X
101lKFT3085aI`@0PFeK201mI5L407UODP@0NUQ>0`1eEdX406]=?`@0JeA7101_E4L4071DA`@0IeYA
101fM7@J07anOP@0O8>2301lOWh407ajN@<0O7Ee101lNGT807anOQH0oooo000D0?oooeD0O7in0`1_
G5@406]KE@@0O6eU301lKF0307aaJ@@0O6eU101lLFT407afK@@0O75Y101lLFP407a]J@<0PG5W1021
KE/807eTE`@0NEmB101jF4h307EGBP@0Jddo101[E4L406mDA`@0L5A7101WFU4407IdM1X0O7in101l
Ph8<07anOP@0O7Yi0`1lMGD407aiN@P0O7in5P3oool001@0ooooE@1lOWh306mLE0@0Je]E101lKFD<
07a]H0<0O75Y101lKFD407aaJ@@0O7I]101lLFT407aaJ0@0O6eY0`21LFL4085]F`P0OFAG101iGe84
07YHCP<0MEM:101[CCl406]DA`@0KeA7101`E4L406MJD@@0MWAd6P1lOWh407b3PP`0O7in101lNWT3
07aeM@@0O7Ui201lOWhF0?ooo`00503ooomA07anOP@0ASXb0`12Acl407IYG0@0O6eP201lKFT707a]
I@@0O75X101lJE`407a]H0P0O6eU101lKF0307aaI0@0N6QN101hH5L407QLE0@0NF1>101_EdL306mH
B`@0M5M:101`E4L406YLC`@0M5mA101`FTd^07anOPL0O8>2301lOWhF0?ooo`00503ooomA07anOP@0
ASXb0`12Acl407IYG0@0O6eP201lKFT707a]I@@0O75X101lJE`407a]H0P0O6eU101lKF0307aaI0@0
N6QN101hH5L407QLE0@0NF1>101_EdL306mHB`@0M5M:101`E4L406YLC`@0M5mA101`FTd^07anOPL0
O8>2301lOWhF0?ooo`00503ooomA07anOP@0ASXb0`12Acl407IYG0@0O6eP201lKFT707a]I@@0O75X
101lJE`407a]H0P0O6eU101lKF0307aaI0@0N6QN101hH5L407QLE0@0NF1>101_EdL306mHB`@0M5M:
101`E4L406YLC`@0M5mA101`FTd^07anOPL0O8>2301lOWhF0?ooo`00503ooomA07anOP@0ASXb0`12
Acl407IYG0@0O6eP201lKFT707a]I@@0O75X101lJE`407a]H0P0O6eU101lKF0307aaI0@0N6QN101h
H5L407QLE0@0NF1>101_EdL306mHB`@0M5M:101`E4L406YLC`@0M5mA101`FTd^07anOPL0O8>2301l
OWhF0?ooo`00503oool807anOP@0O7Yi0`1lNGTn07anOP@0JfEY100o8al301HJ8P@0O6eT101lLF@4
07aaJ0@0O75Y101lLFP307aYH@@0O75Y101lMW4407a]I@@0O6eP101lH5P407QED@<0Ke56101cG4d4
07QPE0@0M6AD101_Fe4407AKCP<0MEQ;101[EdD406]DA0@0ITe2101VDD@406E<?d40O7in5P3oool0
01@0oooo201lOWh407ajN@<0O7Ui?P1lOWh406]UJ@@0?b<O0`0F6R8407a]I0@0O75T101lLFP407aa
J@@0O75X0`1lJF4407aaJ@@0O7Ia101lKFD407a]H0@0O61H101hEE4306mAAP@0Lea=101hH5@407AT
E0@0Ke]A101dFdh307EHB`@0JeM5101[E4@406I=@P@0IU54101UC3m107anOQH0oooo000D0?ooo`P0
O7in101lNWT307aiNCh0O7in101[IFT403lS7`<05QXR101lKF@407aaI0@0O75X101lLFT407aaJ0<0
O6UQ101lLFT407afL@@0O6eU101lKF0407aPF0@0N5EA0`1_DDH407=LC@@0N61D101dI5@406mKD@@0
M5]>0`1eF4/406]GA@@0JeA4101VCD8406IAA0@0ID`o@@1lOWhF0?ooo`00503oool807anOP@0O7Yi
0`1lNGTn07anOP@0JfEY100o8al301HJ8P@0O6eT101lLF@407aaJ0@0O75Y101lLFP307aYH@@0O75Y
101lMW4407a]I@@0O6eP101lH5P407QED@<0Ke56101cG4d407QPE0@0M6AD101_Fe4407AKCP<0MEQ;
101[EdD406]DA0@0ITe2101VDD@406E<?d40O7in5P3oool001@0oooo201lOWh407b3PP<0O7Yi101l
NGTf07anOP@0P8:2100m:ah407ibG`<0MVUH101lKFD407aYH@@0O6eU101lJF4707a]I@@0O6UQ101l
KFD407aaJ0@0N6UP101cJ5P407QPE`<0NF1B201_FD`407AIB0@0ME];101ZE4L306mAA0@0M5A:101d
E4L4071DA`@0KeQ;101WASP407IZICd0O7in5P3oool001@0oooo201lOWh407b3PP<0O7Yi101lNGTf
07anOP@0P8:2100m:ah407ibG`<0MVUH101lKFD407aYH@@0O6eU101lJF4707a]I@@0O6UQ101lKFD4
07aaJ0@0N6UP101cJ5P407QPE`<0NF1B201_FD`407AIB0@0ME];101ZE4L306mAA0@0M5A:101dE4L4
071DA`@0KeQ;101WASP407IZICd0O7in5P3oool001@0oooo201lOWh407b3PP<0O7Yi101lNGTf07an
OP@0P8:2100m:ah407ibG`<0MVUH101lKFD407aYH@@0O6eU101lJF4707a]I@@0O6UQ101lKFD407aa
J0@0N6UP101cJ5P407QPE`<0NF1B201_FD`407AIB0@0ME];101ZE4L306mAA0@0M5A:101dE4L4071D
A`@0KeQ;101WASP407IZICd0O7in5P3oool001@0oooo201lOWh407ajNCd0O7in100_81P407aaJ@@0
PGI`0`1lKF@407a]H0P0O6eU201lKF0307a]I@@0O75Y201lKFD407e>C@@0N3`l101d=SL707@c=@@0
M4<o101_DDL406mAA0@0Kdm30`1[D40406YDA0@0KeA7101`E4<406Y<?P@0HC`^101UC3lZ07anOP@0
O7Yi0`1lNGT<07anOQH0oooo000D0?ooo`P0O7in101lNWTm07anOP@0;b0H101lLFT4085fL0<0O6eT
101lKF0807a]I@P0O6eP0`1lKFD407aaJ@P0O6eU101mCTd407Pl?0@0M3Hg1`1d<cD407A3?`@0Ke57
101_DD@406m?@`<0Je10101ZE4@406mDA`@0L5A3101ZC3h4064l;P@0ID`o:P1lOWh407ajN@<0O7Ui
301lOWhF0?ooo`00503oool807anOP@0O7Yi?@1lOWh402lP60@0O75Y1021MW0307a]I0@0O6eP201l
KFD807a]H0<0O6eU101lLFT807a]I@@0ODi=101h?3`407@f=`L0M3<e101d@cl406mAA`@0Ke54101_
Cd<306]@@0@0JUA4101_E4L4071D@`@0JT`n101Q?2h406E<?bX0O7in101lNWT307aiN@`0O7in5P3o
ool001@0oooo201lOWh407ajNCd0O7in100_81P407aaJ@@0PGI`0`1lKF@407a]H0P0O6eU201lKF03
07a]I@@0O75Y201lKFD407e>C@@0N3`l101d=SL707@c=@@0M4<o101_DDL406mAA0@0Kdm30`1[D404
06YDA0@0KeA7101`E4<406Y<?P@0HC`^101UC3lZ07anOP@0O7Yi0`1lNGT<07anOQH0oooo000D0?oo
o`P0O7in101lPh8i07anOP@0JfEU1034/k8407IYI@@0O6eU0`1lKF@407a]H0@0O6eU101lJE`407aU
F0@0O6EE0`1lJEd407aYH@@0O61L101lEED407eJE@@0M4<j101_=R`306hk=@@0Kchf101^<c84074l
>@@0ITHn101VE4<306]?@`@0JU14101_E4L407ADBP@0Ke=5101dE4P4060h:0<0Je539`1lOWh407b3
PPl0O7in5P3oool001@0oooo201lOWh407b3PST0O7in101[IFD40<Bc/P@0MVUU101lKFD307a]I0@0
O6eP101lKFD407aYG0@0O6EH101lIED307aYG@@0O6UQ101lH5`407aEE@@0OEYE101d@cX406lf;0<0
KS/e101_?SH406hc<P@0LC`i101VASh406ID@`<0Jdm3101ZD4@406mDA`@0M5A:101_DdD407ADB0@0
H3PX0`1[DD<W07anOP@0O8>23`1lOWhF0?ooo`00503oool807anOP@0O8>2>@1lOWh406]UI@@0a;>b
101fJFD407a]I@<0O6eT101lKF0407a]I@@0O6UL101lIEP407aUE@<0O6UM101lJF4407aPG0@0O5EE
101mFUD407A3>P@0KcH/0`1^>cD406ln=P@0KS<b101a?3T406I6?P@0IUA30`1[Cd<406Y@A0@0KeA7
101dE4X406mCA@@0M5A8101P>2P306]A@bL0O7in101lPh8?07anOQH0oooo000D0?ooo`P0O7in101l
Ph8i07anOP@0JfEU1034/k8407IYI@@0O6eU0`1lKF@407a]H0@0O6eU101lJE`407aUF0@0O6EE0`1l
JEd407aYH@@0O61L101lEED407eJE@@0M4<j101_=R`306hk=@@0Kchf101^<c84074l>@@0ITHn101V
E4<306]?@`@0JU14101_E4L407ADBP@0Ke=5101dE4P4060h:0<0Je539`1lOWh407b3PPl0O7in5P3o
ool001@0ooooA@1lOWh403DY8`@05AdL101fJEP407a]G0/0O6eP101hJE/407=LD@@0MVAI0`1lKF04
07aUF0@0N4m4101_=Rl406Y9?`@0GSd^101QG4`306i]F`@0LChc101Q:R4406lb;0@0L3`g101[BT@3
06]C?0@0IU0k101ZE4@406mDA`@0KeQ:101_DD@406mEB0<0Jd/l101lM6lf07anOQH0oooo000D0?oo
odD0O7in100e:B<401DM70@0MVUH101lKE`;07a]H0@0N6UK101cG54407ITF@<0O6eP101lIEP407Q?
A0@0KcH_101ZBCl405hm;P@0HEa<0`1^KE/4074n<`@0HBXQ101_<R`4070l=`@0JdY40`1[Dc`406I@
>`@0JUA4101_E4L406mHBP@0Ke54101_EDP306];?0@0O7A_=P1lOWhF0?ooo`00503ooom507anOP@0
=BTS100E7A`407IYF0@0O6eL2`1lKF0407QYF`@0LeaA101fI5T307a]H0@0O6EH101hCd@406lf;`@0
JTTo101N?Bh4065LC0<0KVeK101a?S<4064Z8@@0Kc8/101`?3L406]:A0<0Je<l101VD3/406YDA0@0
KeA7101_F4X406mAA0@0KeE80`1[Bc`407adKcH0O7in5P3oool001@0ooooA@1lOWh403DY8`@05AdL
101fJEP407a]G0/0O6eP101hJE/407=LD@@0MVAI0`1lKF0407aUF0@0N4m4101_=Rl406Y9?`@0GSd^
101QG4`306i]F`@0LChc101Q:R4406lb;0@0L3`g101[BT@306]C?0@0IU0k101ZE4@406mDA`@0KeQ:
101_DD@406mEB0<0Jd/l101lM6lf07anOQH0oooo000D0?ooo`l0O7in101lNWT407aiNBX0O7in101K
Cdl409EbHP@0H59:101lKFD407QUF`<0MVQQ101lLFP407aUF`@0NEa;101ZC3h406]5@`<0M3/i100l
3PT402lZ90@0M5Y@101nFE4409RPW@@0Q4i70`1W=Rd405YA>P@0EEM81018>2X404hX80@0Ic<]0`1V
C3`406m<?P@0KeA8101dH4h407EKBP@0KeQ;101_E4L3060l;P@0Jd/l101lM6lb07anOQH0oooo000D
0?ooo`l0O7in101lNWT407aiNBX0O7in101KCdl409EbHP@0H59:101lKFD407QUF`<0MVQQ101lLFP4
07aUF`@0NEa;101ZC3h406]5@`<0M3/i100l3PT402lZ90@0M5Y@101nFE4409RPW@@0Q4i70`1W=Rd4
05YA>P@0EEM81018>2X404hX80@0Ic<]0`1VC3`406m<?P@0KeA8101dH4h407EKBP@0KeQ;101_E4L3
060l;P@0Jd/l101lM6lb07anOQH0oooo000D0?ooo`l0O7in101lNWT407aiNBX0O7in101KCdl409Eb
HP@0H59:101lKFD407QUF`<0MVQQ101lLFP407aUF`@0NEa;101ZC3h406]5@`<0M3/i100l3PT402lZ
90@0M5Y@101nFE4409RPW@@0Q4i70`1W=Rd405YA>P@0EEM81018>2X404hX80@0Ic<]0`1VC3`406m<
?P@0KeA8101dH4h407EKBP@0KeQ;101_E4L3060l;P@0Jd/l101lM6lb07anOQH0oooo000D0?ooo`l0
O7in101lNWT407aiNBX0O7in101KCdl409EbHP@0H59:101lKFD407QUF`<0MVQQ101lLFP407aUF`@0
NEa;101ZC3h406]5@`<0M3/i100l3PT402lZ90@0M5Y@101nFE4409RPW@@0Q4i70`1W=Rd405YA>P@0
EEM81018>2X404hX80@0Ic<]0`1VC3`406m<?P@0KeA8101dH4h407EKBP@0KeQ;101_E4L3060l;P@0
Jd/l101lM6lb07anOQH0oooo000D0?ooo`P0O7in101lNWT307aiN@@0O8>2;P1lOWh404<f<0@0=Slo
101fJF4407a]H0@0OFQJ0`1fFe4407a]I@@0O6eR101iDT4406]4=P@0>@l;0`0e>3L40;C@b0@0QiND
1027Zjd4086GWP@0O7If1022X8h309:LU0@0WZ:U101jM74405Pn=@@0920D100a81T30690>0@0JU=3
101dEDT407ALDP@0NV=A101eEdL406mDA`<0KeE8101PCTd406MSK@@0MWAd;P1lOWhF0?ooo`00503o
ool807anOP@0O7Yi0`1lNGT407b3PRh0O7in1013=S0403Ho?`@0MVUQ101lKF0407eXFP<0MU]A101l
KFD407a]HP@0NE91101[A3H403T?2`<0=CPg102dd<P408NGU0@0Qj^]1021Uih407afMP@0PZ2>0`2B
W9@409jRY@@0NWAa101H?SD402@P50@0<B0I0`1R@3P406YC@`@0M5E9101dG58407YSD@@0MEM7101_
E4L306mEB0@0H4i=101WHfd407IdM2h0O7in5P3oool001@0oooo201lOWh407ajN@<0O7Ui101lPh8^
07anOP@0@cH`100f?cl407IYH@@0O6eP101mJ5X307IKD@@0O6eU101lKF8407UB@@@0Jd@f100i3`/3
03Dh=`@0]=381027Ui@408N[[@@0PINN101lMWH408:PSP<0TYbD102NXZD407YdL@@0F3he100T81@4
034P6@<0HT0h101ZDd<407AEB@@0M5aB101jHe4407EGA`@0KeA70`1_EDP4061>C@@0If=]101fM7@^
07anOQH0oooo000D0?ooo`P0O7in101lNWT307aiN@@0O8>2;P1lOWh404<f<0@0=Slo101fJF4407a]
H0@0OFQJ0`1fFe4407a]I@@0O6eR101iDT4406]4=P@0>@l;0`0e>3L40;C@b0@0QiND1027Zjd4086G
WP@0O7If1022X8h309:LU0@0WZ:U101jM74405Pn=@@0920D100a81T30690>0@0JU=3101dEDT407AL
DP@0NV=A101eEdL406mDA`<0KeE8101PCTd406MSK@@0MWAd;P1lOWhF0?ooo`00503oool807anOP@0
O8>2<P1lOWh306m]M@@0ABXU100@6Al407IYF0@0O6eP1021NV/307a]H0@0O6eU101dFdl406Q=>0@0
ERhO101D6@h303lB3`@0KCT`101cBCd407IDBP@0O6eL101lI54407UKDP<0KDi8101dF4/4099]G@@0
YXM`102BMVP403LY7`<0;A`I101M?3<406UA@`@0N6ED101iI5P407EOD@@0Ke950`1_CD8406]==@@0
FE56101FCU4406]ZM2X0O7in5P3oool001@0oooo201lOWh407b3PS80O7in0`1_KGD404DZ9@@041TO
101fJEP407a]H0@0PGY[0`1lKF0407a]I@@0M5]?101XCCP405H^7`@0E1T>0`0o4Pl406di<0@0LdTm
101fE4X407a]G0@0O6AA101iFe8306e>B0@0M5Q;102BKEd40:J7L0@0TWIX100g:Al302dL6@@0GC`c
101YDD<407QUE0@0NFAH101eGe4406mBA@<0Kde2101[CCD405UAAP@0ETiA101[JW@Z07anOQH0oooo
000D0?ooo`P0O7in101lPh8b07anOP<0Kfee1015:RD4010I7`@0MVUH101lKF04085jJ`<0O6eP101l
KFD407AKC`@0J4dh101F;Ql405@I3P<0?a8?101]>C0407=9?@@0MUA:101lKE`407aTD@@0NE]B0`1]
CTP407AHB`@0TVeM102VQg04099fJ0@0=bTO0`0]71T405dl<`@0JE53101hIE@407UTF0@0MEmA101_
DTD306m=@P@0Jdde101IDDH405I>D@@0JfYd:P1lOWhF0?ooo`00503oool807anOP@0O8>2<P1lOWh3
06m]M@@0ABXU100@6Al407IYF0@0O6eP1021NV/307a]H0@0O6eU101dFdl406Q=>0@0ERhO101D6@h3
03lB3`@0KCT`101cBCd407IDBP@0O6eL101lI54407UKDP<0KDi8101dF4/4099]G@@0YXM`102BMVP4
03LY7`<0;A`I101M?3<406UA@`@0N6ED101iI5P407EOD@@0Ke950`1_CD8406]==@@0FE56101FCU44
06]ZM2X0O7in5P3oool001@0oooo>P1lOWh404Hj<P<05Pd8101SBd<4061>BP@0O6eP101lIEP407aM
D@<0O6EE101lKE`407iXE`@0RFMN102DV8<40<G5Y`<0Qgmd101mG5X407AHC`@0JSlg101]?3`406Xf
=`@0JSTb0`1U7QP406HX90@0Fc0Z101`CCl407E2>`@0PUE;0`0a4PT4034L70@0JDY2101cG4d407UT
D@@0MEM7101[F4X306YHB`@0M5531027MF/407YaL@@0IF1Z:P1lOWhF0?ooo`00503ooolj07anOP@0
ASXb0`0F3@P406=;@`@0H4i:101lKF0407aUF0@0O5eA0`1lIED407a]G0@0OVQG1029Ieh409BHP`@0
aLFW0`27Og@407eLFP@0M5Q?101Z?cL406dl?0@0JSHg101Z>C8306DN60@0IRPT101K<2X4071=?`@0
MD8k1022ED/3034B2@@0<A`L101YBT8407=LC@@0NFAA101eEdL406]HBP<0JUQ;101dDD<408MeJ`@0
NW5a101UH6XZ07anOQH0oooo000D0?ooocX0O7in1016>S8301H=20@0Hd]3101PCTX407a]H0@0O6EH
101lGE4307aUE@@0O6eL101nJ5L408UWGP@0U9R31035aJL308MoM0@0OEaJ101dF4l406Xo=`@0KC`l
101Z=SL406Xi<P<0IAhH101V:2@405/`:P@0L4do101e@S/4089EB`<0<A89100a71`406U:@P@0Lea=
101iI54407EGA`@0JeQ:0`1ZF4/407AA@`@0QgE[101jLG4406EPJRX0O7in5P3oool001@0oooo4`1l
OWh407ajN@@0O7Ui6`1lOWh406mYK@@08aPB0`0K4`l4028d=P@0O6eT101lJE`407aTG`@0N6AO0`1f
JE`407aPG0@0OV9I101WA3@406E:@P@0O75]0`1lOg04085oM0@0QhQm1027Qg`4086@NP@0R7]W1023
Of/307n1I@@0OgAL101eC40407U8@`@0NSP`101d;20306hU6@@0>1@?10179BH406eAA`@0NF1A101e
FdX4071?@`<0JTe2101_DDD4034I40@0>30P101hLG4407IdM2H0O7in5P3oool001@0oooo4`1lOWh4
07ajN@@0O7Ui6`1lOWh406mYK@@08aPB0`0K4`l4028d=P@0O6eT101lJE`407aTG`@0N6AO0`1fJE`4
07aPG0@0OV9I101WA3@406E:@P@0O75]0`1lOg04085oM0@0QhQm1027Qg`4086@NP@0R7]W1023Of/3
07n1I@@0OgAL101eC40407U8@`@0NSP`101d;20306hU6@@0>1@?10179BH406eAA`@0NF1A101eFdX4
071?@`<0JTe2101_DDD4034I40@0>30P101hLG4407IdM2H0O7in5P3oool001@0oooo4`1lOWh407aj
N@@0O7Ui6`1lOWh406mYK@@08aPB0`0K4`l4028d=P@0O6eT101lJE`407aTG`@0N6AO0`1fJE`407aP
G0@0OV9I101WA3@406E:@P@0O75]0`1lOg04085oM0@0QhQm1027Qg`4086@NP@0R7]W1023Of/307n1
I@@0OgAL101eC40407U8@`@0NSP`101d;20306hU6@@0>1@?10179BH406eAA`@0NF1A101eFdX4071?
@`<0JTe2101_DDD4034I40@0>30P101hLG4407IdM2H0O7in5P3oool001@0oooo4`1lOWh407ajN@@0
O7Ui6`1lOWh406mYK@@08aPB0`0K4`l4028d=P@0O6eT101lJE`407aTG`@0N6AO0`1fJE`407aPG0@0
OV9I101WA3@406E:@P@0O75]0`1lOg04085oM0@0QhQm1027Qg`4086@NP@0R7]W1023Of/307n1I@@0
OgAL101eC40407U8@`@0NSP`101d;20306hU6@@0>1@?10179BH406eAA`@0NF1A101eFdX4071?@`<0
JTe2101_DDD4034I40@0>30P101hLG4407IdM2H0O7in5P3oool001@0oooo4`1lOWh407b3PQl0O7in
101oPhP40?;=_@<0kk6A101cG4h407IYG0@0O6eO101lMV04085TG`<0O61L101lNV@407i_GP@0OemB
101WB3d407IPE@<0O75Y101lLFP407aYH@@0O75Y101lI6<407ePFP@0N61D0`1iH5D407AKCP@0LE]8
101QG4H406]UC@@0NVaH0`2>MV0408=VG@@0HTHh101TCCd407ALCP@0ME]:101`F4D306YDA0@0KeE8
101RBd44028P7@@0JfYU:P1lOWhF0?ooo`00503ooolC07anOP@0O8>27`1lOWh407n3R0@0l/fm0`3_
/I4407=LCP@0MVUL101lKEl407afH0@0PFAO0`1lH5`407ajI0@0OVmN101oGe8406M8?@@0MV1E0`1l
LFT407aaJ0@0O6UQ101lLFT407aTH`@0OF1J101hH5@307UPE@@0M5]>101aFdP4065LAP@0JfE=101j
K5P308ifH0@0PfIM101RASP406A=?@@0M5a>101eFdX4071HA@<0JUA4101_EDP4069;@@@08R0M101[
JVDZ07anOQH0oooo000D0?oooa<0O7in101lPh8O07anOP@0Oh>8103bcKd30>naT@@0Lea>101fJE`4
07a]G`@0O7IP1021I5l307aPG0@0O7YT101nKeh407mODP@0IdPm101fH5D307aaJ@@0O75X101lJF44
07aaJ@@0O6AS101mH5X407QPE0<0NF1E101dFdh4075KB0@0HEa6101[IDd407Y/F0<0SWIP1023IUd4
0696>0@0I4dm101dG4h407EKBP@0L5Q50`1ZE4@406mEB0@0HT]1100R81d406]ZIBX0O7in5P3oool0
01@0oooo4`1lOWh407b3PQl0O7in101oPhP40?;=_@<0kk6A101cG4h407IYG0@0O6eO101lMV04085T
G`<0O61L101lNV@407i_GP@0OemB101WB3d407IPE@<0O75Y101lLFP407aYH@@0O75Y101lI6<407eP
FP@0N61D0`1iH5D407AKCP@0LE]8101QG4H406]UC@@0NVaH0`2>MV0408=VG@@0HTHh101TCCd407AL
CP@0ME]:101`F4D306YDA0@0KeE8101RBd44028P7@@0JfYU:P1lOWhF0?ooo`00503ooolf07anOP@0
SGmW101lKFD3085oN@@0OG5W101cIEP407I]H0@0O6eU101lNVd707aaK@@0PWEY101oJUT406Y6>`@0
Id/o0`1fJ5`407afK@@0O75X101lKFD407aoJ`@0OFaM101dE4L307AEA@@0JeM3101SCd<405i;>P@0
Hd4f101SACH306=4=P@0Id/f101ZED/406iIC0@0M5Q>101aDTD406]<@`<0IU10101VDD8403dV7P@0
7b<Z101aKgTZ07anOQH0oooo000D0?ooocH0O7in102=OfL407a]I@<0PGmi101mLFL407=UF0@0MVeP
101lKFD407ajK@L0O75]1022MFT407mZF@@0JTHk101WBcl307IXG0@0O7I]101lLFP407a]I@@0O7m[
101mK5d407ADA`<0M5E5101[Ed<406=?@`@0GT/j101S@CH406=5=P<0Hd@f101WBcH406YEB`@0KUU<
101dF4h4075BA@@0Jda30`1VD40406IA@P@0?BHN100O8bX4075_NBX0O7in5P3oool001@0oooo=P1l
OWh408eoI`@0O6eU0`21OgT407eaI`@0LfEH101fKF0407a]I@@0O7Y]1`1lLFd4089eJ@@0OfYI101Z
AS/406M;?`<0MVQL101lMVd407aaJ0@0O6eU101lOf/407e/G@@0M5A70`1dEDD406]G@`@0Hdm3101N
BcX406=1=P@0HdDf0`1SA3H406M;=P@0JUE;101^FD`407AHCP@0LE95101[C4<306I@@0@0IU52100m
9Qh401lS:P@0LFmi:P1lOWhF0?ooo`00503ooolf07anOP@0SGmW101lKFD3085oN@@0OG5W101cIEP4
07I]H0@0O6eU101lNVd707aaK@@0PWEY101oJUT406Y6>`@0Id/o0`1fJ5`407afK@@0O75X101lKFD4
07aoJ`@0OFaM101dE4L307AEA@@0JeM3101SCd<405i;>P@0Hd4f101SACH306=4=P@0Id/f101ZED/4
06iIC0@0M5Q>101aDTD406]<@`<0IU10101VDD8403dV7P@07b<Z101aKgTZ07anOQH0oooo000D0?oo
oc80O7in101hMWD407IfL`@0N6ED0`1_DCl406IIE@@0JfES101lJF4407aaJ@@0O7I]0`1lLFT407af
K@@0PFaZ1022J64407mQDP@0Lde40`1fFe4407a]I@@0O6AO101hF54407IYG0@0NFMH101dGe4306]4
>P@0JdY1101`BS`406M8>P@0Idhn101[Cc`306aA>P@0IdLf101ZBSd407AEB0@0KeA7101`DdD406]?
@`<0Je17101_F4/402/J60@000L3101PFULZ07anOQH0oooo000D0?oooc80O7in101hMWD407IfL`@0
N6ED0`1_DCl406IIE@@0JfES101lJF4407aaJ@@0O7I]0`1lLFT407afK@@0PFaZ1022J64407mQDP@0
Lde40`1fFe4407a]I@@0O6AO101hF54407IYG0@0NFMH101dGe4306]4>P@0JdY1101`BS`406M8>P@0
Idhn101[Cc`306aA>P@0IdLf101ZBSd407AEB0@0KeA7101`DdD406]?@`<0Je17101_F4/402/J60@0
00L3101PFULZ07anOQH0oooo000D0?oooc80O7in101hMWD407IfL`@0N6ED0`1_DCl406IIE@@0JfES
101lJF4407aaJ@@0O7I]0`1lLFT407afK@@0PFaZ1022J64407mQDP@0Lde40`1fFe4407a]I@@0O6AO
101hF54407IYG0@0NFMH101dGe4306]4>P@0JdY1101`BS`406M8>P@0Idhn101[Cc`306aA>P@0IdLf
101ZBSd407AEB0@0KeA7101`DdD406]?@`<0Je17101_F4/402/J60@000L3101PFULZ07anOQH0oooo
000D0?oooc80O7in101hMWD407IfL`@0N6ED0`1_DCl406IIE@@0JfES101lJF4407aaJ@@0O7I]0`1l
LFT407afK@@0PFaZ1022J64407mQDP@0Lde40`1fFe4407a]I@@0O6AO101hF54407IYG0@0NFMH101d
Ge4306]4>P@0JdY1101`BS`406M8>P@0Idhn101[Cc`306aA>P@0IdLf101ZBSd407AEB0@0KeA7101`
DdD406]?@`<0Je17101_F4/402/J60@000L3101PFULZ07anOQH0oooo000D0?oooc80O7in1021MVL4
07a]I@@0NF=H0`1_F4h407eLAP@0MV1L101lH5d407a]I@/0O75Y101lOf/4085aHP@0OV]G101_DD43
075CB@@0O6eU101lOg04085aK@@0O6eY1022L6T407USF0<0NVEE101dE4L4071@@@@0Id@j101WB3`4
06I<A@<0M598101nGe@407ALC`@0KeM:101_E4L407AHBP@0L5=50`1[D40406IA@P@0?b8I100;2PX4
01LC4P@0O7Ui9P1lOWhF0?ooo`00503ooolb07anOP@0PGIW101lKFD407USF0<0KeQ>101mG4H407IP
G0@0O61M101lKFD;07aaJ@@0O7m[1021LF8407i[E`@0Ke510`1aDdT407a]I@@0O7m`1021LFd407a]
J@@0PW1Y101iHeP307YUE@@0M5A7101`D44406M4>P@0IdPl101VC4D307ABB0@0OUmD101dG4l406mG
BP@0KeA7101dF4X4071CA@<0Je10101VDD8403lR6@@02`X:100G4a8407aiNBH0O7in5P3oool001@0
oooo<P1lOWh4085fI`@0O6eU101iHeP306mHCP@0OEa6101fH5`407aPG@@0O6eU2`1lLFT407aoJ`@0
PG5R101nJeL406mA@@<0LE=9101lKFD407aoL0@0PG5]101lKFT4089`J@@0NF=H0`1jIED407ADA`@0
L511101WA3X406M8?0@0ITa50`1dDTP407iOE0@0M5a?101_EdX406mDA`@0M5Q:101`DdD306]@@0@0
IU52100o8QT400/:2P@05a<B101lNGTV07anOQH0oooo000D0?oooc80O7in1021MVL407a]I@@0NF=H
0`1_F4h407eLAP@0MV1L101lH5d407a]I@/0O75Y101lOf/4085aHP@0OV]G101_DD43075CB@@0O6eU
101lOg04085aK@@0O6eY1022L6T407USF0<0NVEE101dE4L4071@@@@0Id@j101WB3`406I<A@<0M598
101nGe@407ALC`@0KeM:101_E4L407AHBP@0L5=50`1[D40406IA@P@0?b8I100;2PX401LC4P@0O7Ui
9P1lOWhF0?ooo`00503ooolb07anOP@0O7mj101hJEP406a@?0<0KEQ:101lH5`807a]H0@0O6eU101l
MW4307afL0@0O75Y101lLFd407afJ`@0OV]N101dHe4306eHAP@0MVEI101lKF0407aaI0@0O75X101m
LF8407AKC@<0KeA7101[E4L4071IB`@0L5Ho101/BSP406I9?P<0KeQ?101hH5L407UPDP@0MF=E101_
Ge4406]GBP@0JeQ:0`1[E4X406mLC`@0^GQ?101V<R4401871@@05a@C9P1lOWhF0?ooo`00503ooolb
07anOP@0O7mj101hJEP406a@?0<0KEQ:101lH5`807a]H0@0O6eU101lMW4307afL0@0O75Y101lLFd4
07afJ`@0OV]N101dHe4306eHAP@0MVEI101lKF0407aaI0@0O75X101mLF8407AKC@<0KeA7101[E4L4
071IB`@0L5Ho101/BSP406I9?P<0KeQ?101hH5L407UPDP@0MF=E101_Ge4406]GBP@0JeQ:0`1[E4X4
06mLC`@0^GQ?101V<R4401871@@05a@C9P1lOWhF0?ooo`00503ooolb07anOP@0O7mj101hJEP406a@
?0<0KEQ:101lH5`807a]H0@0O6eU101lMW4307afL0@0O75Y101lLFd407afJ`@0OV]N101dHe4306eH
AP@0MVEI101lKF0407aaI0@0O75X101mLF8407AKC@<0KeA7101[E4L4071IB`@0L5Ho101/BSP406I9
?P<0KeQ?101hH5L407UPDP@0MF=E101_Ge4406]GBP@0JeQ:0`1[E4X406mLC`@0^GQ?101V<R440187
1@@05a@C9P1lOWhF0?ooo`00503oool^07anOP@0O6eU101dE4X406H_:0@0L4I00`1LC4L406EbH0P0
O6eP101lKFD407a/H@L0O75Y101lLFP407QYH0@0OG5R101mLVL307a]H0@0O6eL101hH5P407IKD@@0
O61H101iF4h407EFA@<0Jda0101WB3`406I<>0@0Gd<f101NA3P406YAA@<0KUa<101cG50407UPDP@0
MEQ;101_E4L407ADA`@0L5A30`1_Cd0406mAAP@0NEmE102LKeX40<Z`Y2X0O7in5P3oool001@0oooo
;P1lOWh407a]I@@0M5A:101V;bP40716@0<0G4a7101ULV0807a]H0@0O6eU101lK64707aaJ@@0O75X
101hJF0407eaHP@0OG9W0`1lKF0407a]G0@0N61H101fFe4407aPF0@0NEQ>101eETD306]<@0@0IdPl
101VC3P405m3=P@0GT@h101ZDDD306iLC0@0Lea@101iH58407EHB`@0KeA7101dE4L4071D@`<0Kdm0
101_DDH407UOE@@0W6mJ103:/:@Z07anOQH0oooo000D0?ooobh0O7in101lKFD407ADBP@0IRlX101`
AT0305a<A`@0IG9P201lKF0407a]I@@0O6aQ1`1lLFT407aaJ0@0N6UP101mLF8407ebI`<0O6eP101l
KE`407QPF0@0MU]A101lH5P407UHCP@0MEI50`1[C40406M8?0@0IT`h101O@cH405i4>0@0JU550`1^
G4`407=LD0@0NF1B101eF4/406mDA`@0M5A7101`E4<306m?@0@0Ke56101iGeD409a_FP@0b[2T:P1l
OWhF0?ooo`00503oool^07anOP@0O6eU101dE4X406H_:0@0L4I00`1LC4L406EbH0P0O6eP101lKFD4
07a/H@L0O75Y101lLFP407QYH0@0OG5R101mLVL307a]H0@0O6eL101hH5P407IKD@@0O61H101iF4h4
07EFA@<0Jda0101WB3`406I<>0@0Gd<f101NA3P406YAA@<0KUa<101cG50407UPDP@0MEQ;101_E4L4
07ADA`@0L5A30`1_Cd0406mAAP@0NEmE102LKeX40<Z`Y2X0O7in5P3oool001@0oooo;P1lOWh407a`
L@@0OUA@101eBCl406]6?`<0N5Q:101fJF4407aaK@@0O75X101lKFD707aaJ@@0O6eU101lKF0407e]
G`@0O6UK101mIEP307IYH@@0O75]1021Og@407a]J@@0O75O101nI5P4075IBP<0Id/n101SAcX405Y2
>P@0K4i1101_Fdh407ALC`<0M61D101cH5@407UPDP@0ME]>101_EdX406m?A`@0M4a:0`1[CdD406YA
BP@0K50o101VBC/406U8?0@0PH>29P1lOWhF0?ooo`00503oool^07anOP@0O71a101nE50407E9?`@0
JdHo0`1hF4X407IYH@@0O75]101lLFP407a]I@L0O75Y101lKFD407a]H0@0OFeO101lJE/407eUF0<0
MVUQ101lLFd4085oM0@0O6eY101lLEl407iTF0@0LEU:0`1WBch406=7>P@0FT8j101/CT4406mKCP@0
M5a?0`1dH5@407=PE0@0NF1B101eFdh406mGBP@0Kdm7101dC4X306]?A@@0JU5:101/D3l406I9>`@0
JDPl1021Ph8V07anOQH0oooo000D0?ooobh0O7in101lL74407iDD0@0MDTo101[ASl307QHBP@0MVUQ
101lLFd407aaJ0@0O6eU1`1lLFT407a]I@@0O6eP101mKEl407aYF`@0OFEH0`1fJF4407aaK@@0PGmd
101lKFT407aaG`@0OVAH101aFDX306M;?P@0HdLj101J@SX406a>@@@0Ke]>101dG4l307APE0@0Lf1D
101iH58407EKCP@0KeM:101_CdL407A<BP<0Jdm5101ZDDX406a@?`@0ITTk101YB3`40863PRH0O7in
5P3oool001@0oooo;P1lOWh407a`L@@0OUA@101eBCl406]6?`<0N5Q:101fJF4407aaK@@0O75X101l
KFD707aaJ@@0O6eU101lKF0407e]G`@0O6UK101mIEP307IYH@@0O75]1021Og@407a]J@@0O75O101n
I5P4075IBP<0Id/n101SAcX405Y2>P@0K4i1101_Fdh407ALC`<0M61D101cH5@407UPDP@0ME]>101_
EdX406m?A`@0M4a:0`1[CdD406YABP@0K50o101VBC/406U8?0@0PH>29P1lOWhF0?ooo`00503ooolZ
07anOP@0O75Y101lNVL407i/E`@0LEHo101ZCCl3071KD@@0O6eP101lKFD407afK@@0O6eU101lJF43
07QUF0@0MVUH101lH5`407eLF0@0Lf1D101hG54307IUF@@0O6UL101lKF0407a]I@@0O6QW101nEdl4
07ECA@L0K4i1101XDTD406IGAP@0JUE5101^FD`307QLD0@0M5a?101dF4/407EHB`@0Ke95101_Cd04
06]?@0<0JeA3101ZEDL407UOE@@0L5A7101C>Bh406EPHBH0O7in5P3oool001@0oooo:P1lOWh407aa
J@@0O7YW101nK5L4075F?`@0JTdo0`1`Fe4407a]H0@0O6eU101lMVd407a]I@@0O6UQ0`1hIEP407IY
F0@0O61L101mG5P407=PE0@0N5aA0`1fIET407aYG0@0O6eP101lKFD407aXI`@0OUM?101eDdD706a>
@@@0J595101VEdH406YEA@@0KUU<0`1hG50407ALC`@0M5Q;101eF4/406mBA@@0Kdm0101[Cd0306]D
@`@0JUE7101iGeD4071DA`@0DcT^101UH64V07anOQH0oooo000D0?ooobX0O7in101lLFT407ajI`@0
OVaG101aESl406Y=?`<0L5]A101lKF0407a]I@@0O7I]101lKFD407aYH@<0N6EH101fJEP407aPG0@0
OEaH101cH5@407QLD@<0MVEI101lJE`407a]H0@0O6eU101lJ6L407iGC`@0ME=51`1/CT4406QBA@@0
IUM6101ZEDD406iIC0<0N5a@101dG4l407AHB`@0MEQ;101_DTD406m?@0@0Jdm00`1[E4<406YEA`@0
NEmE101`E4L405<i;P@0IF1Q9P1lOWhF0?ooo`00503ooolZ07anOP@0O75Y101lNVL407i/E`@0LEHo
101ZCCl3071KD@@0O6eP101lKFD407afK@@0O6eU101lJF4307QUF0@0MVUH101lH5`407eLF0@0Lf1D
101hG54307IUF@@0O6UL101lKF0407a]I@@0O6QW101nEdl407ECA@L0K4i1101XDTD406IGAP@0JUE5
101^FD`307QLD0@0M5a?101dF4/407EHB`@0Ke95101_Cd0406]?@0<0JeA3101ZEDL407UOE@@0L5A7
101C>Bh406EPHBH0O7in5P3oool001@0oooo:P1lOWh407AWF@@0GSha1013<2@4048d;0@0FTU00`1a
H5D407a]H0P0O6UQ101lKF0407aYF0<0OFUL101cG5@406mPD@@0LeaD101hJEl407Q]G`<0MVUH301l
KFD407QfH`@0NFYI101eETP306a>@@@0Id/n101`C40406]@A`@0KeE<101dFDl306mIC0@0M61D101d
HeD407EKCP@0KemA101[Fd`406]CA@<0Jda7101ZDDX406M2<0@0JTHj101`@Bl406Dl<2H0O7in5P3o
ool001@0oooo:P1lOWh407AWF@@0GSha1013<2@4048d;0@0FTU00`1aH5D407a]H0P0O6UQ101lKF04
07aYF0<0OFUL101cG5@406mPD@@0LeaD101hJEl407Q]G`<0MVUH301lKFD407QfH`@0NFYI101eETP3
06a>@@@0Id/n101`C40406]@A`@0KeE<101dFDl306mIC0@0M61D101dHeD407EKCP@0KemA101[Fd`4
06]CA@<0Jda7101ZDDX406M2<0@0JTHj101`@Bl406Dl<2H0O7in5P3oool001@0oooo:P1lOWh407AW
F@@0GSha1013<2@4048d;0@0FTU00`1aH5D407a]H0P0O6UQ101lKF0407aYF0<0OFUL101cG5@406mP
D@@0LeaD101hJEl407Q]G`<0MVUH301lKFD407QfH`@0NFYI101eETP306a>@@@0Id/n101`C40406]@
A`@0KeE<101dFDl306mIC0@0M61D101dHeD407EKCP@0KemA101[Fd`406]CA@<0Jda7101ZDDX406M2
<0@0JTHj101`@Bl406Dl<2H0O7in5P3oool001@0oooo:P1lOWh407AWF@@0GSha1013<2@4048d;0@0
FTU00`1aH5D407a]H0P0O6UQ101lKF0407aYF0<0OFUL101cG5@406mPD@@0LeaD101hJEl407Q]G`<0
MVUH301lKFD407QfH`@0NFYI101eETP306a>@@@0Id/n101`C40406]@A`@0KeE<101dFDl306mIC0@0
M61D101dHeD407EKCP@0KemA101[Fd`406]CA@<0Jda7101ZDDX406M2<0@0JTHj101`@Bl406Dl<2H0
O7in5P3oool001@0oooo:P1lOWh407UTE@@0?R<D100f91h402`O7@@0:RX]0`1aH5T407a]I@@0O6eP
101lKE`407a]I@@0O75]0`21LFd4085jL0@0PVaU101dF4l406Y:@P@0KEE:0`1cHED407IYG@@0O6eU
101lKF0407eTF`@0M5]?101/BTD306M8?@@0HdLh101RBCh406mDB0@0JUA4101ZDDD306iEC0@0Kde4
101ZDDD406]DA`@0IU54101[E4L406]CA@<0Jdm4101VBSl406QI@0@0FS`[101VBSh406Dl=BH0O7in
5P3oool001@0oooo:P1lOWh407UTE@@0?R<D100f91h402`O7@@0:RX]0`1aH5T407a]I@@0O6eP101l
KE`407a]I@@0O75]0`21LFd4085jL0@0PVaU101dF4l406Y:@P@0KEE:0`1cHED407IYG@@0O6eU101l
KF0407eTF`@0M5]?101/BTD306M8?@@0HdLh101RBCh406mDB0@0JUA4101ZDDD306iEC0@0Kde4101Z
DDD406]DA`@0IU54101[E4L406]CA@<0Jdm4101VBSl406QI@0@0FS`[101VBSh406Dl=BH0O7in5P3o
ool001@0oooo:P1lOWh407UTE@@0?R<D100f91h402`O7@@0:RX]0`1aH5T407a]I@@0O6eP101lKE`4
07a]I@@0O75]0`21LFd4085jL0@0PVaU101dF4l406Y:@P@0KEE:0`1cHED407IYG@@0O6eU101lKF04
07eTF`@0M5]?101/BTD306M8?@@0HdLh101RBCh406mDB0@0JUA4101ZDDD306iEC0@0Kde4101ZDDD4
06]DA`@0IU54101[E4L406]CA@<0Jdm4101VBSl406QI@0@0FS`[101VBSh406Dl=BH0O7in5P3oool0
01@0oooo:P1lOWh407UTE@@0?R<D100f91h402`O7@@0:RX]0`1aH5T407a]I@@0O6eP101lKE`407a]
I@@0O75]0`21LFd4085jL0@0PVaU101dF4l406Y:@P@0KEE:0`1cHED407IYG@@0O6eU101lKF0407eT
F`@0M5]?101/BTD306M8?@@0HdLh101RBCh406mDB0@0JUA4101ZDDD306iEC0@0Kde4101ZDDD406]D
A`@0IU54101[E4L406]CA@<0Jdm4101VBSl406QI@0@0FS`[101VBSh406Dl=BH0O7in5P3oool001@0
oooo9P1lOWh407afL@@0Q7ag102EFDH404HZ7`@0>BDP100Z:Rd3075PD@@0N6UH101fJF4407a]I0@0
Kea<101PCCl305Do<P@0B3<X101=?3<405@n>`@0IDI2101UAS`306U=A0@0LF1E101lKFD407a]J@@0
OFaR101jGU84071D?0<0IdLf101XBc`405i8?0@0FTHk101FC40405e=@P<0IEU9101[Fd`406YEB0@0
M5]>101`EdX406]DA`@0Je=50`1[Cd@406]@A`@0FSP/10107aL404/`8P@0H3LV9P1lOWhF0?ooo`00
503ooolV07anOP@0O7Ia1024O7L409EIAP@0ARXO100i9B0402XZ;@<0LF1A101hJEP407IYH@@0O6eT
101_G4`4061=?`<0EClb1018<bP404dl<`@0E3hk101UAT8406E6?0<0JDe4101aH5D407a]I@@0O6eY
101mK68407YNDP@0L5@l0`1WAcH406Q;?0@0GTPl101JAS/405I<@0@0GDe20`1UFDT406]KC0@0JUE8
101dFdh4071GBP@0JeA7101[DdD306]?A0@0Je17101J>2`4040O5`@0Bc0R101P=bHV07anOQH0oooo
000D0?ooobH0O7in101lMW4408AlM`@0UEU61016:Ql403TU80@0:RX]0`1aH54407QYF0@0MVUQ101l
KF@406mLC0@0H4do0`1E?c8404Pc:0@0CC`c101D?S/406E6@P@0IDHl0`1YCD@4075PE@@0O6eU101l
KFT407e/HP@0NUiB101`E3`306M7=P@0J4/l101NB3`405Y6>`@0ETa0101MCD8306EIB@@0Je]<101Z
EDP407AKCP@0L5M:101[E4L406]CA@<0Jdm4101[D4L405Xh;0@0@1lG101;<284060g9RH0O7in5P3o
ool001@0oooo9P1lOWh407Q]HP@0NF=E100Z3`X401P?3@@07QPE100E92P307=QE@@0O6UL101lJEP4
07a]H0@0R7EU101/ETP305M6>0@0=BhZ100M71/401/L50@0;RDN101391/303/G4P@0AbPQ101fIET4
07a]I@@0OG5R101jHE84071B@@<0He8l101OAS@4065=@P@0NEa>101nGe4407AGBP<0JdU2101SC4<4
065AA@@0KeQ;101`EdX406=?@`@0FTm30`1RE4@406]DA`@0KTPf101J<bD405@^9P@0H2dQ9P1lOWhF
0?ooo`00503ooolV07anOP@0N6eR101iHeD402X?2P@060l=100N61D401DT:0<0Lf5E101lJE`407aY
F0@0O6eP1028MFD406aFB0<0EdHh100e;RX401dL6`@06a`D100^9Ah404<T6`<0>aLB1017:24407IU
F@@0O6eU101mLF8407YQDP@0L5910`1SDS`405m6=0@0HDe2101iG4h407iOD@@0M5M:0`1[BD8406=<
@`@0HE55101_F4/4071GBP@0Hdm3101JCd<3069DA0@0JeA7101^B3H405Xc9@@0E2hV101P;B4V07an
OQH0oooo000D0?ooobH0O7in101hKF8407USE@@0:Pl:100H3`d401hH5@@05B@X0`1cHED407aYG0@0
O6UH101lKF0408QeI@@0K5I80`1GASP403D^:P@07A`K100K71@402hU7P@0@b@K0`0k5a8404LX8@@0
MVEI101lKFD407eaHP@0NV5B101`DT4306=B?0@0GdHd101QCD8407ULCP@0OUmA101dEdX306]9@P@0
Hda3101QDDD406mHB`@0L5M:101SCd<405Y?@`<0HUA4101[E4L406i8=P@0FS<U101D;RH4060]8BH0
O7in5P3oool001@0oooo9P1lOWh407Q]HP@0NF=E100Z3`X401P?3@@07QPE100E92P307=QE@@0O6UL
101lJEP407a]H0@0R7EU101/ETP305M6>0@0=BhZ100M71/401/L50@0;RDN101391/303/G4P@0AbPQ
101fIET407a]I@@0OG5R101jHE84071B@@<0He8l101OAS@4065=@P@0NEa>101nGe4407AGBP<0JdU2
101SC4<4065AA@@0KeQ;101`EdX406=?@`@0FTm30`1RE4@406]DA`@0KTPf101J<bD405@^9P@0H2dQ
9P1lOWhF0?ooo`00503ooolS07anOP<0P8:21027PGX407UIB0@0Jchc100Z61<402TG4`@05AdS0`1l
KF0407Q]G`@0MVUL101lKF04085fK0@0SG5R0`2HM6T406a8>P@0<1`F100T61<4028R8@@0@Sdc0`1d
GTl406eHCP@0MVeP101lNWD407ejL@@0NVEE101WBC`305Xk<0@0?A@;100a71X405Hl:P@0CcPZ100l
;B<304<i;@@0Hda0101MCCh406IA@P@0JeA7101/Cd4406=<@0<0HTa4101SB3h405@g;0@0BcH[101H
A3`406Tn=P<0PH>28`1lOWhF0?ooo`00503ooolS07anOP<0P8:21027PGX407UIB0@0Jchc100Z61<4
02TG4`@05AdS0`1lKF0407Q]G`@0MVUL101lKF04085fK0@0SG5R0`2HM6T406a8>P@0<1`F100T61<4
028R8@@0@Sdc0`1dGTl406eHCP@0MVeP101lNWD407ejL@@0NVEE101WBC`305Xk<0@0?A@;100a71X4
05Hl:P@0CcPZ100l;B<304<i;@@0Hda0101MCCh406IA@P@0JeA7101/Cd4406=<@0<0HTa4101SB3h4
05@g;0@0BcH[101HA3`406Tn=P<0PH>28`1lOWhF0?ooo`00503ooolS07anOP<0P8:21027PGX407UI
B0@0Jchc100Z61<402TG4`@05AdS0`1lKF0407Q]G`@0MVUL101lKF04085fK0@0SG5R0`2HM6T406a8
>P@0<1`F100T61<4028R8@@0@Sdc0`1dGTl406eHCP@0MVeP101lNWD407ejL@@0NVEE101WBC`305Xk
<0@0?A@;100a71X405Hl:P@0CcPZ100l;B<304<i;@@0Hda0101MCCh406IA@P@0JeA7101/Cd4406=<
@0<0HTa4101SB3h405@g;0@0BcH[101HA3`406Tn=P<0PH>28`1lOWhF0?ooo`00503ooolS07anOP<0
P8:21027PGX407UIB0@0Jchc100Z61<402TG4`@05AdS0`1lKF0407Q]G`@0MVUL101lKF04085fK0@0
SG5R0`2HM6T406a8>P@0<1`F100T61<4028R8@@0@Sdc0`1dGTl406eHCP@0MVeP101lNWD407ejL@@0
NVEE101WBC`305Xk<0@0?A@;100a71X405Hl:P@0CcPZ100l;B<304<i;@@0Hda0101MCCh406IA@P@0
JeA7101/Cd4406=<@0<0HTa4101SB3h405@g;0@0BcH[101HA3`406Tn=P<0PH>28`1lOWhF0?ooo`00
503oool407aeM@@0O7Ui101lNWT307aiNA@0O7in0`0W40/400X@5@@0NV1B101cASD402hO8P@071@B
100551`307=UF0@0O6eP101hJE`407=UF0@0MVUM1028OW4307ATDP@0YWIP102iQ6P409]VB@@0PDhd
101`FdH306mHB0@0LeE:101fI5P407a/H@@0OFeR101jHE8407YC?`<0J4Hh101fCSX404Lh=@@0<S0c
100;1PL401DG5`<0:RDQ100O6A@401`N7P@0>2`Q101;=RL406Q<?P@0Hdm30`1RCd0405i6>0@0@BdQ
100]8ad403dl=0@0JDTl0`21Ph8S07anOQH0oooo000D0?ooo`@0O7Ee101lNGT407ajN@<0O7Ui501l
OWh302L@2`@02Q0E101jH58407=6=@@0;QlR100L518400DD70<0LfEH101lKF0407QYG0@0LfEH101f
JEd408QnL@<0M6AB102VMV040;V4J0@0VfI91021CS@4071KAP<0KeQ8101cEDX407ITF0@0O6aQ101m
KF8407YQDP@0NU<o0`1XASP407I>>P@0AcPe100b<3<400/61`@05ALG0`0Z9B4401lI50@071hN100h
;24404/f9`@0J4`n101SCd<3069?@0@0GTHh1011;B4402dS7@@0?C`d101YBC`30863PR<0O7in5P3o
ool001@0oooo101lMGD407aiN@@0O7Yi0`1lNGTD07anOP<09a0;100:41D407YPDP@0LdHe100^7b84
01`D4P@01A@L0`1cIEP407a]H0@0N6UL101cIEP407IYG@@0R7ia0`1dI5840:IfH0@0^HAX102KITT4
085>=0@0L5]60`1_F4P407=EBP@0MVAH101lK64407e]HP@0NV5B101jDcl306Q6>0@0MThj1017>3D4
038`<`@02`H7100E5aL302XU8@@07aTD100L7Qh403P/8@@0BcHW101XC3h406=?@`<0HTm0101NASP4
044]8@@0;B<M100m?3@406U9?0<0PH>28`1lOWhF0?ooo`00503oool407aeM@@0O7Ui101lNWT307ai
NA@0O7in0`0W40/400X@5@@0NV1B101cASD402hO8P@071@B100551`307=UF0@0O6eP101hJE`407=U
F0@0MVUM1028OW4307ATDP@0YWIP102iQ6P409]VB@@0PDhd101`FdH306mHB0@0LeE:101fI5P407a/
H@@0OFeR101jHE8407YC?`<0J4Hh101fCSX404Lh=@@0<S0c100;1PL401DG5`<0:RDQ100O6A@401`N
7P@0>2`Q101;=RL406Q<?P@0Hdm30`1RCd0405i6>0@0@BdQ100]8ad403dl=0@0JDTl0`21Ph8S07an
OQH0oooo000D0?ooo`@0O7Yi101lNGT407b3PQ<0O7in100]6A@302/K5P@01P<2100920X401lD60@0
71@@100W6A@4010I7`<0N6UL101fJF4407ABC@@0ID<m101[Edd4085fL@<0Qh=l102>Mg0407mNDP@0
Q6II1024IEL407ULCP<0N6AD101hH5@407ITF0@0O75Y101mK6D407YWF`@0L5Y80`1/ES`407EH?`@0
PeM2102EGTP402lK60@06aHA0`0_7ad4034T80@0<RTQ101J@3H4065A@`@0L4ln101XC403069D@`@0
AR/U100a8AX402lO5`@0:QhJ101J:1`V07anOQH0oooo000D0?ooo`@0O7Yi101lNGT407b3PQ<0O7in
100]6A@302/K5P@01P<2100920X401lD60@071@@100W6A@4010I7`<0N6UL101fJF4407ABC@@0ID<m
101[Edd4085fL@<0Qh=l102>Mg0407mNDP@0Q6II1024IEL407ULCP<0N6AD101hH5@407ITF0@0O75Y
101mK6D407YWF`@0L5Y80`1/ES`407EH?`@0PeM2102EGTP402lK60@06aHA0`0_7ad4034T80@0<RTQ
101J@3H4065A@`@0L4ln101XC403069D@`@0AR/U100a8AX402lO5`@0:QhJ101J:1`V07anOQH0oooo
000D0?ooo`@0O7Yi101lNGT407b3PQ<0O7in100]6A@302/K5P@01P<2100920X401lD60@071@@100W
6A@4010I7`<0N6UL101fJF4407ABC@@0ID<m101[Edd4085fL@<0Qh=l102>Mg0407mNDP@0Q6II1024
IEL407ULCP<0N6AD101hH5@407ITF0@0O75Y101mK6D407YWF`@0L5Y80`1/ES`407EH?`@0PeM2102E
GTP402lK60@06aHA0`0_7ad4034T80@0<RTQ101J@3H4065A@`@0L4ln101XC403069D@`@0AR/U100a
8AX402lO5`@0:QhJ101J:1`V07anOQH0oooo000D0?ooo`@0O7Yi101lNGT407b3PQ<0O7in100]6A@3
02/K5P@01P<2100920X401lD60@071@@100W6A@4010I7`<0N6UL101fJF4407ABC@@0ID<m101[Edd4
085fL@<0Qh=l102>Mg0407mNDP@0Q6II1024IEL407ULCP<0N6AD101hH5@407ITF0@0O75Y101mK6D4
07YWF`@0L5Y80`1/ES`407EH?`@0PeM2102EGTP402lK60@06aHA0`0_7ad4034T80@0<RTQ101J@3H4
065A@`@0L4ln101XC403069D@`@0AR/U100a8AX402lO5`@0:QhJ101J:1`V07anOQH0oooo000D0?oo
o`@0O8>26`1lOWh405@a:@<0=24I100c7aP401lH5P@05Pd<100U5a@402dI50@05APN0`1lIEP407QU
E@@0QhQh101oKf84058h:`@0@bXQ0`12<2H403D/90@0;28N100X7QP4034U70@0=b<L0`17=c0406eP
E@@0MVEI101lJE`407e/FP@0NV1B101`EdX306a4>0@0Hdlj101RD3/407ENC@@0cHY[102RLe/307i=
>0@0OTPe101aCT4407EF?`@0Hd`n101VEdH407EHA`<0Hdm51018;b0402TI50@0;ahH100_8a/405@N
4bH0O7in5P3oool001@0oooo101lPh8K07anOP@0E34Y0`0d8AT403<O60@07aPF100F3@`402DG50@0
;ATD100E61h307aUF0@0N6EE1027R7P407m_HP@0DSP[1013:R43048`9P@0=B`T100/8Qh402PN60@0
<BDL100g8a`304Lg<0@0KF1E101fIET407aYG0@0OFaJ101jH584071GBP<0K4@h101SCcX4069@>`@0
MEi=103=RV/40:9cF`<0OTdh101nB3D4075>@@@0MEHo101SC3h406IGAP@0MEQ70`1SCdD404P_80@0
:ATD100_7QP402lS6`@0E1hC9P1lOWhF0?ooo`00503oool407b3PQ/0O7in101D<BT303@Q6@@0<alH
100O61H401H=30@09ALD100]6A@401DH7P<0O6EH101hIED408N8N0@0OfmR101B>2/404<Z8@<0@S0V
100e;2@402`R7P@0:1hH100a9A`403LS70<0AcL`101]H5D407IUF@@0O6UL101mK5X407YPDP@0L5M:
0`1/A3P406=?>P@0HU0k101eGTd40<f:J`@0XW=K0`1nCCP407i8=@@0LDi1101eESl406=<?P@0IUM6
101eF4L306=?A@@0B2lP100Y6A@402lN60@0;b<K101D7Q<V07anOQH0oooo000D0?ooo`@0O8>26`1l
OWh405@a:@<0=24I100c7aP401lH5P@05Pd<100U5a@402dI50@05APN0`1lIEP407QUE@@0QhQh101o
Kf84058h:`@0@bXQ0`12<2H403D/90@0;28N100X7QP4034U70@0=b<L0`17=c0406ePE@@0MVEI101l
JE`407e/FP@0NV1B101`EdX306a4>0@0Hdlj101RD3/407ENC@@0cHY[102RLe/307i=>0@0OTPe101a
CT4407EF?`@0Hd`n101VEdH407EHA`<0Hdm51018;b0402TI50@0;ahH100_8a/405@N4bH0O7in5P3o
ool001@0oooo7`1lOWh405`i:@<08A0;100H4`l401`C3`@09AHA100J510402PT80@06B@W0`1[G544
085]H0@0O6eP102=OgP409jCP`@0PfIJ0`1VCD/407EIDP@0S5i<101oFTX4071A@@@0NEi?0`1hHED8
07a]I@@0O61P101mIEh407YTE@@0L5==0`1>;RD403`O6@@0@c8X101RD3/406]D@0@0NE]:0`28J5<4
07YSD0@0IUM6101SDdP406]?A`@0Hda5101RD40305i6=P@0:1/E100H510404<n=P@0FcTY10197Q<V
07anOQH0oooo000D0?oooal0O7in101L>BT3024@2`@061<?100L4`l402DF4@@06Q@@100X920401TT
9`<0JeaA1021KF0407a]H0@0SGmh102NTh<408=VFP<0ITe;101eFE8408aNC0@0OeY:101`DD4407UN
C`<0N65E201lKFD407aPH0@0OFEN101jI5D4071CC@<0CRhU100l7aT404<b:0@0HU0k101[E40407UK
BP<0R6QC101jHe0406IGAP@0He=8101[CdL406=<A@@0HU100`1NASH402PK5@@061@@1013?SH405/i
:@@0BAhC9P1lOWhF0?ooo`00503ooolO07anOP@0G3TY0`0Q40/401PC3`@071<?100U5Q4401XD40@0
:2@P100I92L306]LD@@0PFeP101lKF0408eoN0@0WY>31023IUX306I=B`@0MEUB102<GT`407mJBP@0
L551101iGTl307QQE@P0O6eU101lH60407eUGP@0NVAE101`Ddd304h^9@@0?1lI1013<RP4069@>`@0
JeA0101iFdX308QXD`@0NV=@101VEdH406=CB0@0Jdm7101SC4D4069@@0<0GTHf100X6aD401PD40@0
@chf101K>BT404TN4bH0O7in5P3oool001@0oooo7`1lOWh405`i:@<08A0;100H4`l401`C3`@09AHA
100J510402PT80@06B@W0`1[G544085]H0@0O6eP102=OgP409jCP`@0PfIJ0`1VCD/407EIDP@0S5i<
101oFTX4071A@@@0NEi?0`1hHED807a]I@@0O61P101mIEh407YTE@@0L5==0`1>;RD403`O6@@0@c8X
101RD3/406]D@0@0NE]:0`28J5<407YSD0@0IUM6101SDdP406]?A`@0Hda5101RD40305i6=P@0:1/E
100H510404<n=P@0FcTY10197Q<V07anOQH0oooo000D0?ooo`P0O7in101lNWT307aiNA00O7in101X
B3T302lD3P@091@@100L510400l820@0718?100X7a`4020V9`<0Eda4101fIET407a]H0@0O75Y1021
NWD409:FR@<0[Yj=102BUXT409fNU@@0WIZA102SXiT408f;OP<0OFeO101fKF0407Q]G`@0Lg9L101h
JE/407mXFP@0Q7MQ0`2HOFP4068n>0@0:ATH100F4Q04024P7P@0Dd<i0`1[E4D407EH@`@0Hdm3101W
Bch405M4=P@0HDU1101[C4D304HZ80@0:aPB100[8Ad401lS7P@0DbdO100M20@301`I62<0O7in5P3o
ool001@0oooo201lOWh407ajN@<0O7Ui401lOWh406Q8>@<0;a@>100T510401`D40@03`P8100L4Pl4
02PO70@082HW0`1GC4@407IUF@@0O6eP101lLFT4085jM@@0TYJ90`2^WXd409:FR@@0WIjE102MVY44
0:>SV@@0SH]n0`1mKEl407I]H0@0N6eO101cLU`407QYF`@0OfQJ1024Mf4309QmJ0@0HShh100Y6AP4
01HB40@08B0N101C@cT306]DA@@0MEQ3101SCd<406M;?P@0Ed@f101QBD4406]<A@<0ARXP100[6184
02/Q7@@07b<N101C;Al401d810<071TH8`1lOWhF0?ooo`00503oool807anOP@0O7Yi0`1lNGT@07an
OP@0J4Pi0`0_50h402@D40@071@@100?20P401`B3`@0:1lL100P9RL305M<A0@0MVEI101lKF0407aa
J@@0PGYe102BUXT30:jNS@@0TYJ9102MWYD409fJT@@0Xj>I102=Rgh307e]G`@0MVeP101hKEl407=b
G0@0N6UK101oJ5X408AgH@<0V7eX101R?SP402TI60@05Q8@100Q81h405=3>@<0JeA5101eF4<406=?
@`@0Id/n101GA3H40659@@@0Jda50`16:R0402/H4P@0:b4M100O8ah405<]7`@07@P40`0L6APS07an
OQH0oooo000D0?ooo`P0O7in101lPh8C07anOP@0EDDo0`0^8Qd402@F4P@08Q@@100M4Pd401hD40@0
:1lL100];B/305e<@`@0MVEI101lKF0407a]I@@0O75Y101lMW4707akN@@0O7I`101lMW4407afL0@0
O7Ia0`21MV/407aYF0@0PG5T101mJE/407QPE0@0OFEH101mJE/308Q`I@@0YhUh102[NF/4081DB0@0
<B@M100F4Pl301TG5`@09b8Q100b:B4403P[8@@0G4<l101[Cd<406M;?P<0?B8K100T5A44024F5P@0
4P`:100Q4`h403hV8@<08QhL8`1lOWhF0?ooo`00503oool807anOP@0O8>24`1lOWh405E5?`<0;R8M
100T5Q84028D40@07A8=100N510402PO70@0;Bd[0`1MC4<407IUF@@0O6eP101lKFD407aaJ@@0O7Ia
1`1lNgT407afL0@0O7Ia101lMW0407afL@<0PGI[101lJEP4085aI0@0OFUK101hH5@407eUF0@0OFUK
0`28L6D40:N9N0@0ZgU[1020E4P4034T7@@05Q8?0`0I5aL402LR8@@0<RTQ100h:b4405a3?0@0Jdm3
101WBch303dR6`@091DA100Q5QH4018<2P@08A<>100n9R43028N72<0O7in5P3oool001@0oooo201l
OWh407b3PQ<0O7in101EACl302hR7@@091HB100R510401dB3@@07Q@@100X7a`402d]:`<0GDa3101f
IET407a]H0@0O6eU101lLFT407afL@L0O7]i101lMW0407afL@@0O7I`101lMW43085fJ`@0O6UH1021
LF@407eYF`@0N61D101mIEP407eYF`<0R71U102WRGP40:]iJ`@0P5A8100a91d401HB3`<06ALG100W
8R44038Y8@@0>2/Q101L@c`406]?@`@0Id/n0`0m8Q/402@E4@@08AHF100B30X4024C3P@0?RHQ0`0R
7Q`S07anOQH0oooo000D0?ooo`P0O7in101lPh8C07anOP@0EDDo0`0^8Qd402@F4P@08Q@@100M4Pd4
01hD40@0:1lL100];B/305e<@`@0MVEI101lKF0407a]I@@0O75Y101lMW4707akN@@0O7I`101lMW44
07afL0@0O7Ia0`21MV/407aYF0@0PG5T101mJE/407QPE0@0OFEH101mJE/308Q`I@@0YhUh102[NF/4
081DB0@0<B@M100F4Pl301TG5`@09b8Q100b:B4403P[8@@0G4<l101[Cd<406M;?P<0?B8K100T5A44
024F5P@04P`:100Q4`h403hV8@<08QhL8`1lOWhF0?ooo`00503ooolO07anOP@0J4e50`14;bX402@I
50@07a@@100T5A4402DI6@@0:R4O100W:bP304Ln=`@0Je]A101lKE`407aYG@@0O6eU101lK64307aa
J0@0O7Ia101lNgT407afL@@0O7I`101lLFT307afL@@0O75X101lKF0407e]GP@0N6UK201hH5@307QT
F0@0OfAG101jJeP4099_FP@0VG=M102<IU4306E9=P@0HSd]101XBS`407YLC@@0GTM0101OBD<405M:
?@<0?b@L100T5A4401/D3`@05A4<100H5a@402lT8@<08QhL8`1lOWhF0?ooo`00503ooolO07anOP@0
J4e50`14;bX402@I50@07a@@100T5A4402DI6@@0:R4O100W:bP304Ln=`@0Je]A101lKE`407aYG@@0
O6eU101lK64307aaJ0@0O7Ia101lNgT407afL@@0O7I`101lLFT307afL@@0O75X101lKF0407e]GP@0
N6UK201hH5@307QTF0@0OfAG101jJeP4099_FP@0VG=M102<IU4306E9=P@0HSd]101XBS`407YLC@@0
GTM0101OBD<405M:?@<0?b@L100T5A4401/D3`@05A4<100H5a@402lT8@<08QhL8`1lOWhF0?ooo`00
503ooolO07anOP@0J4e50`14;bX402@I50@07a@@100T5A4402DI6@@0:R4O100W:bP304Ln=`@0Je]A
101lKE`407aYG@@0O6eU101lK64307aaJ0@0O7Ia101lNgT407afL@@0O7I`101lLFT307afL@@0O75X
101lKF0407e]GP@0N6UK201hH5@307QTF0@0OfAG101jJeP4099_FP@0VG=M102<IU4306E9=P@0HSd]
101XBS`407YLC@@0GTM0101OBD<405M:?@<0?b@L100T5A4401/D3`@05A4<100H5a@402lT8@<08QhL
8`1lOWhF0?ooo`00503ooolO07anOP@0J4e50`14;bX402@I50@07a@@100T5A4402DI6@@0:R4O100W
:bP304Ln=`@0Je]A101lKE`407aYG@@0O6eU101lK64307aaJ0@0O7Ia101lNgT407afL@@0O7I`101l
LFT307afL@@0O75X101lKF0407e]GP@0N6UK201hH5@307QTF0@0OfAG101jJeP4099_FP@0VG=M102<
IU4306E9=P@0HSd]101XBS`407YLC@@0GTM0101OBD<405M:?@<0?b@L100T5A4401/D3`@05A4<100H
5a@402lT8@<08QhL8`1lOWhF0?ooo`00503ooolO07anOP@0Hd@d0`0a81L4038P6P@091HB100U40`4
02TG4P@0;AdF100W8Qh303Hb;P@0HU17101fJE`407a]H0@0O6eU101lMW4307aaJ@@0O75X201lMW44
07afL0@0O75Y0`1lKF0407a]I@@0O6UP101mI5L407QPE0@0N6UK101hH5@307QPD@@0NEa?101jF4/4
07YKCP@0NE]<1024He@308e/FP@0R6QH101eFD/407E?A`@0L5I5101`Bch405@d9`<0>1lH100T5A44
02/I50@08AHB100L510402@I4`<04PX6101JDE8O07anOQH0oooo000D0?oooal0O7in101SA3@3034P
5`@0<R0J100T5Q8402D@30@0:ALB100]7AH402LR7P<0=S8^101RD4L407IYG0@0O6eP101lKFD407af
L@<0O75Y101lLFP807afL@@0O7I`101lLFT307a]H0@0O6eU101lJF0407eTE`@0N61D101hJE/407QP
E0<0N61A101iG4l407YHB`@0NU]>101iFd`408ASE0<0SFaJ1028J5P407EIB`@0MDm7101`ETD4071;
?P@0E3@W0`0h7aP402@E4@@0:aTD100Q5Q8401`D40@091TC0`0B2PH405YADQl0O7in5P3oool001@0
oooo7`1lOWh406=4=0<0<B0G100b81X402@F4P@09A0<100Y5a8402dM5P@09b8N0`0f<Rh4069@A`@0
MVUL101lKF0407a]I@@0O7Ia0`1lLFT407aaJ0P0O7Ia101lMW0407aaJ@<0O6eP101lKFD407aYH0@0
OFAG101hH5@407QYF`@0N61D0`1hH54407ULC`@0NUQ;101jFdh407UKC0@0Q6=D0`2=K5X408QXF0@0
MEU;101eCdL4071FA@@0L4/n101D=2L303PO60@091DA100[6A@4024F4P@071@@100T6A<3018:1P@0
FU5B7`1lOWhF0?ooo`00503ooolO07anOP@0Hd@d0`0a81L4038P6P@091HB100U40`402TG4P@0;AdF
100W8Qh303Hb;P@0HU17101fJE`407a]H0@0O6eU101lMW4307aaJ@@0O75X201lMW4407afL0@0O75Y
0`1lKF0407a]I@@0O6UP101mI5L407QPE0@0N6UK101hH5@307QPD@@0NEa?101jF4/407YKCP@0NE]<
1024He@308e/FP@0R6QH101eFD/407E?A`@0L5I5101`Bch405@d9`<0>1lH100T5A4402/I50@08AHB
100L510402@I4`<04PX6101JDE8O07anOQH0oooo000D0?oooal0O7in101E?Rl303DY9@@0;R0K100/
6aH401TB3@@06a<?100K4Pl402@K5P<09B0I1017>2l407IUF@@0O6eP101lKFD407aaJ0<0O7]i101l
LFT407aaJ0`0O75Y0`1lLFP407a]G0P0N6UK101hH5@407QLD@L0N61D101iH58406mKCP@0KeQ;101d
H58406]GBP<0KeA7101`E4L406=CA@@0FTm0101JCd<405=6>0@0<bLQ0`0I4Pd4024H5`@05a0A100G
40`400l71`@06Q8A0`0N6QP404@g=Al0O7in5P3oool001@0oooo7`1lOWh405Dn;`<0=BTU100^81/4
02`K5P@06A8=100K4`l401/B3`@091/F0`0U81T404Lh;`@0MVEI101lKF0407a]I@@0O75X0`1lNgT4
07aaJ@@0O75X301lLFT307aaJ0@0O6eL201hJE/407QPE0@0N5aA1`1hH5@407UPDP@0Ke]>101_F4/4
07APDP@0JeM:0`1_E4L4071DA`@0He=5101JCd0405Y?@`@0DdHh100c9b4301TB3@@08APG100G4144
01L@30@03`L7100J4Q4301hJ60@0A3Le7`1lOWhF0?ooo`00503ooolO07anOP@0ECh_0`0e:BD402hP
6`@0;1/F100I4Pd401/C3`@06a8?100T6aH302DP6@@0AcP_101fIET407a]H0@0O6eU101lLFP307ak
N@@0O75Y101lLFP<07aaJ@<0O75X101lKE`807QYF`@0N61D101hG54707QPE0@0NF1B101_Fdh406mH
B`@0M61B101[EdX306mDA`@0L5A7101SDdD405Y?@0@0FTm3101CASP403<W8@<06A8=100Q61L401L@
4@@05a0<100?1`L401XB4@<07QXH1014=cDO07anOQH0oooo000D0?oooal0O7in101E?Rl303DY9@@0
;R0K100/6aH401TB3@@06a<?100K4Pl402@K5P<09B0I1017>2l407IUF@@0O6eP101lKFD407aaJ0<0
O7]i101lLFT407aaJ0`0O75Y0`1lLFP407a]G0P0N6UK101hH5@407QLD@L0N61D101iH58406mKCP@0
KeQ;101dH58406]GBP<0KeA7101`E4L406=CA@@0FTm0101JCd<405=6>0@0<bLQ0`0I4Pd4024H5`@0
5a0A100G40`400l71`@06Q8A0`0N6QP404@g=Al0O7in5P3oool001@0oooo7`1lOWh406Q7>0<0=2@O
100f:B@402dP6`@0<1`G100T5A4402TM6@@0;2HT0`0]:RP402h]:`@0JeA:101lJEd407aYH@@0O6QM
0`1lLFP407akN@@0O7Ia101lMW0807aaJ@<0O75]101hJF0407QYF``0N61D101dH5@306mLC`@0M5a?
101eFdh406mHB`@0KeE8101dFdh306]GBP@0JeA7101/DdD406]?@`@0K4/n101@=R`403@M5`<0<1lJ
100E30`401L@40@040P8100H410401/C40<08B<R100h<S0O07anOQH0oooo000D0?oooal0O7in101X
AcP303@T7`@0=RTT100]81/4030L5`@091DA100Y7AT402`V90<0;BXX100^;B/406]DBP@0O6UM101l
JF4407aXG@<0O75X101lNgT407afL@@0O7I`201lLFT307aaK@@0N6UP101hJE/<07QPE0@0M61D0`1_
G4l407ALC`@0ME]>101_F4/406mEB0@0M5]>0`1[EdX406]DA`@0K5=5101[Cd<406a;?P@0D3H/100d
7AL3030O6P@05@`<100G4104010820@0610@100K4a03024S8P@0>38`7`1lOWhF0?ooo`00503ooolO
07anOP@0J4Lh0`0d91l403HY90@0;B0K100`71L402@E4@@0:AdI100/9R@302dZ:0@0;Rd[101[E4X4
07aYG@@0O6UQ101lJ5d307aaJ0@0O7]i101lMW4407afL0P0O75Y0`1lLFd407QYH0@0N6UK301hH5@4
07APE0<0Kea?101dG4l407EKCP@0KeQ;101_EDP407AKCP<0JeM:101[E4L406aCA@@0Jdm3101/Bch4
050f;0@0=1dG0`0`7aX401D<30@05a0@100@20P401P@40@06a<@0`0Q8b8403Pb<1l0O7in5P3oool0
01@0oooo7`1lOWh406Q7>0<0=2@O100f:B@402dP6`@0<1`G100T5A4402TM6@@0;2HT0`0]:RP402h]
:`@0JeA:101lJEd407aYH@@0O6QM0`1lLFP407akN@@0O7Ia101lMW0807aaJ@<0O75]101hJF0407QY
F``0N61D101dH5@306mLC`@0M5a?101eFdh406mHB`@0KeE8101dFdh306]GBP@0JeA7101/DdD406]?
@`@0K4/n101@=R`403@M5`<0<1lJ100E30`401L@40@040P8100H410401/C40<08B<R100h<S0O07an
OQH0oooo000D0?oooal0O7in101LCDL703P[9`@0>2XU100]71L401XA30@08AHB100a7aP304L`90@0
@S0U101MA3T407IUE@@0O6eP101lJF4307aXG@@0O75X101lMW4407akN@@0O7I`101lLFT307aaJ0@0
PG5X101mKEh407ATE`@0Kea?101cFE0407UIC`<0M5Q;101dED`407EHCP@0KeQ;101_E4L406]AA0<0
JeA7101WBch4071<@0@0HdLj101>>30403hX7`@0<1`F0`0H40/401TA40@050`<100I4@`401P@40@0
9APD0`1?DE8S07anOQH0oooo000D0?oooal0O7in101LCDL703P[9`@0>2XU100]71L401XA30@08AHB
100a7aP304L`90@0@S0U101MA3T407IUE@@0O6eP101lJF4307aXG@@0O75X101lMW4407akN@@0O7I`
101lLFT307aaJ0@0PG5X101mKEh407ATE`@0Kea?101cFE0407UIC`<0M5Q;101dED`407EHCP@0KeQ;
101_E4L406]AA0<0JeA7101WBch4071<@0@0HdLj101>>30403hX7`@0<1`F0`0H40/401TA40@050`<
100I4@`401P@40@09APD0`1?DE8S07anOQH0oooo000D0?oooal0O7in101LCDL703P[9`@0>2XU100]
71L401XA30@08AHB100a7aP304L`90@0@S0U101MA3T407IUE@@0O6eP101lJF4307aXG@@0O75X101l
MW4407akN@@0O7I`101lLFT307aaJ0@0PG5X101mKEh407ATE`@0Kea?101cFE0407UIC`<0M5Q;101d
ED`407EHCP@0KeQ;101_E4L406]AA0<0JeA7101WBch4071<@0@0HdLj101>>30403hX7`@0<1`F0`0H
40/401TA40@050`<100I4@`401P@40@09APD0`1?DE8S07anOQH0oooo000D0?oooaL0O7in101lNWT4
07QaL@@0ED4j0`0_920403<X90@0=2LR100T5a8402dN6P@0:AhI100U7Q`3038[90@0B3`c101JACd4
075PE@@0O6eP1`1lLFT407aaJ0P0O7Ia101lMW0407aaJ@<0N6eO101fIEP407eTE`@0OF1D101mI5L4
07APC`@0M5a?0`1dFdh406mLC0@0Ke]>101[CdL406I@A`L0JeA7101`ETP406=?@`@0FdPj101N?bl4
03lX70@0;A/E0`0Q5Q8401dE40@07aHA100I4@`401`D40@08aPD0`0;1@@40863PQl0O7in5P3oool0
01@0oooo5`1lOWh407ajN@@0N75a101E@CX302lT80@0<bPT100d9b8402@G4P@0;AhJ100Y7QT402DN
70<0<R/T1018?3<405Y5?@@0LF1E101lKF0707aaJ@@0O75X201lMW4407afL0@0O75Y0`1hKEl407IU
F0@0OFAG101mH5@407eTE`@0M61?101dG4l307AKCP@0Kea<101_Fdh406]?A`@0IU171`1[E4L4071F
B0@0Hdm3101KB3X405ho;`@0?bPL100]6aD3024F4P@07AD@100O5Q4401TA30@071@@100S61@300/5
10@0PH>27`1lOWhF0?ooo`00503ooolG07anOP@0O7Yi101hLG4405E1>P<0;b@P100c:2@403@W8P@0
91LB100]7QX402TN6@@09AhL0`0b:b@404Pl<`@0FTDm101aH5D407a]H0L0O75Y101lLFP807afL@@0
O7I`101lLFT307Q]G`@0MVEH101mI5L407ePE0@0OFAG101dH4l407ALC`<0M5]>101_G4`406mKCP@0
Jdm7101VD4L706]DA`@0L5I8101SCd<405]8>P@0GSl_100o:1`402dK5@<08AHB100M5A0401lF4@@0
6A4<100L510402<H50<02`D41021Ph8O07anOQH0oooo000D0?oooaL0O7in101lNWT407QaL@@0ED4j
0`0_920403<X90@0=2LR100T5a8402dN6P@0:AhI100U7Q`3038[90@0B3`c101JACd4075PE@@0O6eP
1`1lLFT407aaJ0P0O7Ia101lMW0407aaJ@<0N6eO101fIEP407eTE`@0OF1D101mI5L407APC`@0M5a?
0`1dFdh406mLC0@0Ke]>101[CdL406I@A`L0JeA7101`ETP406=?@`@0FdPj101N?bl403lX70@0;A/E
0`0Q5Q8401dE40@07aHA100I4@`401`D40@08aPD0`0;1@@40863PQl0O7in5P3oool001@0oooo5`1l
OWh407b3PP@0PHR7101B?SD303LT6`@0=2@O100e:BD403d]:0@0;AlJ100]8Ad4034Q6@<0<2lZ100h
<bX404Lf;P@0Ie17101fJEd407aYH@<0O6eU301lK64407a]I@L0N6EH101cIEP407QXFP@0M5a;101_
FDT407ALB`@0M5a<0`1dH58407EHB`@0KeQ;101dFdX4071DA`@0Jdm30`1[C40406=?@`@0FdLj101C
?Bl403TU8@@0;1XF100L510301P@30@05a0@100C2``400/720@040X;100/8Al301`?3R<0O7in5P3o
ool001@0oooo5`1lOWh407b3PP@0PHR7101B?SD303LT6`@0=2@O100e:BD403d]:0@0;AlJ100]8Ad4
034Q6@<0<2lZ100h<bX404Lf;P@0Ie17101fJEd407aYH@<0O6eU301lK64407a]I@L0N6EH101cIEP4
07QXFP@0M5a;101_FDT407ALB`@0M5a<0`1dH58407EHB`@0KeQ;101dFdX4071DA`@0Jdm30`1[C404
06=?@`@0FdLj101C?Bl403TU8@@0;1XF100L510301P@30@05a0@100C2``400/720@040X;100/8Al3
01`?3R<0O7in5P3oool001@0oooo5`1lOWh407b3PP@0PHR7101B?SD303LT6`@0=2@O100e:BD403d]
:0@0;AlJ100]8Ad4034Q6@<0<2lZ100h<bX404Lf;P@0Ie17101fJEd407aYH@<0O6eU301lK64407a]
I@L0N6EH101cIEP407QXFP@0M5a;101_FDT407ALB`@0M5a<0`1dH58407EHB`@0KeQ;101dFdX4071D
A`@0Jdm30`1[C40406=?@`@0FdLj101C?Bl403TU8@@0;1XF100L510301P@30@05a0@100C2``400/7
20@040X;100/8Al301`?3R<0O7in5P3oool001@0oooo5`1lOWh407b3PP@0PHR7101B?SD303LT6`@0
=2@O100e:BD403d]:0@0;AlJ100]8Ad4034Q6@<0<2lZ100h<bX404Lf;P@0Ie17101fJEd407aYH@<0
O6eU301lK64407a]I@L0N6EH101cIEP407QXFP@0M5a;101_FDT407ALB`@0M5a<0`1dH58407EHB`@0
KeQ;101dFdX4071DA`@0Jdm30`1[C40406=?@`@0FdLj101C?Bl403TU8@@0;1XF100L510301P@30@0
5a0@100C2``400/720@040X;100/8Al301`?3R<0O7in5P3oool001@0oooo7`1lOWh406]>A`<0<B<J
100e:28403DY9@@0;b<N100[6QD402lN5`@0<BDQ0`0_:2<403<V80@0<RXV101MAcl407IYF0@0O6eL
0`1lJEd407aYG0P0O6UH101lKF04085aJ0<0OFeN101hG54407AHB`@0M5E;101dED`407AIDP@0M5a?
0`1dE4L407EEB0P0KeA7101`E4L406]CA@<0Id/n101OA3P405<j;@@0>BDQ100a8AT402@F4@@07Q@@
0`0R5A4401XA40@05@`<100F30`402TI50@0JG9b0`21Ph8S07anOQH0oooo000D0?oooal0O7in101[
CTL3034S6P@0=BPR100e:BD402lS7P@0:aXE100_7QL4034U8@<0;bPS100c9R04038Z9P@0GDLo101f
JEP407a]G0<0O6UM101lJE`807aYF0@0O6eP1021LFP307e]GP@0N5aA101dF4/407AEB`@0M5E<101d
FE8407ALC`<0M5A7101eEDP806mDA`@0L5A7101[DdD306M;?P@0Gd@h101C>Rd403TU8@@0<B4I100T
5Q4401hD40<08QDA100J4A0401D<30@05P`<100Y6A@406UbLP<0PH>28`1lOWhF0?ooo`00503ooolO
07anOP@0Jdi70`0a8aX403DX8P@0=BTU100_8ah402/J5@@0;ahG100a9B4302lX8`@0<bHP100b:RH4
05e7?`@0MVUH101lKE`307aYG@@0O6UL201lJEP407a]H0@0PG5X0`1mKEh407QLD@@0M5Q;101dED/4
07AEC0@0M5UB101dG4l307ADA`@0MEE8201_E4L4071DA`@0Je=50`1WBch405m4>0@0DcX]100i9B44
034Q6@@091HA100N5103028E4@@06Q4@100E30`401H<30@0:ATD101YLW830863PR<0O7in5P3oool0
01@0oooo7`1lOWh406]>A`<0<B<J100e:28403DY9@@0;b<N100[6QD402lN5`@0<BDQ0`0_:2<403<V
80@0<RXV101MAcl407IYF0@0O6eL0`1lJEd407aYG0P0O6UH101lKF04085aJ0<0OFeN101hG54407AH
B`@0M5E;101dED`407AIDP@0M5a?0`1dE4L407EEB0P0KeA7101`E4L406]CA@<0Id/n101OA3P405<j
;@@0>BDQ100a8AT402@F4@@07Q@@0`0R5A4401XA40@05@`<100F30`402TI50@0JG9b0`21Ph8S07an
OQH0oooo000D0?oooal0O7in101iJV8303d^:P@0;b@P100g:2@403PT6P@0<B@N100W7AT402dR7`<0
9adJ100Y9R@402TZ9@@0?blV101RD4<407=UF0<0MVUH201lKF0407QYG0@0LfEE101fJE`307eXFP@0
M5Q;101dG4/406mGA`@0JUE5101ZEDP406iEB0<0KeM:101_DD@406m?A`@0Je17101[E4<406M??P<0
Hd/n101OASP404D]90@0=R<I100Q510401P@30@05a0@0`0N510401XA40@04@P8100C2`/401lF4`@0
1P009P1lOWhF0?ooo`00503ooolO07anOP@0NFYR0`0m;RX402lT80@0=bPT100h91X4034T7P@09adI
100]8Ql302LM6P@0:BHT100Y:RD403l_9P@0HU13101cIEP307IYF0P0O6eP101hJE`407=UE@@0MVUL
0`1mJ5X407AHB`@0M5a;101_EdL406YEA@@0JUE8101^EDP306mGBP@0Ke54101_CdL406]@A`@0JeA3
101WCch306=;?P@0GdHh1015;B@403HS6@@08A@@100H40`401L@40<07Q@@100J4A04014820@04`/;
100O5Q<400H002H0O7in5P3oool001@0oooo7`1lOWh407UZHP<0?BhZ100_920403LX90@0>2@J100a
91h402LM6@@0;B8O0`0W7AX402TV90@0:BXU100o;bH4069@@`@0LfEH0`1fJEP807a]H0@0N6UL101c
IED407IYG0<0OFQJ101dF4/407ALB`@0KeM7101ZEDD406YEB0@0KUE80`1_EdX406mAA0@0Kdm7101[
D4L406]D@`@0Idln0`1SBch405m6>0@0ABdT100f8aT4024D40@0610<100G410301hD40@06Q4@100A
20P401<;2`@07aHC1006000V07anOQH0oooo000D0?oooal0O7in101iJV8303d^:P@0;b@P100g:2@4
03PT6P@0<B@N100W7AT402dR7`<09adJ100Y9R@402TZ9@@0?blV101RD4<407=UF0<0MVUH201lKF04
07QYG0@0LfEE101fJE`307eXFP@0M5Q;101dG4/406mGA`@0JUE5101ZEDP406iEB0<0KeM:101_DD@4
06m?A`@0Je17101[E4<406M??P<0Hd/n101OASP404D]90@0=R<I100Q510401P@30@05a0@0`0N5104
01XA40@04@P8100C2`/401lF4`@01P009P1lOWhF0?ooo`00503ooolO07anOP@0Kf1C0`11<R/403P[
9`@0;bDQ100a9b@402LJ6P@09a`I100Y7QX303DY9@@0<B4I100T71L402LU8`@0A3H^101TBT0306eE
BP@0LeeA101cHED407QYG0@0N6EH101cGE4307ATE`@0Ke]=101ZCD@406mDA`@0Kda0101_CD8406YA
A0<0KeA7101[Cd<406I?@0@0IdPl101OAC`405M7>P<0BcP/101;<RH403PU6P@08A@@100L510401TA
30@050`;0`0A2`/400/71`@02`P8100U61@4034M50@05`T49P1lOWhF0?ooo`00503ooolO07anOP@0
Kf1C0`11<R/403P[9`@0;bDQ100a9b@402LJ6P@09a`I100Y7QX303DY9@@0<B4I100T71L402LU8`@0
A3H^101TBT0306eEBP@0LeeA101cHED407QYG0@0N6EH101cGE4307ATE`@0Ke]=101ZCD@406mDA`@0
Kda0101_CD8406YAA0<0KeA7101[Cd<406I?@0@0IdPl101OAC`405M7>P<0BcP/101;<RH403PU6P@0
8A@@100L510401TA30@050`;0`0A2`/400/71`@02`P8100U61@4034M50@05`T49P1lOWhF0?ooo`00
503ooolO07anOP@0Kf1C0`11<R/403P[9`@0;bDQ100a9b@402LJ6P@09a`I100Y7QX303DY9@@0<B4I
100T71L402LU8`@0A3H^101TBT0306eEBP@0LeeA101cHED407QYG0@0N6EH101cGE4307ATE`@0Ke]=
101ZCD@406mDA`@0Kda0101_CD8406YAA0<0KeA7101[Cd<406I?@0@0IdPl101OAC`405M7>P<0BcP/
101;<RH403PU6P@08A@@100L510401TA30@050`;0`0A2`/400/71`@02`P8100U61@4034M50@05`T4
9P1lOWhF0?ooo`00503ooolO07anOP@0Kf1C0`11<R/403P[9`@0;bDQ100a9b@402LJ6P@09a`I100Y
7QX303DY9@@0<B4I100T71L402LU8`@0A3H^101TBT0306eEBP@0LeeA101cHED407QYG0@0N6EH101c
GE4307ATE`@0Ke]=101ZCD@406mDA`@0Kda0101_CD8406YAA0<0KeA7101[Cd<406I?@0@0IdPl101O
AC`405M7>P<0BcP/101;<RH403PU6P@08A@@100L510401TA30@050`;0`0A2`/400/71`@02`P8100U
61@4034M50@05`T49P1lOWhF0?ooo`00503ooolO07anOP@0Y9jZ0`1I?c/403PY9@@0=2LR100i;RT4
03dX70@0;AXD100c9R8302dQ7@@0<bTW100W7QX401hP7P@08B8N100Y9B4304`h<@@0HDXo101PBT@4
06EAC@@0IEE<101YF4d306]DA`@0Ed<f1019>2h405@l;P@0HTTk101VC40406I4>0<0ITHk101[CcX4
06M;>@@0HdLj101O@3@405Y0=0<0BC4X100d7QP402`I50@091DA100I40`801@<30<040P8100<20P4
01@<30@06A8?101RKG4407IdM2H0O7in5P3oool001@0oooo7`1lOWh40:BNZP<0FClk100h:BD403@W
8P@0>BhY100m:1`402dJ50@0<bHR0`0]8Ad403<Y9`@09ahJ100N81h4024R7P@0:BDQ0`1<>344065:
?`@0H4Y4101UDDd406EEC0@0JEQ=0`1[E4L405M3=P@0BCP^101D?2h40699>`@0ITa0101VA3P306I6
>`@0Jdlj101WBcT406=7>P@0Gd0d101J@3@304Ta:0@0=1hH100/6A@402@E4@@06A0<200D30`30108
20@030P8100D30`401TB3`@0HVea101fM7@V07anOQH0oooo000D0?oooal0O7in102TWZX305To>`@0
>2TU100d9b8403T^:@@0?BPL100]6Q@403<V8P<0;B4M100c:BL402LN6P@07R0N100Q8Qh402TU8@<0
C3Pa101QBSl4061:A0@0IE5=101UED`406UHC@<0JeA7101G@cH404Th;P@0E3`^101RBC/406I<@0@0
IT@h0`1VAS/406]?>P@0Id/i101SAcX405m0=0@0FT0d0`19<BP403@N60@0;1TD100T5A4401T@30P0
50`<0`0@20P400`820@050`<100I4Pl4069]L@@0MWAd9P1lOWhF0?ooo`00503ooolO07anOP@0Y9jZ
0`1I?c/403PY9@@0=2LR100i;RT403dX70@0;AXD100c9R8302dQ7@@0<bTW100W7QX401hP7P@08B8N
100Y9B4304`h<@@0HDXo101PBT@406EAC@@0IEE<101YF4d306]DA`@0Ed<f1019>2h405@l;P@0HTTk
101VC40406I4>0<0ITHk101[CcX406M;>@@0HdLj101O@3@405Y0=0<0BC4X100d7QP402`I50@091DA
100I40`801@<30<040P8100<20P401@<30@06A8?101RKG4407IdM2H0O7in5P3oool001@0oooo7`1l
OWh409RRVP<0LV9C100c9Al402lT80@0;B8O100Y8al402DK6P@0:1`F0`0d9B0403L/:0@0?c0[100]
8R0402lX9P@0;2XV0`0[8a`4038Z9`@0:BPT100]:1l403h`:0@0@SH/0`10<b`404<b:0@0?2`Q100h
;b<4048_8`@0CCHX101IA38305Xn<0@0Bc@/101:<BH4058g;0@0BcP`100o:R@303TQ6@@0;ATD100R
510401P@30@050`<100@20P400/71`<02`P8100<20P401XD40@09aTD100A3PhZ07anOQH0oooo000D
0?oooal0O7in102HXYX3079RD`@0<bDO100_920402dR7`@0:B<O100U6aX402PL5P<0=2DP100g;2P4
03l`:`@0;B8P100_:2H402`Z9P<0:b<L100b:RL402TX90@0;BPO100n<2P4048f;0<0@3</1013<RP4
03`/8@@0>2lS1012;b<404df:0@0FD@b0`1J?S0404/d;0@0BS4V101B=b`404/h<0@0?bXT0`0i8AT4
02dI50@08Q@@100H40`401@<30@040P8100;1`L300/820@030P8100J510402LI50@04@h>:P1lOWhF
0?ooo`00503ooolO07anOP@0V::J0`1bHU<403<U7`@0;b@P100]8Ql402TS7`@09A/J100X71H303@U
80@0=b`X100o<2/402dR80@0;bPV100/:RH302/S70@0<RXW100Y:2@402dX7`@0?S0X1012=R`3040c
;0@0@c8X100l;24403P_8`@0@RlS101==RP405U4<P<0FSh`101;=2`404Xa9P@0DSL/101;>30403lZ
90<0>B4I100]6A@4028D40@0610<100D30`4010820@02`L70`0;20P400`820@06Q@@100W6A@4014>
3RX0O7in5P3oool001@0oooo8`1lOWh308j6T@@0B3Hb100e:BD403@[9`@0=RPT100P5a84028M6P<0
=b`X100i;RT4040d;`@0ASPc1015>Bl403lh;`<0=C8[100a9R44034O6@@0:AhL100Z71T403<T80<0
=2HR100/92@403HV8@@0=R<J100`8a`403DY8`@0>2dT0`0l;24404<b9P@0?2`P100f:R<403`V7`@0
=b@L0`0Y6QD402LM6@@06Q8=100H40`401D<30@04@P81`0<20P4024D40@06A0@1017@T0404Tl>RX0
O7in5P3oool001@0oooo8`1lOWh308j6T@@0B3Hb100e:BD403@[9`@0=RPT100P5a84028M6P<0=b`X
100i;RT4040d;`@0ASPc1015>Bl403lh;`<0=C8[100a9R44034O6@@0:AhL100Z71T403<T80<0=2HR
100/92@403HV8@@0=R<J100`8a`403DY8`@0>2dT0`0l;24404<b9P@0?2`P100f:R<403`V7`@0=b@L
0`0Y6QD402LM6@@06Q8=100H40`401D<30@04@P81`0<20P4024D40@06A0@1017@T0404Tl>RX0O7in
5P3oool001@0oooo8`1lOWh308j6T@@0B3Hb100e:BD403@[9`@0=RPT100P5a84028M6P<0=b`X100i
;RT4040d;`@0ASPc1015>Bl403lh;`<0=C8[100a9R44034O6@@0:AhL100Z71T403<T80<0=2HR100/
92@403HV8@@0=R<J100`8a`403DY8`@0>2dT0`0l;24404<b9P@0?2`P100f:R<403`V7`@0=b@L0`0Y
6QD402LM6@@06Q8=100H40`401D<30@04@P81`0<20P4024D40@06A0@1017@T0404Tl>RX0O7in5P3o
ool001@0oooo8`1lOWh308j6T@@0B3Hb100e:BD403@[9`@0=RPT100P5a84028M6P<0=b`X100i;RT4
040d;`@0ASPc1015>Bl403lh;`<0=C8[100a9R44034O6@@0:AhL100Z71T403<T80<0=2HR100/92@4
03HV8@@0=R<J100`8a`403DY8`@0>2dT0`0l;24404<b9P@0?2`P100f:R<403`V7`@0=b@L0`0Y6QD4
02LM6@@06Q8=100H40`401D<30@04@P81`0<20P4024D40@06A0@1017@T0404Tl>RX0O7in5P3oool0
01@0oooo8`1lOWh30:>SX`@0HdQ2100d9B44034T80@0<BDQ100m:bH403P[9`<0=b`X100m<Rd403DY
9@@0<BHR100a8Al403`S7@<0?28J100a91l402DM6P@0:28O100Q61@4024L6`<0;B@P100Y81`401lG
50@07APG100M5Q<401XB40@07aPD0`0T71H4028K5@@08aHC100P4Q0401lE4P@08AHC0`0L510401D?
2`@050`<100C2``401@<30P030P80`0Q51T4024D4P@0=RLQ1019EEL^07anOQH0oooo000D0?ooob<0
O7in0`2SXj<406=8@P@0=2DQ100a9204034U8@@0?B/V100h:bL303L/:0@0?C8]100e:BD4034V8P@0
<B4O100l8ad303`R6P@0<B@O100U7AX402PR7`@08APD100Q71/302dT80@0:B0L100O5a@401dH5`@0
7AHC100J4Q0401lH50<091`F100R6aD402<F4`@0818@100O5A84024F4`<071@@100E3`/401@<30@0
4`/<100D30`800`820<08A@I100Q518403HW8@@0BEEG;P1lOWhF0?ooo`00503ooolS07anOP<0Xj>S
101SB48403@U8@@0<B@P100a9B4403d[9P@0>2/W0`0g;2P403db;@@0=BTU100a9R84034Q7`@0?2<M
0`0l8QX4034T7`@09AdJ100X8Ql4024H50@08A`K0`0]920402TP70@07aLD100M61L401dF4`@06Q8@
100O61@302@L5P@08Q/E100S5Q<4020B40@07aDB100Q5Q<301`D40@05@l;100D30`401<;30@050`<
200<20P3024D6@@08A@B100f9b4404UEEbh0O7in5P3oool001@0oooo8`1lOWh30:>SX`@0HdQ2100d
9B44034T80@0<BDQ100m:bH403P[9`<0=b`X100m<Rd403DY9@@0<BHR100a8Al403`S7@<0?28J100a
91l402DM6P@0:28O100Q61@4024L6`<0;B@P100Y81`401lG50@07APG100M5Q<401XB40@07aPD0`0T
71H4028K5@@08aHC100P4Q0401lE4P@08AHC0`0L510401D?2`@050`<100C2``401@<30P030P80`0Q
51T4024D4P@0=RLQ1019EEL^07anOQH0oooo000D0?ooob<0O7in0`27SHL409fHV0@0B3Ha100a9B44
03DY9@@0=2LR100k<2`302lS7P@0;bHS100_8ah4030V8P@0?c@[100e;BP302lW90@0<BDQ100a91l4
03LX90@0;1dL100S7AX302DH50@09aLC100Q510401XC3`@071@@100S61@402DG50<07Q<@100K4Pl4
01`D40@08aPD100Q510401hD40<06A0<100H40`401D<30@050`<200<20P401@<30<08aXF100/6aH4
071_Kc80O7in5P3oool001@0oooo8`1lOWh308N=Q`@0WIRH1018=S44034U8@@0=BTU100d9b8403/`
;0<0;b<N100_9R<402lS7P@0<2HR100o=2/403D]:0<0;bLT100a9B44034T7`@0=bPT100/7A`402<M
6P<09APD100W5a<4024D40@06Q<?100L510402<H50@09ALD0`0N4a0401/B3`@071@@100S61@4024D
40@07Q@@0`0I40`401P@30@05@`<100D30`800`820@050`<0`0S6QH402`K5P@0L6m_<P1lOWhF0?oo
o`00503ooolS07anOP<0Qhf7102MV9P404Pf<@@0<BDQ100e:BD403@W8P@0>c0/0`0_8ah402lV8`@0
;b<N100`9R8403ld:`@0=BdX0`0_9b@4034U8@@0<B@O100g:2@402`M70@08adJ0`0U61@402LG4`@0
8A@@100J4`l401`D40@08aPD100U5a@301hC40@06a8?100L510402<H50@08A@@100N510301T@30@0
610<100E30`401@<30P030P8100D30`302<J5P@0;1/F101`Kflb07anOQH0oooo000D0?ooob<0O7in
0`27SHL409fHV0@0B3Ha100a9B4403DY9@@0=2LR100k<2`302lS7P@0;bHS100_8ah4030V8P@0?c@[
100e;BP302lW90@0<BDQ100a91l403LX90@0;1dL100S7AX302DH50@09aLC100Q510401XC3`@071@@
100S61@402DG50<07Q<@100K4Pl401`D40@08aPD100Q510401hD40<06A0<100H40`401D<30@050`<
200<20P401@<30<08aXF100/6aH4071_Kc80O7in5P3oool001@0oooo9P1lOWh409RCU`@0HChh100j
:BD403DY9@@0=2LR100S7AT303L^:@@0?C8]100j<2/402/Q7@@0;1lI100[71L302TN6P@0:b0K100Q
6Ad401hL6P@09Q/I100W5a@3024D6@@06Q@A100K510401P@30@06Q@@200H510301L@30@04P/;100E
3`/401/C3`@0610<100B2`/301L@30@0610@100E30`400`820@050`<100O5A4402`O6P<0:ATD>P1l
OWhF0?ooo`00503ooolV07anOP@0V9>G101Q?SP403XY9@@0=BTU100d9b8402<M6@<0=bhY100m<Rd4
03X`:`@0:b4M100/7aT402/L5`<0:AhJ100[81/4024I7@@07Q`J100V6aT402LG50<08A@I100J5144
01/D40@0610<100J510801PD40<05a0<100B2`/401D?2`@06a<?100H40`4018;2`<05a0<100H4104
01D<30@030P8100D30`401lE4@@0;1lJ0`0Y6A@j07anOQH0oooo000D0?ooobH0O7in102HTiL4064n
>0@0>RTU100e:BD403@W8P@08adI0`0g;RT403db;@@0>S0[100[8Ad402`O6@@0:a`G0`0Y7QX402/P
6`@08ATM100N71X402HK6@@09aLD0`0Q51T401XD4@@06a@@100H40`401XD40P061@@0`0G40`4018;
2`@05@l;100K4`l401P@30@04P/;0`0G40`401P@40@05@`<100<20P401@<30@07aDA100/7aX302TI
53X0O7in5P3oool001@0oooo9P1lOWh409RCU`@0HChh100j:BD403DY9@@0=2LR100S7AT303L^:@@0
?C8]100j<2/402/Q7@@0;1lI100[71L302TN6P@0:b0K100Q6Ad401hL6P@09Q/I100W5a@3024D6@@0
6Q@A100K510401P@30@06Q@@200H510301L@30@04P/;100E3`/401/C3`@0610<100B2`/301L@30@0
610@100E30`400`820@050`<100O5A4402`O6P<0:ATD>P1lOWhF0?ooo`00503ooolV07anOP@0SINA
1020Lf`403d]:0@0<bPT100d9b8403X[9`<0;bPT100^9R8402lQ7@@0:AdI100Q6QP4024D40<09adI
100U6AT402HI60@07a<@100O51L401H@4@<04P/;100F3a0401L@40@050`<100F3a0401<;30@05Pl@
0`0D30`401P@40@071@A100G410401@<30@030P82`0:1`L401P@40@06A4<100C2`/401T>2P<0KFe/
101fM7@f07anOQH0oooo000D0?ooobH0O7in102=Ui44081cK0@0?BdX100c:2@403@W8P@0>R/W0`0_
:2@402hV8P@0;b4M100Y7AT4024J60@08A@@0`0W7AT402DI6@@09QTH100O4a0401lD5`@05Q0A0`0B
2`/401H?40@05a0@100D30`401H?40@04`/<100F3a0301@<30@0610@100L514401L@40@050`<100<
20P;00X71`@0610@100I4@`401<;2`@06@h:0`1]KF`407IdM3H0O7in5P3oool001@0oooo9P1lOWh4
08fGT@@0P7=/100m;BP403<X90@0=2LR100j:bL302lX90@0;RHR100_8Ad402TM6@@08AXH100Q5103
02LM6@@09ATI100V6AP401lC40@07a@G100F4143018;2`@05Pl@100G410401@<30@05Pl@100C2``4
01H?40<050`<100H410401`D4@@05a0@100D30`400`820/02PL7100H410401TA30@04`/;100I3PX3
06e]K0@0MWAd=P1lOWhF0?ooo`00503ooolV07anOP@0SINA1020Lf`403d]:0@0<bPT100d9b8403X[
9`<0;bPT100^9R8402lQ7@@0:AdI100Q6QP4024D40<09adI100U6AT402HI60@07a<@100O51L401H@
4@<04P/;100F3a0401L@40@050`<100F3a0401<;30@05Pl@0`0D30`401P@40@071@A100G410401@<
30@030P82`0:1`L401P@40@06A4<100C2`/401T>2P<0KFe/101fM7@f07anOQH0oooo000D0?ooobX0
O7in102ob//408McK0@0=bPR100_920402lX90<0<BTU100g;RT403PZ:P@0;A/G100Y71P401lF4P<0
6a8>100K50l401hD3`@050`<100A2`X401L@40<06A4A100D30`401L@40@05@`<100G410401D<30@0
9aLD0`0>2@P401D?3`@06a@@100I4A0800`820<040P8100I410401`B4P@0610@100Y6AD403dU6P@0
HT@c0`19=bXj07anOQH0oooo000D0?ooobX0O7in102ob//408McK0@0=bPR100_920402lX90<0<BTU
100g;RT403PZ:P@0;A/G100Y71P401lF4P<06a8>100K50l401hD3`@050`<100A2`X401L@40<06A4A
100D30`401L@40@05@`<100G410401D<30@09aLD0`0>2@P401D?3`@06a@@100I4A0800`820<040P8
100I410401`B4P@0610@100Y6AD403dU6P@0HT@c0`19=bXj07anOQH0oooo000D0?ooobX0O7in102o
b//408McK0@0=bPR100_920402lX90<0<BTU100g;RT403PZ:P@0;A/G100Y71P401lF4P<06a8>100K
50l401hD3`@050`<100A2`X401L@40<06A4A100D30`401L@40@05@`<100G410401D<30@09aLD0`0>
2@P401D?3`@06a@@100I4A0800`820<040P8100I410401`B4P@0610@100Y6AD403dU6P@0HT@c0`19
=bXj07anOQH0oooo000D0?ooobh0O7in102ob//408Y^I`@0?c8/100]8Ad303LZ9P@0>BhY100n<B/4
030X8P@0;B<N100W5a/301P@4P@07a@@100H410401dE4@@07aHA100I4A0701@<30@04`/;100D30`4
01<;2`@071@@100E410303<]=P@0=c<f100W6Ah401H<3@@06Q4A100P5Q83020G4P@06A4@100]8Ad4
038Q6`@0:AXE100o:R@406]_M3d0O7in5P3oool001@0oooo;P1lOWh40;o:b`@0RViW100o<R`402dQ
7@<0=bXV100i;RT403ha:`@0<2PR100]8ah402LG6`<0610B100O510401P@40@07ADA100O5Q4401TA
40L050`<100C2`/401@<30@04`/;100L510401D@40<0<bdf100g<cH402LI7P@05P`=100J4A44020F
4P<081LB100I4A0402dQ7@@0<R4K100Y6QD403lZ90@0Jfmd?@1lOWhF0?ooo`00503oool^07anOP@0
_l[;102:KVL403lb;0@0;B4M0`0g:RH403T^:@@0?S4[100`:28402dS7P@09aLK0`0H418401lD40@0
610@100M5A4401lF4@@06A4@1`0D30`401<;2`@050`<100C2`/401`D40@05A0@0`0c;CH403Lc=P@0
9aTN100F30d401XA4@@081HB0`0P5a8401TA40@0;B4M100b8A/402TJ5@@0?bXT101[Kg@m07anOQH0
oooo000D0?ooobh0O7in102ob//408Y^I`@0?c8/100]8Ad303LZ9P@0>BhY100n<B/4030X8P@0;B<N
100W5a/301P@4P@07a@@100H410401dE4@@07aHA100I4A0701@<30@04`/;100D30`401<;2`@071@@
100E410303<]=P@0=c<f100W6Ah401H<3@@06Q4A100P5Q83020G4P@06A4@100]8Ad4038Q6`@0:AXE
100o:R@406]_M3d0O7in5P3oool001@0oooo<P1lOWh40<KFe`@0RVaT101<>C<302dQ7@@0:RDQ100h
<2`404He<0@0>2DK100`81T3024G4P@05a0@100D30`401H?2`@05a0@1`0D30`401P@40@05@`<100H
410401D<30@04P/;100[:2P302TM8P@0>b`/101A@3H404Pc<@@0BCLa100k:B<3024G4P@0:ahI100W
6aP403DY9@@0Bc0V101fMGD407aiNCd0O7in5P3oool001@0oooo<P1lOWh40<KFe`@0RVaT101<>C<3
02dQ7@@0:RDQ100h<2`404He<0@0>2DK100`81T3024G4P@05a0@100D30`401H?2`@05a0@1`0D30`4
01P@40@05@`<100H410401D<30@04P/;100[:2P302TM8P@0>b`/101A@3H404Pc<@@0BCLa100k:B<3
024G4P@0:ahI100W6aP403DY9@@0Bc0V101fMGD407aiNCd0O7in5P3oool001@0oooo<P1lOWh40<KF
e`@0RVaT101<>C<302dQ7@@0:RDQ100h<2`404He<0@0>2DK100`81T3024G4P@05a0@100D30`401H?
2`@05a0@1`0D30`401P@40@05@`<100H410401D<30@04P/;100[:2P302TM8P@0>b`/101A@3H404Pc
<@@0BCLa100k:B<3024G4P@0:ahI100W6aP403DY9@@0Bc0V101fMGD407aiNCd0O7in5P3oool001@0
oooo<P1lOWh40<KFe`@0RVaT101<>C<302dQ7@@0:RDQ100h<2`404He<0@0>2DK100`81T3024G4P@0
5a0@100D30`401H?2`@05a0@1`0D30`401P@40@05@`<100H410401D<30@04P/;100[:2P302TM8P@0
>b`/101A@3H404Pc<@@0BCLa100k:B<3024G4P@0:ahI100W6aP403DY9@@0Bc0V101fMGD407aiNCd0
O7in5P3oool001@0oooo<P1lOWh407IiN@@0_lo@101iFDX304hj<`@0?2dX100h;RX4040d;`@0ASXf
100b8ad302hO6P@0>RXT100f:B8402LH4`@07aD@100J4Q4301TA4@P050`<100K51L401XB4P@07ADA
100D3@`3024M5`@09QlL100E3Ph401@@3@@04`l<100D3Ph301lD40@09AXG100a8AT404/b90@0OWIe
101[JVm107anOQH0oooo000D0?oooc80O7in101fNGT40;o?d0@0NEU:0`1>>S<403`]:0@0>2hZ1010
=2l404Hj=P@0<R<M0`0^7aX403XZ90@0=RTR100W61<401lE40@06Q8A0`0I4A4801@<30@06a@G100J
4Q8401dE4@@050d<0`0Q7AL402HO70@05@h>100D40d401<?30@050h>0`0O510402DJ5`@0<B4I101;
<R@407ifM@@0JfY_@@1lOWhF0?ooo`00503ooolb07anOP@0MWUi102ocm0407UIBP<0CSXc100l;BP4
03P^:P@0@3@_1016>SH4038S7@<0;QlJ100j:R@403HY8P@09aPC100O5A0401XB4@<06A4A200D30`4
01/D5`@06Q8B100M5A4401@=30<08AdG100V7a`401D>3P@0510=100C3``401@>3P<07a@@100U6QL4
034Q6@@0Bc8T101nMWD406]ZKd40O7in5P3oool001@0oooo<P1lOWh407IiN@@0_lo@101iFDX304hj
<`@0?2dX100h;RX4040d;`@0ASXf100b8ad302hO6P@0>RXT100f:B8402LH4`@07aD@100J4Q4301TA
4@P050`<100K51L401XB4P@07ADA100D3@`3024M5`@09QlL100E3Ph401@@3@@04`l<100D3Ph301lD
40@09AXG100a8AT404/b90@0OWIe101[JVm107anOQH0oooo000D0?ooocX0O7in1035fMl307IUE`@0
=BLP100/8al4040f<P@0CD<o101A@S`3038S7@@08ALG100W5a@403HW8P@0<RLQ100M4a8301@<30@0
8ATM100U724402/S7P@09adP100h:bT402DI7@<0=B`/100h:RT403l]:0@0?B/V100g9b4403d[9@<0
BCX`100m;BH405<m<@@0PWmn102=TXa507anOQH0oooo000D0?ooocX0O7in1035fMl307IUE`@0=BLP
100/8al4040f<P@0CD<o101A@S`3038S7@@08ALG100W5a@403HW8P@0<RLQ100M4a8301@<30@08ATM
100U724402/S7P@09adP100h:bT402DI7@<0=B`/100h:RT403l]:0@0?B/V100g9b4403d[9@<0BCX`
100m;BH405<m<@@0PWmn102=TXa507anOQH0oooo000D0?ooocX0O7in1035fMl307IUE`@0=BLP100/
8al4040f<P@0CD<o101A@S`3038S7@@08ALG100W5a@403HW8P@0<RLQ100M4a8301@<30@08ATM100U
724402/S7P@09adP100h:bT402DI7@<0=B`/100h:RT403l]:0@0?B/V100g9b4403d[9@<0BCX`100m
;BH405<m<@@0PWmn102=TXa507anOQH0oooo000D0?ooocX0O7in1035fMl307IUE`@0=BLP100/8al4
040f<P@0CD<o101A@S`3038S7@@08ALG100W5a@403HW8P@0<RLQ100M4a8301@<30@08ATM100U7244
02/S7P@09adP100h:bT402DI7@<0=B`/100h:RT403l]:0@0?B/V100g9b4403d[9@<0BCX`100m;BH4
05<m<@@0PWmn102=TXa507anOQH0oooo000D0?oooch0O7in0`35cmD40<RnaP@0HTm:100`9R8402lT
8@@0>cPl0`1FBdT4061=A@@0G5=<100m;Rh4034[;@@0Bd==0`1VF5D404Hc;`@0=BXa100d9b/404Tm
@`@0>Rl^100o;BD3038X9@@0?RdW100n9b8403hU7@@0?B/U1015=2/305Lj;@@0CRdP101JIFX407b3
PTT0O7in5P3oool001@0oooo?P1lOWh30<G?e@@0b;k6101RCdX4030V8P@0;b@Q100k>3`305I;B@@0
H4e5101LDd`403d^;P@0<B/]101;@dd306IHE@@0AS<_100e:S4403@W:`@0BCe3100j;bh403l]9@<0
<RPU100n;BL403hW8P@0?RDM100m:bD404Dd:`<0EcX]101>;B0405YUJP@0O8>2B@1lOWhF0?ooo`00
503oooln07anOP<0aLoE1038_/H4069?BP@0<2HR100_924403/h?0<0ET]9101PCDD405aCC0@0?Bh^
100a:bd404]3C@<0IUQE1016<bl403DZ<@@0=2L[1019?D<403X_;P@0?bdU0`0b:2D403h]9`@0?RLR
100n9Ad403d[9@@0AC@[0`1G>Rd404h]80@0FVEZ101lPh9907anOQH0oooo000D0?oooch0O7in0`35
cmD40<RnaP@0HTm:100`9R8402lT8@@0>cPl0`1FBdT4061=A@@0G5=<100m;Rh4034[;@@0Bd==0`1V
F5D404Hc;`@0=BXa100d9b/404Tm@`@0>Rl^100o;BD3038X9@@0?RdW100n9b8403hU7@@0?B/U1015
=2/305Lj;@@0CRdP101JIFX407b3PTT0O7in5P3oool001@0oooo@@1lOWh409:LUP@0dMWJ101lJW44
04Hh=P@0=Bh^0`10@TL4055;C@@0BD4o101FCDD405iAC@@0E4Hm0`19>SH404Hg<0@0ASH/100h:RP4
02LL5P@0;B8O100i;RT303DY9@@0?bTQ101=;bD4050f;@@0G3ld101;;B@304<h>`@0WZ:ZD@1lOWhF
0?ooo`00503ooom107anOP@0TYbF103AfMX407aZL@@0ASPf100e;Rh30412A`@0DD]=1019@Cl405I=
A@@0GU5=101DASd304Tj=P@0ASL`1016=R`403PZ:0@09a`F100]8Ql403T^:@<0=BTU100o:B4404d_
9@@0D3H]101L?c@404/]90<0@cPk102NXZYA07anOQH0oooo000D0?oood40O7in102BW9H40=7IfP@0
O6Ya1016>3H403D^;P<0@497101ABdd404U1?`@0ETe5101NDDd405A6?@<0BCXf1016=c0404Hf;0@0
>2XX100W71H402dR7`@0>BhY0`0e:BD403lY8@@0CBlU101@=Rd405`o=0@0BbdT0`13>3/409jRZU40
O7in5P3oool001@0oooo101lMGD407aiND40O7in1035clL40=7IfP@0cL?20`1SF6D405=8CP@0MFMd
101hIVh4069;A@@0DD4l0`1=@C`4069>C@@0ITi;101UD4P406eFC`@0H4/o101DASl306EABP@0DdTo
1016@SP403T]:0@0D4eE102^^lH30;C5`ED0O7in5P3oool001@0oooo101lMGD407aiND40O7in1035
clL40=7IfP@0cL?20`1SF6D405=8CP@0MFMd101hIVh4069;A@@0DD4l0`1=@C`4069>C@@0ITi;101U
D4P406eFC`@0H4/o101DASl306EABP@0DdTo1016@SP403T]:0@0D4eE102^^lH30;C5`ED0O7in5P3o
ool001@0oooo101lMGD407aiND40O7in1035clL40=7IfP@0cL?20`1SF6D405=8CP@0MFMd101hIVh4
069;A@@0DD4l0`1=@C`4069>C@@0ITi;101UD4P406eFC`@0H4/o101DASl306EABP@0DdTo1016@SP4
03T]:0@0D4eE102^^lH30;C5`ED0O7in5P3oool001@0oooo101lMGD407aiND40O7in1035clL40=7I
fP@0cL?20`1SF6D405=8CP@0MFMd101hIVh4069;A@@0DD4l0`1=@C`4069>C@@0ITi;101UD4P406eF
C`@0H4/o101DASl306EABP@0DdTo1016@SP403T]:0@0D4eE102^^lH30;C5`ED0O7in5P3oool001@0
oooo101lPh9=07anOP@0Qhf70`35b[d40:jk^0@0WJJJ102NXjd40:V__0@0YYj/0`1ZHG@404Y:F0@0
AT53101:?SX404<l>0@0CD4o1016>SH303T^9P@0?c8Z101fMG@40=KNg`@0V:JPG01lOWhF0?ooo`00
503oool407b3PTd0O7in1027SHL30<G:_@@0[[^h102MYYX409jS[@@0ZJnl102VWZ`306YQM0@0BTYH
1016@D<404Xn>P@0@c`h101=@Cl404Hj=P<0>BhV100o<RX407IeM0@0e]kO102HYZ1L07anOQH0oooo
000D0?ooo`@0O8>2C@1lOWh408N=Q`<0aLZm102^^kP409fVVP@0WZ>]102Y[k`40:JN[0<0JV5d101:
BUP404I1@`@0BShj1013?3P404e1?`@0ASXf0`0i;RH403lb:P@0MWEd103Fg]l409RVX5`0O7in5P3o
ool001@0oooo101lPh9=07anOP@0Qhf70`35b[d40:jk^0@0WJJJ102NXjd40:V__0@0YYj/0`1ZHG@4
04Y:F0@0AT53101:?SX404<l>0@0CD4o1016>SH303T^9P@0?c8Z101fMG@40=KNg`@0V:JPG01lOWhF
0?ooo`00503ooomP07anOP@0Qhf2101lPh8409:LT@L0^/2c102ob//40;o3a@@0_lG7102ob//40<G?
d0<0b]WO103:e=X407b3PV@0O7in5P3oool001@0ooooH01lOWh408N=PP@0O8>2102BW9470;[0/`@0
_l[;102o`lD40;o5a`@0_l[;1035cm030<[Ig`@0b]CJ101lPh9T07anOQH0oooo000D0?ooof00O7in
1027SH8407b3PP@0TYbA1`2j`;<40;o:b`@0_l?5102oaLL40;o:b`@0aLo@0`3:fMl40<[DfP@0O8>2
I01lOWhF0?ooo`00503ooomP07anOP@0Qhf2101lPh8409:LT@L0^/2c102ob//40;o3a@@0_lG7102o
b//40<G?d0<0b]WO103:e=X407b3PV@0O7in5P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool009/0oooo0T0000230?oo
o`00W@3oool00d000000oooo0?ooo`200?ooo`00M`3oool5@0000080oooo00=000000?ooo`3oool0
0P3oool00d000000oooo0?ooo`0;0?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000
003oool0oooo07X0oooo001i0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03
@000003ooom0000000/0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0
oooo@0000880oooo001i0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000
003ooom0000000/0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A000000?ooo`3o
oom00000PP3oool007T0oooo00=000000?ooo`3oool00P3oool01d000000oooo0?ooo`3ooom00000
0?oood000000303oool3@00000040?oood0000100000@00000<0oooo0d0000220?ooo`00N@3oool0
1d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000000>0?ooo`03@000
003oool0oooo08X0oooo001h0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo00`0oooo0T00002<0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(225) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807D78
79685C7F6C607F6C647F70687F6C647F70687F70687F70687F70687F6C63806C5F7B685B7C6355\
765B4F785B4D72574B72574B72574B72574B7256497353456E53446E53456E5344
664A3D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7B7B7F7A7A7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D82807C
7C6A607F6C5F7F6C627F70687F6C647F70687F6E637D6A5D7B6A5D7B665B7C6356755F52755D4F\
72574B7356496F554972574B72574B7255487255487353486E53456E53456E5C50
66544C7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7F7F7F79797F7A7A7F7F7F7F7A7A7F7D7D7F7B7B7F7A7A7F7B7B7F7A7A7F7D7D7F7D7D\
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7D7B76
7C6A5B7F6C647F6A607F70687F6C647F6C647D6C6378685D706156765C5278594D755B4F725D50\
725B4F755B4D6E53466E53466E53466E55486E53447053456E53466E534872594C
726E6B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F78787F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7F7F7F7A7A7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D827D78
7C685E7F6C627F6C647F6A627F6E667F6C61826E66886E64776C627C675D7F5D5576574B76574D\
76574F75534B7353486E53466E53466E53466E53486F55487055486E5346664A3D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F807C
7F6A5B7F6C5F7F6C627F6C647F6C647F6C667F6E647F706882706A7B6E5F80655E7B61567B5F52\
795B507B60557A534B724F4672564E70564B6F53466F51457355486F584C694F42
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7E7A
7F6C5F7F6C627F6C5F7F6C627F6C647F6E667F6C647F6C647F706882706A7F71637D685C7B6157\
7D635776594F7C605375574C725044755B536E564B6E53467053466F5B54725E55
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7A6A63756C67
7F6C627F6C5F7F6C617F6C607F6E667F6C647F70687F70687F6E667F70687F6C66826E627F6859\
7D61567D6155795C507A574D75564970504270564B6F5346705346685349796E6C
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7B7B7F7979\
7F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D5E4D4360615B726158
7F6C607F6C667F6C647F6C627F6C647F70687F6A607F6E647F6E667F6E667F6C617F6E637D675C\
7D61567B5D537C5F4F75564975574B7555487053466C584C75594C6C51447C7878
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7D7D\
7F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7870724E2A241E272B7C6A60
7F6E617F6E667F6E667F6E667F6A627F70687F706A7F6C627F6E637F655D7D5F58795D507B6355\
7B5F55796153785B51765B4C7555497056467053456B50446E5548694C3F7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F79797F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807E7E4F3527756A62413E3A7F6C64
7F6A607F6E667F6A627F6E667F6C647F6A627F6E667F70687D6A617B695B7D5F587C5F5274594D\
765B4F795B4C785C4E6F55487553467555497253457053466F5549684B3F7C7270
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D482F248279744A49467C6A607F6C60
7F6C647F6C647F6C617F6C627F6C647F6E667F6C647F6E668058537B4E4879454279443F76423E\
764E467555497555467252457051426F53457253467353446C4F416B493B6F5951
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D787070A798974442407F6E667F6C637F6C60
7F6C647F6A5F7F685D7F68597F6A607F6A627F67617F5F5B805E5779453D783B32733E39753F38\
733A3876463F6E4B416E5344704F426C51447253467553486F5244755246674537
75665F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D48342D3B403E796A5F7F6C5F7F6C617F6C60
7F6C617D6A5E7B61557C655A7F6A5E7F685C7D584F79453D7852496F3E316D5045705448763C32\
6B312775393270413A6E4C446E523D6B4F3E6F5345725346725548725044725549
6C4E427F78757F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D6F60609072643437367C6A607D685C7C69607F6E64
7F685E7F635275554672524B7C4C45571A0F56453C79524A7B4E4885747074433B6F45396B503C\
63483D5B35286030276C3D356B4F3E6F4D3D6F544673594B755648725549725346
69493C755F557F78757F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D533E37414647695A527F6C5F80695D795F547F6E66
7F6C62805745734C3C5218125B4B49988582594E4D7F7E7B7C6D6E7C6663838A7D856863847370\
6F5D555E3C323823164F2A2166453C6C504073524773594F7A5F4D755546725548
725448695149746B6E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7A75794E2D270E1D2479685A7F6C618273657C655A7F6C64
7C615477543D6634245E1C0F3A1A186C4E467B5D537C645C7F73697F6C617F665C755A517C6458\
886C62896E6072554C39251B48282166473A6D5043786052795F53785C4D725245
725044705140675D5B6A61627572787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D5E4D43341E186D57523130327C6A5D7F685B7F64577F685A7F6C5F
826759825D537B6E5D917767594C457B5450795B50744C4478524F784D4677493E6F322A733F38\
6A433A7B5648744840754E45361209482B276A4C43755B4D7C6352785849705749
6F5448755245786A6173686569636E7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7A73742E1D152617120F23276C5A547F6A5D7F675F7D645B7C665A7F655D
8265597149396C51487C6C647F7568826E688270687F6E667C73658463587B675A796151795749\
72453C764D45763C3372322665251A3917125936337156497C6152785A49735044
6C504472544849291D59534B71696E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D838082B69A947763563937347C6A607F6C5F7F6E5D82615D7C635C7F7361
82665B7D5A4D65473C7C665C7F70687F6E667F6A627F70687F676380655B7B5F537C5F53765B4C\
7658476B55447355467655487855466948415938306A5042795D4F785A49735545
6C514472544865473D25221F75706E7C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D887E70756C6C82756C7D685D7866597C6C5F7F6A607F73667F67647F6E66
8370637C62536F4A3E71574B7C69607F726A7F6E667F6C647F776980655B79584B79594B735846\
6F5245674E3C6A463A6A4B3A6A483A6C4C3A6A4E486D544576594D765546704F44
6B51416E51444729212227256C66697F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7D79797C79767D6859795D4E76645E72665F7C685E7F6E647F70687F6E667F726A
826B6680655B7C5C4D714E447961567F6E667F69627D61597C6C617F6859795E5073493D735145\
714C3D674B3C6A4C3D6B4B3B6C4E3A6A4637684B3D7355497556497654466E4F42
6E4F456F55482F1B180A13116963677F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
8279707C716C7F6659785D507B5B496F615F7F635C7F6C647F70687F70687F7068
7F776982685E7F655374514476584E7F6C647F776C8267647C6A62836D63795F537B5D4F724E42\
714F416A453A6A493B684B427250427355496E5245755649755548755548705044
6E4F416B51444222191613133836347F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7E7A7D6A5B79584572594D755C547C6A5D7F655E7F6C647F726C7F736C7F7068
7F706A7F7065826759765F4D7255477C685E7F6E637F6E647F6E66806E627A5C4F755649705346\
7355486E4F3C6C4839684A3E6E544A74574E795B4F785F5272594C705548705548
6E51466F584A9963454A281D2116124745447F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7570\
7C645A7642387853496349406F6C5D7F655D7F6C607F6C647F6E647F736C7F7068
7F70687D6A61806E607B665B7963567C6A5B7D655C7C63587F675F7F61557B5A4A704F426F4C3F\
6B4F3C6846396748396A4D426D5649755A507C5F5278594C725649755548705344
6F50426F5247785C4F835C497F61584747477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7574\
825B5379493E6E423B7152486F665E7F6E667F6E647F6C647F70687F70687F6E66
7F6E63806C617C685B7D645879685E7F6E6682756A7C65607F6E5E8261587658496F4C3F6A493C\
63453B6F4E3E6750456E5247735C50755D517C5F52785B4D725649725046754F48
6E50446F50487152406B4B3E664438827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F77727F7B6F\
826456774F3D6C473D6C564D7C6A5E7F6C647F726A7F6C647F6C647D6A5F7C6C5F
7F655F80645B7863567D605479665A7F6A607F6E647F6C647F6964825C507955476F4E416C4C3F\
684D416650416A504370584C785C50765D50795B4E78594C725346725042704F42
7051446C5246775C516E4E416043397570707F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7C7064715042\
6040305D3F345F483E6F5A507F6C607F6A627F6C647F6E637F6A5D806A5F786157
7965567B5D577B665B7B66597966587F6C647F6C627F6C647D70637F64587954466F4E416A4B3E\
6E4B40684F456E544973584D74594D795F53765F5278594C725B4D705548705044
6E4D456C52486F47356F4A3F704837664C477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D80695A522B1A\
4D2E253B25203C3432735F567F6C627F6C617F6C5F7F6C647F6E66826C647F7166
80655E765B5075544B745E527864587C6A5E7F6C647F6C6180675E7A5F52744E466C4B3D68483A\
664A3E6F52466C534572544973574D75534872574B7356496E53467055486E5245
6E4F446B4C426F5640623D2D6E4F43663A307F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7977857974884E3C\
42271C3F272125292C735F527D6A5D7C6A627F6C617A6353725B4F6D5143654B3E
684F456A4B456F4E466C4E4273584D7663587F6C647F6C66806B607D5D5274523E6A46396A4B3B\
62483B654A3E6550446850446C584A73584C6F544875594C7055486E53466E5245
6E4F446E4F46653D2F522A1C5A3B2C63382C7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7D746C7F695E37120C\
281611281B17172429755F547F6A5D7C685A7F6C61877061725749654C3D48362F
3627223B291D4B342C5B3124562A1F5D433A7C685E7F6C64806E627D5F52745141684F3B664535\
634C4172544772574B6C53466E4D446D524667524672574B7356496A5044655044
6851446E5146704635593124522F266030227F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D807E7E857E787D5C4C6A3A31\
2615112817130B1B227C685C7B6A5D7C685C7F6C5F82706688695B7D6157634134
331D172B1B153127234F3C3164493E5C413B79675B7F726C80736A7D62536F4B3D6341334D1A0E\
472F29634533614435563A2C5B45386A4D42614E406E53457055486F4F42654D41
634D446A4C40603A2F52362A563C34633228827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F79797F7A7A7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D3D19124544417F6153724132\
2E1D201F141105151C7866597F6C5F7B685B7B685B7C6A5E87756A735D4F966959
7E5E4D6347375A3B2C53493D624B3F7153497965597F6E648070677D625379513E6644376E4533\
442E2A47363216090935251F3B2D2637241A3E312C523A2A5D42326D4F41654D41
634F4168483B4E30233B2620463B33663F358582817F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F79797F78787F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D43251E3F261F16060338211B311B1E\
24161227181502151C7B685B79685E7D5C52725449725F5482706A82756C846960
78584C7A5D507255486A5043715C4D785B507963577F7068806D657D65587455446D4F3A6C4E3A\
6E493A7751422B18161C1611382420362620332A22553E3558473A6F4B3B684D41
6351425330283E261C35201831272163382C827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D593129322018301B162317141B0E0D\
2617142918140B181E7C66597B665885796E7A5F5563443663463A61493C584137
4F332A4A30245036295434285F493D745F547963587F6C61806D5E7D5F537457496C4638654F3A\
664C3A7358499E69545B493F5B3B2D5F3C2F4B3D3560483763483C6B5544705144
654F445030212E1A1632201831251C5923187F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D60382924110C1E1510211410261611\
1A13102B221E162125725F54826A5D7C6A5E88756E89776A73554B684B45685048
6F4E4163473D5F4437644C41634A4275635A7C6A607F656180685E7D615374534B5C3427522B20\
54403168513E6E5342755748785A496A50425E4A3D684F446E4F42654D44685141
68493A301E161E151131322D4C30234D1B117F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7B7B7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D6C47382E130D2313101D1410120808\
1F1310271F1C222A2A6353497C665A7F6C607F6E6682726C887E728E756A6F6C66
85756E7F6E6682756C72655C775F5479695D7D6C617B6E5F7D645B7F65587C69588462565B362F\
39201B32211846352C604A3E705345735542654F426C4E3F5F483A684B44684D44
533023321B14281F1B1B231E5D31213419134A4A497F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7F7F7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D5D453E31211B2415112214101C120C\
1C130F291F1C2A2E2C5D4D447963587F6C607F6C647F70687F726C7F75707F7570
7F736C7F726C7F736C7F726C8270657C685A8270657D685B7B63567D64577B645781675C8E6E60\
7B574F61413834241C301E163F2A2345332B4E372A4E372A63473E634B406C4C40
46231C2816112316161D0F0C3919114628231819187F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6C4C453E2B27231712211410231511\
2317172A201D2B2D2953453C725F547F6C5D7F6A607F6E667F6E647F726C7F7570
7F77747F726C7F75707F70687F726C7F6E637F6C5F806C5E7B66597B5F537B62567B64577F6156\
786355835F5077584A664B3D4E3A2D56372B544237654B40554139684B44644B3D
46241C2515111D141019110D2016133624201B1B1A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D69443535221933201B22151125110C\
2817132C1D172E2622433B3468554B7C6A5D7F6C607F6C647F726C7F70687F726C
7F75707F75707F75707F70687F6E637F6E667F6A5F8067597B62567B66597B5F537B61537C5D52\
7A5B4E785B4D76574975594C765A4C6E5346634B406E4B426B52446F493F5D3A2B
3E211A2515112918142015111D1310291B15201E1B6C66677F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D5D3E2F3828232F1F1A2C1A151B110C\
1F130F2013102C1F18332A2157453C79665A7F6C607F6C647F6F677F77747F7068
7F726C7F736C7F736C7F70687F70677F6C5D7D6A5E7D685B7B5F537B5F537B61557B5F537C5F52\
755B4D75574B755B4F6E55487255487053466A5245654F41654F4461483A412A23
21140E2518171911111B110C1108081F151227231F4D42427F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6C463734241E3627232C1E1A2E1A16\
211410281B172B2321342A263A352E725B517F6A5E7F6A627F6B627F726C7F7774
7F726C7F75707F70687F70687F706A7D6A5F7D6A5C7B61557B61557B5F53795F53765D50795D50\
785B4D72574B725549755B4D6E55487053466F5245684F426A4C3F593B303B1F19
2F1E1A160C0C1A11111108081910101B120F2724233B33307F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D634C453929243729253627232C1A16\
1C110C24161331201A402F263E342A654D437C66587F6C627F6A627F6B627F726C
7F75707F77747F736C7F70687F7068826E657D6A5C796456765D50785B517C5B50765B4E76574D\
78594D72574B7255487053467055486C4E40704F4265493C5E3F354C2D22351D17
1B110C1C1211150C0C19110C18100F2317142226275956557F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7B7B7D77775D433C322521352824352722271713\
2C1C18261B17281E1B362C244A3B325F463C7661567F6C607F6E667F6E667F6F67
7F75707F75707F75707F70687D6E627C685D8067597D61557B6155765D4F795B50765B4D75594C\
75594D7052486E53487053466E5346705446684D4166493B63403143281D301B15
2216111D14101E151119100C1C1410221713000000827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7F7F827F7F573D3536241C342420372925392924\
2A1C182D201C302018312D2944352B533F366F574D7C6A5E7F6A627F6E667F6E64
7F70687F70687F716A7D6A5F7D6A5E7866597D6759795D4E765B4D795D4E765B4D765D5078574B\
72594C7558497051466E50446E4F426A504466493C5D4133462A24361D18201611
1B110C191010150C0C0D0808130B0B29201D0C0707827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D6D4D4531221A38272235282431231E\
2D1A162F1F173124203328233D2B2340342C654C4479685A7F6C5F7F6A607F6C61
7F6C5F7F6C5F7F6E64826E657D6A5C7B6053795E5079594E76574C765950765B4D76564978574B\
7255487255487353466E52456C4C3F68483B5D4032462B253C251B281712201511
2115111A1110160C0C160C0C221613232F32504A497F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7B655E3B2A2631241F38282437241B\
30221D291C1830231E2C201C322925352D26503B316F5B4F7B685B7C6A5B7F6C61
7F6C5F7D6A5D7B68597C6A6080695B795D4F795D4E75564872554872554B73574B75584B755145\
7252487051467053446C4F406A4C3F6646394F31263F261B2616121C120C191010
1F14101B1110120808140B0B1F1513000000827F7F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D75605443312B372925312521352723\
291A192A1C192A1F1B3528243121192E211B3C312A58443970584C755E527B6457
7B66597D6A5D7B66597862567C6759785B4E725146755648724F427251456F5346755548705044\
6E50426F4A3F684B3F644B3C5A3D3058392B41281D2816122016111B110C150C0B
140B0C0D08080C08082116132A1A130904027F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D988C93503732382925352722382B27\
39251B2B19153125212E211C3529262B1E192C2521392E264B382E61493F705548
6F564D725B53725D52735D51765A4C684C3D5F42366445366B4D406E4D416E493C6E4B4070503D\
6C4C3D6A493C66443761443752352A41241A351C162616111B110C160C0C150C0C
1108080D0808140B0B19120F353B3D443D3B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8E8F8B6D574C35241F322521302420\
2E241F281A192B1D16352621352A263C2C282D221F362B27382E27422E244F3A34
4837304E3A2E5842385A45395A4137583B2E4C33264C362856372A5F40316448376641345D3C31\
5D3B2C5F3E32583C334E302745261C351B162716111B110C160C0C1108080C0808
0C08080C080819130F2317130004047C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8A7C8344302B342723342925\
352722211712261D1B362A25382B273F322D40332E3E332B3E352D3E322A3E2A23
3C261E3625213D261F463027432D273B2A27422A2240271C4029204830274C352851342652372A\
492F224830274A2C2240281F311B162D1D181D120D1A110C160C0C1108080D0808
0C08081D1310181010313231251E1D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D9690905C403C342521342521\
322622392824302622352A263D312C382A263729253825224028213F271E362721
2C1E1A30231F2A19162F211E3627222F221D2919152A1C182A1914291713312018342219312018\
311A152E18132C19152C191522161119100C170D0C150C0C150C0C0D08080C0808
1D13161D131030231E182629635C5A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8584818F8183412E29322521\
352824342622392E2A31231E35292633241F3427233D3129382A26362722352520
31231E3326222C1C1B271D1A2A19152B19152416111E1410211511271814291714231511211410\
2215112818142415112114101C110C19110C160C0C150C0C0C08080C0808140B0B
1F18152A19153435354747477F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D91888A5C3A35382824\
35282435272229201B3B2E2A392E2A3A2D292D211C32231C311F192E211C2E211C
251A1D251E1B2B1B1A2817142316191E14111E15111A110C1B14101B14101D14101B110C150C0C\
18100C1E13101B110C150C0C19100C191010160C0C0C0808150C0C1B1310241B17
251713414242413F3F7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D8889877A65613B2924\
3528243527223829252F272334282433241F2C1E1A271C18261611291E1A271919
281918211411221518191111160C0C191011191010160C0C181010150C0C181010160C0C191010\
1B1310181010160C0C0D08080C07080C08070C080818101017100C140B0B1C0F0B
3C3E3D3E3A3B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA4A3A46D5953\
352520322521312724342925372C283728272D1A162A1C182016111E130F1F1511
211410170C0C150C0B191011191111150C0C181010160C0C180F10160C0C2416130E0808160F0F\
1B13101A11100D08080C08081008081810101910101710102617143120183E3129
1F16107C78787F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA4A3A4\
6F554F392C272F221D362A27382C283E2F2A3025202D201C26161A191111211410
1911101E15111D1410191010150C0C150C0C140B0B150C0C140B0B1C141016101030272D2A2729\
23161A170C0C1A11111C14101C1410181010281E1B2B1D192618143827213E3D3D
60544E7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
A6A8A96F534D42322D2E211C3127233A302B42312C34231A2F1F19201611181010
160C0C18100C191010160C0C150C0C181010150C0C181010150C0C140B0B282423261B20372C2D\
4337313A2929372A2730221E201611281C17251A173427233E2A223E3D3D564A47
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7C7A7AA7A8A965473C47352F382925372D2A40332E42353131201B2D1E19312420
2D221E2215111E14101A1111191010150C0C150C0C1B13161A11111C1410160E0E27201B2A201F\
1C12121E15111B13101B1211231511251A163020183C2D23534E4C4A3F3F7F7A7A
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7DA7ABAE624D42372620312622413531483D394A3A342F1F1B251817
2B19153225212D221D1C1211150C0C20171B21181C261E1B241A1D2F252322171A2C2626342726\
3A29243124212F221D322520372E2734262140332B4A4744665C537570737F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7DA7A6A9897C7D4D3C38342723392B27413A3B4D403D493B36
463D3A3627263129293F373B463D3C3527262F252B2F23263D34373328283B2A242C25233F2C27\
3B26223B251D3929243D2F2746342B482B20343A3D6056507F7A7A7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D8B8C89A19B9F624F53413330382F2E403F444E4444
493E3B50453F4C403E443B364639384635303F312B3527282C1F1A342724392C283528243E2A22\
462D254831294E362E432B234437377366644D47447F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F79797F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7DA7A6A285828782777451475052474B
60565C61535656454050413D4E3F3B56454452413E55433D52423F4B3B33463A3552423E483C35\
4639313F2C27484141787275726D6960595A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D858481A19B9872757A
75726E827E877F7B827E70745E51594C454B4E4041503F3B483C3951403D483A3542332B48372F\
53514E8884825C5E5A6F686B7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D85847F79777D8B8984958F8E7F7D7D8282897F7B7B7F7A7A7F7D7D827F7F8282847F7A7A\
5354507F7A7A7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D
7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D7F7D7D\
7F7D7D7F7D7D7F7D7D
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH07mmO@@0P7eh101i
J5`407m/H0@0OfaT101oL6P307m/I100Og1X101oK6<4081/G`<0NfQK101lHeD407IKC`@0N5]=3`1b
Ed/4079FB@@0Le=5101^Dd@406iCA@@0KU=40`1VBSdD07mmO@<0OgQh8`1oOGdF0?ooo`00503ooomH
07mmO@@0P7eh101iJ5`407m/H0@0OfaT101oL6P307m/I100Og1X101oK6<4081/G`<0NfQK101lHeD4
07IKC`@0N5]=3`1bEd/4079FB@@0Le=5101^Dd@406iCA@@0KU=40`1VBSdD07mmO@<0OgQh8`1oOGdF
0?ooo`00503ooomH07mmO@@0P7eh101iJ5`407m/H0@0OfaT101oL6P307m/I100Og1X101oK6<4081/
G`<0NfQK101lHeD407IKC`@0N5]=3`1bEd/4079FB@@0Le=5101^Dd@406iCA@@0KU=40`1VBSdD07mm
O@<0OgQh8`1oOGdF0?ooo`00503ooomH07mmO@@0P7eh101iJ5`407m/H0@0OfaT101oL6P307m/I100
Og1X101oK6<4081/G`<0NfQK101lHeD407IKC`@0N5]=3`1bEd/4079FB@@0Le=5101^Dd@406iCA@@0
KU=40`1VBSdD07mmO@<0OgQh8`1oOGdF0?ooo`00503oool407mmO@@0Og]k101oNWX307mmO@@0Og]k
101oNWXS07mmO@@0Og]k0`1oNWXG07mmO@@0PX1l101lJV0407m/G`@0OfaR101oL6P307m/I0@0Og1X
101oKV<407eZG@@0NfYM101kIU/407aSEP<0MEmB101eGDl4079GB`@0LeI9101_EDT7079GB`P0LUE8
101cDdP806iCA@@0KUa@0`1VE4`@07mmO@@0Ogmo0`1oNWXS07mmOAH0oooo000D0?ooo`@0Ogem101o
Ng/407mjNP<0Ogem101oNg/407mjNR<0Ogem101oNg/307mjNQL0Ogem1022P7`407aZH0@0OfaO101o
K68407m`J0<0OfaT101oL6P407m^H`@0OFYM101kJUd407]VF`@0O6=F0`1eGe8407EMC`@0LUM;101c
ETT406mEB@L0LUM;201bEDP407=CB0P0KU=5101^G50306IDC100Ogem101oOgl307mjNR<0Ogem5P3o
ool001@0oooo101oOGd407mkN`@0OgYj0`1oOGd407mkN`@0OgYj8`1oOGd407mkN`<0OgYj5`1oOGd4
08:0O0@0O6YP101oK5l407m/HP@0Og1X0`1oK6@407m`J0@0OfiS101mJUd407]ZG@@0NfIK101lHeH3
07EODP@0MEe?101bEd/407=FB@@0KeE91`1bEd/8079EB0@0Le=8201^DdD406iLD0<0IUA<401oOGd4
07moO`<0OgYj8`1oOGdF0?ooo`00503oool407mmO@@0Og]k101oNWX307mmO@@0Og]k101oNWXS07mm
O@@0Og]k0`1oNWXG07mmO@@0PX1l101lJV0407m/G`@0OfaR101oL6P307m/I0@0Og1X101oKV<407eZ
G@@0NfYM101kIU/407aSEP<0MEmB101eGDl4079GB`@0LeI9101_EDT7079GB`P0LUE8101cDdP806iC
A@@0KUa@0`1VE4`@07mmO@@0Ogmo0`1oNWXS07mmOAH0oooo000D0?ooo`@0Ogem101oOgl407miN@<0
OgYj101oOgl407mjNP@0Ogem101oNg/407mjNP<0Og]k101oNWX@07mmO@@0Ogmo0`1oNWXG07mmO@@0
OG]f101lJU/407m/I0@0OfYP101oL6P707m/I0@0OFaS101hJ5d4071QEP@0MUaB101hFDd307EKC`@0
LUe@101bFdl407EKC@/0KU=6101^EDP406iCA0@0L5=5101^DdH406iCB0@0LUU<0`1bKV/D07mmO@<0
Og]k101oNWXO07mmOAH0oooo000D0?ooo`@0Ogem101oOgl407miN@<0OgYj101oOgl407mjNP@0Ogem
101oNg/407mjNP<0Og]k101oNWX@07mmO@@0Ogmo0`1oNWXG07mmO@@0OG]f101lJU/407m/I0@0OfYP
101oL6P707m/I0@0OFaS101hJ5d4071QEP@0MUaB101hFDd307EKC`@0LUe@101bFdl407EKC@/0KU=6
101^EDP406iCA0@0L5=5101^DdH406iCB0@0LUU<0`1bKV/D07mmO@<0Og]k101oNWXO07mmOAH0oooo
000D0?ooo`@0Ogem101oOgl407miN@<0OgYj101oOgl407mjNP@0Ogem101oNg/407mjNP<0Og]k101o
NWX@07mmO@@0Ogmo0`1oNWXG07mmO@@0OG]f101lJU/407m/I0@0OfYP101oL6P707m/I0@0OFaS101h
J5d4071QEP@0MUaB101hFDd307EKC`@0LUe@101bFdl407EKC@/0KU=6101^EDP406iCA0@0L5=5101^
DdH406iCB0@0LUU<0`1bKV/D07mmO@<0Og]k101oNWXO07mmOAH0oooo000D0?ooo`@0Ogem101oOgl4
07miN@<0OgYj101oOgl407mjNP@0Ogem101oNg/407mjNP<0Og]k101oNWX@07mmO@@0Ogmo0`1oNWXG
07mmO@@0OG]f101lJU/407m/I0@0OfYP101oL6P707m/I0@0OFaS101hJ5d4071QEP@0MUaB101hFDd3
07EKC`@0LUe@101bFdl407EKC@/0KU=6101^EDP406iCA0@0L5=5101^DdH406iCB0@0LUU<0`1bKV/D
07mmO@<0Og]k101oNWXO07mmOAH0oooo000D0?ooo``0Ogem0`1oN7P<07mmO@@0Ogmo101oNWX307mo
O`@0OgYj;P1oOGd4089mN0@0O6QN101oK68407m/I0@0OfYR0`1oKVH407m/H@@0PViV1028KV@407M/
HP@0O6MM101oGED307IGB`@0MUM=101fEdl407ECB`@0Le=82`1^DdH406iCB0@0KeE8101`EDP406iC
AP@0ITXm5`1oOGd307moO`@0OgYj7`1oOGdF0?ooo`00503oool<07mmO@<0OgQh301oOGd407moO`@0
OgYj0`1oOgl407mjNRh0Ogem1022OGP407aXGP@0OfaR101oK6@407mZHP<0OfiV101oK644089^IP@0
R6iT101gK68407aWG@@0OeeE0`1fEd/407IGC@@0MUM?101eDd/407=CB0/0KU=6101^DdP406mEB0@0
L5E8101^DdH406I:?AL0Ogem0`1oOgl407mjNQl0Ogem5P3oool001@0oooo301oOGd307mhN0`0Ogem
101oOgl407mjNP<0Ogmo101oNWX^07mmO@@0PWeh101lJ5h407m/HP@0OfaT101oJV8307m^IP@0OfaQ
1022KVH408Q^I0@0MfaR101lIed407mME@<0MUM;101fEdd407IGC`@0ME=;101cDdP;06iCAP@0KU=8
101_EDP4071EB0@0KU=6101VBSdG07mmO@<0Ogmo101oNWXO07mmOAH0oooo000D0?ooo`P0Ogem101o
Ogl307mjNTT0Ogem101oP7`407mZF`@0OfaO101oK68707m/I0@0OfaV101oKV@407m`J0@0PW1Z101k
KUl4081UGP<0Nf5F101kGe8407UKD0@0Nf1E101jDd/4079?AP<0LUI>101`ET/406mCAP@0Ke55101c
EDP406mHC0@0JDm2?@1oOGdF0?ooo`00503oool807mmO@@0Ogmo0`1oNWY907mmO@@0Oh1l101oJU/4
07m/G`@0OfaR1`1oK6@407m/IP@0OfiT101oL6P4089`JP@0NfiO1020IEh307]QEP@0NemB101iFe04
07]PE@@0NU=;101bCdH3079FCP@0L5I;101_DdH406mAA@@0LeE8101_F4`406U?@Sd0Ogem5P3oool0
01@0oooo201oOGd407moO`<0OgYjB@1oOGd407n0O0@0OfYK101oK5l407m/HPL0OfaT101oK6H407m^
I0@0Og1X1022L6X407]^G`@0P6EN0`1kHEH407]ODP@0NE]@101kH5D407YCB`@0LTm60`1bETh4071F
B`@0Ke=6101_DDD407=EB0@0KeQ<101YCd8m07mmOAH0oooo000D0?ooo`P0Ogem101oOgl307mjNTT0
Ogem101oP7`407mZF`@0OfaO101oK68707m/I0@0OfaV101oKV@407m`J0@0PW1Z101kKUl4081UGP<0
Nf5F101kGe8407UKD0@0Nf1E101jDd/4079?AP<0LUI>101`ET/406mCAP@0Ke55101cEDP406mHC0@0
JDm2?@1oOGdF0?ooo`00503ooomH07mmO@@0Ogij101oK5l407m/HP@0OfaO101oK68307m/I0@0OfiV
201oK6@407m`J0@0PW1Z101oLF<307eXG0@0Nf5G101mHeL407IIC`@0O61C101eEd`3079@A0@0ME]C
101^ET/406iCAP@0L5=6101_Fe@4079NEAX0Ogem101oNg/407mjNQ/0Ogem5P3oool001@0ooooF01o
OGd407mnNP@0OfaO101oK68407m/G`@0OfaR0`1oK6@407m^IPP0OfaT101oL6P4089`JP@0Og5S0`1m
J5`407]QE`@0OF=G101fFDl407aPD`@0MEM<0`1bD4@407EKD`@0KUI;101^DdH4071CAP@0Ke]D101b
GUDJ07mmO@@0Og]k101oNWXK07mmOAH0oooo000D0?oooeP0Ogem101oOWX407m/G`@0OfaR101oK5l4
07m/HP<0OfaT101oKVH807m/I0@0Og1X1022L6X407maH`<0OFQL101kHEL407eSE`@0MUU?101lH5<4
07EGC0<0LU14101eFe<406iFB`@0KU=6101`DdH406mKE0@0LUiE6P1oOGd407mkN`@0OgYj6`1oOGdF
0?ooo`00503ooomH07mmO@@0Ogij101oK5l407m/HP@0OfaO101oK68307m/I0@0OfiV201oK6@407m`
J0@0PW1Z101oLF<307eXG0@0Nf5G101mHeL407IIC`@0O61C101eEd`3079@A0@0ME]C101^ET/406iC
AP@0L5=6101_Fe@4079NEAX0Ogem101oNg/407mjNQ/0Ogem5P3oool001@0ooooE@1oOGd307YZH`@0
MFaW101oK68407m/G`@0OfaQ101oK60307m^IP@0OfaT201oL6P407m^IP@0Og1X101oK6H3089^HP@0
OfQI101mHEH407eQE@@0NEa@101jEdd307EFB@@0L512101`ET/406mCAP@0L5=6101XDdT407U^K1X0
Ogem101oOgl407mjNPP0Ogem101oNg/307miN@@0OgYj201oOGdF0?ooo`00503ooomE07mmO@<0NVYS
101eK6L407m/HP@0OfaO101oK64407m/H0<0OfiV101oK6@807m`J0@0OfiV101oL6P407m/IP<0PViR
101oJ5T407eQEP@0OF5E101iG50407YGC@<0MEI9101`D484071FB`@0Ke=6101`DdH406QCB@@0NFi/
6P1oOGd407moO`@0OgYj201oOGd407mkN`<0OgUi101oNWX807mmOAH0oooo000D0?oooeD0Ogem0`1j
JV<407E/I`@0OfaR101oK5l407m/H@@0OfaP0`1oKVH407m/I0P0Og1X101oKVH407m`J0@0OfaV0`22
KV8407mXF@@0OF5F101mHED407ULD0@0NUM=0`1eETT4071@@P@0L5I;101_DdH4071CAP@0J5=9101i
KV`J07mmO@@0Ogmo101oNWX807mmO@@0Og]k0`1oNGT407mjNPP0Ogem5P3oool001@0ooooE@1oOGd3
07YZH`@0MFaW101oK68407m/G`@0OfaQ101oK60307m^IP@0OfaT201oL6P407m^IP@0Og1X101oK6H3
089^HP@0OfQI101mHEH407eQE@@0NEa@101jEdd307EFB@@0L512101`ET/406mCAP@0L5=6101XDdT4
07U^K1X0Ogem101oOgl407mjNPP0Ogem101oNg/307miN@@0OgYj201oOGdF0?ooo`00503ooomA07mm
O@@0GTe30`1PHE/4079QF0@0OfaP101oK6H407m/I0@0OfaR0`1oK6@407m`J0@0OfYP101oKV@807m^
IP@0OfaQ0`1oKV<407eWG0@0OF5F101kGE<407aOC`@0MEI90`1eEd/407EEB0@0L5=6101/F4`407EI
C0@0K554101lN7PZ07mmO@@0Ogmo0`1oOGd407mjNPP0Ogem5P3oool001@0ooooD@1oOGd405i=@`<0
H65K101bHEP407m/H0@0OfaV101oK6@407m/HP<0OfaT101oL6P407mZH0@0OfiT201oKVH407m/H@<0
OfiS101mIe`407eQEP@0NeeC101lGdl407EFB@<0MEM;101eEDP4071CAP@0K5Q<101eFD`406aAA0@0
O7Qh:P1oOGd407moO`<0Ogem101oNWX807mmOAH0oooo000D0?oooe40Ogem101NCD<3061QF`@0LV5H
101oK60407m/IP@0OfaT101oK68307m/I0@0Og1X101oJV0407m^I0P0OfiV101oK64307m^H`@0OFML
101mHEH407]MD`@0O5m?101eETT307EGB`@0MEE8101`DdH406aHC0@0MEU<101/DD@407ahN2X0Ogem
101oOgl307mmO@@0OgYj201oOGdF0?ooo`00503ooomA07mmO@@0GTe30`1PHE/4079QF0@0OfaP101o
K6H407m/I0@0OfaR0`1oK6@407m`J0@0OfYP101oKV@807m^IP@0OfaQ0`1oKV<407eWG0@0OF5F101k
GE<407aOC`@0MEI90`1eEd/407EEB0@0L5=6101/F4`407EIC0@0K554101lN7PZ07mmO@@0Ogmo0`1o
OGd407mjNPP0Ogem5P3oool001@0oooo201oOGd407mkN`<0OgYj?P1oOGd407Q`LP@0CRXT0`0N9b/4
07aZH0@0OfiQ301oKVH307mZHP@0Og1X101oL6X407m/HP@0OfiS101oIEd407eOF0<0NEe@101kHeD4
07]OE@@0NF5C101hFe4407IKC0<0MEE9101`ETH4071CA@@0Je14101^EDP406U<?d40Ogem5P3oool0
01@0oooo201oOGd407mkN`<0OgYj?P1oOGd407Q`LP@0CRXT0`0N9b/407aZH0@0OfiQ301oKVH307mZ
HP@0Og1X101oL6X407m/HP@0OfiS101oIEd407eOF0<0NEe@101kHeD407]OE@@0NF5C101hFe4407IK
C0<0MEE9101`ETH4071CA@@0Je14101^EDP406U<?d40Ogem5P3oool001@0oooo201oOGd407mkN`<0
OgYj?P1oOGd407Q`LP@0CRXT0`0N9b/407aZH0@0OfiQ301oKVH307mZHP@0Og1X101oL6X407m/HP@0
OfiS101oIEd407eOF0<0NEe@101kHeD407]OE@@0NF5C101hFe4407IKC0<0MEE9101`ETH4071CA@@0
Je14101^EDP406U<?d40Ogem5P3oool001@0oooo201oOGd407mkN`<0OgYj?P1oOGd407Q`LP@0CRXT
0`0N9b/407aZH0@0OfiQ301oKVH307mZHP@0Og1X101oL6X407m/HP@0OfiS101oIEd407eOF0<0NEe@
101kHeD407]OE@@0NF5C101hFe4407IKC0<0MEE9101`ETH4071CA@@0Je14101^EDP406U<?d40Ogem
5P3oool001@0oooo201oOGd407moO`<0OgUi101oNWXf07mmO@@0P7in101?=BL407EZHP<0@Chj101o
K6@407mZH0@0OfiV101oJV8407m^IP<0OfaT101oJV8407m^IP@0Og1X101mJV4407]YF`@0OEmH0`1l
Ge8407AIC@@0MU]?101iFd`407QLCP@0KeE80`1eDdH407EEB@@0LU=5101`DdH406mEB@@0J4/o101l
LW0m07mmOAH0oooo000D0?ooo`P0Ogem101oOgl307miN@@0OgYj=P1oOGd4081nOP@0CcDW101eJV83
044n>P@0OfaT101oJV0407m^IP@0OfYR101oKVH307m/I0@0OfYR101oKVH407m`J0@0OFYQ101kJE/4
07eOF0<0O5mB101dFDd407IKC`@0NE]<101hG4h406mEB0<0ME=6101eEDT4079CA@@0L5=6101_EDT4
06Q;?`@0O79`?@1oOGdF0?ooo`00503oool807mmO@@0Ogmo0`1oNGT407mjNSH0Ogem1020OWh404le
9`@0MFYR0`11?SX407m/I0@0OfYP101oKVH407mZHP@0OfiV0`1oK6@407mZHP@0OfiV101oL6P407eZ
H@@0NfUK101mGeP307aODP@0M5U=101fFdl407UKC0@0N5a>101_EDP307ECAP@0MEE9101bDdD4071C
AP@0KeE9101XBcl407abL3d0Ogem5P3oool001@0oooo201oOGd407mkN`<0Ogem101oNWXf07mmO@@0
B2lT1022NG@404Y9AP<0O6YP101oK60807m/I0@0OfaQ101oK68307m/I0@0OfiV101oK6@407m^IP@0
P5QC101kCTP407U5@P<0ND@o101f@Sh407I>AP@0MEE9101eEDH4079BA@<0L552101_DdD4079CAP@0
Le=4101/Cd4406]9>`@0KeUA:P1oOGd407mkN`<0OgYj301oOGdF0?ooo`00503oool807mmO@@0Og]k
0`1oOGd407mjNSH0Ogem1018;b@4089iM0@0BTU60`1lJV0407m/H0P0OfaT101oK64407m/HP<0OfaT
101oKVH407m/I0@0OfiV1020F5<407]>B0@0NDE20`1iA3l407I2?P@0MTi6101eEDT407EEAP@0LU95
0`1`DD8406mCA@@0LU=6101cDd@406a?@@@0JdTk101_FE4Z07mmO@@0Og]k0`1oNWX<07mmOAH0oooo
000D0?ooo`P0Ogem101oNg/307mmO@@0OgYj=P1oOGd404P_90@0PWUd101:BDH307aZH0@0OfaP201o
K6@407m/H@@0OfaR0`1oK6@407m^IP@0OfaT101oKVH4081HD`@0Ndi8101iAD8307U4?`@0MT8n101f
CTH407EEB@@0MEE6101bDTD3071A@P@0Ke=5101bDdH407=CA0@0K4m1101[BC/406mIDBX0Ogem101o
Ng/307mjNP`0Ogem5P3oool001@0oooo201oOGd407mkN`<0Ogem101oNWXf07mmO@@0B2lT1022NG@4
04Y9AP<0O6YP101oK60807m/I0@0OfaQ101oK68307m/I0@0OfiV101oK6@407m^IP@0P5QC101kCTP4
07U5@P<0ND@o101f@Sh407I>AP@0MEE9101eEDH4079BA@<0L552101_DdD4079CAP@0Le=4101/Cd44
06]9>`@0KeUA:P1oOGd407mkN`<0OgYj301oOGdF0?ooo`00503oool807mmO@@0Ogmo0`1oNWXf07mm
O@@0N71`102WV9L404A2@0@0OfiV0`1oK6<407m/H0@0OfaT101oJUl407mXG@@0OfQI0`1oJV0407mZ
HP@0OfMQ101oGe/4081NE`@0NDDm101h>c8307<n>@@0MClh101c>SP407I6?`@0KT]1101^Dd@3071?
@P@0K554101bDdH407ECB0@0Ke94101eDTH406M5=`<0MFIO9`1oOGd407moO`<0OgYj301oOGdF0?oo
o`00503oool807mmO@@0Ogmo0`1oNWXf07mmO@@0N71`102WV9L404A2@0@0OfiV0`1oK6<407m/H0@0
OfaT101oJUl407mXG@@0OfQI0`1oJV0407mZHP@0OfMQ101oGe/4081NE`@0NDDm101h>c8307<n>@@0
MClh101c>SP407I6?`@0KT]1101^Dd@3071?@P@0K554101bDdH407ECB0@0Ke94101eDTH406M5=`<0
MFIO9`1oOGd407moO`<0OgYj301oOGdF0?ooo`00503oool807mmO@@0Ogmo0`1oNWXf07mmO@@0N71`
102WV9L404A2@0@0OfiV0`1oK6<407m/H0@0OfaT101oJUl407mXG@@0OfQI0`1oJV0407mZHP@0OfMQ
101oGe/4081NE`@0NDDm101h>c8307<n>@@0MClh101c>SP407I6?`@0KT]1101^Dd@3071?@P@0K554
101bDdH407ECB0@0Ke94101eDTH406M5=`<0MFIO9`1oOGd407moO`<0OgYj301oOGdF0?ooo`00503o
ool807mmO@@0Ogmo0`1oNWXf07mmO@@0N71`102WV9L404A2@0@0OfiV0`1oK6<407m/H0@0OfaT101o
JUl407mXG@@0OfQI0`1oJV0407mZHP@0OfMQ101oGe/4081NE`@0NDDm101h>c8307<n>@@0MClh101c
>SP407I6?`@0KT]1101^Dd@3071?@P@0K554101bDdH407ECB0@0Ke94101eDTH406M5=`<0MFIO9`1o
OGd407moO`<0OgYj301oOGdF0?ooo`00503ooom507mmO@@0B3@]100k@3h407UZG`@0OfaO0`1oK644
07m/H0@0OfaQ101mJUh407]QE@@0O6EJ0`1oJUh407mXG0@0OEQ?101iACd407QBB@@0Kcha101]D4D3
071DB0@0MS`b101[<BL407Di<P@0L44j101^C4@306iB?@@0Jdln101_DdD4079CAP@0LUE8101bD4@4
079EB@<0K4i2101oN7Df07mmOAH0oooo000D0?ooodD0Ogem1018=2d403]0?P@0NFYO101oK5l307m/
H@@0OfaP101oK64407eZGP@0Nf5E101lIEX307mZGP@0OfQL101mF4l407U5?@@0N599101_?S4406e@
A@<0L5A8101f?38406/a9`@0MCTb101`@CX406i<A0<0KU8m101[Cch406mCA@@0LU=6101bEDP4079@
A0@0LUE90`1/CT8407mhMCH0Ogem5P3oool001@0ooooA@1oOGd404Pd;@@0>d0n101iJUl407m/G`<0
OfaQ101oK60407m/H@@0OFYN101kHED407aUFP<0OfYN101oJ5`407eHC`@0NDDm101hDTT406ln<@@0
KE150`1`E4P407Hl<P@0Jc4W101e>C840711>P@0KTa40`1^DSd406]??P@0Ke=5101bDdH4079EB0@0
LU14101bEDT306a>@P@0OgQe=P1oOGdF0?ooo`00503ooom507mmO@@0B3@]100k@3h407UZG`@0OfaO
0`1oK64407m/H0@0OfaQ101mJUh407]QE@@0O6EJ0`1oJUh407mXG0@0OEQ?101iACd407QBB@@0Kcha
101]D4D3071DB0@0MS`b101[<BL407Di<P@0L44j101^C4@306iB?@@0Jdln101_DdD4079CAP@0LUE8
101bD4@4079EB@<0K4i2101oN7Df07mmOAH0oooo000D0?ooo`l0Ogem101oNg/407mjNRX0Ogem101_
H604091bI0@0=3Lf101lJV0407eXG0<0O6UP101oKV@407mXGP@0Of=B101eEDH4079BB`<0O4a5101G
6Pl405I5?0@0NE9:101kCTP408EdL0@0M4<k0`1_ACT406]@?0@0HdPm101K=BP4060`9`@0K3de0`1[
Cch406m=?@@0KeA6101cFD/407EFB0@0LUE9101bDdH306U9?0@0MEmE101oN7Db07mmOAH0oooo000D
0?ooo`l0Ogem101oNg/407mjNRX0Ogem101_H604091bI0@0=3Lf101lJV0407eXG0<0O6UP101oKV@4
07mXGP@0Of=B101eEDH4079BB`<0O4a5101G6Pl405I5?0@0NE9:101kCTP408EdL0@0M4<k0`1_ACT4
06]@?0@0HdPm101K=BP4060`9`@0K3de0`1[Cch406m=?@@0KeA6101cFD/407EFB0@0LUE9101bDdH3
06U9?0@0MEmE101oN7Db07mmOAH0oooo000D0?ooo`l0Ogem101oNg/407mjNRX0Ogem101_H604091b
I0@0=3Lf101lJV0407eXG0<0O6UP101oKV@407mXGP@0Of=B101eEDH4079BB`<0O4a5101G6Pl405I5
?0@0NE9:101kCTP408EdL0@0M4<k0`1_ACT406]@?0@0HdPm101K=BP4060`9`@0K3de0`1[Cch406m=
?@@0KeA6101cFD/407EFB0@0LUE9101bDdH306U9?0@0MEmE101oN7Db07mmOAH0oooo000D0?ooo`l0
Ogem101oNg/407mjNRX0Ogem101_H604091bI0@0=3Lf101lJV0407eXG0<0O6UP101oKV@407mXGP@0
Of=B101eEDH4079BB`<0O4a5101G6Pl405I5?0@0NE9:101kCTP408EdL0@0M4<k0`1_ACT406]@?0@0
HdPm101K=BP4060`9`@0K3de0`1[Cch406m=?@@0KeA6101cFD/407EFB0@0LUE9101bDdH306U9?0@0
MEmE101oN7Db07mmOAH0oooo000D0?ooo`P0Ogem101oNg/307mjNP@0Ogmo101oNWXZ07mmO@@0Dchg
1011ATL406UJDP@0OfaO1020JEd307UOE0@0OfiV101oK684081GA@@0Ld`l101B618305];B@@0V8F2
101ICTd407mnN`@0O6e^101lIV<408>:O@<0QFQS1024Lg0406mME@@0GS`b100h8aH404lZ8@<0ITDl
101/D40407=BA`@0LeU?101jGdd407EEAP@0LUE80`1bE4P406UAB@@0M6]^101lN7P^07mmOAH0oooo
000D0?ooo`P0Ogem101oNg/307mjNP@0Ogmo101oNWXZ07mmO@@0Dchg1011ATL406UJDP@0OfaO1020
JEd307UOE0@0OfiV101oK684081GA@@0Ld`l101B618305];B@@0V8F2101ICTd407mnN`@0O6e^101l
IV<408>:O@<0QFQS1024Lg0406mME@@0GS`b100h8aH404lZ8@<0ITDl101/D40407=BA`@0LeU?101j
Gdd407EEAP@0LUE80`1bE4P406UAB@@0M6]^101lN7P^07mmOAH0oooo000D0?ooo`P0Ogem101oNg/3
07mjNP@0Ogmo101oNWXZ07mmO@@0Dchg1011ATL406UJDP@0OfaO1020JEd307UOE0@0OfiV101oK684
081GA@@0Ld`l101B618305];B@@0V8F2101ICTd407mnN`@0O6e^101lIV<408>:O@<0QFQS1024Lg04
06mME@@0GS`b100h8aH404lZ8@<0ITDl101/D40407=BA`@0LeU?101jGdd407EEAP@0LUE80`1bE4P4
06UAB@@0M6]^101lN7P^07mmOAH0oooo000D0?ooo`P0Ogem101oNg/307mjNP@0Ogmo101oNWXZ07mm
O@@0Dchg1011ATL406UJDP@0OfaO1020JEd307UOE0@0OfiV101oK684081GA@@0Ld`l101B618305];
B@@0V8F2101ICTd407mnN`@0O6e^101lIV<408>:O@<0QFQS1024Lg0406mME@@0GS`b100h8aH404lZ
8@<0ITDl101/D40407=BA`@0LeU?101jGdd407EEAP@0LUE80`1bE4P406UAB@@0M6]^101lN7P^07mm
OAH0oooo000D0?ooo`P0Ogem101oOgl307mjNRl0Ogem0`1jMGT404h]9`@03QdT101iJ5X407m/H@@0
PW=U0`1lIEX407m/I0@0O65D101gE3d406Hd90@0GQ`?0`0j6QP406a>AP@0NeeC101lI5`407mcJ@@0
OfaQ101oIU`307EJD@@0O6AH1028K68408U^H0@0LUE<100i9A/304PX8@@0ITLj101]D4<407QPDP@0
NEmC101hG4d4079BA@<0LU14101`DD0406MMF`@0JV5R101eLWPZ07mmOAH0oooo000D0?ooo`P0Ogem
101oOgl307mjNRl0Ogem0`1jMGT404h]9`@03QdT101iJ5X407m/H@@0PW=U0`1lIEX407m/I0@0O65D
101gE3d406Hd90@0GQ`?0`0j6QP406a>AP@0NeeC101lI5`407mcJ@@0OfaQ101oIU`307EJD@@0O6AH
1028K68408U^H0@0LUE<100i9A/304PX8@@0ITLj101]D4<407QPDP@0NEmC101hG4d4079BA@<0LU14
101`DD0406MMF`@0JV5R101eLWPZ07mmOAH0oooo000D0?ooo`P0Ogem101oOgl307mjNRl0Ogem0`1j
MGT404h]9`@03QdT101iJ5X407m/H@@0PW=U0`1lIEX407m/I0@0O65D101gE3d406Hd90@0GQ`?0`0j
6QP406a>AP@0NeeC101lI5`407mcJ@@0OfaQ101oIU`307EJD@@0O6AH1028K68408U^H0@0LUE<100i
9A/304PX8@@0ITLj101]D4<407QPDP@0NEmC101hG4d4079BA@<0LU14101`DD0406MMF`@0JV5R101e
LWPZ07mmOAH0oooo000D0?ooo`P0Ogem101oOgl307mjNRl0Ogem0`1jMGT404h]9`@03QdT101iJ5X4
07m/H@@0PW=U0`1lIEX407m/I0@0O65D101gE3d406Hd90@0GQ`?0`0j6QP406a>AP@0NeeC101lI5`4
07mcJ@@0OfaQ101oIU`307EJD@@0O6AH1028K68408U^H0@0LUE<100i9A/304PX8@@0ITLj101]D4<4
07QPDP@0NEmC101hG4d4079BA@<0LU14101`DD0406MMF`@0JV5R101eLWPZ07mmOAH0oooo000D0?oo
ocX0Ogem101NCD<303@N60@0KEMB100a<38407aZG@@0OfQK101oI5L307mXFP@0OfaO1022IeT4089M
D`@0NfiM102AMfL305U<A@@0NeA@101iFe0407A<A0@0N59?101hCDH407M9?P<0Kc8Z101c?cP406Y3
>P@0NeI8101dB40407E>A@<0=Q891018:bL406Y<@`@0ME]=101lHe8407QHB@@0L5M90`1_E4P407EB
A@@0N6YQ101cJ6D406USKRX0Ogem5P3oool001@0oooo>P1oOGd405i=@`<0=1hH101]Ee84034`<P@0
O6YM101oJ5/407mTE`<0OfQJ101oK5l4089WF@@0PUeC101kKUd4095gI`<0FDa5101kE50407UKD0@0
M4a4101hDTl407Q=AP@0MdTn0`1_<RX407<o>0@0JT<j101kETP407A8@0@0MDi50`0f4PT404P[9`@0
JTa3101eFdd407aSDP@0N5Q9101`EdT306mDB0@0ME95101hJV4407=XI@@0JF=^:P1oOGdF0?ooo`00
503ooolj07mmO@@0GTe30`0d7QP406eGDP@0<C0b101lJUd407mXF`@0OfAG0`1oJ5X407m/G`@0PVMI
1022GE<407]^G@@0TGMW0`1IC4D407]DD0@0NE]@101dC4@407QBC`@0N4e6101gBCh306lb:P@0Lclh
101Z@cX407]FB0@0M4Q0101eCTD303HB2@@0B2/W101ZC4<407EKC@@0O6=B101hF4T4071GB@<0KeA8
101eDTD407QZH@@0LfQU101YHfhZ07mmOAH0oooo000D0?oooa<0Ogem101oNg/407mjNQ/0Ogem101j
Lg@402hM5@<09QLB100?8bL406aJE0@0OfYM101oIel407eTF`<0O6IJ101oIEd4089UF@@0LDTi101/
DDP407a/I0<0OgEX1022KVP4089`J0@0OfiV101lLfD408ASF0@0NfMJ0`1iHE4407UGB@@0LTDl101f
CDD407Hl<`@0LS8V0`1U9AX403TG4P@0FCHc101aETT407aQDP@0N5Y9101cD4@306a@A0@0LUA81019
:Ad405UCB`@0LFU^101lN7PV07mmOAH0oooo000D0?oooa<0Ogem101oNg/407mjNQ/0Ogem101jLg@4
02hM5@<09QLB100?8bL406aJE0@0OfYM101oIel407eTF`<0O6IJ101oIEd4089UF@@0LDTi101/DDP4
07a/I0<0OgEX1022KVP4089`J0@0OfiV101lLfD408ASF0@0NfMJ0`1iHE4407UGB@@0LTDl101fCDD4
07Hl<`@0LS8V0`1U9AX403TG4P@0FCHc101aETT407aQDP@0N5Y9101cD4@306a@A0@0LUA81019:Ad4
05UCB`@0LFU^101lN7PV07mmOAH0oooo000D0?oooa<0Ogem101oNg/407mjNQ/0Ogem101jLg@402hM
5@<09QLB100?8bL406aJE0@0OfYM101oIel407eTF`<0O6IJ101oIEd4089UF@@0LDTi101/DDP407a/
I0<0OgEX1022KVP4089`J0@0OfiV101lLfD408ASF0@0NfMJ0`1iHE4407UGB@@0LTDl101fCDD407Hl
<`@0LS8V0`1U9AX403TG4P@0FCHc101aETT407aQDP@0N5Y9101cD4@306a@A0@0LUA81019:Ad405UC
B`@0LFU^101lN7PV07mmOAH0oooo000D0?oooa<0Ogem101oNg/407mjNQ/0Ogem101jLg@402hM5@<0
9QLB100?8bL406aJE0@0OfYM101oIel407eTF`<0O6IJ101oIEd4089UF@@0LDTi101/DDP407a/I0<0
OgEX1022KVP4089`J0@0OfiV101lLfD408ASF0@0NfMJ0`1iHE4407UGB@@0LTDl101fCDD407Hl<`@0
LS8V0`1U9AX403TG4P@0FCHc101aETT407aQDP@0N5Y9101cD4@306a@A0@0LUA81019:Ad405UCB`@0
LFU^101lN7PV07mmOAH0oooo000D0?oooa<0Ogem101oOgl407mjNQ/0Ogem1023P8840;JJU0<0Mf=F
100i=c@407aZH0@0OfaO101oKUd4089QG@<0O6=L101oLf44089VF`@0OEY=101UAc`407aVG0<0Og1X
101oKVH407mZHP@0Og1X101oIf<4081UF`@0NemC0`1lGe<407IKC0@0MUQ7101[ED@407=EAP@0MUE8
0`1hEDH406U8@@@0FCP`101ZD48407UMC`@0N5Y9101cEDD306aAA0@0LUA8101UAcd402DR7`@0MG1^
101lN7PV07mmOAH0oooo000D0?oooa<0Ogem101oOgl407mjNQ/0Ogem1023P8840;JJU0<0Mf=F100i
=c@407aZH0@0OfaO101oKUd4089QG@<0O6=L101oLf44089VF`@0OEY=101UAc`407aVG0<0Og1X101o
KVH407mZHP@0Og1X101oIf<4081UF`@0NemC0`1lGe<407IKC0@0MUQ7101[ED@407=EAP@0MUE80`1h
EDH406U8@@@0FCP`101ZD48407UMC`@0N5Y9101cEDD306aAA0@0LUA8101UAcd402DR7`@0MG1^101l
N7PV07mmOAH0oooo000D0?oooa<0Ogem101oOgl407mjNQ/0Ogem1023P8840;JJU0<0Mf=F100i=c@4
07aZH0@0OfaO101oKUd4089QG@<0O6=L101oLf44089VF`@0OEY=101UAc`407aVG0<0Og1X101oKVH4
07mZHP@0Og1X101oIf<4081UF`@0NemC0`1lGe<407IKC0@0MUQ7101[ED@407=EAP@0MUE80`1hEDH4
06U8@@@0FCP`101ZD48407UMC`@0N5Y9101cEDD306aAA0@0LUA8101UAcd402DR7`@0MG1^101lN7PV
07mmOAH0oooo000D0?oooa<0Ogem101oOgl407mjNQ/0Ogem1023P8840;JJU0<0Mf=F100i=c@407aZ
H0@0OfaO101oKUd4089QG@<0O6=L101oLf44089VF`@0OEY=101UAc`407aVG0<0Og1X101oKVH407mZ
HP@0Og1X101oIf<4081UF`@0NemC0`1lGe<407IKC0@0MUQ7101[ED@407=EAP@0MUE80`1hEDH406U8
@@@0FCP`101ZD48407UMC`@0N5Y9101cEDD306aAA0@0LUA8101UAcd402DR7`@0MG1^101lN7PV07mm
OAH0oooo000D0?ooocH0Ogem1028OW0407E/K0<0PWE/101mJ5d407QVF@@0O6aO101oJV0407mcIP<0
OfMT101oKVH408=`H`@0O69C101_BSh4075GB`<0O6UP101oLVX407m^IP@0OfaT101oMfT4081UF`@0
NEQ;0`1iFD/407=HAP@0Ke95101WCS`406Y6>P@0JT/j0`1ZB3X406a<>P@0JTi8101]E4D407IIC@@0
MUE6101`Cd@306]A@@@0KU541017:B44028W9@@0K6IY:P1oOGdF0?ooo`00503ooolf07mmO@@0R7i`
101eK6`3089eK0@0OFQM101hIUT407a/G`@0OfYP101oLfH307mWI0@0OfiV1023L6<407aRD`@0KdXn
101aEd/307aYH0@0Og9Z101oKVH407m/I0@0OgMY1020IE/407UHB`<0NEU;101cF4H406mBA@@0Idhl
101ZASX406Y;>P<0JTPj101/C3X406Y>B0@0KEA5101fFDd407IEAP@0L4m40`1[DD4406iAA0@0AbTQ
100R9bD406aVJBX0Ogem5P3oool001@0oooo=P1oOGd408QnL0@0MFa/0`22MF`407eXG@@0N6II101l
K5l407mZH0@0Og=V0`1oIf@407m^IP@0Pg1S101lHU<406m:?P@0LEM;0`1lJF0407mbJP@0OfiV101o
K6@407mgJ@@0P6EK101iF4/307UIB`@0LeQ6101_DTD406M>?0@0JTHj101ZBcX306Y8>P@0K4`j101Z
CTP406eDA@@0MUU=101fEDH4071?A0<0Je51101^DD@404LY8@@08RLU101/IVTZ07mmOAH0oooo000D
0?ooocH0Ogem1028OW0407E/K0<0PWE/101mJ5d407QVF@@0O6aO101oJV0407mcIP<0OfMT101oKVH4
08=`H`@0O69C101_BSh4075GB`<0O6UP101oLVX407m^IP@0OfaT101oMfT4081UF`@0NEQ;0`1iFD/4
07=HAP@0Ke95101WCS`406Y6>P@0JT/j0`1ZB3X406a<>P@0JTi8101]E4D407IIC@@0MUE6101`Cd@3
06]A@@@0KU541017:B44028W9@@0K6IY:P1oOGdF0?ooo`00503ooolb07mmO@@0OGUi101lNGH407eX
F@<0NEe>101fI5h4079VG`@0O6QN101oKV@407m`J0<0OfiV101oLVX4089[IP@0P6EK101lG4d4075>
A0<0NF5F101oKVH407mYHP@0OF5I101lK64407mXF@@0NEi@0`1cBCd407=AA@@0LD`m101WBc`406Y<
?@@0Jd/k0`1/CSX406Y6=`@0J4/m101cEDT407EFB@@0MUA6101^Cd8306i?A@@0KeE8100_6aP400XC
4@@0JF=W:P1oOGdF0?ooo`00503ooolb07mmO@@0OGUi101lNGH407eXF@<0NEe>101fI5h4079VG`@0
O6QN101oKV@407m`J0<0OfiV101oLVX4089[IP@0P6EK101lG4d4075>A0<0NF5F101oKVH407mYHP@0
OF5I101lK64407mXF@@0NEi@0`1cBCd407=AA@@0LD`m101WBc`406Y<?@@0Jd/k0`1/CSX406Y6=`@0
J4/m101cEDT407EFB@@0MUA6101^Cd8306i?A@@0KeE8100_6aP400XC4@@0JF=W:P1oOGdF0?ooo`00
503ooolb07mmO@@0OGUi101lNGH407eXF@<0NEe>101fI5h4079VG`@0O6QN101oKV@407m`J0<0OfiV
101oLVX4089[IP@0P6EK101lG4d4075>A0<0NF5F101oKVH407mYHP@0OF5I101lK64407mXF@@0NEi@
0`1cBCd407=AA@@0LD`m101WBc`406Y<?@@0Jd/k0`1/CSX406Y6=`@0J4/m101cEDT407EFB@@0MUA6
101^Cd8306i?A@@0KeE8100_6aP400XC4@@0JF=W:P1oOGdF0?ooo`00503ooolb07mmO@@0OGUi101l
NGH407eXF@<0NEe>101fI5h4079VG`@0O6QN101oKV@407m`J0<0OfiV101oLVX4089[IP@0P6EK101l
G4d4075>A0<0NF5F101oKVH407mYHP@0OF5I101lK64407mXF@@0NEi@0`1cBCd407=AA@@0LD`m101W
Bc`406Y<?@@0Jd/k0`1/CSX406Y6=`@0J4/m101cEDT407EFB@@0MUA6101^Cd8306i?A@@0KeE8100_
6aP400XC4@@0JF=W:P1oOGdF0?ooo`00503ooolb07mmO@@0PWU`101lLF`407mVF@<0N5e@101kFdT4
06mQG`@0Of=L101oK6@;07m`J0@0OgMY1022J5h407mUD`@0M5540`1fF4h407m/I0@0OgM/1022If@4
07aZHP@0PfeS101iGe<307]MC`@0LTi2101aCd4406Y5>P@0JTTk101XBd83079@@P@0LeE9101^DTD4
07EFB@P0MEE8101`D4@306i?@@@0Je5410128QT401HC4`@0>3Hd101oNWXV07mmOAH0oooo000D0?oo
oc80Ogem1022NG0407aaK0@0OfII0`1hGE0407]KB@@0Kf5O101oHe`407m/I0/0Og1X101oMfT4089X
GP@0OfEC101dDD@307IHCP@0OfaT101oMf`4089WI0@0O6YR1023KF<407UOD`<0Nee?101bCT84075?
@@@0JTDj101ZBC/406Q;@P<0LU12101cEDT406iBA@@0MEI9201eEDP4071@A0<0KTm1101[DD@4048R
6@@05Q<C100h=S@407mjNRH0Ogem5P3oool001@0oooo<P1oOGd4089iL0@0O75/101oIUT307QMD0@0
Ne]9101_HEl407mSG0@0OfaT2`1oL6P407mgJ@@0PVQN101oIE<407AAA0<0MUQ>101oK6@407mgK0@0
PVMT101lJV8408=]H`@0NEmC0`1kGDl4079>@P@0LDm1101ZACX406Y9>`@0J4]20`1bD48407=EB@@0
KU95101eETT807EEB0@0L5140`1^Cd4406]AA0@0@R8I100F4a<403Pf=0@0OgYj9P1oOGdF0?ooo`00
503ooolb07mmO@@0PWU`101lLF`407mVF@<0N5e@101kFdT406mQG`@0Of=L101oK6@;07m`J0@0OgMY
1022J5h407mUD`@0M5540`1fF4h407m/I0@0OgM/1022If@407aZHP@0PfeS101iGe<307]MC`@0LTi2
101aCd4406Y5>P@0JTTk101XBd83079@@P@0LeE9101^DTD407EFB@P0MEE8101`D4@306i?@@@0Je54
10128QT401HC4`@0>3Hd101oNWXV07mmOAH0oooo000D0?oooc80Ogem101oOWX407eZF`@0NEQ50`1b
FDd407ELE0@0O6YM101oIEh407m/I0@0Og9/0`1oLf`407m`J0@0Og1Z101oL6D4089WF@@0MUm=0`1b
EDL407aXGP@0OfiS101oKV@407m^IP@0P6iR101jG4l307EFB@@0L5=6101cEDP406i??0@0K4Pi101X
BSh306iDBP@0M5M>101iFdl407QODP@0LUU<201`EDP306iAAP@0KeQ:102IHdD404XX7@@08AHB1017
AD@V07mmOAH0oooo000D0?oooc80Ogem101oOWX407eZF`@0NEQ50`1bFDd407ELE0@0O6YM101oIEh4
07m/I0@0Og9/0`1oLf`407m`J0@0Og1Z101oL6D4089WF@@0MUm=0`1bEDL407aXGP@0OfiS101oKV@4
07m^IP@0P6iR101jG4l307EFB@@0L5=6101cEDP406i??0@0K4Pi101XBSh306iDBP@0M5M>101iFdl4
07QODP@0LUU<201`EDP306iAAP@0KeQ:102IHdD404XX7@@08AHB1017AD@V07mmOAH0oooo000D0?oo
oc80Ogem101oOWX407eZF`@0NEQ50`1bFDd407ELE0@0O6YM101oIEh407m/I0@0Og9/0`1oLf`407m`
J0@0Og1Z101oL6D4089WF@@0MUm=0`1bEDL407aXGP@0OfiS101oKV@407m^IP@0P6iR101jG4l307EF
B@@0L5=6101cEDP406i??0@0K4Pi101XBSh306iDBP@0M5M>101iFdl407QODP@0LUU<201`EDP306iA
AP@0KeQ:102IHdD404XX7@@08AHB1017AD@V07mmOAH0oooo000D0?ooobh0Ogem101oMG0407aTFP@0
MT8h101hDdT306=9@0@0KfaM101oIEd407m/H0@0OfaT101oKV@307mcK0P0Og1X101mJV44081^H0@0
NfIK0`1iHeH407aZF`@0OFEL101lHeP407mWG`@0Of5E101kFTX3071?@P@0Kd`o101[Cc`406Q6>@@0
IdPi101ZCD8306eFB@@0MEY@101lGe8407QIC0@0LUI9101eEDP4071CA0<0Ke12101_DTL407QLC`@0
Pea9101oHEP404M7AbH0Ogem5P3oool001@0oooo;P1oOGd407meL0@0O6AJ101f@SP407QCB@<0HdU0
101_K5d407mUG@@0OfaP101oK6@407m^I0<0Og=/201oL6P407eZH@@0P6iP101kIU/307USEP@0O6YK
101mIE`407aSF0@0OfMO101oHED407]JBP<0L4m2101_C3l406]??0@0J4Hi101WB3T406Y=@P<0KEI9
101eFU0407aODP@0N5U<101bETT407EEB0@0L5=40`1_D48406mBA`@0N5a?1023G4T407mQF0@0AdM7
9P1oOGdF0?ooo`00503oool^07mmO@@0OgE`101lI5X407I2>0@0N5=90`1SBD0406m/G@@0OfEM101o
K60407m/I0@0OfiT0`1oLf`807m`J0@0OFYQ1020KV0407]VF`<0NF=F101lJU/407eUG0@0O6=H101o
Iel407mQE@@0NeY:0`1`Cd8406m<?`@0Jdll101XAST406M8>@@0JTe20`1]ETT407EJD0@0O5mB101h
FD`4079FB@@0MEE8101`Dd@306m@@P@0Ke97101hG4l408=LB@@0Of5H1017AdLV07mmOAH0oooo000D
0?ooobh0Ogem101oMG0407aTFP@0MT8h101hDdT306=9@0@0KfaM101oIEd407m/H0@0OfaT101oKV@3
07mcK0P0Og1X101mJV44081^H0@0NfIK0`1iHeH407aZF`@0OFEL101lHeP407mWG`@0Of5E101kFTX3
071?@P@0Kd`o101[Cc`406Q6>@@0IdPi101ZCD8306eFB@@0MEY@101lGe8407QIC0@0LUI9101eEDP4
071CA0<0Ke12101_DTL407QLC`@0Pea9101oHEP404M7AbH0Ogem5P3oool001@0oooo;P1oOGd407me
M0@0PU]C101iBCh406i2>`<0LE98101_IUh407m^IP@0OfiT101oK6@707m`J0@0OfiV101oKV<4081/
H@@0O6QK101mI5P307UXGP@0OfiV1022MFX407aUH0@0OfiN1022HEP407IHB@<0Kd`o101ZBC`406=5
>`@0Kdhn101WD4D406iBA`<0Lea@101eGE4407aODP@0N5]=101bETT4079@AP@0MDm80`1^D4@406m@
B0@0LE90101[Bch406I4>0@0PWmo9P1oOGdF0?ooo`00503oool^07mmO@@0OgEd1022Fe<407U9?P@0
KT8k0`1aDTP406mVGP@0OfiV101oKV@407m/I0L0Og1X101oKVH407m^H`@0P6aQ101lJ5/407eTF0<0
NFQN101oKVH4089eJP@0O6EP101oKUh4089QF0@0MUQ90`1_C3l406Y9?0@0HdDk101_CSh406M@A@@0
KU970`1cG50407EMD@@0O5mB101hFdd4079FB@@0LU16101eCdP306i@A0@0Ke18101aDT0406];?P@0
IT@h1022OglV07mmOAH0oooo000D0?ooobh0Ogem101oMG@4089KD`@0NDTn101^@S/3075BB0@0KfIN
101oKVH407m^I0@0OfaT1`1oL6P407m^IP@0OfiS1020K64407aXF`@0OFAH0`1iJ5h407m^IP@0PWEZ
101lIF0407m^GP@0PV5H101fF4T306m<?`@0JTTl101SAC/406m>?P@0Ie15101^DTL307=LD0@0MEeA
101lGe8407QKC@@0LUI9101bD4H407E?B0<0KU14101_D4P4075B@0@0Jd/n101VA3P4089oObH0Ogem
5P3oool001@0oooo;P1oOGd407meM0@0PU]C101iBCh406i2>`<0LE98101_IUh407m^IP@0OfiT101o
K6@707m`J0@0OfiV101oKV<4081/H@@0O6QK101mI5P307UXGP@0OfiV1022MFX407aUH0@0OfiN1022
HEP407IHB@<0Kd`o101ZBC`406=5>`@0Kdhn101WD4D406iBA`<0Lea@101eGE4407aODP@0N5]=101b
ETT4079@AP@0MDm80`1^D4@406m@B0@0LE90101[Bch406I4>0@0PWmo9P1oOGdF0?ooo`00503ooolZ
07mmO@@0OgMb101oNfl4089TEP@0Mdlm101/Acd306aFC@@0O6YN101oK6@407mbJPP0OfaT0`1mJUl4
07a/G`@0OfEO1020I5/407QSEP@0OF1D0`1iIUX407mZH0@0OfiT101oK6@407mYI0@0PUa@101iEDL3
06m>@@@0K4`o101XCD4406I@@@@0JU13101`F4`307QLD0@0MUe@101iFdh407QIC0@0LU=6101bD484
071?@P<0L554101/DTH407MLD@@0KTi1101P@cT407E`L2H0Ogem5P3oool001@0oooo:P1oOGd407mg
LP@0Og]_1022I5H407M??@@0K4Lm0`1/ETd407aZGP@0OfaT101oLVX807m/I0<0OFYO101lK5l407mU
G`@0P6AK101hHeH407ePE0<0NFIJ101oJV0407m^I0@0OfaT101oJF@4089LD0@0NEE70`1_CT4406a<
?`@0J4e1101VD44406Y@@`@0L5Q<0`1hG50407IMD0@0NE]>101hFD`4079CAP@0LU12101`Cd83071A
A0@0K596101gG54406i>@@@0H4<i101eL70V07mmOAH0oooo000D0?ooobX0Ogem101oMg8407mkK`@0
PVAF101gCcd406a7?@<0K5I=101lJUh407m/I0@0Og9Z201oK6@307eZG`@0O6aO101oIEl4081TF`@0
N6=F101mH5@307UVFP@0OfYP101oKV@407m/I0@0OfUT1022G50407UEA`<0Kdi1101/C3l406Q=@@@0
IU11101ZD4<4071HC0<0N5a@101fGE0407UKCP@0N5U<101bDdH4079@@P@0L4m20`1`DD@406aBAP@0
MeaA101^CT440613>@@0MG1`9P1oOGdF0?ooo`00503ooolZ07mmO@@0OgMb101oNfl4089TEP@0Mdlm
101/Acd306aFC@@0O6YN101oK6@407mbJPP0OfaT0`1mJUl407a/G`@0OfEO1020I5/407QSEP@0OF1D
0`1iIUX407mZH0@0OfiT101oK6@407mYI0@0PUa@101iEDL306m>@@@0K4`o101XCD4406I@@@@0JU13
101`F4`307QLD0@0MUe@101iFdh407QIC0@0LU=6101bD484071?@P<0L554101/DTH407MLD@@0KTi1
101P@cT407E`L2H0Ogem5P3oool001@0oooo:P1oOGd407a`I0@0LE12101P@30405do=0@0GdPn0`1_
FU0407m/H0@0OfYR101oK6@407m^H`@0OfYM0`20JUl407QQE`@0NFEF101kGEL407]VF`@0NfII0`1i
IUP407m/I0@0OfaR101oK6@407e`H`@0OfAH101iE4H306m>@@@0JT/n101^Bd0406Q?A@@0KUA9101c
F4d307AIC@@0NEmC101fGe8407QIC0@0LU]=101`EDP4071@A0<0KTe5101/DTP406m7=@@0KdXo101`
B3L406I<AbH0Ogem5P3oool001@0oooo:P1oOGd407a`I0@0LE12101P@30405do=0@0GdPn0`1_FU04
07m/H0@0OfYR101oK6@407m^H`@0OfYM0`20JUl407QQE`@0NFEF101kGEL407]VF`@0NfII0`1iIUP4
07m/I0@0OfaR101oK6@407e`H`@0OfAH101iE4H306m>@@@0JT/n101^Bd0406Q?A@@0KUA9101cF4d3
07AIC@@0NEmC101fGe8407QIC0@0LU]=101`EDP4071@A0<0KTe5101/DTP406m7=@@0KdXo101`B3L4
06I<AbH0Ogem5P3oool001@0oooo:P1oOGd407a`I0@0LE12101P@30405do=0@0GdPn0`1_FU0407m/
H0@0OfYR101oK6@407m^H`@0OfYM0`20JUl407QQE`@0NFEF101kGEL407]VF`@0NfII0`1iIUP407m/
I0@0OfaR101oK6@407e`H`@0OfAH101iE4H306m>@@@0JT/n101^Bd0406Q?A@@0KUA9101cF4d307AI
C@@0NEmC101fGe8407QIC0@0LU]=101`EDP4071@A0<0KTe5101/DTP406m7=@@0KdXo101`B3L406I<
AbH0Ogem5P3oool001@0oooo:P1oOGd407a`I0@0LE12101P@30405do=0@0GdPn0`1_FU0407m/H0@0
OfYR101oK6@407m^H`@0OfYM0`20JUl407QQE`@0NFEF101kGEL407]VF`@0NfII0`1iIUP407m/I0@0
OfaR101oK6@407e`H`@0OfAH101iE4H306m>@@@0JT/n101^Bd0406Q?A@@0KUA9101cF4d307AIC@@0
NEmC101fGe8407QIC0@0LU]=101`EDP4071@A0<0KTe5101/DTP406m7=@@0KdXo101`B3L406I<AbH0
Ogem5P3oool001@0oooo:P1oOGd4081YFP@0DR/J101=;RD403/U80@0?3@b0`1cGeH407m/HP@0OfaQ
101oK5l407m/I0@0OfiV0`22K6@407maIP@0P6EN101fFe0407EDB`@0M5iB0`1hI5P407aZGP@0OfaT
101oK644081WGP@0NUmB101dCTH306a;?@@0J4Pj101VBSh406mBAP@0K5=5101bE4T307=GC@@0ME=8
101bEd/407=FB@@0KU=6101`EDP406iBA@<0KTm4101[C48406mF@0@0HSd]101^Cd<406Hj<2H0Ogem
5P3oool001@0oooo:P1oOGd4081YFP@0DR/J101=;RD403/U80@0?3@b0`1cGeH407m/HP@0OfaQ101o
K5l407m/I0@0OfiV0`22K6@407maIP@0P6EN101fFe0407EDB`@0M5iB0`1hI5P407aZGP@0OfaT101o
K644081WGP@0NUmB101dCTH306a;?@@0J4Pj101VBSh406mBAP@0K5=5101bE4T307=GC@@0ME=8101b
Ed/407=FB@@0KU=6101`EDP406iBA@<0KTm4101[C48406mF@0@0HSd]101^Cd<406Hj<2H0Ogem5P3o
ool001@0oooo:P1oOGd4081YFP@0DR/J101=;RD403/U80@0?3@b0`1cGeH407m/HP@0OfaQ101oK5l4
07m/I0@0OfiV0`22K6@407maIP@0P6EN101fFe0407EDB`@0M5iB0`1hI5P407aZGP@0OfaT101oK644
081WGP@0NUmB101dCTH306a;?@@0J4Pj101VBSh406mBAP@0K5=5101bE4T307=GC@@0ME=8101bEd/4
07=FB@@0KU=6101`EDP406iBA@<0KTm4101[C48406mF@0@0HSd]101^Cd<406Hj<2H0Ogem5P3oool0
01@0oooo:P1oOGd4081YFP@0DR/J101=;RD403/U80@0?3@b0`1cGeH407m/HP@0OfaQ101oK5l407m/
I0@0OfiV0`22K6@407maIP@0P6EN101fFe0407EDB`@0M5iB0`1hI5P407aZGP@0OfaT101oK644081W
GP@0NUmB101dCTH306a;?@@0J4Pj101VBSh406mBAP@0K5=5101bE4T307=GC@@0ME=8101bEd/407=F
B@@0KU=6101`EDP406iBA@<0KTm4101[C48406mF@0@0HSd]101^Cd<406Hj<2H0Ogem5P3oool001@0
oooo9P1oOGd407miM`@0QGUd1028CS`4048W70@0?bLQ100U:B`307=ODP@0OFYM101lJV8407m/H@@0
NV=C101bFdl306eA@`@0ID/n101XCdD406Y;A@@0Kdi6101/CT8307=HC@@0MV=H101oK6@407m/IP@0
P6]P101mGE8407AB?P<0JTHi101ZBc/40698>`@0IDXn101UD4@406Q@A0<0K5Q:101cF4`406mDB0@0
MEU<101`EDP406iCAP@0KU950`1^Cd@406i?AP@0ICd_101B:Q`405Xk;0@0HcP/9P1oOGdF0?ooo`00
503ooolV07mmO@@0OgUg1025NG@408Q>?0@0@RLL100o9b4402DY;0<0LemB101mJUd407aZHP@0OfaQ
101jHe<4079KC`<0KE53101UBch406Q?A@@0JT]5101_CTH406a>@P<0LeQ=101fHeP407m/I0@0OfaV
1020Jf0407eMDP@0M58n0`1ZAST406Y;>`@0HTPk101UBSh406E@A0@0J5140`1/F4X407=HC0@0KeA8
101eFD`4071EB0@0KU=6101^DTD306i?A0@0KTm6101U?Bl4058Z70@0FS//101S>2`V07mmOAH0oooo
000D0?ooobH0Ogem101oNGL408EiM0@0R4hl10129a`403lW8@@09BT/0`1cGe8407eZG@@0O6YR101o
K64407YSD`@0LU]?0`1]DD<406E;?P@0J4m5101ZBdD406m>AP@0K4i20`1cF4d407ISF0@0OfaT101o
K6H4081[H0@0OEeB101dDSh306Y6>@@0JT/k101RB3/406E:?P@0IE14101XD4@306aHBP@0LeQ<101_
E4P407EIC0@0L5E8101^DdH406iBA@<0KTm4101^CdH406Dm;`@0DRXL101J>b`406<h;2H0Ogem5P3o
ool001@0oooo9P1oOGd407edK0@0OfUN100g4P`402PF4@@0:1/G100G92T307EOE0@0OfYM101lJ5X4
07m/H@@0Qg1Q101bEdT306E<?@@0B3H_100f9b8403/Y7@@0Bc@/101K<B@305HZ7`@0GD<j101lJ5h4
07m/I0@0P6iR101mGe8407AA@@<0J4lk101VACD406=<@@@0LUA7101bEd/406aCAP<0KTe4101]DTH4
06MBAP@0LUM;101cETT406Y@A0@0IE140`1XDD@406iAAP@0L4He101I<B@4058_9P@0H30R9P1oOGdF
0?ooo`00503ooolV07mmO@@0OGA/101oJEh403LB30@0:1HA100X6aL401LT:@<0MEmD101oJUd407aX
FP@0OfaQ1027L644079GB@<0ID`m1018=Rl403HW8P@0>bTM101;=2`405/a90<0ERXO101M@cX407aX
GP@0OfaT1020KV8407eODP@0M5510`1XCc/406I5=@@0Hda1101bE4L4079GB`@0K5=60`1^CD@406eB
AP@0Ie96101bEd/407=FB@@0JU14101UD4@306QAA0@0KU56101`ASD405Ta90@0DRlV101P<28V07mm
OAH0oooo000D0?ooobH0Ogem101mM6`407mYGP@0=a8<100X5Q4402PK5`@05b@Y0`1eGe@407mZG@@0
O6QJ101oK64408M`H@@0LUM90`1UC3d404Pf;`@0=RLR100k:Ad404/d;0@0Fc4T0`1F:Ql405e3>P@0
O6QN101oK6@4081^HP@0OEmB101dDD4306Q?>`@0ITDe101SC444079DA`@0LUM;101/DdH306i=A0@0
KE96101WDTH4079GB`@0LeI9101ZD4@406E@A0<0J554101^DDH40716=@@0FC4T101B;bH4060`8RH0
Ogem5P3oool001@0oooo9P1oOGd407edK0@0OfUN100g4P`402PF4@@0:1/G100G92T307EOE0@0OfYM
101lJ5X407m/H@@0Qg1Q101bEdT306E<?@@0B3H_100f9b8403/Y7@@0Bc@/101K<B@305HZ7`@0GD<j
101lJ5h407m/I0@0P6iR101mGe8407AA@@<0J4lk101VACD406=<@@@0LUA7101bEd/406aCAP<0KTe4
101]DTH406MBAP@0LUM;101cETT406Y@A0@0IE140`1XDD@406iAAP@0L4He101I<B@4058_9P@0H30R
9P1oOGdF0?ooo`00503ooolS07mmO@<0P7in1025OWP407eLC0@0JSXa100V5A4402PG4`@02a/R0`1l
J5`407]ZG@@0O6QL101oK5l4089`IP@0R6UK0`1mHEL406=1=0@0<adG100[6aD4034W8`@0Cc`a0`1T
BCh405a1>`@0NFMK101oLV`4081cJP@0OF9C101_Bcd306=1<`@0CAX>1017;bT406=5<`@0HD@e101F
>R`305]5>0@0JTe2101QCT0406iCA@@0L5E8101_Cd8406E=@@<0Hde4101ZC404060j;`@0DSHZ101F
?3@406<b:0<0PWmo8`1oOGdF0?ooo`00503ooolS07mmO@<0P7in1025OWP407eLC0@0JSXa100V5A44
02PG4`@02a/R0`1lJ5`407]ZG@@0O6QL101oK5l4089`IP@0R6UK0`1mHEL406=1=0@0<adG100[6aD4
034W8`@0Cc`a0`1TBCh405a1>`@0NFMK101oLV`4081cJP@0OF9C101_Bcd306=1<`@0CAX>1017;bT4
06=5<`@0HD@e101F>R`305]5>0@0JTe2101QCT0406iCA@@0L5E8101_Cd8406E=@@<0Hde4101ZC404
060j;`@0DSHZ101F?3@406<b:0<0PWmo8`1oOGdF0?ooo`00503ooolS07mmO@<0P7in1025OWP407eL
C0@0JSXa100V5A4402PG4`@02a/R0`1lJ5`407]ZG@@0O6QL101oK5l4089`IP@0R6UK0`1mHEL406=1
=0@0<adG100[6aD4034W8`@0Cc`a0`1TBCh405a1>`@0NFMK101oLV`4081cJP@0OF9C101_Bcd306=1
<`@0CAX>1017;bT406=5<`@0HD@e101F>R`305]5>0@0JTe2101QCT0406iCA@@0L5E8101_Cd8406E=
@@<0Hde4101ZC404060j;`@0DSHZ101F?3@406<b:0<0PWmo8`1oOGdF0?ooo`00503ooolS07mmO@<0
P7in1025OWP407eLC0@0JSXa100V5A4402PG4`@02a/R0`1lJ5`407]ZG@@0O6QL101oK5l4089`IP@0
R6UK0`1mHEL406=1=0@0<adG100[6aD4034W8`@0Cc`a0`1TBCh405a1>`@0NFMK101oLV`4081cJP@0
OF9C101_Bcd306=1<`@0CAX>1017;bT406=5<`@0HD@e101F>R`305]5>0@0JTe2101QCT0406iCA@@0
L5E8101_Cd8406E=@@<0Hde4101ZC404060j;`@0DSHZ101F?3@406<b:0<0PWmo8`1oOGdF0?ooo`00
503oool407miN@@0OgYj101oNg/307mjNQ@0Ogem0`0m6A8404E4@@@0Of5C101b@C8402hM80@07a@A
10055A`307QVF@@0OfaO201kJ5/407aZGP@0QgEZ0`1cGDl409IYF@@0OUi=101SAcL405Xk;0@0DdTm
0`1RBcl4075CB@@0NFEI101oKV@4081`I`@0OF9C101iDCh306I4=`@0KTDc1014;RX404Lf<P@05PT9
100e9Al303/]9P@0=b@J100n<B`4058j:P@0GD8b101]Cd4406E=@@<0Hdm1101XB3/404h`8`@0>bHP
1016>c<406Ho=@<0QH:18`1oOGdF0?ooo`00503oool407miN@@0OgYj101oNg/307mjNQ@0Ogem0`0m
6A8404E4@@@0Of5C101b@C8402hM80@07a@A10055A`307QVF@@0OfaO201kJ5/407aZGP@0QgEZ0`1c
GDl409IYF@@0OUi=101SAcL405Xk;0@0DdTm0`1RBcl4075CB@@0NFEI101oKV@4081`I`@0OF9C101i
DCh306I4=`@0KTDc1014;RX404Lf<P@05PT9100e9Al303/]9P@0=b@J100n<B`4058j:P@0GD8b101]
Cd4406E=@@<0Hdm1101XB3/404h`8`@0>bHP1016>c<406Ho=@<0QH:18`1oOGdF0?ooo`00503oool4
07miN@@0OgYj101oNg/307mjNQ@0Ogem0`0m6A8404E4@@@0Of5C101b@C8402hM80@07a@A10055A`3
07QVF@@0OfaO201kJ5/407aZGP@0QgEZ0`1cGDl409IYF@@0OUi=101SAcL405Xk;0@0DdTm0`1RBcl4
075CB@@0NFEI101oKV@4081`I`@0OF9C101iDCh306I4=`@0KTDc1014;RX404Lf<P@05PT9100e9Al3
03/]9P@0=b@J100n<B`4058j:P@0GD8b101]Cd4406E=@@<0Hdm1101XB3/404h`8`@0>bHP1016>c<4
06Ho=@<0QH:18`1oOGdF0?ooo`00503oool407miN@@0OgYj101oNg/307mjNQ@0Ogem0`0m6A8404E4
@@@0Of5C101b@C8402hM80@07a@A10055A`307QVF@@0OfaO201kJ5/407aZGP@0QgEZ0`1cGDl409IY
F@@0OUi=101SAcL405Xk;0@0DdTm0`1RBcl4075CB@@0NFEI101oKV@4081`I`@0OF9C101iDCh306I4
=`@0KTDc1014;RX404Lf<P@05PT9100e9Al303/]9P@0=b@J100n<B`4058j:P@0GD8b101]Cd4406E=
@@<0Hdm1101XB3/404h`8`@0>bHP1016>c<406Ho=@<0QH:18`1oOGdF0?ooo`00503oool407miN@@0
OgQh101oOgl307mjNQ00Ogem10139Ah303lV7`@05PH3100h8A/4034K7P@091HB100W61D4008E70<0
NfQK101iJ5h407eLDP@0LUA9101bGe@4089`JP<0PWE/1024JF0407QHC0@0NUe@101bEDP406Y@@`<0
LEa=101hFe0407USE`@0Og1X1020KFD407eUF0@0M5E40`1]CcX406a>>P@0KTTj101gDD8402/H5P@0
71HA0`0h920403HV80@0<bXR101E?SD405Q7>P@0Kd/k101XCD4306=A@P@0Dc0X100n9Q`403DP60@0
<BLQ101S>2`3089oOb<0Ogem5P3oool001@0oooo101oNGT407mhN0@0Ogmo0`1oNWX@07mmO@@0@bDN
0`0o9Ql401H60`@0>24K100a6ah402@F4P@09aPE10025A`307]XF`@0NFQN101mG584079DB@@0LUmD
1022L6X3089eK0@0Q6UP101hF4`407YMD0@0LUE8101ZD4<3075LC@@0N5]@101iHeL407m`J0@0P6eU
101mIEP407AEA0<0KDlj101/CSX406i9>P@0Me52100[61H401`F4@<0>2@P100f9R0403<Z8P@0EChe
101HAcX406m;>`@0J4e10`1SDD8405<`:0@0?RHL100e81P4034W8@@0HcP/0`22OglS07mmOAH0oooo
000D0?ooo`@0OgUi101oN7P407moO`<0OgYj401oOGd404<U7P<0?bHO100F1P<403PQ6`@0<A/N100T
5Q8402LH5@@00QDL0`1kJ5/407UXGP@0OEaB101bE4T4079OE0@0PW1Z0`22MF`408AYH0@0N5Q<101j
GE04079EB0@0JU130`1aG4d407QKD0@0NF=G101oL6P4081]I@@0OFEH101dED@306e?>P@0K4hj101^
BCX407MA@P@0:aPF100L5Q4303PT80@0=RHP100c:R8405Dn=@@0F4Lj101_Bc/406Q=@@<0He52101C
<2P403hV70@0=B0H100a9b4406<h;0<0PWmo8`1oOGdF0?ooo`00503oool407miN@@0OgQh101oOgl3
07mjNQ00Ogem10139Ah303lV7`@05PH3100h8A/4034K7P@091HB100W61D4008E70<0NfQK101iJ5h4
07eLDP@0LUA9101bGe@4089`JP<0PWE/1024JF0407QHC0@0NUe@101bEDP406Y@@`<0LEa=101hFe04
07USE`@0Og1X1020KFD407eUF0@0M5E40`1]CcX406a>>P@0KTTj101gDD8402/H5P@071HA0`0h9204
03HV80@0<bXR101E?SD405Q7>P@0Kd/k101XCD4306=A@P@0Dc0X100n9Q`403DP60@0<BLQ101S>2`3
089oOb<0Ogem5P3oool001@0oooo101oOGd407mjNQL0Ogem101I<BT3038P60@0<1/F100S5a@401/>
3@@09QLD100Y61@400/H7P<0O6II101kIUP408EiKP@0NUmE101SA3H406=6>P<0HDTl101H@CL404lc
:P@0BS0T101@=RT405@d:0<0GdTm101dGe@407USF0@0OfaQ1020KEh407eOD`@0M5M90`1/ASP406E?
>P@0IT`j101cF4T409iYE0@0FdTo0`1K>bd405ll;`@0Bcde101PB3L406=8?0@0JeE4101`DD@306E?
A0@0D30Q100^6QH4038P60@0<BDL101I8aPV07mmOAH0oooo000D0?ooo`@0Ogem101oNWXG07mmO@@0
FC4Y0`0b81P4030K5P@08aLD100K3Pd402HG50@0:APD100;61h307aVF@@0NfIH1025NFh407YOE@@0
Hd@f101SASX30659?0@0F44g101?<bX404X`90@0D3HY101D=2P305m9?@@0M5mD101iHeP407m/H@@0
P6eN101mGe<407AGB@<0K4Hh101UCcX406I<>P@0LeQ9102NJE@405]9?`<0Fc/]101O?2l404/m=@@0
H4Pg101SB3`406]EA0@0L5540`1UCd@4050`8@@0;QXF100b81P4034U70@0FB<H9P1oOGdF0?ooo`00
503oool407mmO@@0OgYj5`1oOGd405Ta:@<0<R0H100`6aH402<G50@06`h=100V5a@402TH50@02aPN
0`1lIUT407]VF0@0QGU^101jGeD406=4=P@0HdHj0`1QBC`405Q1=`@0Cc<Z101:<2@4050f:@@0E3@X
0`1OBCd407AOE0@0NF=H101oK644081]GP@0OEmC101dEdT306a6>0@0IDlj101VC3X407=HB@@0WVUD
101KBCl305/k;@@0Gc`_101;?CD40618=`@0HdPl101[ED@4071AA0<0IDm4101@<24402hJ5P@0<R0H
100a9A`405TS62H0Ogem5P3oool001@0oooo101oOGd407mjNQL0Ogem101I<BT3038P60@0<1/F100S
5a@401/>3@@09QLD100Y61@400/H7P<0O6II101kIUP408EiKP@0NUmE101SA3H406=6>P<0HDTl101H
@CL404lc:P@0BS0T101@=RT405@d:0<0GdTm101dGe@407USF0@0OfaQ1020KEh407eOD`@0M5M90`1/
ASP406E?>P@0IT`j101cF4T409iYE0@0FdTo0`1K>bd405ll;`@0Bcde101PB3L406=8?0@0JeE4101`
DD@306E?A0@0D30Q100^6QH4038P60@0<BDL101I8aPV07mmOAH0oooo000D0?oooal0Ogem101P>2T3
02@A30@07QD@100Q510402HF4@@06Q<@100[8Qh401HQ9@<0LUmD1022JUd407aZGP@0R7E^1029MfX4
07=EB`<0J4]5101XD4P406m>@@@0HdLm101OA3L406A<@@<0HdY2101eHeX407aZH0@0OfEQ1020J5h4
07eQD`@0M5=;0`1L=2L4058[80@0E40a101XDCh406iC@P@0MEM80`1hFTT406Y@@P@0GTXm101XCd@4
06i?@P@0IDe4101XDD4306Q9>P@0<1hF100N5A44034b;@@0C30S101=6a4V07mmOAH0oooo000D0?oo
oal0Ogem101P>2T302@A30@07QD@100Q510402HF4@@06Q<@100[8Qh401HQ9@<0LUmD1022JUd407aZ
GP@0R7E^1029MfX407=EB`<0J4]5101XD4P406m>@@@0HdLm101OA3L406A<@@<0HdY2101eHeX407aZ
H0@0OfEQ1020J5h407eQD`@0M5=;0`1L=2L4058[80@0E40a101XDCh406iC@P@0MEM80`1hFTT406Y@
@P@0GTXm101XCd@406i?@P@0IDe4101XDD4306Q9>P@0<1hF100N5A44034b;@@0C30S101=6a4V07mm
OAH0oooo000D0?oooal0Ogem101P>2T302@A30@07QD@100Q510402HF4@@06Q<@100[8Qh401HQ9@<0
LUmD1022JUd407aZGP@0R7E^1029MfX407=EB`<0J4]5101XD4P406m>@@@0HdLm101OA3L406A<@@<0
HdY2101eHeX407aZH0@0OfEQ1020J5h407eQD`@0M5=;0`1L=2L4058[80@0E40a101XDCh406iC@P@0
MEM80`1hFTT406Y@@P@0GTXm101XCd@406i?@P@0IDe4101XDD4306Q9>P@0<1hF100N5A44034b;@@0
C30S101=6a4V07mmOAH0oooo000D0?oooal0Ogem101P>2T302@A30@07QD@100Q510402HF4@@06Q<@
100[8Qh401HQ9@<0LUmD1022JUd407aZGP@0R7E^1029MfX407=EB`<0J4]5101XD4P406m>@@@0HdLm
101OA3L406A<@@<0HdY2101eHeX407aZH0@0OfEQ1020J5h407eQD`@0M5=;0`1L=2L4058[80@0E40a
101XDCh406iC@P@0MEM80`1hFTT406Y@@P@0GTXm101XCd@406i?@P@0IDe4101XDD4306Q9>P@0<1hF
100N5A44034b;@@0C30S101=6a4V07mmOAH0oooo000D0?ooo`P0Ogem101oNg/307mjNQ00Ogem101/
AcP302hC3@@08a<@100M5104018820@07a<@100W7a`4028Z:P<0He=9101lIUX407m/H0@0OfiV1022
LV`408QnLP<0SWEZ101_K6H408EeKP@0OfiV1022MF`4079UG0<0MemD101iJEd407e/H@@0NfiO101m
I5/407mUF0@0O6UH0`24HUH405/f;`@0>B0K100b8AP404He;0@0H4Xn0`1`DdD407=E@P@0IDm2101/
CSl405m8>P@0J4]4101XCD@305<`8`@0<Q/D100X7a/401/S7P@0GC4Q100d6A<304Y:BB<0Ogem5P3o
ool001@0oooo201oOGd407mkN`<0OgYj401oOGd406a7>0<0;Q<=100S4a0401dD40@04PP8100O4a04
02LO70@08RXZ0`1SDdT407aVFP@0OfaP101oKVH4089bK0@0R7ib0`2>MFX406m/IP@0QGE^101oKVH4
089eK0@0LVEL0`1gGe@407UYG@@0OFaQ101kKUl407eTF`@0OfEH101lJEP308AREP@0FcH_100i81/4
038Q60@0ASD/101PBSh3071CA@@0LeE2101UCd8406a>?`@0GdPj101XBd@406Q=A0<0Dc0S100b6a@4
02PO6`@06b<N101M<B4403@I4`<0BTY98`1oOGdF0?ooo`00503oool807mmO@@0Og]k0`1oNWX@07mm
O@@0K4Lh0`0^4`d402<C40@07A@@100B20P401lC40@09alL100R:RX306=CB@@0O6IJ101oK60407m^
IP@0PW9/1028OW8308ieJP@0KfaV1025MFh407m^IP@0PWE/101bIE`307MOE0@0NFUM101mK64407]^
G`@0OFAK101oIEP407aYF0<0Q69F101K=Rl403TP6`@0<R4H1016=B`4061:?P<0L5=5101cED8406E?
@P@0K4ho101OB3X406Q;A0@0J4e40`1C<2<4038K50@0:1lK100K8ah405da8@@0=1TC0`1:BTTS07mm
OAH0oooo000D0?ooo`P0Ogem101oOgl307mjNQ00Ogem101MACh3034Q6`@091DA100R510401`B30@0
71<?100Y7a`402X^;0<0GDe4101iHeP407m/H0@0OfaT101oL6P407mbK0L0OgE`101oLf`407mbK0@0
Og=/101oLV`3089`I@@0O6QJ1022L6D407eXF`@0Nf=F101mI5L407]TE`<0PFML102>KV0407]GC`@0
HD4h100d91`4030N5P<0?bXS1015<b/804hg:P@0HdLn101SBd0406a<@0<0AR<L100X5Q4402<F5P@0
7@l<100i6A4404HX8`<061TH8`1oOGdF0?ooo`00503oool807mmO@@0Ogmo0`1oNWX@07mmO@@0GDDn
0`0a8A/402@E4@@08Q@@100L4P`401`C3`@0:AlL100Z;R`305e=A0@0NF=H101oK60407m/I0@0Og1X
101oLV`707meL0@0Og=/101oLV`407mcK0@0Og9/0`22L6D407aXFP@0PW1U101mJ5/407]SEP@0OFAG
101kI5L3085WG0@0SViP101kEdl40651>0@0=2@L100`7QH303lZ8`@0AC<[201>=bX406=7?P@0Hd]0
101/C40304HS70@0:1HA100S5QH401d?30@0>ATA1016:2<301PI62<0Ogem5P3oool001@0oooo201o
OGd407moO`<0OgYj401oOGd405e5?P<0<B4K100T5A44028D40@0718<100L4`l402TO70@0:Rh/0`1M
CD@407USF0@0OfaP101oK6@407m`J0@0Og9/1`1oMG0407mcK0@0Og9/101oLf`407mbK0<0PW1U101l
J5X4089`I@@0OFQK101kHeH407eTE`@0NfAG0`21Ie`408i^H0@0NeM?101Q@CP403@T70@0<1hF0`0o
:R<404Dc:`P0CSLZ101SAch406=;@0@0K4a00`168a`402PF4@@08aHF100M3``403TI4@@0ARPS0`0H
6APS07mmOAH0oooo000D0?ooo`P0Ogem101oOgl307mjNQ00Ogem101MACh3034Q6`@091DA100R5104
01`B30@071<?100Y7a`402X^;0<0GDe4101iHeP407m/H0@0OfaT101oL6P407mbK0L0OgE`101oLf`4
07mbK0@0Og=/101oLV`3089`I@@0O6QJ1022L6D407eXF`@0Nf=F101mI5L407]TE`<0PFML102>KV04
07]GC`@0HD4h100d91`4030N5P<0?bXS1015<b/804hg:P@0HdLn101SBd0406a<@0<0AR<L100X5Q44
02<F5P@07@l<100i6A4404HX8`<061TH8`1oOGdF0?ooo`00503ooolO07mmO@@0K4a50`0n:bL402<G
4P@08A@@100S5A4402<G5`@0:R0M100[;BT305=5?0@0LUmD101oK5d407mZH0@0OfiV101oKV@307mb
K0@0OgE`101oMg@407mbK0@0OgE`101oL6P307mbK0@0OfiS101oK5l4081/GP@0NfII101kGe<407]R
EP<0NfAG101oHEH407QSE@@0Pem@101gF4X406I;?@<0CSX]101F=b/405A2=`@0ID]0101E@CT406Q;
A0@0I4/m0`1691`402DE4@@07A@@100I4@d4020F4`@0=R@P0`0K6aXS07mmOAH0oooo000D0?oooal0
Ogem101/C4D303h[9`@08aLB100Q510402<E4@@08aLG100Z81d402/]:@<0DdDl101bGe@407m/G@@0
OfYP101oKVH407m^I0<0Og9/101oMG0407mgM0@0Og9/101oMG0407m`J0<0Og9/101oKV<407m/G`@0
P6aN101kIUT407]OD`@0Nf9F0`1kI5L407mQEP@0N6=E1023Ge0407MHBP@0IT/m0`1>>Rd405Hg:`@0
E48g101UBd0405E1>@@0J4]4101TBcd304HT70@09ADA100M510401TA3@@081HC100f920301/K6R<0
Ogem5P3oool001@0oooo7`1oOGd406a<A@<0?R/W100S5a84024D40@08aDA100S5aL402XP7@@0:bdY
0`1CAC`4079OE0@0OfaM101oJV0407m^IP@0OfiT0`1oLV`407meL0@0OgMd101oLV`407meL0@0Og1X
0`1oLV`407m^H`@0OfaO1020K5h407]VF@@0NemC101kHUH307]TE`@0Of5F101hHeD408=OD0@0MeQ:
101VBcd304hj;@@0ESL[101D@SL406E;@0@0ED4i101XBd@406A;?@<0AR@L100U5A4401dD40@06A4=
100P5Q<403HT80<06a/J8`1oOGdF0?ooo`00503ooolO07mmO@@0K4a50`0n:bL402<G4P@08A@@100S
5A4402<G5`@0:R0M100[;BT305=5?0@0LUmD101oK5d407mZH0@0OfiV101oKV@307mbK0@0OgE`101o
Mg@407mbK0@0OgE`101oL6P307mbK0@0OfiS101oK5l4081/GP@0NfII101kGe<407]REP<0NfAG101o
HEH407QSE@@0Pem@101gF4X406I;?@<0CSX]101F=b/405A2=`@0ID]0101E@CT406Q;A0@0I4/m0`16
91`402DE4@@07A@@100I4@d4020F4`@0=R@P0`0K6aXS07mmOAH0oooo000D0?oooal0Ogem101YA3D3
03DR6@@0<b0K100R5A4402DA30@0:1LC100/7AL402hV8P<0@c/d101XED/407aZG@@0OfaP101oK6@4
07mbK0<0Og1X101oLV`<07meL0@0Og1X0`1oKV<407m^IP@0OfYO1020IeT407]REP@0NfII101kGe<3
07]QD`@0O5eB101jFdh407QKC@@0MUM9101eFD`307IJC0@0KU=6101SBd0406i;@P@0Je94101_BCl4
05dj:`<0?R4J100U5A4402TH50@081DA100M4a0402TK5@<081hK101/IVLO07mmOAH0oooo000D0?oo
oal0Ogem101YA3D303DR6@@0<b0K100R5A4402DA30@0:1LC100/7AL402hV8P<0@c/d101XED/407aZ
G@@0OfaP101oK6@407mbK0<0Og1X101oLV`<07meL0@0Og1X0`1oKV<407m^IP@0OfYO1020IeT407]R
EP@0NfII101kGe<307]QD`@0O5eB101jFdh407QKC@@0MUM9101eFD`307IJC0@0KU=6101SBd0406i;
@P@0Je94101_BCl405dj:`<0?R4J100U5A4402TH50@081DA100M4a0402TK5@<081hK101/IVLO07mm
OAH0oooo000D0?oooal0Ogem101YA3D303DR6@@0<b0K100R5A4402DA30@0:1LC100/7AL402hV8P<0
@c/d101XED/407aZG@@0OfaP101oK6@407mbK0<0Og1X101oLV`<07meL0@0Og1X0`1oKV<407m^IP@0
OfYO1020IeT407]REP@0NfII101kGe<307]QD`@0O5eB101jFdh407QKC@@0MUM9101eFD`307IJC0@0
KU=6101SBd0406i;@P@0Je94101_BCl405dj:`<0?R4J100U5A4402TH50@081DA100M4a0402TK5@<0
81hK101/IVLO07mmOAH0oooo000D0?oooal0Ogem101YA3D303DR6@@0<b0K100R5A4402DA30@0:1LC
100/7AL402hV8P<0@c/d101XED/407aZG@@0OfaP101oK6@407mbK0<0Og1X101oLV`<07meL0@0Og1X
0`1oKV<407m^IP@0OfYO1020IeT407]REP@0NfII101kGe<307]QD`@0O5eB101jFdh407QKC@@0MUM9
101eFD`307IJC0@0KU=6101SBd0406i;@P@0Je94101_BCl405dj:`<0?R4J100U5A4402TH50@081DA
100M4a0402TK5@<081hK101/IVLO07mmOAH0oooo000D0?oooal0Ogem101M?Rl303PX8`@0;alJ100/
6QD401/A30@07a<?100P4a0402`O60<0<bXQ101GAC`407UVFP@0OfaP101oK6@407m_I`<0OgMd101o
L6P407mbK0P0Og=/101oL6P307m`I`@0OfaM101mJUh407eXF`P0NemC101kHED307]OD`@0O5mB101e
Fdd407EGB`@0ME]?101^EDP3079EB0@0L5=6101ZDTD406E?@@@0IDm4101QB3X4044Z8`<08A@>100U
61L401TA4@@06a4<100A20P401lE4P<09b<O101=@T8O07mmOAH0oooo000D0?oooal0Ogem101M?Rl3
03PX8`@0;alJ100/6QD401/A30@07a<?100P4a0402`O60<0<bXQ101GAC`407UVFP@0OfaP101oK6@4
07m_I`<0OgMd101oL6P407mbK0P0Og=/101oL6P307m`I`@0OfaM101mJUh407eXF`P0NemC101kHED3
07]OD`@0O5mB101eFdd407EGB`@0ME]?101^EDP3079EB0@0L5=6101ZDTD406E?@@@0IDm4101QB3X4
044Z8`<08A@>100U61L401TA4@@06a4<100A20P401lE4P<09b<O101=@T8O07mmOAH0oooo000D0?oo
oal0Ogem101M?Rl303PX8`@0;alJ100/6QD401/A30@07a<?100P4a0402`O60<0<bXQ101GAC`407UV
FP@0OfaP101oK6@407m_I`<0OgMd101oL6P407mbK0P0Og=/101oL6P307m`I`@0OfaM101mJUh407eX
F`P0NemC101kHED307]OD`@0O5mB101eFdd407EGB`@0ME]?101^EDP3079EB0@0L5=6101ZDTD406E?
@@@0IDm4101QB3X4044Z8`<08A@>100U61L401TA4@@06a4<100A20P401lE4P<09b<O101=@T8O07mm
OAH0oooo000D0?oooal0Ogem101M?Rl303PX8`@0;alJ100/6QD401/A30@07a<?100P4a0402`O60<0
<bXQ101GAC`407UVFP@0OfaP101oK6@407m_I`<0OgMd101oL6P407mbK0P0Og=/101oL6P307m`I`@0
OfaM101mJUh407eXF`P0NemC101kHED307]OD`@0O5mB101eFdd407EGB`@0ME]?101^EDP3079EB0@0
L5=6101ZDTD406E?@@@0IDm4101QB3X4044Z8`<08A@>100U61L401TA4@@06a4<100A20P401lE4P<0
9b<O101=@T8O07mmOAH0oooo000D0?oooal0Ogem101/ASL303@T7P@0=RLS100/7QX402hJ5P@08A@@
100X6aL402/S8@<0=2XV100j=Bh4079KD@@0OfYN101oJV8407m[HP<0Og9/101oMg@407mbK0@0OgE`
201oL6P307m`JP@0OFYO101mJU`807]QE@@0NemC101iGe<307IMD0@0NEe@101hFdd4079GB`@0LUE9
101eFdd306iEB0@0L5=6101_DTD406Q?@P@0JT`o101I>c0403/O6@<0;ahJ100F30`401XA4@@04@P8
100I410401/B3`<09b@S100k<c0O07mmOAH0oooo000D0?oooal0Ogem101/ASL303@T7P@0=RLS100/
7QX402hJ5P@08A@@100X6aL402/S8@<0=2XV100j=Bh4079KD@@0OfYN101oJV8407m[HP<0Og9/101o
Mg@407mbK0@0OgE`201oL6P307m`JP@0OFYO101mJU`807]QE@@0NemC101iGe<307IMD0@0NEe@101h
Fdd4079GB`@0LUE9101eFdd306iEB0@0L5=6101_DTD406Q?@P@0JT`o101I>c0403/O6@<0;ahJ100F
30`401XA4@@04@P8100I410401/B3`<09b@S100k<c0O07mmOAH0oooo000D0?oooal0Ogem101/ASL3
03@T7P@0=RLS100/7QX402hJ5P@08A@@100X6aL402/S8@<0=2XV100j=Bh4079KD@@0OfYN101oJV84
07m[HP<0Og9/101oMg@407mbK0@0OgE`201oL6P307m`JP@0OFYO101mJU`807]QE@@0NemC101iGe<3
07IMD0@0NEe@101hFdd4079GB`@0LUE9101eFdd306iEB0@0L5=6101_DTD406Q?@P@0JT`o101I>c04
03/O6@<0;ahJ100F30`401XA4@@04@P8100I410401/B3`<09b@S100k<c0O07mmOAH0oooo000D0?oo
oal0Ogem101/ASL303@T7P@0=RLS100/7QX402hJ5P@08A@@100X6aL402/S8@<0=2XV100j=Bh4079K
D@@0OfYN101oJV8407m[HP<0Og9/101oMg@407mbK0@0OgE`201oL6P307m`JP@0OFYO101mJU`807]Q
E@@0NemC101iGe<307IMD0@0NEe@101hFdd4079GB`@0LUE9101eFdd306iEB0@0L5=6101_DTD406Q?
@P@0JT`o101I>c0403/O6@<0;ahJ100F30`401XA4@@04@P8100I410401/B3`<09b@S100k<c0O07mm
OAH0oooo000D0?oooal0Ogem101SC4D303TY90@0=bTU100f9b<402`J5P@0714<100T5Q<4034P6P<0
@2lV100n=2X406E=@`@0O6IH101oK68407mZHP<0Of]R101oLV`407meL0@0OgMd101oLf`707m`J0@0
PViU101mJU`407UTEP@0MUe@101hFe4407aKD0<0MU]>101fEdd407QIC@@0LUM;101bEDP4071CAP<0
L5E8101/CT04071?@P@0IDTl101N?cD404`]8P@0=AdG0`0K4@`401`B4@@05@`<100I4@`401P@3`@0
8aLD0`0R9RL405UFEAl0Ogem5P3oool001@0oooo7`1oOGd406=<A@<0>BTT100g:BD403HW8`@0;1XF
100L4@`402@F4`@0<B0J0`10;bH403hd:P@0IDe3101lIUP407m/HP@0OfYR0`1oJf8407mbK0@0OgE`
101oMg@407mcK0L0Og1X1022KVD407eZG0@0NFAF101fGE0407QKD@@0O5]@0`1fFdh407IGC@@0N5U=
101bEd/4079EB0@0L5=60`1`EDP406a>@0@0L4m2101UBC`405ho=@@0C2dR100e7AL301/A30@0718A
100E30`401TA30@0610?100S5a@3028V9`@0FEIE7`1oOGdF0?ooo`00503ooolO07mmO@@0Hda50`0i
:B@403LY9@@0=RLS100/6QH401`A30@091HC100a81X3040_9P@0?S@Z101UCD<407aVF0@0OfaR101o
JV8307m[HP@0Og9/101oMG0407mgM0@0Og=/1`1oL6P4089^I@@0OFYL101iI5H407IMD0@0N5]A101l
Fe0307IKCP@0MUM=101hFDd4079GB`@0LUE8101`DdH3071EB0@0K4i0101`Cd8406E9?0@0GSle101<
;B8403DM5`<06a4<100L4Q4401D<30@06A4<100H40l402<G50<08RHW101IEUDO07mmOAH0oooo000D
0?oooaL0Ogem101oNg/407egM`@0GD<l0`0b9B4403DX90@0=BLR100W5a<402`L60@09Q/G100X7Q/3
03H/90@0BS/b101OAS`407IQEP@0OfaP1`1oKVH407m_I``0OgE`101oL6P307e^HP@0O6QM1020IeT4
07eQE@@0Nf5E101fGDl407UKD0<0MU]=101eFD`407EIC@@0L598101^DdP4071CAP<0KU=6101`E4H4
06Q=@@@0ITTk101S@34404<X7@@0<1/E0`0R5Q4401dD40@07QDA100I40`401`D40@08QLC0`000004
089oOal0Ogem5P3oool001@0oooo5`1oOGd407mkN`@0OGMg101M@c`3038U8@@0=BPT100e9b8402LG
4`@0;1`H100V6aL402PN6`<0=R`T101:>c8405m6?0@0MV5F101oK60707m^IP@0OfmW301oMG0407m`
J0<0OFiR101lJ5d4081WF@@0OF5E101kHED407IMC`@0NE]@0`1fFdd407EIC0@0MEU=101`DTP406iC
B0@0L5=60`1^DdH4071DAP@0J4e1101VBC/406=0<@@0@bPM100`6aD3028F4@@07A@@100N5A4401T@
30@071@@100R5a<3000000@0PWmo7`1oOGdF0?ooo`00503ooolG07mmO@@0Og]k101mMgL405e3?0<0
<RDQ100e:2@403DW8P@09aLC100/71P402HK5`@0:1hK0`0f;2@404Xk<P@0GdHl101fHEH407m/H0L0
OfiV101oKfL<07meL0@0Og1X0`1mKV8407aXG@@0P6MI101mHED407]QE@@0MUe?101iFe0307IKC@@0
MEU<101eFDd4071BB0@0KU=8101`DdH306iCAP@0L5A6101XCD4406I9>`@0Hd0a1013:1d4030K5@<0
8QHA100M510401hE4@@06A0<100L5104028G4`<000001022OglO07mmOAH0oooo000D0?oooaL0Ogem
101oNg/407egM`@0GD<l0`0b9B4403DX90@0=BLR100W5a<402`L60@09Q/G100X7Q/303H/90@0BS/b
101OAS`407IQEP@0OfaP1`1oKVH407m_I``0OgE`101oL6P307e^HP@0O6QM1020IeT407eQE@@0Nf5E
101fGDl407UKD0<0MU]=101eFD`407EIC@@0L598101^DdP4071CAP<0KU=6101`E4H406Q=@@@0ITTk
101S@34404<X7@@0<1/E0`0R5Q4401dD40@07QDA100I40`401`D40@08QLC0`000004089oOal0Ogem
5P3oool001@0oooo5`1oOGd407moO`@0PWmo101G?CD303HT70@0=2@P100g:BD403TY90@0:Q`H100]
81`4030P60<0<BdY1014=B/405<o=P@0KeM=101lJUh407mZHP<0OfiV101oKV@807m`J0@0Og5Z101m
JUl307eZGP@0N6II101mIeT407UMCP@0MU]=101iGDh407IKC@<0MUe@101hEd/4079IC0@0MEQ9101`
DDH406i@A0<0KTm2101ZD4@406I9?0@0GD4c1016:R@403HM60@081HA0`0K4@`401T@40@05@`<100=
20P401<;2`@0:B0M0`0<1`L4089oOal0Ogem5P3oool001@0oooo5`1oOGd407moO`@0PWmo101G?CD3
03HT70@0=2@P100g:BD403TY90@0:Q`H100]81`4030P60<0<BdY1014=B/405<o=P@0KeM=101lJUh4
07mZHP<0OfiV101oKV@807m`J0@0Og5Z101mJUl307eZGP@0N6II101mIeT407UMCP@0MU]=101iGDh4
07IKC@<0MUe@101hEd/4079IC0@0MEQ9101`DDH406i@A0<0KTm2101ZD4@406I9?0@0GD4c1016:R@4
03HM60@081HA0`0K4@`401T@40@05@`<100=20P401<;2`@0:B0M0`0<1`L4089oOal0Ogem5P3oool0
01@0oooo5`1oOGd407moO`@0PWmo101G?CD303HT70@0=2@P100g:BD403TY90@0:Q`H100]81`4030P
60<0<BdY1014=B/405<o=P@0KeM=101lJUh407mZHP<0OfiV101oKV@807m`J0@0Og5Z101mJUl307eZ
GP@0N6II101mIeT407UMCP@0MU]=101iGDh407IKC@<0MUe@101hEd/4079IC0@0MEQ9101`DDH406i@
A0<0KTm2101ZD4@406I9?0@0GD4c1016:R@403HM60@081HA0`0K4@`401T@40@05@`<100=20P401<;
2`@0:B0M0`0<1`L4089oOal0Ogem5P3oool001@0oooo5`1oOGd407moO`@0PWmo101G?CD303HT70@0
=2@P100g:BD403TY90@0:Q`H100]81`4030P60<0<BdY1014=B/405<o=P@0KeM=101lJUh407mZHP<0
OfiV101oKV@807m`J0@0Og5Z101mJUl307eZGP@0N6II101mIeT407UMCP@0MU]=101iGDh407IKC@<0
MUe@101hEd/4079IC0@0MEQ9101`DDH406i@A0<0KTm2101ZD4@406I9?0@0GD4c1016:R@403HM60@0
81HA0`0K4@`401T@40@05@`<100=20P401<;2`@0:B0M0`0<1`L4089oOal0Ogem5P3oool001@0oooo
7`1oOGd406e=A@<0<B8J100h9b8403DX90@0<B<N100]6QH402lO5`@0<B@P0`0c:2<403d[8`@0@3@/
101UC4@407UXFP@0OfaO0`1oJV0407m/H@P0OfaO101oKV@4089^I@<0OFYL101kH5<407UND0@0NEU>
101fEd`407IID0@0MU]=0`1fETT407QGB`P0LUE8101cDdH406iBA@<0K4`o101XB3/405e0<P@0AR/U
100l9A/402PG4P@081DA0`0Q5A4401XA40P05P`<100R5Q<402<_<P<0D4Y98`1oOGdF0?ooo`00503o
oolO07mmO@@0KDe50`0a8QX403PW8P@0=BPT100a8ah402dJ5P@0;alG100a920303<X8`@0?B/S1010
=2`406E<A0@0NFQJ101oK5l307mZH0@0OfaQ201oK5l407m^I0@0PViU0`1mJU`407]PD`@0NEi@101i
FDh407IGC0@0MUU@101fFdd307IFB@@0N5M;201bEDP407=CAP@0KU950`1/C3l406Q8>`@0GD0b1016
:bD403`U6`@0:1LB100P5A43024E4@@06Q4@200F30`4028F4`@08blb0`1@BTTS07mmOAH0oooo000D
0?oooal0Ogem101]CDD3034R6P@0>2LR100e:2@4034S7P@0;AXF100_7aL4034T80<0<bPS100m:b<4
040d;0@0IDa4101iJ5X407m/G`<0OfYP101oK64807m/G`@0OfiT1022KVD307eZG0@0Nf1C101iGU04
07UICP@0MUM<101fFE0407IKC@<0MUI9101hEd/8079EB0@0Le=6101^DTD306a<?`@0J4Pk101M@384
04H[9@@0?2DK100X5a84020E4@<08ADA100J4A0801H<30@08QHC100S;c83051:BB<0Ogem5P3oool0
01@0oooo7`1oOGd406e=A@<0<B8J100h9b8403DX90@0<B<N100]6QH402lO5`@0<B@P0`0c:2<403d[
8`@0@3@/101UC4@407UXFP@0OfaO0`1oJV0407m/H@P0OfaO101oKV@4089^I@<0OFYL101kH5<407UN
D0@0NEU>101fEd`407IID0@0MU]=0`1fETT407QGB`P0LUE8101cDdH406iBA@<0K4`o101XB3/405e0
<P@0AR/U100l9A/402PG4P@081DA0`0Q5A4401XA40P05P`<100R5Q<402<_<P<0D4Y98`1oOGdF0?oo
o`00503ooolO07mmO@@0NfEN0`0k:RH4034T7`@0>2PT100g91/4030R7@@0:A`H100`8ah302`P70@0
<RTU100e;BH4050k<@@0Ke]?101kJ5/307aZF`@0OfaQ101oK5l407eZG@@0NfQI101lJV03081YF`@0
NEe?101iGDh407EFB0@0LUE8101bED/407=GB`<0MEQ;101eDDD4079BB0@0L556101`Dd@406a?@0<0
JT`o101VAST404la9P@0?bHK100V5Q8401`B30@06A0@0`0O510401/A40@04PP8100D2`/401lE4`@0
00000`22OglS07mmOAH0oooo000D0?oooal0Ogem101kIEh303/Z9P@0<B@O100h:2@403LT6`@0<28M
100Y71P4030S7P<0;20L100b:BD403D]9P@0D3/a101_Fdl407]XF`<0O6YK101oK64407m/G`@0OFYM
101kJ5T407aZH0<0P6UK101iGDl407UMCP@0MEI8101bEDP4079EB`@0LeM;0`1eF4/407EAA@@0LU98
101`DDH4071CA0@0K4m00`1ZC3l406I6>@@0Cc4V100o9Q/402HF4P@0718<100I410301lD40@06a4@
100B20P401@;2`@07aDC10000003089oOb<0Ogem5P3oool001@0oooo7`1oOGd407]UGP<0>bXV100a
91l403PX90@0=b@K100`8Qd402TL60@0<2<N0`0/81`4038Y9@@0=BdV101@>c4406mKC`@0NfQK0`1l
JU/407m/H@@0OfaO101mJUd407]XF@@0O6YP0`20JE/407UMC`@0NEe>101eETP4079EB0@0LUE;101c
Ed/307EHB`@0ME55101bDTP4071AAP@0L5=4101/Cd0306Y<?`@0ITHi101?<BH403lV6`@09QHB100L
4P`401T@40<07a@@100K4A04018820@050/;100O5A<4000000<0PWmo8`1oOGdF0?ooo`00503ooolO
07mmO@@0NfEN0`0k:RH4034T7`@0>2PT100g91/4030R7@@0:A`H100`8ah302`P70@0<RTU100e;BH4
050k<@@0Ke]?101kJ5/307aZF`@0OfaQ101oK5l407eZG@@0NfQI101lJV03081YF`@0NEe?101iGDh4
07EFB0@0LUE8101bED/407=GB`<0MEQ;101eDDD4079BB0@0L556101`Dd@406a?@0<0JT`o101VAST4
04la9P@0?bHK100V5Q8401`B30@06A0@0`0O510401/A40@04PP8100D2`/401lE4`@000000`22OglS
07mmOAH0oooo000D0?oooal0Ogem101eH5@304<a:`@0=bTU100a9B4403DW8`@0:AXI100Z71T402XO
6`<0=BPT100a8AT402hQ6`@0?34Z101HA3T4071HC0<0MEiB101kI5L407]VF@@0OFYM101kIUT407QR
EP<0O6MI101hFdh4079AAP@0MEI8101bCd84079AA@@0Ke=60`1eEDP4071@A0@0KU12101_BSl406Q;
?`@0I4/l0`1J?C0405Pi:`@0@BPM100X5Q84020F4@@06a4<100E30/301@;30@03@P8100<20P4024F
4`@0:QXC1009108V07mmOAH0oooo000D0?oooal0Ogem101eH5@304<a:`@0=bTU100a9B4403DW8`@0
:AXI100Z71T402XO6`<0=BPT100a8AT402hQ6`@0?34Z101HA3T4071HC0<0MEiB101kI5L407]VF@@0
OFYM101kIUT407QREP<0O6MI101hFdh4079AAP@0MEI8101bCd84079AA@@0Ke=60`1eEDP4071@A0@0
KU12101_BSl406Q;?`@0I4/l0`1J?C0405Pi:`@0@BPM100X5Q84020F4@@06a4<100E30/301@;30@0
3@P8100<20P4024F4`@0:QXC1009108V07mmOAH0oooo000D0?oooal0Ogem101eH5@304<a:`@0=bTU
100a9B4403DW8`@0:AXI100Z71T402XO6`<0=BPT100a8AT402hQ6`@0?34Z101HA3T4071HC0<0MEiB
101kI5L407]VF@@0OFYM101kIUT407QREP<0O6MI101hFdh4079AAP@0MEI8101bCd84079AA@@0Ke=6
0`1eEDP4071@A0@0KU12101_BSl406Q;?`@0I4/l0`1J?C0405Pi:`@0@BPM100X5Q84020F4@@06a4<
100E30/301@;30@03@P8100<20P4024F4`@0:QXC1009108V07mmOAH0oooo000D0?oooal0Ogem101e
H5@304<a:`@0=bTU100a9B4403DW8`@0:AXI100Z71T402XO6`<0=BPT100a8AT402hQ6`@0?34Z101H
A3T4071HC0<0MEiB101kI5L407]VF@@0OFYM101kIUT407QREP<0O6MI101hFdh4079AAP@0MEI8101b
Cd84079AA@@0Ke=60`1eEDP4071@A0@0KU12101_BSl406Q;?`@0I4/l0`1J?C0405Pi:`@0@BPM100X
5Q84020F4@@06a4<100E30/301@;30@03@P8100<20P4024F4`@0:QXC1009108V07mmOAH0oooo000D
0?oooal0Ogem102HS9<3050g<P@0>2TU100e9b8403P[9`@0>BDK100[6AD4034U8@<0;R4L100e:BH4
02/N6@@0;2DQ100i;RH404/h;P<0HDTo101`EDP406mFC@@0LU]C101bGE8407=MD@<0MUY<101XC3d4
05m2=P@0I4Df101[CD0406i=@@@0KTTl0`1^Bd04071@?@@0K4`m101ZBC`406I4=`@0HD@g0`1B=BX4
044T6P@0=A`F100V5Q4401/A30@05P`<100E30`3014820@03@P8100D2`/401TB3`@0=C/m1014?C/V
07mmOAH0oooo000D0?oooal0Ogem102HS9<3050g<P@0>2TU100e9b8403P[9`@0>BDK100[6AD4034U
8@<0;R4L100e:BH402/N6@@0;2DQ100i;RH404/h;P<0HDTo101`EDP406mFC@@0LU]C101bGE8407=M
D@<0MUY<101XC3d405m2=P@0I4Df101[CD0406i=@@@0KTTl0`1^Bd04071@?@@0K4`m101ZBC`406I4
=`@0HD@g0`1B=BX4044T6P@0=A`F100V5Q4401/A30@05P`<100E30`3014820@03@P8100D2`/401TB
3`@0=C/m1014?C/V07mmOAH0oooo000D0?oooal0Ogem102HS9<3050g<P@0>2TU100e9b8403P[9`@0
>BDK100[6AD4034U8@<0;R4L100e:BH402/N6@@0;2DQ100i;RH404/h;P<0HDTo101`EDP406mFC@@0
LU]C101bGE8407=MD@<0MUY<101XC3d405m2=P@0I4Df101[CD0406i=@@@0KTTl0`1^Bd04071@?@@0
K4`m101ZBC`406I4=`@0HD@g0`1B=BX4044T6P@0=A`F100V5Q4401/A30@05P`<100E30`3014820@0
3@P8100D2`/401TB3`@0=C/m1014?C/V07mmOAH0oooo000D0?oooal0Ogem102HS9<3050g<P@0>2TU
100e9b8403P[9`@0>BDK100[6AD4034U8@<0;R4L100e:BH402/N6@@0;2DQ100i;RH404/h;P<0HDTo
101`EDP406mFC@@0LU]C101bGE8407=MD@<0MUY<101XC3d405m2=P@0I4Df101[CD0406i=@@@0KTTl
0`1^Bd04071@?@@0K4`m101ZBC`406I4=`@0HD@g0`1B=BX4044T6P@0=A`F100V5Q4401/A30@05P`<
100E30`3014820@03@P8100D2`/401TB3`@0=C/m1014?C/V07mmOAH0oooo000D0?oooal0Ogem102>
Sh/306eGC0@0=B@O100b9B44030T80@0;R@O100X6QT402/M5P<0=BHQ100e:RH403`/:0@0;B8O100f
:bL403P^9`<0@RhT101?>S@404Pg<0@0CSX^101H@SP405Y5>@<0FT4g101H>bh404`c9P@0C3HX101F
=bX405m0<@@0I4Pg0`1V@C@405dl<@@0GC//101O?S8405Pl<`@0CS0W0`159Q`403DK5P@09aHA100K
4@`401H<30@04@P82`0<20P401TC3`@08aLC100010@407ahN2H0Ogem5P3oool001@0oooo7`1oOGd4
08j?R`<0KEM<100e91l4038U8@@0<2@P100^91l402PJ6@@0:adF0`0e9R4403DZ9P@0?2`X100]8Ql4
03H[9`@0>2hW0`12;R@404lj=0@0B3L`101>>Rh405Q2>0@0FTDi0`1J@CL405Pk;P@0C3<V101<=RP4
05Hg:P@0Gd0a101TB3L306I1=0@0GC`a101M>b`405ln<P@0F3`c101><2L304DV70@0=A/F100W5Q44
01/A30@05P`<100A20P;00`820@06A<?100S5a<4000410@0O7Qh9P1oOGdF0?ooo`00503ooolO07mm
O@@0SXn;0`1]Ed`403DT7`@0<RDQ100`920402hT7`@0:1XI100[7AH303DV8@@0=BXV100l;2P402dR
7`@0=R/W100h;RL3048^90@0CcXd1018=c0404hj;P@0F48h101JACT305Y1=`@0F3/^101<<bH404`f
:0@0ESLZ101O@34406A8=`<0IT4d101M?34405dk;0@0Gchb101H?3<404h`9`<0ABHL100e6aH402LF
4@@06a4<100F30`4014820/030P8100I4`l402<G4`@000@4101lN7PV07mmOAH0oooo000D0?ooob<0
Ogem0`2:O8<404@`:`@0=2LS100d:BD403DW8P@08ALB100V7A/303HZ9@@0>2/W100o<Rd4040c;P@0
?S<[100n=Bd303hb:P@0?RXS100l9Qh403HU8@@0?BHO1016<2L304<]9`@0>bXW1012:R84040W70@0
@2TP1018<2L404`e:0<0DC@V101B=bX404T_8P@0B30W101:;284040X7`<0<A/F100]7AP401dB3@@0
6Q4<100F30`4014820@03@P80`0<20P401dC40@0610@100a<S4402DN7BX0Ogem5P3oool001@0oooo
8`1oOGd308YlP`@0A30[100d9b<403@Y9@@0=BLR100Q5a8402HM6`<0=RXU100h:bL403lb;@@0@3<^
100n<b/403he;@<0?S8Z100n:R<403`V7P@0=RDQ100m9Ql404H`9`<0@bdW100k:RL4048Z8P@0@2LL
1010:B0404P`9`@0C3DX0`1A=2H4058g:P@0BBlR1018<2L404X/8P@0@2PO0`0a6aH402dM60@07A8=
100J4@`401H<30@04@P8100=20P300`820@07A<@100H4104034b<@@09AhM:P1oOGdF0?ooo`00503o
oolS07mmO@<0RWb31014<2/403@W8`@0=2TU100e9b84024G4P@09QdK0`0f:RD403P[9`@0?c8]1010
<bh403hc:`@0?SD]0`0n<RX403hZ8`@0?2HN100f9B4403dV7`@0AS0W0`13;BL403/Z9`@0@RXR1010
9a`4040Y80@0B30W101<=BP3054d9P@0DSLZ1019;b8404P`9`@0BR`R1010:1l3034K5P@0;AdH100M
4Pd401XA30@05P`<100A20P400d820<030P8100M4a0401P@40@0<C8a100U7QdZ07mmOAH0oooo000D
0?ooob<0Ogem0`2:O8<404@`:`@0=2LS100d:BD403DW8P@08ALB100V7A/303HZ9@@0>2/W100o<Rd4
040c;P@0?S<[100n=Bd303hb:P@0?RXS100l9Qh403HU8@@0?BHO1016<2L304<]9`@0>bXW1012:R84
040W70@0@2TP1018<2L404`e:0<0DC@V101B=bX404T_8P@0B30W101:;284040X7`<0<A/F100]7AP4
01dB3@@06Q4<100F30`4014820@03@P80`0<20P401dC40@0610@100a<S4402DN7BX0Ogem5P3oool0
01@0oooo8`1oOGd309J@T0@0G40l200d9B44038V8P@0>BPT100`9R8303DZ9P@0?C4/100h:RH403LY
9@@0>2DR1010:24303lW7P@0=RLQ100/7QX4030S7`@0:QTF100_8Ah303HW8P@0;b8M100Y6AD402XL
60@0:QTD100Y5a<4034P60<0=28I100a81P4034J5@@0;QPC200/6AD3028F4@@06A0<100G3@`801D<
30@03@P8100<20P301dC5P@07A<@100`8ah401PV:@@0HeaJ:P1oOGdF0?ooo`00503ooolS07mmO@<0
UY2@101L@3`803@U8@@0<RHR100i:2@4030V8P<0=BXV100m<B`403PZ9P@0=bTU100h9B84040X8@<0
?bLN100f9b4402`N6P@0<2<O100Z6AH402lQ7P<0=RLR100_8Qd402TI5@@0:Q`H100Z6A@402TG4`@0
<B0H0`0d8QT4034P60@0<AXE100^61<802`I5@<08QHA100I40`401L=30P05@`<100=20P400`820<0
7A<F100M4a04030S7P@062HY101SG5XZ07mmOAH0oooo000D0?ooob<0Ogem0`2FT90405a0?0P0=2DQ
100b9R8403TX90@0<2HR0`0e:RH403da;0@0>2XV100g:BD403PU8P@0@2PQ0`0o9ah403HW8@@0;1hJ
100`8al402XI5P@0;b4N0`0f9b8402lR7@@0:ATE100Z71P402XI50@0:ALC100a81P303@R6@@0<B0H
100a6QD402hH4`P0;1TE0`0R5Q4401T@30@05`d<200E30`400d820@030P80`0M4aH401dC40@0<2<N
100H9RT406=LFRX0Ogem5P3oool001@0oooo8`1oOGd309J@T0@0G40l200d9B44038V8P@0>BPT100`
9R8303DZ9P@0?C4/100h:RH403LY9@@0>2DR1010:24303lW7P@0=RLQ100/7QX4030S7`@0:QTF100_
8Ah303HW8P@0;b8M100Y6AD402XL60@0:QTD100Y5a<4034P60<0=28I100a81P4034J5@@0;QPC200/
6AD3028F4@@06A0<100G3@`801D<30@03@P8100<20P301dC5P@07A<@100`8ah401PV:@@0HeaJ:P1o
OGdF0?ooo`00503ooolS07mmO@<0QHB1102?PH<4044^:@@0<RDQ100e:2@403@V8P@0>BhZ0`0a8ah4
03DY9P@0<b@O100d9b<403da:@@0>2XV0`0f9b8403DU80@0<B<N100c9R8402`L6`@09adJ0`0Z6AD4
02/I5@@091HA100N5104024E4@@09aPD100Y5a@302<E4@@08A@@100R5A4402PH50@091DA100Q5103
01`A30@06A4<100F30`401D<30P030P8100D2`/301lH5@@0:QTE100d=CD404M7Abh0Ogem5P3oool0
01@0oooo8`1oOGd308F4P@@0Sh631011;RT4038U8@@0=BPT100d9R8403T^:P<0<B<N100e:BH403<T
7`@0=2LS100m<BT403PZ9P<0=RLR100e9B04034S7P@0<bHR100/71/402LM6P<0:QTE100[6AD402@F
4@@07Q@@100Q5A4402LH50@0:ALD0`0S5A44024D40@08QDA100X61@402@E4@@08A@@0`0L4@`401TA
30@05P`<100E30`800`820@050/;0`0O61D402XI5@@0=3De1017AdL^07mmOAH0oooo000D0?ooob<0
Ogem0`25Q84408n1P`@0@BhY100b9B4403DX90@0=2HR100i;RX3034S7P@0=BTV100c91l403@W8`@0
?C4Y100h:RH303HW8P@0=BDP100a8ah403<V8P@0;1`K100W7AX302XI5@@0:aTE100T5Q4401hD40@0
8ADA100W61@402TG50<08aDA100Q5104028E4@@0:1PD100T5A44024D40<0714<100I4@`401H<30@0
5@`<200<20P401@;2`<07aPE100Z6AD403@e=@@0AdM7;P1oOGdF0?ooo`00503ooolS07mmO@<0QHB1
102?PH<4044^:@@0<RDQ100e:2@403@V8P@0>BhZ0`0a8ah403DY9P@0<b@O100d9b<403da:@@0>2XV
0`0f9b8403DU80@0<B<N100c9R8402`L6`@09adJ0`0Z6AD402/I5@@091HA100N5104024E4@@09aPD
100Y5a@302<E4@@08A@@100R5A4402PH50@091DA100Q510301`A30@06A4<100F30`401D<30P030P8
100D2`/301lH5@@0:QTE100d=CD404M7Abh0Ogem5P3oool001@0oooo9P1oOGd40968RP@0G3Xe100h
:2@403DX90@0=BLR100Y81/303/^:P@0>BhZ100j;BT402dQ70@0<R<L100a7aT702hQ70@09AXM100U
7Q/402/K6P@0:1LD0`0S5QT401hD4@@07QDA100J4@`801/D40@07A@@0`0K4@`401D<30@0610<100N
4a0401/A30@05@`<0`0I40`401T@40@05P`<100<20P401D<30@06a<@100T6aL302DG4`@0@D921011
?clb07mmOAH0oooo000D0?ooobH0Ogem102AR8X405`j=@@0>2PT100e:2@403DW8P@0:B0K0`0k;RX4
03T^:P@0>RdY100]8A`4038S70@0<AlI1`0^8A`402DJ7@@09AhK100[6aX402PG50<08aHI100N5144
01hE4@@06Q4<200K510401dD40<06a4<100E30`401P@30@07Q<@100K4@`401D<30<06A0<100I4104
01H<30@030P8100E30`401/C40@091/G0`0U5a<40452@P@0@Clo<P1oOGdF0?ooo`00503ooolV07mm
O@@0THR:101L>SD403PX90@0=BPT100e9b8402TP6`<0>bhZ100i;RX403X]:@@0;B4L100b8a`4034O
6@L0;R4L100U6Qd402DN6`@0:a/J100X5a@302<F6@@07Q@A100N5A4401XA30P06a@@100M510301/A
30@05@`<100H40`401hC40@06a4<100E30`301T@30@06A0@100F30`400`820@05@`<100K4a0402@K
5`<09ALC1011@T84044o?c80Ogem5P3oool001@0oooo9P1oOGd40968RP@0G3Xe100h:2@403DX90@0
=BLR100Y81/303/^:P@0>BhZ100j;BT402dQ70@0<R<L100a7aT702hQ70@09AXM100U7Q/402/K6P@0
:1LD0`0S5QT401hD4@@07QDA100J4@`801/D40@07A@@0`0K4@`401D<30@0610<100N4a0401/A30@0
5@`<0`0I40`401T@40@05P`<100<20P401D<30@06a<@100T6aL302DG4`@0@D921011?clb07mmOAH0
oooo000D0?ooobH0Ogem1028RHL407YUH@@0>bTT100e:2@403DW8P@0>2TU0`0_9b<403@X90@0<b@O
100/7QX402LL60@09QHA0`0Y7QX402LI6@@0:1TH100Q5144028E60@06A4A0`0F30`401T@4@@06A0@
100F30`401P@40@05@`<100H410301H<30@06A0@100K4a0401P@40@05P`<100=20P300`720@030P7
100<20P401P@40@05a0<100D2`/401`?2`<0?3hm100n>S/f07mmOAH0oooo000D0?ooobH0Ogem1028
RHL407YUH@@0>bTT100e:2@403DW8P@0>2TU0`0_9b<403@X90@0<b@O100/7QX402LL60@09QHA0`0Y
7QX402LI6@@0:1TH100Q5144028E60@06A4A0`0F30`401T@4@@06A0@100F30`401P@40@05@`<100H
410301H<30@06A0@100K4a0401P@40@05P`<100=20P300`720@030P7100<20P401P@40@05a0<100D
2`/401`?2`<0?3hm100n>S/f07mmOAH0oooo000D0?ooobH0Ogem1028RHL407YUH@@0>bTT100e:2@4
03DW8P@0>2TU0`0_9b<403@X90@0<b@O100/7QX402LL60@09QHA0`0Y7QX402LI6@@0:1TH100Q5144
028E60@06A4A0`0F30`401T@4@@06A0@100F30`401P@40@05@`<100H410301H<30@06A0@100K4a04
01P@40@05P`<100=20P300`720@030P7100<20P401P@40@05a0<100D2`/401`?2`<0?3hm100n>S/f
07mmOAH0oooo000D0?ooobH0Ogem1028RHL407YUH@@0>bTT100e:2@403DW8P@0>2TU0`0_9b<403@X
90@0<b@O100/7QX402LL60@09QHA0`0Y7QX402LI6@@0:1TH100Q5144028E60@06A4A0`0F30`401T@
4@@06A0@100F30`401P@40@05@`<100H410301H<30@06A0@100K4a0401P@40@05P`<100=20P300`7
20@030P7100<20P401P@40@05a0<100D2`/401`?2`<0?3hm100n>S/f07mmOAH0oooo000D0?ooobX0
Ogem102TXj@406eID`@0=BDP100b9B44034W90<0=2TU100g;2P403LX9`@0;AXF100Z71P4020F4@<0
7Q<?100O5A44024D40@05``<100E30/401T@4@<06A4A100E30`401P@40@05P`<100H3a0401H<30@0
91HC0`0>20P401H?3`@06a<@100J4A0400d820@030P80`0@20P401P@40@06A0@100G410402HG50@0
<B0H100n<BT301lF40@0O7Qh=P1oOGdF0?ooo`00503ooolZ07mmO@@0Y:>T101]FE<403DU80@0<RDQ
100a9b@303@Y9@@0=b`X100g:2L402dJ5P@0:Q`H100P5Q4301hC3`@07aDA100Q510401L<30@05@`;
100I414301TA4@@05@`<100H410401H<30@060l@100F30`402@F4`<03PP8100F3`l401/C40@06Q4@
100=20P400`820<040P8100H410401T@40@05a0@100V5a@4034P60@0?S4Y0`0O5Q0407ahN3H0Ogem
5P3oool001@0oooo:P1oOGd40:BSY0@0KEUC100e9B04038U8@@0<BLT0`0d:BD403L/:0@0=bPW100]
6QH402XL60@081HA0`0N4`l401lE4@@08A@@100G30`401D<2`@06A0A0`0I4A4401D<30@0610@100F
30`401P?40@05P`<100T5Q<300h820@05Pl?100K4a0401XA40@03@P8100<20P3010820@0610@100I
410401L@40@09QLD100a81P403ha:@<07aH@101lN7Pf07mmOAH0oooo000D0?ooobh0Ogem102TXj@4
06mEC`@0>B`W100_8Qd303HZ9`@0>2`X100n;bX4030U80@0;B0L100V5QX301TA4@@08A@@100I4A04
01hE4@@07A@@100I410701D<30@050/;100E30`401@;2`@071@@100F4103030W;@@0:RLY100S5QX4
01L<30@06Q4A1`0L510401P@40@0:1hK100[7AT402HH50@0>2LQ100n?Cd3061DCSX0Ogem5P3oool0
01@0oooo;P1oOGd40:BSY0@0KeE?100i;2L402lR7@<0=RXW100h;2P403h_:P@0<2DP100]81`402HF
6P<06A4A100Q510401TA40@07QDA100M510401T@40L05@`<100D2`/401D<30@050/;100L510401H@
40<0<2L]100Z9bT402<F6P@05``<100J4A4701`D40@0610@100X7Q/402/M6@@09QPD100h9b4403hm
?@<0H5A>>P1oOGdF0?ooo`00503oool^07mmO@@0Y:>T101_EDl403T/9`@0;b8M0`0f:RL403P/:0@0
?RlZ100`9B0402dP70@09QHJ0`0I4A44024D40@06A4@100N5A4401dD40@06A0@1`0E30`401@;2`@0
5@`<100D2`/401`D40@05Q0@0`0`9bd402XW:@@08aHJ100G30`401XA4@L071@@100H410402PN6`@0
:adI100V61@403PW8@@0?Sdm0`1PE4hj07mmOAH0oooo000D0?ooobh0Ogem102TXj@406mEC`@0>B`W
100_8Qd303HZ9`@0>2`X100n;bX4030U80@0;B0L100V5QX301TA4@@08A@@100I4A0401hE4@@07A@@
100I410701D<30@050/;100E30`401@;2`@071@@100F4103030W;@@0:RLY100S5QX401L<30@06Q4A
1`0L510401P@40@0:1hK100[7AT402HH50@0>2LQ100n?Cd3061DCSX0Ogem5P3oool001@0oooo<P1o
OGd40:JXZ@@0Ke==1012<Rd302hQ70@0<BLS100j<2/4048a;0@0=2<J100_7aT3020F4@@0610@100F
30`401P@30@06A0@100F30`301D<30@0610@100E30`401P@40@05@`<100D2`/402PT8`<09Q/P100g
;2d404<g<@@0>RTY100g:RL4030R7P<081HA100X71L402DJ5`@0=2LS100n:R8403hm?@@0ETY7?@1o
OGdF0?ooo`00503ooolb07mmO@@0YZRY101_Ddd4048b;@<0;R4L100a9b<403X`:`@0@S4/100d8aX4
02lO6@<081HA100H410401H<30@0610<100I410401H<30<05@`<100H410401D<30@0610@100E30`4
01@;2`@0:2@S0`0V6b0403L/;@@0@cLa100j:BT403LZ9`@0<28N0`0P5Q4402PL5`@09AXG100d9b<4
03hZ8P@0?Sdm101FBTLm07mmOAH0oooo000D0?oooc80Ogem102VZ:T406mCC@@0@S8]0`0^8A`4034W
8`@0>S0[1012<B`403@S6P@0;alI0`0P5Q4401P@40@05P`<100H40`401T@40@05P`<0`0E30`401P@
40@05@`<100H410401D<30@050/;100X92<302HK80@0=b`]1013=c4403XY:@@0=bXW100`8Qh3020F
4@@0:1`G100U6QL403@W8`@0?RXR100n?Cd405I:Acd0Ogem5P3oool001@0oooo<P1oOGd40:JXZ@@0
Ke==1012<Rd302hQ70@0<BLS100j<2/4048a;0@0=2<J100_7aT3020F4@@0610@100F30`401P@30@0
6A0@100F30`301D<30@0610@100E30`401P@40@05@`<100D2`/402PT8`<09Q/P100g;2d404<g<@@0
>RTY100g:RL4030R7P<081HA100X71L402DJ5`@0=2LS100n:R8403hm?@@0ETY7?@1oOGdF0?ooo`00
503ooolb07mmO@@0O7Yj102WZ:T406E7?0<0AcD_100h:BD403L]:P@0@3<^1012=C44034P6`<0;AhI
100a920402dR7P@08QDA100N510401XA4@<06A0@200E30`401/C5P@06Q4A100L510401H>3P<09b0K
100Z81l401`B4P@07QDA100K4a0401/B4@<08aDA100U6QH4030P60@0?2dS101CCT`404Xo?`@0OgYj
?@1oOGdF0?ooo`00503ooolb07mmO@@0O7Yj102WZ:T406E7?0<0AcD_100h:BD403L]:P@0@3<^1012
=C44034P6`<0;AhI100a920402dR7P@08QDA100N510401XA4@<06A0@200E30`401/C5P@06Q4A100L
510401H>3P<09b0K100Z81l401`B4P@07QDA100K4a0401/B4@<08aDA100U6QH4030P60@0?2dS101C
CT`404Xo?`@0OgYj?@1oOGdF0?ooo`00503ooolb07mmO@@0O7Yj102WZ:T406E7?0<0AcD_100h:BD4
03L]:P@0@3<^1012=C44034P6`<0;AhI100a920402dR7P@08QDA100N510401XA4@<06A0@200E30`4
01/C5P@06Q4A100L510401H>3P<09b0K100Z81l401`B4P@07QDA100K4a0401/B4@<08aDA100U6QH4
030P60@0?2dS101CCT`404Xo?`@0OgYj?@1oOGdF0?ooo`00503ooolb07mmO@@0O7Yj102WZ:T406E7
?0<0AcD_100h:BD403L]:P@0@3<^1012=C44034P6`<0;AhI100a920402dR7P@08QDA100N510401XA
4@<06A0@200E30`401/C5P@06Q4A100L510401H>3P<09b0K100Z81l401`B4P@07QDA100K4a0401/B
4@<08aDA100U6QH4030P60@0?2dS101CCT`404Xo?`@0OgYj?@1oOGdF0?ooo`00503ooolj07mmO@@0
Yj^^0`1RCD8403LV80@0<BHR1011=C4404Pm>@@0BSXd0`0_7a/402DH5`@0:aTE100b9B4402dR7@@0
718A0`0E30`4020G6`@08APL100V7Q/402@J7@@0;bDS100R5aX302`V9P@0=2LV100j:B@4034T8@@0
;b8M100b9B0303L^9`@0=2HQ1010<b/404Y7A0@0IUaC101eL7=107mmOAH0oooo000D0?ooocX0Ogem
102WZjh3069=@P@0=bHP100a9R84044e<@@0B3di101:>S@302lO6`@09APG100[6AD4038U8@@0;B8M
100L4Q4301D<30@081LK100Q61`402HN6`@091XM100_9B<4028G6P<0;2HV100d9bH403XY90@0<B@Q
100_8Qd4038U80<0=bhW100d9R44040c:`@0BTM4101VG5<407E`Ld40Ogem5P3oool001@0oooo>P1o
OGd40:N[[P<0HTe2100g9R04034V8P@0@CDa1018?CT404Xj=0<0;alK100U61L402/I5@@0<RDQ100]
8Qd401`B4@<05@`<100P5a/4024H70@09QhK100T6Qd402lU8`@08QLJ0`0/9RH403@W9P@0>RTT100a
924402lR7@@0<RDP0`0g;RL403@V8@@0@3<[101:Ad@406ILD`@0MG1c@@1oOGdF0?ooo`00503ooolj
07mmO@@0Yj^^0`1RCD8403LV80@0<BHR1011=C4404Pm>@@0BSXd0`0_7a/402DH5`@0:aTE100b9B44
02dR7@@0718A0`0E30`4020G6`@08APL100V7Q/402@J7@@0;bDS100R5aX302`V9P@0=2LV100j:B@4
034T8@@0;b8M100b9B0303L^9`@0=2HQ1010<b/404Y7A0@0IUaC101eL7=107mmOAH0oooo000D0?oo
och0Ogem0`2WYZT408UlO@@0CC`h100d9b<403T[9`@0@CXk0`1=@3d404Tk=P@0ASdj100f9bH4034Y
:@@0?cLk0`16?C`403DW9P@0;bD[100_8bH403dd=`@0<bPX100k:R@302`U8`@0?b`W100k9R8403/U
7@@0>BTT100m;bL304Hd:`@0B2/P100d>Sd4061FD0@0OgYjA@1oOGdF0?ooo`00503oooln07mmO@<0
YjJY1029O7d404dl>0@0=2LS100i:bL4044j>`<0CD0m1019>cH404Hm>P@0=RLV100a:BT403lg>`<0
ASdl100e9bH402lU:`@0;b<V100m=3L403<X:0@0>bXT0`0/9B<403l/9`@0>bHR100k9Ad403TY90@0
?BlW0`16=2/404P[80@0=3Xm101PEU0407mjNTD0Ogem5P3oool001@0oooo?P1oOGd30:NVZ@@0RGam
101=?3P403@W8`@0>B/W1011>S/304e0?@@0BC/f1016?CX403HW9P@0<BTY100o=c/304Hm?0@0=BLV
100_9B/402lS9P@0?C@g100c:2P403/Z90<0;2DS100o;2L403/V8P@0>bDM100i:B@403d_9`<0AS@[
1018:b0403@j?@@0H5I@101oNWY507mmOAH0oooo000D0?oooch0Ogem0`2WYZT408UlO@@0CC`h100d
9b<403T[9`@0@CXk0`1=@3d404Tk=P@0ASdj100f9bH4034Y:@@0?cLk0`16?C`403DW9P@0;bD[100_
8bH403dd=`@0<bPX100k:R@302`U8`@0?b`W100k9R8403/U7@@0>BTT100m;bL304Hd:`@0B2/P100d
>Sd4061FD0@0OgYjA@1oOGdF0?ooo`00503ooom107mmO@@0Rhb9102QVil4069?D`@0@C<`100h;bh3
040oA0@0CTA41019?S/40515?`@0C40n1014>cH304Hi>0@0ASD`100o<B/403DW:0@0;1lJ100d9b@4
03T/:0<0=BPT100n:R8404H]9@@0B34Y101>=Rh404<[8`<0A3Lg101cIV@404e7A4d0Ogem5P3oool0
01@0oooo@@1oOGd408^<R@@0XI^O101RCe<4044c<0@0>2l^0`10?d@404i4A0@0BChk101@ACl404a0
?P@0A3/f0`16>CP404He<0@0?c4[100e9bP402`O6P@0=2LT100i;2P303DX90@0?RXR1016;BD404Pa
:@@0CSH^1013:b<304@g=`@0LfIT101=AdA=07mmOAH0oooo000D0?oood40Ogem102;S8T40:6KW`@0
HTmC1011<c0403P_;P<0@3m4101>A4@404Tn>`@0D4Do101<@3h404@k=P<0ASTh1016=C0403la:`@0
=BLX100/7aX403@W90@0>B`X0`0e:2@403hZ8P@0ARdU1018<BT404hf;P@0@b/S0`14=cL407=VI0@0
CDM4C@1oOGdF0?ooo`00503oool407miN@@0OgYj@@1oOGd40:NVXP@0QH:71022Mg@30557D0@0DTM;
101PEU`4065CEP@0ETE0101@@Cd304ho>`@0ETE4101B@Ch405E3?@@0DT8o101;>c<404Hj=@<0DT8n
1018?3D404Hi<@@0?b`W1018@D4407QbM@<0LVeY101PFEYA07mmOAH0oooo000D0?ooo`@0OgUi101o
NWY107mmO@@0YjJR1025PXL4089gM0<0DDM@101BAd/4061FG0@0HE=F101FAD040511?@<0CSlk101F
AD@40591?P@0ED<m101B@Sl404/k<`@0ASXe0`1B@Sh404Pl=@@0ASTa100o;2L404Q1@@@0N79e0`1b
KFT4061IFU40Ogem5P3oool001@0oooo101oNGT407mjNT40Ogem102WYZ8408F2Q`@0PWMd0`1AAe04
0597B`@0H5IL101QDeH405I5@0@0D44m0`1>?c/405I5A0@0DT4n101E@cd40592?`@0Bc/c1016>SD3
0592?P@0B3`e1016>C4403l/9`@0B451101hLWD3079]J@@0H5UJD@1oOGdF0?ooo`00503oool407mi
N@@0OgYj@@1oOGd40:NVXP@0QH:71022Mg@30557D0@0DTM;101PEU`4065CEP@0ETE0101@@Cd304ho
>`@0ETE4101B@Ch405E3?@@0DT8o101;>c<404Hj=@<0DT8n1018?3D404Hi<@@0?b`W1018@D4407Qb
M@<0LVeY101PFEYA07mmOAH0oooo000D0?ooo`@0Ogem101oNWY907mmO@@0QHB10`2QViP4079eNP@0
MG9^1022OXL407mkPP@0OW1d0`1NDET404a5B`@0CT11101@?c/404Pl>@@0DD0m1018>SD3048c:`@0
B3L_101CDDh408R4PP@0G5iJ101_J6]H07mmOAH0oooo000D0?ooo`@0Ogem101oNWY907mmO@@0QHB1
0`2QViP4079eNP@0MG9^1022OXL407mkPP@0OW1d0`1NDET404a5B`@0CT11101@?c/404Pl>@@0DD0m
1018>SD3048c:`@0B3L_101CDDh408R4PP@0G5iJ101_J6]H07mmOAH0oooo000D0?ooo`@0Ogem101o
NWY907mmO@@0QHB10`2QViP4079eNP@0MG9^1022OXL407mkPP@0OW1d0`1NDET404a5B`@0CT11101@
?c/404Pl>@@0DD0m1018>SD3048c:`@0B3L_101CDDh408R4PP@0G5iJ101_J6]H07mmOAH0oooo000D
0?ooo`@0Ogem101oNWY907mmO@@0QHB10`2QViP4079eNP@0MG9^1022OXL407mkPP@0OW1d0`1NDET4
04a5B`@0CT11101@?c/404Pl>@@0DD0m1018>SD3048c:`@0B3L_101CDDh408R4PP@0G5iJ101_J6]H
07mmOAH0oooo000D0?ooof00Ogem1025Q7l407UgO@@0RhV40`2EShh407mmO@@0PX:9101oNg/407mj
NP@0Ogem1022Ogl308:2Q0@0OgYj101CE50407mjNV00Ogem5P3oool001@0ooooH01oOGd408F4O`@0
NGMm102;RH@309F?SP@0Ogem1022PXT407mkN`@0OgYj101oOGd4089oO`<0PX:4101oNWX405=DD0@0
OgYjH01oOGdF0?ooo`00503ooomP07mmO@@0QHAo101iMgd408^9Q0<0UHn>101oOGd408:2R@@0Og]k
101oNWX407mmO@@0PWmo0`22PX@407mjNP@0DeA@101oNWYP07mmOAH0oooo000D0?ooof00Ogem1025
Q7l407UgO@@0RhV40`2EShh407mmO@@0PX:9101oNg/407mjNP@0Ogem1022Ogl308:2Q0@0OgYj101C
E50407mjNV00Ogem5P3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool009/0oooo0T0000230?ooo`00W@3oool00d000000
oooo0?ooo`200?ooo`00N03oool3@0000080oooo0d0000030?ooo`03@000003oool0oooo00/0oooo
0d0000020?ooo`9000000`3oool3@00000D0oooo00=000000?ooo`3oool0NP3oool007P0oooo00=0
00000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003ooom0000000/0oooo00I0
00000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0oooo@0000880oooo001i0?ooo`03
@000003oool0oooo0080oooo00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`090?ooo`05
@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@0000880oooo001i0?oo
o`03@000003oool0oooo0080oooo00A000000?ooo`3oool0oooo0T00000=0?ooo`=0000000@0oooo
@0000400001000000`3oool3@0000880oooo001h0?ooo`03@000003ooom000000080oooo00=00000
0?oood0000000P3oool00d000000oooo0?ooo`0>0?ooo`03@000003oool0oooo08X0oooo001i0?oo
o`03@000003oool0oooo0080oooo00A000000?ooo`3oool0oooo0d00000=0?ooo`900000S03oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(270) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817E76
7B6B5D806F61806F65807368806F65807369807369807369807368806F64816F5F7C6A5B7C6555\
785E4F785D4E735A4B735A4B735A4B735A4B7358497355456F55456F55456F5545
6C534380807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
7B6B5D806F60806F65807368806F65807369807367817266817266816E61816D5D7C68587C6353\
785D4E785B4C735A4B735A4B735A4B7358497358497355476F55456F55456F5848
6C534380807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E807C7A80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E817E76
806F60806F65806F61807369806F65807368817266806E5F7C695A7C67587C6353786152735E4F\
735B4C735A4B6F55477358497358497358497355457355476F55476F55476C533F
6C655E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E807C7980807E807C7980807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807E76
7B6B5D806F61806F65806F65807368806F64806F657B6B5D6E675C776256785B4F735A4B735D4F\
735D4F735A4C7358496F55476F55476F55476F55476F57466F55476F55476C5343
80807E80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
806B5D806F64806F65806F65806F65806F65806F61806F65806F657C6B5C81625B775F50775B4E\
785A4F775B507351476F54476F574B6F55476F55476F55477358496F574A6C5343
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F78
806F60806F61806F60806F65806F65806F65806F65807368807369806F657B6B5D7C63587C6255\
7C6254785B4F7C6052735348735247735E546F55477355477355476E574B715B4C
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E817972807F78
806F61806F60806F64806F61806F65806F65807369806F65806F65807368806F65806F5F7B6758\
7C62577C6254785D4F785A4E735849735547735B4F6F55476F55476E55477B6E67
80807E80807E80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E6D5E52817E76715F56
806F61806F65806F61806F61806F65807368806F64807369807368807368806F64806F6481695B\
8166577C61547C615178584C785A4B7355476F55476F574A7357486C53437B7775
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807C79\
807C7980807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E807D7B512F27403F397B6B5D
806F61806F65806F65806F65806F65807369806F65806F61807367806D63816D60816B5B816D5D\
7C62577C62547C5D51785D4B7357487358487355476F5547735B4C71574880807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7A80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E7F807D573D2E6E6766221F22806F65
806F61807368806F65807368806F65806F65807369807368816F63816D5E81625A7C6152785E4F\
7C61527C61517860517358497858497358496F55456F55476F57486E574B80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E573D2E85847F2728237B6B5D806F61
806F65806F65806F64806F65806F65806F65806F658073688163597C60547C554C7C554A785347\
785D4E785B4C785B497357487355457355477355477355456F54457358497B6E67
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E807D7A817F7B272823807368806F64806F61
806F65806F63806F63806F5F806F65806F65807066806D638163597C49417C413778443E78423A\
78443E7853457354457355457351436F55457355477355476F54437353466F5748
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807C79\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E513D356E67637B6F67806F64806F64806F61
806F64816E6181695A806B5D806B5D806E6181635981554B815C547B4134784A41734038783A31\
73382E78423A6F483E6F52456F543F6F5243735547735547735547735245735A4B
715A4D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E7B716F7E71642228297B6B5D816E5E806F61806F61
806E61816B597C604F7B6256815D506925158163557C4D45774A42715149653B3073554575503F\
6E3C3469332773382E6F4A3E6F54416F513E6F5746735748735547735748735547
735A4B80787180807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E57433C5A5452635348806F60816D607B675A807368
806E61815D4978554364201880635D7744403B151077584E774D437B5E5581766C774038694B3F\
624A3C5F3A2F4927176E35296B4F406F513E735447735B4C785E4B735547735849
735748735B4B81787180807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E817F7E4B2F272B2E2E7B6B5D806F64806F607B6356806F65
8168597E5B42713A285F1E114529266E665D817269807871807B758077728170667C6B5D817063\
7B6F6867584F4F3A333B22186737296F5443735446775F51785E4F785D4B735445
735547735C4F736D707C777580807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E6D5E524B2F277263601D1F227B6B5D806E5E806E5E806F60806F64
81685978574A644C3B5D332D3B231D7750487C60527C5D5281686081655681594A78473B7C5549\
785B4C80604F6F504560493E3B1309673E336E5446775F4E7C6553785B4C735849
73534673574A6C665B6B635D716E7580807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E817E7C3121182E1C151D1F20634F48806F5F806D5F816759806759806D5F
816A5977503E775F527B6B5D806F6180635D7B5F56775B52775B527C514B72544B73463E734038\
6F42397353476F42366A392B57261A411D156F4C42775F4E7C6553785B49735445
6F5547735A4B593829807C7A6E676D80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E807C7980807E80807E80807E80807E80807E80807E\
80807E817F7E716B6A0D1F20171E21806F64806F5F806B5D80625C7B6B5D806F60
816158785748694D3F806F65807369806F65806F65807369806D63816D5D7C62547C6152785D4B\
7858487351437849406F4239623A30522E2856312973574A7C6151785B49735545
6F52457357485D44393B2F29807C797B777580807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E807F78716F73806F617C63567C6B5C806F60806B5D806F6180635D806F61
816E5E785D4E7351437C6759806F65807369806F65806F6580736781625A7C5E4F7C6151785B4A\
7757486F523F6F4E3F6F523F6F4E3F6F4F3F6B4D466E5441785D4E785A48735445
6F5543735547462C233B362B6C655E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
81807E807F78816E5E816B5B8071687B6B5C7B6B5D806F61806F65806F65807369
806D637C66577858497254487B6B5D807369807066816F63807367816B5B7C6051785041785B49\
6F503F674F3F6B4D3C6B4B3A6B4D3A6B48386A5040735A4B785B4C7857486F5143
6F52456F57462D1B182D2A2777727980807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
807F787B7773816B5B7C6353775F4F6C6663806B5D806F65807369807369807369
80736780635B7C61517855477B6356806F6580736880635D7B6B5D816D5E785E4F7858496F4C3F\
6F50416B483A6B4D3C6B4E406F513E6A50406A4D3E7858497858497355476F5143
6F52436F55473B2119271F1C68615B80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
807F78816F5F7F604C775F52715B4F7B6B5D80635D806F65807369807369807369
807368806F60816555785E4B77584C806F65807367806F65806F65816E617C5E51785B4C735547\
7354456B4B3A6B483A6B4E406E5347725448785B4C785E4F735748735547735547
6F52456F57476E503B2F211A332621807C7980807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807F7A\
8174688055467C62516B4D3E7B6B5D80635D806F61806F65807369807870807369
807368816F63816E5E775F52775F4F7B6B5D816D61806F60807066816B5B7C604F735445735243\
6F54416E4B3C6F4E3A6B4D406E5447775B507C6152785D4E735B4C7358496F5545
6F54456F574A735A4A674B393B201627201B80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E807B76\
816356784B3E6F433A6E54486C675D806F61806F61806F65807369807369807368
807367816F637B6A5B7C67597B6B5D806F61806F617B635A806E5E816158785A48734F416E4E3F\
6B4B3C6F4F3C614A3E6A4D41735B4E775F507C6152785D4E735849735447735447
6F54437354487355426F51436B4B3C80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807B807E76\
815E54774B3C6F463E6C574C7B6B5D806F65807369806F65807368817266807367
806D63816E5E7C695A8167587B6B5D806F64807368806F65806D63816251785A4A6F4F416B4D3E\
674B3E674C3E6B5043735B4C775F507861527C6051785D4E735748735445735145
7352456F5448735A4D6B4C3D6F544885858280807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E81796B7F6251\
734F3B744B3B6A4D3F715B4F806F61806F65807368807367806F63816F637C695B
816D5D81625B7C67597C63567B6759806F65806F61806F65816F638160567854456F4F416B4D3E\
6B4E406752456E5747735B4C785E4F7C6254785E4F785A4B735A4B735245735143
6F51456F5748734D387354476F50416C656380807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E816E5C5C331E\
5F392C472C245C463C776356806F61806F64806F64806F65806F61806B5D7B6B5D
7C62587860527C60537C6A5B7C6B5C806F61806F65806F64816D617C65547753486F4F3F6B4B3C\
6B4E406F53466F5547785A4E785D4F785B4C786051785B4C7358497358496F5445
6F51456F52477255416B42327355476C453680807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807D81776F704432\
3B251B422922373130776356816F63806F65806F60816B5B816B5E7E63537E6353
7E63567B584F78584C7358497C66577B6B5D806F65806F65816D5E7C5E517352416B483C6B4D3C\
674A3C6E5143725748735547735B4C78584C735748735A4B6F55476F55476F5445
6F51456F52476942306335226B49366C453A80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817D748170663C140D\
341C15311F19342F2F776356806F5F7B6B5D806F64816E5E725A4A6E5342563E34
4B322A5A36266944396E3E2C6E3E2C776355806F65806F65816E617C5E517352416B4E3A6A4736\
674F426B50436653466652456F5447725A4A6F5748735A4B7358496E54456E5445
6F52456F52476B453456302256332768402D80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E7F807D807D747C604F5C372E\
22130F2918142126277B67597C6B5C806B5D806F60806F617C6353645448523A2E
321F19331F17422F275E3E2F593A3056352E7B675A806F65816F637C6251714E3E6A4936562011\
6246386E503B7050406A47357252436E51456752437358497358496E5243675143
6751456E5243643E305A37295A392F66342580807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E4B211885776B816555643C2F\
2A1C1E2215102522247C6B5C806F607C6B5C816F5F806F61816F63735B4C7C5E51
443D35312C25392E25403D375C433872584B7B6B5D80736981756B7C655473503E624436603D2C\
452923563C321E0C0B5433274C372C4B2E216146396948326F503E6E5445674E40
6751436B4B3E533225492C225940356B423785858280807E80807E80807E80807E80807E80807E\
80807E80807E80807E
807C7A807C7980807E807C7980807E80807E80807E80807E512F274B2F27280804643A2C3C2224\
291913271916171E217C6B5C7B6B5D8165567C67567B6B5D806F657B6B5D775F51
6F55476F574861493A604A3B6E5848775C4E7B675A8073698170647C65557352416B4B38624636\
5A403557463C221615231812402A243828213B2D23533F345643346B4A3A675143
67524357342B452C1F3B231946332971534385858280807E80807E80807E80807E80807E80807E\
80807E80807E80807E
807C79807C7980807E80807E80807E80807E80807E80807E512F27311F182D19142918141E0F0E\
2718152718142124257B6B5C7C6B5C806F6573544A7150407E63537B6251735548
6A43356742306C47356E4534785E4C7C63567B675A8073678170637C61557358476B4B3867513A\
6B4C3C6F5547674C3F1F26263B2C2441332A31312C51403262483C6F55436B4F42
6751434F3122311C17372219402A1F68372880807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E57362726120D231712261611241612\
1B13102F221E2C28287B6759806B5D7B6B5D806F65725F5262483D644B405E4B3F
5241364B39314F3A2E544035563D34715F527B6B5D806D63816E5E7C615273554A643A2A643927\
67513A6F55436F55456F5547674F405B42375A43376B4E406F513F6751436F5543
6B4E3E3120182317122F2C27412A1F5D291B80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6043352B120D2214101D1510130908\
22151029211C373430725F51806B5D806F61806F65806F657B6B5D6C524B544A47
6C524B634A3F634E435D473E72584C7B6B5D816F63816F6381635B7C6657735F506B4C45502E26\
47291E4B2F206C4B396F55457355456F55436751436F5241654E3F6F5147675143
573526331D16251E1A292721633524492C2480807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E807C7980807E80807E80807E80807E57433C311F192314102215101A110C\
1D130F2B211C37342F6454487B6759806F61806F65807369807369807369807369
807369807369807369807369806F607B6B5D8073677C6A5B7C695A7C67587763557762556F574B\
4D3A3541312937251C472A1E623E305F45366745326143326B4E425E4B3E6F4F43
45251D2A18122518172A130E4F1F14492D252C241F80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E604942372924211612221510221510\
2217162B211C3B332C6650447B6759806F60806F65807369807369807871807871
807871807369807870807369807369806F60806F60816E5E7C67587C62547C67587C66587C6257\
735E526F524752423941342B3B2F254B352A473E34524034523E346E51456C4E3F
43241C2416111E15101C120D2A17133E262131292480807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60433537241B31201B20151025110C\
2718142D1F193A2E265A493D725F52806F60806F61806F65807369807369807871
807871807871807870807369807367807368806F5F816D5D7C67587C67587C62547C66577C6155\
786051735D4E6F55476653465E4C3F564338564237674B3F6751436B4A415F402F
3E231B2416112718141D15101F14102F1F183F393580807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E573D2E3929232E1E192A1A151B110C\
23141024161137251C4837296E584B7B6B5D806F61806F65807369807871807369
807871807870807870807369807367806F60816E61816A5B7C62547C66577C66577C62547C6152\
785D4E785A4B735B4C6F55477358496F55476E54456E51436E51456B4B3C482E25
25160E2819181B11101D120D1309082718143B312A63575580807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60433533251F3527222A1D192A1914\
1F1410271B172D231F3F2E255443357B6759806F61806F65807369807871807871
807369807870807369807369807368816F5F816E5E7C66577C66577C62547C62547C61527C6152\
785D4E735A4B735A4B735D4E6F55477355476E5445675143674F415C40323C221A
2C1E19160C0C1C12121208081911101D130F352B274F403A80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E5C49423929233529243326212A1A15\
1D120D27181432231C3E3128463C30725C4E806B5D806F65806F65807369807871
807871807871807369807369807368806F647C6A5B7C66577C61527C61547C6152786051785D4F\
785D4E735A4B7358497358497358496F52436F5445674E3F674639533225361F18
1D120D1D1212150C0C19110C170F0F241714130D09453B3680807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E81807E57433C352722372A25352722271813\
2A1C18241A162D1F1B412F25523E326A4D3F7B6759806F61806F65806F65807369
807871807871807870807369817266806F63816D5D7C6657776254785E4F7C5E52785D4E785B4C\
785A4E7357497358497355476F55476F54456B4E406C4B3C63423241291E311C16
2116111C14101C141018100C1C1410241714190E0980807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E807C794F3A3337261E332621372A25332621\
271B172D211C2F2119372F2952392C664C3F776356806F61806F65807369807369
80787080787080776F8172668171647C6B5C81695A7C61517C61527C6151785E4F785E4F785A4B\
735D4E7358496F52476F54456F54456E54456C4E3F6346364E30273B2019231712
1D120D1A1110160D0C0E0908160C0C2B211C1D120D85858280807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E60494231221939292335292432241F\
2E1C172F2119312520382C2347302657413472584C7B6B5D806F64806F65807367
807367807367807368806F647C6A5B7C66577C67567C6051785D4C785E4F785E4C785B4C785D4E\
7358497358497355476F54456F4F416C4E3F6346364E312843291D2A1813211611
201510191110160C0C150C0C1F151200000031201B80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6D5E5737272233251F392A2535241B\
2E221D2A1C1833251F30231E3B2D27483329674C3E7C6B5C816F5F806F60806F64
806F60816F5F816F5F806F64816D5D7C63537C6151785849785A4B785A4E785D4E785B4C785547\
7357497355477355456F52436E4F4168493A54352843291D2A18131F130D1B1110
2015101B1110120808150C0C2216131D120D85858280807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E6D5E5240302B352924332621372722\
2B1B192C1E192D211C35292431221939271F563F326F55457C68587C6A5B816E5E
816F5F816F5F7C6A5B7C6A5B816D5D7C5E4F785849785B49735445735849735849785849735445\
735445734F436E52436C503F664434614131452C1F2D19132317121B110C160C0C
160C0C0E09080D08082015122519131D120D80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E807B7A423029372A25352722372B26\
33231A2919153126212E221D372A252E1E193D2E25523A2E6C4B3B785D4E7C6251
7C65577C685A7C68587C66577C6251745544714E3E73503E735445735143735041735445735441\
6F4F416E4E3F6A493A64493A56392C49291D391F182717121B110C160D0C160C0C
1108080D0808130C0B1B130F21191427160D80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E5C4B4334241F352722332621\
3125202B1B192F1F18352722342A25372A252F231F3E30294633295A3B2C674A40
62483B6C4D3C7055477055456D4F41674534593A2B5F402E6942316E4B396F4E3C6E47386B4636\
6C463269473761423659372B4C2C1F391E172A17121D120D170D0C1208080D0808
0D08080D080819130F221613130D097B777580807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E7971723B2C25332723332924\
3326212117122B1F1C372A23372B263D312C3B2F2A3A2F293F332C453329472F27
452D23422D264F3025563C2F4E352C4730294C2F24492D1F4F30245A392B5D3D2C623C2B5D3D2E\
54332556372B543226472D22361E17311E191E120D1B110C160C0C1108080D0808
0C08081B130F160F0F2929261D120D80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E81807E4C3834332621352722\
3327223326212A231F342A253D312C392C273B2D283E2A25442F25402C21392A24
31201B372620311C173B27213D2A2434241F311D1734201A341D16381D1741281C41281C3F271B\
3D1F18391E17361F18341D172518121D120D190E0D160C0C160C0C0D08080D0808
1B13151B130F2B211C09090954453F80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E746B6C372722332621\
352924332621382E2932241F3B2E29362721372A253C2F283929243B2721372620
30231E3226212B1C1A2A1F1B2E1C172E1C172617122116112416122A19142C1914271712271712\
2717122C19142616112416111D120D1A110C160C0C150C0C0D08080D0808130C0B
1F1815271815130D0927201B80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E817E7C4E3530352924\
3529243527222E231E3E302B362C27372C272E221D39271F34231C32241F30231E
271C1E2C221D2D1D1B2919152417192116112116111B110C1D15101E15102116111D120D170D0C\
1B110C2215101D120D170D0C1B110C191110160C0C0D0808150C0C19130F1F1815
2216131D16121D120D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E675753372621\
372A253527223529242F2723392C273627212E201B2C1E192A18122D211C291B19
291B192216122417191C1212190D0D1B11121A1110160D0C191110160D0C1A1110160D0C191110\
1B1310191110170D0C0D08080D08080D08080D0808181010160F0B150C0C20110C
211D191D120D80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E4D403A\
30231E352722332924352A25372D283527252C1B162A1D19211612221510221712
231612180D0D170D0C1B1112191110150C0C191110160C0C181010160C0C2216130D0808181010\
1C14101A11100D08080D0808100808160F0F160F0F160F0F241714271D16242420
1309047B777580807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
4D3E3831272330231E372D28372D283B2E292E231F2D1F1B2416191A1110221510
1A11101E15101B1310181010160C0C160C0C150C0C160C0C150C0C1C14101810102D2425201E1D\
1F1417160D0C19111019130F19130F170F0F251D1A241A17241714352620271B12
4F372880807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807D4D3B36372D282E221D372C273D312C3B2E292F22192C1E191E1512191110
170D0C19110C1A1110160D0C160C0C181010150C0C181010150C0C150C0C272321241A1F362F2F\
362F2C2B212127211F251D1A1D1510251B17241A1733272334261F1D161140291F
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E8585824B372E3D312C332723382F2A40332D3D312C2E1E192A1D1929211C
241D1A1E13101C1410191110181010150C0C160C0C1B13161911101B13101810102C24202F2322\
221615261A15231813211514261712251B172F2119352B2335312B3B241B807C79
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E49372E362721372A2543373243393440332D2A1D19281A19
2E1C172F2520271E1A1A1110160C0C1F171A1E1618221C1820181C28211F1D15172924222F2523\
332621271F1C271E1A29211C2924212B211C342C25271F154A322471696C80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E494238362C27372A2542332E453E3C433732352C28
322B292F2220302926332D2C292725251E1D2922272B2223332D2C2D24233527222B24233E2D28\
37262237261E352924372C253B31293E2A2027201B4F3728807C7980807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E6C65674337353B2F2A3931304441424A3F3C
493D3849403A3B333238343243393A42352F382E2A31262830231F392C2A392D283529243F2C24\
402D25402E264131293C2A22483A344F372831201680807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E40373A3B362D3D393D534A48
4F4A484C45414B423C4D423F4D403A4B3F3C4138334439343B3331372F293B322E4138333D332D\
46332B422C254A3C334A372D3B241B4F403F80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
807C79807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E777275403B43
544948655F64594F4E5649424E43414E434153423F53423C4D403A53423C493B3449382F4F3D34\
40393040372D31241F685B5E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E777279807C796C656C4A454C4A454C453E38453B36453B36453B364037313B2E24\
3B3228807C7980807E80807E80807E80807E80807E80807E80807E80807E80807E
80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E80807E\
80807E80807E80807E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH0820OP@0PGif101k
Jed4081_H@@0P6mU1020LfP3081_I@`0P7=Y1020LfP4081_I0@0PFmO0`1lJU/407aUE@@0N5i?101h
GDh?07=JB`@0LeQ9101cEDD<06mEA@<0K5=35020P7h3081lNB<0P81n5P3oool001@0ooooF020P7h4
085nMP@0Nf]M1020Kf44081_I@@0P7=X0`20KfD<081cJ@@0P7=X1020Kf@4085_G`<0O6YK101lIED4
07QNC`@0N5e>3`1cFT/407=HB@@0LeE5301_EDD306aC@a@0P81n0`20O7TS0820OQH0oooo000D0?oo
oeP0P81n1021OWH407][G@@0P6mQ1020KfD4081cJ0<0P6mU3020LfT4081cJ0@0P6mT1021Kel307aZ
F`@0O6EE101hGTl407QMCPl0LeY;101cF4T407=EA@`0KeE50`1/Dd<D0820OP<0P7ai8`20P7hF0?oo
o`00503ooomH0820OP@0PGif101kJed4081_H@@0P6mU1020LfP3081_I@`0P7=Y1020LfP4081_I0@0
PFmO0`1lJU/407aUE@@0N5i?101hGDh?07=JB`@0LeQ9101cEDD<06mEA@<0K5=35020P7h3081lNB<0
P81n5P3oool001@0ooooF020P7h4081oN0@0Nf]M1020Kf04081_I@@0P7=X0`20KfD4081cJ@@0P7=W
2021LVH4085^H@@0PFeM0`1lJ5P407aSD`@0N5e>101hFd`;07=JB`P0LeQ9101cEDL806mEA@@0KeQ8
0`1/Dd<D0820OP<0P7ai8`20P7hF0?ooo`00503ooomH0820OP@0P7mh101kJed4081_H0@0P6mU1020
LfP3081_I@@0P7=Y1020LfL8085bIP@0PFiQ1021KEd307aXF0@0O6=C101hGDh407QKC0/0LeY;201c
F4T407=EA`P0KeE5101_F4P306aC@a@0P81n0`20O7TS0820OQH0oooo000D0?oooeP0P81n1020OgP4
07][G@@0P6mP1020KfD4081cJ0<0P6mU1020LfT4081cI`P0PG9V1021KV44085]G@<0O6QH101lHe<4
07QMCP@0N5]<2`1cFT/807=HB@@0LeE7201_EDD406mHB0<0K5=35020P7h3081lNB<0P81n5P3oool0
01@0ooooF020P7h4081oN0@0Nf]M1020Kf04081_I@@0P7=X0`20KfD4081cJ@@0P7=W2021LVH4085^
H@@0PFeM0`1lJ5P407aSD`@0N5e>101hFd`;07=JB`P0LeQ9101cEDL806mEA@@0KeQ80`1/Dd<D0820
OP<0P7ai8`20P7hF0?ooo`00503oool80820OP@0P7aj1`20P7h4081lNBL0P81n0`20O7TG0820OP@0
PGif1020Kf04081_I@@0P6mQ1020LfT3081_I@@0P7=X1021LVH4081^G`@0O6UJ101lIeP407aSD`<0
N65B101cGTl407=KC0@0LeY;101_EDL;07=HB@@0LeE5101cEDL806mEA`@0K5<o0`1/IEhj0820OQH0
oooo000D0?ooo`P0P81n1020O7X70820OP@0P7ai9`20P7h3081lNAL0P81n1021OWH4081_H0@0P6mU
1020Kf44081cJ@<0P6mU1020LfP4085bIP@0P6iO101lJEX407aWF0@0O6=C0`1hHE8407=NC`@0Le]<
101cFT/406mEA`/0LeQ9101cEDD407=EA`P0KeE7101/Dcl306aUGSX0P81n5P3oool001@0oooo2020
P7h4081lNPL0P81n1020O7TW0820OP<0P7ai5`20P7h4085nMP@0P6mP1020KfD4081_H@@0P7=Y0`20
KfD4081cJ0@0PG9V1020KUl407aYFP@0O6MH101lHe<307QQDP@0Lei?101cFd`407=JB`@0KeE72`1c
F4T407=EA@@0LeE7201_EDL406aC?`<0K6EN>P20P7hF0?ooo`00503oool80820OP@0P7aj1`20P7h4
081lNBL0P81n0`20O7TG0820OP@0PGif1020Kf04081_I@@0P6mQ1020LfT3081_I@@0P7=X1021LVH4
081^G`@0O6UJ101lIeP407aSD`<0N65B101cGTl407=KC0@0LeY;101_EDL;07=HB@@0LeE5101cEDL8
06mEA`@0K5<o0`1/IEhj0820OQH0oooo000D0?ooo``0P81n0`20O7T@0820OP@0P7ai0`20P7h4081l
NBh0P81n1020OWH407][G@@0P6mQ2020KfD3081cJ0@0P6mT1020KfD407][G@@0KVML101gHUH407QK
C`<0LeY;201cGDl407=JC0@0LeQ93`1_EDL406mGAPP0KeE7101/Dd<J0820OP@0P7ai7`20P7hF0?oo
o`00503oool<0820OP<0P7ai4020P7h4081lN@<0P81n1020O7T^0820OP@0P7if101kJed4081_H@P0
P6mU0`20LfP4081_I0@0P6mU101kJed406iWG0@0Mf9F101hFdl307=JB`P0Lee?101cFT`407=HB@l0
KeE7101_EdH806mEA`@0K5=36P20P7h4081lNAl0P81n5P3oool001@0oooo3020P7h3081lNA00P81n
1020O7T30820OP@0P7ai;P20P7h4081nMP@0Nf]M1020Kf48081_I@<0P7=X1020Kf@4081_I@@0Nf]M
101^Ie`407MREP@0N5]?0`1cFT/807=MC`@0LeY<101cF4T?06mEA`@0KeM6201_EDL406aC@aX0P81n
1020O7TO0820OQH0oooo000D0?ooo``0P81n0`20O7U90820OP@0P7mh1020Jed4081_I0l0P6mU1020
Kf48081_I@@0O6]L1021HU/307MOD0@0Me]>101hFTl407MKD0@0Le57101_E4L306mGB``0KeE7101c
F4T406mGBP@0K5=3?@20P7hF0?ooo`00503oool<0820OP<0P7aiB@20P7h4081oN0@0P6]M1020Kf@?
081_I@@0P6mQ2020KfD407a[G0@0PF9K0`1gGe0407MKCP@0N5Y?101gFe0407=AA`@0KeA70`1_Ed/<
06mEA`@0LeQ9101_EdX406aC@cd0P81n5P3oool001@0oooo3020P7h3081lNDT0P81n1020OgP4081[
G@@0P6mT3`20KfD4081_H@P0P6mU101lJe`4085RF`<0Mem@101gFdh407QJC`@0Me]@101cDDL406mD
A`<0KeM;301_EDL407=HB@@0KeM:101/Dd<m0820OQH0oooo000D0?ooo``0P81n0`20O7U90820OP@0
P7mh1020Jed4081_I0l0P6mU1020Kf48081_I@@0O6]L1021HU/307MOD0@0Me]>101hFTl407MKD0@0
Le57101_E4L306mGB``0KeE7101cF4T406mGBP@0K5=3?@20P7hF0?ooo`00503ooomH0820OP@0P7mh
1020Kf04081_H@@0P6mP3`20KfD4081cJ0@0P7=Y1020KfD407][G@<0O6=H101lHUD407aRE0@0N5]?
101lH58407=CB0<0Le97101cGU@406mEA`P0LeE7101^Ed/4075KC3d0P81n5P3oool001@0ooooF020
P7h4081oN0@0P6mP1020Kf44081_H0l0P6mU1020LfP4081cJ@@0P6mU101kJed307aSF0@0O69E101l
HU@407QKC`@0O61B101cDdP307=BA`@0LeiD101_EDL807=EA`@0KUM;101aFd`m0820OQH0oooo000D
0?oooeP0P81n1020OgP4081_H0@0P6mQ1020Kf0?081_I@@0P7=X1020LfT4081_I@@0Nf]M0`1lHeP4
07aRE@@0O69D101hFdl407aPDP@0Le=80`1cDTL407=NE0@0KeE7201cEDL406iGB`@0LE]<?@20P7hF
0?ooo`00503ooomH0820OP@0P7mh1020Kf04081_H@@0P6mP3`20KfD4081cJ0@0P7=Y1020KfD407][
G@<0O6=H101lHUD407aRE0@0N5]?101lH58407=CB0<0Le97101cGU@406mEA`P0LeE7101^Ed/4075K
C3d0P81n5P3oool001@0ooooE@20P7h3085iLP@0P7mh1020Kf44081_H0@0P6mT1020Kf47081_I@@0
P7=Y2020KfD4081cJ0@0P6mU0`20Kel407]WF0@0O69G101lHU@407QMC`@0N5Y>0`1cF4T407=EA`@0
Le]?201_EDL406iEA`@0NfiW7P20P7h4081lNA/0P81n5P3oool001@0ooooE@20P7h3085iLP@0P7mh
1020Kf44081_H0@0P6mT1020Kf47081_I@@0P7=Y2020KfD4081cJ0@0P6mU0`20Kel407]WF0@0O69G
101lHU@407QMC`@0N5Y>0`1cF4T407=EA`@0Le]?201_EDL406iEA`@0NfiW7P20P7h4081lNA/0P81n
5P3oool001@0ooooE@20P7h3085iLP@0P7mh1020Kf44081_H0@0P6mT1020Kf47081_I@@0P7=Y2020
KfD4081cJ0@0P6mU0`20Kel407]WF0@0O69G101lHU@407QMC`@0N5Y>0`1cF4T407=EA`@0Le]?201_
EDL406iEA`@0NfiW7P20P7h4081lNA/0P81n5P3oool001@0ooooE@20P7h3085iLP@0P7mh1020Kf44
081_H0@0P6mT1020Kf47081_I@@0P7=Y2020KfD4081cJ0@0P6mU0`20Kel407]WF0@0O69G101lHU@4
07QMC`@0N5Y>0`1cF4T407=EA`@0Le]?201_EDL406iEA`@0NfiW7P20P7h4081lNA/0P81n5P3oool0
01@0ooooD@20P7h406eNDP<0PGif101aGeH4081_H@@0P6mU2020Kf43081_I@@0P7=X1020Kf@4081c
J@P0P7=X1`20Kf@4085YF`@0PFIG101lHE@407aQD@@0N5Q<0`1hFT/407=EA`@0KeE7101_EdX407=G
B0@0K5=3101kMgD^0820OPL0P7ai2020P7hF0?ooo`00503ooomA0820OP@0KEiB0`21OWH4075OEP@0
P6mQ1020KfD8081_H@<0P6mU1020LfP4081_I0@0P7=Y2020LfP7081_I0@0PFUK1021IUL407aQE0@0
O65A101hF4`307QJB`@0LeE7101_EDL406mGBP@0LeM8101/Dd<407]gMBh0P81n1`20O7T80820OQH0
oooo000D0?oooe40P81n101]GU83085nMP@0LEmF1020Kf44081_I@P0P6mQ0`20KfD4081cJ0@0P6mT
1020LfT8081cJ0L0P6mT1021JE/4085VE`@0O65D101lHE4407QHC0<0N5Y;101cEDL406mEA`@0KeM:
101cEdP406aC@`@0NgMe;P20P7h7081lN@P0P81n5P3oool001@0ooooD@20P7h406eNDP<0PGif101a
GeH4081_H@@0P6mU2020Kf43081_I@@0P7=X1020Kf@4081cJ@P0P7=X1`20Kf@4085YF`@0PFIG101l
HE@407aQD@@0N5Q<0`1hFT/407=EA`@0KeE7101_EdX407=GB0@0K5=3101kMgD^0820OPL0P7ai2020
P7hF0?ooo`00503ooom=0820OP@0P7ek101A;bL3040o>@@0Nf]M1020Kf4?081_I@@0P7=Y1020KfD4
081_H@@0P7=W1020KF<4085]H0<0PF]K1021KEd407aRE`@0O69D101lGE4407QMB`<0LeM8101cF4P4
07=EA`@0KeE7101cFd`4075GB440P81n5P3oool001@0ooooC@20P7h4081mN`@0DBlW0`10?cT407][
G@@0P6mQ3`20KfD4081cJ@@0P6mU1020Kf44081cI`@0P6eS1021KF03085[F`@0PFeM101lHUL407aR
E0@0O5eA101hGD/307=GB0@0LeQ8101cEDL406mEA`@0Le]<101aEdQ10820OQH0oooo000D0?ooodd0
P81n1020OG/4054_9`<0@3li101kJed4081_H@l0P6mU1020LfT4081_I@@0P6mQ1020LfL4081]H`@0
PFeP0`21Je/4085]G@@0O69G101lHU@407aMD@@0N5e;0`1cEdP407=HB0@0LeE7101_EDL407=KC0@0
LEM8@@20P7hF0?ooo`00503ooom=0820OP@0P7ek101A;bL3040o>@@0Nf]M1020Kf4?081_I@@0P7=Y
1020KfD4081_H@@0P7=W1020KF<4085]H0<0PF]K1021KEd407aRE`@0O69D101lGE4407QMB`<0LeM8
101cF4P407=EA`@0KeE7101cFd`4075GB440P81n5P3oool001@0oooo3020P7h3081lNSX0P81n101o
P7d405Lm;P@0KVMV0`0R7b84081_I@@0P6mQ1020LfP4081_I@@0P7=X1`20KfD4081cJ@@0P7=X1021
Kf<4085]GP@0PF9J0`1lHE8407QNC`@0O65B101lHE4407QPD@@0LeQ90`1hF4T407=HB@@0KeE5101_
EDL406mGB0@0KUM;@@20P7hF0?ooo`00503oool<0820OP<0P7aj>P20P7h407n0O@@0Ecd^101^IfH3
028O8P@0P6mU1020Kf44081cJ0@0P6mU1020LfP7081_I@@0P7=Y1020LfP4085_H`@0PFeN1021HUX3
07aQDP@0N5i?101lHE8407aQD@@0N61A101cF4T307QHB@@0LeQ9101_EDD406mEA`@0KeM8101^Ed]1
0820OQH0oooo000D0?ooo``0P81n0`20O7Xj0820OP@0Oh1m101G?Bh406iWIP<08QlR1020KfD4081_
H@@0P7=X1020KfD4081cJ0L0P6mU1020LfT4081cJ0@0PFmS1021KEh4085RFP<0O65B101hGTl407aQ
DP@0O65A101hH54407=HB@<0N5Q9101cF4T406mEA@@0KeE7101_EdP406iGBd40P81n5P3oool001@0
oooo3`20P7h4081lNCH0P81n101G?Bh408F4O`@09bPS0`1kJed4081_H@P0P6mU1020Kf@?081_I@@0
P7=X1021HeT407aPE0@0O5E<0`1lEDX407QCA`@0N5e>101hFd`407QKB@@0LeM80`1cEDD807=EA`@0
LeE5101_E4D407=HB@@0NfiW?@20P7hF0?ooo`00503oool?0820OP@0P7ai=P20P7h405Lm;P@0QHAo
100W:2<307][G@@0P6mQ2020KfD4081_I0l0P6mU1020LfP4085SF@@0O61D101lED`307aEBP@0N5=7
101hGDh407QKC0@0N5]9101cEdP307=EA@P0LeE7101cEDD406mDA@@0LeQ9101kKVLm0820OQH0oooo
000D0?ooo`l0P81n1020O7Tf0820OP@0Ecd^1025Q7l402LX8`<0Nf]M1020Kf48081_I@@0P6mT3`20
KfD4081cJ0@0PF=I101lH5@407aEC0<0O5E:101hDdL407QMCP@0N5]<101hFdT407=GB0<0LeE5201c
EDL407=EA@@0KeA5101cF4T407]^Icd0P81n5P3oool001@0oooo3`20P7h4081lNCH0P81n101G?Bh4
08F4O`@09bPS0`1kJed4081_H@P0P6mU1020Kf@?081_I@@0P7=X1021HeT407aPE0@0O5E<0`1lEDX4
07QCA`@0N5e>101hFd`407QKB@@0LeM80`1cEDD807=EA`@0LeE5101_E4D407=HB@@0NfiW?@20P7hF
0?ooo`00503oool<0820OP<0P7ai=P20P7h4081mNP@0PGmk100W:2<4081cJ0<0P6mT1020Kf44081_
I@P0P6mS1020Kel7081_I@@0P71V1020KF<4085SF@@0O4U1101l@CL307Q4?P@0N48j101hA3h407QC
A@@0LeA5101cEDD307=A@`@0KeE5201cEDL406mD@`@0Le=6101_EdP^0820OP<0P7ai3020P7hF0?oo
o`00503oool<0820OP<0P7ai=P20P7h4081mNP@0PGmk100W:2<4081cJ0<0P6mT1020Kf44081_I@P0
P6mS1020Kel7081_I@@0P71V1020KF<4085SF@@0O4U1101l@CL307Q4?P@0N48j101hA3h407QCA@@0
LeA5101cEDD307=A@`@0KeE5201cEDL406mD@`@0Le=6101_EdP^0820OP<0P7ai3020P7hF0?ooo`00
503oool<0820OP<0P7ai=P20P7h4081mNP@0PGmk100W:2<4081cJ0<0P6mT1020Kf44081_I@P0P6mS
1020Kel7081_I@@0P71V1020KF<4085SF@@0O4U1101l@CL307Q4?P@0N48j101hA3h407QCA@@0LeA5
101cEDD307=A@`@0KeE5201cEDL406mD@`@0Le=6101_EdP^0820OP<0P7ai3020P7hF0?ooo`00503o
ool<0820OP<0P7ai=P20P7h4081mNP@0PGmk100W:2<4081cJ0<0P6mT1020Kf44081_I@P0P6mS1020
Kel7081_I@@0P71V1020KF<4085SF@@0O4U1101l@CL307Q4?P@0N48j101hA3h407QCA@@0LeA5101c
EDD307=A@`@0KeE5201cEDL406mD@`@0Le=6101_EdP^0820OP<0P7ai3020P7hF0?ooo`00503ooom5
0820OP@0DCde101^If<407]_I`L0P6mT1020Kf44081_I0@0PFiQ1021JEX7081[G@@0P6iQ1021HeT4
085EB`@0PEaD101k@C@407Q:@@<0Ld0h101h>S4407<h;P@0N48j101_B3h406mBA@<0Ke@o101_DT<<
07=EA`@0Le95101cFT/3075JCCX0P81n5P3oool001@0ooooA@20P7h4054m=@@0KVMS101kKfL7081_
I0@0P6mQ1020Kf@4085^H@@0PFUJ1`20Jed4081^H@@0PF=I1021ED/4085LE0@0Nd4d101hBT4307=0
>0@0N3Xa101c>2h407Q2>P@0KdPn101_DTD306mD?`@0Ke93301cEDL407=BA@@0LeY;0`1aFTdj0820
OQH0oooo000D0?ooodD0P81n101A?CD406iWH`@0NfmW1`20Kf@4081_H@@0P6mT1021KV44085YFPL0
P6]M1020KV44085SF@@0PEE;1021G5@407]1=0@0N4Y10`1c@3P407Pj<@@0LcP^101h@SX406m8?P@0
Ke950`1_E3l406mB@``0LeE7101cDTD407=JB`<0LEY=>P20P7hF0?ooo`00503ooom50820OP@0DCde
101^If<407]_I`L0P6mT1020Kf44081_I0@0PFiQ1021JEX7081[G@@0P6iQ1021HeT4085EB`@0PEaD
101k@C@407Q:@@<0Ld0h101h>S4407<h;P@0N48j101_B3h406mBA@<0Ke@o101_DT<<07=EA`@0Le95
101cFT/3075JCCX0P81n5P3oool001@0oooo@@20P7h407]aK`@0OW5T100R:2T407][G@@0PFiN1`20
Kf44081^H@@0PF]I101lH4l407]REP<0PEe@101Y9AD4085SE@@0O4e5101gBT84075AB@@0IC/`0`1c
EDD407E@?`@0KS`d101Y<bL407<h;P@0KdXn0`1_E44406mA?P@0KeM6101cEdP407=EA`@0LeM8101c
EDL307=JB`@0P7Qa=P20P7hF0?ooo`00503ooom10820OP@0Ng5_101nLF@4028X:@@0Nf]M1021KUh7
081_H@@0P6iQ1021JeT407aPC`@0Nf9F0`21GE0406TU5@@0PF=E101lCDD407M:@P@0LE59101U>c03
07=EA@@0ME0o101^?3@406Tc9`@0LcP^101_BSh306mD@@@0Ke4n101_EdH407=GB0@0LeE7101cEdP4
07=EA`<0LeY;1020N74f0820OQH0oooo000D0?oood40P81n101kLFl407iaI0@08RPY101kJed4085^
GPL0P6mQ1020KV44085[F@@0O61?101kHUH3085MD0@0JBDE1021HeD407a=A@@0MdY2101aDDT406Dk
<0<0LeE5101eD3l406hl=0@0JC<W101c>2h406m:?P<0KeA1101_DCh406mGAP@0LeM8101cEDL407=G
B0@0LeE70`1cFT/4081hLCH0P81n5P3oool001@0oooo@@20P7h407]aK`@0OW5T100R:2T407][G@@0
PFiN1`20Kf44081^H@@0PF]I101lH4l407]REP<0PEe@101Y9AD4085SE@@0O4e5101gBT84075AB@@0
IC/`0`1cEDD407E@?`@0KS`d101Y<bL407<h;P@0KdXn0`1_E44406mA?P@0KeM6101cEdP407=EA`@0
LeM8101cEDL307=JB`@0P7Qa=P20P7hF0?ooo`00503ooolC0820OP@0P7ai:P20P7h405M3?0@0FUAB
101SDdP4081_H0@0PFeP0`1kIeX4081cJ0@0P6iQ1021GDT407QE@`@0I20H0`20Hed407M4@0@0>aD@
101gF4h407M=@`@0NeiE1021MV`307M0>0@0JD/o101RBS`405lj;`@0BBLG101^=BT306]?@0@0Ke4n
101cE4L407=KC0@0N5i;101cEDL407=HB@<0LeM8101cFd/4085hLC80P81n5P3oool001@0oooo4`20
P7h4081lNBX0P81n101G@c`405YDDP@0He=81020Kf04085]H0<0NfMJ1020LfP4081^H@@0PEe9101h
ED<406@P60<0P6=M101gA40403/E40@0MeQ>101gCD<407]NE@@0PGI/0`1g@3P406U;?`@0HTXl101O
>Rl404TW5`@0KSDY0`1[Cd0406mA?P@0LeA7101cFd`407QNB`@0LeE7101cF4T307=GB0@0Le];1021
N74b0820OQH0oooo000D0?oooa<0P81n1020O7TZ0820OP@0Ed<l101JE58406=CB0@0P6mP1021KF03
07]WFP@0P7=X1020KV44085MB@@0N5E3101T81P3081SG@@0MdA0100k5A0407MHCP@0Mde3101kGUD4
085fK0<0Md0h101YBcl4069:?0@0GcX_10199aL406he:@<0Jdm0101_DCh407=DA`@0Le]<101hGT/4
07=EA`@0LeQ90`1cEdP407=KB`@0PGQa<P20P7hF0?ooo`00503ooolC0820OP@0P7ai:P20P7h405M3
?0@0FUAB101SDdP4081_H0@0PFeP0`1kIeX4081cJ0@0P6iQ1021GDT407QE@`@0I20H0`20Hed407M4
@0@0>aD@101gF4h407M=@`@0NeiE1021MV`307M0>0@0JD/o101RBS`405lj;`@0BBLG101^=BT306]?
@0@0Ke4n101cE4L407=KC0@0N5i;101cEDL407=HB@<0LeM8101cFd/4085hLC80P81n5P3oool001@0
oooo3020P7h3081lNBl0P81n0`21Ogh404/_9`@0:bh^101kJed4081_I0@0P6mP0`1kHeH4081_I@@0
PFQI101nFd84074j:0@0GahA0`15:BH406iVG@@0PG9Y1020N744081kM@@0P7Mb1021L6H307a[G@@0
PG1S101kKfP406MHC`@0CcXc100k8QP306Lg:@@0KeA3101cE4H407MOD@@0N5i?101hGD/407=DA@<0
LeE7101cG4l407=]L0@0O7Me;P20P7hF0?ooo`00503oool<0820OP<0P7ai;`20P7h3085oOP@0BblW
100[;Rh407][G@@0P6mT1020Kf0307]SEP@0P6mU1021J5T407iK@P@0LCXX101O7Q4304DY9P@0KVIM
1021LVT4081hL@@0P7]e1020Mg84085`IP<0O6]M1021L6<407]_J0@0IeQ?101?>S<403/R60<0IcLY
101_E4<407=DAP@0MemA101hGTl407QMB`@0LeA50`1cEDL407=LC`@0Lfe`101lMgD^0820OQH0oooo
000D0?ooo``0P81n0`20O7T_0820OP<0PGmn101;;bL402/^;P@0Nf]M1020Kf@4081_H0<0Nf=F1020
KfD4085XF@@0OU]2101a>RP405lN4@<0ABTV101^IUd4085bJ@@0P7Qa1020NgD4081gLP@0PG1V0`1l
Jed4085`H`@0NfmX101WF4l404lj<`@0>b8H0`1W=bT406mD@`@0LeA6101gGe4407QNC`@0N5e;101c
E4D307=EA`@0Lea?101cKG0407agMBh0P81n5P3oool001@0oooo3020P7h3081lNBl0P81n0`21Ogh4
04/_9`@0:bh^101kJed4081_I0@0P6mP0`1kHeH4081_I@@0PFQI101nFd84074j:0@0GahA0`15:BH4
06iVG@@0PG9Y1020N744081kM@@0P7Mb1021L6H307a[G@@0PG1S101kKfP406MHC`@0CcXc100k8QP3
06Lg:@@0KeA3101cE4H407MOD@@0N5i?101hGD/407=DA@<0LeE7101cG4l407=]L0@0O7Me;P20P7hF
0?ooo`00503ooolj0820OP@0KEiB0`1;;bL4079SH0@07AlR101kJed8081^GP<0P6mP1020Kf@4085X
F@@0N5M:101TC3/405dc;@<0>b<M101gD4P407aPDP@0O5eB1021J604085UEP@0PEU:0`1hAc/407aE
B@@0N5]<1020H4l406m@A@@0H4Tn0`0k4`T406Ln<`@0KUA6101gGdh407aUD`@0N5]<101cF4T307=C
AP@0LeM:101/IU/406]SG@@0LFie:P20P7hF0?ooo`00503ooolj0820OP@0KEiB0`1;;bL4079SH0@0
7AlR101kJed8081^GP<0P6mP1020Kf@4085XF@@0N5M:101TC3/405dc;@<0>b<M101gD4P407aPDP@0
O5eB1021J604085UEP@0PEU:0`1hAc/407aEB@@0N5]<1020H4l406m@A@@0H4Tn0`0k4`T406Ln<`@0
KUA6101gGdh407aUD`@0N5]<101cF4T307=CAP@0LeM:101/IU/406]SG@@0LFie:P20P7hF0?ooo`00
503ooolj0820OP@0KEiB0`1;;bL4079SH0@07AlR101kJed8081^GP<0P6mP1020Kf@4085XF@@0N5M:
101TC3/405dc;@<0>b<M101gD4P407aPDP@0O5eB1021J604085UEP@0PEU:0`1hAc/407aEB@@0N5]<
1020H4l406m@A@@0H4Tn0`0k4`T406Ln<`@0KUA6101gGdh407aUD`@0N5]<101cF4T307=CAP@0LeM:
101/IU/406]SG@@0LFie:P20P7hF0?ooo`00503ooolf0820OP@0PGil100a8AP302hL5@@07AlP101S
CdP4081_G`@0P6eO1021IeT3081WF@@0P6eO1021JUT407M@?P@0MemB101kJed3081_H@@0P6=M101k
GeH807MKDP@0O55;101bE4/307=6?P@0Ld0h101_@ST407=CA`@0Kd8f101Z>B/305LV6P@0@AdE101_
C48407MOCP@0O6EC101hFdT407=DA@<0KeE7101cFT/405Th:@@0P7aj101^IfdZ0820OQH0oooo000D
0?ooocH0P81n1021OW`4034Q60<0;Q`E100M7b0406=?B0@0P6mO1020KEl4085WF@<0P6MI1020KEl4
085ZF@@0Me0n101gGe8407][G@<0P6mQ1020Hed407]OEPP0Me]B101lDD/4079DB`<0LdHn101c@3P4
06m2>@@0Le=7101_@SH406Xi:`<0EbHJ10117AD406m<@P@0Mem>101lIE<407QKB@@0LeA50`1_EDL4
07=JB`@0FCPY1020O7X406iWKBX0P81n5P3oool001@0oooo=P20P7h4085nO0@0<B4H0`0^71D401dO
80@0Hdm81020Kel4081]G`@0PFMI0`20IeT4081]G`@0PFYI101gD3h407MODP@0Nf]M0`20Kf44081S
G@@0NemF201gFe8407aAB`@0LUA;0`1cASh407=0>0@0Kd8i101cDdL406m2=P@0JST[0`1G9QX4044M
5@@0Kda2101gGdh407aUD`@0N5]9101cE4D306mEA`@0LeY;101I>2T4081lNP@0KVM]:P20P7hF0?oo
o`00503ooolf0820OP@0PGil100a8AP302hL5@@07AlP101SCdP4081_G`@0P6eO1021IeT3081WF@@0
P6eO1021JUT407M@?P@0MemB101kJed3081_H@@0P6=M101kGeH807MKDP@0O55;101bE4/307=6?P@0
Ld0h101_@ST407=CA`@0Kd8f101Z>B/305LV6P@0@AdE101_C48407MOCP@0O6EC101hFdT407=DA@<0
KeE7101cFT/405Th:@@0P7aj101^IfdZ0820OQH0oooo000D0?oooaL0P81n1020O7TK0820OP@0PGmn
101aJfX300dO80@05ahQ1020Kf@4081_G`@0P6]M1020HU`307][G@@0P6mP1021HEP407QGB0@0JDdo
1020KfD3081cJ@P0P6mU1020LfT4081]H`@0PFeM101lHU@307aQDP@0N5e;101hF4P407=A@`@0N4U0
101_@ST3068j<0@0DRhX101F<BT407=GBP@0O65A101hFdT407=EA@<0Ke95101cEdP405e4>@@0>blY
1020O7T407]gMBH0P81n5P3oool001@0oooo5`20P7h4081lNA/0P81n1021Ogh4075[JP<03AlP100G
7R44081_I0@0P6mO1020Jed4081RG0<0Nf]M1020Kf04085QF0@0N5M8101YCCl4081_I@<0P7=Y2020
KfD4081cJ@@0P6eS1021KEd407aRE0<0O65B101hGD/407QHB0@0Le53101hBD0406m2>@<0HSX`101B
;RP405Ha:@@0LeM:101lHE4407QKB@@0LeE50`1_DTD407=GB0@0GD@i100k;bT4081lN@@0NgMe9P20
P7hF0?ooo`00503ooolG0820OP@0P7ai6`20P7h4085oOP@0LF]Z0`0=7b0401LN8@@0P6mT1020Kel4
081[G@@0P69L0`1kJed4081_H0@0PF5H101hEdP406U=?`@0P6mU0`20LfT8081_I@@0P7=Y1020KF<4
085]G@@0O69D0`1lHE8407QMB`@0N5Q8101cDD<407Q9@0@0Kd8i0`1R>S04058^:0@0ES4Y101cEdX4
07aQD@@0N5]9101cEDD306mBA@@0LeM8101MA3T403/_:@@0P7ai101kMgDV0820OQH0oooo000D0?oo
oaL0P81n1020O7TK0820OP@0PGmn101aJfX300dO80@05ahQ1020Kf@4081_G`@0P6]M1020HU`307][
G@@0P6mP1021HEP407QGB0@0JDdo1020KfD3081cJ@P0P6mU1020LfT4081]H`@0PFeM101lHU@307aQ
DP@0N5e;101hF4P407=A@`@0N4U0101_@ST3068j<0@0DRhX101F<BT407=GBP@0O65A101hFdT407=E
A@<0Ke95101cEdP405e4>@@0>blY1020O7T407]gMBH0P81n5P3oool001@0oooo=P20P7h4081oN0@0
LFmc0`20Kf4407aSEP@0O6]L1020Kf04081[G@@0P6mQ0`20Hed4081_H@@0PFiN101hGDh407=A@`@0
O6MI0`20KfD4081cJ@P0P6mU1020LfL4085RFP@0O5i?0`1lHE4407QKBP@0MeM8101_DSl406m>?`@0
Ke8o0`1_CSl406m??`@0Jde6101^E44407QMCP@0N5Y8101cE4D306mE@`@0LeE71016;2<403/f:`@0
K6EN:P20P7hF0?ooo`00503ooolf0820OP@0P7mh101aKg<3081_H@@0O6=F101lJe`4081_H0@0P6]M
1020Kf43081SG@@0P6mQ1021KUh407QMCP@0Le53101lIeT3081_I@@0P7=Y2020KfD4081cI`@0PF9J
101lGTl307aQD@@0N5]:101gEdP406mB?`@0Kdho101_DSl306m>?`@0Kdlo101[CDH406iD@@@0N5e>
101hFTP407=DA@<0KeE3101cEDL404H/8`@0>cH[101/IEhZ0820OQH0oooo000D0?ooocH0P81n1020
OgP4075_L`<0P6mQ101lHeH407a[G0@0P6mP1020Jed4081_H@<0P6=M1020Kf44085^GP@0N5e>101c
DD<407aWF@<0P6mU1020LfT8081_I@@0P7=W1021HUX407aNC`<0O65A101hFdX407MGB0@0Ke8o101_
CSl406mB?`<0Kdho101_Ccl406]=AP@0KUA1101hGDh407QJB0@0LeA50`1_ED<407=EA`@0AR`S100k
=R/406aUGRX0P81n5P3oool001@0oooo=P20P7h4081oN0@0LFmc0`20Kf4407aSEP@0O6]L1020Kf04
081[G@@0P6mQ0`20Hed4081_H@@0PFiN101hGDh407=A@`@0O6MI0`20KfD4081cJ@P0P6mU1020LfL4
085RFP@0O5i?0`1lHE4407QKBP@0MeM8101_DSl406m>?`@0Ke8o0`1_CSl406m??`@0Jde6101^E444
07QMCP@0N5Y8101cE4D306mE@`@0LeE71016;2<403/f:`@0K6EN:P20P7hF0?ooo`00503ooolb0820
OP@0PH1n1020OgP4085^GP<0PF]K1020LFP407][G0@0Nf]M1020Kf47081_I@@0P7=Y1020KF<407aV
E`@0N5Q9101bE4P307][G@@0P7=Y1020L6H4085_H`@0P7=W1021Je/407aPD@<0N511101hFdT406m@
?`@0Idlo101[CC`406];>P<0Jddj101[B3P406Y@@0@0LeY;101hFd`407QGB0@0Ke530`1_DTD406mG
AP@0;A/H100]:RL407MbNBX0P81n5P3oool001@0oooo<P20P7h40860OP@0P7mh1021KUh3085[F`@0
P75X101kJe`407][G@@0P6mQ1`20KfD4081cJ@@0P6eS101lIUL407QHB@@0LUA80`1kJed4081cJ@@0
P71V1021Kf<4081cI`@0PF]K101lH54307Q@@@@0N5]9101_D3l406M??`@0Jddl101[BcX306]=>P@0
JdPh101ZD40407=JB`@0N5]<101hEdP406mA@`<0Ke95101_EdH402dK60@0;BXW101gLWTZ0820OQH0
oooo000D0?oooc80P81n1021P7h4081oN0@0PFiN0`21Je/4081aJ0@0Nf]L101kJed4081_H@L0P6mU
1020LfT4081]H`@0O6IG101hF4T4079DB0<0Nf]M1020LfT4081`IP@0PFmS1020LfL4085[F`@0O61A
0`1hD44407QKB@@0Ke0o101WCcl406]=?0@0Jd/j0`1[CCX406]8>0@0JU10101cFT/407QKC0@0N5M8
101_DD<306mBA@@0KeM6100]6aP402dZ9`@0Mg9i:P20P7hF0?ooo`00503ooolb0820OP@0PH1n1020
OgP4085^GP<0PF]K1020LFP407][G0@0Nf]M1020Kf47081_I@@0P7=Y1020KF<407aVE`@0N5Q9101b
E4P307][G@@0P7=Y1020L6H4085_H`@0P7=W1021Je/407aPD@<0N511101hFdT406m@?`@0Idlo101[
CC`406];>P<0Jddj101[B3P406Y@@0@0LeY;101hFd`407QGB0@0Ke530`1_DTD406mGAP@0;A/H100]
:RL407MbNBX0P81n5P3oool001@0oooo<P20P7h4081oN0@0NgMc1021Je/307aSD`@0Mem?101/IV<4
081[G@@0P6mU2`20LfT4081cI`@0P6=K101lHE4407QEA`<0Nf=F1020KfD4081cJ0@0P6=M101kJed4
085]GP@0N5i?0`1hF4T406m<?`@0Ke11101[B3X406]=?0@0Jdi00`1_DCh406Y@@0@0JTdn201hF4T4
07=EA`@0Ke530`1_DT<406mEA`@0>b4I100W7a`406QQFbX0P81n5P3oool001@0oooo<P20P7h4081o
N0@0NgMc1021Je/307aSD`@0Mem?101/IV<4081[G@@0P6mU2`20LfT4081cI`@0P6=K101lHE4407QE
A`<0Nf=F1020KfD4081cJ0@0P6=M101kJed4085]GP@0N5i?0`1hF4T406m<?`@0Ke11101[B3X406]=
?0@0Jdi00`1_DCh406Y@@0@0JTdn201hF4T407=EA`@0Ke530`1_DT<406mEA`@0>b4I100W7a`406QQ
FbX0P81n5P3oool001@0oooo<P20P7h4081oN0@0NgMc1021Je/307aSD`@0Mem?101/IV<4081[G@@0
P6mU2`20LfT4081cI`@0P6=K101lHE4407QEA`<0Nf=F1020KfD4081cJ0@0P6=M101kJed4085]GP@0
N5i?0`1hF4T406m<?`@0Ke11101[B3X406]=?0@0Jdi00`1_DCh406Y@@0@0JTdn201hF4T407=EA`@0
Ke530`1_DT<406mEA`@0>b4I100W7a`406QQFbX0P81n5P3oool001@0oooo<P20P7h4081oN0@0NgMc
1021Je/307aSD`@0Mem?101/IV<4081[G@@0P6mU2`20LfT4081cI`@0P6=K101lHE4407QEA`<0Nf=F
1020KfD4081cJ0@0P6=M101kJed4085]GP@0N5i?0`1hF4T406m<?`@0Ke11101[B3X406]=?0@0Jdi0
0`1_DCh406Y@@0@0JTdn201hF4T407=EA`@0Ke530`1_DT<406mEA`@0>b4I100W7a`406QQFbX0P81n
5P3oool001@0oooo<P20P7h4081oN0@0PFmO101oH4`307MODP@0LE]?101kJed4081SG@@0P6mU2`20
LfT4081cJ0@0P6mP1021IED407QNB`<0MeQ<1020KfD4081cI`P0P6mU1021KV4407aND@<0N5]<101c
EDL407=DA@@0Jd/j101[B3X406]>@0<0KU=7101bE4P407QKC0@0N5i?101cEdP807=EA`<0Ke95101_
EdL406i@>`@0;b4J100c9R44081lNBH0P81n5P3oool001@0oooo<P20P7h4081oN0@0PFmO101oH4`3
07MODP@0LE]?101kJed4081SG@@0P6mU2`20LfT4081cJ0@0P6mP1021IED407QNB`<0MeQ<1020KfD4
081cI`P0P6mU1021KV4407aND@<0N5]<101cEDL407=DA@@0Jd/j101[B3X406]>@0<0KU=7101bE4P4
07QKC0@0N5i?101cEdP807=EA`<0Ke95101_EdL406i@>`@0;b4J100c9R44081lNBH0P81n5P3oool0
01@0oooo<P20P7h4081oN0@0PFmO101oH4`307MODP@0LE]?101kJed4081SG@@0P6mU2`20LfT4081c
J0@0P6mP1021IED407QNB`<0MeQ<1020KfD4081cI`P0P6mU1021KV4407aND@<0N5]<101cEDL407=D
A@@0Jd/j101[B3X406]>@0<0KU=7101bE4P407QKC0@0N5i?101cEdP807=EA`<0Ke95101_EdL406i@
>`@0;b4J100c9R44081lNBH0P81n5P3oool001@0oooo;P20P7h4081oNP@0PGAX1020EDH407aRD@<0
Jddn101kJed4081SG@@0P6mQ1020KfD4081cJ@<0P7Q`1020LfT4081cJ0@0PFmS1021KUh407MODP<0
Mem?101kJed4085]H@@0P6mP1020L6H4085[F`@0O61?0`1cE4D407=B@`@0KeA1101^Bc`406m>>P@0
Jde00`1^E4L407MKD0@0O65B101hGDh407=KC0@0LeQ9101_EDD306mDA@@0KeM:101cFTX406M;>@@0
>b0F100W81/V0820OQH0oooo000D0?ooobh0P81n1020OgX4085dJ0@0P5E6101lHU4306]=?P@0Nf]M
1020Hed4081_H@@0P6mU1020LfT3081hL0@0P7=Y1020LfP4085_H`@0PFiN101gGe8307MOC`@0Nf]M
1021KF44081_H0@0P71V1021Je/407aPC`<0LeA5101cDT<406mD@@@0KT/l101_CSX406]=@0<0KUA7
101gFe0407aQDP@0N5e>101cFd`407=HB@@0KeE50`1_E4D406mGBP@0LeY:101WBcT403/P5P@09b0K
9P20P7hF0?ooo`00503oool^0820OP@0P7mj1021M6P4081EAP@0O69A0`1[CCh407][G@@0P6=M1020
Kf44081_I@@0P7=Y0`20N704081cJ@@0P7=X1021Kf<4085^GP@0MemB0`1gGdl407][G@@0PFeQ1020
Kf04081`IP@0PF]K101lH4l307=DA@@0Le93101_E44406i;?0@0Kdhj101[CD0306iDA`@0Me]@101l
HE8407QMCP@0Le]<101cF4T406mEA@<0KeA5101_EdX407=JBP@0Id/i100k81H402LP6bH0P81n5P3o
ool001@0oooo;P20P7h4081oNP@0PGAX1020EDH407aRD@<0Jddn101kJed4081SG@@0P6mQ1020KfD4
081cJ@<0P7Q`1020LfT4081cJ0@0PFmS1021KUh407MODP<0Mem?101kJed4085]H@@0P6mP1020L6H4
085[F`@0O61?0`1cE4D407=B@`@0KeA1101^Bc`406m>>P@0Jde00`1^E4L407MKD0@0O65B101hGDh4
07=KC0@0LeQ9101_EDD306mDA@@0KeM:101cFTX406M;>@@0>b0F100W81/V0820OQH0oooo000D0?oo
obh0P81n1020NgH4085SEP@0N4/n101_@cX306iDB0@0K6MM2020Kf44081_I@L0P7=Y1020LfP4081c
I`@0PFmS101kJU/407aWF@<0Nf]M2020Kf4407]SFP@0P6iN1021HEP407QJB0<0Ldm1101^CSl406];
?0@0Kdll101QBSh406Y=@@<0Le]>101gGe0407aQDP@0N5e>101cF4T807=DA`<0KeA3101cE4P407=E
@P@0Ke53101[Bc`Z0820OQH0oooo000D0?ooobh0P81n1020NgH4085SEP@0N4/n101_@cX306iDB0@0
K6MM2020Kf44081_I@L0P7=Y1020LfP4081cI`@0PFmS101kJU/407aWF@<0Nf]M2020Kf4407]SFP@0
P6iN1021HEP407QJB0<0Ldm1101^CSl406];?0@0Kdll101QBSh406Y=@@<0Le]>101gGe0407aQDP@0
N5e>101cF4T807=DA`<0KeA3101cE4P407=E@P@0Ke53101[Bc`Z0820OQH0oooo000D0?ooobh0P81n
1020NgH4085SEP@0N4/n101_@cX306iDB0@0K6MM2020Kf44081_I@L0P7=Y1020LfP4081cI`@0PFmS
101kJU/407aWF@<0Nf]M2020Kf4407]SFP@0P6iN1021HEP407QJB0<0Ldm1101^CSl406];?0@0Kdll
101QBSh406Y=@@<0Le]>101gGe0407aQDP@0N5e>101cF4T807=DA`<0KeA3101cE4P407=E@P@0Ke53
101[Bc`Z0820OQH0oooo000D0?ooobh0P81n1020NgH4085SEP@0N4/n101_@cX306iDB0@0K6MM2020
Kf44081_I@L0P7=Y1020LfP4081cI`@0PFmS101kJU/407aWF@<0Nf]M2020Kf4407]SFP@0P6iN1021
HEP407QJB0<0Ldm1101^CSl406];?0@0Kdll101QBSh406Y=@@<0Le]>101gGe0407aQDP@0N5e>101c
F4T807=DA`<0KeA3101cE4P407=E@P@0Ke53101[Bc`Z0820OQH0oooo000D0?ooobX0P81n1020P7/4
081nMP@0PEiD101gBc`406m6?P<0K5M<101kJed4081_I@@0P7=Y1020KfD4081cJ0<0PG9V1020LfL4
081]H`@0PFiN101lJEX4085WF0<0Nf]M1020Kf@4081cJ0@0P6mU1020KF<4085RD@@0N5Y:0`1_Cd44
06]=?P@0Id/n101WC3h406]@@`@0Le]<0`1gGe0407QQDP@0O61A101hGDh407=GB0@0LeA5101cDDD3
07=BA@@0KeA8101cFTd406]<?@@0KeA81025QH8V0820OQH0oooo000D0?ooobX0P81n1020P7/4081n
MP@0PEiD101gBc`406m6?P<0K5M<101kJed4081_I@@0P7=Y1020KfD4081cJ0<0PG9V1020LfL4081]
H`@0PFiN101lJEX4085WF0<0Nf]M1020Kf@4081cJ0@0P6mU1020KF<4085RD@@0N5Y:0`1_Cd4406]=
?P@0Id/n101WC3h406]@@`@0Le]<0`1gGe0407QQDP@0O61A101hGDh407=GB0@0LeA5101cDDD307=B
A@@0KeA8101cFTd406]<?@@0KeA81025QH8V0820OQH0oooo000D0?ooobX0P81n1020P7/4081nMP@0
PEiD101gBc`406m6?P<0K5M<101kJed4081_I@@0P7=Y1020KfD4081cJ0<0PG9V1020LfL4081]H`@0
PFiN101lJEX4085WF0<0Nf]M1020Kf@4081cJ0@0P6mU1020KF<4085RD@@0N5Y:0`1_Cd4406]=?P@0
Id/n101WC3h406]@@`@0Le]<0`1gGe0407QQDP@0O61A101hGDh407=GB0@0LeA5101cDDD307=BA@@0
KeA8101cFTd406]<?@@0KeA81025QH8V0820OQH0oooo000D0?ooobX0P81n1020P7/4081nMP@0PEiD
101gBc`406m6?P<0K5M<101kJed4081_I@@0P7=Y1020KfD4081cJ0<0PG9V1020LfL4081]H`@0PFiN
101lJEX4085WF0<0Nf]M1020Kf@4081cJ0@0P6mU1020KF<4085RD@@0N5Y:0`1_Cd4406]=?P@0Id/n
101WC3h406]@@`@0Le]<0`1gGe0407QQDP@0O61A101hGDh407=GB0@0LeA5101cDDD307=BA@@0KeA8
101cFTd406]<?@@0KeA81025QH8V0820OQH0oooo000D0?ooobX0P81n1021NF/407mRD@@0Ldlk101d
Bc/406Y=?`<0LE]?1020Kf44081_I@@0P7=X1020LfL4081_H`<0PFmS101lJE/4085]G@@0PF9K101l
IeT407aSEP<0NfMI1020KfD4081_H@@0P6mU1021Kf<4085PEP@0N5A50`1_Cd4406]=?P@0Jdi0101W
DTD406iGA`@0Le]<0`1hGTl407aRE0@0N5i?101hFT/407=JB`@0Le95101cDD<306mAA@@0KeM8101c
CCP407=DA`@0Ke11101/IF<V0820OQH0oooo000D0?ooobX0P81n1021NF/407mRD@@0Ldlk101dBc/4
06Y=?`<0LE]?1020Kf44081_I@@0P7=X1020LfL4081_H`<0PFmS101lJE/4085]G@@0PF9K101lIeT4
07aSEP<0NfMI1020KfD4081_H@@0P6mU1021Kf<4085PEP@0N5A50`1_Cd4406]=?P@0Jdi0101WDTD4
06iGA`@0Le]<0`1hGTl407aRE0@0N5i?101hFT/407=JB`@0Le95101cDD<306mAA@@0KeM8101cCCP4
07=DA`@0Ke11101/IF<V0820OQH0oooo000D0?ooobX0P81n1021NF/407mRD@@0Ldlk101dBc/406Y=
?`<0LE]?1020Kf44081_I@@0P7=X1020LfL4081_H`<0PFmS101lJE/4085]G@@0PF9K101lIeT407aS
EP<0NfMI1020KfD4081_H@@0P6mU1021Kf<4085PEP@0N5A50`1_Cd4406]=?P@0Jdi0101WDTD406iG
A`@0Le]<0`1hGTl407aRE0@0N5i?101hFT/407=JB`@0Le95101cDD<306mAA@@0KeM8101cCCP407=D
A`@0Ke11101/IF<V0820OQH0oooo000D0?ooobX0P81n1021NF/407mRD@@0Ldlk101dBc/406Y=?`<0
LE]?1020Kf44081_I@@0P7=X1020LfL4081_H`<0PFmS101lJE/4085]G@@0PF9K101lIeT407aSEP<0
NfMI1020KfD4081_H@@0P6mU1021Kf<4085PEP@0N5A50`1_Cd4406]=?P@0Jdi0101WDTD406iGA`@0
Le]<0`1hGTl407aRE0@0N5i?101hFT/407=JB`@0Le95101cDD<306mAA@@0KeM8101cCCP407=DA`@0
Ke11101/IF<V0820OQH0oooo000D0?ooobX0P81n1021KU`405`c7P@0GcT/1017;2@405a6?0<0Mf=F
1020Kf48081_I0@0P6mU1020Kf43081[G@@0Nf]M101lHUP407QPDP@0O61C101lJU/307a[G0@0P6mQ
1020KfD4081_I0@0PFeQ101lIE@407MCB0<0Kdlo101[Bc`406]>@0@0Ke=6101_EDL407QJCP<0N5e?
101hFd`407QPD@@0N5]<201cF4T406mDA@<0Ke55101_DTL4079E@@@0Jd8b101cEDL406a5=RH0P81n
5P3oool001@0oooo:P20P7h4085^G0@0G3<N101O>B`404L/90@0G4Hl0`1gHeH4081_H@P0P6mT1020
KfD4081_H@<0P6]M101kJed407aRF0@0N61B101lH5<407aZF`<0O6]L1020Kf44081_I@@0P6mT1021
KF4407aUE0@0Me=80`1_Ccl406];?0@0Jdi0101_DdH406mEA`@0N5Y>0`1hGDl407QKC0@0N61A101h
Fd`807=HB@@0KeA50`1_DDD406mBA`@0LUE1101[@S8407=EA`@0K4Df9P20P7hF0?ooo`00503ooolZ
0820OP@0PFiL101L<ah405li;0@0Ab`T101LAS`307MSEP@0P6mQ2020Kf@4081_I@@0P6mQ0`20Jed4
07][G@@0O69H101hH58407aPD`@0O6YK0`1lJe`4081_H@@0P6mU1020Kf@4085]H@@0O6ED101gDdP3
06m??`@0Jd/l101[CT0406mCAP@0KeE7101hFTh307QMC`@0N5]<101hH54407QKC0P0LeQ9101_E4D3
06mAA@@0Ke97101bED4406]2<P@0LeE7101/ACHV0820OQH0oooo000D0?ooobX0P81n1021KU`405`c
7P@0GcT/1017;2@405a6?0<0Mf=F1020Kf48081_I0@0P6mU1020Kf43081[G@@0Nf]M101lHUP407QP
DP@0O61C101lJU/307a[G0@0P6mQ1020KfD4081_I0@0PFeQ101lIE@407MCB0<0Kdlo101[Bc`406]>
@0@0Ke=6101_EDL407QJCP<0N5e?101hFd`407QPD@@0N5]<201cF4T406mDA@<0Ke55101_DTL4079E
@@@0Jd8b101cEDL406a5=RH0P81n5P3oool001@0oooo9P20P7h40820O@@0PGM_101`A38403/U6`@0
@RTR100g<C0307MSEP@0PFmS1020KfD4081_H0@0PF]K1021Jeh707iSD`@0OV=F101kF4l407QHC0@0
LeQ90`1lIUL407][G@P0P6mU1021KEh407aND@@0Le910`1[B3`406]=?0@0IdXl101^DD<4079GB0@0
LeE70`1cFd`407QHC0@0LeM8101cFT/806mEA`@0KeA50`1_DDD406mBA`@0JD8`101S=B8406]9=P@0
K4Dj9P20P7hF0?ooo`00503ooolV0820OP@0P81m1021Mfl40714<P@0>bDK1012:B8403La<0<0Mf=F
1021Kf<4081_I@@0P6mP1021Je/4085[GPL0OV=C101nHeH407]HC`@0N5Q<101cF4T307aVE`@0Nf]M
2020KfD4085]GP@0O5iA101cDT4306]8?0@0Jddl101WBS`406iA@`@0LUM8101cEDL307=KC0@0N5Q<
101cEdP407=JB`P0KeE7101_E4D306mAA@@0Ke97101Y@S0406<e8P@0JdTf101/ACXV0820OQH0oooo
000D0?ooobH0P81n1020P7d4085gK`@0L4@b100k9A/4048Y8P@0=c4`0`1gHeH4085_H`@0P6mU1020
Kf04085[F`@0PF]N1`1nHe<407iSEP@0NeQ?101hF4`407=HB@<0O6IG101kJed8081_I@@0PFeN101l
GU4407=B@@<0JdPl101[CC`406M:?0@0KU53101bEdP407=EA`<0Le]<101hF4`407=GB0@0LeY;201_
EDL406mDA@<0Ke55101_DTL406U2<0@0HcDR101[BCH406a5>RH0P81n5P3oool001@0oooo9P20P7h4
085mM0@0PG1V100l50d403@L5@@0<AlI100d;bl307MSEP@0P6mO101kJed4081_I0@0PFiN101bFTX3
06iC@P@0EShd101;<RX405Xf9P@0JD@i1`1^?R`407MSE@P0P6mU1021KV4407aND@@0Le910`1[CSX4
06Y7=P@0Idm2101[D4<406ICAP@0IU950`1_E4L4079JBP@0KeM8101cFT/407=HB@P0KUA50`1_DTD4
06mBA`@0JdDd101F<28405Hc9`@0J40]9P20P7hF0?ooo`00503ooolV0820OP@0PGed1021L6H403`D
3@@0=1`E100a7aT403@_;`<0Mf=F1020Kel407][G@@0P6mT1021KUh4079JBP<0KU=2101F?S@404/b
:P@0FSHV101YA3T706hn;0@0Mf=E2020KfD4085^H@@0O5iA101cDT4306]>>P@0JTLf101WCd8406]@
@`@0IU=6101VDTD306mDA`@0LUY:101_EdP407=JB`@0LeQ9201^E4D306mBA@@0Ke97101[AC@405H`
8P@0ES<W101X@2dV0820OQH0oooo000D0?ooobH0P81n1021OG@4085`IP@0?1@=100d71D4034O6@@0
=2l_0`1gHeH4081_G`@0Nf]M1020Kf@4085^GP@0LUY:0`1^Dd8405Hn=0@0Bc8Z101J=RH406U4>@L0
KSh/101gHeD8081_I@@0PFiQ101lGU4407=B@@<0Jdhj101ZAcH406M?@P@0Je13101VDdH406IBA@<0
KeA7101bFTX406mGB0@0LeY;101cF4T806iDA@<0Ke95101_DTL406]5=0@0ES0R101F<bL406Q0;BH0
P81n5P3oool001@0oooo9P20P7h4085mM0@0PG1V100l50d403@L5@@0<AlI100d;bl307MSEP@0P6mO
101kJed4081_I0@0PFiN101bFTX306iC@P@0EShd101;<RX405Xf9P@0JD@i1`1^?R`407MSE@P0P6mU
1021KV4407aND@@0Le910`1[CSX406Y7=P@0Idm2101[D4<406ICAP@0IU950`1_E4L4079JBP@0KeM8
101cFT/407=HB@P0KUA50`1_DTD406mBA`@0JdDd101F<28405Hc9`@0J40]9P20P7hF0?ooo`00503o
oolS0820OP<0Oh1m1020OG@407aPC`@0G3L^100R4`l402TH50@08BHW0`1kIeT407a[G0@0P6]M1020
Kf04081_H@@0O6=C0`1TE4P4058j;P@0<QlI100c7aL4048_9`@0GSh_0`1I>S0405He;P@0NfMJ1020
KfD4085_H`@0O69A101aCSh306Y9=P@0ER0A101RASP406i@>`@0L510101ZAcD3079B@`@0KU55101W
DT<807=HB@@0KU93101WDD<306MAA@@0KU93101T?S0405Xg:@@0FST_101V=2DV0820OQH0oooo000D
0?ooob<0P81n0`1oP7d4081mM0@0O61?101L=bh4028C3`@0:APD100Q9RL307]WF@@0O6]L1020Jed4
081_H0@0P6mQ101lHe<306ADB0@0DSX^100b7aT403<O5`@0@RlW101N?Rl305Tj<0@0ESD^101kIeX4
081_I@@0PFmS101lHU44075>?P<0JTTf101F81440696>0@0KU0k101`D40406Y7=@<0LU93101^DDD4
06MB@`P0LeQ9101^DT<406MA@`<0Ie55101^DT<406@n<0@0FSLY101J>Bl406Hd9BH0P81n5P3oool0
01@0oooo8`20P7h307n0O@@0P7ed101lH4l405`g;P@08Q<?100Y61@4024V9`<0NfMI101lJe`4081[
G@@0P6mP1020Kf4407aSD`<0I5A8101B>Rh4038O6@@0<alG1012;bL405hn;`<0FCX`101F=Bh407]W
FP@0P6mU1021Kf<407aRD@@0LDhn0`1ZBCH405HP4@@0HTHh101^D3/4071@@0@0JTLe0`1bDT<406iA
A@@0Ie93201cF4T406iB@`@0Ie530`1WDDD406iB@`@0I3h`101J=bT405Xi;`@0IS@U9P20P7hF0?oo
o`00503ooolS0820OP<0Oh1m1020OG@407aPC`@0G3L^100R4`l402TH50@08BHW0`1kIeT407a[G0@0
P6]M1020Kf04081_H@@0O6=C0`1TE4P4058j;P@0<QlI100c7aL4048_9`@0GSh_0`1I>S0405He;P@0
NfMJ1020KfD4085_H`@0O69A101aCSh306Y9=P@0ER0A101RASP406i@>`@0L510101ZAcD3079B@`@0
KU55101WDT<807=HB@@0KU93101WDD<306MAA@@0KU93101T?S0405Xg:@@0FST_101V=2DV0820OQH0
oooo000D0?ooob<0P81n0`1;8AP408EgJ`@0PFEE101T?2l402XL7P@08QD@100U8R@307a[G0@0P6mP
101lJe`4085_G`@0P6mQ1021Kf<307=KC0@0O5iA1014?CD4034/9@@0>BhU1010?CL305a3>0@0LUQ;
101kJed4081cJ@@0PGE[101lIE@407=@?P<0HT@f101P?B`404DY8`@0ES`b100N30/405@c9`<0C3L/
101;;R440656>@@0JDPb101_D3h406iDA@@0Idi00`1WDD<406];?P@0Dc8U1019;28405U0=@@0Jd8g
0`25QH8S0820OQH0oooo000D0?ooob<0P81n0`1;8AP408EgJ`@0PFEE101T?2l402XL7P@08QD@100U
8R@307a[G0@0P6mP101lJe`4085_G`@0P6mQ1021Kf<307=KC0@0O5iA1014?CD4034/9@@0>BhU1010
?CL305a3>0@0LUQ;101kJed4081cJ@@0PGE[101lIE@407=@?P<0HT@f101P?B`404DY8`@0ES`b100N
30/405@c9`<0C3L/101;;R440656>@@0JDPb101_D3h406iDA@@0Idi00`1WDD<406];?P@0Dc8U1019
;28405U0=@@0Jd8g0`25QH8S0820OQH0oooo000D0?ooob<0P81n0`1;8AP408EgJ`@0PFEE101T?2l4
02XL7P@08QD@100U8R@307a[G0@0P6mP101lJe`4085_G`@0P6mQ1021Kf<307=KC0@0O5iA1014?CD4
034/9@@0>BhU1010?CL305a3>0@0LUQ;101kJed4081cJ@@0PGE[101lIE@407=@?P<0HT@f101P?B`4
04DY8`@0ES`b100N30/405@c9`<0C3L/101;;R440656>@@0JDPb101_D3h406iDA@@0Idi00`1WDD<4
06];?P@0Dc8U1019;28405U0=@@0Jd8g0`25QH8S0820OQH0oooo000D0?ooob<0P81n0`1;8AP408Eg
J`@0PFEE101T?2l402XL7P@08QD@100U8R@307a[G0@0P6mP101lJe`4085_G`@0P6mQ1021Kf<307=K
C0@0O5iA1014?CD4034/9@@0>BhU1010?CL305a3>0@0LUQ;101kJed4081cJ@@0PGE[101lIE@407=@
?P<0HT@f101P?B`404DY8`@0ES`b100N30/405@c9`<0C3L/101;;R440656>@@0JDPb101_D3h406iD
A@@0Idi00`1WDD<406];?P@0Dc8U1019;28405U0=@@0Jd8g0`25QH8S0820OQH0oooo000D0?ooo`@0
P7aj1020O7T40820OP<0P7ai4020P7h4054_9`<0BblW100X20@406@j;0@0?28T100Y6A<402LI5P@0
5ahQ0`1lJe`407][G@@0PFEF101lIeH407][G@@0P6mU0`1kJed407MOD@@0KeE7101_EdP40659>P@0
H4Xk0`1^F4P407MLCP@0NfMJ1020LfT4085`I0@0O6EE101cDT4306];>0@0HTHf101J@3D405M6?0@0
8QHE100S6183040Z90@0>2PQ100k;B<405<o=0@0ET<d101[BSX406MA@`<0Ie93101G=2/404D/7`@0
>b<I1016<bT4075C@`<0QHF28`20P7hF0?ooo`00503oool4081lNP@0P7ai1020P7h3081lNA00P81n
101A;bL304/_9`@0:0P4101T>R`403`R90@0:ATC100W6AH401LN8@<0O6]L101kJed4085UEP@0O6MF
101kJed4081_I@<0Nf]M101gGe4406mEA`@0KeM8101QBCX4061:>`<0KUQ8101gG4h407]WFP@0P7=Y
1021L6@407aUE@@0Le910`1[BcP40696=P@0FT0e101GAS`4028F5@@08aPB0`10:R@403PX8@@0>bdS
101C?c@405I3=0@0JdXj101WDD<306MB@`@0Ec@[1015;1l403/S6@@0AS<Y101aDd<308F5PR<0P81n
5P3oool001@0oooo1020O7X4081lN@@0P81n0`20O7T@0820OP@0DBlW0`1;;bL402P810@0I3X/100l
8R@402TI4`@09aTF100G7R4307a[G0@0Nf]M1021IEH407aWEP@0Nf]M1020KfD307][G@@0MemA101_
EDL406mGB0@0HDTj101PBS/306iHB0@0Mea>101kIeX4081cJ@@0PG1T101lIED407=B@@<0Jd/h101R
ASH405Y0=@@0EdHl100R5QD402<H4P<0@2XT100h:24403/]8`@0Dcld101F@c@406]:>P@0Ie530`1W
DT<405Ld:`@0AB`O100k8aT404Hc:@@0LE=30`25QH8S0820OQH0oooo000D0?ooo`@0P7aj1020O7T4
0820OP<0P7ai4020P7h4054_9`<0BblW100X20@406@j;0@0?28T100Y6A<402LI5P@05ahQ0`1lJe`4
07][G@@0PFEF101lIeH407][G@@0P6mU0`1kJed407MOD@@0KeE7101_EdP40659>P@0H4Xk0`1^F4P4
07MLCP@0NfMJ1020LfT4085`I0@0O6EE101cDT4306];>0@0HTHf101J@3D405M6?0@08QHE100S6183
040Z90@0>2PQ100k;B<405<o=0@0ET<d101[BSX406MA@`<0Ie93101G=2/404D/7`@0>b<I1016<bT4
075C@`<0QHF28`20P7hF0?ooo`00503oool8081lNAL0P81n101A;bL3034O60@0;ATD100Y61@401h?
3P@09aPE100W61@4024T9@<0Nf]L101lJe`4081_I@@0LeA:101aD40407iSD`<0Nf9A101cEDP406Y3
=@@0Id8`101/AcD406i5=0<0N5i<101lHeH407]WFP@0P7=W1021L6<407aQE@@0LeQ70`1[BcP406MA
>P@0Jd`l101_EDL406M<?`@07bHV0`0k;2@4044c:P@0<C4/101A@3840698?0@0KeE3101[Cd8306MA
@`@0Cc4R100a71L403LR6@@0@2XO101X=bPV0820OQH0oooo000D0?ooo`P0P7ai5`20P7h4054_9`<0
<AlH100]6A@402TH50@07Pl>100W61D402LH50@08B@U0`1kJe`407a[G0@0P6mU101cE4X4075@@0@0
OV=C0`1kHU4407=EB0@0JT<e101W@S0406a7=@@0KTDd0`1hGT`407aSEP@0NfMJ1020LfL4085`H`@0
O65E101cF4L306];>0@0Ie4j101[C3`406mEA`@0Id`o100O9RH303//90@0@C<Z100a<B`40550<P@0
HTPl101_ED<406]?@P<0Ie53101?<B84034L5`@0=b8I1010:Ql406Pg:2H0P81n5P3oool001@0oooo
2020O7TG0820OP@0DBlW0`0a7aP402dI50@0:APD100N3`h402LH5@@09aPD100Q92D307][G0@0O6]L
1020KfD407=DBP@0LE10101nHe<307]RD@@0LeE8101Z@cD406M2<0@0K4Le101^AC@307QNC0@0O6=F
101kIeX4081cI`@0PG1S101lHED407=HA`<0Jd/h101WDCX406]<?0@0KeE7101WC3l401lV9P<0>b`T
1011<bX4034a;0@0DD0b101RB3`406mE@`@0Jdm20`1WDD<404la8P@0<A`G100g8QT4040Z7`@0J3LX
9P20P7hF0?ooo`00503oool8081lNAL0P81n101A;bL3034O60@0;ATD100Y61@401h?3P@09aPE100W
61@4024T9@<0Nf]L101lJe`4081_I@@0LeA:101aD40407iSD`<0Nf9A101cEDP406Y3=@@0Id8`101/
AcD406i5=0<0N5i<101lHeH407]WFP@0P7=W1021L6<407aQE@@0LeQ70`1[BcP406MA>P@0Jd`l101_
EDL406M<?`@07bHV0`0k;2@4044c:P@0<C4/101A@3840698?0@0KeE3101[Cd8306MA@`@0Cc4R100a
71L403LR6@@0@2XO101X=bPV0820OQH0oooo000D0?oooal0P81n101G=RL302HB3@@08aLB100V5Q44
02@F4P@06a<@100_8Qh402`X:0<0NfMI1020Jed407][G@@0P6mU101bGe840698?@<0I4]0101NBcl4
0591=P@0BcTa101?>Rh405A0=@<0ESdd101aGe8407][G@@0P6eS1021KUh407aQDP@0LeE:0`1T>RX4
06@i9`@0Ie4j101_ED<406mEA@@0KeE70`1WCd0405]2=`@0FT<g101[CT0406mA?`@0Ie53101_ED<3
06]>?P@0<B0H100S5a8402l/9`@0@BXO101M:A/V0820OQH0oooo000D0?oooal0P81n101G=RL302HB
3@@08aLB100V5Q4402@F4P@06a<@100_8Qh402`X:0<0NfMI1020Jed407][G@@0P6mU101bGe840698
?@<0I4]0101NBcl40591=P@0BcTa101?>Rh405A0=@<0ESdd101aGe8407][G@@0P6eS1021KUh407aQ
DP@0LeE:0`1T>RX406@i9`@0Ie4j101_ED<406mEA@@0KeE70`1WCd0405]2=`@0FT<g101[CT0406mA
?`@0Ie53101_ED<306]>?P@0<B0H100S5a8402l/9`@0@BXO101M:A/V0820OQH0oooo000D0?oooal0
P81n101G=RL302HB3@@08aLB100V5Q4402@F4P@06a<@100_8Qh402`X:0<0NfMI1020Jed407][G@@0
P6mU101bGe840698?@<0I4]0101NBcl40591=P@0BcTa101?>Rh405A0=@<0ESdd101aGe8407][G@@0
P6eS1021KUh407aQDP@0LeE:0`1T>RX406@i9`@0Ie4j101_ED<406mEA@@0KeE70`1WCd0405]2=`@0
FT<g101[CT0406mA?`@0Ie53101_ED<306]>?P@0<B0H100S5a8402l/9`@0@BXO101M:A/V0820OQH0
oooo000D0?oooal0P81n101G=RL302HB3@@08aLB100V5Q4402@F4P@06a<@100_8Qh402`X:0<0NfMI
1020Jed407][G@@0P6mU101bGe840698?@<0I4]0101NBcl40591=P@0BcTa101?>Rh405A0=@<0ESdd
101aGe8407][G@@0P6eS1021KUh407aQDP@0LeE:0`1T>RX406@i9`@0Ie4j101_ED<406mEA@@0KeE7
0`1WCd0405]2=`@0FT<g101[CT0406mA?`@0Ie53101_ED<306]>?P@0<B0H100S5a8402l/9`@0@BXO
101M:A/V0820OQH0oooo000D0?oooal0P81n101P@cD302/B3@@08Q@@100M5A0401<920@08QD@100Y
8A`403Ld<0<0LUmA1020Jed4081_H@P0P6mU101kJed306aBB`@0E4Y7101/DT/406=:?`@0Hdi3101M
Ach3079HC0@0Nf]M2021Kf<4085SF`@0O6IG101cGe0306]<A@@0D2hV1017:Ah404/_80@0K4/i101_
EDD307=EA@@0KeE3101WDD<406mB@@@0IDho101_DDL406MA@`<0EcDV100c7AH402DN6P@0:BLQ101S
=B@404T/92H0P81n5P3oool001@0oooo7`20P7h40613=@<0:a8=100R510401dE40@04`T8100R5A04
02TQ70@0=c@`0`1bGe44081[G@@0P6mQ2020KfD407][G@<0K59;101DBTL406aBB`@0HdXo101SCT<4
05e7?P<0LUQ<101kJed8085_H`@0PF=K101lIUL407=OD0<0Jda5101@;RH404LY7P@0BblP101/BcT4
06mEA@<0LeE5101_ED<406MA@`@0Ke91101UCSl406mAA`@0Ie530`1G=BH403<M5P@09AhJ100Y9b44
06<e90@0BB`T9P20P7hF0?ooo`00503ooolO0820OP@0H4<e0`0[4Pd4028D40@07AD@100C2@P4028E
40@0:B4L100g=303079OD@@0P6]M1020Kf48081_I@@0Nf]M0`1/DT/405A:A`@0K59;101SBSl406=>
@`@0GDLn0`1bF4`407][G@P0PFmS1021He/407aVE`@0Lem@0`1[C4D4050^9P@0AbTN101;;b0406a;
>@@0KeE50`1cEDD406mE@`@0Ie53101_DT4406E>?`@0Ke57101WDD<305Le9P@0<adF100U7QX402TW
8@@0HcDT1019;2@V0820OQH0oooo000D0?ooo``0P81n0`20O7T@0820OP@0Ed<l0`0a7aT402<D40@0
8QD@100J4@`401dC3`@0:b4L100g=2l306ADB0@0NfMI1020Kf44081_IAl0P7=Y0`20Kf0407][G@@0
P7=W101lJU/407aYFP@0O6MH101gHeD307MRE@@0KeM;101=>SD4044a:@@0=bDL1017:Qh3068n<0@0
GdDf101WAC840653<P@0Jdi2101NBch406m?@`<0ABDM100Z618402DH5`@0:Q<>101?7a@404T]9@<0
;2@O8`20P7hF0?ooo`00503oool<0820OP<0P7ai4020P7h405M3?0<0<AlI100S5104028E40@06Q4<
100M4`l402/Q70@0=c@_0`1TE4P407]WF@@0P6mQ1020KfDO081cJ@<0P6mP101kJed4081cI`@0O6YK
101lJEX407aWF0@0Mf=E0`1gHUD406mGB`@0CCXe1011<BT403LU70@0AbXN0`1R?S0405m5=P@0IdDb
101Q@c8406]>@P@0GT/n101_Cd<304DU7@@0:QPB100U61L402XC3P@0CalD1019;BD302`T7b<0P81n
5P3oool001@0oooo3020P7h3081lNA00P81n101G@c`3034O6@@08a@@100R5A0401XA30@07A<?100[
8A`403Ld;`<0I5A8101kIeT4081_H@@0P6mU7`20LfT3081_H0@0Nf]M1020LfL407aZF`@0O6UJ101l
IeP407MSE@<0Mf9E101_Ed/404dj=@@0@C4Y100g9A`404LZ7P<0HSh`101OACH406M5<P@0HD<b101[
CT8405i;?P@0Kdm30`159Ad402XH4P@09APG100Z4`h404lO50@0BBdU0`0/91lS0820OQH0oooo000D
0?ooo``0P81n0`20O7T@0820OP@0Ed<l0`0a7aT402<D40@08QD@100J4@`401dC3`@0:b4L100g=2l3
06ADB0@0NfMI1020Kf44081_IAl0P7=Y0`20Kf0407][G@@0P7=W101lJU/407aYFP@0O6MH101gHeD3
07MRE@@0KeM;101=>SD4044a:@@0=bDL1017:Qh3068n<0@0GdDf101WAC840653<P@0Jdi2101NBch4
06m?@`<0ABDM100Z618402DH5`@0:Q<>101?7a@404T]9@<0;2@O8`20P7hF0?ooo`00503ooolO0820
OP@0H4U20`0g:B@4024F4PP08QD@100R5aH402/Q70@0>c</0`1VD4@407]WF@@0P6mP1020KfD8081c
J@/0P7Qa1020LfT4081hL0L0P7=Y2020Kf04085^GP@0O6MH101lHU@407aWF0<0O6IH101lHUL407=N
DP@0Ke97101B@ST4044d:`<0>blU101;=BX404Ln=0@0DT0d101B?S@406iAA@@0K4ho0`1391`402@F
4@@07QD@100L4Pd402XG4`@0?RHQ0`0a:B@S0820OQH0oooo000D0?oooal0P81n101PBD8303LY90@0
8AHB200R5A04028G5P@0:b4L100k<b`306I@A0@0NfMI1020Kf04081_I@P0P7=Y2`20N744081cJ@@0
P7Q`1`20LfT8081_H0@0PFiN101lIeP407aRE0@0O6MH0`1lIUP407aRE`@0LeiB101_DTL40592>@@0
@C@[0`0k;bD404/e:P@0Achd101B@3@4058n=0@0KU55101/CSl304<T70@091HA100N5A0401`B3@@0
:QLC100n9R43034Y92<0P81n5P3oool001@0oooo7`20P7h40619@P<0=bTT100Q5Q88028E40@08QLF
100[8A`403/c;0<0IU14101kIeT4081_H0@0P6mU2020LfT;081hL@@0P7=Y1020N707081cJ@P0P6mP
1021KUh407aWF0@0O69D101lIeP307aVF0@0O69G101cGU8406mBA`@0DT8i1011=2/303/_9@@0BcDZ
1017?S@40590=0@0DShd101^DDD406a>?`<0@b@L100T5Q4401hE40@0718=100Z5a<403hV8@<0<BTT
8`20P7hF0?ooo`00503ooolO0820OP@0H4U20`0g:B@4024F4PP08QD@100R5aH402/Q70@0>c</0`1V
D4@407]WF@@0P6mP1020KfD8081cJ@/0P7Qa1020LfT4081hL0L0P7=Y2020Kf04085^GP@0O6MH101l
HU@407aWF0<0O6IH101lHUL407=NDP@0Ke97101B@ST4044d:`<0>blU101;=BX404Ln=0@0DT0d101B
?S@406iAA@@0K4ho0`1391`402@F4@@07QD@100L4Pd402XG4`@0?RHQ0`0a:B@S0820OQH0oooo000D
0?oooal0P81n101P@cD303LT6`@0<B0K100P5A0402DA30@09aPD100]7aT403X^9P<0FTTm101bGe84
081_H0@0P6mQ1020KfD7081cJ@`0P7Qa1020N704081cJ@<0P7=W1020LfP4081_G`@0PFeM201lIeP4
07aRE0<0O6IG101lHED407QPD@@0Lee>101_EDL406ICAP<0GT`o101F@cP405I2=`@0Id/o101WDD<4
06]:@@@0Gd0_0`0n8a/402@F4@@09aPD100M5A0401lD40@0;alH0`0o>CDS0820OQH0oooo000D0?oo
oal0P81n101P@cD303LT6`@0<B0K100P5A0402DA30@09aPD100]7aT403X^9P<0FTTm101bGe84081_
H0@0P6mQ1020KfD7081cJ@`0P7Qa1020N704081cJ@<0P7=W1020LfP4081_G`@0PFeM201lIeP407aR
E0<0O6IG101lHED407QPD@@0Lee>101_EDL406ICAP<0GT`o101F@cP405I2=`@0Id/o101WDD<406]:
@@@0Gd0_0`0n8a/402@F4@@09aPD100M5A0401lD40@0;alH0`0o>CDS0820OQH0oooo000D0?oooal0
P81n101P@cD303LT6`@0<B0K100P5A0402DA30@09aPD100]7aT403X^9P<0FTTm101bGe84081_H0@0
P6mQ1020KfD7081cJ@`0P7Qa1020N704081cJ@<0P7=W1020LfP4081_G`@0PFeM201lIeP407aRE0<0
O6IG101lHED407QPD@@0Lee>101_EDL406ICAP<0GT`o101F@cP405I2=`@0Id/o101WDD<406]:@@@0
Gd0_0`0n8a/402@F4@@09aPD100M5A0401lD40@0;alH0`0o>CDS0820OQH0oooo000D0?oooal0P81n
101P@cD303LT6`@0<B0K100P5A0402DA30@09aPD100]7aT403X^9P<0FTTm101bGe84081_H0@0P6mQ
1020KfD7081cJ@`0P7Qa1020N704081cJ@<0P7=W1020LfP4081_G`@0PFeM201lIeP407aRE0<0O6IG
101lHED407QPD@@0Lee>101_EDL406ICAP<0GT`o101F@cP405I2=`@0Id/o101WDD<406]:@@@0Gd0_
0`0n8a/402@F4@@09aPD100M5A0401lD40@0;alH0`0o>CDS0820OQH0oooo000D0?oooal0P81n101G
?Bh303TY8`@0;QhI100Z6QD401/A30@08a@@100T5Q4403LU70<0B3LY101^F4/407][G@@0P6mQ1020
KfD4081cJ@<0P7Qa1020LfT4081hL@P0P7Q`1020LfT3081cI`@0P6mP1021KV44085ZF`@0O69D201l
IUL307aRE0@0O65B101hGDh407QJB`@0Le]<101_EDL307=HB@@0KeE7101^E4D406iA@`@0KU55101[
Bc`404P^9@<09AH>100X6AP401/A40@07A8=100C2@P402LH50<0>c4Z101SEeDO0820OQH0oooo000D
0?oooal0P81n101G?Bh303TY8`@0;QhI100Z6QD401/A30@08a@@100T5Q4403LU70<0B3LY101^F4/4
07][G@@0P6mQ1020KfD4081cJ@<0P7Qa1020LfT4081hL@P0P7Q`1020LfT3081cI`@0P6mP1021KV44
085ZF`@0O69D201lIUL307aRE0@0O65B101hGDh407QJB`@0Le]<101_EDL307=HB@@0KeE7101^E4D4
06iA@`@0KU55101[Bc`404P^9@<09AH>100X6AP401/A40@07A8=100C2@P402LH50<0>c4Z101SEeDO
0820OQH0oooo000D0?oooal0P81n101G?Bh303TY8`@0;QhI100Z6QD401/A30@08a@@100T5Q4403LU
70<0B3LY101^F4/407][G@@0P6mQ1020KfD4081cJ@<0P7Qa1020LfT4081hL@P0P7Q`1020LfT3081c
I`@0P6mP1021KV44085ZF`@0O69D201lIUL307aRE0@0O65B101hGDh407QJB`@0Le]<101_EDL307=H
B@@0KeE7101^E4D406iA@`@0KU55101[Bc`404P^9@<09AH>100X6AP401/A40@07A8=100C2@P402LH
50<0>c4Z101SEeDO0820OQH0oooo000D0?oooal0P81n101G?Bh303TY8`@0;QhI100Z6QD401/A30@0
8a@@100T5Q4403LU70<0B3LY101^F4/407][G@@0P6mQ1020KfD4081cJ@<0P7Qa1020LfT4081hL@P0
P7Q`1020LfT3081cI`@0P6mP1021KV44085ZF`@0O69D201lIUL307aRE0@0O65B101hGDh407QJB`@0
Le]<101_EDL307=HB@@0KeE7101^E4D406iA@`@0KU55101[Bc`404P^9@<09AH>100X6AP401/A40@0
7A8=100C2@P402LH50<0>c4Z101SEeDO0820OQH0oooo000D0?oooal0P81n101P@cD303<U7`@0=BLR
100Z7AT402XI50@07a@@100W6aL402dS7`<0?bhU101D@cD407]WF@@0P6mQ1020KfD4081cJ@L0P7Qa
1020LfT4081hL0P0P7=Y0`20LfP4085_G`@0PFiN201lIUL807aRE0L0O65B101hGDh807=JB`@0Lee>
0`1_EDL407=EA`@0KUA5101WDD<406M?@@@0G40b100l8QX302`N6@@05P`<100L4Q84018820@06A4@
100M4`l303D[9`@0Cd0j7`20P7hF0?ooo`00503ooolO0820OP@0H4<e0`0c9Al403DW8P@0:QdI100Z
6A@401lD40@09a/G100]8al303l^9@@0E4<e101kIeT4081_H@@0P6mU1020LfT7081hL@@0P7=Y1020
N708081cJ@<0P7=X1021Kel4085^GPP0O6IG201lHU@707aQDP@0N5e>201cFT/407=MCP<0KeE7101c
EDL406iDA@@0Ie53101WCd4405a0<P@0?28J0`0/7QT401H<30@0718B100B20P401TA40@07A<?0`0e
:bL404m0>Ql0P81n5P3oool001@0oooo7`20P7h40613=@<0<bDO100e9b8402XM6@@0:QTD100O5104
02LK5`@0;B<O0`0o;RD405A3=@@0NfMI1020Kf44081_I@@0P7=Y1`20N744081cJ@@0P7Q`2020LfT3
081cJ0@0PFmO1021KUh807aVE`P0O69D1`1lHE8407QMCPP0LeY;101cGDh306mEA`@0LeE7101^E4D4
06MA@`@0Idm1101L@38403`R6P<0;1hI100F30`401`B4P@04PP8100I4A0401dC3`<0=B/W101?@3XO
0820OQH0oooo000D0?oooal0P81n101P@cD303<U7`@0=BLR100Z7AT402XI50@07a@@100W6aL402dS
7`<0?bhU101D@cD407]WF@@0P6mQ1020KfD4081cJ@L0P7Qa1020LfT4081hL0P0P7=Y0`20LfP4085_
G`@0PFiN201lIUL807aRE0L0O65B101hGDh807=JB`@0Lee>0`1_EDL407=EA`@0KUA5101WDD<406M?
@@@0G40b100l8QX302`N6@@05P`<100L4Q84018820@06A4@100M4`l303D[9`@0Cd0j7`20P7hF0?oo
o`00503ooolO0820OP@0G4U20`0i:B<403DY90@0<bHQ100Z6QD401dB3@@09aPD100b8a`303ha:0@0
AS``101bG4h4081[G@P0P6mU0`20LfT<081hL@P0P7=Y0`20LfP4081_I0@0O6YK101lIUL407aQDP@0
O65D101lHE8307QPD@@0N5e?101hGDh407=JB`/0LeQ9101_DT<406mDA@@0Idho101WAST405<b9@@0
=QlH0`0M4Pd401dB4P@05@`<100I4@`401L?3`@091LD0`0C3@T404Dk=Ql0P81n5P3oool001@0oooo
7`20P7h405a9@P<0>BTS100e:B@403<V8@@0:QXE100M4Pd402LH50@0<R<L0`0n<BP404Hl<0@0LUa>
1020Jed8081_I@<0P7=Y3020N748081cJ@<0P7=X1020Kf@407aZF`@0O6IG101lHE8407aQE0@0O65B
0`1hH54407QMC`@0N5e>101cFT/;07=HB@@0Ke93101_E4D406M>?`@0IdHi101C<RD403HO60<07A8=
100M4Q8401D<30@06A4<100G3`l402@G50<04`d91015>cHO0820OQH0oooo000D0?oooal0P81n101L
BD8303TY8`@0=BTT100c9R4402XJ5@@07A8=100W61@4038S70<0?S4X1016?304079LCP@0P6]M2020
KfD3081cJ@`0P7Qa2020LfT3081cJ0@0P6mT101lJU/407aVE`@0O65B101lHE@407aQDP<0N61A101h
GDl407QMCP@0LeY;2`1cF4T406mB@`@0KeA5101WCSl406M6>@@0Dc8U100f7aP301dB3@@07A8B100E
30`401TA30@05`l?100T5a@301<=2@@0AC/f7`20P7hF0?ooo`00503ooolK0820OP@0PH1n101G@c`3
03DW8P@0=bXU100e9b8402LH4`@0:Q`H100T6QH402dO6`<0@BlU101B?S8406Y=?`@0NfMI1020Kf47
081_I@@0P7=Y2020N744081hL0@0P7=Y0`21LVH4081_H`@0PFeM101lIUL407MRE0@0N5i?101lGU83
07QMCP@0N5]<101hFTh407=GB@@0LeQ9101cEDL306mEA`@0KeA5101[CT0406a;?0@0Hd8b1011:Ah4
034L5P<08AHA200L510401P@30@071@@100T5a@301T>2B<0P81n5P3oool001@0oooo6`20P7h40860
OP@0Ed<l0`0e9b8403LZ9@@0=BLR100W61<402XL60@091XF100]7a/3044_9@@0DShb101ZCCl407]W
F@@0P6mQ1`20KfD4081cJ@P0P7Qa1020N704081cJ@<0PG9V1020Kf<4085]G@@0O6IG101gHU@407QN
C`@0O5iB0`1hGDh407QKC0@0N5Y>101cEdT407=HB@@0LeE70`1_EDL406mDA@@0Jdi0101/Bc`406=2
<P@0@BTN100a71H3024F4@P071@@100H40`401`D40@091LD0`0I3PTS0820OQH0oooo000D0?oooa/0
P81n1021P7h405M3?0<0=BLR100g:RD403DW8P@09aPC100Z71P402@J5P@0;AlK0`11;bD4058n<P@0
JTdo101kIeT4081_H@L0P6mU1020LfT8081hL@@0P7Q`1020LfT3085bIP@0P6mS1021KEd407aVE`@0
Mf9D101hGTl407aNDP<0N5e>101hFd`407QJCP@0LeM9101cF4T407=EA`<0KeE7101_E4D406]>@0@0
K4/l101S@S84044Y7P@0<A`F0`0Q5Q4801`D40@0610<100L510402@G50<06@h98`20P7hF0?ooo`00
503ooolK0820OP@0PH1n101G@c`303DW8P@0=bXU100e9b8402LH4`@0:Q`H100T6QH402dO6`<0@BlU
101B?S8406Y=?`@0NfMI1020Kf47081_I@@0P7=Y2020N744081hL0@0P7=Y0`21LVH4081_H`@0PFeM
101lIUL407MRE0@0N5i?101lGU8307QMCP@0N5]<101hFTh407=GB@@0LeQ9101cEDL306mEA`@0KeA5
101[CT0406a;?0@0Hd8b1011:Ah4034L5P<08AHA200L510401P@30@071@@100T5a@301T>2B<0P81n
5P3oool001@0oooo6`20P7h4081lN@@0CcXc0`0g9Qh403<V8@@0=bXU100c9R4402LK5`@0;B4L100_
8AT303L_:@@0DST/101VC3l407MSEP@0P6mQ1020KfD7081cJ@P0P7Q`1020Mfl4085bIP<0PG5T101l
Je`4085YFP@0O65A101lHE8407aQD@L0N5i?101hFT/407=MCP@0LeQ9101_DTL706mDA@@0KUA5101/
CSl406=6=P@0CS0W100k81T402<G4P<07A8=100J4A0401H=30@03PT8100F30`402/Q70<07A8=1025
QH8O0820OQH0oooo000D0?oooa/0P81n1020O7T404lj<`<0=bHN100c9R4403LZ9@@0<bHQ100W6aL4
02dQ70@0;b4I0`0g;bT4058i;0@0IT`o101gHeH4081_H@@0P6mU1`20LfT8081hL0@0P7M_1021LVH3
085aI0@0O6]L1021JEX407aQD@@0O65B101lHE4707QNC`@0N5Y;101cGDh407=HB@@0Ke971`1_E4D4
06iDA@@0K4ho101SASH404h`9`@0>b0I100S5a8301dB3@@06Q4@100F3@`400h920@05P`<100[8A`3
01dB3@@0QHF27`20P7hF0?ooo`00503ooolK0820OP@0P7ai101?>S<303LV7P@0<bHQ100g:RD403<V
8@@09a/G100]8A`402lQ6@<0=blY101B>B`406I<?`@0Mf=F1020Kf44081_I@L0P7=Y2020N704081g
K`@0PG9V0`21LF@407a[G0@0PFUJ101lHE4407aQDP@0O65A1`1hGTl407QJB`@0Lee>101cF4T406mB
A`L0KeA5101^E4D406a>?`@0HdHf101><2L403/P6@@08aLB0`0M4Pd401XA40@05Pd<100>2@P401H<
30@0:b4L0`0M4Pd408F5PQl0P81n5P3oool001@0oooo6`20P7h4081lN@@0CcXc0`0g9Qh403<V8@@0
=bXU100c9R4402LK5`@0;B4L100_8AT303L_:@@0DST/101VC3l407MSEP@0P6mQ1020KfD7081cJ@P0
P7Q`1020Mfl4085bIP<0PG5T101lJe`4085YFP@0O65A101lHE8407aQD@L0N5i?101hFT/407=MCP@0
LeQ9101_DTL706mDA@@0KUA5101/CSl406=6=P@0CS0W100k81T402<G4P<07A8=100J4A0401H=30@0
3PT8100F30`402/Q70<07A8=1025QH8O0820OQH0oooo000D0?oooal0P81n101PBD83034R6@@0>BTS
100e:B@4038T7`@0;Q`G100_8AT4034U80<0>2`S1017<2H405M1=0@0LUQ<101kJed4081_I0<0P6mU
3020LfL4081cJ0@0P6mT0`1lJU/407aVE`@0O6MF101lH54407QMC0@0N5i?101hGT`307QKC0@0N5e>
201cF4T407=EA`@0KeA50`1_Cd4406a>?`@0HdHf101><BP404<Y7@@0:QPC100Q5Q43020E40@06A4@
100F30`401D<30@07aDB10000003034P6b<0P81n5P3oool001@0oooo7`20P7h40619@P<0<B8I100i
:B<403DY90@0<R@O100^71L402lQ6@@0<BDP0`0h;2<404L`9P@0Ed4d101bF4`407][G@@0P6mT0`20
KfD<081cI`@0P7=X1020Kf@307aZF`@0O6IG101lIeH407aPD@@0N5e<101hGTl407QNC0<0N5]<101h
GDh807=HB@@0LeE7101_E4D306m?@@@0K4ho101SASH404ha:0@0@bTM100Z61<4024F4@<081D@100I
4A0401H<30@05@`<100O5A84000000<0<B0K8`20P7hF0?ooo`00503ooolO0820OP@0H4U20`0a8QT4
03TY8`@0=BTT100b91l402hL5`@0;b4I100a9B0303P/8`@0Ac0V101G@C@4079HC0@0Nf]M1020Kf@3
081_I@`0P7=W1020LfP4081_I0<0O6YK101lIUL407aWEP@0O61A101hGD`407QNC`@0N5i<0`1hFd`4
07QMCPP0LeQ9101cEDL406mDA@<0Kdm1101/CSl406=6=P@0CS4X1013:Ad402XH4`@08AHA0`0P5A04
01TA40@05P`<100E30`401lE4P@000000`0a81/S0820OQH0oooo000D0?oooal0P81n101PBD83034R
6@@0>BTS100e:B@4038T7`@0;Q`G100_8AT4034U80<0>2`S1017<2H405M1=0@0LUQ<101kJed4081_
I0<0P6mU3020LfL4081cJ0@0P6mT0`1lJU/407aVE`@0O6MF101lH54407QMC0@0N5i?101hGT`307QK
C0@0N5e>201cF4T407=EA`@0KeA50`1_Cd4406a>?`@0HdHf101><BP404<Y7@@0:QPC100Q5Q43020E
40@06A4@100F30`401D<30@07aDB10000003034P6b<0P81n5P3oool001@0oooo7`20P7h406eNE`<0
=bLR100c9Al403TZ9@@0=B@K100^8Qd402XL60@0<bDO0`0`8ah403/]9`@0B3<Y101WC3h407a[G0@0
PFmO0`20Kf04081_I0@0P6mP2021Kel4081_I0<0PFeM101lHe<407aQD@@0N5Q9101hFT/407QJCP@0
N5e>0`1hFd`407QEA`@0LeM9101cEDL407=EA@@0Ke930`1^Cd4406Q9>P@0E3DX1013:Ad402XH4`@0
7a<=100K4A03020E40@06a4@100B20P401D<30@08QHC100M4Pd308F5PR<0P81n5P3oool001@0oooo
7`20P7h406eNE`<0=bLR100c9Al403TZ9@@0=B@K100^8Qd402XL60@0<bDO0`0`8ah403/]9`@0B3<Y
101WC3h407a[G0@0PFmO0`20Kf04081_I0@0P6mP2021Kel4081_I0<0PFeM101lHe<407aQD@@0N5Q9
101hFT/407QJCP@0N5e>0`1hFd`407QEA`@0LeM9101cEDL407=EA@@0Ke930`1^Cd4406Q9>P@0E3DX
1013:Ad402XH4`@07a<=100K4A03020E40@06a4@100B20P401D<30@08QHC100M4Pd308F5PR<0P81n
5P3oool001@0oooo7`20P7h406eNE`<0=bLR100c9Al403TZ9@@0=B@K100^8Qd402XL60@0<bDO0`0`
8ah403/]9`@0B3<Y101WC3h407a[G0@0PFmO0`20Kf04081_I0@0P6mP2021Kel4081_I0<0PFeM101l
He<407aQD@@0N5Q9101hFT/407QJCP@0N5e>0`1hFd`407QEA`@0LeM9101cEDL407=EA@@0Ke930`1^
Cd4406Q9>P@0E3DX1013:Ad402XH4`@07a<=100K4A03020E40@06a4@100B20P401D<30@08QHC100M
4Pd308F5PR<0P81n5P3oool001@0oooo7`20P7h406eNE`<0=bLR100c9Al403TZ9@@0=B@K100^8Qd4
02XL60@0<bDO0`0`8ah403/]9`@0B3<Y101WC3h407a[G0@0PFmO0`20Kf04081_I0@0P6mP2021Kel4
081_I0<0PFeM101lHe<407aQD@@0N5Q9101hFT/407QJCP@0N5e>0`1hFd`407QEA`@0LeM9101cEDL4
07=EA@@0Ke930`1^Cd4406Q9>P@0E3DX1013:Ad402XH4`@07a<=100K4A03020E40@06a4@100B20P4
01D<30@08QHC100M4Pd308F5PR<0P81n5P3oool001@0oooo7`20P7h406eNDP<0@30[100e:B@403<V
8@@0=bLR100[6aT402`N6@@0;B4L0`0e:B@4034R6@@0>BLO101F?c8406mEA@@0O6QH0`1lJU/4085^
GPP0PFmO201lJU/3085]G@@0O5i?101hF4T407QKB@@0LeA5201cF4T307QHB@P0LeA5101cCd<406iB
@`@0K50o0`1VA3@40651<@@0AB`O100]6A<402<G4P@06a4<1`0F30`400h920@03@P8100P5A8402DI
4`@07A8=9P20P7hF0?ooo`00503ooolO0820OP@0KEiB0`10<2/403DY90@0<bHQ100g9b8402/K6@@0
;1hI100]8A`303DY90@0<B8I100i9al405Ho<P@0KeE5101lJ5P307aZF`@0PFiN2021Kel807aZF`<0
PFeM101lGTl407QHB@@0N5]9101cE4D807=HB@<0N5Q9201cE4D407=?@`@0KU93101/D3l306I4=0@0
HD4a1015;1l402dI4`@08aLB100K4@`701H<30@03PT8100=20P4020E4P@09ATC100M4PdV0820OQH0
oooo000D0?oooal0P81n101]GU83040`:`@0=BTT100c9R4403LW8P@0:a/I100/7QT402dQ70<0=BTT
100a8QT403TW7`@0ESlb101_EDD407aXF0<0O6YK1021KUh8085_G`P0O6YK0`21KEd407aNC`@0N5Q9
101hFdT407=DA@P0LeQ90`1hF4T807=DA@@0Ldm3101^DT<406a@?`<0IT@d101Q@C4404D/7`@0;ATC
100S5a8401/A30L05P`<100>2@P400d820@081DB100U6A<401dB3BH0P81n5P3oool001@0oooo7`20
P7h406eNDP<0@30[100e:B@403<V8@@0=bLR100[6aT402`N6@@0;B4L0`0e:B@4034R6@@0>BLO101F
?c8406mEA@@0O6QH0`1lJU/4085^GPP0PFmO201lJU/3085]G@@0O5i?101hF4T407QKB@@0LeA5201c
F4T307QHB@P0LeA5101cCd<406iB@`@0K50o0`1VA3@40651<@@0AB`O100]6A<402<G4P@06a4<1`0F
30`400h920@03@P8100P5A8402DI4`@07A8=9P20P7hF0?ooo`00503ooolO0820OP@0P7]j0`12<2T4
03LZ9@@0=BLR100g:bH403<S6P@0:ATE100a9R4302hR7@@0=bXU100^7QT403d^9@@0DSX^101/Bc/3
07QMCP@0O69A101lIEL407aXFP@0O6QH101lIUL307aRD@@0M5E4101aCSh407=@?P@0LeA5101cDD<4
07=@@@<0LeA5101cE44406m?@@@0KTho101ZBCX406A9>P<0EST/1019:Ad403TO60@09aLB100K4@`4
01H=30@05P`<0`0A20P400d820@04``;100K4`l4024I50@09aH=9P20P7hF0?ooo`00503ooolO0820
OP@0P7]j0`12<2T403LZ9@@0=BLR100g:bH403<S6P@0:ATE100a9R4302hR7@@0=bXU100^7QT403d^
9@@0DSX^101/Bc/307QMCP@0O69A101lIEL407aXFP@0O6QH101lIUL307aRD@@0M5E4101aCSh407=@
?P@0LeA5101cDD<407=@@@<0LeA5101cE44406m?@@@0KTho101ZBCX406A9>P<0EST/1019:Ad403TO
60@09aLB100K4@`401H=30@05P`<0`0A20P400d820@04``;100K4`l4024I50@09aH=9P20P7hF0?oo
o`00503ooolO0820OP@0P7]j0`12<2T403LZ9@@0=BLR100g:bH403<S6P@0:ATE100a9R4302hR7@@0
=bXU100^7QT403d^9@@0DSX^101/Bc/307QMCP@0O69A101lIEL407aXFP@0O6QH101lIUL307aRD@@0
M5E4101aCSh407=@?P@0LeA5101cDD<407=@@@<0LeA5101cE44406m?@@@0KTho101ZBCX406A9>P<0
EST/1019:Ad403TO60@09aLB100K4@`401H=30@05P`<0`0A20P400d820@04``;100K4`l4024I50@0
9aH=9P20P7hF0?ooo`00503ooolO0820OP@0P7]j0`12<2T403LZ9@@0=BLR100g:bH403<S6P@0:ATE
100a9R4302hR7@@0=bXU100^7QT403d^9@@0DSX^101/Bc/307QMCP@0O69A101lIEL407aXFP@0O6QH
101lIUL307aRD@@0M5E4101aCSh407=@?P@0LeA5101cDD<407=@@@<0LeA5101cE44406m?@@@0KTho
101ZBCX406A9>P<0EST/1019:Ad403TO60@09aLB100K4@`401H=30@05P`<0`0A20P400d820@04``;
100K4`l4024I50@09aH=9P20P7hF0?ooo`00503ooolS0820OP<0G4]3100d91l403DW8P@0<bHQ100a
9B0402/K6@@0;alH0`0e9b8403@Z9@@0=bXU100_8al403h`:@@0AS<Y0`1J>b`406M:@0@0HTPk101/
CC`4071EA`@0L5E50`1]Cd4406M5=0@0FCX[101O@2h406U2<@@0KT/i101_CS`306i7>0@0JdHf101/
AS8406U7=`@0HD8f101I=b/304`/7`@0>AhG100Z5a8401dB3@@05`d<100B20P;00d820@06A<?100R
5Q<401<=2@@0NgMe9P20P7hF0?ooo`00503ooolS0820OP<0G4]3100d91l403DW8P@0<bHQ100a9B04
02/K6@@0;alH0`0e9b8403@Z9@@0=bXU100_8al403h`:@@0AS<Y0`1J>b`406M:@0@0HTPk101/CC`4
071EA`@0L5E50`1]Cd4406M5=0@0FCX[101O@2h406U2<@@0KT/i101_CS`306i7>0@0JdHf101/AS84
06U7=`@0HD8f101I=b/304`/7`@0>AhG100Z5a8401dB3@@05`d<100B20P;00d820@06A<?100R5Q<4
01<=2@@0NgMe9P20P7hF0?ooo`00503ooolS0820OP<0G4]3100d91l403DW8P@0<bHQ100a9B0402/K
6@@0;alH0`0e9b8403@Z9@@0=bXU100_8al403h`:@@0AS<Y0`1J>b`406M:@0@0HTPk101/CC`4071E
A`@0L5E50`1]Cd4406M5=0@0FCX[101O@2h406U2<@@0KT/i101_CS`306i7>0@0JdHf101/AS8406U7
=`@0HD8f101I=b/304`/7`@0>AhG100Z5a8401dB3@@05`d<100B20P;00d820@06A<?100R5Q<401<=
2@@0NgMe9P20P7hF0?ooo`00503ooolS0820OP<0NG5b100k;2D403<W8`@0<bTT100c9R44024G4P@0
:alL0`0g:R<403L[9P@0?C4/100k;bX403X_:@@0?c</0`15<bT404L_9`@0ABdS1012;BH404l`9@@0
ES`_0`1>=B`404L`:@@0C2lT1019;Al404l`90@0FST[101M?B`3068l:`@0GCd^101D<bD405Hg:`@0
E38V1017;B8303HN5`@0<AhI100N4Pd401/A30@05P`<100A20P400d820<030P8100K4`l401H?3`@0
:BTV100M4PdZ0820OQH0oooo000D0?ooob<0P81n0`1iLG8403//9@@0<bLS100c:B@403<V8@@08ALB
100[7a`303LZ8`@0=b/V100m<B`403/_:P@0>RlY100o<b`304Dc:@@0AblW1015;B<4048]9P@0Cc0U
101F?2l304he;0@0Ac0Y101<;b@404T]7`@0Cc0T101J>B/405dm;0<0HS`[101M?Bh405@c9@@0ESL[
101D<RH404L]8P<0=QhG100a7QT401hB3@@06a4<100F30`4014820@03@P80`0<20P401/C3`@05Pl?
100Y:BH401dB3BX0P81n5P3oool001@0oooo8`20P7h307UaLP@0>b`U100c9b<403<Y90@0<bHQ100Q
5a8402/O70<0=bXS100g:bH403da;0@0>blZ100j;bT403lc;0<0AC<Y1017;bL404D]8`@0@RdV101?
<2D405Hl;`<0CSD/1017<2T404`_90@0BBdO101?<2@405Xi:`@0GCd/0`1R?2/405dm;P@0E3<U101F
=b/405@b9P@0AbdR0`0f7QL4034N6@@07Q8=100K4@`401H<30@04@P8100=20P300`820@06a<?100F
3`l402TY9P@07A8=:P20P7hF0?ooo`00503ooolS0820OP<0NG5b100k;2D403<W8`@0<bTT100c9R44
024G4P@0:alL0`0g:R<403L[9P@0?C4/100k;bX403X_:@@0?c</0`15<bT404L_9`@0ABdS1012;BH4
04l`9@@0ES`_0`1>=B`404L`:@@0C2lT1019;Al404l`90@0FST[101M?B`3068l:`@0GCd^101D<bD4
05Hg:`@0E38V1017;B8303HN5`@0<AhI100N4Pd401/A30@05P`<100A20P400d820<030P8100K4`l4
01H?3`@0:BTV100M4PdZ0820OQH0oooo000D0?ooob<0P81n0`21P7h404`h=0@0<bHQ100e9b8403<W
8P@0<bHQ100Z8al303@Z9@@0?C4/100i;2L403/]:0@0?RXU1014;bD3040/8@@0>BXT100a81/403LV
80@0<A`G100k9b4303dZ90@0=2@O100a7AL403@P6P@0=1dF100h7AL7044X70@0?bLK100m7aP403TN
5`@0=QlH100d7AL302DH4P@07A8=100I3Pd801H<30P03@P80`0K4aD401/C3`@0:b4L10092@T405A5
?bX0P81n5P3oool001@0oooo8`20P7h30860OP@0C3Pd100c9R4403DW8P@0<bLR100c9R4402XS7`<0
=2XU100m<B`403T/9`@0>bdX100n:RD404@_9@<0@2`Q100i:R@4034P6`@0=bHP100a71L403/W8@<0
?BXT100d91l4034M5`@0=20J100d7AH403PM5`L0@BPL100o9a/403dO60@0>AhG100f7aP403@M5`<0
9APB100M4Pd401T>3@P05P`<200=20P301/C5@@06a<?100[8A`400T92@@0E4Do:P20P7hF0?ooo`00
503ooolS0820OP<0PH1n101<>3@403<V8@@0=BLR100c9b8403<V8@@0:R<O0`0d:RD403da;0@0>B`W
100k;BP403hZ9@@0A2lU0`10;24403TZ90@0<B0K100g9R04034L5`@0>bLQ0`0m:R@403@T7`@0<AdG
100d81X403@M5P@0>1dG1`11:1`403lW6`@0?AlH100i7QL403HO60@0=1dG0`0U618401dB3@@06@h=
200F30`800d820<06a<E100K4`l402/Q70@02@T9101DAClZ0820OQH0oooo000D0?ooob<0P81n0`21
P7h404`h=0@0<bHQ100e9b8403<W8P@0<bHQ100Z8al303@Z9@@0?C4/100i;2L403/]:0@0?RXU1014
;bD3040/8@@0>BXT100a81/403LV80@0<A`G100k9b4303dZ90@0=2@O100a7AL403@P6P@0=1dF100h
7AL7044X70@0?bLK100m7aP403TN5`@0=QlH100d7AL302DH4P@07A8=100I3Pd801H<30P03@P80`0K
4aD401/C3`@0:b4L10092@T405A5?bX0P81n5P3oool001@0oooo9P20P7h407A[K0@0=bLR100c9R44
03DY90@0<bHQ100h;RT3038T7`@0>bhY100f9b4403LZ9@@0?2lX100i:B@303/W8@@0=bHP100`8ah4
038V8@@0:a`J100Z7a/702hL5`@09QLB100Q5Q4402@F4P@0:QTD100/6A@;02LG4P@0;1TD100V5Q44
02@F4@<07A8=100J4@`401H<30@05@`<200=20P401<<2`<07aPE100W61D401<=2@@09b0K;P20P7hF
0?ooo`00503ooolV0820OP@0M6]/100g9b8403<V8@@0=BTT100c9R4403P^:@<0<R@O100k;RT403HW
8@@0=bXU100l;bP403TY90<0>bLQ100g9R04030S7P@0<RHQ100[71X402XO6`L0;Q`G100V5a84024F
4@@091HB100Z6A@402`I50/09aLB100/6A@402HF4@@091HA0`0M4Pd401XA30@05P`<100E30`800d8
20@04``;0`0O61D402LH5@@04`d9100W81/^0820OQH0oooo000D0?ooobH0P81n101dJf`403LW8P@0
<bHQ100e:B@403<V8@@0>2hY0`0b91l403/^:@@0=RLQ100g:RD403`_:0@0>BTT0`0k9b4403LV80@0
<2<N100b9R4402/L6P@0:QlK1`0^71L402HG4P@08AHA100T5Q8402XI50@0;1TD2`0W5a8402`I50@0
9QHA100T5Q4301dB3@@06Q4<100F30`401D<30P03@P8100C30/301lH5@@09aPE100C3@T402LP6bh0
P81n5P3oool001@0oooo9P20P7h407A[K0@0=bLR100c9R4403DY90@0<bHQ100h;RT3038T7`@0>bhY
100f9b4403LZ9@@0?2lX100i:B@303/W8@@0=bHP100`8ah4038V8@@0:a`J100Z7a/702hL5`@09QLB
100Q5Q4402@F4P@0:QTD100/6A@;02LG4P@0;1TD100V5Q4402@F4@<07A8=100J4@`401H<30@05@`<
200=20P401<<2`<07aPE100W61D401<=2@@09b0K;P20P7hF0?ooo`00503ooolV0820OP@0PGil101>
=C0803DY90@0=BLR100^8ah303h`:`@0=R`W100g;2L402hR7@@0>BLO100d8a`3038T7`@0<2<N100W
71h402`R7@@0;AdK100Y6AD302@G6@P08AHA100K4@`401dE40@07QD@100Q5Q4301dB3@@05`d<100K
4@`4028E40@07A8=100G3@`301/A30@06A4@100F30`400d820@05@`<100I4`l401lH5@<08QHC100M
5Q8401dB3C80P81n5P3oool001@0oooo9P20P7h4085nO0@0CSD`200e:B@403DW8P@0;R<N0`0n<2/4
03H/9`@0=b`W100^8Qd403TW7`@0=2<L0`0b91l4030S7P@09a`N100/8Qd402dM6`@0:ATE0`0T5aT8
024F4@@06a4<100M5A0401hE40@08AHA0`0M4Pd401L=30@06a4<100R5A0401dB3@@05`d<0`0K4@`4
01TA40@05P`<100=20P401D<30@06A<?100O61D3028F4`@07AHB100M4Pdb0820OQH0oooo000D0?oo
obH0P81n1021OW`404he<0P0=BTT100e9b8402hS7P<0?S0[100f;2L403L/9`@0;R8M100i9al403@S
70<0<R@O100`8ah402LL7P@0;28M100]7A/402TI5@<091LI200Q5Q4401/A30@07AD@100N5A04024F
4@<07A8=100G3@`401/A30@08QD@100M4Pd401L=30<06a4<100I4A0401H<30@03@P8100E30`401TC
3`@07aPE0`0R5Q<401dF4P@07A8=<P20P7hF0?ooo`00503ooolV0820OP@0PGil101>=C0803DY90@0
=BLR100^8ah303h`:`@0=R`W100g;2L402hR7@@0>BLO100d8a`3038T7`@0<2<N100W71h402`R7@@0
;AdK100Y6AD302@G6@P08AHA100K4@`401dE40@07QD@100Q5Q4301dB3@@05`d<100K4@`4028E40@0
7A8=100G3@`301/A30@06A4@100F30`400d820@05@`<100I4`l401lH5@<08QHC100M5Q8401dB3C80
P81n5P3oool001@0oooo:P20P7h406MGD`@0=bHQ100g:RD403DW8P@0=BTT0`0_9b<403T/9`@0=RLQ
100^81/402`N6@@0:QPB0`0]8A`802TK6@@08QHB100T5aT401`B4P<06@d=100K4A8401XA40@05Pd<
100I4A0401H=30@06Q4@0`0F3@`401TA40@06a<@100I4A0401L=30l03@P8100H410401H?2`@05@`<
100P4@`3024M6@@07A8==P20P7hF0?ooo`00503ooolZ0820OP@0IeMC100g9R4403LZ9@@0=BLR100e
:B@302lW8`@0>B`W100f9b4402hP6`@0;1hI100Z618302dQ70P0:A/I100R5Q8402@G6@@0718B0`0I
3@d401/A4P@06Q4@100F3@`401TA40@05Pd<100J4A0301H=30@06A4@100K4a0401TA40@05`d<3`0=
20P401P@40@05Pl;100E30`4020A30<08AdI100M4Pdf0820OQH0oooo000D0?ooobX0P81n101WEe<4
03LV8@@0=bXU100e9b8403DY90<0;bLS100i;2L403HW8@@0;R0K100/7QT402XH4P<0;B4L200Y6aT4
028F4P@091LI100L4Q8301T=3@@06a4B100J4A0401H=30@06A4@100F3@`401XA40<05Pd<100I4A04
01/C40@06A4@100G3@`?00d820@0610@100F3`/401D<30@0814<0`0Q7AT401dB3CH0P81n5P3oool0
01@0oooo:P20P7h406MGD`@0=bHQ100g:RD403DW8P@0=BTT0`0_9b<403T/9`@0=RLQ100^81/402`N
6@@0:QPB0`0]8A`802TK6@@08QHB100T5aT401`B4P<06@d=100K4A8401XA40@05Pd<100I4A0401H=
30@06Q4@0`0F3@`401TA40@06a<@100I4A0401L=30l03@P8100H410401H?2`@05@`<100P4@`3024M
6@@07A8==P20P7hF0?ooo`00503oool^0820OP@0CD0j100`8ah403DW8P@0<bTT0`0e:RD403L]:0@0
=BLU100/6aH402XM6@@08AHB0`0R5A04028G4P@08aHB100H3@d401L=30@06a4B0`0I4A0401D<30@0
6A4@100F30`401P@40@05P`<100R5Q<300d820@0610@100L510401XA40P03@P80`0@20P<01H?3`@0
91LD100W7AH402@T80<04`T4101kMgDf0820OQH0oooo000D0?ooobh0P81n101=@3X4030S7P@0=BLR
100c:B@303DZ9@@0=bdX100e9bD402`K5P@0:QdI100Q5Q83028E40@08QLB100S5Q8401P=3@@05`d<
100K4A8301TA40@05@`<100I4A0401H<30@0610@100F30`4028F4`<03@P8100H410401`D40@06Q4@
200=20P3010820`05Pl?100T5a@402LM5P@092@P0`0C2@@407]gMCH0P81n5P3oool001@0oooo;P20
P7h404e0>P@0<2<N100e9b8403<Y90<0=BXU100g;BP403DW9@@0;1/F100Z7AT4024F4P<08QD@100R
5a8402<F4P@060d=100G3@`401/A4P<06A4@100E30`401TA40@05P`<100H410401H<30@08QHC0`0=
20P401P@40@071@@100J4A0800d820<040P8300F3`l402@G50@09adF100T920301<910@0NgMe=P20
P7hF0?ooo`00503ooolb0820OP@0CChh100a9b<4030S7PL0=bdX100k;RT402hS7`@0;AlK100T5QT3
01XA40@08QD@100J4A0401hE40@06a<@100H410701H<30@05@`<100F30`401D<30@071@@100H4103
02dT9@@081hM100O51L401H=30@06A4@1`0I4`l401L?3`@09AdJ100T6QL402@G50@0=BHP100W6a83
04lg:3X0P81n5P3oool001@0oooo<P20P7h404dn>0@0<BLS100`8ah703L]:0@0>bhY100^8al402dO
6`@091HI0`0J4A04028E40@06Q4@100N5A0401/C40@0610@1`0F30`401D<30@05P`<100E30`401`D
40@0610@0`0]92D4020N7@@07a@G100F3@`401TA40L06A<?100G3`l402DM6P@091XG100T5a@403DV
80@09a/B0`1?=bPj0820OQH0oooo000D0?oooc80P81n101=?SP4034W8`@0<2<N1`0g;BP403/^:@@0
;R<O100]7a/402@F6@<06Q4@100R5A0401XA40@07QD@100K4a0401P@40L05P`<100E30`401H<30@0
5@`<100L510401P@40<0;B@U100P7Qd401lD5`@05Pd<100I4A0701TC3`@05`l?100U7AX402@J5`@0
91LD100e9R0402LK4P<0CcLX>P20P7hF0?ooo`00503ooolb0820OP@0CChh100a9b<4030S7PL0=bdX
100k;RT402hS7`@0;AlK100T5QT301XA40@08QD@100J4A0401hE40@06a<@100H410701H<30@05@`<
100F30`401D<30@071@@100H410302dT9@@081hM100O51L401H=30@06A4@1`0I4`l401L?3`@09AdJ
100T6QL402@G50@0=BHP100W6a8304lg:3X0P81n5P3oool001@0oooo<P20P7h40820O@@0CC/f100g
;BP302hR7@@0=b`W100m<B`403/^:@@0;b8I100/7QT301hE4P@06A4@100G3@`401TA30@06Q4@100F
3@`301H<30@0610@100E30`401P@40P05@`<100W8b4302@J7`@0=Rl_100f;b`402/Q8@@09b4O100U
7AX301dE40@09A/G100T6QL403<W8`@0=2HO100M5Q44040Y7cd0P81n5P3oool001@0oooo<P20P7h4
0820O@@0CC/f100g;BP302hR7@@0=b`W100m<B`403/^:@@0;b8I100/7QT301hE4P@06A4@100G3@`4
01TA30@06Q4@100F3@`301H<30@0610@100E30`401P@40P05@`<100W8b4302@J7`@0=Rl_100f;b`4
02/Q8@@09b4O100U7AX301dE40@09A/G100T6QL403<W8`@0=2HO100M5Q44040Y7cd0P81n5P3oool0
01@0oooo<P20P7h40820O@@0CC/f100g;BP302hR7@@0=b`W100m<B`403/^:@@0;b8I100/7QT301hE
4P@06A4@100G3@`401TA30@06Q4@100F3@`301H<30@0610@100E30`401P@40P05@`<100W8b4302@J
7`@0=Rl_100f;b`402/Q8@@09b4O100U7AX301dE40@09A/G100T6QL403<W8`@0=2HO100M5Q44040Y
7cd0P81n5P3oool001@0oooo<P20P7h40820O@@0CC/f100g;BP302hR7@@0=b`W100m<B`403/^:@@0
;b8I100/7QT301hE4P@06A4@100G3@`401TA30@06Q4@100F3@`301H<30@0610@100E30`401P@40P0
5@`<100W8b4302@J7`@0=Rl_100f;b`402/Q8@@09b4O100U7AX301dE40@09A/G100T6QL403<W8`@0
=2HO100M5Q44040Y7cd0P81n5P3oool001@0oooo=P20P7h408F5PP@0BcL^0`0m<B`403<W8`@0>2lZ
1010<bd403da;0@0;QhI0`0Z7AT402TQ70@091dJ100N4a0401`D40@06A4@0`0H410401D<30@05P`<
100K4aH401TA40@06a<@100H410302`T80@0;b<R100R5QD402HJ5@@08aPC100Q5A@302HG4P@09A/G
100_8AT403D[8`@0=C4[100k91/4081lNCd0P81n5P3oool001@0oooo=P20P7h408F5PP@0BcL^0`0m
<B`403<W8`@0>2lZ1010<bd403da;0@0;QhI0`0Z7AT402TQ70@091dJ100N4a0401`D40@06A4@0`0H
410401D<30@05P`<100K4aH401TA40@06a<@100H410302`T80@0;b<R100R5QD402HJ5@@08aPC100Q
5A@302HG4P@09A/G100_8AT403D[8`@0=C4[100k91/4081lNCd0P81n5P3oool001@0oooo=P20P7h4
08F5PP@0BcL^0`0m<B`403<W8`@0>2lZ1010<bd403da;0@0;QhI0`0Z7AT402TQ70@091dJ100N4a04
01`D40@06A4@0`0H410401D<30@05P`<100K4aH401TA40@06a<@100H410302`T80@0;b<R100R5QD4
02HJ5@@08aPC100Q5A@302HG4P@09A/G100_8AT403D[8`@0=C4[100k91/4081lNCd0P81n5P3oool0
01@0oooo=P20P7h408F5PP@0BcL^0`0m<B`403<W8`@0>2lZ1010<bd403da;0@0;QhI0`0Z7AT402TQ
70@091dJ100N4a0401`D40@06A4@0`0H410401D<30@05P`<100K4aH401TA40@06a<@100H410302`T
80@0;b<R100R5QD402HJ5@@08aPC100Q5A@302HG4P@09A/G100_8AT403D[8`@0=C4[100k91/4081l
NCd0P81n5P3oool001@0oooo?P20P7h304Tg;P@0=RLQ100g:RD404<g<P@0@cTd1010<bd302XM6@@0
:1XI100^71L402lU80@09ahJ100J4A0301H<30@07aLJ100N5QP4028L60@081PL100X8Al401dE5`<0
:B@R100_9B<403<V8@@09alL100W7QX402TQ70<0:B@Q100[8A`403@/9@@09alE101:<R@4075YK440
P81n5P3oool001@0oooo?P20P7h304Tg;P@0=RLQ100g:RD404<g<P@0@cTd1010<bd302XM6@@0:1XI
100^71L402lU80@09ahJ100J4A0301H<30@07aLJ100N5QP4028L60@081PL100X8Al401dE5`<0:B@R
100_9B<403<V8@@09alL100W7QX402TQ70<0:B@Q100[8A`403@/9@@09alE101:<R@4075YK440P81n
5P3oool001@0oooo?P20P7h304Tg;P@0=RLQ100g:RD404<g<P@0@cTd1010<bd302XM6@@0:1XI100^
71L402lU80@09ahJ100J4A0301H<30@07aLJ100N5QP4028L60@081PL100X8Al401dE5`<0:B@R100_
9B<403<V8@@09alL100W7QX402TQ70<0:B@Q100[8A`403@/9@@09alE101:<R@4075YK440P81n5P3o
ool001@0oooo?P20P7h304Tg;P@0=RLQ100g:RD404<g<P@0@cTd1010<bd302XM6@@0:1XI100^71L4
02lU80@09ahJ100J4A0301H<30@07aLJ100N5QP4028L60@081PL100X8Al401dE5`<0:B@R100_9B<4
03<V8@@09alL100W7QX402TQ70<0:B@Q100[8A`403@/9@@09alE101:<R@4075YK440P81n5P3oool0
01@0oooo@@20P7h404U2>0@0=R`W100g:RD4048c;P@0AChl0`13=c8403D/:0@0<R/Y100_8R04030Y
9P@0<bd/0`0Y9bD402DN7@@0:B8W100[8R<403<];0@0;B@S100e9b8302/T8`@0?RdX100g9R8403LV
7P@0=BTT100g;2D303/a:@@0?RXP100W81/404lg:0@0P7aiA@20P7hF0?ooo`00503ooom10820OP@0
BD8h100f;2L403LZ9@@0@S<^1015?S`304<g<P@0=B`X100b:bT402lR80@0<2TV100c;B`302TW9@@0
9AhM100Y8RL402/R8`@0<bd/100]92<403DW8P<0:b@S100n;BP403LV8P@0=bHN100e:B@403L/9@<0
>c4Y100n:R0402LP6`@0CcLX1020O7U50820OQH0oooo000D0?oood40P81n1019@SP403H/9`@0=bXU
1012<bh404Dn?0<0@cLb100e;2P4038[:@@0;b8P100`:BH403<];0<0:BLU100U7Qd402TR9`@0:b8S
100c;B`402dT8`@0=BLR0`0[92<403h]:0@0=bHR100g9Qh403DY90@0=b`U0`0k<BT403hZ80@09b0K
101?=bP4081lNDD0P81n5P3oool001@0oooo@@20P7h404U2>0@0=R`W100g:RD4048c;P@0AChl0`13
=c8403D/:0@0<R/Y100_8R04030Y9P@0<bd/0`0Y9bD402DN7@@0:B8W100[8R<403<];0@0;B@S100e
9b8302/T8`@0?RdX100g9R8403LV7P@0=BTT100g;2D303/a:@@0?RXP100W81/404lg:0@0P7aiA@20
P7hF0?ooo`00503ooom50820OP@0K6EW1013=cD403/_:P@0>C4`0`14@D8404Xo?0@0BCdh1019@3X4
03/c<P@0>3@b0`13>CX4048e;`@0>2hZ100a9RP4030S7`@0>B`Z100i;BP303DY90@0?b`T1010;BD4
040^9P@0@C4Y100l:R8304Pj=0@0CcLX100a81I=0820OQH0oooo000D0?ooodD0P81n101/IFL404<g
=@@0>blZ100i<C0304A1@P@0BSll1019?CP404U0>P@0>c<b100h=38304<i>P@0@SD_100h;RX4034V
:0@0<2<O100i;2X403T]:0<0=BTT100o;2@4040]9@@0@2hV1011<BT403`Z8P<0B3Xd101?=bP4034P
5Td0P81n5P3oool001@0ooooA@20P7h406aUI`@0@cLe100k;bX403Ta<0<0A452101:?c`404Tm>0@0
BD0j100k<c8403Pd<P<0@cTj1012=Bl403P^:P@0<BHX100`8al403T/:P@0>BdX0`0e:B@403l/90@0
@2dU1010;RH4044a:@@0?2XR0`18>S@404lg:0@0<B0FC@20P7hF0?ooo`00503ooom=0820OP@0@3Lj
100k=Rd303di?@@0DdY8101?BTP404a5@@@0Bd8l101=@Sl304e0>P@0Bcll1011>3<404@i=0@0>c<a
100g;bT403/b;P<0@CPc100m<bd404Hc:`@0@R`U101:?3<404Xg;@<0>b@K101?@3mA0820OQH0oooo
000D0?ooodd0P81n1010=cX403/f;@<0?CTm101CBTP404m:B0@0C4E1101;@S`404e2?`<0CD0j101;
?c`4044h<`@0A3Td100k<c4403L_:@@0>c8^0`11>3<403dc;@@0AS<[1012;2D404Xl<`@0BSL]0`0k
91/404m0?e40P81n5P3oool001@0ooooC@20P7h4040g>P@0>cH]0`0m>Cd405=:B0@0CdY8101<AD44
04]2?0@0CD8o0`1=@3X404/o?0@0@CPc1014>C@403/c<@@0=blY100k<Rh3044h<`@0?C<]1016<b/4
048/9@@0BS`c101:=bd303/T6`@0Cd0oD@20P7hF0?ooo`00503ooom=0820OP@0@3Lj100k=Rd303di
?@@0DdY8101?BTP404a5@@@0Bd8l101=@Sl304e0>P@0Bcll1011>3<404@i=0@0>c<a100g;bT403/b
;P<0@CPc100m<bd404Hc:`@0@R`U101:?3<404Xg;@<0>b@K101?@3mA0820OQH0oooo000D0?ooo`P0
P7aiC@20P7h307MbM@@0@3]3101DBDP406EOI0@0FDm>101FBD8704i3@@@0Dd8o101C@S`404e0>P@0
Dd8l1019>c@304Th;`@0Ccdd1010>C04040g;@@0<B@O101XFeiH0820OQH0oooo000D0?ooo`P0P7ai
C@20P7h307MbM@@0@3]3101DBDP406EOI0@0FDm>101FBD8704i3@@@0Dd8o101C@S`404e0>P@0Dd8l
1019>c@304Th;`@0Ccdd1010>C04040g;@@0<B@O101XFeiH0820OQH0oooo000D0?ooo`P0P7aiC@20
P7h307MbM@@0@3]3101DBDP406EOI0@0FDm>101FBD8704i3@@@0Dd8o101C@S`404e0>P@0Dd8l1019
>c@304Th;`@0Ccdd1010>C04040g;@@0<B@O101XFeiH0820OQH0oooo000D0?ooo`P0P7aiC@20P7h3
07MbM@@0@3]3101DBDP406EOI0@0FDm>101FBD8704i3@@@0Dd8o101C@S`404e0>P@0Dd8l1019>c@3
04Th;`@0Ccdd1010>C04040g;@@0<B@O101XFeiH0820OQH0oooo000D0?ooof@0P81n101gLWT4081l
N@<0K6E/201:AD`404Dn>0`0AC/f0`10=c4403/^90@0>c8X1020O7UP0820OQH0oooo000D0?ooof@0
P81n101gLWT4081lN@<0K6E/201:AD`404Dn>0`0AC/f0`10=c4403/^90@0>c8X1020O7UP0820OQH0
oooo000D0?ooof@0P81n101gLWT4081lN@<0K6E/201:AD`404Dn>0`0AC/f0`10=c4403/^90@0>c8X
1020O7UP0820OQH0oooo000D0?ooof@0P81n101gLWT4081lN@<0K6E/201:AD`404Dn>0`0AC/f0`10
=c4403/^90@0>c8X1020O7UP0820OQH0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002K0?ooo`900000P`3oool009d0
oooo00=000000?ooo`3oool0P03oool007P0oooo0d0000030?ooo`03@000003oool0oooo0080oooo
00=000000?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo
0?ooo`1j0?ooo`00N03oool00d000000oooo0?ooo`030?ooo`07@000003oool0oooo0?oood000000
oooo@000000;0?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00
00220?ooo`00N@3oool00d000000oooo0?ooo`020?ooo`07@000003oool0oooo0?oood000000oooo
@000000;0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@000
0880oooo001i0?ooo`03@000003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oood00000<
0?ooo`=0000000@0oooo@0000400001000000`3oool3@0000880oooo001h0?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool00d000000oooo@000000>0?ooo`03@000003oool0
oooo08X0oooo001i0?ooo`04@000003oool0oooo0?ooo`=000000`3oool00d000000oooo0?ooo`0<
0?ooo`900000S03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(315) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282789282789282788D6C58
92705C92706092756492706092756492756492756492756492706092705C8D6C588D6854895F4C\
895F4C835B48835B48835B48835B48835B488357447F57407F57447F57407F5744
928278928278928278928278928278927E75928278928278928278928278928278928278928278\
928278928278928278
92827892817792857B92827892817792857B928278928278928278928278928278928278928278\
92827892827892817792857B9282789282789282789282789282789282788F6E5A
8F6E5B92705C92756792706092756492756492736191746494746494705D8F6D588C69548D624E\
8A5F4C845B47865D4A835B48835B488359468359467F57427F57427F57407F5D4E
927566928278928278928278928278927F75927F75928278928278928278928278928278928278\
928278928278928278
928278927F75927E7592857B927F75927F7592827892817792857B92817792857B928278928278\
928278928278927F75927F75928278928278928278928278928278928278916F5A
95736192706092736092756492706092766591715D8A6D5A956B548F6654896650876450835D4A\
835A488156447F5744845B47845B478459468457428157467F57447F5742856E60
856E6392827892827892827892827892827892817792857B928278928278928278928278928278\
928278928278928278
928278928278927E75928278928278928278928278927F75927F75927F75927F75928278928278\
9282789282789282789282789282789282789282789282789282789282788F6C58
8F705E92705E92706092736392736392705F8F6E5E8268567E614F89594D7F5844825B48825F4E\
825F4C8058467F5B467F57447F57447F57447F57428159447C54427F5744928278
928278928278928278928278928278928278927F75927F75928278928278928278928278928278\
928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278928278928278928278928278928278926E5A
926E5C92706192706392706092706092705E92725F926F5F8F6B598D64538D5C50875C48875A4A\
86564A87594A7A4C3F7E56447E5D4A7C523F8157448159467F5946815A488F7B72
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92827892827892827892827892827892827892827892827892827892827892705C
92705C92705E92705C9270639270609272629270609276659275648F6B598C65538A5D4E8D6050\
8A5E4C895D4C88584A805143835648815F507F523F8457448157448765558C7566
92827892827892827892827892827892827892827892817792857B928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282789282788C72659C8774
92705E92705C92705F927060927262927060927564926F5F92726292706092705E8F6A538C6352\
8A60508A614E86594A855B48805744815B49815B498157447C57448D7368927B6F
928278928278928278928278928278928278928278927F75927F7592827892827892817792847A\
92857B928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282786B5546B0907C8C6857
92706092705E92705B92705E92756492706092736192776A92736392736392705F926E5C916452\
9166508D6150895F4A875747875B488154427C5744835A488154438C786F8F7B72
928278928278928278928278928278928278928278928278928278928278928278927F75927B72\
927F75928278928278
92827892827892817792857B928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282788A787141221AA3846D8F6E57
927262926E5E927262926E5E927363927564926F5D92705E927361926B5F91725B927059946D5B\
8D63528C6150895B48895B46805946815742815746815B47845D4995857B928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278927F75927E7592857B928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789483794B2F2380645D573B36927060
927360927363927363927363927060927363927767927060916F5A946658916352895F4C8C614E\
8F64508C644E835D4C875946875B478159447E57427C57448159468D796F958F88
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928177928278927F75928278928278928278928278928278928278928278928278\
92827892827892827892827892827892827853362795807455382C8F6E57927060
92706092706092705F9270639270609272629270609273638D5B4D8D65548C5A4A8C5C4A895A48\
896B51875D47875D478356438159438657468357447F57428356458768569C9591
92827892827892827892827892827892827892827892827892827892827892827892817792857B\
928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282788A786F654E435B403492736392705C927060
927060926F5D92715F92715F927366927363926D5F9272628D54488C493C893F348C4A42874237\
8C5043815844845A4584574281524083594483574481574281523F815946896D5C
9C9F9E928278928278928278928278928278928278928278928278928278928278927F75927F75\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278473028BD9A8692736692706192705F927060
92705F916B59946B5695735E926E5E926D5B915B52925A4B8F5E52853B2C8F5144893B34813127\
873D30874A3D7C51407F5B447F5239815745865746835744835442835644835D4A
927F75928882928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892817792857B928278928278928278928278928278928278928278\
9282789282789282789282787E6962685243644F448F6E5B916D56957764926E5B
926D588C69518C5E4C9975638F5C4B6A2513B67F6B8C443A8753467842357333257F5E487F4534\
823A33753022923E317D5B4781563B815440815B46855844805242835946835744
8C6D5A9C958E928882928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892817792857B927F75927F75928278928278928278928278928278928278928278\
9282789282789282789282784730299D7763825F4F92705C8D6655927665927363
92685487553E8454416C2018A982746B1B135E1E138644368945348F67568A51447F392F6B3521\
653D2D5B2D20592716974532815F4583503D855D4A855D48855A44805444835946
835B488C766D9A867395887E928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278927F75927F75928278928278928278928278928278928278928278928278928278\
9282789282789282788C7C76361E1694745F92705F92705F8F68558F6859927060
8F5F4B8253377F372655180D85594D8A7F6D947A6D958F8592796D927C728C695A9482718F6B59\
82706857382F452921451D1395493287604A8C5F4A8A6352865A46835944835240
835B47817068877574988A889C8F7E928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
9282789282786B55465131297D5D54614C408F6E5A926D5892725D927663927061
8957467D533E6E3829510D0C5E221D8755448C5F4E926D5E976B5D8F71598F56448D53428A5B49\
92796287564474534751382C4812089B5E4A89644A8D6854895F4A835947815644
8656448162507F7169735D5B95887F928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892817792857B928278928278928278928278928278928278\
9282788C7A7326170F321B14855D4F7F5A49926F5A926858916D54956E5A926B5A
895F4882513B997C6A8F6F5A9265568F5D5189574A865245894C4284453E80453B7F362E7F3630\
7D4A3B824C3F7642346937274E1E1564281B986E56916B5489624A8357447F5442
835B47835F4C5C3B2CB9ADAE84706D95887E928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278927F75927F75928278928278928278928278928278928278\
928278836E6B4430280000064E3E38957361926C5892685A8F61568F765C92685A
8955487E4C3A8A685495796A927564926E5E9273639275649268588D6B528D6350895F4A895B46\
815440874A3E84433876352C62292159231D73422E8F64548C614A8357447F5440
835444835B48473027876D619C8C858F7B72928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92827888706888706A8F69558A614D916F5A95705C926E5B92685992695A926E59
8A634D825141865845977D6895776A927262926E5E92756492685A8D5C4E8C5D498C664F845945\
80564382523B7F513E7F553E7F4F3E7D4F3E815444865A44895D48815642815642
81594284594737221B927B718C7866928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
917F76957661916D5B92705B8D786D996F538F705E92725F926F5F927262927262
8F645487614A82503F8A6652927968927767926B5D917A649576638C614E8C5B4884513C846149\
774D3977513B7A4C3A7C4E36774A387A4935855D4A855D4A875B478254427F5240
7F57428159441F12108D746D9C8F8E928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
8F76688F766A8C644E89624C876C5D88665D927660927564927564927564927564
92685A8F5D508658448C594895796892756492685B8F65568F6E598A614D865A46814E3D7E503F\
7749387A4B387A4F3C7F523D7E50397A4F3B7F53408757448759468154427C503F
7F574281594726151049332BBDADA192857B928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92705C916F5D85543F916F5D885E4F8F6E5A92685E92756492766792715F927564
92705E926B55895A46895A44916A5B957668927361927265926E5E8D6554875847875B47815744\
7F4E3D794A357748397F5442855646875946865A48835A48835443815442815442
7F5441815A464930242B1B164D3A32CDC3B9928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278927C6F\
8F6C598D564484654C8465519C6B5A92685A927060927564927869927869927564
927060916F5A8D6552875E4A8C65508F6E5C916B5B957C66926D628C6B518658478156437F5440\
81563E774A38824F398156448658488D6150895F4C835D4A835B478159467C5742
81544381624E794E3A5D392A371D18583D34928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278926B5D\
8958457F42347F5241846756886E5E92725C926E5B927564927564927564927363
9273618D6C5B8F68548A6C5892705E92725C8F65548F6856926554895C4C81523F7F4F3D7A4D3B\
7D4F397A4E39784D3D7F5342855E4C8D614E895F4C835B48835744835444815642
7F543F865F4E7D4D378156459483798F7F75928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278927E71926F63\
894E427D42338354468C6B578F6E5E927564927262927060927665917461957666
926B5D8D7258916854916D58927363927361927366927060926656895D467F56437A4E3C774C3A\
734C3B7C4E3B815646895F4C8A635089614E8C5F4C835D4A835442835443815243
815442835C507E4E3B79503D8D776FA2988E928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789282788F6B558D614E\
794D37884F3A8F644E8F6B57927060927363927665927361926F5F8D6F5D916B58
926B589466588D6A548D6452926E5C92706092705E9270609167588C54467F503F7A4E3C7A4E3C\
795240795742855B48855F4A8C614E8C6350895A4883594683564481503F81503F
7F544283624E7F442E8666547C5344929998928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827892827892827892827887553E562E1A\
6B3C2D532E24A1725992705E92705E92705F927061927060926E598F6B568C6554
875C4C895F4E8C685394755F91715D95736392706092705F8D6859875D477F4F427D5139784B3B\
8154428159468457468A5F4D8C5F4E875F498A644F845B47845B478159467F5240
7F5244815B497A4731824F3C845142928275928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278927F75855848552F1F\
3C231948282289635092705F916F5F9573639270598C69569572608D6552946D58
926757905A4D8C614B89614D92725D95766592706092705E8D63528357447A4C3B7A4938754E3C\
7D4E3C7F58458458458A5B47895F4E845444865B488159467C54427F57447F5240
7F52447F57446A3A277539238A553C958581928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789172618C6458331009\
381D153B221B976B578D6C58926F5A8F705F92705F876350775442744E3A5C3E32
56352A723C288C54417F402B844831A78C759576689270608D65548354447A4E38784E36754535\
7F56447851417251417852417F58477D5A45895D4A835B487F57447A54427F5442
8454447F5444643727622D1E773E2C92897C928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789483798C65528456453C231D\
22120D341A148A6C588F6B578D6A5695705C92705C8F6B5978523F6B4D3F3E2B20
311B164222165A3C2F7A3C2A6F3C2F7B5142926F5F9270618D644F835442754935784E34571D0F\
8F634B82563B7E55437749348F5D4A7A5444815943845B49815946754F3D755442
7F54447A543F6134276D38277C403390796C8F7F75928278928278928278928278928278928278\
928278928278928278
92847A92857B92817792857B928278928278928278928278928278471D14CF9A7C8B614E4B2920\
24171929150F976F5A916F5A92705C8D6C5894715D95736387614F85584865473B
3526232D1D18412E265D4136794B3D8A68549277679278698D6D5B8359467448346B4333582D1F\
5D392F5E3C2C1F0C0A723D2B6143325430208356417E4F338D5A4378564575503E
7F52426D49384E2A1E5E30238F5744947C76928278928278928278928278928278928278928278\
928278928278928278
927E75928278927F75927F759282789282789282789282784C292045281F3E0B05844B36391F20\
2919122F1915876A568D6C5892705E895E4B8F7259997C6A8F6F5D89604C7E5240
78503D754F3D6C433176513B845A488A63509275649275648D6654835D487A4834724A356C3D2F\
63453B4E3930150E0E3D1E144D312839251C5E3929694333744B36754A39735442
7F54404E2C2446291B4A25198548359C998E95857B928278928278928278928278928278928278\
928278928278928278
927B72927F75928278928278928278928278928278928278351914382117301511351D161D0E0D\
301A153019138A6B568F6F5A8D6F5D8C5F547A4C3C81554197735C8C6B55815748
7844347C4B34844F38864F379E775E946C589270609276638D6657835F4E7A4E3A774D34755238\
815240795040412D282119183B251E3F2D254E382E65422F724E3F81543E765040
75523F3F2419351B15472418753322998C81928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278391D1429120C2718112C1711261510\
2115103D251E865D4A99725D8F6E5A8F6E5E886554714938683D316448396D4838
50352953362B5935286941327451418865548F6E5B926B5A8D6D54835C4A7A4B3E693723734029\
8865438459457F57437B5242684534603B2F734736784E3B7F523F75543F845942
6D4A39271812271711633B2E542419998278928278928278928278928278928278928278928278\
928278928278928278
92827892827892817792857B92827892827892827892827841251A29100B251510211510150908\
2917113927207D58459A725D95735E9270609272628F6C5A825748684039684039
7240336B3D2E683A2B714132845C4B927262916C5B94695D91635485614E7C524662362D4C241C\
55301F5A3522965C418D624B8157407954407552407D523D724F3E84564879543F
4E2E202C19122C20196639296A301F584238CAC3B9928278928278928278928278928278928278\
928278928278928278
928278928278927F75927F759282789282789282789282783D271F311B1526140E2615101B100B\
25140F3A2720754F3D8D6B5792705C927060927564927564927667927361927361
92715F92766792715F92725F8F6B558F705F8F705F8A68548D68548A6854876250815949603E33\
43272135241C45271B5732217D48356F4F397B4A33734733845847734E3D7D4F3F
361C152A17102C1B183D160E6322144A332A8F7F75928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278412A233B26201F130E28151025150F\
28181639261E6D493792695499766192705F927366927767927869927D7292796C
92766792766792756492756492725F926E5792705C8D68548D65528D63508D6B568D6354856150\
7D55486843384831293B261F452A205236295D40325A3D2F6F42387D5642774B39
331A1427151023161021110C3A19134B2F27928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827844271D3D251B2F1E1824140F2B110C\
2E1A15392319573A2D8F644D94745F95735E927060927564927667927564927D72
92796C92796C927564927564927361927363926F588D68548D6B568D65528D63508D6654896150\
855F4C7D5B487652416F4F3F6041325D3C2F684133744E3F764E3F754C3D5D3C29
351D162715102D19131E140F2815103F261B8A7670A69F94928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282783D2318402A222F1C162E19131D100B\
2B16102C17114D2C1F734A32A07A6692735E92706092756492796C927667927564
927D7292786992786992756492705C92705F916B599168548D63508D69548D66528D6350895F4C\
875B48875B48815A487F54428359467C57447A52407F52427F524274493742281E
24140C2E1A181F110F20120C150908371D156F51479F928B928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827841261B39272039251F2E1B162C1712\
23140F2E1C163E282057352695664E997761927363927363927B6C927D72927667
92766792756492756492756492705E916F58916B568D66528D66528D63508C63508F614E8C614E\
835B48835B48835D4A815B487F5442815744755240795240704F3D5A3A2C361D16
2D1D17180C0B1F12111408081D110F27150F5F443B99857B928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278402A223F29213C292236241D2E1813\
1E110C321B1542281E54382A774F3B977561957361927063927363927B6C927D72
92796C92766792715F9275649270608F6E5A8A65528C63508F614E91645389644E895F4C895F4E\
835D48835B48835946815B478159467D523F7C5644754D3B6B4536502D20331B15
1F120C1F1210180C0B1C100B1B100F2E1913654E446B5147928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789281779182793D29223D2821402C253A2720281610\
2E1C162C1B1539221B6239287849368F665095735E92706092726292726292796C
92796C92796C927564927564916F5D95715F8D68548A665287614E895D4C8C5F4E895B48875D4C\
875948815646845B468157447F57447C503E78503E754735643E2E3B2319321A14
21150F20140F1F130F1B100B2115102F19149483798F7F75928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278927F758F786F35211B43271D3927223F2B2434221C\
2C1B1534211B382117543B2F6E3F2D92644F947761957363927363927767927869
927B6E927B6E92766891746191705D916F5A9163508C614C8F64528C614C895F4E895D4A835B48\
835D4A8154447C54447F54427F56437A5442754D3B6A4230502D24391E16251710
1F120C1E1210190D0C0F09081B0D0C41261E887B7295857B928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282783F2922392117402B243E2A2336231C\
311B1539231939261F4C352858312487564097745F92705F927061927366927663
9276669276669273668F6E5A8A65528D68548C644F8C614C895F4C89614A895F4A895B47835F4C\
8359468359467F57447F52407D4F3D724F3C6A4431502E2545281B2A1611231610
25150F1B100F180C0B170C0B2917124D322C5B3A31928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282784D362F36221B3C271F442C25382218\
33211B311D163D28203A261E492F2671412E92684F9A7C6894715D95736192705F
92705C916F5A94715F9573618D66528C624E8C614C8757468A5D4C8A5D4C8C5F4C875946875946\
8356468159448157427D4F3F7A4F3D6B473557302342271B2C171121130C1F1210
2816101D1110140808180C0C30191495857B95857B928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278533C313E2A243C29223C27203D271F\
2D1A17321F1836231C3E2A233922184E2D207F553D956A5295725C94755F94725D
94745F916F5A8D6B5691705B8F68548959468A5D47875B46835643835D49875B47875946815442\
8454437F52407D5641774F3B71443169422F42271B2E18112517101D110B180D0C
1A0D0C1009080F08082C1713311B138C7F78928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278644D433621193E2B243A2720412D26\
341F162D19143C2A2335221B412B23331E16593C2C6A43329159419B725A8D6650
92705D8F6E588F6B54926B57875F4B7C513D86533F8A563F87584784544284513E845A4781543C\
7D4F417A4D3B754A386B4A385A342650291B381E162916101D110C190D0C180D0B
1408080E0808170C0B2715105E3C315B3D31928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278826B66422A2335211C3D28223D2821\
35241C2E19163D24193A2721412D263926203A271F4B342A60392A774732775244
74523F86553F87614C855E48774E3E714530673D2A77472F80483581533B854F3B7A4A39794832\
7E4A34774A376942346138284E291C3C1D162B17101F120C190D0C1408080F0808
0F08080E080720140F2C171389786F8F7B72928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282785B463D3220173C2922392922\
38251E21151039231C432D25412D26453129412D264531274C3429513427503027
4E2F2252302663382767433253342A5332275A302158311E5F332571422D71422D6D3E2A6B3F2D\
603423653C2D5C32254D2C20381C15361E171F110B1E110C180C0B1308070E0807
0E080722130F1A100F4F372E6E5E56928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278735D5936211B3927203C2821\
3A272134231D35241E412D2647322A402C25452F274A2C24523225452C203E2A23
372019422921391C15492D24432A223B251E3A1D163D231A3D1E164621184E2D1D4B2A1C4B2A1C\
4420174321183D20183B1E1627171121130C1B0D0C190D0B180D0B0E08070E0807
22131522130E32221D61474175574D928278928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282788C7872533A35301D173A2720\
3E2A2339261F45312936231C4A342C39251E422D264A302640272141271E3D271F
34211B3F29222B191633231C351C16331D162917112517112B1711331A14331B142C18112E1811\
2D1711341A142916102A16101E120C1D110C180C0B180C0B0E08080E0808170C0B
2C1B172C1713513A31583D34928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278755F5839221B3B2A23\
3E2A233A272036261E473029422E2738272136221B4A2B1F36221B3A261E38241D
2A1B1C38261D2F1B19301B152817182516102416101E110C23161024161026161020120C1B0D0C\
20120C2A16111F120C1B0D0C1F120C1D110F180C0B0E0808180C0B1D130E261814
2B171351372E51332B928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92827892827892827892827892827892827892827892827892827892827888726C4A2F2936221C\
402C253A27203B2922392A23452E2639261E3220193620192C171137241D2D1B18
2C1B192817112917192012101C0D0C1F12111E1210190D0B1E1210190D0C1E1210190D0B1D110F\
20140F1D110F190D0B0F08080F09081009080F09081C100F1A100B180C0C2A130C
583F37543A31928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789282786B5147341E18\
301F193D28223C2B243C2B24422E273825212F1913301E182215102A1711251712
2916111A0D0C1B0D0C1F12111C100F180C0B1D1110180C0B1D1110180C0B2C18130D08071E1110\
2115101D11100E08080E08081308071A100F190F0E1B100F2C18132C1C1438251F
685B5A8F7B72928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
9282789282789282789282789282789282789282789282789282789282789282789282786B5147\
321C1631231D36231C433029412E27412D272E1F193420192515161D110F281610
1D111021150F1E130F1B100F180D0C180D0C180D0C180D0C180D0C2115101E1110302425261C17\
211213180D0B1B100F1C120E1C120E1B100F2F1F192618152C1713492C21624434
724E3D928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
6B4D43321C1636272035221B412F274A342C3C2A243420162D1C181F14101D1110
190D0C1E120C1E1210190D0C180D0C1C100F170C0B1C100F170C0B190D0C3127232C1B2144352E\
372825281A1A2D201B271A151E130E2C1B162D1C173C29223E231B54382F68473A
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
95857B6E5147371D163D2D2738262047342C47322A422D252D1B142D1C162E201B
241A1621120E1F140F1B100F1B100F180C0B180D0C2115161B100E1F130F1F13123627213E2824\
2416142C1C152A1B142415132A17112F1E173821174C3227523B366F4E3E927F75
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
92827892827868473A371E1635221C452F27523C344B39303D29232B1A142E1B19
331D1635251E291C161B100E180D0C2518192115162A1D1822161934231C1C12133F2D2534231F\
32221C2C1E192A1C162D1F1A33241D2F1E194C302454382D643D3188726C928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278684E412F14072D1C15422D264E39304D3F3C462F25372521
372521311E1B3429243829262C1E182518182D212534231E3A2D2C35231C34231E3E2C27422B25\
3E26203E271C392923432D244E352839251C6B4E41724A3A927F75928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278856E6954342E2F1B15402D244035355C4740523C35
513D3349373140302E4433304D3B37412E283F2D2A3524243A2721412C27422E273E2A234C2C21\
492D24472D244A312844291F62453B5E37215E3D31928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
92847A92857B928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278928278684E4A37130F2D140E3A2B2A644E44
5B4A434E3B2E523E36534039563F36523B3549352C42302B412D2839282146322C49342C442D24\
513127482A2272514451261344130972544D928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
927B72927F75928278928278928278928278928278928278928278928278928278928278928278\
9282789282789282789282789282789282789282789282788C787262474A4B292B
6240416446455E3B2C4C2E224A352B5C443C5E41355B42395B42395A4136533C33573A2E573F32\
6B5145340F034E2622826863928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278928278928278928278928278928278928278928278928278
9282788C78758C7572856B6961444A4A2D34472625442217442318442015411C123A1306371000\
65473A927F75928278928278928278928278928278928278928278928278928278
928278928278928278928278928278928278928278928278928278928278928278928278928278\
928278928278928278
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooomH09:2N0@0SFaH102B
L5`4099`H0@0TWET102BL60?099eI0@0TW1P102BL5`408e/F0<0SFQD2029Gd`C08=KB0@0PeM4101o
Ed0407mGA0@0OeM0101oEd@C09:2N0@0TWie9P2BPWPF0?ooo`00503ooomH09:2N0@0SFaH102BL5`4
099`H0@0TWET102BL60?099eI0@0TW1P102BL5`408e/F0<0SFQD2029Gd`C08=KB0@0PeM4101oEd04
07mGA0@0OeM0101oEd@C09:2N0@0TWie9P2BPWPF0?ooo`00503ooomH09:2N0@0SFaH102BL5`4099`
H0@0TWET102BL60?099eI0@0TW1P102BL5`408e/F0<0SFQD2029Gd`C08=KB0@0PeM4101oEd0407mG
A0@0OeM0101oEd@C09:2N0@0TWie9P2BPWPF0?ooo`00503ooomH09:2N0@0SFaH102BL5`4099`H0@0
TWET102BL60?099eI0@0TW1P102BL5`408e/F0<0SFQD2029Gd`C08=KB0@0PeM4101oEd0407mGA0@0
OeM0101oEd@C09:2N0@0TWie9P2BPWPF0?ooo`00503oool409:2N0@0TX5g102BQG/309:2N0@0TX5g
102BQG/S09:2N0@0TX5g0`2BQG/G09:2N0@0SfiJ102?KU/4099`G0@0TWEW102BL607099eI0@0TW=Q
102AM6@409AdI0@0U71M102?KEP308aYE0@0SF9>102:Gd`408AKA`@0QUe:1`23FdP808=IAPP0OeM2
101oEd0407mMCP<0TWEV402BPWP7099oMB<0TX9h5P3oool001@0oooo102BPWP409:1M`@0TXEk0`2B
PWP409:1M`@0TXEk8`2BPWP409:1M`<0TXEk5`2BPWP408m^FP@0SfiK102BL5`4099eI`@0TW1P1`2B
MF@4099cH@@0TGAT102DM6@409A`G@@0SfeH0`2<JE@408eRCP@0RUm<1024FdL408IMBPL0Pe]82023
FDH807mG@P@0OeM0101oGDh3099eIQ00TX9h1`2BOgDS09:2N1H0oooo000D0?ooo`@0TX9h102BPGL4
09:5N`<0TX9h102BPGL409:5Nb<0TX9h102BPGL309:5NaL0TX9h102?KUX408m^F`@0TW1L102BMFL4
099`H0L0TWET102BLf44095dI0@0U7AT102DL5d408m]F0<0S6UD102=HTh408YOC0@0Q5]71026GDX7
08=KB0P0PeU6201oEd8407mG@0@0Oee>0`2BMFH@09:2N0L0TWme8`2BPWPF0?ooo`00503oool409:2
N0@0TX5g102BQG/309:2N0@0TX5g102BQG/S09:2N0@0TX5g0`2BQG/G09:2N0@0SfiJ102?KU/4099`
G0@0TWEW102BL607099eI0@0TW=Q102AM6@409AdI0@0U71M102?KEP308aYE0@0SF9>102:Gd`408AK
A`@0QUe:1`23FdP808=IAPP0OeM2101oEd0407mMCP<0TWEV402BPWP7099oMB<0TX9h5P3oool001@0
oooo102BPWP4099oM@@0TWie0`2BQG/8099oM@@0TX9h102BPGL409:5N`<0TX5g102BQG/@09:2N0L0
TWme5`2BPWP4095_FP@0UG=Q102BL604099cH0@0TWET0`2BL604099fI@@0TG5M102:KEX409E[E0@0
SfID1029IU0308MTD0@0Pee:1023FTP4085FA0@0OeM41`24FdL408AIAP@0Q5M21021EdH407mGA0@0
OeM21025KV0308E^Ha@0TX9h0`2BPGL409:5Nal0TX9h5P3oool001@0oooo102BPWP4099oM@@0TWie
0`2BQG/8099oM@@0TX9h102BPGL409:5N`<0TX5g102BQG/@09:2N0L0TWme5`2BPWP4095_FP@0UG=Q
102BL604099cH0@0TWET0`2BL604099fI@@0TG5M102:KEX409E[E0@0SfID1029IU0308MTD0@0Pee:
1023FTP4085FA0@0OeM41`24FdL408AIAP@0Q5M21021EdH407mGA0@0OeM21025KV0308E^Ha@0TX9h
0`2BPGL409:5Nal0TX9h5P3oool001@0oooo102BPWP4099oM@@0TWie0`2BQG/8099oM@@0TX9h102B
PGL409:5N`<0TX5g102BQG/@09:2N0L0TWme5`2BPWP4095_FP@0UG=Q102BL604099cH0@0TWET0`2B
L604099fI@@0TG5M102:KEX409E[E0@0SfID1029IU0308MTD0@0Pee:1023FTP4085FA0@0OeM41`24
FdL408AIAP@0Q5M21021EdH407mGA0@0OeM21025KV0308E^Ha@0TX9h0`2BPGL409:5Nal0TX9h5P3o
ool001@0oooo102BPWP4099oM@@0TWie0`2BQG/8099oM@@0TX9h102BPGL409:5N`<0TX5g102BQG/@
09:2N0L0TWme5`2BPWP4095_FP@0UG=Q102BL604099cH0@0TWET0`2BL604099fI@@0TG5M102:KEX4
09E[E0@0SfID1029IU0308MTD0@0Pee:1023FTP4085FA0@0OeM41`24FdL408AIAP@0Q5M21021EdH4
07mGA0@0OeM21025KV0308E^Ha@0TX9h0`2BPGL409:5Nal0TX9h5P3oool001@0oooo202BPWP4099n
M@l0TX9h3`2BOgD^09:2N0@0SfaH102?L5h4099`GP@0TW1P1`2BLf<4099`G`@0SfiN1022J5H407iQ
C`@0REU=101oF4@3089KB0@0PUm>1022Gd`4081HAP@0Oe]62`1oEd@407mG@P@0PEU4101lE48407mG
A1/0TX9h1`2BOgDO09:2N1H0oooo000D0?ooo`P0TX9h102BOWD?09:2N0l0TWme;P2BPWP408m/F0@0
Sg1N102BL5h4099`H0L0TW=S102BL5l408m^GP@0PVQF101nHDl408UIC@@0OeQ40`22FdP4089OCP@0
PUm<1020F4H407mKAP/0OeM4101oEd84085IA0@0O5A2101oEd@K09:2N0L0TWme7`2BPWPF0?ooo`00
503oool809:2N0@0TWie3`2BPWP?099oMBh0TX9h102?K5P408m`GP@0TW1N102BL607099cH`@0TW1O
102?KUh4089XEP@0OV5?1029FDd407mHA0<0PU]81022Gdh4089OC0@0P5Q6101oFdH;07mGA0@0OeM2
1021FD@407aD@P@0OeM46`2BPWP7099oMAl0TX9h5P3oool001@0oooo202BPWP7099oMDT0TX9h102B
KUX4099^G0@0TW1Q102BL6<7099`H0@0TW1N102BLUl4099_G`@0Sf]I102=I5<408eLD0<0Qea81027
FTX408IFBP@0QeU:101jC3l407iFA0<0OUe:101lDSl4085GA0@0PEU6101oFDH4085JB0@0Sg]b?@2B
PWPF0?ooo`00503oool809:2N0L0TWmeB@2BPWP4099^FP@0TViL102BL644099`H`L0TW1P102BL5h4
099bG`@0TVmO102?JeT408eTD`@0SEa@0`27G4P408MJBP@0QUI:1027FDX407Y<?`@0OUI40`1nGDX4
07aB?`@0PEM41021FDH407mIAP@0PEY8102?Ng8m09:2N1H0oooo000D0?ooo`P0TX9h1`2BOgE909:2
N0@0TViJ102BKU`4099`H@@0TW1S1`2BL604099`GP@0TW9O102BKel408m[F@@0SFAC102=G50308ML
B0@0QeY:1026ETX408MIBP@0NT`o101nET@307iMBP@0O58o1021Ed@4085IAP@0OeU61021FTP408mk
LSd0TX9h5P3oool001@0oooo202BPWP7099oMDT0TX9h102BKUX4099^G0@0TW1Q102BL6<7099`H0@0
TW1N102BLUl4099_G`@0Sf]I102=I5<408eLD0<0Qea81027FTX408IFBP@0QeU:101jC3l407iFA0<0
OUe:101lDSl4085GA0@0PEU6101oFDH4085JB0@0Sg]b?@2BPWPF0?ooo`00503ooomH09:2N0P0TW1L
102BL5h4099`G0@0TW1S0`2BL604099bHP@0TW1P102BMVD4099eI0@0Sf]I102<IE<308YMCP@0SF1@
102:GT`408UMC0@0R5Q:1020DD<308=FB0@0PEm@101oDSl408AGA0@0PEM41027IED408aeIQX0TX9h
102BPGL409:5Na/0TX9h5P3oool001@0ooooF02BPWP8099`G0@0TW1N102BL5`4099`H`<0TW1P102B
LV84099`H0@0TWIU102BMF@408m[F@@0S6EC0`2:GDh408ePD0@0RUi<1029GD`408QHBP@0P5530`23
ETP4085OD0@0Oe8o1024Ed@4085GA0@0QfEE102<MFHJ09:2N0@0TX5g102BQG/K09:2N1H0oooo000D
0?oooeP0TX9h202BL5`4099`GP@0TW1L102BL6<3099`H0@0TW9R102BL604099fI@@0TWET102?JeT4
08aUD`<0RUe>102=H50408YNC0@0REe<1028F4X4081A@`<0PeI81021Ge0407mB?`@0Q5M41021Ed@4
08MUE@@0S7EV6P2BPWP409:1M`@0TXEk6`2BPWPF0?ooo`00503ooomH09:2N0P0TW1L102BL5h4099`
G0@0TW1S0`2BL604099bHP@0TW1P102BMVD4099eI0@0Sf]I102<IE<308YMCP@0SF1@102:GT`408UM
C0@0R5Q:1020DD<308=FB0@0PEm@101oDSl408AGA0@0PEM41027IED408aeIQX0TX9h102BPGL409:5
Na/0TX9h5P3oool001@0ooooE@2BPWP308abI@@0W8Md102BL5h4099`G0@0TW1O102BL603099bHP@0
TW1P102BMF@4099_G`@0TW9R102BL604099`GP<0SfYC102<He8408YPD0@0RV5>1026FDX408EKB0<0
P5M42021FdT4085GA0@0O5M4102=LfP4099kKaX0TX9h202BOgD809:2N0@0TX5g0`2BQ7X409:5N`P0
TX9h5P3oool001@0ooooE@2BPWP308abI@@0W8Md102BL5h4099`G0@0TW1O102BL603099bHP@0TW1P
102BMF@4099_G`@0TW9R102BL604099`GP<0SfYC102<He8408YPD0@0RV5>1026FDX408EKB0<0P5M4
2021FdT4085GA0@0O5M4102=LfP4099kKaX0TX9h202BOgD809:2N0@0TX5g0`2BQ7X409:5N`P0TX9h
5P3oool001@0ooooE@2BPWP308abI@@0W8Md102BL5h4099`G0@0TW1O102BL603099bHP@0TW1P102B
MF@4099_G`@0TW9R102BL604099`GP<0SfYC102<He8408YPD0@0RV5>1026FDX408EKB0<0P5M42021
FdT4085GA0@0O5M4102=LfP4099kKaX0TX9h202BOgD809:2N0@0TX5g0`2BQ7X409:5N`P0TX9h5P3o
ool001@0ooooE@2BPWP308abI@@0W8Md102BL5h4099`G0@0TW1O102BL603099bHP@0TW1P102BMF@4
099_G`@0TW9R102BL604099`GP<0SfYC102<He8408YPD0@0RV5>1026FDX408EKB0<0P5M42021FdT4
085GA0@0O5M4102=LfP4099kKaX0TX9h202BOgD809:2N0@0TX5g0`2BQ7X409:5N`P0TX9h5P3oool0
01@0ooooD@2BPWP406]EAP<0/91l102<J5L4099`H0@0TW1N102BL5/4099`GP<0TWET102BL604099c
H@@0TWMZ202BLf<4099`G`<0TViL102AI584095VD0@0SF5@1029GdX408MGA`<0Qe]81021E48407aG
A0@0PeY81021E4<408ahK`@0Sg]b:P2BPWP4099oM@<0TW]b102BOgD809:2N1H0oooo000D0?oooe40
TX9h101[EDH30;2@O0@0S6QG102BL604099`GP@0TW1K102BL5h3099eI0@0TW1P102BLf44099gJPP0
TW=S102BL5l3099^G0@0TFAB102AIU0408eQD0@0REm:1027EdL308MKB0@0PEA2101lEd@408=JB0@0
PEA3102<N6l408mkLRX0TX9h102BOgD3099kLP@0TWme202BPWPF0?ooo`00503ooomA09:2N0@0JeE6
0`2`T7`408aXE`@0TW1P102BL5h4099`F`@0TW1N0`2BMF@4099`H0@0TW=Q102BMfX8099cH`@0TW1O
0`2BKU`4095TDP@0TFI@102=HE0408UOBP@0QeM70`27FdP4085D@P@0O5M41023FTP4085D@`@0S7Q_
102?Ng8Z09:2N0@0TWme0`2BNg84099oM@P0TX9h5P3oool001@0ooooD@2BPWP406]EAP<0/91l102<
J5L4099`H0@0TW1N102BL5/4099`GP<0TWET102BL604099cH@@0TWMZ202BLf<4099`G`<0TViL102A
I584095VD0@0SF5@1029GdX408MGA`<0Qe]81021E48407aGA0@0PeY81021E4<408ahK`@0Sg]b:P2B
PWP4099oM@<0TW]b102BOgD809:2N1H0oooo000D0?ooo`P0TX9h102BPGL309:5Nch0TX9h102:N744
044R6P<0XhA]102?KUL4099bHP@0TViN102BLV84099^GP<0TW=S102BMF@4099_G@@0TW1N102BLf44
099[G`@0TG9K0`2BL5T409A]F`@0SF=B102<HE0408UKB0@0RE]60`20FDH4085G@P@0PEM61021FdL4
08AMB@@0UHEk@@2BPWPF0?ooo`00503oool809:2N0@0TX5g0`2BQG/n09:2N0@0RWQa10118QX30:>4
K@@0SfiG102BLV84099^GP@0TW9R102BKUh3099cH`@0TWET102BKed4099`GP@0TW=Q102BJel4095b
F`<0TW1I102DKE/408eSDP@0S65@1029FdP408UKAP<0P5U61021Ed84085GAP@0PE]71024GDT409F5
Nd40TX9h5P3oool001@0oooo202BPWP409:1M`<0TXEk?P2BPWP408YhL@@0@B8J0`2SQ6d408m^E`@0
TW9R102BKUh4099bHP@0TViN0`2BLf<4099eI0@0TVmM102BL5h4099cH@@0TV]O102ALU/3099`F@@0
U6eK102=He8408aQD0@0RE]81029FdH3081IAP@0PEM21021EdH4085KA`@0Q5e9102EQG]109:2N1H0
oooo000D0?ooo`P0TX9h102BPGL309:5Nch0TX9h102:N744044R6P<0XhA]102?KUL4099bHP@0TViN
102BLV84099^GP<0TW=S102BMF@4099_G@@0TW1N102BLf44099[G`@0TG9K0`2BL5T409A]F`@0SF=B
102<HE0408UKB0@0RE]60`20FDH4085G@P@0PEM61021FdL408AMB@@0UHEk@@2BPWPF0?ooo`00503o
ool809:2N0@0TWme0`2BOWD409:5NcH0TX9h102DPgT404/_8`@0P6AM0`1G>cH4099`H0@0TW=P302B
Lf<3099`H0@0TW=S102BMfL4099`H0@0TFmJ102DIUP4095SDP<0REm<102<HDh408mTD0@0S6A>1023
GD`408MIAP<0Qe]71021FD@407iG@P@0O5M41021FDH408eiK`@0UHn8?@2BPWPF0?ooo`00503oool8
09:2N0@0TWme0`2BOWD409:5NcH0TX9h102DPgT404/_8`@0P6AM0`1G>cH4099`H0@0TW=P302BLf<3
099`H0@0TW=S102BMfL4099`H0@0TFmJ102DIUP4095SDP<0REm<102<HDh408mTD0@0S6A>1023GD`4
08MIAP<0Qe]71021FD@407iG@P@0O5M41021FDH408eiK`@0UHn8?@2BPWPF0?ooo`00503oool809:2
N0@0TWme0`2BOWD409:5NcH0TX9h102DPgT404/_8`@0P6AM0`1G>cH4099`H0@0TW=P302BLf<3099`
H0@0TW=S102BMfL4099`H0@0TFmJ102DIUP4095SDP<0REm<102<HDh408mTD0@0S6A>1023GD`408MI
AP<0Qe]71021FD@407iG@P@0O5M41021FDH408eiK`@0UHn8?@2BPWPF0?ooo`00503oool809:2N0@0
TX5g0`2BPWP4099oMCH0TX9h101C=RL409F0M0@0ECP/0`2?KUL<099`H0@0TW1O102BL6<3099`H0@0
TW9R102BL604099cH`@0SE]=102=IE@408aJBP<0S5a:1029FTP408U[D@P0Qee71023ET<3085I@`@0
QUM61023Ed@407mG@P@0PeI51027J5H409bETBX0TX9h102BPGL309:5N``0TX9h5P3oool001@0oooo
202BPWP409:1M`<0TX9h102BOgDf09:2N0@0DcHW102EP7@405Dh;0<0SfiG302BL604099`G`@0TW1S
0`2BL604099bHP@0TW1P102BLf<408eKC@@0SFED102<FTX308aLBP@0REY81029Je4808MMA`@0PeI3
0`21FD<408IGAP@0PeM4101oEd8408=FA@@0QfQF102LUI4Z09:2N0@0TX5g0`2BQG/<09:2N1H0oooo
000D0?ooo`P0TX9h102BPGL309:2N0@0TWme=P2BPWP405<f9`@0UH1d101E>2`308m^E``0TW1P102B
L5l4099`H`<0TW1P102BLV84099`H0@0TW=S102=Fdd408eUE0@0S5Y:0`2<G4X408UJB0@0RF]A2027
GDL408=F@`<0PEU31026EdH408=GA0@0OeM21023ETD408MXEP@0W9FA:P2BPWP409:1M`<0TXEk302B
PWPF0?ooo`00503oool809:2N0@0TX5g0`2BPWP4099oMCH0TX9h101C=RL409F0M0@0ECP/0`2?KUL<
099`H0@0TW1O102BL6<3099`H0@0TW9R102BL604099cH`@0SE]=102=IE@408aJBP<0S5a:1029FTP4
08U[D@P0Qee71023ET<3085I@`@0QUM61023Ed@407mG@P@0PeI51027J5H409bETBX0TX9h102BPGL3
09:5N``0TX9h5P3oool001@0oooo202BPWP7099oMCH0TX9h102:N6l406E>@`@0Fd0d102BLf<3099`
G0P0TW1P102BKed8099aG`<0TW=V102BLf<4099]G`@0TW9R102=E4P408a9?0@0RCld0`2<BT8408M2
=`@0S5131021F4@408AJA@@0Q5M20`21DT0408=IA0@0PeM41021Ed84085B?`@0PEU61029KE`309bO
WRL0TX9h1`2BOgD<09:2N1H0oooo000D0?ooo`P0TX9h1`2BOgDf09:2N0@0RWQ_101UCT<405]0=0@0
TW=S0`2BL5`8099`H0@0TVmM202BLEl3099cIP@0TW=S102BKEl4099bHP@0SEA8102<BC`408To=0<0
S4Y21027@SL408a@@`@0PEQ41024FTD408AG@P<0PE901023FD@408=GA0@0PEM21021DSl4085IAP@0
RFeL0`2LWihW09:2N0L0TWme302BPWPF0?ooo`00503oool809:2N0L0TWme=P2BPWP408YhK`@0IDi3
101K@3@4099cH`<0TW1L202BL604099_G@P0TW5O0`2BLfH4099cH`@0TVeO102BLV8408eDB0@0S4Tl
1029?c@308a:@P@0Qd8g102<D4<4085HA0@0Q5Y51024Ed83085B@0@0PeU41023Ed@4085G@P@0PE8o
1021FDH408U]G0<0W9nN9`2BPWP7099oM@`0TX9h5P3oool001@0oooo202BPWP7099oMCH0TX9h102:
N6l406E>@`@0Fd0d102BLf<3099`G0P0TW1P102BKed8099aG`<0TW=V102BLf<4099]G`@0TW9R102=
E4P408a9?0@0RCld0`2<BT8408M2=`@0S5131021F4@408AJA@@0Q5M20`21DT0408=IA0@0PeM41021
Ed84085B?`@0PEU61029KE`309bOWRL0TX9h1`2BOgD<09:2N1H0oooo000D0?ooodD0TX9h1017<2P4
0;fJQP@0TW=V102BL643099`G`@0TW1P102BL5l4095[F@@0U6]F102ELeh3099^GP@0TVeK102AFe84
099JB`@0SeiB1025>b`408mAA0<0RC/d1021<BL408Lm<0@0QdXm101lDD0407mKA0<0Oe8i1021EdD4
08IGAP@0PeM41023E48408=FA0@0Pee:0`2BOgD409:8PSH0TX9h5P3oool001@0ooooA@2BPWP404L`
:0@0_IZ6102BLfH4099`H@<0TW1O102BL604099`G`@0TF]I102DJeH409EcGP<0TViN102BKE/4095K
DP@0TUY;102?GU8408Dk;0@0Se540`29>c@4084a9`@0Qcd`1027BSd407aA@0@0Oe]40`1oDST4085G
A@@0QUM61023Ed@408=D@P@0PeI41023GDX3099oM@@0TXR2=P2BPWPF0?ooo`00503ooom509:2N0@0
Ac0X102mVXH4099cIP@0TW1Q0`2BL5l4099`H0@0TW1O102AJeT409A[EP@0UG=N0`2BKUh4099]F`@0
TE]B102BFT/408mNDP@0QC//102?DD@308Tk=0@0PC4W1027?C0408M:?@@0O550101oFd@307mB>@@0
PEM51026EdH408=GA0@0PeA21023ET@408=MBP<0TWme102BR88f09:2N1H0oooo000D0?ooodD0TX9h
1017<2P40;fJQP@0TW=V102BL643099`G`@0TW1P102BL5l4095[F@@0U6]F102ELeh3099^GP@0TVeK
102AFe84099JB`@0SeiB1025>b`408mAA0<0RC/d1021<BL408Lm<0@0QdXm101lDD0407mKA0<0Oe8i
1021EdD408IGAP@0PeM41023E48408=FA0@0Pee:0`2BOgD409:8PSH0TX9h5P3oool001@0oooo3`2B
PWP409:1M`@0TXEk:P2BPWP407iYHP@0J593101TCd@408m^F`@0TFeF0`2EMf@4099^F`@0TVeH102<
JE4408aNC0@0VGES0`2?G4/406XU4`@0]Wm[102<A3X408MCAP@0N48e101c<bD307mNB0@0OdDd1022
>S<407D`8P@0TSha101mFdL3085F>`@0PEA01021FdH408EHA0@0P5921023FDH408=GA0<0S6eJ102L
UHh409:8PS80TX9h5P3oool001@0oooo3`2BPWP409:1M`@0TXEk:P2BPWP407iYHP@0J593101TCd@4
08m^F`@0TFeF0`2EMf@4099^F`@0TVeH102<JE4408aNC0@0VGES0`2?G4/406XU4`@0]Wm[102<A3X4
08MCAP@0N48e101c<bD307mNB0@0OdDd1022>S<407D`8P@0TSha101mFdL3085F>`@0PEA01021FdH4
08EHA0@0P5921023FDH408=GA0<0S6eJ102LUHh409:8PS80TX9h5P3oool001@0oooo3`2BPWP409:1
M`@0TXEk:P2BPWP407iYHP@0J593101TCd@408m^F`@0TFeF0`2EMf@4099^F`@0TVeH102<JE4408aN
C0@0VGES0`2?G4/406XU4`@0]Wm[102<A3X408MCAP@0N48e101c<bD307mNB0@0OdDd1022>S<407D`
8P@0TSha101mFdL3085F>`@0PEA01021FdH408EHA0@0P5921023FDH408=GA0<0S6eJ102LUHh409:8
PS80TX9h5P3oool001@0oooo3`2BPWP409:1M`@0TXEk:P2BPWP407iYHP@0J593101TCd@408m^F`@0
TFeF0`2EMf@4099^F`@0TVeH102<JE4408aNC0@0VGES0`2?G4/406XU4`@0]Wm[102<A3X408MCAP@0
N48e101c<bD307mNB0@0OdDd1022>S<407D`8P@0TSha101mFdL3085F>`@0PEA01021FdH408EHA0@0
P5921023FDH408=GA0<0S6eJ102LUHh409:8PS80TX9h5P3oool001@0oooo202BPWP409:1M`<0TXEk
202BOgDZ09:2N0@0Ac0Y102MMf<4089OC`@0TW1L102=IUD3099fI@@0TW=S102BJ5@408ME?P@0Q5A1
101/81P30:V2M0@0Ja/C101N7Q<408I4=P@0RDDd102?IeH408YAA0<0OcT_101[=B4406Dm;@@0FbdP
101I9aH409M5<P<0PEm51023D3d408EMBP@0QEe81025FT@4081DA0@0PeU60`23FdP408afK@@0VXIc
102ER7h^09:2N1H0oooo000D0?ooo`P0TX9h102BPGL309:5N`P0TWme:P2BPWP404L`:@@0WGMS1022
Gdl4099`G0@0SFIE0`2BMVD4099cH`@0TVQD1027ECh408AD@@@0K20H0`2YPW@406/K4`@0GQhC1026
A3H408U5=0@0SfMF102:DD@307li;`@0JcDQ101U?Bd405/]80@0FBLF102GAC83085OA@@0Pe0m1025
GDX408EMB0@0QEY41020E4@408=IAP<0Pe]8102<MVd409Z6L`@0UHQn;P2BPWPF0?ooo`00503oool8
09:2N0@0TX5g0`2BQG/8099oMBX0TX9h1017<2T409egH`@0PUm?102BL5`408eVE@<0TWIU102BLf<4
099XE0@0QeDn1024E44406`P60<0ZH9d101[6a<405hN4`@0QT@f1029AC@408mWEP@0RU540`1o>Bl4
06/e8@@0ICd]101K;B0405TW5P@0UdDb0`21GdD408=@?@@0QEe:1025GDP408EJA0@0P5A41023FDH3
08=KB0@0S7I]102JQW<409F8ORh0TX9h5P3oool001@0oooo202BPWP409:1M`<0TXEk202BOgDZ09:2
N0@0Ac0Y102MMf<4089OC`@0TW1L102=IUD3099fI@@0TW=S102BJ5@408ME?P@0Q5A1101/81P30:V2
M0@0Ja/C101N7Q<408I4=P@0RDDd102?IeH408YAA0<0OcT_101[=B4406Dm;@@0FbdP101I9aH409M5
<P<0PEm51023D3d408EMBP@0QEe81025FT@4081DA0@0PeU60`23FdP408afK@@0VXIc102ER7h^09:2
N1H0oooo000D0?ooo`P0TX9h1`2BOgD_09:2N0<0S7af100f7QH409AdG`P0TW1O102?J5D308mXF@@0
TW1P102?Gd/4089C=`@0OcLV101E60d308EIC@@0RWm]102DNVd409F?Q@@0TWU]102BO78408aYFP<0
U89a102?JeT4089`J0@0EcP_1015:B4404DM4`<0UDTb1027H4X408aOBP@0RV=B1026FTH408=IA0@0
Pe900`23FdL4085`J0@0QgEd102HRXP409b?ORX0TX9h5P3oool001@0oooo202BPWP7099oMBl0TX9h
0`2<O7H403HN5P@0U7AO202BL5l408mXE@<0SfQI102BL60408mOB`@0PU<g101o=bH405DH3@<0QEU=
102:Ofd409AjK@@0UHn5102BNFd4099lLP@0S6UJ0`2DPW4408m[F@@0PW1X101G>2l404DY8@@0AAdC
0`2EBC8408MPBP@0S5m:102:He8408IJAP@0PeU41023DT0308=KA`@0PG1X1027MG@409R:R0@0W8mn
:P2BPWPF0?ooo`00503oool809:2N0L0TWme;`2BPWP308alMP@0=QhF102DM5l8099`G`@0SfQE0`2?
J5T4099`H0@0Sem;1022DcL407lg9P@0EAP=0`25FDd408YoK@@0U7Y]102EShD4099iK@@0TWab102<
JEX309B2L@@0Sf]I1022L6P405Lh;`@0ABTQ10157A<309E9<P@0Qf1:102<GdX408YSDP@0QUY61023
FD@408=B@0<0Pe]71021L6P408MeM0@0V8Z8102LSghZ09:2N1H0oooo000D0?ooo`P0TX9h1`2BOgD_
09:2N0<0S7af100f7QH409AdG`P0TW1O102?J5D308mXF@@0TW1P102?Gd/4089C=`@0OcLV101E60d3
08EIC@@0RWm]102DNVd409F?Q@@0TWU]102BO78408aYFP<0U89a102?JeT4089`J0@0EcP_1015:B44
04DM4`<0UDTb1027H4X408aOBP@0RV=B1026FTH408=IA0@0Pe900`23FdL4085`J0@0QgEd102HRXP4
09b?ORX0TX9h5P3oool001@0oooo>P2BPWP406]EAP<0DC4Y101mGE@4065<@0@0SfiJ102BKEP4099b
G@<0TWIS102BL64408UGAP@0OE<n101^>2T4054=30<0GR8M1027ED@408aOCP@0TVeN102GJed408ma
F@@0SeI40`2=Dd8408YKB@@0TWUR1027ET@407ACA`@0DCP/0`184PP409]NBP@0RFA:102=J5@408UO
BP@0PeU71021ET@308IFA0@0PF9@101oLFT407=MF`@0UHQo:P2BPWPF0?ooo`00503ooolj09:2N0@0
JeE60`1A<BT407eME0@0HDa0102?KUX4099]F0@0TW9M0`2BMV<4099`H@@0REM6101mDch406hh:@@0
D@d<0`1N8Qd408MEA0@0S5m>102BKEh409M[G@@0Sg5I102?ET@308eC@P@0RU]9102BNF8408MFA0@0
M5=7101A>2`304PB20@0Vei:1029I4X408eXE0@0REm:1023FDL4085FA0<0QUI41021HU0407maJ@@0
LeeK102ER7lZ09:2N1H0oooo000D0?ooocX0TX9h101[EDH3054a:@@0OEeD101QC40408m^FP@0TVeH
102BLUd3099fH`@0TW1Q1029EdH407eC?P@0KSPY101A3@`305hR7@@0QeE4102<Gdh4099]GP@0Uf]M
102?LET408mFA0<0SE=2102:FdT4099iHP@0QeI4101dDdL4054h;0<0B188102KGTX408UTBP@0SFQD
1029GdX408=IA`@0PEI40`26ET@4085RD0@0Og5Y101cGE/409F8ObX0TX9h5P3oool001@0oooo4`2B
PWP409:1M`@0TXEk6`2BPWP408ajL`@09QL?0`0b6a@408EMC`@0OeY9102BKeX4099XF0@0TFeD0`2E
KUX4099[FP@0REm81022DC/409UlJP@0SfmJ0`2BIEH408mMD@@0REM:1026DTD408U<@P@0Q4Dn1020
AC/307lf;P@0OcH`101mBS/4089<?`@0MT8d101Y=bL304hN5@@0I2PK102HKUH4095[E0@0RF9:1023
Ed@407mD@P<0Pe]71023Gd`405`k;0@0^Jf^1024L6d409F8ORH0TX9h5P3oool001@0oooo4`2BPWP4
09:1M`@0TXEk6`2BPWP408ajL`@09QL?0`0b6a@408EMC`@0OeY9102BKeX4099XF0@0TFeD0`2EKUX4
099[FP@0REm81022DC/409UlJP@0SfmJ0`2BIEH408mMD@@0REM:1026DTD408U<@P@0Q4Dn1020AC/3
07lf;P@0OcH`101mBS/4089<?`@0MT8d101Y=bL304hN5@@0I2PK102HKUH4095[E0@0RF9:1023Ed@4
07mD@P<0Pe]71023Gd`405`k;0@0^Jf^1024L6d409F8ORH0TX9h5P3oool001@0oooo4`2BPWP409:1
M`@0TXEk6`2BPWP408ajL`@09QL?0`0b6a@408EMC`@0OeY9102BKeX4099XF0@0TFeD0`2EKUX4099[
FP@0REm81022DC/409UlJP@0SfmJ0`2BIEH408mMD@@0REM:1026DTD408U<@P@0Q4Dn1020AC/307lf
;P@0OcH`101mBS/4089<?`@0MT8d101Y=bL304hN5@@0I2PK102HKUH4095[E0@0RF9:1023Ed@407mD
@P<0Pe]71023Gd`405`k;0@0^Jf^1024L6d409F8ORH0TX9h5P3oool001@0oooo4`2BPWP409:1M`@0
TXEk6`2BPWP408ajL`@09QL?0`0b6a@408EMC`@0OeY9102BKeX4099XF0@0TFeD0`2EKUX4099[FP@0
REm81022DC/409UlJP@0SfmJ0`2BIEH408mMD@@0REM:1026DTD408U<@P@0Q4Dn1020AC/307lf;P@0
OcH`101mBS/4089<?`@0MT8d101Y=bL304hN5@@0I2PK102HKUH4095[E0@0RF9:1023Ed@407mD@P<0
Pe]71023Gd`405`k;0@0^Jf^1024L6d409F8ORH0TX9h5P3oool001@0oooo4`2BPWP8099oMA/0TX9h
1023KV/404@`:0<00006101>?SP409EcH@@0TVaH102BJ5X408mQEP<0SgIL102BJ5X408UEB0@0OT`j
102:J5@409EiJP<0TWET102BKUh4099cH`@0TWET102BJ5P408e[DP@0SF=@0`29GdX408UKAP@0PEA0
1027BSh408A3>0@0MSD/0`1R:B4405TS7@@0Ld8^102?I5@408aQBP@0PeM4101oE40308=DA0@0Pe]8
1017<2L408M]H@@0W8b5102?Ng8V09:2N1H0oooo000D0?oooa<0TX9h202BOgDK09:2N0@0Pfi[1014
<2P300001P@0CShh102ELf44099/F0@0TVQJ102?HEH308mfG0@0TVQJ1029EDP407i<>P@0RVQD102E
NFX3099eI0@0TViN102BLf<4099eI0@0TVQH102=Je8408eSD0<0REm:1029FdH4085D@0@0QdXn1024
@cP407He;0<0HRTQ101I8ad407=2;P@0SfAD102<HDX408=GA0@0OeA00`23E4@408=KB0@0Ac0W1027
KF4409b<Q@@0Sg]b9P2BPWPF0?ooo`00503ooolC09:2N0P0TWme6`2BPWP408=^J`@0A30X0`0000H4
04hn>0@0UG=Q102BK5P4099XFP@0Sf5F0`2?MU`4099XFP@0REE8101nC3X408YXE0@0UGUZ0`2BMF@4
099^GP@0TW=S102BMF@4099XF0@0SF]B102=He0308UOBP@0RE]61021E40408M:?P@0Q4<h101f=B`3
068Y8@@0FB<M101c@Rh408mTE0@0S65:1023Ed@407mD@0<0PeA41023FdP404L`9`@0QfeQ102LS8D4
08mkLRH0TX9h5P3oool001@0oooo4`2BPWP8099oMA/0TX9h1023KV/404@`:0<00006101>?SP409Ec
H@@0TVaH102BJ5X408mQEP<0SgIL102BJ5X408UEB0@0OT`j102:J5@409EiJP<0TWET102BKUh4099c
H`@0TWET102BJ5P408e[DP@0SF=@0`29GdX408UKAP@0PEA01027BSh408A3>0@0MSD/0`1R:B4405TS
7@@0Ld8^102?I5@408aQBP@0PeM4101oE40308=DA0@0Pe]81017<2L408M]H@@0W8b5102?Ng8V09:2
N1H0oooo000D0?ooocH0TX9h1028L6P408Q`JP<0SfUE102:HDd4095_FP@0UG1L102BKU/4099XF@<0
TVUJ102BKUT408YSC@@0PU511026F4D409MmJ0<0UGMZ102BLV84099^GP@0TWET102BJ5X408eLCP@0
S5e90`2<ITl408AIA@@0P5I31022DS/407mA?P@0OeDn0`1oCch407e??P@0PEA41026FT@408UMB0P0
PEI20`21FD8408AIA`@0=b8K102BNg4408ahIRX0TX9h5P3oool001@0oooo=P2BPWP408Q`J0@0R71Z
0`2?JED408YQC@@0TFmJ102EL5`4099^F`@0TVQI0`2BJEX4099^F@@0RV==1022DD4408IHA@@0UgeX
0`2EMfX4099bHP@0TViN102BMF@4099XFP@0SEa>102<GDT308aVC`@0Q5U51020ET<4089B>`@0Oe4n
101oECh307m??P@0ODln1021E4@408IJA0@0REe82021ET83085I@P@0Q5U7100g8Q/4099kL@@0S7QV
:P2BPWPF0?ooo`00503ooolf09:2N0@0R71X1028L6X308mYE@@0RV5=102AKeX409E`G0@0TViK102B
J5T3099YFP@0TViI102:Hdd4089A@@@0QUQ5102GOFP309EgJP@0TW9R102BKUh4099eI0@0TVQJ102=
G4h408aMB@<0S6I?1024FDD4081F@`@0PU8k101oDCh407mE?P<0Odln101mCch4085DA0@0QUY41029
GDP8085F@P<0PEU21024FDL403LR6`@0TW]a102<N6HZ09:2N1H0oooo000D0?ooocH0TX9h1028L6P4
08Q`JP<0SfUE102:HDd4095_FP@0UG1L102BKU/4099XF@<0TVUJ102BKUT408YSC@@0PU511026F4D4
09MmJ0<0UGMZ102BLV84099^GP@0TWET102BJ5X408eLCP@0S5e90`2<ITl408AIA@@0P5I31022DS/4
07mA?P@0OeDn0`1oCch407e??P@0PEA41026FT@408UMB0P0PEI20`21FD8408AIA`@0=b8K102BNg44
08ahIRX0TX9h5P3oool001@0oooo<P2BPWP4095oMP@0UGIQ102AKE/3099`F`@0SGQ]102IKe<408m`
GP@0TW9O102BKel7099bHP@0SfAD1027HDX4089@?`@0RVIB0`2BNFP4099gI`@0TV]M102ANV@409Ef
H`@0S65>102<FdP308AA?0@0Q659101gCCT407MA>`@0NT`j101lCSH307M:>0@0NTTe2025GDX408MK
A`@0PUA2101oDT0307mG@P@0PEU4100O4Q0408edK@@0W8n>:P2BPWPF0?ooo`00503ooolb09:2N0@0
TGmf102EMV44095]F`<0TW1K102=N6d409U_D`@0Sg1N102BLUl4099_G`L0TW9R102?I5@408MQBP@0
PU0o102:IU83099iJ0@0TWMW102BJed4095jI0@0UGIS102<HDh408aKB0<0Q54l1024HDT407M=>@@0
Me4k101jC3X407a>=P<0MdXh101jBCD808EMBP@0Qe]71022E48407mB@0<0OeM21021FD@401lB40@0
SGA]102LShhZ09:2N1H0oooo000D0?oooc80TX9h102AOgH409EfH@@0TFeK0`2BL5/408ehK@@0VFmC
102?L5h4099bG`@0TVmO1`2BLV8408mTE0@0Qf5:1022D3l408YVDP<0TWUX102BMfL4099[G@@0TGYT
102EMV<408aQCP@0S5]80`24DC`408AQB@@0Mddi101gDC/407Y<>P@0O4hf0`1gBSP407Y9=@P0QEe:
1027FdL4089D@P@0Oe900`1oEd84085IA0@07a8@102=M6d409b?SRX0TX9h5P3oool001@0oooo<P2B
PWP4095oMP@0UGIQ102AKE/3099`F`@0SGQ]102IKe<408m`GP@0TW9O102BKel7099bHP@0SfAD1027
HDX4089@?`@0RVIB0`2BNFP4099gI`@0TV]M102ANV@409EfH`@0S65>102<FdP308AA?0@0Q659101g
CCT407MA>`@0NT`j101lCSH307M:>0@0NTTe2025GDX408MKA`@0PUA2101oDT0307mG@P@0PEU4100O
4Q0408edK@@0W8n>:P2BPWPF0?ooo`00503ooolb09:2N0@0SgIX102?MVX408aTCP<0RF9<1027K5d4
08QVG@@0TWIP3`2BMF@4099XFP@0See@1026F4@408aIB0<0UGUX102BMF@4099XF`@0SfEF102?KUT4
08YQC@@0QUY60`21CSd407i@?`@0MdTh101jBcP407Y??0@0Oe8m0`1nD3T407Y?>`@0Oe=01027Ed@4
08MIAP@0PEA2101lD3l307mG@P@0PEU7100V5A0404Tc:`@0_JfQ102BQG/V09:2N1H0oooo000D0?oo
oc80TX9h102?MVP408mfJP@0S6A>0`29HT`408M/G@@0R6IM102BMV0?099eI0@0TVQJ102?GE0408IH
A0@0S5U80`2ENFP4099eI0@0TVQK102?IEH408m^F@@0RV5=1026FTH3085>?@@0OU0o101gBCP407Y;
>0@0NTll101oDSd307i@>@@0NTlk101oDd0408MGA0@0QeU61021E48407a@?`<0OeM21021FDL402HE
40@0BC<[102m[J4409:5NbH0TX9h5P3oool001@0oooo<P2BPWP408mfJ0@0SgIZ102<I4h308URC0@0
QfaM1028IUd4099fH0l0TWET102BJ5X408mMD0@0QUQ4102<FDP309EiJ0@0TWET102BJ5/408mUEP@0
SfiI102:HDd408IJAP<0PDhm101nD3l407M9>0@0NT/h101jCc`407mB?@<0OU0i101jCc/407mC@0@0
QeM41027FDH4085D@P@0O50o0`1oEd84085IA`@09QD@1019<b/40;f]X@@0TXEk9P2BPWPF0?ooo`00
503ooolb09:2N0@0SgIX102?MVX408aTCP<0RF9<1027K5d408QVG@@0TWIP3`2BMF@4099XFP@0See@
1026F4@408aIB0<0UGUX102BMF@4099XF`@0SfEF102?KUT408YQC@@0QUY60`21CSd407i@?`@0MdTh
101jBcP407Y??0@0Oe8m0`1nD3T407Y?>`@0Oe=01027Ed@408MIAP@0PEA2101lD3l307mG@P@0PEU7
100V5A0404Tc:`@0_JfQ102BQG/V09:2N1H0oooo000D0?oooc80TX9h102BL5`4095_G@@0QE@o0`2A
Ked408QNC`@0SfiJ102BJ5h4099eI0@0TWIW0`2BLEl4099eI0@0TW1N102BJeD408UJAP@0REY40`2A
JU/409EfJ0@0TW=Q102BLVD4099^GP@0SFED1027F4L308MKA`@0PEM4101oCSd407U:=@@0MdPi101o
E48308EFAP@0QeU61026FTP408=JB0@0PeA32021E48307mD@@@0PEY61019<2@402/K5P@0CCXb103=
`kTV09:2N1H0oooo000D0?oooc80TX9h102BL5`4095_G@@0QE@o0`2AKed408QNC`@0SfiJ102BJ5h4
099eI0@0TWIW0`2BLEl4099eI0@0TW1N102BJeD408UJAP@0REY40`2AJU/409EfJ0@0TW=Q102BLVD4
099^GP@0SFED1027F4L308MKA`@0PEM4101oCSd407U:=@@0MdPi101oE48308EFAP@0QeU61026FTP4
08=JB0@0PeA32021E48307mD@@@0PEY61019<2@402/K5P@0CCXb103=`kTV09:2N1H0oooo000D0?oo
oc80TX9h102BL5`4095_G@@0QE@o0`2AKed408QNC`@0SfiJ102BJ5h4099eI0@0TWIW0`2BLEl4099e
I0@0TW1N102BJeD408UJAP@0REY40`2AJU/409EfJ0@0TW=Q102BLVD4099^GP@0SFED1027F4L308MK
A`@0PEM4101oCSd407U:=@@0MdPi101oE48308EFAP@0QeU61026FTP408=JB0@0PeA32021E48307mD
@@@0PEY61019<2@402/K5P@0CCXb103=`kTV09:2N1H0oooo000D0?ooobh0TX9h102BO6l408m/F@@0
SEI41024ID`308AUD@@0W6]J102BJ5X4099`H0@0TWET1`2BN6T4099eI0@0TW1P102AKeX408eUDP@0
Qei:0`2<IE0408m^G0@0TF]K102EO6H4099]HP@0S6]A1026F4L3085F@`@0OeA01021ESh407M:>0@0
PTli1021ET@308IHB0@0SF5@1029Gd`408=MBP@0Pe]71021FDH407aG@P<0PEA31021HTh407U>>P@0
GCTZ100g7AP405Pm=2H0TX9h5P3oool001@0oooo;P2BPWP4099lK`@0SfaI102=ET@408AUC0<0Q6EA
102LJeX4099XFP@0TW1P102BMF@7099hJ@@0TWET102BL604095_FP@0SFEB1027GTX308aUD0@0SfiL
102AJe/409ElIP@0TVeR102<Je4408IHA`<0PEI3101oE404085F?P@0MdXh1022CcT4085FA0<0QUQ8
102=HE0408UOC0@0Pee:1023FdL4085IAP@0O5M20`21E4<4085RCP@0NDhj101M>BX403LM60@0F3dd
9P2BPWPF0?ooo`00503oool^09:2N0@0TWa_102?K5T408eFA0@0Q6E<0`24IE4409a[FP@0TVQJ102B
L604099eI0L0TWQY102BMF@4099`H0@0TFmJ102=IE8408MNBP<0S6E@102?KU`4095[F`@0UGaV102B
KF8408a[D@@0QUQ70`21ET<407mD@0@0PEHn101gBSP4089?>@@0PEI40`26F4P408eQD0@0REm<1023
GDX408=KA`@0PEU6101lEd83085D@`@0PF9>101iCSX405di:P@0=adH101H?C@V09:2N1H0oooo000D
0?ooobh0TX9h102BO6l408m/F@@0SEI41024ID`308AUD@@0W6]J102BJ5X4099`H0@0TWET1`2BN6T4
099eI0@0TW1P102AKeX408eUDP@0Qei:0`2<IE0408m^G0@0TF]K102EO6H4099]HP@0S6]A1026F4L3
085F@`@0OeA01021ESh407M:>0@0PTli1021ET@308IHB0@0SF5@1029Gd`408=MBP@0Pe]71021FDH4
07aG@P<0PEA31021HTh407U>>P@0GCTZ100g7AP405Pm=2H0TX9h5P3oool001@0oooo;P2BPWP4099[
G@@0REQ5101o@S@407mB@@<0Q6MF1028KUh4099bG0@0TViK2`2BMF@4099cH`@0TW=Q102=K5/408mX
E0@0RVaH0`2BL5h4099bG0@0SfED102?J5H4099UE0@0REa<1021DSl307m??@@0NTdk101mCcT407Y>
>@@0N4dm101oDd8308ENC0@0SF5>1029Gd`408=KB0@0PeM41023E4@4085F@P<0Oe@o1026Gdh407e=
=`@0PEI5102DPgT408moMBH0TX9h5P3oool001@0oooo;P2BPWP4099[G@@0REQ5101o@S@407mB@@<0
Q6MF1028KUh4099bG0@0TViK2`2BMF@4099cH`@0TW=Q102=K5/408mXE0@0RVaH0`2BL5h4099bG0@0
SfED102?J5H4099UE0@0REa<1021DSl307m??@@0NTdk101mCcT407Y>>@@0N4dm101oDd8308ENC0@0
SF5>1029Gd`408=KB0@0PeM41023E4@4085F@P<0Oe@o1026Gdh407e==`@0PEI5102DPgT408moMBH0
TX9h5P3oool001@0oooo;P2BPWP4099[G@@0REQ5101o@S@407mB@@<0Q6MF1028KUh4099bG0@0TViK
2`2BMF@4099cH`@0TW=Q102=K5/408mXE0@0RVaH0`2BL5h4099bG0@0SfED102?J5H4099UE0@0REa<
1021DSl307m??@@0NTdk101mCcT407Y>>@@0N4dm101oDd8308ENC0@0SF5>1029Gd`408=KB0@0PeM4
1023E4@4085F@P<0Oe@o1026Gdh407e==`@0PEI5102DPgT408moMBH0TX9h5P3oool001@0oooo;P2B
PWP4099[G@@0REQ5101o@S@407mB@@<0Q6MF1028KUh4099bG0@0TViK2`2BMF@4099cH`@0TW=Q102=
K5/408mXE0@0RVaH0`2BL5h4099bG0@0SfED102?J5H4099UE0@0REa<1021DSl307m??@@0NTdk101m
CcT407Y>>@@0N4dm101oDd8308ENC0@0SF5>1029Gd`408=KB0@0PeM41023E4@4085F@P<0Oe@o1026
Gdh407e==`@0PEI5102DPgT408moMBH0TX9h5P3oool001@0oooo:P2BPWP4099nL@@0TVmS1029CT84
07e2<`@0PeA60`2<JeL408m^GP@0TWET102BLV84099`H0@0TWIU0`2AM64409EfIP@0TV]M102=LUP4
095XE0@0TFeH0`2BLf<4099cH@@0TW=V102BL604099VEP@0REe6101oET<307Y>?0@0Md`j101cC3/4
07a>>`@0PEI61029Gd`308YSD0@0RF5>102<Gd`408=MBP@0PeA21023E4<4085B@`<0PEA21023G504
07i>>`@0NE0m102=Mfl40::HSRH0TX9h5P3oool001@0oooo:P2BPWP4099nL@@0TVmS1029CT8407e2
<`@0PeA60`2<JeL408m^GP@0TWET102BLV84099`H0@0TWIU0`2AM64409EfIP@0TV]M102=LUP4095X
E0@0TFeH0`2BLf<4099cH@@0TW=V102BL604099VEP@0REe6101oET<307Y>?0@0Md`j101cC3/407a>
>`@0PEI61029Gd`308YSD0@0RF5>102<Gd`408=MBP@0PeA21023E4<4085B@`<0PEA21023G50407i>
>`@0NE0m102=Mfl40::HSRH0TX9h5P3oool001@0oooo:P2BPWP4099nL@@0TVmS1029CT8407e2<`@0
PeA60`2<JeL408m^GP@0TWET102BLV84099`H0@0TWIU0`2AM64409EfIP@0TV]M102=LUP4095XE0@0
TFeH0`2BLf<4099cH@@0TW=V102BL604099VEP@0REe6101oET<307Y>?0@0Md`j101cC3/407a>>`@0
PEI61029Gd`308YSD0@0RF5>102<Gd`408=MBP@0PeA21023E4<4085B@`<0PEA21023G50407i>>`@0
NE0m102=Mfl40::HSRH0TX9h5P3oool001@0oooo:P2BPWP4099nL@@0TVmS1029CT8407e2<`@0PeA6
0`2<JeL408m^GP@0TWET102BLV84099`H0@0TWIU0`2AM64409EfIP@0TV]M102=LUP4095XE0@0TFeH
0`2BLf<4099cH@@0TW=V102BL604099VEP@0REe6101oET<307Y>?0@0Md`j101cC3/407a>>`@0PEI6
1029Gd`308YSD0@0RF5>102<Gd`408=MBP@0PeA21023E4<4085B@`<0PEA21023G50407i>>`@0NE0m
102=Mfl40::HSRH0TX9h5P3oool001@0oooo:P2BPWP408m[E@@0SF5>101iCCL408Q?>P@0SfA>0`2?
JeL4099`H0@0TW=S102BMVD4099cH@@0TVmO0`2=Ked4095[F0@0TV]H102DIUP408eZE0@0SFAB0`2B
KU`4099`H0@0TW1N102BL604095WF0@0S5A6101oD3l707Y>?0@0NE90101iEd8408EKB0@0QEm:0`2<
HDh408aSD0@0REY81023FDH408=FA0P0PE0o0`1oE48408=RCP@0Od@^1026IU@407aCA0@0TYVH9P2B
PWPF0?ooo`00503ooolZ09:2N0@0Sf]E102=HDh407U==`@0R4lj102?I4h308m[E`@0TW1P102BLf<4
099fI@@0TW=Q102BKel308e_G@@0TF]H102BJeP409AVF0@0SFYD102=I583099^G0@0TW1P102BL5h4
099`H0@0TFMH102<E4H407m@?`L0NThl101iDT0407UG@P@0QE]81025GdX308aQCP@0S6=@1029FTP4
08=IAP@0PeI42021D3l307mD@P@0Pf9>101oA2h408IVE0@0O5=4102BVIPV09:2N1H0oooo000D0?oo
obX0TX9h102?JeD408eQCP@0NDdg1028CcX408mTCP<0Sf]G102BL604099cH`@0TWIU102BLf44099_
G`<0SFmM102AJeP4099[F0@0U6IH102=JU@408eTDP<0TViL102BL604099`GP@0TW1P102AIeP408aD
AP@0Oe0o1`1jCS`407UB@0@0NEM21025FdP408EOBP<0S65>102<He0408UJB0@0PeU61023ET@8085@
?`<0OeA21023HTh407m4;P@0QVID101lDd@409:IV2H0TX9h5P3oool001@0oooo:P2BPWP408m[E@@0
SF5>101iCCL408Q?>P@0SfA>0`2?JeL4099`H0@0TW=S102BMVD4099cH@@0TVmO0`2=Ked4095[F0@0
TV]H102DIUP408eZE0@0SFAB0`2BKU`4099`H0@0TW1N102BL604095WF0@0S5A6101oD3l707Y>?0@0
NE90101iEd8408EKB0@0QEm:0`2<HDh408aSD0@0REY81023FDH408=FA0P0PE0o0`1oE48408=RCP@0
Od@^1026IU@407aCA0@0TYVH9P2BPWPF0?ooo`00503ooolZ09:2N0@0QeDn101F;QX406/l;@@0DbhT
102QLUT7099`GP@0TW1O102BL644099`H0@0TViI0`2?JeH408aUE0@0Qea<1029Gdh408aXD`@0U7EO
0`2ALEd409EcH`@0TW1P102BL5l408eXF@@0Qee7101oCd8307eA>@@0N4/k1021E484085IAP@0Q5M6
102:Gdd308aOCP@0Qem9102:I4l808AKA`@0PEU6101oDT0307mBA0@0PE]9101jAc44089??0@0Q552
102BPWDV09:2N1H0oooo000D0?ooobX0TX9h1027ECh405H^6P@0Jc`]101C;R@40:5bF@L0TW1N102B
L5l4099`H@@0TW1P102BKUT308m[EP@0S6ED1027G4`408UOCP@0S6QC102DMEl3095aG@@0UG=S102B
L604099`G`@0SFQI1027GDL407m?@P<0OE4i101hBc/4085D@P@0PEU61024EdH408YOC@<0S5m>1027
GdT408YTC`P0Q5]71021FDH407mB@0<0Oe941021FdT407Y7<@@0PTll1024DD8409:2MBH0TX9h5P3o
ool001@0oooo:P2BPWP408ME?P@0ERhJ101[?2d405<^90@0XG9I1`2BL5h4099`G`@0TW1Q102BL604
099^F@<0Sf]F102<IE@408MLC0@0REm>102<J5<409AeG`<0TG5M102ELf<4099`H0@0TW1O102=J5T4
08MMA`@0Odm20`1mDCT407Q;>`@0PEA21021FDH408AGAP@0RUm=0`2<Gdh408MOB@@0RVA?2024FdL4
085IAP@0Oe900`1oDT@4085KB@@0NTLa1022Cc`408AA@P@0TX9e9P2BPWPF0?ooo`00503ooolZ09:2
N0@0QeDn101F;QX406/l;@@0DbhT102QLUT7099`GP@0TW1O102BL644099`H0@0TViI0`2?JeH408aU
E0@0Qea<1029Gdh408aXD`@0U7EO0`2ALEd409EcH`@0TW1P102BL5l408eXF@@0Qee7101oCd8307eA
>@@0N4/k1021E484085IAP@0Q5M6102:Gdd308aOCP@0Qem9102:I4l808AKA`@0PEU6101oDT0307mB
A0@0PE]9101jAc44089??0@0Q552102BPWDV09:2N1H0oooo000D0?ooobH0TX9h102BOgD408EHB0@0
EBlO100l8aT404PX8P@0RF=@0`2BL5l4095_G`@0UG=S102BL5T408aYEP@0UG9P0`2=IE8409A]F0@0
TVMG102@FTd408aQB`@0RF5=0`2BLUd409EfI@@0TW1P102BL5h408eSDP@0PeM4101jC3/307Y9>0@0
MDhl101mCS`407mHA@@0Q5Q5102:FdL308UOCP@0Q5A41026FdP4085IAP@0O5A2101oEd@407mB@0<0
Oe94101oEd@406Xj9`@0MCTS102:EC`409F5PBH0TX9h5P3oool001@0oooo9P2BPWP4099oM@@0QEQ8
101E;al403`S6@@0B2PR1029He03099`G`@0TFmO102ELf<4099`F@@0S6UF102ELV0308eUDP@0U6eH
102BIeL4091JC@@0S65;1029HDd3099bG@@0UGIU102BL604099`GP@0SF=B1023Ed@407Y<>`<0NTTh
101eCS`407e>?0@0OeQ51024F4D408YKA`<0REm>1024E4@408IKB0@0PEU6101lE48407mGA0@0Oe90
0`1oDT@407mGA0@0JSXW101e>B<408YE?0@0UHF19P2BPWPF0?ooo`00503ooolV09:2N0@0TWme1025
F4P405D_7`@0?2<I1018:28408USD0<0TW1O102AKel409EcH`@0TW1I102<JEH409EbH0<0SFEB102D
KEP4099WE`@0T5Y=102<HD/408UQC@<0TW9M102EMVD4099`H0@0TW1N102=He8408=GA0@0NT`k0`1j
BCP407E>?0@0ODhl101oF4D408AHA@@0RU]70`29Gdh408ADA0@0QU]81021FDH407aD@P@0OeM4101o
DT0307mBA0@0OeM4101Z>RL407Di8`@0RUDl102EQH4V09:2N1H0oooo000D0?ooobH0TX9h102ALV44
08aTF0@0<a09100h7AD403/R6`@0Uf]G0`2=K5P4099_FP@0Sg1O102BL5l408MSD0@0MeA20`1dCSX4
05`n<P@0ESDZ101b?2P408aD@@@0Od0[0`24B3440:N<M@@0UGIX102BL60408eUE0@0PeA4101jCSP3
07Q>=P@0MDDe101oET@407QA@@@0LU51101hDT4307mHA`@0OEY51029GDX408=KB0@0OeM4101jE484
07mD@P<0Q5A4101oE4@406@g9`@0HRdN101g?R`409:9O2H0TX9h5P3oool001@0oooo9P2BPWP4095b
H@@0S6AH100c40T403PM5@@0>b8K102GJeL308e/F0@0TVmJ102?L5l4099`G`@0Qf=@101gE48307A>
>P@0G3hb101F=BX4078l:0@0S5A1101o@2/308A8<@@0Yhae102EMVP4099`H0@0SFED1023E4@407Y>
>0<0N4hf101eACD407mFA0@0N551101bDD4407QB@@<0OeQ7101mFTD408UMBP@0Pe]8101oEd@407YD
@P@0OeA20`24E4@407mDA0@0I3LW101R;Ah407Ln;0@0TXUl9P2BPWPF0?ooo`00503ooolV09:2N0@0
TG9Q102<I5P403<@2@@0>1dE100k8Q/409M[E`<0SFaH102BKeX408m`G`@0TW1O1027He0407MD@P<0
M4hj101L?S8405He:P@0LS`X102<E44407m0:`<0Q4Pa102WS7D409EfJ0@0TW1P102=IE@408=DA0@0
NThh0`1hCSH407E5=@@0OeI4101hDD44079A@@@0N5910`1oF4L407eJA@@0REe:1023FdP407mGA0@0
NUA2101oE48308ADA0@0OeA4101T=bL4068]7P@0Mch/102BRG`V09:2N1H0oooo000D0?ooobH0TX9h
102ALV4408aTF0@0<a09100h7AD403/R6`@0Uf]G0`2=K5P4099_FP@0Sg1O102BL5l408MSD0@0MeA2
0`1dCSX405`n<P@0ESDZ101b?2P408aD@@@0Od0[0`24B3440:N<M@@0UGIX102BL60408eUE0@0PeA4
101jCSP307Q>=P@0MDDe101oET@407QA@@@0LU51101hDT4307mHA`@0OEY51029GDX408=KB0@0OeM4
101jE48407mD@P<0Q5A4101oE4@406@g9`@0HRdN101g?R`409:9O2H0TX9h5P3oool001@0oooo8`2B
PWP309B3N@@0S6EB1024ETD403`S7@@08Q8=100d6Q@408Y/F0<0Sf]G102=JUH409E`G0@0TW1L102?
JeT407QB?`<0Jddo100n:b04034K5P@0@R8F101J?2l407Xl:P<0Kc`_101kDD84099_G`@0TW1Q102=
I4l408=D@P@0MDTe0`1hCS@405LM3`@0Sf=;1022ES/407iE@`@0MdTd0`2?GDX407YDA0@0PEU31024
FdT4085IAP@0MDlm101eE48307mDA0@0NU@o101Q=2L406dh9`@0O40c102@NF`308moMB<0TX9h5P3o
ool001@0oooo8`2BPWP309B3N@@0S6EB1024ETD403`S7@@08Q8=100d6Q@408Y/F0<0Sf]G102=JUH4
09E`G0@0TW1L102?JeT407QB?`<0Jddo100n:b04034K5P@0@R8F101J?2l407Xl:P<0Kc`_101kDD84
099_G`@0TW1Q102=I4l408=D@P@0MDTe0`1hCS@405LM3`@0Sf=;1022ES/407iE@`@0MdTd0`2?GDX4
07YDA0@0PEU31024FdT4085IAP@0MDlm101eE48307mDA0@0NU@o101Q=2L406dh9`@0O40c102@NF`3
08moMB<0TX9h5P3oool001@0oooo8`2BPWP309B3N@@0S6EB1024ETD403`S7@@08Q8=100d6Q@408Y/
F0<0Sf]G102=JUH409E`G0@0TW1L102?JeT407QB?`<0Jddo100n:b04034K5P@0@R8F101J?2l407Xl
:P<0Kc`_101kDD84099_G`@0TW1Q102=I4l408=D@P@0MDTe0`1hCS@405LM3`@0Sf=;1022ES/407iE
@`@0MdTd0`2?GDX407YDA0@0PEU31024FdT4085IAP@0MDlm101eE48307mDA0@0NU@o101Q=2L406dh
9`@0O40c102@NF`308moMB<0TX9h5P3oool001@0oooo8`2BPWP309B3N@@0S6EB1024ETD403`S7@@0
8Q8=100d6Q@408Y/F0<0Sf]G102=JUH409E`G0@0TW1L102?JeT407QB?`<0Jddo100n:b04034K5P@0
@R8F101J?2l407Xl:P<0Kc`_101kDD84099_G`@0TW1Q102=I4l408=D@P@0MDTe0`1hCS@405LM3`@0
Sf=;1022ES/407iE@`@0MdTd0`2?GDX407YDA0@0PEU31024FdT4085IAP@0MDlm101eE48307mDA0@0
NU@o101Q=2L406dh9`@0O40c102@NF`308moMB<0TX9h5P3oool001@0oooo102BQ7X409:5N`@0TX5g
0`2BQG/D09:2N0<0AadD103?VW`408]QCP@0BbTP100T5aT402TE3`@0UfmJ0`2AKeX4099`G0@0SFaH
102DLEd409EcH`@0Qf5?0`25F4P406E7>`@0=BHS100]7AP4044^9P@0GD4f0`1iBcd408YXE0@0TWMW
102BN6T408e]F`@0PeU6101dB3@306]3<`@0F2dO101M>Bl405hl;0@07``:101b?B/30653<P@0E30P
1023ET4407i?<`@0SEY3101hETD407E@?P<0Oe92101]BCP404hZ7P@0GS0S102?Ed@409AlMRH0TX9h
5P3oool001@0oooo102BQ7X409:5N`@0TX5g0`2BQG/D09:2N0<0AadD103?VW`408]QCP@0BbTP100T
5aT402TE3`@0UfmJ0`2AKeX4099`G0@0SFaH102DLEd409EcH`@0Qf5?0`25F4P406E7>`@0=BHS100]
7AP4044^9P@0GD4f0`1iBcd408YXE0@0TWMW102BN6T408e]F`@0PeU6101dB3@306]3<`@0F2dO101M
>Bl405hl;0@07``:101b?B/30653<P@0E30P1023ET4407i?<`@0SEY3101hETD407E@?P<0Oe92101]
BCP404hZ7P@0GS0S102?Ed@409AlMRH0TX9h5P3oool001@0oooo102BQ7X409:5N`@0TX5g0`2BQG/D
09:2N0<0AadD103?VW`408]QCP@0BbTP100T5aT402TE3`@0UfmJ0`2AKeX4099`G0@0SFaH102DLEd4
09EcH`@0Qf5?0`25F4P406E7>`@0=BHS100]7AP4044^9P@0GD4f0`1iBcd408YXE0@0TWMW102BN6T4
08e]F`@0PeU6101dB3@306]3<`@0F2dO101M>Bl405hl;0@07``:101b?B/30653<P@0E30P1023ET44
07i?<`@0SEY3101hETD407E@?P<0Oe92101]BCP404hZ7P@0GS0S102?Ed@409AlMRH0TX9h5P3oool0
01@0oooo102BQ7X409:5N`@0TX5g0`2BQG/D09:2N0<0AadD103?VW`408]QCP@0BbTP100T5aT402TE
3`@0UfmJ0`2AKeX4099`G0@0SFaH102DLEd409EcH`@0Qf5?0`25F4P406E7>`@0=BHS100]7AP4044^
9P@0GD4f0`1iBcd408YXE0@0TWMW102BN6T408e]F`@0PeU6101dB3@306]3<`@0F2dO101M>Bl405hl
;0@07``:101b?B/30653<P@0E30P1023ET4407i?<`@0SEY3101hETD407E@?P<0Oe92101]BCP404hZ
7P@0GS0S102?Ed@409AlMRH0TX9h5P3oool001@0oooo102BOWD409:2N0L0TWme402BPWP404`Y80<0
ABPO100n2`D408A;=P@0>AlP100Y6A8402lI5@@0QfYF0`2=K5P4099`GP@0REi;102?LUT409UlJP@0
SfmM0`29H4`407iB@0@0N50m101eCcd406a3<@@0MU4k0`24FTP408YSD0P0TWET102=IU@408=MB0@0
NTPd0`1bBSD406`m;`@0HdDk101>>C0401D>3P@0?AhD0`1=<BP403TU70@0GSTY101Y@c<407A;=P@0
MDXi101cE48307mD@0@0CR`T1016:A/404XU6@@0QDPe102LVHh309F5Nb<0TX9h5P3oool001@0oooo
102BOWD409:2N0L0TWme402BPWP404`Y80<0ABPO100n2`D408A;=P@0>AlP100Y6A8402lI5@@0QfYF
0`2=K5P4099`GP@0REi;102?LUT409UlJP@0SfmM0`29H4`407iB@0@0N50m101eCcd406a3<@@0MU4k
0`24FTP408YSD0P0TWET102=IU@408=MB0@0NTPd0`1bBSD406`m;`@0HdDk101>>C0401D>3P@0?AhD
0`1=<BP403TU70@0GSTY101Y@c<407A;=P@0MDXi101cE48307mD@0@0CR`T1016:A/404XU6@@0QDPe
102LVHh309F5Nb<0TX9h5P3oool001@0oooo102BOWD409:2N0L0TWme402BPWP404`Y80<0ABPO100n
2`D408A;=P@0>AlP100Y6A8402lI5@@0QfYF0`2=K5P4099`GP@0REi;102?LUT409UlJP@0SfmM0`29
H4`407iB@0@0N50m101eCcd406a3<@@0MU4k0`24FTP408YSD0P0TWET102=IU@408=MB0@0NTPd0`1b
BSD406`m;`@0HdDk101>>C0401D>3P@0?AhD0`1=<BP403TU70@0GSTY101Y@c<407A;=P@0MDXi101c
E48307mD@0@0CR`T1016:A/404XU6@@0QDPe102LVHh309F5Nb<0TX9h5P3oool001@0oooo102BOWD4
09:2N0L0TWme402BPWP404`Y80<0ABPO100n2`D408A;=P@0>AlP100Y6A8402lI5@@0QfYF0`2=K5P4
099`GP@0REi;102?LUT409UlJP@0SfmM0`29H4`407iB@0@0N50m101eCcd406a3<@@0MU4k0`24FTP4
08YSD0P0TWET102=IU@408=MB0@0NTPd0`1bBSD406`m;`@0HdDk101>>C0401D>3P@0?AhD0`1=<BP4
03TU70@0GSTY101Y@c<407A;=P@0MDXi101cE48307mD@0@0CR`T1016:A/404XU6@@0QDPe102LVHh3
09F5Nb<0TX9h5P3oool001@0oooo102BNg84099oMAL0TX9h100e6A@303PQ5`@0<1DA100e7AH401d>
3@@0<1XE100`6A<408Y[EP<0SfmJ102=Ked408aOE0@0NT`l1021ED4409McG0<0S6]E1021EdP407Q4
=0@0O4/d1024CcP408I?=`<0WWMN102DK5P4099`H0@0TWIS102=IUL408=OCP@0NThj0`1gCC@407EB
>0@0PE90101iD404044]:0@08ATH0`0k9Ah403l]9@@0CSP^101U@Rl4079>?`@0PE@n101fD40307EB
?`@0?b@I100e6aD404LT60@0MC<R102IS84V09:2N1H0oooo000D0?ooo`@0TW]b102BOgDG09:2N0@0
=ATD0`0h8AL4030E4@@0=AdF100M3Pd4030J5@@0<1TC102:JeH308m_FP@0SFmM102<Ge@407Y<?0@0
PEE1102GLe`308a[E@@0PEM8101hA3@407a;=0@0Q4lh1026CcL309igGP@0U6aH102BL604099fH`@0
SFIG1023Gdh407Y>>P<0Mddd101eDSP4085B@0@0NE101011;BP4024I60<0>bDN100o;BD404hh;P@0
ID8_101bCSl4085D?P@0MU100`1eDSl403lT6@@0=A/E101791P407Dc8P@0VHb19P2BPWPF0?ooo`00
503oool4099kLP@0TWme5`2BPWP403DI50<0>24G100`5A4403DM5P@07@h=100`6QD4030I4`@0RV]F
0`2?KeX408e_G@@0S5mD101jC3`4085E@@@0Ug=L0`2<JeD4085GB0@0N4@d101lBc@408A?>0@0QTlg
0`2NMeh409A/F0@0TW1P102BMV<408eVE`@0Pem>101jCSX307M==0@0ME8h1021DT0407U@@0@0@BdX
100Q6AP303/U7P@0?bdU101>>2h406E2;`@0LTho1021E3h407I@@0<0ME8o100o91T403DK5@@0Ab@H
101e<b8409V<PBH0TX9h5P3oool001@0oooo102BNg84099oMAL0TX9h100e6A@303PQ5`@0<1DA100e
7AH401d>3@@0<1XE100`6A<408Y[EP<0SfmJ102=Ked408aOE0@0NT`l1021ED4409McG0<0S6]E1021
EdP407Q4=0@0O4/d1024CcP408I?=`<0WWMN102DK5P4099`H0@0TWIS102=IUL408=OCP@0NThj0`1g
CC@407EB>0@0PE90101iD404044]:0@08ATH0`0k9Ah403l]9@@0CSP^101U@Rl4079>?`@0PE@n101f
D40307EB?`@0?b@I100e6aD404LT60@0MC<R102IS84V09:2N1H0oooo000D0?oooal0TX9h100i7A@3
02TB30@09aPA100/5a4402HE40@08AD@100m9Ah408IMBP<0VG9M102?KUX408m^GP@0R6ED101aBCP4
06Pm<@<0I4Pi101]B3P4050e:@@0DcH[101I=BP406U1<P<0M5511028IE@408m^F`@0TV]J102=KE@4
08=LBP@0NT/n0`1Y=b<407=0:@@0R6E31024FDD407mG@`@0Ne920`1XAC@4060k;`@0LdLf101hCS/4
07mB?`@0ME@o1024FD8306e:>@@09aPB100W5a4406<k;P@0E2@I102IPWPV09:2N1H0oooo000D0?oo
oal0TX9h100i7A@302TB30@09aPA100/5a4402HE40@08AD@100m9Ah408IMBP<0VG9M102?KUX408m^
GP@0R6ED101aBCP406Pm<@<0I4Pi101]B3P4050e:@@0DcH[101I=BP406U1<P<0M5511028IE@408m^
F`@0TV]J102=KE@408=LBP@0NT/n0`1Y=b<407=0:@@0R6E31024FDD407mG@`@0Ne920`1XAC@4060k
;`@0LdLf101hCS/407mB?`@0ME@o1024FD8306e:>@@09aPB100W5a4406<k;P@0E2@I102IPWPV09:2
N1H0oooo000D0?oooal0TX9h100i7A@302TB30@09aPA100/5a4402HE40@08AD@100m9Ah408IMBP<0
VG9M102?KUX408m^GP@0R6ED101aBCP406Pm<@<0I4Pi101]B3P4050e:@@0DcH[101I=BP406U1<P<0
M5511028IE@408m^F`@0TV]J102=KE@408=LBP@0NT/n0`1Y=b<407=0:@@0R6E31024FDD407mG@`@0
Ne920`1XAC@4060k;`@0LdLf101hCS/407mB?`@0ME@o1024FD8306e:>@@09aPB100W5a4406<k;P@0
E2@I102IPWPV09:2N1H0oooo000D0?oooal0TX9h100i7A@302TB30@09aPA100/5a4402HE40@08AD@
100m9Ah408IMBP<0VG9M102?KUX408m^GP@0R6ED101aBCP406Pm<@<0I4Pi101]B3P4050e:@@0DcH[
101I=BP406U1<P<0M5511028IE@408m^F`@0TV]J102=KE@408=LBP@0NT/n0`1Y=b<407=0:@@0R6E3
1024FDD407mG@`@0Ne920`1XAC@4060k;`@0LdLf101hCS/407mB?`@0ME@o1024FD8306e:>@@09aPB
100W5a4406<k;P@0E2@I102IPWPV09:2N1H0oooo000D0?ooo`P0TX9h102BPGL309:5Na00TX9h1011
9AX302T@2`@09AD@100Q5A0401D920@0:ALA100i9b0407eHA@<0VW9M102ELeh4099`H0@0TW9R102?
K5X4089GB0L0J40i101b@3<406/m;P@0J3X[101a@C8308ALB`@0TW9R102AK5/409AYG@@0TF=D1025
HDh407aBAP<0HSH]101<91`405D`7`@0FSDR102FG44408eRB`<0PEM0101iE40407EB@0@0OE8m101b
Cch408AFB0@0NE@o0`1>;R0402`I4P@0;20I101V>BT406X`7`@0F48h0`3:`kTS09:2N1H0oooo000D
0?ooo`P0TX9h102BPGL309:5Na00TX9h10119AX302T@2`@09AD@100Q5A0401D920@0:ALA100i9b04
07eHA@<0VW9M102ELeh4099`H0@0TW9R102?K5X4089GB0L0J40i101b@3<406/m;P@0J3X[101a@C83
08ALB`@0TW9R102AK5/409AYG@@0TF=D1025HDh407aBAP<0HSH]101<91`405D`7`@0FSDR102FG444
08eRB`<0PEM0101iE40407EB@0@0OE8m101bCch408AFB0@0NE@o0`1>;R0402`I4P@0;20I101V>BT4
06X`7`@0F48h0`3:`kTS09:2N1H0oooo000D0?ooo`P0TX9h102BPGL309:5Na00TX9h10119AX302T@
2`@09AD@100Q5A0401D920@0:ALA100i9b0407eHA@<0VW9M102ELeh4099`H0@0TW9R102?K5X4089G
B0L0J40i101b@3<406/m;P@0J3X[101a@C8308ALB`@0TW9R102AK5/409AYG@@0TF=D1025HDh407aB
AP<0HSH]101<91`405D`7`@0FSDR102FG44408eRB`<0PEM0101iE40407EB@0@0OE8m101bCch408AF
B0@0NE@o0`1>;R0402`I4P@0;20I101V>BT406X`7`@0F48h0`3:`kTS09:2N1H0oooo000D0?ooo`P0
TX9h1`2BOgD@09:2N0@0?BLO0`0a6aD402HD3P@09QD@100K40/402DD3`@0>RLP101eCcd308e[E`@0
TW1L102BL608099eI0@0TWIW1`2BLf44099aG`@0TWIW102BLEl4099bG`<0Sf]E202?L5l408YXE0@0
SFQD102:J5@408MRD0<0PEU9101P?S<404<W8@@0=B@L10159a/405Lb8@<0ODPe101_CcT407]:<`@0
LdLc1024F4L407=>?@@0ODlo0`0f71D402XG40@0;1/H100m5Ph406<R50@0BS<Z0`2?OgDS09:2N1H0
oooo000D0?ooo`P0TX9h1`2BOgD@09:2N0@0?BLO0`0a6aD402HD3P@09QD@100K40/402DD3`@0>RLP
101eCcd308e[E`@0TW1L102BL608099eI0@0TWIW1`2BLf44099aG`@0TWIW102BLEl4099bG`<0Sf]E
202?L5l408YXE0@0SFQD102:J5@408MRD0<0PEU9101P?S<404<W8@@0=B@L10159a/405Lb8@<0ODPe
101_CcT407]:<`@0LdLc1024F4L407=>?@@0ODlo0`0f71D402XG40@0;1/H100m5Ph406<R50@0BS<Z
0`2?OgDS09:2N1H0oooo000D0?ooo`P0TX9h1`2BOgD@09:2N0@0?BLO0`0a6aD402HD3P@09QD@100K
40/402DD3`@0>RLP101eCcd308e[E`@0TW1L102BL608099eI0@0TWIW1`2BLf44099aG`@0TWIW102B
LEl4099bG`<0Sf]E202?L5l408YXE0@0SFQD102:J5@408MRD0<0PEU9101P?S<404<W8@@0=B@L1015
9a/405Lb8@<0ODPe101_CcT407]:<`@0LdLc1024F4L407=>?@@0ODlo0`0f71D402XG40@0;1/H100m
5Ph406<R50@0BS<Z0`2?OgDS09:2N1H0oooo000D0?ooo`P0TX9h1`2BOgD@09:2N0@0?BLO0`0a6aD4
02HD3P@09QD@100K40/402DD3`@0>RLP101eCcd308e[E`@0TW1L102BL608099eI0@0TWIW1`2BLf44
099aG`@0TWIW102BLEl4099bG`<0Sf]E202?L5l408YXE0@0SFQD102:J5@408MRD0<0PEU9101P?S<4
04<W8@@0=B@L10159a/405Lb8@<0ODPe101_CcT407]:<`@0LdLc1024F4L407=>?@@0ODlo0`0f71D4
02XG40@0;1/H100m5Ph406<R50@0BS<Z0`2?OgDS09:2N1H0oooo000D0?oooal0TX9h1011:R<303/V
80@07a<>100X5A0402DE3`@0:1PF100i9Qh406e9=`<0TVUD102IMV44099`G`@0TW=V102BMfL4099h
J@<0TWeb102BNF`8099fI`P0TWET0`2BLUl4099^E`@0TW1L102=J5@408eUDP@0SF=@102=JeH308eS
E0@0QF5@101mEDP406Q3>0@0B34Y100k9Ql304DZ80@0DSHY101M@38405Xm;`@0Kd8h101mET8407M;
>@<0<aXD100W5A0402<F40@08A4<100j6A<404/_9bH0TX9h5P3oool001@0oooo7`2BPWP4044Z8`<0
>bHP100O4`h402PE40@09AD?100X61H403TV7P@0KDTg0`2BJE@409UfH@@0TW1O102BLfH4099gI`@0
TWQY0`2BOG84099iK0P0TWIW202BMF@3099bG`@0TViG102BL5`408eXE0@0SFEB102=He0408e[EP<0
SF=D1025HE0407eEB0@0J4<h1018<BT403/V7`<0ABXP101B=RT405e0<P@0FSd_101_@SP407eF@P@0
Md/i0`0c6Q@402LE40@08aH@100Q4@`403XI4`@0BblW9P2BPWPF0?ooo`00503ooolO09:2N0@0@BXS
0`0k9R0401lC3P@0:1D@100U5@l402PH5P@0>BHN101]BCL3099YE0@0VGIQ102BL5l4099cIP@0TWMW
102BN6T3099mLP@0TWU/202BMVL8099eI0<0TW9O102BKUL4099`G0@0SFQD102=IE8408eSD0@0SF]F
0`2=He@408EQD0@0OEE8101X@cP404Pa:@@0>bHO0`15:R04058f:@@0GD0b101J?Bl406m2>0@0OEI2
101gBcT303<J50@09aD@100S5Q04024A30@0>QTC101;;bLV09:2N1H0oooo000D0?oooal0TX9h1011
:R<303/V80@07a<>100X5A0402DE3`@0:1PF100i9Qh406e9=`<0TVUD102IMV44099`G`@0TW=V102B
MfL4099hJ@<0TWeb102BNF`8099fI`P0TWET0`2BLUl4099^E`@0TW1L102=J5@408eUDP@0SF=@102=
JeH308eSE0@0QF5@101mEDP406Q3>0@0B34Y100k9Ql304DZ80@0DSHY101M@38405Xm;`@0Kd8h101m
ET8407M;>@<0<aXD100W5A0402<F40@08A4<100j6A<404/_9bH0TX9h5P3oool001@0oooo7`2BPWP4
04@W7@<0?BDK100_7QP402@D3`@0:a4<100^6QD403TS6@@0EcX]0`2?I4d409AdG`@0UG=N102BL604
099eI0@0TWIW0`2BMF@4099mLPP0TWU/202BMF@3099cH@@0TW=S102BKeP408eXE0@0SF]F102=IE84
08eSD0<0SFID1029HE0408EOC0@0OE]8101fDT4406m??`<0H44b101M?2l406Q1<`@0M4ho101fCSl4
07E<?@@0GC`Y0`0e7AH402LE40@0;ATC100N50l402PE40@0?bHK0`2:MW040:JOU1l0TX9h5P3oool0
01@0oooo7`2BPWP404@W7@<0?BDK100_7QP402@D3`@0:a4<100^6QD403TS6@@0EcX]0`2?I4d409Ad
G`@0UG=N102BL604099eI0@0TWIW0`2BMF@4099mLPP0TWU/202BMF@3099cH@@0TW=S102BKeP408eX
E0@0SF]F102=IE8408eSD0<0SFID1029HE0408EOC0@0OE]8101fDT4406m??`<0H44b101M?2l406Q1
<`@0M4ho101fCSl407E<?@@0GC`Y0`0e7AH402LE40@0;ATC100N50l402PE40@0?bHK0`2:MW040:JO
U1l0TX9h5P3oool001@0oooo7`2BPWP404@W7@<0?BDK100_7QP402@D3`@0:a4<100^6QD403TS6@@0
EcX]0`2?I4d409AdG`@0UG=N102BL604099eI0@0TWIW0`2BMF@4099mLPP0TWU/202BMF@3099cH@@0
TW=S102BKeP408eXE0@0SF]F102=IE8408eSD0<0SFID1029HE0408EOC0@0OE]8101fDT4406m??`<0
H44b101M?2l406Q1<`@0M4ho101fCSl407E<?@@0GC`Y0`0e7AH402LE40@0;ATC100N50l402PE40@0
?bHK0`2:MW040:JOU1l0TX9h5P3oool001@0oooo7`2BPWP404@W7@<0?BDK100_7QP402@D3`@0:a4<
100^6QD403TS6@@0EcX]0`2?I4d409AdG`@0UG=N102BL604099eI0@0TWIW0`2BMF@4099mLPP0TWU/
202BMF@3099cH@@0TW=S102BKeP408eXE0@0SF]F102=IE8408eSD0<0SFID1029HE0408EOC0@0OE]8
101fDT4406m??`<0H44b101M?2l406Q1<`@0M4ho101fCSl407E<?@@0GC`Y0`0e7AH402LE40@0;ATC
100N50l402PE40@0?bHK0`2:MW040:JOU1l0TX9h5P3oool001@0oooo7`2BPWP403dS60<0@2XR100_
71H402hI4`@07A0;100[5Q0402`G4@@0CB`O0`1cBS840:1jIP@0TW=N102BL604099eI0@0TWU/0`2B
MVL4099eI0@0TWeb202BN6T4099eI0<0TW1L102BL5l4095[F@@0TFQD102=He0408eYE0@0SFIB0`2=
He0408UOC0P0Qe]81021FTP407mD@P<0PeU6101lEd@407YB@0P0Oe92101dBCL4048X7P<091@<100^
6QP401lA3`@0818<100E2@P403LM5@<0Ke57102OTX/O09:2N1H0oooo000D0?oooal0TX9h100m8aP3
040Z8P@0;a`F100^6A<401d@2`@0:aH@100/5a4404d/7`<0LdXb102PNVH4099cGP@0TW1P102BMF@4
099iK0<0TWIW102BMF@4099mLPP0TWQY102BMF@3099`G0@0TW1O102AJeT4095XE0@0SF=@102=JE@4
08eVDP<0SF=@1029Gd`808MKB0@0PEY8101oE48308=IAP@0O5M4101jDT0807mB@P@0M4Tg1012:1h3
02@D30@0;QXH100O4@l4020B30@05@T8100g7AD306mAA`@0Wi:;7`2BPWPF0?ooo`00503ooolO09:2
N0@0?B<H0`10:R8402lL5P@0;QTC100M40/402/F40@0;1LA101=;1l307=:<P@0X7YV102BLeh4099`
H0@0TWET102BNF`3099fI`@0TWET102BOG88099hJ@@0TWET0`2BL5`4099`G`@0TF]I102AJ5@408eS
D0@0SFUD102=IU8308eSD0@0REm<2027FdP4085JB0@0OeA20`23FDH407aGA0@0NU90201oDT8407A9
=`@0@RPN0`0T50`402hJ60@07a4?100P4P`401D920@0=adE0`1_DDL409nBRal0TX9h5P3oool001@0
oooo7`2BPWP403dS60<0@2XR100_71H402hI4`@07A0;100[5Q0402`G4@@0CB`O0`1cBS840:1jIP@0
TW=N102BL604099eI0@0TWU/0`2BMVL4099eI0@0TWeb202BN6T4099eI0<0TW1L102BL5l4095[F@@0
TFQD102=He0408eYE0@0SFIB0`2=He0408UOC0P0Qe]81021FTP407mD@P<0PeU6101lEd@407YB@0P0
Oe92101dBCL4048X7P<091@<100^6QP401lA3`@0818<100E2@P403LM5@<0Ke57102OTX/O09:2N1H0
oooo000D0?oooal0TX9h10119Q/303TW80@0>BDO100^6aH402`G4P@08a@?100^71H403hX80<0EcDV
102EITh409UgH@P0TW=S102BNf`3099mLPP0TWIW302BMF@3099`GP@0TFmH102AJeH808eVDP@0SF=@
102<He0308mQCP@0S65>2023FdP408=MBP@0PE]80`1oE484085GA0@0ME90101iDT04071??@@0FSX/
100f7AH302dM5`@060`;100O4Q4401@820@07A4?100W5@l305m4>`@0VHEk7`2BPWPF0?ooo`00503o
oolO09:2N0@0@BHK0`0i9b0403TU7`@0;Q/F100/5a8402<D3`@0;Q`F100n:20305Le9P@0UFI>102I
Mf48099cH`@0TW]/0`2BOG88099fI``0TWET0`2BL5h4095_F0@0TF]F202=IU8408eSD0@0S6=@0`2?
HDh408aQCPP0Pe]81023GDX4085KB0<0OeA21021Ed@407EB@0@0NE90101`Ccd405Xj;0@0=QdF0`0]
7AL401P<2`@07a8A100D20P401dA3`@09aD?0`1OA3/409V5Nal0TX9h5P3oool001@0oooo7`2BPWP4
044V6`<0>BLP100i9Al402hK5P@0;1LB100S50l402hL5P@0?RPP0`1G=BH409EVCP@0VGMQ202BLf<4
099kK0<0TWeb202BMVL<099eI0<0TW1N102AKeP4095[EPP0SFIB102=He0408aSD0<0Sf5>102<HDh8
08=KB0@0Pee:1021FdP307mD@P@0PEM4101eDT0407UB@0@0L4lm101J>R`403HM5P<0;AdG100H30/4
01lB4@@050P8100M4@l402LE3`<0Gd@k102IQG/O09:2N1H0oooo000D0?oooal0TX9h10119Q/303TW
80@0>BDO100^6aH402`G4P@08a@?100^71H403hX80<0EcDV102EITh409UgH@P0TW=S102BNf`3099m
LPP0TWIW302BMF@3099`GP@0TFmH102AJeH808eVDP@0SF=@102<He0308mQCP@0S65>2023FdP408=M
BP@0PE]80`1oE484085GA0@0ME90101iDT04071??@@0FSX/100f7AH302dM5`@060`;100O4Q4401@8
20@07A4?100W5@l305m4>`@0VHEk7`2BPWPF0?ooo`00503ooolO09:2N0@0@2XR0`0o:B4403`Y8P@0
=R@M100^61<401hA30@0<Q/E1012:1h305@h:P@0Mdlk102GMF4409EcH@@0TW1S102BLf<3099kK0@0
TWeb102BNF`4099fI`@0TW5O102BMF@3099`H0@0SfiJ102:IE8408aSD0@0Sf5>102AI5<408UTCP<0
REm<1029Gdh408=MB0@0Pe]81023FDH4085KA`<0PEU6101mDSl407aFA0@0MDdk101[ACH4050]80@0
<a/E0`0O4P`401lB40@060`;100L40/401/@3`@0;QTC0`1UCT@406]AAal0TX9h5P3oool001@0oooo
7`2BPWP4040Z8P<0?bTQ100l:B8403HT7@@0;QPC100N4@`4038K5@@0@RPN0`1D>2X407M?>`@0UgEQ
102ELf44099`H`@0TW=S0`2BNf`4099mLP@0TWU/102BMVL4099aG`@0TWET0`2BL60408m^FP@0RVEB
102<He0408mQCP@0TFAC1029I4h308UOC0@0REm>1023GDP408=KB0@0PeU61021FdL3085IAP@0OE8o
101lET@407E=>`@0JdDf101@;B0403<K5@<07a8<100O4Q0401P<2`@0710;100K40l402hI4`<0IDi4
101[DDLO09:2N1H0oooo000D0?oooal0TX9h1010:R8303lY8@@0?2TR100f91d402hH4`@07Q4<100b
6aD4048X7P<0E3PZ101gCc/409MeH@@0UG=Q102BL6<4099cH`<0TW]/102BOG84099iK0@0TWIW102B
LEl4099eI0<0TW1P102?KUX408YUDP@0S6=@102?HDh4095TD`@0RFA>0`29Gd`408UOCP@0Pee81023
FdP408=IAP@0PE]70`21FDH407eB?`@0O5I4101eCC/406]5=P@0D2dP100c6aD301lB30@07a8@100H
30/401`@2`@06a0?100^6A<306E>A0@0Je577`2BPWPF0?ooo`00503ooolG09:2N0@0TX5g102APWT4
03dY8P<0?BPQ1010;2D403XW80@0:1H@100^71H402`K5@@0>B8K0`1R>BP407Q9=P@0SfI@102ELeh4
099`H0L0TW9R302BNF`8099eI0<0TFmM102ELEl408eXE0@0RVIB1027HDh408UMC0@0S5m>0`29FdP4
08MMC0@0QeU81021ETH408AKAP@0PEM40`1oEd@407a@?P@0N50n101eAcD406@n;P@0>b<I100b6Q@3
024E3`@081@?100O4`l401/@2`@08AD@100_6A@309B3N@@0Sgme7`2BPWPF0?ooo`00503ooolG09:2
N0@0TX5g102APWT403dY8P<0?BPQ1010;2D403XW80@0:1H@100^71H402`K5@@0>B8K0`1R>BP407Q9
=P@0SfI@102ELeh4099`H0L0TW9R302BNF`8099eI0<0TFmM102ELEl408eXE0@0RVIB1027HDh408UM
C0@0S5m>0`29FdP408MMC0@0QeU81021ETH408AKAP@0PEM40`1oEd@407a@?P@0N50n101eAcD406@n
;P@0>b<I100b6Q@3024E3`@081@?100O4`l401/@2`@08AD@100_6A@309B3N@@0Sgme7`2BPWPF0?oo
o`00503ooolG09:2N0@0TX5g102APWT403dY8P<0?BPQ1010;2D403XW80@0:1H@100^71H402`K5@@0
>B8K0`1R>BP407Q9=P@0SfI@102ELeh4099`H0L0TW9R302BNF`8099eI0<0TFmM102ELEl408eXE0@0
RVIB1027HDh408UMC0@0S5m>0`29FdP408MMC0@0QeU81021ETH408AKAP@0PEM40`1oEd@407a@?P@0
N50n101eAcD406@n;P@0>b<I100b6Q@3024E3`@081@?100O4`l401/@2`@08AD@100_6A@309B3N@@0
Sgme7`2BPWPF0?ooo`00503ooolG09:2N0@0TX5g102APWT403dY8P<0?BPQ1010;2D403XW80@0:1H@
100^71H402`K5@@0>B8K0`1R>BP407Q9=P@0SfI@102ELeh4099`H0L0TW9R302BNF`8099eI0<0TFmM
102ELEl408eXE0@0RVIB1027HDh408UMC0@0S5m>0`29FdP408MMC0@0QeU81021ETH408AKAP@0PEM4
0`1oEd@407a@?P@0N50n101eAcD406@n;P@0>b<I100b6Q@3024E3`@081@?100O4`l401/@2`@08AD@
100_6A@309B3N@@0Sgme7`2BPWPF0?ooo`00503ooolG09:2N0@0TWme102?N6l403DQ6`<0@bLM100i
9b8403l[90@0=28L100/6aD403@Q6`@0>24G0`1D>bl406ho;@@0TVA?102DMf4409EcH`@0TW=S0`2B
MfL4099hJ@P0TW]^102BMVP4095dH@<0TG1M102AKeX4095SD0@0S65<102?I58408aQC0@0REm>0`29
GDX408=KB0@0Pee:1021E4@407aDA0@0OeA20`1oET<407YD@P@0MDdk101Z@S04050]90@0>AhF100U
5a0301lB30@07Q8@100I3@`400l920@06`d<10119Qh308QkLP@0UHEk7`2BPWPF0?ooo`00503ooolG
09:2N0@0TWme102?N6l403DQ6`<0@bLM100i9b8403l[90@0=28L100/6aD403@Q6`@0>24G0`1D>bl4
06ho;@@0TVA?102DMf4409EcH`@0TW=S0`2BMfL4099hJ@P0TW]^102BMVP4095dH@<0TG1M102AKeX4
095SD0@0S65<102?I58408aQC0@0REm>0`29GDX408=KB0@0Pee:1021E4@407aDA0@0OeA20`1oET<4
07YD@P@0MDdk101Z@S04050]90@0>AhF100U5a0301lB30@07Q8@100I3@`400l920@06`d<10119Qh3
08QkLP@0UHEk7`2BPWPF0?ooo`00503ooolG09:2N0@0TWme102?N6l403DQ6`<0@bLM100i9b8403l[
90@0=28L100/6aD403@Q6`@0>24G0`1D>bl406ho;@@0TVA?102DMf4409EcH`@0TW=S0`2BMfL4099h
J@P0TW]^102BMVP4095dH@<0TG1M102AKeX4095SD0@0S65<102?I58408aQC0@0REm>0`29GDX408=K
B0@0Pee:1021E4@407aDA0@0OeA20`1oET<407YD@P@0MDdk101Z@S04050]90@0>AhF100U5a0301lB
30@07Q8@100I3@`400l920@06`d<10119Qh308QkLP@0UHEk7`2BPWPF0?ooo`00503ooolG09:2N0@0
TWme102?N6l403DQ6`<0@bLM100i9b8403l[90@0=28L100/6aD403@Q6`@0>24G0`1D>bl406ho;@@0
TVA?102DMf4409EcH`@0TW=S0`2BMfL4099hJ@P0TW]^102BMVP4095dH@<0TG1M102AKeX4095SD0@0
S65<102?I58408aQC0@0REm>0`29GDX408=KB0@0Pee:1021E4@407aDA0@0OeA20`1oET<407YD@P@0
MDdk101Z@S04050]90@0>AhF100U5a0301lB30@07Q8@100I3@`400l920@06`d<10119Qh308QkLP@0
UHEk7`2BPWPF0?ooo`00503ooolO09:2N0@0?bTR0`0i8AL4040[90@0?RXS100f8a`4034K5@@0>B<I
100i9Ql304`e:0@0F34T1027ET0409MdG`@0TW1O102BL643099cIP@0TWIS202BMVH4099cIP@0SfiJ
0`2:IE8408eXE0@0S6A?102<HD`408UOC0@0RF5:1029GdX308UKA`@0Pem<2023FDH407mGA0@0Oe90
0`1mCcd4079??0@0JT@a101@;RD404DX6`@0:QHA100S5Q0302DE3`@06a0?100H30/401L<2`@0:ALB
101=<R`305/j<B<0TX9h5P3oool001@0oooo7`2BPWP403lY8P<0>B4G1010:b@403hZ8`@0=R<L100a
6aD403TS6@@0>BHO0`1<=BP405Pa90@0QeI0102GM5l4099`G`@0TW1Q0`2BLfH4099fH`P0TWIV102B
LfH408m^FP<0RVEB102=J5@408aTC`@0S65<1029Gd`408UQBP@0REm:0`29FdL408=OC0P0PeU6101o
Ed@407mB@0<0ODlm101bCc`406Y4<@@0D2hU1015:1/402XF4@@08aH@0`0U5@l401/@3`@060`;100G
30/402TG4P@0CC8/0`1K>S4S09:2N1H0oooo000D0?oooal0TX9h100o:B8303TQ5`@0@2/T100n:R<4
03HS70@0<A/E100i8aT403TV7`<0C3DX101H<B@408MF@0@0UgAO102BL5l4099`H@<0TW=V102BMV<8
099fIP@0TW=V102?KUX308YUDP@0SFQD102<I4l408aQC0@0REm<1029HDX408UOBP<0RE]71023Gd`8
08=IAP@0OeM4101oDT0307e??@@0LTll101ZA344050^9@@0ABPK100Z5Q4402<F40<09AD?100K40l4
01P<2`@05``;100Y5a8404db;0<0FcXa8`2BPWPF0?ooo`00503ooolO09:2N0@0?bTR0`0i8AL4040[
90@0?RXS100f8a`4034K5@@0>B<I100i9Ql304`e:0@0F34T1027ET0409MdG`@0TW1O102BL643099c
IP@0TWIS202BMVH4099cIP@0SfiJ0`2:IE8408eXE0@0S6A?102<HD`408UOC0@0RF5:1029GdX308UK
A`@0Pem<2023FDH407mGA0@0Oe900`1mCcd4079??0@0JT@a101@;RD404DX6`@0:QHA100S5Q0302DE
3`@06a0?100H30/401L<2`@0:ALB101=<R`305/j<B<0TX9h5P3oool001@0oooo7`2BPWP404df;`<0
=R8K100l9al404@/9@@0>28H100c8A/4034M5P@0?BPP0`0j9Qh404T_9P@0LD4^102BJ4l409YlJ0@0
U75M0`2ELf44099`G`@0TW1L102AKeX409AaG`@0UG=Q0`2=IU8408aRCP@0S65<1027EdH808YMC0@0
S5m<1`27FDH408=FAP@0PEU41021Ed8407e??`<0NTlm101[AcD405L`8`@0@RLK100/5a44024C30@0
7a8@0`0X5Q0401dA40@050P8100H30`4030I50L0UHEk8`2BPWPF0?ooo`00503ooolO09:2N0@0CCH_
0`0f8Q/403`W7`@0A2`U100h8QP403<Q6`@0<AdF100m:20303XV7P@0BBlV101a@Bh4099XC`@0VWaX
102DLEd309EcH@@0TW1O102BL5`4095_FP@0U75O102ELf4308eVDP@0S69>102<HD`408MGAPP0RUe<
102<Gd`708MIAP@0PeI61021FD@4085G@P@0ODlo0`1jCcd406]7=@@0Ec0S10129a/402`G4@@08A<<
100O4Q0302PF40@07A4@100D20P401P<30@0<1TD1`2EQG/S09:2N1H0oooo000D0?oooal0TX9h101=
=Rl303HR6`@0?2LO1014;2D403PR60@0<b4K100a7AH403dX80<0>RHN1019;bH40751;P@0TVQ?102J
O6P409AaG@<0UG=Q102BL5l4099`G0@0TFmJ102DLEl409EcH@<0SFIB102<HTh408aQC0@0QeM6202:
GD`408aOC0L0QeU61023ETH4085IA0@0PEM2101mCcl307Y??@@0JdLe101G<2<4048W6`@0;1LA100Q
4``401lB40<0:1H@100M4A0401@820@060`<100`6A@709F5Nb<0TX9h5P3oool001@0oooo7`2BPWP4
04df;`<0=R8K100l9al404@/9@@0>28H100c8A/4034M5P@0?BPP0`0j9Qh404T_9P@0LD4^102BJ4l4
09YlJ0@0U75M0`2ELf44099`G`@0TW1L102AKeX409AaG`@0UG=Q0`2=IU8408aRCP@0S65<1027EdH8
08YMC0@0S5m<1`27FDH408=FAP@0PEU41021Ed8407e??`<0NTlm101[AcD405L`8`@0@RLK100/5a44
024C30@07a8@0`0X5Q0401dA40@050P8100H30`4030I50L0UHEk8`2BPWPF0?ooo`00503ooolO09:2
N0@0Dc`a0`0n:R@403`Y8P@0?2LP100m9al402dJ5`@0<QlH100f8a`303hZ8`@0>B8H101>;B0407mE
?@@0UFYB102ELU`309AeG`@0U79M102DM5l4095_FP@0SF]F102AL5/308mXE0@0REU6102:GDL408MK
AP@0PeI31023GDT408MKA`<0QeU61021E48408AD@`@0Oe90101mET4407M?>`<0LD@a101Y@Rl4048W
6`@0;QPA100U5a0401dA2`@060d<0`0J3@`4010920@03`P8100/5a<4034K4`@0S7mh9P2BPWPF0?oo
o`00503ooolO09:2N0@0Dc`a0`0n:R@403`Y8P@0?2LP100m9al402dJ5`@0<QlH100f8a`303hZ8`@0
>B8H101>;B0407mE?@@0UFYB102ELU`309AeG`@0U79M102DM5l4095_FP@0SF]F102AL5/308mXE0@0
REU6102:GDL408MKAP@0PeI31023GDT408MKA`<0QeU61021E48408AD@`@0Oe90101mET4407M?>`<0
LD@a101Y@Rl4048W6`@0;QPA100U5a0401dA2`@060d<0`0J3@`4010920@03`P8100/5a<4034K4`@0
S7mh9P2BPWPF0?ooo`00503ooolO09:2N0@0Dc`a0`0n:R@403`Y8P@0?2LP100m9al402dJ5`@0<QlH
100f8a`303hZ8`@0>B8H101>;B0407mE?@@0UFYB102ELU`309AeG`@0U79M102DM5l4095_FP@0SF]F
102AL5/308mXE0@0REU6102:GDL408MKAP@0PeI31023GDT408MKA`<0QeU61021E48408AD@`@0Oe90
101mET4407M?>`<0LD@a101Y@Rl4048W6`@0;QPA100U5a0401dA2`@060d<0`0J3@`4010920@03`P8
100/5a<4034K4`@0S7mh9P2BPWPF0?ooo`00503ooolO09:2N0@0Dc`a0`0n:R@403`Y8P@0?2LP100m
9al402dJ5`@0<QlH100f8a`303hZ8`@0>B8H101>;B0407mE?@@0UFYB102ELU`309AeG`@0U79M102D
M5l4095_FP@0SF]F102AL5/308mXE0@0REU6102:GDL408MKAP@0PeI31023GDT408MKA`<0QeU61021
E48408AD@`@0Oe90101mET4407M?>`<0LD@a101Y@Rl4048W6`@0;QPA100U5a0401dA2`@060d<0`0J
3@`4010920@03`P8100/5a<4034K4`@0S7mh9P2BPWPF0?ooo`00503ooolO09:2N0@0I4e30`0f8AT4
03h[90@0>RLP1011;BH403@O5P@0;ATD100l:R<303DR6`@0@B/S100c7QH405Tl;0@0JT<b102AFD43
09]bFP@0SFI@102BL5d408m^F0@0Sf]D102BJeL308MOB`@0O54m1026Dcl408YF?`@0QeQ71024E484
08AA?P<0Q5Y71021E3`407e?@@@0NTdk101eBSP406]:>0<0FS@V101@:A/403PN5P@0:AH@100M4@`4
01T=30@060d;0`0D20P400h820@05``;100W5A0405hl<@@0Fcda9P2BPWPF0?ooo`00503ooolO09:2
N0@0I4e30`0f8AT403h[90@0>RLP1011;BH403@O5P@0;ATD100l:R<303DR6`@0@B/S100c7QH405Tl
;0@0JT<b102AFD4309]bFP@0SFI@102BL5d408m^F0@0Sf]D102BJeL308MOB`@0O54m1026Dcl408YF
?`@0QeQ71024E48408AA?P<0Q5Y71021E3`407e?@@@0NTdk101eBSP406]:>0<0FS@V101@:A/403PN
5P@0:AH@100M4@`401T=30@060d;0`0D20P400h820@05``;100W5A0405hl<@@0Fcda9P2BPWPF0?oo
o`00503ooolO09:2N0@0I4e30`0f8AT403h[90@0>RLP1011;BH403@O5P@0;ATD100l:R<303DR6`@0
@B/S100c7QH405Tl;0@0JT<b102AFD4309]bFP@0SFI@102BL5d408m^F0@0Sf]D102BJeL308MOB`@0
O54m1026Dcl408YF?`@0QeQ71024E48408AA?P<0Q5Y71021E3`407e?@@@0NTdk101eBSP406]:>0<0
FS@V101@:A/403PN5P@0:AH@100M4@`401T=30@060d;0`0D20P400h820@05``;100W5A0405hl<@@0
Fcda9P2BPWPF0?ooo`00503ooolO09:2N0@0I4e30`0f8AT403h[90@0>RLP1011;BH403@O5P@0;ATD
100l:R<303DR6`@0@B/S100c7QH405Tl;0@0JT<b102AFD4309]bFP@0SFI@102BL5d408m^F0@0Sf]D
102BJeL308MOB`@0O54m1026Dcl408YF?`@0QeQ71024E48408AA?P<0Q5Y71021E3`407e?@@@0NTdk
101eBSP406]:>0<0FS@V101@:A/403PN5P@0:AH@100M4@`401T=30@060d;0`0D20P400h820@05``;
100W5A0405hl<@@0Fcda9P2BPWPF0?ooo`00503ooolO09:2N0@0PV]V0`12:R<403DQ70@0?BPR100m
:24403DT70@0;QTF100m91T303XW8@@0@BdV100i9R0403XW7`@0Bc@Z101P>BX307M7<P@0Me94101d
DSl408IE?`@0Qf5<1025GTP307M>?P@0LDD`101W?BX407M7;`@0P4Pe1021Dc/408E?>`<0NTXi101i
B38407i:=0@0MdXg101Y@S@4064h:0<0CRTL100l7AH402/G40@07a8<100I3@`401@820L03`P8100>
20L4020D3`@0;1LC1029N6l408mkLRH0TX9h5P3oool001@0oooo7`2BPWP4089[IP<0@RXS100e8A`4
03dX8P@0?BPQ100e91`402hI5P@0?B@I0`0j9b44044]9P@0>BHP100j9al404/d:P@0H3TZ0`1gAc84
07MBA0@0M58o1026ECl408MQC0@0QEi80`1gCSh40755<0@0IcdZ101gAbl40818=@@0PE<k1025Cc/3
07Y:>@@0NDPb101nBS@407M:=`@0JD8d101Q>2P304hY70@0?1dF100[5a0401lB30@06@d<100D20P7
00l820@03PP7100P50l402`G4`@0RGQ_102?Ng8V09:2N1H0oooo000D0?oooal0TX9h1022JfH3048Z
8`@0=B4L100m:28403dX8@@0=B@L100^6AH403dT6@<0>RLQ1011;BH403TV80@0>RLO101;=2X4060i
:P<0MdLb101gDT@407AB?`@0QUDo1027HD`408ENB0<0Mdhn101aAC0406Lm:P@0MdL_1020B3D4085C
>`@0QDlk0`1jBST407U8<P@0OTXd101gBSL406U2=0@0HCPX0`1>:A`403`M5P@0:aL@100O4P`401T=
30@050P81`0?20P400h81`@081@?100/5a<408UhK`@0Sg]b9P2BPWPF0?ooo`00503ooolS09:2N0<0
FdHm100b81L403`Y8P@0>BTR100h9Ah4024E40@0>B<L0`13;BD4044]9P@0AC4Y1011;BH404Da9`@0
C3@Y0`1A=2L4050`9`@0CRlR101B<2H406<h9`@0Id<b0`1C=2X405<b9`@0FS0Q101H<Ah405lc9@P0
LD8]0`1]?RX406/o;@@0H3@S101U?2d405`b9@@0CB`P0`0h71D403HN5`@07a4;100N4@`401P<2`@0
4`P71`0>20L4028C3`@06Q0?101?=bh406iNERX0TX9h5P3oool001@0oooo8`2BPWP305]6?@@0<R0G
100l:B8403TY8P@0>2DN100Q5A0403TS70<0@bdU1011;BH404Da:@@0@BdV1015<BL404`d:@<0DC@W
101@<2L404h_8P@0DS0V101S>2L406M3<P<0Dc@Z101C<RL405X`8@@0F34N101O<bD80752;@<0KChZ
101[?bd4060d8`@0IC`]101L<RD404d/80<0>1`E100f7QL401lA2`@07Q4<100H30/401<81`L03PP7
100R4`l401X@3`@0CcL^101^GUHZ09:2N1H0oooo000D0?ooob<0TX9h0`1KASd4038P5`@0?2TR100i
:B8403PU7P@08AD@100i8a`304<]9@@0@BdV1015<BT4044]9P@0AC4W101<=2T3054d9`@0D30W101>
;b84058`9P@0HcPW101W@c8305<d:P@0Dc8W101J<24405Pa7P@0Gc<U201a@Rd306dn:P@0Jcl]101P
=2<406Dl;@@0G38U101=;20303PL5@@0=QhG100O4@/401hA30@060`;100C20L700h81`@08Q<?100J
40l404lg;P@0KUiF:P2BPWPF0?ooo`00503ooolS09:2N0<0FdHm100b81L403`Y8P@0>BTR100h9Ah4
024E40@0>B<L0`13;BD4044]9P@0AC4Y1011;BH404Da9`@0C3@Y0`1A=2L4050`9`@0CRlR101B<2H4
06<h9`@0Id<b0`1C=2X405<b9`@0FS0Q101H<Ah405lc9@P0LD8]0`1]?RX406/o;@@0H3@S101U?2d4
05`b9@@0CB`P0`0h71D403HN5`@07a4;100N4@`401P<2`@04`P71`0>20L4028C3`@06Q0?101?=bh4
06iNERX0TX9h5P3oool001@0oooo8`2BPWP307=MF@@0=R4K100i9b0403`X8@@0>RLQ100d8ad403DT
7P<0@BdV1017<RX4040/9@@0ABlW101:;2@4058b9@<0AB`P100n:R<403LP6@@0@RTQ100i71D404T]
90<0@bXR100k9Ah403XM5P@0?B<J100m7QH404HQ60@0CRdM1`1;:Q`404@P5`@0@b4H100m81P403/N
5P<09aLA100Q4``401/=30@06@d;100H3@/800h81`<08Q<E100R4`h4038R7@@0HDM1101eEddZ09:2
N1H0oooo000D0?ooob<0TX9h0`1cGET403HQ6`@0>BLP100l:24403XW8@@0=2<M100e91h3044]9P@0
Ac8Z1010;2D404D_9`@0BR`T101B<RD304D/80@0?RXS100g81T4048Y8@@0>A`E1019;B@304<Z8P@0
>bDN100j7AH403dS6P@0?AhF10168AP404h]7@L0BbXL101481L404<Q60@0?B0H100k7QH302LG4@@0
8A<<100K3@`401T=2`@060d;200>20L3028C5@@08Q<>100b8Qd40657@@@0MEM=:P2BPWPF0?ooo`00
503ooolS09:2N0<0LeeI100f8A/403TW80@0?2PQ100j9b4403@S7@@0=B@N0`11;BH404Lb:P@0@2`U
1015;bL404X/90@0DS8U0`15;20403hZ8`@0=b0I1012:B4403TL5@@0BBdT0`13:R8403/U7P@0>QdF
100m8aX403dN5P@0AR4H101>;Ad704/Z70@0A20G10138AP403dP60@0>ahF0`0W5a44024C30@06`d<
100I3@/401P=2`P03PP70`0R4aD4028C3P@0<R8M101QAd4407EGCBX0TX9h5P3oool001@0oooo8`2B
PWP307=MF@@0=R4K100i9b0403`X8@@0>RLQ100d8ad403DT7P<0@BdV1017<RX4040/9@@0ABlW101:
;2@4058b9@<0AB`P100n:R<403LP6@@0@RTQ100i71D404T]90<0@bXR100k9Ah403XM5P@0?B<J100m
7QH404HQ60@0CRdM1`1;:Q`404@P5`@0@b4H100m81P403/N5P<09aLA100Q4``401/=30@06@d;100H
3@/800h81`<08Q<E100R4`h4038R7@@0HDM1101eEddZ09:2N1H0oooo000D0?ooob<0TX9h0`2<N784
05<j=@@0<1dG100j9b0403hZ8`@0>BHO1015<BT303HS70@0BS@/100i9Ah4048]9P@0BS0V10109b43
044W7P@0?BLO100d8A/403lY8P@0:aTF100c8a`303DL5P@0<adF100Y5a4402DG4@@0:aLA100c6Q@4
03<K50<0;1PA100^614402dG4@@0=1XD100Y5Q0402XF40<07Q8<100M4@`801P<2`P03PP8100G30/3
02`K5`@0;1LC101A>S4405Pm=2h0TX9h5P3oool001@0oooo8`2BPWP308ahLP@0DcXe100`7AL403XW
80@0?RXS100i9Ql404Da:@<0=R<L101:=2`403TU7P@0@RdV101:<2H4040W8@<0@BLN100m9al403@Q
6`@0?bTR100[6AH403<S70<0=A`F100c7AH402TG4@@09ALA100[5a4403<J50@0<a/D0`0/614402hH
4@@0;ALA100d6Q@402TF40@0:QH@0`0N4P`401dA30P060`;200>20P401L<2`<0;1/G100/5a<4054j
<@@0F3dd;P2BPWPF0?ooo`00503ooolS09:2N0<0S7Qb101C>SD4030M5`@0>RLP100n:R<403TV7`@0
AC4Y0`0f8a`404Xd;0@0>BDN1012;BH404X`9P@0@2LQ0`119ah403dW7`@0=24K100o:B8402/I5P@0
<b<L0`0e71H403<M5P@0:ALA100U5a4402/G4@@0<aXD100c6a@302`H4@@0;QPA100]5a4403@J50@0
:AH@100Z5Q0301hB30@07A4<200H30/800h820@05``;0`0/6aL402`G4`@0DCXa101H?C@^09:2N1H0
oooo000D0?ooob<0TX9h0`2<N78405<j=@@0<1dG100j9b0403hZ8`@0>BHO1015<BT303HS70@0BS@/
100i9Ah4048]9P@0BS0V10109b43044W7P@0?BLO100d8A/403lY8P@0:aTF100c8a`303DL5P@0<adF
100Y5a4402DG4@@0:aLA100c6Q@403<K50<0;1PA100^614402dG4@@0=1XD100Y5Q0402XF40<07Q8<
100M4@`801P<2`P03PP8100G30/302`K5`@0;1LC101A>S4405Pm=2h0TX9h5P3oool001@0oooo9P2B
PWP407EOF0@0>B8K100k:R<403hZ8`@0>RLP100f9Qh304L`:@@0@RhW100h9b4403HR6`@0BR/O100f
8Q/303XV7P@0>2@M100Z6a`403PV7@@0;a/I100`6aD302PG60@09AH@100T5Q0401hA30@08aH@100T
5Q0402HF40<0818<100K3@`4020B30@0:QHA100O4P`401/=30<07a8<100M4@l401P<2`@03PP8100H
30/401dC3P@09QPD0`0[5a<4054g;P@0DC<[<P2BPWPF0?ooo`00503ooolV09:2N0@0MEmH100i8Q/4
03/Z8`@0?RXS100j9b0403HV7P<0Ac0Y1012;RL403PW8@@0=R8K101::al403HR6`<0>RHN100h91d4
02XK70@0>2HM100_6aT4030K5@<0:1LH100U5Q0402@F40@07Q4<100S5Q0402@F40@09QH@0`0P4P`4
01/=30@0818<100Z5Q4401lB30@06`d<0`0O4P`401dA3`@060`;100>20P401P<2`@07A<>100V61@3
02/G4`@0DCL^101A<b/b09:2N1H0oooo000D0?ooobH0TX9h101eGeP403TR6`@0>bXS100n:R<403XW
80@0=RHN0`17<2T4048^9`@0>2LQ100f8Q/404X[7`@0=R8K0`0j9Qh403PT7@@0:Q/L100h9Qd402lK
6@@0<1/E0`0X5aP402DF40@091H@100N4@`402<F40@091H@100V5Q03020B30@06`d<100P4P`402XF
4@@07a8<100K3@`301lB30@07A4?100H30/400h820@060`;100M4`h402HH50<0:aLC101A=bh4054c
:c80TX9h5P3oool001@0oooo9P2BPWP407EOF0@0>B8K100k:R<403hZ8`@0>RLP100f9Qh304L`:@@0
@RhW100h9b4403HR6`@0BR/O100f8Q/303XV7P@0>2@M100Z6a`403PV7@@0;a/I100`6aD302PG60@0
9AH@100T5Q0401hA30@08aH@100T5Q0402HF40<0818<100K3@`4020B30@0:QHA100O4P`401/=30<0
7a8<100M4@l401P<2`@03PP8100H30/401dC3P@09QPD0`0[5a<4054g;P@0DC<[<P2BPWPF0?ooo`00
503ooolV09:2N0@0R79/101:;bT403HR70@0@2`U100j9b0403/Y8P<0>BXS1015;RH403TV7P@0<R0I
100f81T402`G4@<0=b@M100]6aP402`K6@@0:1LA100Y5aT4020B40<070d<100O4Q4401hB40@06@d;
100N4Q0401T=30@07Q8@0`0I3@/401dA3`@081@?100M4@l401T=2`@03`P80`0?2@P4010920@03`T8
100L40l401X@2`@060`<100Z4``305Po=`@0E3Xa=P2BPWPF0?ooo`00503ooolV09:2N0@0R79/101:
;bT403HR70@0@2`U100j9b0403/Y8P<0>BXS1015;RH403TV7P@0<R0I100f81T402`G4@<0=b@M100]
6aP402`K6@@0:1LA100Y5aT4020B40<070d<100O4Q4401hB40@06@d;100N4Q0401T=30@07Q8@0`0I
3@/401dA3`@081@?100M4@l401T=2`@03`P80`0?2@P4010920@03`T8100L40l401X@2`@060`<100Z
4``305Po=`@0E3Xa=P2BPWPF0?ooo`00503ooolV09:2N0@0R79/101:;bT403HR70@0@2`U100j9b04
03/Y8P<0>BXS1015;RH403TV7P@0<R0I100f81T402`G4@<0=b@M100]6aP402`K6@@0:1LA100Y5aT4
020B40<070d<100O4Q4401hB40@06@d;100N4Q0401T=30@07Q8@0`0I3@/401dA3`@081@?100M4@l4
01T=2`@03`P80`0?2@P4010920@03`T8100L40l401X@2`@060`<100Z4``305Po=`@0E3Xa=P2BPWPF
0?ooo`00503ooolV09:2N0@0R79/101:;bT403HR70@0@2`U100j9b0403/Y8P<0>BXS1015;RH403TV
7P@0<R0I100f81T402`G4@<0=b@M100]6aP402`K6@@0:1LA100Y5aT4020B40<070d<100O4Q4401hB
40@06@d;100N4Q0401T=30@07Q8@0`0I3@/401dA3`@081@?100M4@l401T=2`@03`P80`0?2@P40109
20@03`T8100L40l401X@2`@060`<100Z4``305Po=`@0E3Xa=P2BPWPF0?ooo`00503ooolZ09:2N0@0
Je57100d7QP4030O6@@0?BPR1`0l:b@4048^9`@0>2DQ100_6A<4030N60@08QD@0`0Z5a4402DG4P@0
:AHA100J3@`401/=30@07a8A0`0L40l401P<2`@07A4@100H30/401dA40@060`;100/61<300d81`@0
7Q4@100Q5A0401dA40P03PP80`0C20L401X@3`@06@l>100K40l402`H4`@0;1`D100h9Al306QKFP@0
Sg]b=P2BPWPF0?ooo`00503ooolZ09:2N0@0Je57100d7QP4030O6@@0?BPR1`0l:b@4048^9`@0>2DQ
100_6A<4030N60@08QD@0`0Z5a4402DG4P@0:AHA100J3@`401/=30@07a8A0`0L40l401P<2`@07A4@
100H30/401dA40@060`;100/61<300d81`@07Q4@100Q5A0401dA40P03PP80`0C20L401X@3`@06@l>
100K40l402`H4`@0;1`D100h9Al306QKFP@0Sg]b=P2BPWPF0?ooo`00503ooolZ09:2N0@0Je57100d
7QP4030O6@@0?BPR1`0l:b@4048^9`@0>2DQ100_6A<4030N60@08QD@0`0Z5a4402DG4P@0:AHA100J
3@`401/=30@07a8A0`0L40l401P<2`@07A4@100H30/401dA40@060`;100/61<300d81`@07Q4@100Q
5A0401dA40P03PP80`0C20L401X@3`@06@l>100K40l402`H4`@0;1`D100h9Al306QKFP@0Sg]b=P2B
PWPF0?ooo`00503oool^09:2N0@0Je57100b71H4034S7@@0=R<L0`13<2T4044^9`@0@BdW100^7aT4
03@P6@@09ADF0`0M4@l402PF40@07A4@100Q5@l401hC3`@06a0?4`0H3@`4024E40@07Q4@0`0`92D4
02HL5`@08A8C100H3@/401/@3`L0718>100K40l402lO6@@09QPE100/5a<404T/8@@0HT@d0`1bCSdj
09:2N1H0oooo000D0?ooobh0TX9h101[DDL4038L5P@0<B<M100f8a`304<`:@@0@BhW1011;BL402hO
6@@0=20I100U5AH301dA3`@0:1H@100M4A04024E3`@07Q<?100K40lC01P=30@08AD@100N4A03030T
9@@09Q`G100Q4Q<401P=2`@06a0?1`0L4Ph401/@3`@0;alI100V61D402`G4`@0BB`Q101RA3@3079>
?CX0TX9h5P3oool001@0oooo;P2BPWP406]AA`@0<Q`F100a8ad403HS70<0@c0Y1011;RL4044]9`@0
;QlI100d81T402DE5P<07A4?100X5Q0401dA40@08AD?100N4`l401/@3a<060d<100Q5A0401hA40<0
<2@U100V71L4024B4`@060d;100K40l701`B3P@06a0?100_7aT402HH5@@0;1LC1019;2440694=0<0
LThm>P2BPWPF0?ooo`00503oool^09:2N0@0Je57100b71H4034S7@@0=R<L0`13<2T4044^9`@0@BdW
100^7aT403@P6@@09ADF0`0M4@l402PF40@07A4@100Q5@l401hC3`@06a0?4`0H3@`4024E40@07Q4@
0`0`92D402HL5`@08A8C100H3@/401/@3`L0718>100K40l402lO6@@09QPE100/5a<404T/8@@0HT@d
0`1bCSdj09:2N1H0oooo000D0?oooc80TX9h101[CD<4038L5P@0=RLP0`0e8Q/4044_9`@0BS@/100l
:R@403@P5P@0;A`H0`0O510401dA40@06@d<100N4P`401hB40@06@d<0`0H3@`401`@3`@05``;100L
40l401L<2`@06@d<100a9b<302`K8@@0A3D^100g:2D402PJ6P@0;B0K100W6QD301hC3P@0;1/F100]
71L403`Y8P@0?R<K101D>2l406Q7>Sd0TX9h5P3oool001@0oooo<P2BPWP406]=@`@0<Q`F100f9b03
03DR6`@0@BlW101:=2`403`Z90@0=20F100]71P301lD40@07A4@100I3@`401hB30@07Q8@100I3@`3
01P=30@0710?100G30/401`@3`@05``;100I3@`4034W8`<0;1/Q1014=Bh403LX9@@0:1XJ100]81/4
02LJ5@<07Q<>100/6aH402dL5`@0?2TR100n8a/405@h;`@0J4Lj?@2BPWPF0?ooo`00503ooolb09:2
N0@0Jde3100b71H403HW80<0=B8K1011;bL404Xd;0@0?2XT100d81H402dL60<07a@@100M4A0401T=
30@07Q8<100N4Q0401T=30<060d<100L40l401L<2`@0710?100G30/401T=30@0<BLS0`0/6b4404@e
;P@0=bPU100X6QX402dP6`@09aXE0`0N4`h402`K5P@0;A`G100l:B8403hS6`@0E3P_101XAcXm09:2
N1H0oooo000D0?oooc80TX9h101[CD<4038L5P@0=RLP0`0e8Q/4044_9`@0BS@/100l:R@403@P5P@0
;A`H0`0O510401dA40@06@d<100N4P`401hB40@06@d<0`0H3@`401`@3`@05``;100L40l401L<2`@0
6@d<100a9b<302`K8@@0A3D^100g:2D402PJ6P@0;B0K100W6QD301hC3P@0;1/F100]71L403`Y8P@0
?R<K101D>2l406Q7>Sd0TX9h5P3oool001@0oooo<P2BPWP409F5N`@0KU57100g7AH303d]9`@0>2HP
1017=2`404Lb:P@0@RdU100]6a@302dL5P@0;R0K100T6QH4024B3P@07a@?1`0K40l401P<2`@060d<
100Q5AH401/@3P@07a<?100O4a8303HW8@@0?RPT100T5Q@402`L5@@0:Q/D100T5A<302XG4@@0;ahG
100h8AL404`b9`@0DS/f101_CSh4099oMCd0TX9h5P3oool001@0oooo<P2BPWP409F5N`@0KU57100g
7AH303d]9`@0>2HP1017=2`404Lb:P@0@RdU100]6a@302dL5P@0;R0K100T6QH4024B3P@07a@?1`0K
40l401P<2`@060d<100Q5AH401/@3P@07a<?100O4a8303HW8@@0?RPT100T5Q@402`L5@@0:Q/D100T
5A<302XG4@@0;ahG100h8AL404`b9`@0DS/f101_CSh4099oMCd0TX9h5P3oool001@0oooo<P2BPWP4
09F5N`@0KU57100g7AH303d]9`@0>2HP1017=2`404Lb:P@0@RdU100]6a@302dL5P@0;R0K100T6QH4
024B3P@07a@?1`0K40l401P<2`@060d<100Q5AH401/@3P@07a<?100O4a8303HW8@@0?RPT100T5Q@4
02`L5@@0:Q/D100T5A<302XG4@@0;ahG100h8AL404`b9`@0DS/f101_CSh4099oMCd0TX9h5P3oool0
01@0oooo<P2BPWP409F5N`@0KU57100g7AH303d]9`@0>2HP1017=2`404Lb:P@0@RdU100]6a@302dL
5P@0;R0K100T6QH4024B3P@07a@?1`0K40l401P<2`@060d<100Q5AH401/@3P@07a<?100O4a8303HW
8@@0?RPT100T5Q@402`L5@@0:Q/D100T5A<302XG4@@0;ahG100h8AL404`b9`@0DS/f101_CSh4099o
MCd0TX9h5P3oool001@0oooo>P2BPWP406Q7>P<0=ahF100e8Q`404D_9`@0DS`d101;>C0403dY8`<0
:aXD100^6aT403<M5P@0=BDN100Y71H401/@3P<060d<100U61T4024E5P@0:QdH100R5QT403@S70@0
718C0`0o;BD403@S7`@0<R8L100/7QT402XL5P@0;AlJ0`0c91d402lN6@@0C30T101D>2d406@m<@@0
R79/@@2BPWPF0?ooo`00503ooolj09:2N0@0J4Lj0`0g7QH403DR70@0ABlW101B?3@404/i<0@0?BTS
0`0[6Q@402hK6@@0<adF100e9Ah402TL5P@06a0>0`0H3@`402DH6@@08ADF100Z7AP4028F6@@0=2<L
100L4Q<303l]9@@0=2<O100b8Q`402`N6@@0:Q`F100]7aX303<T7@@0;ahI101<<2@405@h;@@0I3da
1028LVa109:2N1H0oooo000D0?ooocX0TX9h101XAcX303LN5P@0=B8L1015;bL4058l=0@0BcT`100m
:B<302/J50@0;Q/I100c7AH403DU7P@0:A`F100K40h301P=30@09API100Q5AH402XM60@08QHI100d
8a`401`B4`<0?bdU100d8al4038R70@0;1hI100Z71H402dO6P<0<b@M100_7QT404``90@0E3P]101T
?C4408QbK440TX9h5P3oool001@0oooo>P2BPWP406Q7>P<0=ahF100e8Q`404D_9`@0DS`d101;>C04
03dY8`<0:aXD100^6aT403<M5P@0=BDN100Y71H401/@3P<060d<100U61T4024E5P@0:QdH100R5QT4
03@S70@0718C0`0o;BD403@S7`@0<R8L100/7QT402XL5P@0;AlJ0`0c91d402lN6@@0C30T101D>2d4
06@m<@@0R79/@@2BPWPF0?ooo`00503oooln09:2N0<0J4i1100_50L402dL5@@0@RdV101>>C0404do
?0<0ARlU200g9B44034N6`@0=2TT100h:BH302`N60@09APH100]8BD403@S7P@0>Rd/100e8a`403@S
7P<0?R`W1012:bD403hV80@0?RLL100i:B<404<]90<0CSDX100i9A`406]>@@@0LTXj102BOgE509:2
N1H0oooo000D0?oooch0TX9h0`1XCT4402lD1`@0;A`E1012;BH404hi<0@0CCll0`16;bD803LU8@@0
<AhK100d:B@403PY9P<0;1hH100U61P402dQ9@@0=2<N100j;B`403DS70@0=2<N0`0n;2L4048[9@@0
?RHP100n9a`403TY8`@0@bdT0`1>=BP403TU70@0Jdi1101bBSX4099oMDD0TX9h5P3oool001@0oooo
?P2BPWP306Q>@@@0;a@7100]71D4048]9P@0CST`101=?c`304H_9@P0=bDQ100a7Q/403@Y90@0>2TV
0`0/7QP402DH60@0;B4U100d8ah403X];0@0=B<L100d8ah303h/9`@0@R/U100n9R0403hW70@0>BTS
1013;B@304he:0@0>BDL101[CT44079:>P@0TWmeA@2BPWPF0?ooo`00503oooln09:2N0<0J4i1100_
50L402dL5@@0@RdV101>>C0404do?0<0ARlU200g9B44034N6`@0=2TT100h:BH302`N60@09APH100]
8BD403@S7P@0>Rd/100e8a`403@S7P<0?R`W1012:bD403hV80@0?RLL100i:B<404<]90<0CSDX100i
9A`406]>@@@0LTXj102BOgE509:2N1H0oooo000D0?oood40TX9h1025KVT405@d;P@0;a/E1010;B@4
040e=@<0G4M0101B?3D4054m<`@0BCLa1010<2h404@c<0<0CC/g1011;RP403l]:P@0=B@T100j9b44
044/9`@0@RhW0`0n:R<404`/8@@0BBdT1017;B@404Xa:0@0A2TO0`1RAC/405hg8@@0GSdaC@2BPWPF
0?ooo`00503ooom109:2N0@0QFiY101D=2h402lK5@@0@2dT1010=CD305a7@0@0DS`e101A?C<404Tg
<@@0@30^1014<c0304dk=`@0@BhX100o;BX403DT90@0>RLQ1011;2L4048^9`<0?RXS101<;24404T]
90@0AbdT101:<BP404@Y7`<0HTDk101N=b4405hm<Dd0TX9h5P3oool001@0oooo@@2BPWP408E^J@@0
E3@^100_6aD4040]90@0@3De0`1LAd04058l=@@0DCdc1019=c44040`;P@0A3<`0`1=>cL4044^:0@0
?bdZ100e92@403XW8@@0@B`W1012;RL303hZ8`@0C2`Q1019;B@404L]90@0BS4X1014:Al30695>`@0
GSLQ101N?C5=09:2N1H0oooo000D0?ooo`@0TXAj102BQG]109:2N0@0J4i:100g4`l402dD3P<0>R/Z
101TCT@405]:@`@0CS/^101B?SH405=0>@<0ESlf101B>cD404Te;0@0@S0[1011;BP403TX8@@0AS8/
0`19=2`404@]90@0DC4W1018:R84079AA0@0DBHC0`144`T4079DCE40TX9h5P3oool001@0oooo102B
Q7X409:5Nd40TX9h101XCTX403LC3`@0;A@>0`0j:bX406A>A0@0FdY3101>>bh4058n=P@0Dd0i0`1F
?cH4058k=@@0BCD/1012<2/4044]:0@0>BPQ1016<R`304Td;0@0A2dT101A<BL404PZ8P@0LU54101A
9Q<304@C2@@0LUA=D@2BPWPF0?ooo`00503oool409:4NP@0TXEk@@2BPWP406Q>BP@0=a<?100]50h3
03X[:P@0I4i4101KBT<404hk;P@0DShf101C@3T305Ho=P@0DS/e1019=B`4048`:`@0@BdX100i:244
04Hb;0<0BC@/1014;B@4054a9`@0B2XR101bDD@4054V4`<0A1<9101bE4eA09:2N1H0oooo000D0?oo
o`@0TXAj102BQG]109:2N0@0J4i:100g4`l402dD3P<0>R/Z101TCT@405]:@`@0CS/^101B?SH405=0
>@<0ESlf101B>cD404Te;0@0@S0[1011;BP403TX8@@0AS8/0`19=2`404@]90@0DC4W1018:R84079A
A0@0DBHC0`144`T4079DCE40TX9h5P3oool001@0oooo102BNg84099oMDT0TX9h102<N7830697BP@0
BbT[101R@44406A6A@@0GS//101<;R8304Xe:`@0G4@l101N@CD805]2>@@0FT4f101C?3<305Lj;P@0
Eclb101[DDD403@?0`@0CRHR1022J6=H09:2N1H0oooo000D0?ooo`@0TW]b102BOgE909:2N0@0S7Qb
0`1RAdX404/Y:`@0HT11101TATD405hk;0@0C2hR0`1:=B/405a4?0@0GT4e201K@ST405Y1=P@0Dc`c
0`1G>Rh405Lo<P@0Je55100d3`<404hV8P@0PVQSF02BPWPF0?ooo`00503oool4099kLP@0TWmeB@2B
PWP408ahLP<0HTM:101;:B/40690@@@0I4I5101N>b`404`^8P<0BSD[101LA3`405i1=@P0Fd8i101J
@CH405<l<`<0EcX^101G?c8406]AA@@0=0l3101>9R84089XHeP0TX9h5P3oool001@0oooo102BNg84
099oMDT0TX9h102<N7830697BP@0BbT[101R@44406A6A@@0GS//101<;R8304Xe:`@0G4@l101N@CD8
05]2>@@0FT4f101C?3<305Lj;P@0Eclb101[DDD403@?0`@0CRHR1022J6=H09:2N1H0oooo000D0?oo
of00TX9h102<N7D408aeLP@0QF]Y0`1QA4X404X]=0@0AbHU10148QL404@S60@0A20E1011718303XC
1P@0=a00101UAcX4099oMF00TX9h5P3oool001@0ooooH02BPWP408ahM@@0S7Eb1025JfT30654BP@0
BRdd10179RD404@R5`@0A2<H101481D4044L4P<0>Q<6100g400406E7>P@0TWmeH02BPWPF0?ooo`00
503ooomP09:2N0@0S7Qe102<MG8408E[J@<0HDA:101:;C@404LV9@@0A28G10148aP404@P5@@0@A`B
0`0j4`H403L@00@0IDLj102BOgEP09:2N1H0oooo000D0?ooof00TX9h102<N7D408aeLP@0QF]Y0`1Q
A4X404X]=0@0AbHU10148QL404@S60@0A20E1011718303XC1P@0=a00101UAcX4099oMF00TX9h5P3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool009/0oooo0T0000230?ooo`00W@3oool00d000000oooo0?ooo`200?ooo`00
N03oool2@0000080oooo1D0000020?ooo`03@000003oool0oooo00/0oooo0d0000020?ooo`900000
0`3oool3@00000D0oooo00=000000?ooo`3oool0NP3oool007X0oooo00E000000?ooo`3oool0oooo
@00000030?ooo`03@000003ooom0000000/0oooo00I000000?ooo`3ooom000000?oood0000040?oo
o`04@000003oool0oooo@0000880oooo001i0?ooo`03@000003oool0oooo0080oooo00=000000?oo
o`3oool00`3oool00d000000oooo0?ooo`090?ooo`05@000003oool0oooo@000003oool00d000002
0?ooo`04@000003oool0oooo@0000880oooo001j0?ooo`05@000003oool0oooo0?oood0000000`3o
ool2@00000d0oooo0d000000103ooom00000@000040000030?ooo`=00000PP3oool007P0oooo00=0
00000?oood0000000`3oool01D000000oooo0?ooo`3ooom000000100oooo00=000000?ooo`3oool0
RP3oool007T0oooo00A000000?ooo`3oool0oooo0T0000030?ooo`=000003@3oool2@00008`0oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.8 Illusive color imaging",
  FontFamily->"Times New Roman",
  FontSize->18]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "In this section, we carry out a color illusive imaging. The principle of \
the method is similar to those of monochrome illusive imaging in chapter 2. \
One difference between the monochrome and color images is that a monochrome \
illusive image generation process should be repetitively applied to all of \
the color components red, green and blue.\n\tTo improve a ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " front-end response speed, we remove the needless memories and check up \
them.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["\<\
Remove[\"color3D\",\"color3DG\"];
Unprotect[In,Out];Clear[In,Out];Protect[In,Out];
Print[\"Memory: \",Round[N[MemoryInUse[]/1000]],\"K Bytes used\"];\
\>", "Input",
  CellLabel->"In[86]:=",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    InterpretationBox[
      \("Memory: "\[InvisibleSpace]5138\[InvisibleSpace]"K Bytes used"\),
      SequenceForm[ "Memory: ", 5138, "K Bytes used"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["We define a ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[
  " function \[OpenCurlyDoubleQuote]illusion3D\[CloseCurlyDoubleQuote]. This \
function is based on a knowledge obtained in the monochrome illusive image \
generation processes, and requires using the functions \
\[OpenCurlyDoubleQuote]eigen2Dvect\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]poissonSOR2D\[CloseCurlyDoubleQuote]. ",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica ",
    FontFamily->"Times New Roman",
    FontSize->10.5,
    FontSlant->"Italic"],
  StyleBox["function illusion3D",
    FontFamily->"Times New Roman",
    FontSize->10.5]
}], "Subsubsection"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "The parameter \[OpenCurlyDoubleQuote]color\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]rotation\[CloseCurlyDoubleQuote] of \
\[OpenCurlyDoubleQuote]illusive3D\[CloseCurlyDoubleQuote] are the list \
containing color image data and a integer giving a number of lighting angle \
subdivisions.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
illusion3D[color_,rotation_]:=
\tModule[{view,dim,vector,dummy,sol,i,j,k,p},
\t\tview=Table[{Cos[2.Pi i/rotation],Sin[2.Pi i/rotation]},
\t\t\t{i,0,rotation-1}];
\t\tdim=Dimensions[color];\t\t
\t\tvector=Table[eigen2DVect[color[[i]]],{i,dim[[1]]}];
\t\tdummy=Table[vector[[p,i,j]].view[[k]],
\t\t\t{k,rotation},{p,dim[[1]]},
\t\t\t{i,dim[[2]],1,-1},{j,dim[[3]]}];
\t\tsol=Table[poissonSOR2D[-dummy[[i,j]],
\t\t\t{dim[[2]],dim[[3]]}],{i,rotation},{j,dim[[1]]}];
\t\tTable[imageNormalize[sol[[i,j]]],{i,rotation},{j,dim[[1]]}]];\t\
\>", "Input",
  CellLabel->"In[89]:="],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox["Using this function, we compute the illusive image data.",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell["illusive=illusion3D[sampleL,rotation];//Timing", "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \({47.6500000000000945`\ Second, Null}\)], "Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "Figure 15 show a set of illusive images. From the left to right images on \
the upper in Fig. 15 are corresponding to the 0, 45, 90 and 135-degree \
lighting angles, respectively. Similarly, from the left to right images on \
the lower are corresponding to the 180, 225, 270 and 315-degree lighting \
angles.",
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
illusiveG=Table[Show[convertRGB[illusive[[i]]],
\tPlotLabel->StringForm[\"`1` deg.\",(i-1) (360/rotation)],
\tAspectRatio->dim[[2]]/dim[[3]],DisplayFunction->Identity],
\t{i,rotation}];\
\>", "Input",
  CellLabel->"In[91]:="],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[
\tTable[Table[illusiveG[[i+j]],{j,0,3}],{i,1,rotation,4}]],
\tImageSize->{400,200},PlotLabel->\"Fig.15. Illusive color images\"];\
\>", "Input",
  CellLabel->"In[92]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48837 
%%ImageSize: 400 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0116279 0.238095 [
[.5 .50087 -89 0 ]
[.5 .50087 89 12.5625 ]
[ 0 0 0 0 ]
[ 1 .48837 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50087 -150 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Fig) show
81.000000 12.812500 moveto
(.15) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Illusive) show
165.000000 12.812500 moveto
(color) show
201.000000 12.812500 moveto
(images) show
237.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .48837 L
0 .48837 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0116279 0.245293 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
988F8C988F8C988F8C988F8C988F8C988F8C988F8C988F8C978F8C978F8C978F8C978F8C978F8C\
978F8C978F8C978F8C968E8C968F8C968F8D968F8D968F8D968F8E96908F969191
958F8E968E8C968E8C968E8C968D8B968E8B968E8B968E8B968E8C978E8C978E8C978E8C978E8B\
978D8A978D8A968C89968B88968A87958A87958986958885958884948783938581
91827E938682948784958885958986958A87968A87968B87968B88968C89978C89978D8A978D8A\
978D8B988E8B988E8C
988F8C988F8C988E8C988F8C978F8C978E8C978F8C978F8C978E8C968E8C968E8C968E8C968E8D\
958E8D958E8D958E8D958E8C948E8D948E8D948E8D938F8E938F8F939090949293
938F8F938E8D938D8B948D8B948C8B948D8B958D8B958D8B948D8B958C8B958C8A958C8A958C8A\
958B88958A8794888694878493868392858192838092827E91807C907E7A8E7D77
8D7B768F7E7990807C91827E92847F928581938682938783948784948885958986958A87968B88\
978C89978D8A988E8B
988F8C988F8D978F8C978E8C978F8D978F8C968F8C968F8D968E8C958E8D958E8C958E8D948E8D\
948E8D948E8D938E8D938E8D928E8D928E8D918E8E918E8E918F8F909091909193
908E8F908D8D918C8B918C8B928B8A928B8A938C8B938C8B928C8B938C8B958B8A958B89958A88\
94898794888693858392838090817E8F7F7C8E7E7A8E7B778D79748B77718A746D
8A756F8B78728C7A758D7C778E7E798F807B90817D91827E928480928581938783948885958986\
968B88978C89978D8B
988F8C988F8D978F8D978E8C968F8C968F8D968F8D958F8D958E8D948F8D948E8D938E8D938E8D\
928E8D928E8D918E8D918E8D908E8D908D8E8F8D8E8E8E8E8E8E8F8D8F918E9093
8D8D8F8D8C8C8E8B8B8E8A8A8F8A8A908B8A928B8B938C8C938D8D938E8C958C8C948A89948987\
94878593858392828090807D8F7D7A8D7B778B78748A757089726D876F68856B63
866E6787716B89746E8A76718B79738C7B768D7D788E7F7A8F807C90827E918480938682948884\
958986968B88978D8A
988F8C978F8D978F8D968F8D968F8D958F8D958F8D948F8D948E8D938E8D938E8D928E8D928E8D\
918E8D908E8D908E8E8F8D8E8E8D8E8E8D8E8D8D8E8C8D8E8B8D8F8A8D908A8F92
8A8C8E8A8B8B8B8A898C89898D89898E89898F8A89908B8A918C8B918C8B928C8B928A89928886\
92868392838191817E8F7C798D79758B767288736E866F69856B6583686181645C
826860846B64856E6786716A88736D8976708A78738C7B768D7D788E7F7B90817D918480938682\
948885958A87978D8A
988F8C978F8C978F8D968F8D958F8D958E8D948E8D948E8D938E8D928E8D928E8D918E8E908E8E\
908E8E8F8E8E8E8D8E8D8D8E8C8D8E8B8C8E8A8C8E898B8D888B8D868B8E868B8F
868A8C87898A8888898988878A87878B87878C88878D88888E88888F89898F89889088878F8583\
8F83818E807D8E7D7A8C79768A747088716C856D6882696381655E7E61597E5F57
7F625A80655D826861836B64846E6886716B87746E8977718B79748C7C778E7F7A90817D918480\
938783958986978C89
988F8C978F8C968F8D968F8D958E8D948E8D938E8D938E8D928E8D918E8E918E8E908E8E8F8E8E\
8E8E8E8D8D8E8D8D8E8C8D8E8B8C8E898C8E888B8E868A8D84898C82878A818689
8387898487888586878686868786868885868985858A86858A85858B85858B84848C83838C8180\
8C7F7D8B7C798A797589747187706C846B668167617F635C7D5E567959507A5A50
7B5C547C5F577E635B7F665E816962836C6685706986736D8876708A79748C7C778E7F7B90827E\
928581948885968C89
988F8C978F8C968F8D958E8D948E8D948E8D938E8D928E8E918E8E908E8E8F8E8E8F8E8E8E8E8E\
8D8D8E8C8D8E8B8D8E8A8D8E898C8E888C8E868B8E858A8D81888B7A82867D8487
808587818587838586838485848384858484868383868282878282878181888080887E7E877C7B\
87797886767486747184706C826B668067617E625B7A5D5578584F75524776544A
77564D7959507A5D547C60587E645C806860826B65846F6986726D8876718A7A758D7D798F817D\
918480948884968B88
978F8C978F8D968F8D958E8D948E8D938E8D928E8D918E8E908E8E8F8E8E8E8E8E8E8E8E8D8D8F\
8C8D8F8B8D8F8A8D8F888C8F878C8F868C8E858B8E848B8E828A8E767F847B8286
7E83857F8485808384818384828282828182838182848081847F80847E7E847B7C847879837676\
83747382716F816E6C806B677E66617C625C7A5C5576564E735147704A3F724D42
73504575534976574E785B527A5F577D635B7F6760816B64846F6986736D8977728B7B768E7F7B\
90837F938783968B88
978F8C968F8D958F8D948E8D938E8D928E8D918E8E908E8E8F8E8E8E8E8E8D8E8F8C8E8F8B8D8F\
8A8D8F898D8F888D8F878C8F868C8F858C8F848B8F848C8F80898C7B84877B8386
7C82857D82847E81827E81827F80817F7F80807F80817F7F817E7E817C7C817879817576807172\
7F6E6E7E6C6A7D69677B656279615C785C5776585173524A704C426D44396D4539
6F493E714D4272514775554C775951795E567C625B7E6760816B6584706A87746F8A79748C7D79\
8F827E928682958A87
978F8C968F8D958F8D948E8D938E8D928E8E918E8E908E8E8F8E8E8D8E8F8C8E8F8B8E8F8A8D8F\
898D8F888D8F878D8F858C8F848C8F838C8F828B8F808A8E7E888C7C85897B8386
7B82847B81837B80817C7F7F7C7E7F7D7E7E7D7D7E7E7D7E7F7D7E7F797A7F75777E71737D6D6F\
7C696A7B676779646277605E755C5873585272534C704E466D483E6A4035683D31
6A42366C463B6E4B40714F4673544B765951795E567B635C7E6861826D6785726C8877728B7B77\
8E807C928581958A87
978F8C968F8D958F8D948F8D928E8E918E8E908E8E8F8E8E8E8E8F8D8E8F8B8E8F8A8E8F898D90\
888D90868D90858D90848C90828C90818B90838D927D888C7C868A7B85887A8386
7A8284798182797E80797D7D797C7C7A7C7C7A7C7C7B7B7C7D7E7E7D7B7C7D78787C74747B7070\
79696978646475605F735C5A7158556F544F6D50496C4B436A463C68403465392D
65392C683F336A44396D4A3F6F4F4572544B755A51785F577C645D7F6A63836F698675708A7A75\
8D7F7B918481958A86
978F8C968F8D948F8D938F8E928E8E918E8E8F8E8E8E8E8F8D8E8F8C8E8F8A8E90898E90888D90\
878D90858D90848D90828C90818C907F8B90758388788589798589798487788386
788285788183777E7F767B7C767A7B767A7B777B7B787B7B7A7D7D7B7F7E7B7C7B7B7A797A7674\
776D6B756564725E5E6F59576D55526B514B694D4669494168453B663F34643A2D
62352864392C663E326844396B493F6E4F4672554D755B5379615A7D6760816D6785726D897873\
8C7E79908380948986
978F8D968F8D948F8D938E8E918E8E908E8E8F8E8F8D8E8F8C8E8F8B8E90898E90888E90878E91\
868D91848D91828D91818C917F8B917E8B90758389768489768488768387778487
778386778183757E7F73797A73787A73787A717879777F7F7A7F7F7D82827D81807C7B7A7A7977\
777371736B696D5F5E6B5655685250674E49664A4466473F65443A643F3462392D
5F33265F322561382B643E3267443A6A4A416E504872574F765D567A645D7F6A6483706B877672\
8B7D7890837F948985
978F8D958F8D948F8D928E8E918F8E8F8E8F8E8E8F8C8E8F8B8E908A8E90888E91878E91868E91\
858E92838D92818D917F8C917E8D9372838A738389748389758489758286768487
778588778386758081727B7B6E7778768080757F7F7781817981817A80807C82817D7F7D7E7C7B\
7C777578716F6D6462665755644F4D634B4762474163453E63433A623E3460392D
5E34275C30225C32265E372C623E3466453B6A4C436F534B735A5378615A7D6861816E69867570\
8A7B778F827E948885
978F8D958F8D938F8E928F8E908E8E8F8E8F8D8E8F8C8E908A8E90898E91878E91868E92858E92\
848E93828E93808D927D8B917D8C936C7F87708188728388738489748488758588
76868A7786897684857782826F787872797A747B7B757B7A767D7C787D7B797C7B7977767A7674\
7B74707C7370776B686B5E5C604F4D5E47445E443F60433C614239613E345F392E
5D33275B2F20592F215931255C372D61403666483F6C4F4771574F765E577B655F806C6785736E\
897A768E817D938885
978F8D958F8D938F8E918F8E908E8F8E8E8F8C8E8F8B8E90898E90888E91868E92858E92848F93\
848F94838F94808E9377878D75868D6F80886F8288718288728288728388748589
76888C77878B78898A7A8989748383737E7F737D7D737B7B747B7B767A7A767A79767573777270\
766E6B776E6B76686472625E6555515B46425B423E5D413A5F41385F3E345D392E
5B34285A2F21582E1F572F225732285D3B3163433A684C436E534C735B5479635C7E6A6583726D\
8879758E807C938884
968F8D958F8D938F8E918F8E8F8E8F8D8E8F8B8E8F8A8E90888E91868E91858E92848E93838F94\
83909584929786949B7B8C926F838A70828A6F82896F838970828970838972858A
74878C748588728183738284728282728181738080738080748180767F7E767E7C767B79767773\
74706D746D6973686371615D6B5A555E4A4659413D5B403A5D40385E3E345D392E
5A3428592F22552A1C4E271A532E2359362C5F40366548406B504971595276615A7C686382706B\
8778738D807C938784
968F8D948F8D928F8E908F8F8E8E8F8C8F908A8E90898E91878E91858E92838E92828E93828F94\
8290968594998B999F85949975878E70838A6E82896D83896E82896E828970858A
72878C7285896E7E816E7D7F6F7E7F6F7E7F707E7F717E7F727F7F737E7E737C7B737977727572\
71716E6F6D686E69646D645F6B5E5864544E5C47425A423B5C40395D3E355C3A30
5A352A593125592F224A24184E2A1F5533295C3C3362453C684E466E564F745E587B6761806F6A\
8677728C7F7B928784
968F8D948F8D928F8E908F8F8E8E8F8C8E908A8E90878E91858D91838D92828D92808D937F8E94\
7F8F958091977F8F967B8C9373868E6E82896B80886B81886B82886C82896D848A
6F858B6F84886C7E816A797C6B7A7B6C7B7D6D7C7D6E7C7D6F7E7E717D7D717A7A7076756F7371\
6E6F6C6B6A67696561685F5B655A5461524C5D4A455B453E5B423A5C3F365B3A31
59362B5933265830224722174B271D5130265839305F4239664B436C544D735C5679655F7F6D68\
8576718C7E7A928783
968F8D948F8E928F8E908F8F8D8E908B8E90898E91868E91848D92828D927F8C927D8C937C8C93\
7A8C93788C9476899072848C6E8088697E87687D85687E85687F86688087698188
6B83896B81876A7E8268787B68777969787A6A7A7B6C797B6D7B7C6E7C7C6E797A6E75756D7070\
6C6D6B69686566635F645D5A6258535F524C5C4A455B46405A433C5B40375A3B32
5A372D5A35285B32244520144623184E2C2255362C5C3F376349416A524A715B5477635E7E6C67\
8575708B7E7A928683
968F8D948F8E928F8F8F8F8F8D8F908A8E91888E91858D91828D92808C927D8C927A8B92788A92\
76899273879070848D6C8088697C84667B83657A82647A82647C83657D84657E85
668086677F85677D8265787C64747766767867797B69797B6B797B6C7A7C6C78796C75756A706F\
696C6B66666463605E605B585F57535D524E5B4C475A484259443D594038593C33
59382E5A362A5E3527492317421E134A281E5233295A3D3461463E6850496F595276625C7D6B66\
84746F8A7D79918683
968F8D948F8E918F8F8F8F908C8F908A8E91878E92848D92818D927E8C927A8B92778A92748891\
7187916D828C6A7F8865798363788161788061777F60777F617880617A82617A82
627C83637C83637B8162777C61737762747764767866767968777A6A787A6A7678697273676E6E\
656A69626463605F5C5C59565B54515A504D594C4858494357453E574039573C34
57392F59372B5F382B562E20472115452218503027583B325F443C664E476D575174615B7B6A65\
83736F8A7C78918682
968F8D948F8E918F8F8F8F908C8F91898F92868E92838E937F8D937C8C93788B92748992708791\
6C838E677D886378835E747E5B747E5C747D5C747D5C747D5C757D5D767E5D767F
5D777F5E777F5F777D5F757B5E7377607376617477637477657578677578677476666F71646B6C\
6166675E62615B5C5B595654575350564E4B564B4756474255433D543F38543B33
54372E55342A573429563024522B1E4C291F5030275639315D423B644C456B564F725F5A7A6964\
82726E897C78918582
968F8D948F8E918F908E8F918C8F92898F92858F93828E937E8D937A8C93768A937189926C8792\
67828E627C875C737F59707A57707A57717B58717B58717B58727B58727B59727B
59737B5A727B5A72795A70775A6F755C70765F7377617377637578657578657375636E7061696B\
5D64655B5F60585A5A55555454514F524D4A534A4652464251423D503E38503933
4F352E4F31294F30264D2A1F4A24184B281E4E2F2554372F5B4139624A4369544E715E58796863\
80716D887B77908582
968F8D94908F9190908F90918C9092899093858F94818E947D8D94798C94748B946E8892688590\
61808B5A7884546F7B516B77516C77526D78536E79546F79546F78546F78546F78
546E77546D76546D75556B73566B71586D735B70745E7276617478637478647174626D705F686A\
5B6364575D5E545757515252504E4D4F4B494E48454E45414D413C4C3D374B3832
4A342D492F27492D2547261C4320154523194B2B2251352D583E375F484267524C6F5C57776662\
7F706C887B77908581
968F8E94908F9190918F91928C9193899194859095818F967D8E96788D96738B956C899564828D\
5979864F707D4968764967744B68744D6A754F6B76506C77516D77516D77506C76
4F6B754E69734F68714F677051686E546A70586D725B70755E73776174786271745F6C6F5C6668\
596062545A5C5055564E50504C4C4B4B49474A46444A434049403C483C37463731
45322C432D26422A224022193F1E14401D1346281F4D322A543C355C464065504B6D5B56756561\
7E706C877A76908481
96908E9490909291928F92938C92958992968691978190977D8F97788E97728D986D8C9864838F\
557684486B7A3D61704162704565724867744B69754D6B764E6C774E6C764C6B75
4B697449667048636D49626B4C636B4F666D546A70596E745D72775F73776070745D6B6E5A6567\
555E6051585A4D53544A4E4E474A4A46464545434145403E443D3A433A35423631
40312B3E2B253D2922391F17381C133A191041241C492F2851393359443E624F496B5955746460\
7D6F6B8679768F8481
97908E9591909392929093948D93968A93978693988292997D9199778F99728E996E8D9A688694\
577785456978375D6E3B5E6E4062704465724868754B6A764B6A754B6A75486772
45657043626E425F6B445E68465E674B616951676E576D735C72775F73785F70745C6B6E596567\
535D604E57594A5253464C4D434848424444414040413E3C413B393F38343E3430
3C302A3A2B26382722321D1730171033150D3C211A442C254D373156423D5F4D4868585372635F\
7B6E6A8579758F8481
97908F9592919493949194968F95988C959A88959B83949B7D929B77909A718E9A6C8B97658492\
5274833F667630596B365C6C3B606F4063714568754B6C784E6E7A4E6E794C6C77
4567733F626E3D5E6A405E68425C65465D654F666D556C735B72785F74795F71765C6C6F586567\
525D5F4F585A4A5254454C4D4046473E42433C3E3E3C3C3B3D3A373C36333A332F
382F2A372B263527222F1F192B15102D120B361E183F292449352F52403B5C4B4766565270625E\
7A6D698478758E8481
97918F96929295949593969891979A8E989C8B989E86979E7F949D76909B6E8D9A6A8995688592\
5476853E65762C5669325A6C385F6F3D6271436775496C7950717E54747F587580
51707B48697542646F42646E46636C49626A4F676E556D745B737A5F757B6072785D6C71596669\
505B5E4E575A485153414A4C3B43453A4041373C3D3839393937363A353338322E
352E2A332A26302521271C1824140F27100B311C163A272244322D4F3E395949456355516E615D\
796C698378758E8380
98918F979393969696959899949A9D929B9F8F9CA28A9BA28298A176919C64849263839162818E\
5274833B64762854682F586B355D6E3B6171406574466A774D717E5274805A7883
5B788356747F4F6D774969734966704B656E506870556D755B737A60767C62757A617075606D70\
586265535D604C5658404B4F3C454838404233393C34373836353539353337322F
342E2B322A262B24202018151A0F0C200D092B1814352420402F2C4B3B385647446153506C5F5C\
776B688277748D8380
989290989494989898989A9C979DA0969FA394A1A791A2A98AA0A87C97A26687955A7D8B577A89\
4A6F803862742653672D576A335C6D3961723E6373436775496D7B4F7380547683
54768253737F4F6F7B4B6A764A68724C6871506A72566F765C747B60767D63767C637377616F71\
60686A6066675E62624D5457474C4E4347493A3F41393C3D3939393A3735383331
35302D322B2827211F1B1614130A081808042414112F201D3B2D2A4739365246435E524F6A5E5B\
766B688177748D8380
9993919A96959A9A9A9B9D9F9BA0A39BA4A89BA7AC9AABB19BB0B888A1AA75949F638592587B8A\
476E7F3761742552672B5669315B6D3862723E6676426877456A78496E7C4C717F
4D72804C707D4A6D7A486A764867734C6A74516C755670785C747C61767D63777D637278616E72\
5E696B6067686467675D60605557574E4F504547484041423D3C3C3B39383A3533
37312F342E2B25211F1815140F0A091204021D100E291D1B362A284337344F44415C514E685D5B\
746A678076748C8380
9A93919B97979C9C9C9DA0A19FA4A7A0A9ACA1ADB2A3B3B9A7BAC193AAB37E9AA56C8C995C7F8D\
4870813561742453682754682F596C355F703D6676456C7C49707E4D72804F7583
5378865377845174824E717D4D6D794E6D77526E7856717A5B747C60767E64787E64747B606D73\
5C676C5B65675B6163585E5F56595A505353474B4C4345453F3F3F3D3B3B3A3736
393331342E2C2321201414150F0D0C0C0201160C0B2319183127253F35334C4240594F4D665C5A\
7369678076738C8280
9A94929C99989E9E9EA0A2A4A3A8AAA5ADB1A8B3B8ABB9BFB0C1C89FB3BB8AA2AC75939F618391\
4B72833662752554692553672B5769325C6D396272406979476F7E4D74824F7785
5279885379875378865075824F707D4F6F7A52707A55727A5A747C5F767D64797E697A7F67757A\
606B71596468545D62525A5D5156594D5153484B4D4446474141413E3D3D3E3939
3C3635342E2C2221210F13140B0B0C0600000903031C15142C24233B333249413F574E4D655C5A\
7269677F76738C8280
9B94939E9A99A1A0A0A3A5A6A6ABADAAB1B4ADB8BCB1BFC4B6C7CDA7BAC293AAB47E99A5698997\
50768739647727566B2452662854672E596A355E6E3B6373416878456D7C497080
4B73824C73824D73824D72804D717E4E6F7B51707A54717B58727B5C737B61757C66777D6B787C\
6B7479676E725C6468535B5E4D54584A5053474B4D444748424343424040413D3C
413A39332F2E2221220F1417060B0D06040505010317121328222238313147403F564E4D645B5A\
7168677E75738B8280
9C95939F9B9AA3A1A1A6A8A9AAAEB0AEB5B8B2BCC0B7C3C8BDCCD1AEBFC69CB1BA859FAA6F8E9B\
567B8B3E687B29586D2251662551652B556731596A365E6E3B62723F6675436A79
456D7C476E7D486F7E496E7D4A6E7C4C6E7B4F6E7A526F7A5570795870785C7178617278657378\
677276687073666C6E616668595E605457594F51534C4D4E474748454343434040
433D3C353131242525151A1C080E11030608010104131112252122363131453F3F544E4D635B5A\
7168677E75738B8280
9C9594A09C9BA5A3A3A9AAABADB1B3B2B8BBB7C0C3BCC7CCC2CFD5B2C2C9A2B5BE8CA5B07593A0\
5C7F8F446C7F2D5B70225166224F632752642D566732596A365D6D3A61713D6473
406776426978446A7A456B7A476B79496B794B6C784E6C78516C76546D76586D755B6E745F6E73\
616D72636C7062696C6065685D6164595C5D5356574F50504B4B4B494746474342
433E3C3633332828291B1E200D121503080B0002040F0E10232022343131454040544E4D625C5A\
7069677E76748B8280
9D9694A29D9CA6A4A4ABACADB0B3B5B6BBBEBBC3C7C1CBD0C6D4D9B7C7CDA7BAC293AAB57C99A6\
6285954A72843360742352681F4D61244F622A53642E5666325969365D6D396070
3B62723E64744066764167774368774569764869764A69754D69744F6972536972566971596A70\
5B696F5C676C5D65695B6366595F62575B5D5356584F51524C4D4D4B4949494645
413E3E353434292A2C1D2023111619060C1002070A0E0F11232223353233454141544F4F635C5B\
7169687E76748B8280
9E9695A39E9DA8A6A6AEAEAEB3B6B7B9BEC0BFC6CAC5CFD3CCD8DDBCCAD1ACBEC699B0BA84A0AC\
6C8D9B53798B3B677B2A586E1F4E63224D612750622B53642F5565325868355C6C
375E6E3961713B62723D64733F65744165744366744666724865714B65704D656F50656E53656D\
56656C576369576166576064565D6055595C5356585152534F4F4F4E4B4B4B4746
43403F3737372C2D2E212427161B1E0C1317080D11111316252527373536464343555150635E5D\
716A697E77758B8380
9E9795A49F9EAAA7A7B0AFB0B6B8B9BCC0C3C3C9CCC9D2D6CFDBE0C0CFD5B0C2CA9FB5BF8BA6B1\
7493A15A7F90446D80315E73245267224D61254E612951622C53642F5565315768
335A6B355D6E375F703960703B61713D62713F637141636F43626E45616C49616C4B616B4E6169\
516169526067535E64535D61535B5F53585C525558515354504F504F4D4D4B4847
4240403938392E303125282A1B1F2212181C0F14181B1D202A2B2D3A383A494646575353655F5F\
726B6A7F77768C8381
9F9795A5A09EABA8A8B2B1B1B8BABBBFC3C5C6CCCFCDD5D9D4DEE2C5D2D8B5C6CDA5B9C392ABB7\
7C9AA86487974B758736647829576C234F63234E61264F612951622C53632E5465
30576731596A335B6C355C6D365D6D385E6D3B5F6D3D5E6C3E5E6B405E6A435E69465E68495E67\
4C5E664D5D644F5C62505B6051595E51585C515558505455515152504E4E4A4848
4342423A3A3B313334272A2D1E2225151B1F1015192123262F30323E3D3E4C494A595555676161\
736D6C8078778C8481
9F9895A6A09FACA9A9B3B2B2BBBCBCC2C5C7CACFD2D2D9DCDAE3E6CAD6DCBBCAD1ABBEC79AB1BC\
85A1AE6D8E9E557C8E3E6A7E2D5D72235166224D61244E61274F612950622B5162
2C53642E55662F576831586932596A335A6A355B6A375A683859673B5A663E5A65415A65445A64\
475A634A5B624C5A614D595F4E585D4F575B5055584F53564F50524D4D4F484849
414243393B3C313436282C2F1F2528191F23171B1F27292C3535374241434F4D4D5C5858696363\
756E6D8179788D8482
9F9896A6A19FAEAAA9B5B3B3BDBDBEC5C7C8CDD1D3D6DCDFDFE7EBD1DCE1C2D0D6B2C3CCA1B6C1\
8DA7B37695A45F849547728535637826556A224E63234E61254E61264F60284F61
2951622A52632B54652D55672E57682E56673056663155653355643555633856633C56623F5761\
42576145576048575F4A585E4C575C4E565A4F55594F53564D50534B4D4F47484A
4143443B3D3E3336392B2F3223282C1E232724272B2E30333B3B3D4746475351515F5B5B6B6665\
76706F827A798D8582
A09896A7A1A0AFABAAB6B4B4BEBEBFC7C8C9D0D3D5D9DFE1E3EBEED9E3E7C9D6DCB9CAD1A9BDC7\
96AEBA7F9DAB698B9C537B8D3F6C802D5C72245166224E62234E61244E60254E61
264F612650622750622752642953652953642A52632B52622C51602F516032525F3653603A535F\
3D545F41545E44555E47565D4A565C4D565B4F565A4F54574D51534A4D4F45484B
4043463B3E4034383B2C313423292D1C21252A2D303537394141434C4B4C575555635F5E6D6868\
787271837C7A8E8583
A09896A8A1A0AFABAAB7B5B4C0BFBFC9C9CAD2D5D6DCE0E2E7EDEFE0E8ECD2DDE2C2D1D8B1C4CD\
A0B6C08AA5B27595A46185964D768939667B29586E235166224E63224D61224D61
224D60234D61234E61234E62245063245063244E61254E5F274D5E294D5D2C4E5D304F5D35515D\
38525D3D525D41535D44555D48555C4B555B4F565B4F54584D52554B4E51464A4C
4044483B4043353A3D2E3437292E3223272B3133363C3D3F4746485150515C5959666262706B6A\
7A7473847D7B8E8684
A09896A8A2A0B0ABAAB8B5B4C1BFBFCACACAD3D5D6DEE1E3EBEFF2EAF0F3DBE4E9CBD8DEBBCBD3\
ABBFC897AFBA829EAC6F909F5C82934A73873763792B596F245268224E63224E62
204C601F4B601F4B601F4C60204D611F4D611D4B5E1E495C20495B234A5B274B5B2B4C5B304E5B\
344F5B39515C3E525C43545D48565E4B565C4F565C50565A4F53574C5053484C4F
43484B3F4346383D4130373B2D3337313437393C3E4344464D4C4E565555605D5D696565736E6D\
7C7675867E7C8F8784
A09896A8A1A0B0ABAAB8B5B4C1BFBFCACACAD4D5D5DEE1E2EAEEEFF0F6F8E4ECEFD4DFE4C4D2D9\
B4C6CFA2B8C38EA8B47D9AA86C8D9D5D81924B73863C677B315E7329566B265267
214E631E4C611D4B601D4B601E4C611D4C611B4B5F1A485C1B475A1E4759224A5A274B5A2B4C5B\
2F4D5B364F5B3C525D41545E47575F4C585E4F585E50575C5055594E53564B4F52
464B4E42474A3C4145363C3F2F3437393C3F4243464A4B4C5352535C595A6461616D696876706F\
7E7876877F7E908785
A09896A8A19FB0ABA9B8B4B3C1BEBECAC9C9D4D4D4DEDFE0E9EBECF4F7F9EFF4F7DFE7ECD0DBE1\
C0CFD6AFC2CB9BB2BD8BA5B17B99A66D8D9C5E8192507688446C7F3A6478335E71
2D586C275469235066224F64235065204F651E4E631D4B601B4A5D1C485C204A5C254B5C2A4D5D\
2F4F5D34505D3B535E4256604959614D5A61525B61535A5E53595C5256594F5356
4B4F52484B4E43474A3D41453B3D404344474A4B4D525152595858615E5F696565716C6B797372\
807A7888817F908885
A09895A8A19FB0AAA8B8B3B2C0BDBCC9C7C7D3D2D2DDDDDDE7E9EAF4F6F7F7FAFDE9EFF2DAE2E7\
CBD7DDBCCBD3AABDC699AFBA8AA3AF7C98A56D8C9B5F81925578894D7182456B7C
3D6578366073315C702C586C2C586C2A566A275468245166224F63214D61244D60284F602C5060\
3252613753603E56624559634C5C64505D64545E63565D62565C60565A5D53575A
5053564E50534B4D4F44484B484A4C4D4D4F5252545957595F5D5E6663636D6969746F6E7B7574\
837C7A8A8280918886
A09795A7A09EAFA9A7B7B2B1BFBCBBC8C5C5D1D0CFDBDBDAE5E6E6F1F2F2FAFDFEF4F8FAE4EAEE\
D5DEE3C7D3D9B6C5CDA7BAC397ADB78BA3AF7D98A5708F9D6686955D7E8E567887
4F7283476C7D43697B3D64763A6174375F71355D70325A6D2F596B2F5769315668345767375867\
3B5A67415B67475E684C5F685361685662685A62675B61655B60635A5E60585B5D
55575A5456585152555152545253555656575A595A605E5E6562636B6767716D6C7872717E7877\
857D7C8B8381928987
A09795A79F9DAEA8A6B6B1AFBEBAB8C6C3C2CFCDCCD8D7D7E2E2E2EDEEEEF8FAFAFBFDFEEEF1F4\
E0E6EAD2DBDFC1CED4B4C3CAA7B9C19CB0B98DA4AF809AA678929E6E8A97668391
5F7E8C5677875374834E6F7F4A6C7D46697A4467784165753F63733E61713F617042617045626F\
48626F4C646E52656F56666E5A676E5D676D60676C61666A6164676062655E5F61
5B5C5E5A5A5C59595B5A595B5B5B5C5E5D5E6260606663646B6767706C6B7570707B7574817A79\
867F7D8C8482928A87
9F9794A69F9CADA7A5B5AFADBCB7B6C4C0BFCCCAC9D5D3D3DFDEDDE9E9E8F4F5F5FEFFFFF7F9FA\
EAEEF0DDE3E6CFD8DCC1CCD2B4C2C9AABAC19EB0B991A6B0899EA87E95A0778F9B
708995698390637F8C5E7B895A7785567482547180526F7E4F6C7B4F6B7A4F6B78526C78556C78\
586D785B6E775F6E77626E75636D73656D72676D70686C6F686A6C656668616264
5F5F615F5F60605F606160616361626563646865666C6869706C6C74706F7974737E7877837C7B\
88817F8E8683938A88
9F9694A59E9BACA5A3B3ADABBAB5B3C1BDBCC9C6C4D2CFCEDAD8D8E4E3E2EFEEEDFBFBFBFFFFFF\
F5F7F8E8EBEDDBE0E3CED6DAC2CCD1BAC5CBAFBCC3A4B3BA9BABB390A2AA889BA4
81959E7B909A748B957087916C838F687F8B647C88627A866077835F7682607580647781647680\
6777806B787F6D787E6F777C6F767A7075787174767072746E6F716E6C6E6A6869
6461626664656765666866666A67676C69696E6B6B716D6D7570707973737D7776817B79867F7D\
8A83818F8784948B88
9E9693A49C9AABA3A1B1AAA9B8B2B0BEB9B8C6C1C0CDCAC8D5D3D1DEDCDBE8E6E5F2F0F0FDFBFB\
FFFEFEF4F4F5E7E9EADADEE0CFD5D8C7CED1BFC7CCB5BFC4ADB8BDA3AFB69AA7AE
93A1A98D9CA488989F82939B7D8F97798B9475879072848E70818B6E80896E7E87728088758189\
7882897A82887C81867D80847C7F817A7C7E797A7B7978797575767270726E6C6E
6D6B6B6D6A6B6E6B6B6E6B6C706C6C726E6E74706F7672717974737D7776807A79847D7C88817F\
8C8482908885948B89
9E9592A39B99A9A19FAFA8A6B5AFADBBB5B4C2BDBBC9C4C3D0CCCBD8D4D3E0DDDCE9E6E5F1EFEF\
FBFAF9FDFBFBF3F1F1E5E6E7D9DBDDD0D4D6CBCFD2C4C9CCBDC2C5B5BBBEABB3B8
A4ADB29EA7AC98A2A8939EA48E9AA089959C869299828E96808C937C88907B868D7D868C7F868D\
858A8E888B8E88898C88888B868587838283807F807E7D7D7D7B7B787676767273
7471717470707470707571707671717772727974737B76757E7877807A79837D7B87807E8A8281\
8E8583918986958C89
9D9492A29A97A79F9DACA5A3B2ABA9B7B1AFBDB8B6C3BEBDCAC5C4D1CCCBD8D4D3DFDCDBE7E4E3\
EFECEBF8F6F5F9F6F5EFECECE4E3E3D9D9DAD3D4D5CED0D1C9CBCCC2C4C6BBBDC0
B6B8BBAFB3B6A9ADB0A4A9AC9EA4A899A0A4959CA091989D8F959B8B9297878E92868C90878C90\
8B8D918B8D8F8C8C8E8C8B8D8C8A8B898787878484848181827F7F7D7A7A7C7878
7B77767A76757A75757A75757B76757C77767E78777F7A79827B7A847D7C867F7E8982808C8482\
8F8785928987958C8A
9D9491A19896A59D9BAAA2A0AFA7A5B3ADABB8B2B0BEB8B6C3BEBCC9C4C3CFCBC9D6D1D0DCD8D7\
E3E0DEEBE7E6F4F0EFF4F0EFEBE7E6DFDDDDD8D7D7D4D2D3D1D0D0CBCACBC4C3C4
BFBEC0BBBABCB8B7B8B3B3B4ADAEB0A8A9ABA4A5A89FA1A49C9EA1989A9E97989B929497949597\
979597989596989494979293959191938E8D8D89898A868588848384807F827D7D
807B7B7F7A7A7F7A797F7A79807A79817B7A827C7B847D7C857F7D87807F8982808C84828E8684\
918886938A88968D8A
9C9390A09794A39B98A79F9DABA4A1AFA8A6B3ADABB8B1AFBDB6B5C1BCBAC7C1BFCCC7C5D2CDCB\
D8D3D1DED9D7E4E0DEEDE8E6EFE9E8E9E3E2DDD9D8D6D2D1D2CECED0CDCDCDC9C9
C9C5C5C5C1C1C0BCBCBDB9B9BBB7B7B6B2B2AFACACA9A7A9A6A4A5A2A1A3A19E9F9B9A9B9C9A9B\
9E9A9A9E99999E98979C96969A9493999291908B8B8E89888B8685898383878180
85807F847F7E847E7D847E7D857E7D857F7D867F7E87807F8982808A83818C84828E8684908885\
928987948B89968D8A
9B928F9E9593A19996A49C9AA8A09DABA3A1AEA7A5B2ABA9B6AFADBAB3B1BEB7B5C2BCBAC6C0BF\
CBC5C3D0CAC9D6D0CEDBD5D3E0DAD8E5DEDCE3DCDAD9D3D2D3CDCBCEC9C8CCC6C6
C9C3C3C8C2C0C5BEBDC1BAB8BDB6B5BAB4B2B5AFADB1ABAAABA6A5A7A3A3A5A1A1A39F9FA19E9D\
A29D9CA39D9CA39B9AA19A999D97969C9595958F8E918C8B8F89888D86858B8583
8A83828982818982818982808982808982818A83818B84828C84838D85838F8784908886928987\
938B88958C89978D8B
9B918E9D93919F9694A19996A49B99A69E9CA9A19FACA4A2AEA7A5B1AAA8B4ADABB8B1AFBBB4B2\
BFB8B6C2BCB9C6C0BDCAC3C1CEC7C4D2CBC8D7D0CDD7CFCCD5CCC9CFC7C5C8C1BF
C7BFBEC6BEBDC4BBB9C0B8B6BCB5B3BAB2B0B7AFAEB5ADABB1AAA8AFA7A6AAA4A3A8A3A1A6A1A0\
A4A09EA49F9EA29C9BA59F9EA39C9B9C959497918F948D8C928B899089878F8886
8E87858D86848D85848D85848D85838D86848E86848F87848F8785908886918986928A87938B88\
958C89968D8A978E8B
9A918E9B928F9D94919E9593A09795A29997A39B98A59D9AA79F9DA9A19FABA3A1ADA5A3B0A8A5\
B2AAA8B4ADAAB7AFADBAB2AFBCB4B2BFB7B4C1B9B6C2B9B6C2BAB6C5BCB8C1B9B6
BEB6B3BEB6B3BDB5B3BDB5B2BAB1B0B4ADABB2AAA9B0A8A6ADA6A4ACA5A3AAA3A1A7A19FA69F9D\
A49E9CA9A2A0A49E9BA19A989E97959B949298918F968E8C948D8B938B89928A88
918A88918987918987918986918986918987918987928987928A87938A88948B88948B89958C89\
968D8A978D8B988E8B
99908D9A908E9B918F9B928F9C93909D94919E95929F9693A09794A19895A29996A39A98A49B99\
A59D9AA69E9BA89F9CA9A09EAAA29FABA3A0ACA4A1ADA4A1ADA5A1AEA5A1ADA4A1
ACA3A0ACA4A0ACA3A0ADA5A1AFA6A2AEA5A1ADA4A2ACA3A1ABA29FAAA19FA9A19FA9A19EA79F9C\
A19997A098959E96949D94929B93919A918F98908E978F8C968E8B968D8B958D8A
958C8A958C8A958C89958C89958C89958C89958C89958C8A958C8A968D8A968D8A968D8A978D8B\
978E8B988E8B988E8C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0116279 0.488926 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(225) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
8D8A898D8B898D8B898D8B898E8B8A8E8B8A8E8B8A8E8C8A8E8C8B8E8C8B8E8C8B8E8D8B8E8D8C\
8E8D8C8E8D8C8E8D8D8E8E8D8E8E8D8E8E8D8E8E8E8E8F8E8E8F8F8E90908F9293
8E8F8F8E8E8E8E8E8D8E8E8D8F8D8C8F8E8D8F8E8D8F8E8D8F8F8D908E8D908F8D908E8D908E8C\
908D8B908C8A8F8B898E8A878E89868D88858D87858D85838B84818A827F89807C
877C7889817D8A83808B84828B85838B86848C86848C87858C87858C88868C88868C88868D8987\
8D89878D89888D8A88
8D8B898D8B8A8E8B8A8E8C8A8E8C8B8E8C8B8E8D8C8E8D8C8F8E8D8F8E8D8F8F8E8F8F8E8F8F8F\
8F90908F90908F91918F91918F92928F92928F93938F93948F94958F95978F979A
8F94968F93938F92918F929190919090919191929192929192929192929193929193919092908F\
928E8C918D8B908B888F89868E87848D85828C83808B817D897E79877A76857771
83746E867975877D78887F7B89817D8A827F8A83808A84818B84828B85838B86848C87848C8785\
8C88868D89878D8988
8D8B898E8C8A8E8C8B8E8C8B8E8D8C8F8E8D8F8E8E8F8F8F8F8F8F909090909190909191909292\
90939390939491949591949591959691969791979890979A90999B909A9D909CA0
8F999B909798909596909595919595929595939595949695939695949695959594949392949290\
93908E938E8C918B889088858E85828D837F8B7F7C8A7C7787787385736D816E66
81706983746E857772867A75877C78887E7A897F7C89807D8A827E8A83808B84818B85838B8684\
8C87858C88868D8987
8D8B8A8E8C8B8E8D8C8F8D8C8F8E8D8F8F8E90908F909191909191909293919393919494919595\
91969792979892979992989A92999B929A9C929B9D929C9F919DA0919EA291A0A5
909C9F909A9C91999A919899929898939898949898959898959998959998969797969594959391\
94918F948F8C938B889187848F84808D807C8A7C7788777285736C826D667E675E
806B64826F6883736D857670867873867A76877C78887D79887F7B89817D8A827F8A83818B8582\
8B86848C87858D8987
8E8B8A8E8C8B8E8D8C8F8E8D8F8F8F909090909191919292919394919495929596929697929899\
93999A939A9B939B9D939C9E939D9F939EA1939FA293A0A492A0A592A1A791A3A9
919FA3919DA0929C9D929B9C939A9B949A9B959A9A969A9A969B9B969B9A979A99979796969592\
969290958F8C948C889287838F827E8D7E7989797486736D846E678068607D6359
7F675F806B64826F6883726B84746E857771867974877B76877D78887E7B89807D8A827F8A8481\
8B85838C87858C8887
8E8B8A8E8D8C8F8E8D8F8F8E90909090919191939391949492959692969793989993999A939A9C\
949B9E949D9F949EA1959FA295A0A495A2A695A3A794A4A893A4AA92A5AA91A5AB
91A2A691A0A3929EA0939D9F949D9E959C9D959C9C969C9C979C9C989C9C989B9A989998979694\
979391968F8C958C8893868290807C8D7C76897671867069826A617E63597C6056
7E645B7F685F806B63826E6783716A84736D857670857873867A75877C78887E7B89807D8A827F\
8B84818B86848C8886
8E8C8A8E8D8C8F8E8E90908F90919191939391949592969693979893999A949A9C949B9D959D9F\
959EA195A0A396A1A596A3A796A4A896A6AA96A7AC96A8AE95A8AF92A8AF90A5AC
91A3A892A2A593A1A393A0A1949FA0959F9F969E9F979E9E989E9D989E9D999C9B999A99989795\
989491978F8C958B8793858290807B8D797489746D856D6581665D7C5E537C5E54
7D61587E655C7F685F806B63816E6682706A83736D847670857873867A76877D78887F7B89817E\
8A83808B85838C8886
8E8C8A8F8D8D8F8F8E90919091929291949492969693979893999A949B9C959C9E959EA096A0A3\
96A1A597A3A797A5A998A6AB98A8AD98AAAF99ABB199ADB399AEB58FA7AF8EA4AB
90A4A992A3A793A2A594A2A395A1A296A1A297A0A198A0A099A0A0999F9F9A9D9D9A9B9A999896\
989491978F8C968A87938581907E798D787288716A836A628063597B5A4F7B5C51
7C5F547D62587E655C7F685F806A63816D6682706A83736D847570857873867B76877E7A89807C\
8A827F8B85828C8785
8E8C8B8F8E8D90908F90919191939392959693979893999A949B9D959D9F969FA196A0A397A2A6\
98A4A898A6AA99A8AD99AAAF9AACB19AAEB49BB0B69CB2B99BB3BB89A3AC8EA5AC
90A5AA92A5A994A4A795A4A696A3A497A3A498A3A399A3A29AA2A29AA1A09B9E9E9B9B9A9A9896\
999391988E8B96898693847F907D788C7770886F6883685F7F60567A584C7A594E
7B5C517C5F547D61587E645B7F675F806A63816D6682706A83736D847671857974877C78887F7B\
89817E8B84828C8785
8E8C8B8F8E8E90919091929292949593969793989A949B9C959D9F969FA197A1A497A3A698A5A9\
99A7AC9AA9AE9AABB19BADB39BB0B69CB2B99CB4BB9FB7BF94AFB78BA5AD8FA7AD
91A7AC93A7AB94A6A996A6A897A5A698A5A599A5A59AA5A59BA5A59CA4A29CA09F9C9C9B9A9795\
999290988D8B96888592827E8F7B768B756F876E6683665D7E5F547A564A7A564A
7A594D7B5B517C5E547D61587D645B7E675F806B63816E6782716B83746E857772867A76877D7A\
89817D8A84818C8785
8E8C8B8F8F8E909191919393929596939899949A9B959C9E969FA197A1A498A3A799A5A999A8AC\
9AAAAF9BACB29CAFB59CB1B79DB3BA9EB6BD9FB9C198B3BC8FABB48FAAB291AAAF
93A9AE94A9AD96A9AC97A8A998A7A899A7A79AA7A79BA8A79CA8A79DA5A49DA1A09D9C9B9B9795\
9A918F988C8A96878392817C8E7A758A736C866C6583665D7E5F547B574B785346
7955497A584C7A5B507B5E547C61587D645C7E68607F6B64816F6882726C847570857974877C78\
88807C8A83808C8784
8E8D8C8F8F8F90929292949493969794999A959B9D969EA097A0A398A3A699A5A99AA8AC9BABAF\
9CADB29DB0B69DB2B99EB4BC9EB7BF9FB9C29CB9C291AFB891AEB792ADB493ACB2
94ACB196ACB097ABAE98A9AB99A9A999A8A89AA9A99CA9A89DAAA99EA6A59EA2A19D9D9B9D9897\
9B918F998C89958582917F7B8D787388716B856B6382655C7E5F547C584C785245
77514478544879574C7A5B507B5E547C61587D655C7E6861806C6581706A83746E847873867B77\
887F7B8A83808B8684
8E8D8C90908F919292929595939899949A9C959D9F97A0A298A2A599A5A99AA8AC9BABAF9CADB3\
9DB0B69EB3B99FB5BDA0B8C0A0BAC3A1BDC792B2BC91B0BA92AFB893AFB695AFB4
96AFB498AFB399ADB099ABAC99AAAA9AAAAA9AAAA99CA9A89EA8A79FA6A69EA1A09E9E9C9F9B99\
9C93919A8C8A958482907D7A8C7772877069846A6281645B7F5F547C584D795347
764E4077514478544878574C795B507A5E557B62597D665E7E6A63806E6782726C837671857A75\
877E7A89827F8B8684
8E8D8C90909091939392969694999A959B9D969EA197A1A499A4A89AA7AB9BAAAF9CADB29EB0B6\
9FB3B9A0B6BDA1B9C0A2BCC4A2BFC89DBCC78EAFBA91B0B993B1B994B0B796B1B7
98B2B79BB2B69BB0B299ACAC9AABAB9CABAB97A6A59BA7A79DA5A49FA5A4A0A4A2A1A09EA19D9B\
9E96939C908D958683907C798A7571866E6883686081635B7F5F557D594E7A5448
774F41764D3F76504377544877574C785B51795F567B635B7D67607F6C6581706A83746F857974\
877D7989817E8B8683
8F8D8C909190919494939697949A9B969D9F97A0A298A3A69AA6AA9BA9AE9CACB19EB0B59FB3B9\
A1B6BDA2B9C1A3BCC4A3BFC8A5C3CC93B4C08FB0BB91B1BA94B2BA95B1B798B3B9
9AB5BA9DB5B99DB2B49CAEAE98A7A79AA7A897A3A39BA5A59DA5A49FA4A4A1A6A5A2A09EA29D9B\
A19996A09592978A868E7D7988736F846D6781665F80625A7F5F557E5B4F7B5649
795042764C3D754D4074504375534876574D775C527960587B655D7D69627F6E6882736D847773\
867C7888817E8B8583
8F8E8D909191929495939798959B9C969EA098A1A499A5A89AA8AC9CABB09DAFB49FB2B8A1B6BC\
A2B9C1A4BDC5A5C0C9A5C2CBA4C3CD8CAFBC8FB0BB91B1BB94B2BA96B2B899B4BA
9CB7BC9FB7BA9EB4B59EB0AF94A2A397A3A499A4A49BA4A39EA6A6A0A6A5A2A6A5A2A09EA29E9C\
A29996A197939B8D8891827E877470826B6580645E7F6159805F567F5C507C574A
7A5143784C3D754C3E724C3F714F4373534975584F775D5479625A7C67607E6C6681716C837671\
867B7788807D8B8583
8F8E8D919191929595949899959C9E979FA298A3A69AA6AA9BAAAE9DADB29EB1B7A0B4BBA2B8C0\
A4BCC4A7C1CAABC6CFA4C3CC99BAC68BAEBA8FB0BB92B2BB95B2BA97B3B99AB5BB
9DB8BD9EB5B89DB1B39CADAE96A6A698A5A69BA6A69CA5A59FA8A7A1A7A6A3A7A5A2A29FA29E9B\
A19794A096929C8E889786818B79748069647E635D7F6158806056805D517E584B
7B5244794D3E754A3B714A3B6E4A3E704F4573554B755A517860577A655E7D6A6480706A827570\
857A7688807C8A8582
8F8E8D91929293969694999B969D9F98A1A399A4A79BA8AC9CABB09EAFB59FB3B9A1B7BEA3BBC2\
A5BFC7AAC5CEAFCBD5A1C0CB8DB1BD8DAFBB90B1BB93B3BB95B2BA97B3BA9AB5BB
9DB7BC9DB3B79AACAE9AAAAC99A9A99BA8A89CA7A89EA8A8A0A9A9A2A9A8A3A7A5A3A3A1A39E9B\
A198959E95909C8E88978680907C76826B667E625C7F6158816157815E527F594C
7C54467A4F40784C3C6C44366B463A6D4B4070524773574E765D5579635B7C69627E6E6881746F\
847975877F7C8A8582
8F8E8D919292939697959A9C979EA098A2A59AA6A99CAAAE9DADB39FB1B7A0B5BCA1B8C0A3BCC5\
A5C1CAA9C6CFAAC8D39DBEC990B2BE91B2BD92B2BC94B2BA96B2BA98B2BA9AB5BB
9DB6BB9DB3B799ABAD99A9AB9AA9AA9BA9A99DA8A99FA9A9A1AAAAA3AAA9A4A7A6A4A4A2A39F9C\
A19A969D958F9A8D8896857F8F7C7587706980655F806259816157825F53805A4E
7D55477C51427C4E3E673F316842366A483C6E4E4471554B745B527761597A67607D6D6781736E\
847974877E7B8A8482
8F8E8E919393949798969B9D979FA299A3A79BA7AB9DABB09EAFB59FB3B9A1B7BEA2BAC2A3BEC7\
A4C1CBA5C5CFA2C2CE9DBDC896B6C193B3BD93B2BB95B2BA96B2BA98B2B99AB4BA
9CB5BB9CB3B79AADB099A8AA9AA8A99CA9A99EA9AAA0AAAAA2ABABA4ABAAA5A8A7A5A4A2A4A09C\
A29A969D938F998C8694847D8E7B7489726B83696282655B826359836054815B4F
7F56487E52437D4F3E653D2F643F326845396B4B416F524872584F765F5779655E7C6B6580716C\
837873867E7A8A8481
8F8F8E929393949899969C9E98A1A39AA5A89CA9AD9EADB29FB1B7A0B5BCA1B9C0A2BCC5A3BFC9\
A3C2CDA2C3D0A0C0CC9CBBC698B6C094B3BD94B1BA95B1B996B1B998B2B99AB3BA
9BB5BA9CB3B79CAFB29AA9AB9AA7A89CA8A99FAAABA1AAAAA3ABABA5ACABA6A9A8A6A5A3A49F9C\
A19A969C928E978B8592827D8E7B7489736B856B6284685E84655A846155825C4F
8057497F5444805140633C2D613C2F65423669483D6C4F4570564D745D5578635C7B6A647F706B\
827772867D7A8A8481
908F8E929494959999979D9F99A2A49BA7AA9DABAF9FAFB4A0B3B9A2B7BEA2BBC3A3BEC7A3C1CC\
A3C4D0A1C3CE9FC0CB9BBAC497B4BD94B2BB94AFB895AFB897B1B898B2B899B3B9
9BB4B99CB2B79CB0B39BABAD9BA7A89DA8A99FABABA1AAABA3ABABA6ADACA7AAA8A6A6A3A49F9C\
A19A969C918D97898491817B8D7B738A736C876D64866A6085665C846256825D50
80584A7F5445815342673F305D382A623E3266453A6A4D426F544B735B5376625A7A69627E6F6A\
827672867D79898381
908F8E939494959A9A989FA09BA3A69DA8AC9FADB1A1B1B7A2B6BCA3BAC1A4BDC6A4C1CAA4C4CE\
A3C6D2A1C2CE9FBFCA99B6C095B2BB94B0B994AEB795AFB796B0B798B1B899B2B8
9AB2B89BB1B79DB0B49BACAE9BA7A99DA8A99FAAABA2ABABA4ACACA7ADACA8ABA9A6A5A3A49F9C\
A099959B918C96898390807A8C7A728A746C897067886C6286685D846357825E51
7F584B7D54457D51426E443560382A5D382C644237694A406D52487159517560597967617D6E69\
817571857C79898381
90908F939595969B9B99A0A29CA5A89EAAAEA1AFB4A2B4B9A4B8BFA5BCC4A6C0C9A6C4CEA5C7D2\
A4C7D3A1C2CE9DBAC696B1BB93AFB993AEB794AEB695AEB696AFB698B0B799B1B7
9AB1B79BB0B69CAFB39BABAE9BA8AA9DA9AAA0ABABA2ABABA5ADACA8ADACA9ABA9A7A5A2A49F9B\
9F98949B908B958882907F798C7A728B756D8A7269896E6386695E846458815E51
7D584B7A5244774E406F4536643A2B5D382B63413568493E6C504670574F745F5778665F7C6D68\
807470857C78898380
91908F949696979C9C9BA1A39EA7AAA0ACB0A3B1B6A5B6BCA6BBC2A7BFC7A8C4CDA8C7D1A7CAD6\
A5C8D4A1C1CC9AB5C093AEB891ADB792ADB693ADB695AEB696AFB697B0B799B0B7
9AB0B69BAFB59AADB19BAAAD9BA8AA9DA9AAA0ABABA2ABABA5AEADA9ADACA9ABA9A7A5A2A49E9B\
9F96939A8F8A948780907F798D7A738B766E8B736A896F65866A5F836458805E52
7C584B775143734D3E6C4334633829623B2D64403467473C6B4E456F564D735D5677655E7B6C67\
80746F847B78898380
919090959797999D9E9CA3A59FA9ABA2AEB2A5B4B9A7B9BFA9BEC5AAC3CBABC7D1ABCBD6A9CCD7\
A6C8D39FBEC996B1BC90ABB68FABB491ABB492ADB594AEB696AFB698B0B798B0B6
99B0B59AAEB399ABB09AA8AC9AA7A99CA8A99FAAAAA2ABABA6AEADAAAEADAAABA8A8A5A2A49E9A\
9F9691998E899486809080798E7B748D786F8B746B8A7065866B608365597F5E52
7B574B755042714C3E6A423363392961392C633F3266453A694D436D544B715C5476635D7A6B66\
7F736E847B77888280
9191909697979A9E9F9EA4A6A1ABADA5B1B5A8B7BBAABCC2ACC2C9AEC7CFAFCBD5B0D0DBADCED8\
A7C6D19BB9C58FACB88CA8B38DA9B28FAAB391ACB594AEB696AFB698B0B799B0B6
99AFB499ACB198A9AE98A7AA98A5A89BA6A89EA8A9A2ABABA7AEADAAAEADABABA8A8A5A2A49D99\
9F9590998E8895878192817A8F7D758E78708B756B897066866B608365597F5F52
7A584B745143704C3F694132633A2B5E3527613C2F644338674B416B524A705A5274625B796A64\
7E726D837A7688827F
9291909798989B9FA0A0A6A8A4ADB0A8B4B7ABBABEAEC0C5B0C5CCB2CBD3B3D0D9B5D5E1B4D1DB\
A7C4CE97B5C187A6B387A4B08AA6B18DA8B290ABB494ADB597AFB699B0B799B0B6
99AFB498ACB196A7AC95A4A896A3A699A4A59DA7A7A2AAAAA7AEADABAEADACABA8A9A5A2A59E99\
9F95909B8E8896898293827B907E758E79708B746B897066866B608265597E5F53
79584B7451456F4D40674132603A2B5B31235E392C61413565483F6950486E585173615A786963\
7D716D82797688827F
9292919899999DA1A2A2A8AAA7B0B2ABB7BAAFBDC2B2C4C9B5C9D0B6CFD7B8D4DDB9D8E2B8D2DC\
A8C3CD95B2BE80A1AF82A1AD86A4AF8AA6B18FAAB394AEB698B0B79BB2B89BB1B6
99AFB496ABB094A5AB93A2A694A0A396A1A29BA4A5A1A9A9A7ADACACAFADADACA9AAA5A2A79E99\
A196919D8F89998A8394847C917E768F7A718B746B887065856B608265597E6053
79594C745346704E406542345C3628572E1F5B36295E3E3363463C674E466C574F715F59766862\
7C706C82797587817F
939291999A9A9FA2A3A4AAACAAB2B5AFBABDB4C1C5B7C8CDBACED4BBD3DBBCD7E1BCD8E1BCD4DC\
A8C1CB90AEBA799CAB7D9DAB82A1AD87A4AE8DA9B294AEB599B1B89DB3B89EB2B7
9BAFB494A9AF8FA3A890A1A5919EA1929B9D99A1A2A1A7A7A8ADACADAFADAEACAAACA7A3A9A09A\
A39791A0918B9C8C8497867E927F778F7A7189736A876F65856B6082665A7E6053
795A4C745447704F41634134573326532A1C5733275B3B3060443A644C446A554E6F5E57756661\
7B6F6B81787587817F
9493929A9B9BA1A4A5A7ACAEADB5B7B3BEC1B9C6CABECDD2C1D4DAC1D8DFBFDAE3BED7DFBED2DA\
A6BFC98BABB77397A7799AA87F9FAA84A2AD8BA7B092ACB399B1B79CB2B7A2B4B8
9DB0B493A8AE8EA1A68C9FA48D9B9E90999B989FA0A0A6A6A8ADACAEB0AEB0AEABAFA8A4ADA49D\
A49791A3948DA08F869A8880927F778E797188736A866E64846A5F83665A7E6053
795A4D7655476F4E405F3F325231244E271A53302557392E5C4138614A4267534C6D5C56736560\
7A6E6A80787487817E
9493929C9C9CA3A6A6AAAFB0B1B8BAB8C2C4BFCBCEC5D4D8CADBE1CBE1E7BED8E0BCD3DBB9CED6\
A5BDC688A8B56E93A37597A57B9CA882A0AB88A4AD8EA8B095ADB499AFB59FB2B7
9BAEB395A8AE8FA1A68B9DA28C9A9E919A9D989FA0A1A6A6A8ADACAFB0AEB2AFACB1AAA5B0A59F\
A99A93A99890A7938A9A8880937F778F7A72877269846E6482695E8265597F6154
7B5C4E7857496F4E405B3D304C2D214925194F2E2253362C583F365E484064514A6B5A5471645F\
786D697F777486807E
9594939D9D9DA5A7A8ADB1B2B5BBBDBDC6C8C6D0D3CEDBDFD8E7EBD3E6ECC1D7DFB9CED7B4C8D0\
9EB7C283A4B26A90A07195A37899A5809FAA86A1AB8BA4AC91A9B096ADB399AEB3
98ACB194A7AD90A2A78D9DA18E9B9E939C9E99A0A0A1A7A6A9ADACAFB0AEB2AFACB2AAA5B0A59E\
AD9D95AD9B92AD988E9B8981968179917C7386726A846D6482695E836659816254
7E5E507C5A4A6D4D3F583B2F462A1F442216492A204E3329543C335A453E614F486858536F625E\
776C687E767386807E
9694939E9E9EA7A9A9B0B3B4B9BEC0C2C9CBCCD5D8D7E2E5E4F1F5D6E6EBC8DBE1B9CDD5AEC3CC\
96B2BE7EA0AE678E9E6D92A07596A27D9CA6849FA989A3AB8EA5AD93A9AF95ABB0
95A9AF92A5AB8FA1A78E9DA28E9B9E949D9F9AA1A2A2A7A7A9ADACB0AFADB3AFACB3ABA6B0A59E\
AD9E96AD9B92AC978DA08D8499857C937D7489746B876F65866B5F85685B856456
826052805C4D6B4B3E54392E42291F3E1D1243261C492F264F383156423B5D4C466556516D615C\
756B677D757285807D
9695949F9F9FA9AAAAB2B5B6BCC1C2C6CDCED1D9DBDDE7EAEBF6F9DDE9EECCDCE2BBCED6A9C1C9\
91AFBA7A9DAB658C9D6A8E9D72939F7997A2819DA687A1A98CA4AB91A6AC91A6AD
93A7AD91A3A990A1A68E9EA28F9B9F959FA19CA4A4A3A9A8AAACABB0AEACB3B0ABB5ACA8B2A59F\
AD9E97AB9A91A7948BA18E849D877E967F758F776D8C73688A6E61896A5D886658
886354825D4D694A3D4D362C422A20391B113D2219422B2349352E513F395A4A446254506B5F5B\
736A667C7572847F7D
979594A1A0A0AAACACB5B7B7BFC3C4CACFD1D5DCDEE2EAECEFF9FBE2EDF1D0DEE3BDCFD6A8C0C9\
90ADB9789BA9658C9C678B9A6E8F9B75939E7C98A1839CA589A0A78DA2A88DA2A9
90A3AA90A2A891A2A790A0A4939FA397A2A39EA6A7A3AAA9A9ACAAAFADAAB2AEA9B6ADA8B5A8A2\
B0A099AC9B92A5938BA18D849E877E998177947B7091766A8E71648C6C5F8C695B
8D6757815C4D66483C4A352B422B21381C12321A123B251E43312A4C3C365647425F524E685E5A\
7169657B7471847F7D
979694A2A1A0ACADADB7B8B9C1C5C5CDD1D2D9DFE0E5ECEEF3FAFDE6EFF2D4E0E5BFD0D7AAC0C9\
90ADB9799BA9668D9C6589986B8B9872909A79939D7F98A0849BA2889EA48BA0A6
8EA1A78FA1A791A2A893A2A796A3A79AA4A69FA8A8A4AAA9A9ABA9ADACA8B0ACA7B4ABA5B6A9A2\
B4A39CB19E95A9968DA48E859E887F9B8278977D7293786B9072658F6F61916C5D
9269597F5A4B65483B4D372D3F2920351C1327130C32201A3D2C274739335245405C504C665C59\
7068657A7371837F7D
989695A2A2A1ADAEADB8BABAC4C6C7CFD3D4DBE0E1E8EEEFF5FCFDE7F0F3D8E3E7C1D2D9ACC1CA\
93AFBA7B9DAA688E9D6488966889956F8D977590997B949C81979E859AA1899DA3
8C9FA58FA1A692A3A894A4A898A5A99BA7A9A0A8A9A4ABAAA8ABA9ABAAA7AFAAA5B1A9A3B4A7A0\
B3A39CB29F97AE9990A89288A28B819E8479997E7397796C937566957163956E5F
936A5A7D594B66483C4F382E3B281F2D19121F0F092B1C163728234235314E423E594F4B635B57\
6E6764797370837E7C
989695A3A2A1AEAEAEBABBBBC5C7C7D1D4D5DDE1E2EAEFF0F7FDFEE9F1F3DAE4E8C5D5DAAEC4CC\
97B1BB80A0AD6D919F6388966586936C8A94738D967991987E949B83989E889BA1
8B9EA48FA0A692A3A895A4A999A6AA9CA8AAA0A9AAA4ABAAA7AAA8AAA9A6ADA8A4B0A7A1B2A59E\
B2A29AB19E95AE998FAA9389A68D83A1877B9D81749B7C6E99786A997466987161
9169597B584A64473B4F372E39271F2717121A0D082316123024203D322F4A403C564D4A615A57\
6D6663787270827E7C
989695A4A2A2AFAFAEBBBBBBC7C8C8D3D5D5DFE2E3ECF0F1F9FEFFEBF1F3DCE5E9C8D7DCB3C7CE\
9CB5BE86A4B07294A2658997638491698792718B94778E967D929982969D879AA0
8B9DA28EA0A692A3A896A5A999A7AB9DA8AAA1AAABA4AAA9A7A9A7A9A8A5ACA7A2AEA5A0B0A39D\
B0A099AF9C94AD988EAB9389A88E83A5897DA28477A07F719E7B6C9E77689B7262
8E675777564862463A4D362D37261F221611150C081A100D2B211E39302D473E3B544C49605956\
6B6563777270827E7C
999695A4A3A2B0AFAEBCBCBBC8C9C8D4D6D6E1E3E3EDF1F1FBFEFFECF2F3DDE6E9CBD9DEB8CAD1\
A2B9C28CA8B37798A5698C9A6284916885906F8992768D957C909781949B86999E
8A9CA18EA0A592A3A796A5A99AA7AB9EA9ABA1AAAAA4AAA9A6A9A6A8A7A4ABA6A1ADA49EAEA29B\
AF9F97AE9B93AD978EAB9389A98F83A88A7EA68679A38173A27D6EA179699A7161
8863547353465E433848332B32231D1E1411110A07150D0A271F1C362F2C453D3B524B485E5856\
6A656376716F827E7C
999695A4A3A2B0AFAEBCBCBBC8C9C8D5D6D6E2E3E4EFF1F1FCFFFFEEF3F4DEE7EACFDBDFBDCDD3\
A9BDC591ABB67D9CA86E909D6587946885906F8891758C947B909781939986979D
8A9CA18FA0A593A3A797A5A99AA7AA9EA9ABA1AAAAA3A9A8A5A8A5A7A6A2AAA4A0ABA39DADA099\
AE9E96AD9A92AD978DAC9388AB8F84A98B7FA88779A68374A57E6FA17969966E5E
835F516F50435840364230282D201A19120E0A0604140E0C251F1D352F2C433D3B514B495D5856\
6A656376716F817E7C
999695A5A3A2B0AFAEBCBCBBC9C9C8D6D6D6E3E4E4F0F1F1FDFFFFEFF3F4E0E8EAD2DCE0C2D0D6\
AEC0C898B0B984A1AC7393A06A8B976A86916F8891758C947C909681939986979C
8B9BA08F9FA493A3A797A5A99BA8AA9EA8AAA1A9A9A3A8A7A5A6A4A7A5A1A9A39EAAA19BAC9E98\
AD9C95AD9991AC968CAC9288AB8F83AB8C7FA98779A88375A57E6E9E7767906A5B
7D5B4E674B40523C333C2C25271C18130E0C05020016111025201F342F2D433E3C504B495D5856\
696563757270817E7C
999695A5A3A1B0AFAEBDBCBBC9C9C8D6D6D5E3E4E3F1F1F1FFFFFFF0F4F5E3E9EBD4DEE1C6D2D7\
B3C4CA9FB5BD8CA6B07A98A471909B6D8994708892768C947C909782949A87979D
8C9BA0909FA394A3A798A5A99BA7AA9EA8A9A1A9A8A2A7A6A4A5A2A5A3A0A7A19CA99F9AAB9D96\
AB9B93AC9890AC958BAC9287AC8E83AC8B7EAB877AA88374A37C6D997364886557
75564A60473C4B372F3528221F18140D0A0904020117131226222135312F433F3D504C4A5D5957\
696564757270817E7C
999695A4A2A1B0AFADBCBBBAC9C8C7D6D5D4E3E3E2F1F1F0FFFFFFF2F5F6E6EAEBD8DFE2CAD5D9\
B9C8CEA6B9C195ACB5849EA97996A1718D97728A93778D957D919883959A88989E
8D9CA0919FA395A3A699A5A89CA7A99EA7A8A0A7A7A2A5A4A3A3A0A4A19EA59F9AA79E98A99B95\
AA9991AA978EAB948AAB9186AC8E82AC8B7EAA8779A682739E796A916D5F7F5F52
6B504658423843332C2D231E17121005040309070719161628252436333144403F514D4C5D5A58\
6A6665767271817E7D
999694A4A2A0B0AEADBCBAB9C8C7C6D5D4D3E2E1E0F0EFEEFFFEFDF6F7F7E9ECEDDBE2E4CFD8DC\
BFCCD0AEBEC59DB1B98FA6AF829CA677929D758D97798F977F939984969B8A999E
8E9DA193A0A396A2A599A5A79DA7A89FA7A8A0A6A5A1A4A2A1A19EA29F9BA39D99A59C96A79993\
A89790A9948CAA9289AB9085AB8D81AB8A7DA98678A37E7097746688675A75594D
614A414F3C343B2E28241D1A0F0E0C0000000E0D0C1C1A1A2A2827383534454241524F4D5E5B5A\
6A6766767371827F7D
989694A4A1A0AFADACBBB9B8C7C5C4D3D2D1E1DFDEEEEDECFDFCFBF8F8F7ECEEEFE0E5E6D4DBDE\
C6D0D3B6C3C8A6B7BD99ACB48DA3AC829AA37C939C7D929A81959B86979D8C9B9F
909DA194A0A397A2A59AA4A69DA7A89FA7A79FA4A49FA2A09F9F9CA09C99A19B96A39994A59791\
A6958DA7938AA89087AA8E83A98B80A8877AA583759C796B8E6E617E61556C5349
58453C4637303128231B18160A0B0A0000011110101F1E1E2D2B2B3A383747454353514F5F5D5B\
6B6867777472827F7D
989594A3A19FAEACABBAB8B6C6C4C2D2D0CEDEDCDBECEAE8FAF8F7FBFAF9F1F1F1E5E8E8D8DDDF\
CCD4D7BDC8CCAEBBC1A2B2B997AAB18EA2AA859AA28499A085989F89999E8F9DA1
939EA196A1A398A2A59BA4A59FA6A7A0A6A69EA3A29C9F9E9C9C9A9D9A979E9894A09691A2958F\
A3938BA59088A68E85A78C81A6897EA384779E7D7093736684675C745B50624D44
4F3F383D312C27221F131312040606060607151515232222302F2F3D3B3B494746555352615E5D\
6C6968777473827F7E
989593A2A09EADABA9B8B6B4C4C1C0CFCDCBDBD9D7E8E6E4F5F2F0FEFBFAF5F4F3E9EAEADDE0E1\
D2D8DAC4CDD0B5C0C5ABB8BCA0AFB59AAAB092A3A98EA0A68C9EA38F9DA294A0A3
96A1A397A2A499A2A49CA3A4A0A6A5A0A5A49DA1A09A9D9C999A979A97949B96929E948F9F928D\
A09088A18D85A28B82A2897EA1857A9C7F7395766B896C617A61566A544B58463F
463934332B271F1C1B0E0F0F0003040D0E0F1B1B1B282727343333413F3E4C4A4958555463605F\
6D6B6978757483807E
979493A29F9DACA9A8B7B4B2C1BFBDCCCAC8D8D5D4E4E1DFF0EDEBFDF9F7FAF7F5EDECECE2E3E4\
D7DADCCBD1D3BBC5C8B1BCC0A9B5B9A3B0B49DABB098A7AB97A5A998A4A79BA4A6
9BA4A69BA3A59BA2A49DA3A3A0A4A49FA2A29C9F9F9A9B9A98989697949298938F9B918D9B8F8A\
9C8D869C89829D877F9C847B99807693786E8A70667D655C6F5A515F4E464E403A
3B332F292523191818090C0D0407081415162121212D2D2D3938384443424F4E4D5A5857656261\
6F6C6B79767583807F
979492A19E9CABA8A6B5B2B0BFBCBAC9C7C5D4D1CFDFDCDAEBE8E5F7F4F1FCF8F7F1EFEEE6E6E6\
DBDDDDD0D4D5C2C9CBB8C1C3B2BBBEACB6B9A6B1B4A2ADB1A0AAADA1A9ABA2A8A9
A1A7A89FA5A69FA4A59FA2A2A0A3A29FA1A09C9E9D9A9A9997969495929096908D978E8A978C87\
978A8496867F96837B947E769079708871697F6961725E5764534C554741433A36
312C2A212020141515070B0C0F11121B1D1D2728283333323E3D3D4847475351505D5B5A676563\
716E6D7A777684817F
969392A09D9BA9A6A4B2AFAEBCB9B7C6C3C1D0CDCBDAD7D5E5E2DFF0EDEAFBF6F4F6F2F0EAE8E7\
DFDFDFD4D6D7C9CDCEC1C6C8B9BFC1B5BCBEAEB6B8AAB2B4A9B0B1A8AEAEA7ABAB
A6AAA9A2A7A6A4A7A6A1A3A2A0A2A19FA09F9D9D9C9A999796959393918F938E8B948C88938984\
9286818F827C8F7E778B797286736C7E6B6473625B675852594D484A403D383331
2726251C1C1D0F11120F12131A1C1C2425262F2F2F3939394342424D4C4B565554605E5D696766\
72706F7B7977848180
9693919E9B9AA7A4A2B0ADABB9B6B4C2BFBDCCC8C6D5D2D0DFDCD9EAE6E3F4F0EDF8F4F2EDE9E8\
E3E1E0D9D9D8CFD0D0C7CACABFC3C4BCC0C1B6BBBCB1B6B7B1B4B4AEB0B0ACAEAD
AAACAAA6A8A7A6A7A6A3A4A3A2A2A09F9E9D9D9B9A999796959391928F8D918C8A918A868F8682\
8C827E897E79887A7583746E7C6D6873655F695D575D524D4F47433F3A382F2E2C
2122221517181315161B1D1E2425262D2E2E3636363F3F3F4848475150505A59586361606C6A68\
7472707C7A78858280
9592909D9A98A5A2A0ADAAA8B6B3B1BEBBB9C7C4C1D0CCCAD9D5D3E3DFDCEDE8E6F6F1EEF0EAE8\
E6E2E1DDDBDAD4D3D2CBCCCCC5C7C7C2C4C3BDBFBFB8BABAB6B7B6B1B2B1B0B0AE
ADADABAAAAA8A8A7A5A5A4A3A3A19F9F9D9C9B9A9898969493918F918E8C8E8A878D87848A8380\
877F7C857B778277727D716C7468646A605C605753534C4945413F373634282929
1A1C1D17191A1F20212627272D2E2E3536363E3E3D4645454E4D4D5655545E5D5C6664636E6C6B\
7674727E7B7A858381
9491909C9997A3A09EABA8A6B2AFADBAB7B5C2BFBCCAC7C4D2CFCCDBD7D4E4DFDDEDE8E5F0EAE8\
E9E4E2E0DCDBD8D5D3D0CECDC9C9C8C7C6C5C2C2C1BEBDBBBBB9B7B5B4B2B3B1AF
AFADABADABA8A9A7A4A6A3A1A2A09E9E9C9A9A9896979493928F8E8E8C8A8A87858A858286807E\
837D7A8279767E7471766D6A6D6561625B585752504B48463E3D3D313232242627
1A1C1C222323292A2A2F30303637373E3E3E4545444C4C4B5453525B5A596261606A6867716F6E\
7876747F7C7B868382
94918F9B9796A19E9CA8A5A3AFACAAB6B3B0BDB9B7C4C1BECCC8C5D3CFCCDBD6D4E2DDDAE9E4E1\
EBE5E2E4DEDBDBD7D5D2CFCDCCCAC8C9C6C4C6C3C1C1BEBCBEBBB8B9B6B3B4B1AF
B1AEABADAAA7A9A6A4A6A3A0A29F9D9E9B99999795959391908E8C8B898887848385817F827E7C\
817C7A7F787579716F716A686762605C5856504E4D464545393B3B2D3030242626
2526262C2D2D3333333939393F3F3F4646454C4C4B5352515A5858605F5E6765646D6B6A747170\
7A7876807E7C878482
93908E9996949F9C9AA5A2A0ABA8A6B2AEACB8B4B2BEBAB8C5C1BECBC7C5D2CDCBD8D3D0DED9D6\
E4DEDBE5DFDCDED8D5D5D1CECECAC8C9C5C3C6C2C0C3BFBCC0BBB7BBB6B3B5B1AE
B2ADAAADA9A6A9A6A2A6A29FA19E9C9C9A9798969493918F8F8D8B898786848280817F7D7E7C7B\
7F7B797C7675746F6E6E696765615F5856554C4C4C424343383A3B2D2F302C2D2D
3232333838383D3D3D4343424848484E4D4D5453525958585F5E5D6563636B6968716F6D767473\
7C7A78827F7E878583
928F8E9894939D9A98A29F9DA8A4A2ADAAA8B3AFADB8B4B2BEBAB8C3BFBDC9C4C2CEC9C7D3CECC\
D8D3D0DED8D5DED8D5D7D1CDCFCAC7C8C3C1C5C0BDC2BDBAC0BAB6BBB5B1B5B0AC
B1ACA9ADA8A5A9A5A1A6A19EA19D9A9C9996979492918F8E8E8C8B8886868281807E7E7D7C7B7A\
7D7A78797574726E6D6B6867615F5F5555554B4C4C404242393B3A3535363A3A3A
3E3E3E4342424747474C4C4B5150505655545B5A59605F5E6563636A68676F6D6C747271797776\
7E7C7A83807F888584
928F8D9693919B97969F9C9AA4A19FA9A5A3ADAAA8B2AEACB7B3B1BBB7B5C0BCB9C5C0BEC9C4C2\
CDC8C6D2CCC9D6D1CED6CFCCCFC9C5C7C2BEC1BCB9BFB9B6BDB7B4B8B3AFB2ADAA
AFAAA7ABA6A3A9A3A0A5A09DA09C999B9895969391908E8D8D8B8A8786868583827D7D7D7D7C7B\
7C7978767373706E6D6866665F5E5E5656564A4C4C424343414140434242464645
4A49494E4D4D5251505655545A59585E5D5C6261606765646B69686F6D6C7371707875747C7A78\
807E7C858280898684
918E8C9591909995939C9997A09D9BA4A19FA8A4A2ACA8A6B0ACAAB4B0ADB7B3B1BBB7B4BFBAB8\
C2BEBBC6C1BEC9C4C1CDC7C4CBC5C1C6C0BDBFBAB6BBB5B2B7B1AEB3AEABAFAAA7
ABA6A3A9A4A1A6A19DA29E9A9E9A989B9895969391908E8E8C8B898887878584847E7E7E7D7D7C\
7A7978757373706D6D6766665F5F5F5A59584C4D4D4B4B4A4E4D4D504F4F525251
5554545857575C5B5A5F5E5D6261606664636968676D6B6A716F6D7472717875747B79787F7C7B\
82807E8683828A8785
908D8B93908E9693919996949C99979F9C9AA39F9DA6A2A0A9A5A3ACA8A6AFABA9B2AEABB5B0AE\
B7B3B1BAB5B3BDB8B5BFB9B6C0BAB7C0BAB7BEB8B4B6B1ADB2ACA8ACA8A5AAA5A2
A7A2A0A6A19EA29E9A9F9B989C99979B9895969390928F8E8D8B8A8988888584848180807D7D7D\
7A7979767474706E6D6A69696362615D5C5B5756555958575B5A595C5B5B5F5D5D
615F5F6362616664636867666B69686E6C6B716F6E7371707674737977767C7A787F7C7B827F7E\
8582808785838A8786
8F8C8B928E8D94918F9693919995939B98969D9A98A09C9AA29E9CA4A19FA6A3A1A9A5A3ABA7A5\
ADA9A6AFAAA8B0ACA9B2ADAAB3AEABB3AEABB4AFABAFAAA7ACA6A3A8A4A1A39F9D
A19D9AA19D9A9F9B989D99979B9795989593959190928F8E8E8B8B8B89888685848382827F7F7F\
7B7A7A787775706F6E6E6D6C6A68686664646664646765646866656967666A6968
6C6A696E6C6B706E6D72706F7472707674727876747A78767C7A787E7C7A807E7C82807E858280\
8784828986848B8886
8F8B8A908D8B928E8D93908E9592909693919895939996949B98969C99979E9A999F9C9AA19D9B\
A29E9CA39F9DA4A09EA5A19FA6A29FA6A29FA6A19EA4A09DA39E9BA29E9B9C9997
9A97949B98969A97959B979499959395929093908F918E8D8E8B8A8C8989898786868484838180\
7C7B7A7C7B79777574767473767372747271747170747271747271757372767473
7775747876757A77767B78777C7A787E7B7A7F7C7B807E7C827F7E83807F858280868382878583\
8986848A87868C8987
8E8B898F8B8A8F8C8B908D8B918E8C928F8D928F8E93908E94918F959290969290969391979492\
989492989593999593999694999694999694999593999593989492979391959290
94918F95918F94908F95918F95918F928F8D908E8D8F8C8B8E8B898C8A888B8987898786878483\
82807E83817F82807F827F7E817F7D817E7D817E7D817E7D817E7D817F7D827F7E
82807E83807F83817F8481808582808583818683828784828785838885848986848A87858A8786\
8B88868C89878C8988
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0116279 0.732558 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(270) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
767E7F767E80777F80777F80777F81778081778081788082788182788182788183788283798283\
7982847983847983857983857984857A84867A84867A85877A85877A86887A878A
7985877A85867A84867A84867A84857A84867A85867B85867B85867B85867C85867B85857B8485\
7B83847B82837A8182798081798080787F7F787E7E787C7C777B7A767979757776
737473757877757A7A767B7B767C7C767C7C767C7C767C7D767D7D767D7E767D7E767D7E767D7E\
767D7E767E7E767E7F
767E80777F807780817880827881827982837982847983847A84857A84867B85877B85877B8688\
7C87897C878A7C888B7D898B7D898C7D8A8D7D8B8E7D8B8F7E8C907E8D917D8F93
7D8D907D8C8E7D8B8D7E8B8D7E8A8C7E8B8C7F8B8D808C8D808C8E808C8D818C8D818B8B808A8A\
7F88887F87867D85847D83837C81817B807F7A7E7D797B7A77787675757373716E
726F6C747472757775767877767A79767A7A777B7B777B7B777C7C777C7C777D7D767D7D767D7E\
767D7E767D7E767E7E
777F807780817881827981837982847A83857A84867B86877C86887C888A7D888A7D898B7E8A8D\
7F8B8E7F8C8F808D90808E91818F9281909481919581929681939881959981969C
819498819295819194819193829192829193839193849292849292849292849191848F8F838D8D\
828B8B818A898188878086857F83827E817F7C7D7C7A7A7878767375726E726C67
726D6974716E757472767775777877777978777A79777B7A777B7B777C7B777C7C777C7D777D7D\
767D7D767D7E767D7E
777F807880827982837982847A84857B85877C86887D888A7E898B7E8A8D7F8B8E808D90818E91\
81909382919483929684949784959985969B85989C85999E859A9F859BA1859DA3
849A9F85989C85979A859799859698869698869697869596859596869595869494869392859190\
858F8E848E8C848B898287868184827F817F7D7D7B7B797679757176706B736A65
746D6975706D767370777573777775777876787978787979777A7A777B7A777B7B777C7C777C7D\
777D7D767D7E767D7E
777F807881827982847A84857B85877C87897D898B7E8A8D808C8E818D90828F92839194839396\
84949885969A86989C87999E889BA0899DA2899EA489A0A589A1A789A2A989A3AA
88A0A5889EA3889DA0899C9F899B9E899B9D8A9A9B8A9A9B8A9A9A8A99998A9898899696889493\
889291878F8E878D8B858A8883858382827F7F7E7B7C79757A746F776E69746963
756D6876706C77726F787471787673787775787877787978787A79787A7A787B7B777C7B777C7C\
777C7D777D7D767D7E
7780817982837A83857B85877C87897E898B7F8B8D808D8F818F9283919484939685959886979B\
87999D889B9F8A9DA18B9FA48CA1A68DA3A98DA5AB8EA7AD8EA8AF8DA9B08CA9B0
8CA6AC8BA4A88CA2A68CA1A48CA0A28DA0A18D9FA18E9FA08E9F9F8E9E9E8D9C9C8D9B9A8D9998\
8C96958C93928B908E898B8A878785848380827E7B7F79757C736E776C66766A63
776D6878706B78726E797470797572797774797876797977787978787A79787B7A787B7B777C7C\
777C7C777D7D767D7E
7780817982847B84867C87887E898B7F8B8D808D90828F9283929585949786969A88999D899B9F\
8A9DA28CA0A58DA2A78EA4AA8FA7AD91A9B092ACB393AEB593B0B892B1B98FAEB6
8EAAB08EA8AD8FA7AB8FA6A890A5A791A5A691A5A691A4A592A4A492A4A492A2A292A0A0919E9D\
919A999097958F93918D8F8D8A8A8888858285807D817A757D736E796C65796C65
796E6879716B7A726E7A74707A75727A76737A7775797876797977797A78787A79787B7B787C7B\
777C7C777D7D767D7E
7880827983847B85877D888A7F8A8D808D8F828F9284929585959887979B899A9E8A9CA18C9FA4\
8DA2A78FA4AA90A7AD92AAB093ADB395B0B796B3BA98B6BE9BBBC394B5BE90AFB7
91AEB391ACB192ABAF93ABAD94AAAC94AAAC95AAAB95AAAA96AAAA96AAA997A8A897A6A597A3A2\
969F9E949B999397959192908E8C8A8B878487817D837B7680746F7B6D667B6E67
7B706A7B716C7B736E7B74707B75717B76737A77747A78757A7876797977797A79787B7A787B7A\
777B7B777C7D767D7E
7881827A84857C87887E898B808C8E828F9184929586959887979B899A9E8B9DA28DA0A58FA3A8\
90A6AC92A9AF94ACB395AFB697B3BA99B6BD9BB9C19DBEC69EC0C88FB2BB91B1B9
93B0B694B0B595B0B396AFB297AFB198AFB099AFB09AAFAF9AB0B09BB0AF9CAEAE9CACAB9BA8A6\
9AA3A2999F9D979A98949592918F8C8E89868A837F867D788377717E70697E716A
7E726B7D726D7D736E7D746F7C75717C76727B77737B78757A78767A7977797A78797A79787B7A\
787B7B777C7C767D7E
7881827A84867D87897F8A8D818D9083919485949787979B899A9E8B9DA28EA1A590A4A992A7AD\
94ABB195AEB497B1B899B5BC9BB8C09DBCC49EBFC8A1C4CD96BAC48CB0BA92B3BB
95B4BA97B5B999B4B89AB4B79BB4B69CB4B59DB4B49EB5B59FB6B5A0B5B4A0B3B2A0B0AE9FABA9\
9EA7A59DA2A09B9D9B97979494918E908B878C8580897F7A85797381746D81736C
80736D80746D7F746E7E756F7E75717D76727C77737C77747B78757A79767A7978797A79787B7A\
787B7B777C7C777D7D
7881837B85867D888A808C8E828F91849296879699899A9D8B9DA18EA1A590A4A992A8AD94ABB1\
97AFB599B3BA9BB6BE9DBAC29FBEC6A1C2CBA4C7D19BC0CA90B6C093B6BF96B7BE
98B8BE9AB9BE9CB9BD9DB8BB9FB8BA9FB8B9A0B9B9A1BAB9A3BCBAA3BAB8A4B7B5A4B4B1A3AFAC\
A2A9A7A1A5A29E9F9C9B9996979390938D898F87828C817C887D7686787183746E
82746E82746E81756F80756F7F75707E76717D76727C77737C78757B78767A7977797A78797A79\
787B7B777C7C777D7D
7982837B85877E898B818D8F83909386949888989C8B9CA08DA0A490A4A992A8AD95ACB197AFB6\
9AB3BA9CB7BF9EBBC3A1BFC8A3C3CCA4C7D19FC4CF94BBC696BBC597BBC49ABBC2
9CBCC29EBDC3A0BDC1A1BDBFA2BCBEA3BCBDA4BDBDA5BDBCA6BDBCA7B9B8A7B6B5A7B2B0A7AEAD\
A6AAA8A5A6A4A1A09E9E9A979A9490958E899188838E837E8A7F78887A73867770
85756E84756E83756E82756F8075707F76717E76727D77737C77747B78757A79767A7978797A79\
787B7A777C7C777D7D
7982837C86887F8A8C828E9184929587969A8A9A9E8D9FA390A3A792A7AC95ABB198AFB59AB4BA\
9DB8BFA0BCC4A2C0C9A4C5CEA7C9D2AACED89DC4D099C0CB9ABEC89BBEC79EBFC6
A0C0C7A3C2C7A5C2C5A5C0C2A6C0C0A7C0C0A7C0BFA8BDBDA9BABAAAB7B7A9B1B1A9AEADAAAEAD\
A9ABA9A8A6A4A4A19EA09A989B9592978E8A93898490847F8D807A8B7C75897971
86756D86766E85766E83756F82756F8076707F76717E76727D77737C78747B78767A7977797A79\
787B7A777C7C777D7D
7982847C87887F8B8D83909286949789989C8C9DA18FA1A592A5AA95AAAF97AEB49AB3B99DB8BE\
A0BCC4A3C1C9A6C5CEA9CAD3ABCFD9A5CCD898C0CC9BC1CB9DC1CB9FC1C9A1C2C9
A4C4CAA7C6CBA9C6C9A9C4C4AAC3C3ADC3C3A9BBBBA8B7B8A9B3B4A9B1B1A9B1B0ACB0AFADAEAD\
ACA8A7ACA6A4A8A2A0A39B999D9592988F8A94898491847F90817B8E7D768C7B73
8A787088766E87766E85756E83756F81756F8075707E76717D76727C77747B78757A7977797A78\
787B7A787C7B777D7D
7983847D8789808C8F8491938795998A9A9D8D9FA391A4A894A8AD97ADB39AB2B89DB7BDA0BCC3\
A4C1C8A7C6CEAACBD3ACCFD8B0D4DEA1C8D49BC1CD9DC2CC9FC3CCA1C3CAA4C5CB
A7C7CDABC9CDACC8CAAEC6C7ABBEBFA8B7B8A3B1B2A7B2B3A9B1B2ABB2B2ADB3B3ADADACACABAA\
ADA9A7AEA9A7ABA3A1A59C999E95929A8F8A96898493857F92827C9180788F7D75
8D79718B766C8A766D87766D84756E82746E80756F7F75707D76717C76737B77747A7876797978\
787A79787B7B777D7D
7A83847D888A818D8F85929588979A8C9CA08FA1A593A6AB96ABB099B0B69CB5BBA0BAC1A3BFC7\
A7C5CDABCBD3AFD0D9B0D4DDAFD5DF9CC3D09CC2CE9FC3CDA1C4CCA4C4CBA7C6CC
AAC9CEAEC8CCADC5C7ADC1C2A4B6B8A6B6B8A8B7B8AAB6B7ACB7B9AEB8B9B0B8B8B0B4B2B0B2B1\
AEADACACA9A8A8A29FA59D9AA097939B908B97898495868094847D94827A927F76
907B728E786E8C776F89766D85746C82736D80746E7F746F7E75707C76727B77747A7875797977\
787A79787B7B777C7D
7A83857E898A828E908693968A999C8D9EA291A3A895A9AD98AEB39CB3B99FB8BFA2BEC5A6C3CB\
AAC9D1AFD0D9B6D8E2B5D9E3A7CEDA98C0CD9DC2CDA1C4CDA4C5CDA6C5CCA9C6CC
ACC8CDACC4C8A9BDC0A6B6B9A3B2B4A8B4B6ABB7B8ADB8B9B0BCBCB2BCBCB3BCBBB3B8B7B3B6B5\
B1AFADAFADAAABA6A2A7A09CA199949B8F8A98898497868097867F97847C958078
937C7391796F8D766C89746A84716A82726B80726C7F736E7E746F7C75717B76737A7775797977\
787A79787B7B777C7D
7A83857F898B838F918795988B9A9E8FA0A493A6AA97ABB09AB1B69EB6BCA1BBC2A5C1C8A8C6CE\
ACCCD5B1D3DCB7DAE4ACD1DC9BC3CF9BC1CDA0C4CDA3C5CDA6C5CCA9C5CBABC7CC
AEC7CCAEC4C7ABBDBFAAB9BBAAB7B9ACB6B8ADB7B8AFB8B9B1B9BAB4B9BAB4B8B8B5B5B5B4B1B0\
B3AEADB0ADAAADA7A3A9A19DA399959B8E8A99888499878199878099857C988279
957E75947C71947B708A736A846F6882706980716A7F726C7D736E7C74707B75727A7774797876\
787978787B7A777C7C
7B84857F8A8C8490928896998D9CA091A2A695A8AC99AEB39DB3B9A0B9BFA4BFC6A7C4CCAAC9D2\
ADCED7AFD3DCABD1DD9EC6D399C0CDA0C3CEA3C5CEA6C5CCA9C5CCABC5CBADC6CB
B0C6CBAFC4C7ADBDC0AEBCBEAEBBBCB0BABBB1BABBB3BBBCB5BDBDB7BCBDB8BABAB8B8B7B7B4B3\
B6B1AEB3ACA9AFA4A2A99D9AA394909C8C879987829A87819C87809C867D9A8379
987F75977D72967B6F866E64836D65816E667F6F687E706A7D726C7C736F7B75717A7673797875\
787978787B7A777C7C
7B8486808B8D8591948A989A8E9EA193A4A897AAAF9CB0B69FB6BCA3BCC3A7C2C9AAC7CFACCCD5\
AED1DBAED4DFABD1DDA7CCD7A5C7D2A5C6D0A7C6CEA9C6CCACC6CBAEC5CBB0C6CB
B1C7CBB1C5C8B1C1C3B1BEC0B2BDBEB3BDBEB5BEBEB7BEBEB9BFBFBBBFBFBCBEBDBCBBB9BBB7B5\
BAB3B0B5ADA9B1A6A2AC9F9BA69793A1908B9D8A859D89819E89809E887E9C847A
9A8076997E72997C6F866D62816B61806C647F6E667E6F697D716B7C726D7B74707A7572797775\
787977787A7A777C7C
7B8586818B8D8692958B999C90A0A395A6AA9AADB19EB3B9A2BABFA6C0C6AAC6CDADCBD3AFD0D9\
B1D4DFB1D6E2B0D4DFAED1DBACCCD5AAC9D1ABC7CEADC7CDAFC7CCB1C7CCB2C8CC
B4C8CCB4C6C9B4C3C6B4C0C1B5BFC0B7C0C0B8C1C1BBC1C1BCC1C1BFC2C1BFC0BEBFBDBBBEB9B5\
BBB4B0B6ADA9B2A6A1AD9F9AA89893A4928CA18D86A08C83A18B82A0887F9E847A
9B81769A7E729A7C6F856C62816A617F6B627E6C647D6E677C6F697C716C7B736F7A7571797774\
787877787A79777C7C
7C8586818C8E8793968D9B9D92A2A597A9AD9CB0B4A1B6BCA6BDC3AAC3CAADC9D1B0CFD7B3D4DE\
B4D9E4B4D9E4B5D8E1B2D3DCAFCDD5ADCBD2AFC9CFB0C8CEB2C8CEB4C9CDB5C9CD
B7C9CDB7C7CBB8C6C8B8C3C4B8C0C1BAC1C1BCC2C2BEC2C1BFC3C1C2C4C2C2C2BFC2BEBBBFB9B5\
BDB5B0B8AEA9B4A7A1AE9F99AA9992A6938CA48F87A48E85A48C82A2897F9F857A
9C8176997D72997C6F876E6480685F7E69607D6A627D6C657C6E687B706B7B726E7A7470797673\
787876787A79777C7C
7C8587828D8F8895978E9C9F94A4A79AABAF9FB2B7A4BABFA9C1C6AEC7CEB1CED5B5D4DCB7D9E3\
B9DEE8BADDE6B9DBE4B5D2DAB1CDD4B1CBD2B2C9D0B4CACFB6CACFB7CBCFB9CBCF
BACBCEBBCACCBCC8CABBC5C6BBC2C2BDC3C3BFC4C4C1C5C3C3C6C4C5C6C4C6C5C2C5C0BDC3BBB6\
BFB5B0BBAEA9B6A7A1B1A099AC9A92AA958DA9928AA89087A68D83A48A80A1867B
9C8176987C7092776C856D637F675D7C655C7C685F7C6B637C6D667B6F697B716D7A7370797573\
787876777A79777C7C
7D8687838E908A9698909EA196A6A99DAEB1A2B5BAA8BDC2ADC4CAB2CCD2B6D2DABAD9E1BDE0E9\
BFE4EDBFE2EABCDAE2B7D0D8B5CDD4B5CBD2B6CBD1B7CCD0B9CDD1BBCED2BCCED1
BDCED0BFCCCFBFCACBBEC6C6BEC4C3C0C5C4C2C7C5C4C7C5C6C9C6C9C9C6CAC7C3C8C2BDC6BDB8\
C2B6B1BEB0AAB8A8A1B3A099B09B93AE9890AD968DAC948AA99186A68C81A2877C
9D8276977C7091766B866C607B6055765E557B665D7C69617C6C657B6E687B716C7A736F797572\
787775777978777C7B
7D8688848F918B979992A0A299A8ABA0B0B4A6B9BDACC1C5B2C8CEB7D0D6BCD8DEC0DEE6C3E5ED\
C4E6EEC3E0E8BED6DEB8CFD6B6CDD3B8CDD2B9CDD2BBCED2BDCFD3BED0D3C0D1D3
C1D0D2C2CFD0C1CCCDC1C9C8C1C7C5C3C7C5C5C8C5C6C8C5C9CAC7CCCAC6CDC8C3CBC3BEC9BEB8\
C4B7B1C0B0A8B9A8A0B6A29AB49E96B29C92B29A8FB0978CAC9387A98E82A4897D
9F8377997C7093786B8A6E628164587E64597D665D7D69607C6B647B6E677B706B7A726E797471\
787775777978777B7B
7E87888590918D999B94A2A49CAAADA3B3B7AABCC0B0C4C9B7CDD2BCD5DBC2DDE4C7E5EDCAE9F1\
CBE7EFC7DFE7C0D4DCBACED5B9CED3BACED3BCCFD3BED0D4C0D2D5C2D3D6C4D3D5
C5D3D4C5D1D2C5CFCEC5CBCAC4C9C7C5C9C6C7C9C6C9CAC6CCCCC7CFCCC7CFC9C4CEC4BECABEB7\
C6B7B0C1B0A8BDAAA2BBA69DB9A298B7A095B69D92B4998EB09589AC9084A88A7E
A284789C7E7195796D8D706386685C82675B7F675D7E685F7D6B637B6D667B6F6A7A716D797470\
787674777978777B7B
7E87888691928E9A9C96A3A69EADAFA6B6B9AEBFC3B5C8CCBCD1D6C2DADFC9E3E9CFECF3D4EFF5\
D4EBF1CCE0E6C1D4DABBCED4BBCED3BCCFD3BED0D4C1D2D6C4D4D6C6D5D7C8D6D6
C9D5D5C9D3D3C8CFCFC7CCCBC7CAC8C7C9C6C9CAC6CCCBC7CFCCC8D1CCC7D2C9C4D0C5BECDBFB8\
C9B8B1C5B3AAC2AEA4C0A99FBEA69BBCA398BA9F94B79B8FB3978AB09184AB8C7F
A586799F8073997C709172668A6C5F83665A80665C7E685E7D6A627C6C657A6E687A716C797370\
787673777877777B7B
7F8889879293909B9D99A5A7A1AFB2AAB9BCB2C3C6BACCD0C1D6DAC9DFE4CFE8EDD7F1F7DDF2F7\
D8EAEECDDFE3BFD1D7BCCDD3BCCED2BECFD3C0D1D4C4D3D6C7D5D7CAD7D7CCD7D7
CDD7D6CCD5D4CBD1D0C9CECCC8CBC8C9CAC6CBCAC6CDCBC7D1CDC8D4CEC8D5CBC4D3C6BFD0C1B9\
CDBAB2CAB5ACC7B1A7C6ADA2C3AA9EC1A69ABEA296BB9E91B7998CB39486AE8E80
A8887AA383759E7E719574678C6D608463568165597F675D7D69607C6B647A6D6779706B78736F\
787573777877767B7B
7F8889899294929D9E9BA7A9A5B2B4AEBCBFB7C7C9C0D1D4C8DBDECFE4E8D6EDF1DCF4F8DFF1F4\
D7E8EBCBDCE0BBCDD3BACBD1BCCDD1BECED2C1D0D3C6D4D6CBD7D8D0DADAD2DBDA
D3DAD8D0D7D5CDD1D0CACECCC9CBC8C9C8C4CBC8C4CECAC5D2CDC7D6CDC8D7CBC5D6C7C0D4C2B9\
D1BDB3CFB8AECEB5AACBB0A5C8ACA0C6A89CC2A397BE9F92BA9A8CB69587B19082
AC8A7CA78577A281739878698D6C5E8461548163577F655B7D675F7B6A627A6C66796F6A78726E\
777572777876767B7B
80898A8A9395949EA09EA9ABA8B4B6B2BFC1BCCBCDC6D6D8CFE0E3D6EAEDDDF2F6E2F6F9E7F5F7\
DDE8EBCAD9DDB7C9CFB8C9CEBACACFBDCCCFC1CFD1C6D2D4CBD5D6D0D8D7D4D9D7
D4D9D6D0D5D3CCCFCDCACDCAC9C9C6C7C5C1CAC6C1CEC8C3D3CCC6D7CDC7D9CCC5D9C8C0D8C4BA\
D4BEB4D3BAAFD1B7ABCFB3A7CDAFA2CAAB9EC4A598C0A092BD9C8DB99788B59283
AF8C7DAB8778A582739876678B695A835F508061557E64597C665D7B6961796B65786E6978716D\
777472777776767A7A
80898A8B9495959FA1A0ABACABB7B8B6C3C4C1CFD0CCDBDDD7E7E9DFF0F3E3F7FAE6F6F8E7F2F4\
D8E3E6C5D4D8B2C5CBB5C5CBB8C8CCBCCACDC0CCCEC4CFD0C8D2D1C9D2D0CED3D1
CDD2D0C7CDCBC4C7C5C2C4C2C0BFBCC2BDB9C8C2BDCEC6C0D4CBC5D8CEC6DBCDC5DBCAC0DCC8BD\
D8C0B5D9BEB2D9BCAFD7B8ABD1B2A4CDAC9EC6A698C3A293BF9D8EBC9889B79383
B28E7EAF8A79A984739A76668B6758825C4E805F537D62577B655B7A675F786A64776D6877706C\
767371767775767A7A
81898A8C959697A1A2A2ACAEAEB9BABAC5C7C6D3D4D4E1E2E1EFF0EEFDFEEBFBFDEAF6F6E7EFF0\
D7E1E3C2D1D5AFC1C7B2C3C8B6C5C9BAC8CABECACBC2CCCCC5CDCDC6CECCC8CECC
C2C8C7BDC3C3BBBFBEBABCBBBDBBB8C2BCB8C8C0BBCEC6C0D4CBC5D9CDC6DBCCC3DBC8BFDBC5B9\
D8BDB1DDBFB1E0BFB0D7B8A9D2B1A2D0AE9FC8A798C4A293BF9D8EBD9888B99483
B6907FB48C7BAD85739B75658A6657815C4E7F5E527C61567A635A78665E776962766C67766F6B\
767370767675767A7A
81898A8D959698A1A2A4ADAEB0BABBBDC8C9CBD6D7DAE6E6EEF9F9F4FFFFEDF8F9EDF4F4E8EEED\
D5DEE0BECDD2AABDC3AFBFC4B3C2C5B9C7C8BDC8C9C0C9C8C3CAC9C5CAC9C5CAC7
C3C7C5BFC2C1BCBEBBBBBAB8BEBAB6C3BCB7C8C0BACFC5BFD5CBC3D9CCC4DCCBC2DBC7BDD9C3B7\
D7BDB1D7BCAFD8BAACCEB1A4CCAD9FC9A99BC1A294BE9E8FBC9989BD9786BC9483
BA917FBA8F7CAE85739A7565886657805C4D7D5D507A5F5478615876645C756761756A65756E6A\
75726F757674757A79
82898A8D959699A2A3A6AFAFB2BCBCC0C9CACED8D8DEE8E8F0FAFAEEF7F7EAF2F3E5EBEBDFE5E5\
CBD7DAB8C8CDA7BAC0ACBCC1B0BEC2B5C1C3B9C2C3BEC6C5C2C8C7C5CAC7C7C9C6
C6C7C4C2C2BFC0BFBCBFBCB9C0BAB5C4BCB6C9C0B9CFC6BFD5CAC2DACBC2DCCBC1DCC8BCDBC3B7\
D8BEB1D6BAADD1B5A7C7AC9FC4A89BC1A496BC9E90BC9B8CBE9989BF9886BF9583
BF9380BE917DAD83719773638664567E594A7B5B4E785C52765F5674625A73655F736964736D69\
74716E747574757979
828A8B8E96979AA2A3A7AFB0B4BCBDC1CACAD0D8D8DFE8E8F0F8F8EDF4F4E8EEEEE0E6E7D5DDDF\
C4D0D4B4C3C8A5B7BDA9B9BDAEBBBDB2BCBEB6BEBFB9BFBEBCC0BEBFC1BEBDBFBC
BCBDBBBABAB7BAB8B5BBB7B3BDB6B2C4BBB5CAC1BAD0C6BED6C9C1DACAC0DCCBBFDEC9BDDEC5B8\
DABFB1D8BBADD3B6A8CDAFA1C8A99BC4A495C19F90C29E8DC29C89C39A87C39884
C49682C0927DAC816F926F5F8564557C574978584C745A4F725C53715F5871635D716762716B67\
72706D737473757979
828A8B8E96979BA3A3A7AFB0B4BCBDC2CACAD0D8D8DFE7E6EEF6F5EBF1F0E3E9E9DAE1E2CFD9DA\
C0CCCFB0C0C4A4B6BCA7B6BAABB7BAB0B9BAB4BBBAB7BBBAB9BBB9B9B9B7B8B8B5
B9B7B4B9B6B2BAB5B1BCB6B2C1B9B4C7BEB7CDC3BCD2C7BFD7C8C0D9C9BFDBC8BCDCC5B9DCC2B4\
DCBFB0DCBDAED6B8A8D1B2A2CEAD9DCBA898C8A493C7A18FC69E8BC69B88C69A85
C99983BF907BA87F6C926F5F896657805B4C74554970554B6E58506D5C556D605A6E65606F6966\
716E6C727372747978
828A8B8E96979BA3A3A7AFAFB4BCBCC2C9C9D0D7D6DEE5E4EDF3F2E8EEECE0E6E5D6DEDECAD4D6\
BBC9CCAEBEC2A3B5BAA5B3B7A9B5B7AEB7B7B2B8B8B5B9B8B8BAB7BAB9B6BBB9B6
BCBAB6BEBAB5C0BBB6C2BCB7C6BFB9CBC2BBD0C6BED4C8C0D7C9C0DAC9BEDAC7BBDBC5B7DAC1B3\
D7BBADD6B8AAD4B5A6D5B3A3D3B09FD1AB99CDA795CBA390C89E8AC79C87CA9B86
CC9983BC8D78A87D6A9671608965557B5749694B4069504668544C6958516A5D576B625E6D6864\
6F6D6B717371747878
828A8B8E96979BA2A3A7AFAFB4BBBBC1C8C8CFD6D5DDE3E2EAF0EFE4EAE9DEE4E3D3DBDBC7D2D3\
BAC7C9AEBDC1A5B5BAA5B2B6A8B3B5ADB5B6B1B7B6B5B8B6B8B9B7BBBAB7BDBBB8
C0BCB8C2BDB9C5BFBBC8C1BCCBC3BDCFC6BFD3C8C0D7CBC1D9CAC0DBC9BEDCC8BBDCC5B8DCC2B4\
DABEAFD7B9AAD3B3A4CFAE9FCDAB9ACCA896C9A492C9A08DC89E89CC9D88CD9B86
CB9881B98975A67B68946D5D825E5072504461453B614A41624F4763544E655A5568605B6A6662\
6D6C6A707271737878
828A8A8E96969AA2A2A7AEAEB4BABAC1C7C7CED4D3DBE1E0E9EFEDE3E9E8DCE2E1D1D9D9C6D0D1\
BAC6C9B0BDC1A8B6BAA5B2B5A7B2B3ACB4B4B1B6B4B5B7B5B9B9B6BDBBB8C0BDB9
C3BFBBC6C1BCC9C4BECCC5BFD0C8C1D3CAC2D7CCC3DACDC3DCCCC1DDCBBFDEC9BCDEC7B9DEC4B5\
DCC0B1DABBABD6B6A5D2B0A0CFAC9ACCA795CBA491CCA28DCDA08BCF9E89D09C86
C9957FB58671A076648E68587A5A4C694C415A423859443C5B49425E504A615651645D59686361\
6B6A686F7170727777
82898A8E95969AA1A1A6ADADB3B9B9C0C6C5CDD2D1DADFDEE7ECEBE1E5E4DADFDED0D7D7C7CFD0\
BCC6C8B3BEC1AAB7BAA6B2B5A6B0B2ABB3B2B1B5B3B6B7B5BABAB6BFBDB9C3BFBB
C6C2BDCAC5C0CDC7C2D1C9C3D4CCC4D8CDC5DBCFC6DECFC4DFCEC2E0CDC0E1CBBDE1C8BAE1C5B6\
E0C1B2DDBDACDAB8A7D7B3A2D5AF9DD3AB98D3A894D3A590D3A28DD4A08AD29C85
C5917BB0816D9C726088635474554860463C513C334E3B3453433D584B465C534E615A5765615F\
6969676E706F727777
82898A8D959599A0A0A5ACACB2B8B8BEC4C3CBD1CFD8DDDCE5EAE8DEE3E1D7DCDBCFD5D5C6CECE\
BCC5C6B3BDBFAAB6B8A6B2B4A5AFB0ABB2B1B1B5B3B7B8B5BCBBB7C1BEBAC5C1BC
CAC4BFCDC8C2D1CAC4D5CDC5D9CFC7DCD1C8DFD2C8E1D2C6E2D0C4E3CEC1E4CCBEE4CABBE4C7B7\
E3C3B2E0BEADDEBAA8DCB6A3DAB29ED9AE9AD8AB96D6A791D6A48ED5A18ACE9982
BC8B75A87B68946C5B7F5C4E694D41543E3546332B43322C4B3D38524742584F4B5D585562605D\
6767666C6F6E717676
81898A8D9494999F9FA4ABABB0B7B6BDC2C1C9CFCDD6DBD9E3E7E5DDE0DED5DAD8CED4D3C6CDCD\
BEC6C6B3BDBFABB7B8A6B2B4A5B0B1ABB1B0B2B5B3B9B9B5BEBCB8C4C0BBC9C4BE
CDC7C1D1CBC4D6CEC6D9D0C8DDD3CAE0D4CAE3D5C9E5D4C8E6D2C5E6D0C2E7CEBFE7CBBBE6C8B7\
E6C4B3E4C0AEE2BCA9E0B8A5DFB4A0DDB19CDBAC97DAA992DAA58ED59F88C8947D
B58570A075628964547354475D443948352D362721392B264438334C433F534C495A5553605E5C\
6666656B6E6E717676
8189898C9394989E9EA3A9A9AFB5B4BBC0BFC7CCCBD4D9D7E1E5E2DADEDCD3D8D6CDD2D1C7CDCC\
BEC4C4B4BDBDAEB7B8A9B2B4A9B1B1ADB1B0B4B5B2BBBAB6C1BEB9C7C2BCCCC6C0
D1CAC3D6CEC7DAD1CADED4CBE2D6CDE4D7CDE7D8CCE8D6C9E9D4C6EAD2C2EACFBFEACCBBE9C8B7\
E8C5B3E7C2AFE5BDAAE4B9A5E2B5A0E0B19CDFAD97DDA992D9A38CD09B84C08D77
AC7D6A956C5B7E5C4E674B40513B323D2D262D201B362A263F353148403D504A475753515E5C5B\
6465646A6D6D707676
8188898C9393979D9DA2A8A7ADB3B2B9BEBDC5C9C8D1D5D3DEE1DFD7DBD9D1D5D4CCD0CEC6CBC9\
BEC4C3B7BEBEB1B8B9ADB4B4AEB4B3B1B4B2B7B6B3BDBBB7C4C0BBCAC5BED0C9C2
D5CEC6DAD1CADFD5CCE3D8CEE7DACFE9DACEEBDACDEDD8CAEDD6C7EDD3C3EDD0BFECCDBBECC9B7\
EAC6B3E9C2AFE7BEAAE6BAA5E4B6A0E4B29CE2AE97DEA991D7A189CB967FB88671
A276638A65547454475D443945332A30231E261B173228243C3330453E3B4D48465552505C5B5A\
636463696D6D707576
8088888B9292959C9CA0A6A5ABB0AFB6BBBAC1C6C4CDD1CFDADDDBD4D8D6D0D2D0CACECCC6CAC8\
C0C5C3B9BEBEB5BAB9B2B7B5B3B7B5B4B6B3B9B8B4C0BDB8C8C2BDCEC7C1D4CCC5
DAD1C8DFD4CCE4D8CEE8DACFEBDCD0EEDDCFF0DDCEF1DACBF0D7C7F0D4C3EFD1BFEFCEBCEECAB7\
ECC6B3EBC2AEEABEA9E8BAA5E7B6A0E6B29BE2AE96DDA78ED29C84C18E78AC7D69
946C5B7E5C4C674B3F4F3A303628212016122117142E262339322F423D3A4B47455351505A5B59\
626463696C6C6F7576
8087888A9191949A9A9EA4A3A8AEADB3B8B6BEC2C0C9CDCBD5D8D6D2D4D2CDD0CDC9CCC9C5C8C6\
C1C4C2BCBFBDB8BBB9B7B9B7B7B9B6B8B8B5BDBAB6C4C0BACCC5BED2CAC2D9CFC6
DFD3C9E5D7CCE9DACFEDDDD0F1DFD1F3DFD1F4DECFF4DBCBF4D8C7F3D4C3F2D1BFF1CEBBF0CAB6\
EEC6B2EDC2ADECBEA9EABAA4E8B59EE5B099E0AB93D7A189C8947EB685709F7461
8763537152455A42374130282B1F1A1B120E231B182D262337312F403C3A49474551514F595A59\
616363686C6C6F7576
7F87878990909299989CA2A1A6ABAAB0B4B3BABEBCC4C8C6D0D3D0CFD1CECBCDCAC7CAC7C5C6C4\
C1C3C0BDBFBCB9BBB8B8B9B6B9B9B6BCBAB6C1BCB7C8C2BBD0C8C0D7CDC4DED2C8
E5D6CBEADACDEEDDCFF2DFD1F6E1D2F9E1D1F9DFCEF8DCCAF6D8C6F5D4C2F4D1BEF3CDBAF1CAB5\
F0C5B1EEC1ACECBDA7EAB9A2E7B49CE2AD96DBA68ECE9982BC8A75A77A67906A58
79594A64493D4C372E32251F1F1713150D0B201A182B262435312F3F3C3B484745515150595A59\
606363686C6C6F7576
7F8687888E8F9197979A9F9FA3A8A7ACB1AFB5B9B8BFC2C0C8CBC8CBCDCAC9CAC7C6C7C4C2C3C1\
C0C1BEBCBDBAB9BAB6B9B9B5BAB9B5BEBBB5C3BDB7CCC3BBD3C9C0DBCEC4E4D4C8
EAD8CBEFDCCEF4DFD0F7E1D1FBE3D2FEE3D2FDE0CEFADCCAF8D7C5F6D3C0F5D0BDF4CCB8F2C8B4\
F0C4AEEEBFA9EBBAA4E8B59EE3B098DBA890D19D86C08F79AC7F6C976F5E805F4F
6A4E41533D333B2B25241B17120B09110B091F1A182A26253532303F3D3B484746505150585A5A\
606363676C6D6F7576
7E8586868D8E8F9595979D9CA0A5A4A8ADABB1B5B3B9BDBAC1C4C1C9CAC7C7C8C5C4C5C1C1C1BE\
BFBFBCBCBCB8B8B8B5B8B7B3B9B7B2BEB9B4C2BCB5CAC2B9D2C7BEDDCEC2E8D5C7
EFD9CBF3DDCEF7DFCFFBE1D0FFE3D0FFE1CFFDDDCBFBD9C6F9D5C2F7D1BEF5CDB9F4C9B5F2C6B1\
EFC2ABEBBCA5E8B69FE3B099DBA992D19E88C3917CB0836F9C7462866354705245
5942374230292B201B18110F0A0604140F0E1F1C1A2B28273533323F3E3D484847505251585B5B\
606464676D6D6F7576
7E8586858C8C8D9393959B9A9CA2A1A4A9A8ACB0AEB4B7B5BBBEBBC4C6C2C4C5C1C0C1BEBEBEBB\
BCBCB8BABAB6B6B6B2B6B4B0B8B5B0BDB8B2C1BBB4C7BFB7D0C4BBDBCBBFE5D1C3
EBD6C7F0D9C9F4DBCAF8DCCAFCDDCAFBDBC8F9D8C5F7D4C1F6D1BCF4CCB8F2C9B4F1C6B0EEC1AB\
EABCA6E5B59FE0B099D9A892CF9F89C2927DB285729E76658967577356495D453B
46342D2F241F1C15120B0806060403151211211E1D2C2A293635343F3F3F484949515352585C5C\
606465686D6D6F7576
7D8485848B8B8B9291929898999F9EA0A5A4A7ACAAAEB2B0B5B8B6BCBEBBC0C2BFBDBEBBBBBBB8\
B8B8B5B6B6B2B2B2AEB4B2AEB7B4AFBCB7B1C1BAB3C7BEB5CEC3B8D7C7BCDFCCBE
E5CFC0E8D0C1EDD3C2F1D3C2F3D4C2F3D3C0F2D0BEF1CDBAEFC9B5EDC5B1EBC2ADE9BEA9E5B9A4\
E1B49EDAAD97D4A691CA9D88BF927FB086749F79688B695A765A4D61493F4A3830
3227211E18150E0B090100000907071715152322212E2D2C373837414141494B4B515454595D5D\
616566686D6E6F7676
7C8484838A8A899090909695969C9B9DA1A0A3A7A6A9ADABAFB2B0B5B7B5BBBCB9BABBB8B7B7B4\
B4B4B1B3B2AFB1B0ACB3B1ACB6B2ACBBB5AFBEB7B0C3BAB1CBBEB3D2C1B6D7C4B7
DCC7B9DEC7B9E3CABAE5CAB9E7CAB9E7C9B8E6C7B5E5C3B1E1BFADDEBAA8DCB6A3DAB39FD6AE9A\
D0A894C9A08DC19886B78F7DAB85749B78688A6B5C765C4F634C424D3C34362B26
201A17100D0C0100000201010F0F0F1B1B1A2626263031303A3B3A4244444B4D4D5356565A5E5E\
616667686E6F6F7677
7C8384828989888E8E8D9393939998999E9D9EA3A2A4A8A6A9ACAAAEB1AFB4B6B3B7B8B5B3B3B0\
B0B0ADB0AFABAFAEAAB0ADA9B1AEA8B7B1ABBAB3ACBFB6AEC7BAB0CBBBB0CFBDB1
D3BFB2D5C0B2D9C1B2D9C0B1DAC0B0DABEAED9BBABD6B7A7D2B3A2CFAF9ECCAB9AC9A695C3A18F\
BD9A89B59382AE8B7BA48273967769866A5D755D52634F454E3F38392F2A231E1B
12100E0201010000000B0B0B1616162021212A2B2B3435353C3E3E4547474D50505458585B6060\
626768696F706F7677
7B8383818788868C8C8B9191909695959A999A9F9E9FA3A2A3A7A5A8ABA9ACAEACB1B2B0AEAEAC\
ACACA9ABABA7AAA9A5ABA9A4AEAAA5B2ADA7B6AFA8BAB0A8C0B3A9C1B3A9C5B6AA
C8B7AACAB7ABCCB7AACDB7A9CDB5A7CBB2A4C8AFA1C5AC9DC1A798BEA394B99E8FB5998AAF9384\
A78C7EA185789A7E71907568826A5E725E536250484E413B3B322E292421161514
0405050000010A0A0B1314141D1E1E2627272F3131383A3A404242484B4B4F5253565A5A5D6262\
6369696A7071707778
7B82837F8687848B8B898F8F8D9393929796969B9A9A9E9D9EA2A0A1A5A3A5A7A5A7A8A6A7A8A5\
A6A7A4A6A6A2A5A4A1A6A4A0A7A4A0AAA6A0AEA8A1B1A9A1B5ABA2B7ABA2BAADA2
BCADA2BEADA2BEACA0BEAB9FBCA99DBAA69AB7A397B4A093AF9B8FAB968AA49084A18C7F9A8579\
947F748E796E8672687B685F6C5C545D50494C433D3B35322A2826191919090B0C
010203090A0B1213141B1C1D2425262C2E2E3437373C3F3F4447474B4E4F525656585D5D5E6464\
646A6B6A7172707778
7A82827E8586828989868D8D8A90908E9493929796959A99999D9B9B9F9E9EA19F9FA2A0A0A29F\
A0A19F9FA09D9F9F9C9E9E9B9F9E9AA29F9AA5A09AA6A09AAAA29AABA299ACA299
AEA299AEA198ADA096AD9F95AC9E93AA9B91A7988DA3948A9F8F85998A8093847B8E7E7486776F\
82746B7C6E6673655E665B5559504B4B45403B38352C2B2A1D1F1F0F1213050708
0809091214141B1D1D2325262B2D2E3335363A3D3D414445484B4C4E52535459595A5F60606666\
666C6D6B7273717879
7A81827D8485818888848B8B888E8E8B91908E9393919695949897969A99989B9A999C9A999C9A\
999B99999B98989A979899959998949997939B98939B98939E99929F98919E9790
9F978F9F968E9F958D9E948B9C928A998F87968C849288808E847D897F788379727D746D78706A\
736B666C645F615A5657524E4C48453E3C3A2F302F222424151919090C0D0A0C0D
1416161C1E1F2426272B2E2F323536393D3D404344464A4A4C5051525757585D5D5D6263626869\
676E6E6C7374717879
7981817C83847F8687828989858B8B888E8E8B90908D92928F9493919594929695939795949795\
94969594969493959392939091918E90908C91908C918F8B938F8A928E898F8C86
8F8B858F8A848F8A838F89828D87808A847E87827B837D787F7A757A757176716D716E6A6D6966\
6B666364605C5A5654504E4B424241333635262A2B191F201115160F1213181A1B
1F222326292A2D30313437383A3E3E404445464A4B4C5051515656565B5C5B6061606566646A6B\
696F706D747572797A
7980817B82837E8585808787838989858B8B878D8D898F8E8B90908C91918D92918E92918E9291\
8E92908E918F8D8F8D8B8D8A8B8C89888A8688888588878388878286858084837E
83827E82807C817F7A817F797E7D787B7A7578777375747172726E6D6D6B6B6B68646564626361\
5E5F5D5557564D4F4E424545363A3B2C31321F2627161B1C171A1B1D2021242728
2B2E2F313536373B3C3D4142424647474C4D4C5152515657565B5C5A60605F6465636969676D6E\
6B71726E7576727A7B
7880807A82827C83847E8586808787828989848A8A868B8B878D8C888D8D898E8D898E8D8A8E8D\
898D8C898C8B878B8985888680838180828080827F80817E7F7F7B7B7C79777976
7677747778747677737375716F726F6F726F6E716E6B6E6D686B6A6569696367665D61625B5F5F\
565A5A4F5353464B4B3C424332393A2C3233202527202425272A2B2C3031323637
373B3C3C4141414646464B4B4B4F504F5455535859575C5D5B61615F6465626869666C6D697071\
6C7374707778737A7B
787F807981817B82837D84847E8585808687818788828889838989848A8A858A8A858A8A858A8A\
858A898489888387868185837E82807B7E7C797C7A777A77757875727673717472
7073716F72706C706E6B706E6B706F6C706F686D6D676C6C656A6B6368695F64655B6161565D5E\
5157594B50514348493C4243353A3B2E32332A2F30313637363B3C3B3F403F4445
434849484D4D4C51514F5555535859565C5D5A60605D636460666763696A666C6D696F706C7273\
6E7576717879737B7C
777F807880817A81827B82837C83847D84847E85857F8686808686808787818787818787818787\
8186868085857F84847D82827B807F797D7C757A796E73726B716F6C72706B7070
696E6D686E6D686F6E696F6F696F6E686E6D656C6C646A6B6067695E65675C6364596062565C5E\
5157584D525344494A3E43443B3F403B3F413F4445424749464B4C494F504D5253
50555653595A565C5D595F605C62625E6465616768636A6A666C6D686E6F6A71726C73746E7576\
70777872797A747C7D
777E7F787F807880817981817A81827B82837B82837C83837C83847D84847D84847D84847D8484\
7D83837C83837C82827B8180797F7F777D7D757A7A7277776F75756C7273676E6F
676D6E686F6F676E6E686E6E696F6F686F6E686E6F666D6E646B6C62696A6067685E65675B6163\
52595A4F55564B51534D52544F54554F5556515758545A5B565C5D585E5F5A6162
5D63645F656661676862696A646B6C666D6E686F6F6970716B72736C73746E75766F7777717879\
72797A737B7C757C7D
767E7F777E7F777F80787F80787F807880817980817980817980817981817981817A81817A8181\
798081798081798080787F7F777E7F767D7E757C7C747B7B72797A7178796F7677
6F76776F76776E75766E75766D7375697172687072676E70666D6F656C6E646B6D626A6B606768\
5E656661686961686962686962696A636A6B646B6C656C6D666D6E676E6F686F70
6970716A71726B72736C73746D74756E75766F767770777870787971797A72797A737A7B737B7C\
747C7D757C7D757D7E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0116279 0.97619 0.233112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(315) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
405C6F405D70405D70405D71405E71415E71415E72415F72415F73425F73426073426074426074\
436175436175436176436276436276446277446377446377446378446378446378
446377446378446378446378446378446378446478446478456478456478446478446478446477\
446376446376446276446275436275436175436174436073436072425F71425E70
425E70425E71425F72425F72425F72425F72415E72415E72415E72415E71415E71405D71405D70\
405D70405C70405C6F
405D70405E71415E72415F7242607342607443617543617544627644637744637845647945657A\
46657A46667B47677C47687D48687E48697F486A7F486A80496A80496B80486A80
486A80496B80496B81496B80496B80496B80496C814A6C824A6D824A6D824A6D814A6D80496B7F\
496A7E486A7D48697C48687C48687B47677B47667A466578466476456274446071
445F71446174446275446276446276446175446175436175436174436074426073425F73415E72\
415E71405D70405C70
405D70415E71415F7342607443617544617644637745647946657A46667B47677D48687E48697F\
496A804A6B814A6C824B6D844C6E854C70874D70884D71894D72894E728A4E738A
4E738A4D72894D72894D72884D72884D72884D72884E72874E73874D73874D73874C72864C7084\
4B6F834B6E824B6F824C6F824C6E824C6D814B6B7F4A6A7D49687B486678466374
466274476577476579476679476579466579466579456478456377446276446275436174426073\
415F72415E71405D70
405D70415E7242607343617544627745647846657A47667B48677D49697E4A6A804B6C824B6D84\
4C6F864D70874E72894F738B50758D51768F517890527992537A93537A93527A93
527A92527A9152799152799152799051788F51778D4F768B4F758A4F75894F75894E75894E7589\
4E75894E75884E74884F74884F73874F72864E70844D6E824C6D804B6B7E4A697C
4A697C4A697D4A6A7E4A6A7E4A697E49687D48677C48667B47667A466579456378446276436175\
426073415E72405D70
405D71425F7343607444627645647846667B48677D49697E4A6B804B6C834C6E854D70874E7289\
50748B51758E527790537992547B94557D97567F9957819B58829C58829D58829C
57819B57819B57809A568098567F97567F95557E94557C92547B90547A8F53798F52798E52798E\
52798E52788E51788D52798D52788C52768B51768A5174895072864F6F834E6E82
4E6E824E6F834E6E834D6E834C6D824C6C814B6B804A6A7F49687D48677C47667A456478446276\
436175425F73415D71
415E7142607344627645637846667A48687D496A7F4B6C824C6E844D70874F728950748C51768E\
537891547B94567D96577F9958829C5A849F5B86A25D89A55E8BA75E8CA85D8BA7
5C89A45C88A25B87A15B86A05B869E5B859D5A859C5A859B59839A588297588096588096578096\
578096577F96577F95567E94567E95567D93567B91567A9054788D537488527387
5274895274895173895073884F71874E70864D6E844C6D824B6B8149697E48687C47667A456478\
446276426074415E71
415E7243607444637746657A48677D496A7F4B6C824D6E854E718850738B51768E537891557B94\
567D9758809A59829D5B85A05D88A45E8BA7608EAB6291AF6495B36597B66395B3
6190AD608FAA608EA8608DA75F8CA65F8CA55F8CA45F8CA35F8BA35E8BA25E8AA15D89A05D89A0\
5D889F5D879E5C869D5C859D5B859C5B849C5B839A5A8097587E95577C91577A90
567A91567A9155799054788E53768C51748A5072884E70854D6E834B6C814A6A7E48687C46667A\
456377436074415E72
415E7243617545647847677C49697F4B6C824D6E854E718850748B52768F547992567C95587F99\
59829C5B85A05D88A35F8BA7618EAB6391AF6595B4689AB96CA0C16B9FC06698B7
6596B36494B06494AE6493AE6493AD6493AD6494AD6494AD6495AD6495AD6495AD6494AC6493AA\
6492A96390A8638EA7628DA6618CA4608AA35F89A25E879F5D859D5C839B5B829A
5B829A5A8098597F96577D94567B9254788F53768C5173894F71864D6E844B6B8149697D47667A\
456377436175415E72
415F7244627646657A48687D4A6B814C6E844E718850748B52778F547A92577D9659809A5B839E\
5D86A25F8AA6618DAA6391AE6594B26798B7699CBC6CA1C26EA4C46BA0C0689BBA
689AB8689AB76899B6699AB5699AB5699AB5699AB4699CB56A9DB66A9FB76BA0B86BA0B86B9EB6\
6A9BB36A98B16996AF6895AD6693AC6691AB6490AA638FA9638EA8628DA7608BA5
5F89A35E87A15D859E5B829B597F97577C94557A9153778D51748A4F71864D6E834B6A8048677C\
466479446276425F72
425F7344627746667A49697F4B6D834E708650738A52768E557A92577D9659809A5B849E5E87A3\
608BA7628FAC6492B06796B5699ABA6B9EBF6DA2C36FA5C9699FC26599BB699DBD
6B9FBD6C9FBE6DA0BD6DA0BD6EA0BC6EA1BC6EA2BC6EA3BC6FA5BE70A6BF70A6BF70A6BE70A5BE\
70A3BC70A1BA6F9EB86E9CB66C9AB46A98B26996B06895B06795B16796B26695B2
6491AD628EA9618BA55F88A15D849D5A8199587D95567A9153768D5173894E70854C6C8249697E\
47667A446276425F73
425F7345637747677C4A6A804C6E844F728852758D547991577D9559809A5C849E5E88A3618CA8\
6390AC6694B16898B66B9CBB6DA0C06FA4C673AACE6DA4C7669BBD699EBF6CA1C1
6EA3C270A4C471A5C572A6C472A7C473A7C373A8C373A9C374ABC574ADC675AEC675AEC575ADC4\
75ABC375A8C174A6BF73A3BD72A0BB709DB86E9CB76C9BB76C9CB96C9EBC6B9DBC
6999B76795B26591AD638DA86089A35E859E5B819A587D9556799153768C5072884D6E844A6B80\
48677B456377425F73
42607445647848677C4B6B814E6F8651738B53778F567B94597F995C839E5E88A2618CA76490AC\
6794B26998B76C9DBC6FA1C271A5C773AACD6EA5C86AA0C36CA2C56EA3C570A5C6
72A7C874AACA76ACCB77ADCB77ADCB78ADCA78AEC978AEC978ACC678AAC579AAC579A9C379AAC3\
7AACC57AACC57AAAC378A7C176A4BF74A2BD72A0BC709FBB6F9FBC6FA1BF6FA3C3
6EA2C26C9CBA6997B46793AE648EA9618AA35E859E5B8199587C9455788F52748A4F6F854C6B80\
49687C456478426073
42607446647949687E4C6D834F718852768D557A92587E975B829C5E87A1618BA6648FAC6794B1\
6A98B76D9DBC70A2C273A7C875ABCE79B1D577AFD471A8CC71A7CA72A8CA74A9CA
76ABCC79AECF7BB1D17CB2D07DB2CF7DB2CF7DB1CE7CAFCB7CA9C57CA5C07CA1BD7BA0BB7DA4BF\
7EA9C47FABC67EACC67DABC57BA8C379A6C277A4C075A2BF73A2BF73A3C173A5C4
72A5C570A3C26E9EBB6B98B56893AE658EA86189A25E849C5A7F97577A9153768C5071874D6D82\
49687D466478436074
43607446657A4A6A7F4D6E8450738A54788F577C945A819A5D859F618AA5648EAA6793B06A98B6\
6D9DBC70A2C274A7C877ACCE7BB2D677AFD472AACE74AACD75ABCD76ABCC78ACCC
7AAFCF7DB2D380B5D581B7D582B7D484B7D382AFCB7EA5C17CA1BB7A9BB57A9DB67DA2BC7FA0BC\
81A1BB83A6C184ADC882AEC97FACC77CA9C47AA7C278A4C177A4C276A5C376A7C6
77AACA76A9C973A4C2709EBB6C98B46892AD648DA66087A05D829A597D9455788E5173894E6E83\
4A697E466579436074
43617547667A4A6B804E708652748B557991597E975C839D6088A2638DA86692AE6A97B46D9CBA\
70A1C174A7C778ACCE7BB1D47EB5D97BB2D676ACCF77ACCF78ADCF79ADCE7BAECF
7DB0D07FB3D282B5D486B8D785B2D07EA4C07B9FBA7D9EB97D9CB77D9EB97D9DB97D9BB57C9BB4\
7E9EB781A3BE86A9C487AEC983AEC980ACC67DA9C57BA7C37AA6C37AA7C57AAAC8
7AABCA7AABCA79A9C775A4C1709DB96C96B16790AA638AA35F849C5B7F9657799053748A4F6F85\
4B6A7F47657A436174
43617547667B4B6B814F708753768D577B935B80995E86A0628BA66590AC6995B26C9AB8709FBE\
73A5C578ABCD7CB2D580B7DA7FB7DA7BB2D579AED17AAED07BADCE7CADCE7EAFCF
80B0D082B0CF82AFCD81ACCB80AAC87FA9C780A8C681A7C581A7C482A8C682A8C582A8C481A8C4\
7FA5C27DA1BD7DA2BC83A9C287B0CA85B0CA82ACC87FAAC67EA9C57DAAC77DABC9
7DADCC7DAECE7CADCD7AAAC775A2BE6F9AB56A93AD658DA661869F5C8198587B9254768C507086\
4C6B8047667A436175
44617548677C4C6C8250728855788F597D965D839C6188A2648EA96893AF6C98B56F9DBC72A3C2\
76A8C97AAFD182B9DD87C0E67EB6DB77ADD07AAED07CAFD07EB0D07FAFCF80AFCE
81AECD80AAC77EA2BF7A9BB77B9CB880A3BF82A6C384A9C785ADCA86AECB86AECB86B0CE86B0CD\
85ACCA83AAC781A9C480A8C385ADC787B0CB84AEC982ACC881ACC880ACC980ADCB
80AECC7FAFCE7EAECD7BAAC878A4C1729DB86D95B0688FA86388A15E829A5A7C9355778D517187\
4C6C8148667B446175
44627649687C4D6E8352738A5679915B80985F859F638BA56791AC6B96B36E9BB972A1BF75A6C5\
78AACB7BB0D27FB5D87EB4D879ADD179ABCE7CAED07FB0CF81B0CE82AFCE83AFCD
84AECB84ACC983A9C581A4C082A2BE83A2BF84A3BF85A4C186A5C287A6C487A7C488A6C488A6C4\
87A9C786ABC784AAC682A9C681A8C484ABC686AEC985AEC984ADC983AECA83AECC
83B0CD83B1D086B6D582B1D07AA6C3759FBB6F97B26A91AA658AA360849C5B7E9556788E527288\
4D6C8148677B446175
44627649687D4E6F8453758B587B935C819A6187A1658EA86A94AF6E99B6719FBD75A4C377A9C9\
79ACCE79AED072A7CA6CA1C573A7CA7CAED080B0D083AFCF84B0CE85B0CD86AECC
87ADCA87ACC887ACC888ABC888A9C689A8C589A9C58AA9C68BABC78CABC88CABC88CABC88CABC8\
8CABC88CA9C789A6C485A3BF82A0BB82A1BC85A7C287ACC887AEC986AECA86AFCB
85AFCD85B1CE85B0CD83AECB7DA8C577A0BB7199B36C92AC668CA461859D5C7F9657798F537389\
4E6D8249677C446275
4562764A697E4F708554768D597D955E839C638AA46890AB6D97B3719DBA75A3C178A8C87BADCE\
7CB0D37CB2D67AB0D57AAED07DAFD082B2D285B3D287B2D088B1CE8AB0CD8AB0CC
8AAFCA8AAECA8CB0CC8DB1CE8DB0CC8EAECA8EAECA8FAECA90AECA90AECB91B0CC91B1CD92B0CC\
91AFCB90AECA8DACC78BA9C589A7C287A6C287A8C288ABC589AEC889AFCA88B0CB
87B0CC87B0CD87B1CE84AECA7EA8C379A1BC739AB56D93AD688DA563869E5E8097587A90537489\
4E6E8349687C446275
4563774B6A7F50718756788F5B7F9661869E668DA66B94AE709AB675A1BE79A7C57DADCC80B2D3\
82B7D983B9DC84B9DD85BADD87B9DA88B8D68AB7D58CB6D38DB5D18EB4D08FB3CF
8FB3CD8FB2CD90B2CE91B4D092B5D192B4CF93B4CF94B4D094B3CF95B3CE95B3CE96B4CF95B4CE\
94B2CD92B1CB91AEC88EABC58CA9C38BA9C38AAAC38BACC68CAFC88BAFC989AFC9
88AFCA86AFCA86AFCB86B0CD81ABC87BA3BF759CB66F95AE698EA664879F5F8198597B9154748A\
4F6E834A687C456276
4563774B6B7F5172885779905D81986388A1698FA96E97B1749EBA79A5C27DACCA81B2D285B8D9\
88BDE08AC0E48CC1E38DC0E28CBEDE8DBDDC8FBCD991BAD792BAD693B9D594B8D4
94B6D294B5D195B5D196B7D397B8D497B7D397B6D198B6D098B6D098B6D099B6CF99B5CF98B5CE\
97B4CD96B3CB94B0C992AEC690ACC28EAAC18EAAC28FADC68FAFC88DAFC88BAFC8
89AEC986ADC883ACC884AFCC83AECA7CA5C0769DB77095AE6B8FA765889F6082985B7B9155758A\
506F834A687C456276
4664784C6B80527389597B925F839A658AA36C92AC729AB577A2BE7DA9C682B1CF87B8D88BBFE0\
8FC5E692C8EA94C9EB94C5E693C2E094C0DE95BFDD96BFDC97BEDA98BEDA99BED9
9ABCD79ABBD59ABAD49BBAD49BBAD69CBBD69CBBD69CBAD59DBAD49DBAD49EBBD49EBAD39DB9D1\
9CB6CF9AB4CD98B3CB97B1C894AEC593ADC393AEC593AFC792B0C890B0C98EB0C8
8AAEC785ABC57DA5C179A4C17FAAC67EA7C1769CB67196AE6C8FA76789A06182995C7C9156758A\
506F844B697D456276
4664784D6C8154748A5A7C9361859C688DA56E95AF759DB87BA6C182AECB88B6D48DBEDE92C7E8\
97CEF09AD2F39BCFEE9BC9E79AC5E49AC3E19BC3E19CC4E09DC4E19EC4E09FC4DF
A0C3DEA0C2DCA0C0DA9FBED79FBDD7A0BED8A0BFD9A1BFD9A1C0D9A2C0D9A2BFD8A2BED6A2BDD5\
A1BBD3A0B9D09EB6CC9BB3C99AB1C899B2C898B3C997B4CA96B4CB94B4CB91B2CA
8DB1C988ADC682A8C07AA1BA7499B37499B2769AB37296AE6D90A76889A06283995D7C9257768B\
516F844B697D456276
4664784E6D8255758B5C7E9463869E6A8FA87298B179A1BB80AAC587B2CF8DBBD994C4E399CCEC\
9ED2F1A1D2F1A1CFEE9FCBEA9FC9E7A0C8E4A0C8E4A1C9E5A3C9E5A4CAE6A5CAE5
A6CAE5A6C9E3A5C7E0A5C5DDA5C3DCA5C2DAA4C1D9A4C1D8A5C1D9A5C1D9A6C1D8A6C0D8A6BFD6\
A5BED4A3BBD0A1B7CC9FB6CB9FB6CC9FB7CC9EB7CD9DB8CE9BB7CD99B7CD96B6CB
92B3CA8EB0C789ADC583A8C17EA3BC7BA0B8789CB47497AE6F91A76A8AA06484995E7D9258768B\
5270844C697D456276
4765794E6D8256768C5E7F966588A06D91AA759BB47CA4BE84ADC98CB7D393C1DF9BCBEBA2D2F3\
A7D4F5A9D4F3A8D1F0A6CFECA5CDEAA5CCE8A6CCE8A7CDE9A8CFEAAAD0ECABD1EC
ACD1EAACD0E9ACCEE6ABCBE4AAC9E1A9C7DFA9C5DDA9C4DBA9C4DAA9C4DAA9C3DAA9C2D8A9C1D7\
A8BFD4A7BDD2A6BCD1A6BCD1A5BCD1A5BDD2A4BDD2A3BCD1A1BBD09EBAD09CB8CE
98B6CD94B4CA8FB1C88AADC587ACC483A8C07DA0B77799B07192A86B8BA165859A5F7E9259778B\
5270844C697D466376
4765794F6E8357778D5F8197678AA17094AC789DB680A7C189B1CC91BBD79AC6E3A3D1F0ACDBFA\
B4DFFDB5DDF9B1D7F3ADD3EEABD1ECAAD0ECABD1ECACD1EDADD2EEAFD4EEB1D5EF
B3D6EFB3D5EDB2D3EAB1D0E7B0CDE5AECBE2ADC8DFACC7DDACC5DCADC4DBADC4DAADC4DAADC3D9\
ACC2D7ACC2D6ACC2D5ACC2D5ADC2D6ACC2D6ABC1D5A9C0D4A6BED2A4BCD1A1BBD0
9EBACF9AB8CE97B7CE92B4CC8DB1CA87ACC481A3B97A9BB17494A96D8CA167859A607E935A778B\
5370844D6A7D466376
476579506F8358788D618298698CA27296AD7BA0B984AAC48DB5CF96BFDB9FCAE6A8D4F1B3DEFA\
B9E1FCBAE0FAB7DBF5B2D6F0B0D4EEAFD3EDAFD3EDB0D3EEB2D5EEB5D7EFB7D8F0
B9D9F1B9DAF1B9DAF1B7D7EEB5D3EAB2CFE5B0CBE1AFC8DEAFC7DDB0C7DCB0C7DCB1C7DBB1C6DB\
B1C6DAB2C6DAB3C7DAB4C8DBB4C8DBB3C8DBB1C7DAAFC5D8ADC2D6AAC0D4A7BFD3
A4BDD1A1BCD19EBAD09AB9CF94B5CB8CADC385A5BA7E9CB27795AA708DA269869A627F935B788C\
5471844D6A7D466376
486579506F8359798E6283996B8DA37497AF7EA2BB88AEC792B9D39BC4DEA4CEEAACD5F0B2D9F3\
B8DDF7BBDEF7B9DBF4B5D7F1B3D5EFB2D4EDB2D3ECB4D5EEB7D8F1BBDCF5BFDFF8
C1E0F8C1DFF6BEDDF3BCDAF0B9D7EDB6D1E7B3CCE1B1C9DDB1C7DBB1C7DBB2C7DCB3C7DCB5C8DC\
B6C9DCB8CBDDBACCDEBACDDFBACCDFB9CCDEB7CADDB4C8DAB1C5D8AFC4D7ACC2D5
A9C0D3A7BFD2A5BFD2A1BED29AB8CD91AEC389A6BA819EB27996AA728EA26A879A637F935C788C\
5571844D6A7D466376
486679516F845A798E6383996C8EA47699B081A5BC8CB1C997BDD6A1C9E3AAD3EEB2DAF4BBDFF7\
C0E1F8BEDEF6BADAF2B7D7EFB5D5EDB3D3EBB3D2EAB3D2E9B5D3EAB8D6ECBDD9EE
C3DDF2C4DDF3C1DBF1BED9EEBBD8EDB7D2E7B4CBDFB2C7DBB2C6D9B3C6D9B4C7DAB6C8DBB8CADD\
BACCDEBBCCDEBCCEDFBED0E1C0D2E3BFD1E2BCCEE0B9CBDDB6C9DBB4C7D9B2C5D7
AFC3D5ACC1D3A9BFD1A3BCCD9CB6C894AFC18CA6B9849FB27C97AA748FA26C879A6480935D788B\
5571844E6A7D476376
486679516F845A798E6384996D8EA4789AB083A6BD8FB4CC9CC2DBA8CFE9B1D9F2B7DCF6B9DBF3\
BADBF1BBDBF1B9D8EFB7D5EBB6D3EAB5D2E8B4D1E6B3CFE3B1CCE0AFCADEB0CBDF
B4CDE2B7CEE3B8CEE1B6CBDEB2C7DAB1C5D8B2C6D9B2C5D7B3C4D6B3C5D7B5C6D8B7C9DABACDDD\
BDCFE0C0D0E1C4D4E5C7D7E7C7D6E6C4D3E4C1D1E2BECFE0BACCDDB7C9DAB5C7D8
B3C6D6B2C5D5B0C3D3AABDCDA1B5C598AEBF8FA7B9879FB17E97AA7690A26D889A6580935E798B\
5671844E6A7D476376
48667A516F845A798E6483986E8EA4789AB084A6BD92B5CDA2C7DFB4DCF6BEE5FFBEE0F8BDDCF3\
BCDAEFBBD8EDBAD6EBB8D4E9B6D2E7B5D1E5B5D0E4B3CDE1B1C9DBAEC6D8AAC2D4
A5BCCFA5BBCEA8BDD1ABBED1AEBFD1B0C2D3B1C3D5B2C4D5B3C4D5B3C4D4B3C4D4B4C4D4B5C3D3\
B8C5D4BFCCD9C6D3E0C8D5E3C6D4E2C8D5E4C6D5E3C1D1E1BDCEDEB9CAD9B7C7D7
B7C7D6B7C7D6B6C5D4B1C1D0A7B9C89CB0C193A9BA89A1B28098AA7790A26F889A6680925E798B\
5671844F6A7D476376
486579516E825A788C6382966D8DA27898AE84A5BB92B4CBA6CAE3B4D8F1BFE0F7C6E5FBC5E1F6\
BFDBF0BAD6EBB7D3E8B6D2E6B6D0E3B5D0E2B5D0E2B4CDDEB2C8D9AFC4D4ACC0CF
AABDCDA9BBCBA9BAC9ABBBCBADBDCCB0BFCEB1C1D1B2C2D2B3C3D2B3C2D1B3C1D0B3C0CFB2BFCF\
B2C0CFB2C1D0B4C3D1B8C6D4BBC9D7BBCAD8BBCAD8B9C8D6B8C7D4B8C7D5B9C7D5
BAC7D5BBC9D7BAC8D5B3C2D0AABDCCA1B5C596ABBB8CA2B28299AA7990A17088996780925F788A\
5771834F6A7C476376
486477516D8159778B6380956C8B9F7795AA82A1B78EAEC49CBCD3A8C7DEB2CEE4BAD5E9BDD7EB\
BAD4E9B6D2E5B6D1E4B5CFE2B5CDE0B3C9DBB2C7D7B4C9DAB5CADAB4C7D7B3C4D2
B1C0CEB0BECCAFBDCBB0BECBB0BECBB0BDCBB1BFCEB2C2D0B3C2D1B3C1CFB3C1CDB4C1CDB4C1CE\
B4C0CEB1BECCABB9C7A7B6C5ABBAC8ADBDCBB0BECCB3C1CEB7C4D0B9C5D1BAC6D2
BCC8D4BDC8D4BAC6D2B3C1CEABBCCAA3B5C499ACBB8EA3B28499A97A90A17088986780915F788A\
5771834F6A7C476375
486477506D80597589617F936B889C7492A67E9CB189A7BC94B1C69FBCD1AAC4D8B0C9DDB3CCE0\
B4CCE0B5CCDFB5CDE0B6CEE0B4CBDCB3C7D8B0C3D2AEBECCADBCC9ACBBC7A9B6C2
A5B1BDA5AFBAA6B0BBA8B1BCABB5C0AFBAC6B2BECBB3C1CEB4C2CEB4C0CCB3BFCAB5C1CBB7C3CD\
B7C3CEB5C1CDB2BECBAFBCC8AEBAC6AFBAC6B2BDC8B6C1CBB9C4CDBAC6CFBCC7D1
BEC9D3BFC9D3BBC5CFB1BDC9ABB9C5A6B6C49CAEBD90A3B28599A87A8F9F708797677F905F7789\
5770824F697B476275
4764774F6C7F577488607C90688598718EA17A97AA839FB38CA7BB95B0C39EB8CBA5BED1ABC3D6\
AEC6D9B1C8DAB4CBDDB6CCDDB5CADBB3C7D7B2C3D1AFBECBACB7C3A8B1BCA5ADB8
A4AAB3A4A9B1A5A9B1A8ADB6ADB4BFB1BBC6B4BFCBB6C1CEB6C1CDB4BFCBB2BBC7AFB8C2B0B9C2\
B6C0C7BAC4CDBAC4CDB7C1CBB6BFCAB5BFCAB7C1CAB9C3CCBBC5CEBCC5CEBDC7CF
C0C9D1BEC8D0B8C2CBB5BFC9B1BDC8ADBCC9A2B3C191A3B18598A67A8E9D708595677D8E5E7687\
566F814E697B476275
4763764E6A7E5672855E798C6681946E899C7691A47E99AB86A0B28EA6B895ADBF9CB4C6A2BACB\
A7BFD0ADC4D5B1C8D9B4CADAB5CAD9B5C8D7B3C5D3B2C1CEB0BCC8AEB8C2ACB4BE
ACB3BCACB2BAADB3BBAFB6BEB2BAC3B5BEC9B7C2CDB8C3CFB8C3CFB6C1CCB4BEC8B0BAC3ADB5BD\
AAB3BBACB6BEB3BCC4BAC2CABCC4CCBCC4CCBCC4CCBCC4CCBBC3CBBBC3CABDC5CC
BFC5CDBCC3CBB8C0C8B8BFC7B4BCC5A9B4BF9CAAB78F9FAD8395A3788C9A6E8392667B8C5D7585\
556E7F4E687A476274
4662764D697C5570835C778A637E906B8597728C9E7993A58099AA869EB08DA5B695ACBD9BB2C3\
A2B9C9A9BFCFB1C6D6B6CADAB7CBDAB6C9D8B5C7D5B5C4D1B4C2CEB3BFCAB2BDC7
B2BBC4B3BBC4B4BCC5B6BEC7B8C1CABAC3CDBBC6D0BCC7D1BBC6D1BAC5CFB8C3CCB5BFC8B2BBC4\
AFB7C0ACB4BDAAB3BBABB3BBAFB7BFB2BAC2B3BBC2B4BBC2B8BEC5BCC1C8BEC2C9
BDC1C8B9BEC5B5BAC2B2B6BFAEB2BAA4ACB698A4B08C9BA880919F7688966C808F6479895C7383\
546D7E4D6779466174
4662754C687B536E805A7486607A8C6781936E8798758D9E7B93A58299AB889EAF8EA4B496ACBC\
9EB4C4A7BCCCB0C5D3B6CAD9B8CCDAB8CBD9B8C9D6B8C8D4B8C6D1B8C5D0B8C4CF
B8C3CDB9C3CDBAC4CEBCC6CFBEC8D2BFCAD4C0CCD5C0CCD6C0CBD5BFC9D3BDC7D0BBC5CEB8C1CA\
B5BEC6B2BBC2B0B7BFAEB5BCADB4BBAFB5BBB2B7BDB5BBC0B9BDC3BCBFC5BDC1C7
BBBEC4B5B8BEAFB3B9A9AEB5A4A9B19DA5AF94A1AC8998A47C8C99728391697C8B6176855A7080\
536B7C4C6677466173
4561744B6779516C7E5771835E7788647D8E6A8293708898778D9D7D92A18297A6899EAC92A5B4\
9CAEBCA5B8C6AEC1CEB6C9D6B9CCDAB9CCD9BACBD8BBCBD7BBCBD6BCCAD5BDCAD5
BECBD5BFCBD5C1CCD6C2CDD7C4CFD8C5D0DAC6D1DBC6D1DAC5D0D9C4CFD8C3CDD5C1CAD2BEC7CE\
BCC3CBB9C0C7B6BDC3B5BBC1B5BAC0B5BABFB7BBC0BABCC1BCBDC3BEBEC3BEBEC2
BABABEB1B2B7AAACB1A3A6AC9CA1A8949BA38C96A0818E997685916D7D8A6577855E7281586D7D\
5169794B6476456072
4560734A6577506A7C556F805B7485607889667D8D6C8292718796778C9A7D919F8396A48B9EAB\
94A7B49FB0BDA8B9C5B2C3CEB8CAD6BBCDD9BCCEDABECFDBBFD0DCC1D0DBC2D0DA
C4D0DAC5D2DBC7D3DCC8D4DDCAD5DECBD6DFCCD7E0CCD7DFCBD6DECAD4DCC9D2D9C7CFD6C5CCD3\
C2C9CFBFC6CBBDC3C8BBC0C5BBBFC3BBBEC2BBBEC2BCBEC2BCBEC2BDBDC1BABABD
B1B2B6AAABAFA2A4A9999CA190949A878D947F868F76808A6E7B8667768361727F5B6E7C556A7A\
4F66774A6374455F72
4460724964764E6879536C7D5870805D7484627988687D8C6D818F738593788A977E909D8698A4\
90A1AD9AABB6A4B5C0ACBEC9B5C6D2BBCDD8BFCFDBC1D1DDC3D3DFC5D5E0C7D6E1
C9D7E1CBD8E2CDD9E2CFDBE4D0DCE5D1DDE5D1DDE5D2DCE4D2DBE3D0DAE0CFD7DECCD5DBCAD1D7\
C8CED2C5CACFC3C8CCC2C5C9C0C3C7C0C1C5BFC0C3BEBFC2BFBEC1BCBBBDB5B4B7
ACABAFA3A2A698999E8E909684878E7A7F866E747B68707866717B616F7B5C6D79576A78526776\
4D6474496173445F71
445F724862744C667751697A556C7C59707F5E7482637886697C8A6E818D7485927A8B9782929D\
8A9AA494A3ADA1AEB8ABB9C3B5C3CCBCCBD5C1D0DAC4D3DEC7D6E1CAD9E3CCDBE6
CFDDE8D1DFE9D3E1EAD5E2EBD7E3ECD8E4ECD8E4EBD8E3E9D7E0E7D6DEE4D4DBE1D2D8DDD0D5DA\
CDD1D6CBCFD2C9CCCFC7C8CBC5C6C8C3C3C5C2C1C3C1BFC0BEBBBDB8B5B7AFADAE
A4A2A599989B8E8E9283858A797C816F737A666D74616A725E69735B69745767745366734F6473\
4B6272476071435E70
435E714761734A64754E6676526978566B7A5A6E7C5D707D6274816779866E7F8A75848F7B8A94\
85939D909EA79CA9B2A9B4BDB5C1C9BECBD4C4D2DBC8D6E0CBDAE4CEDDE8D2E1EC
D5E4EFD7E6F1DAE8F2DCEAF3DEEAF3DFEAF2DFEAF0DFE9EFDEE7ECDDE4E9DAE0E5D8DCE0D5D9DC\
D2D5D9CFD1D4CDCED0CACBCDC8C8C9C7C5C6C6C2C3C3BEBFBEB9B9B6B1B1AAA6A6
9E9A9C9190918585887A7C7F6F717562676C5C61685A626A58626B55626D53626E50626F4C616F\
49606F465E6F435D6F
425E704660714961724C63734F6574526775556875586A765B6C7861707B6876816F7D8777858E\
818E978C98A198A3ABA6B0B7B4BEC5BFCAD1C6D2DACBD8E1CFDDE7D3E2ECD7E6F0
DAE9F4DEECF6E0EEF7E2EFF6E4F0F6E6F1F7E7F1F6E6EFF3E5ECEFE3E8EBE0E5E7DDE1E4DADDE0\
D7D9DBD4D5D6D1D0D1CECCCDCCC9C9C9C5C5C6C2C1C2BDBBBBB4B3AFA9A8A29D9C
9490918685867A7A7C6D6F726063675355594F5358525960515B64505D674E5D694C5E6B4A5E6C\
475D6D455D6E425C6E
425D6F445E70475F704960704C61704E627050636F52636F55646E596770616E7769757E717D86\
7B868E879198949DA3A2ABB0B0B8BEBDC6CBC8D2D9CFDAE2D4E0E8D8E5EEDDEAF2
E1EEF5E5F1F8E8F3FAEAF5FBECF6FBEEF6FBEEF5F9EDF3F6ECF0F3EAEDEFE6E9EBE3E5E6E0E0E1\
DCDCDCD9D7D7D5D2D2D2CDCDCEC9C8CAC4C2C5BEBCBEB6B4B4ACAAA7A09E999392
8A86867D7A7B6F6E7062636657595D4F52574C51574C535A4C565F4B58624A5965495A67475B69\
455B6B435C6C415C6E
415C6F435D6E455D6E475E6D495E6C4A5E6B4C5D694D5D674E5C66525F6759656C626D746B757C\
757E8480898F8C959A99A1A6A7AFB4B8BFC4C6CED2D0DADFD7E3E8DDE9EFE2EEF4
E7F3F8EBF6FAEEF8FCF1FAFEF4FBFEF5FBFDF6FAFCF4F8F9F2F4F5EFF1F1ECECEDE8E7E7E4E2E2\
E0DDDDDCD8D7D8D3D1D4CDCBCFC8C5C9C1BFC1B8B5B7AEAAAAA19E9B93918D8785
807B7A726F6F6462635555584A4C4F46494D454A50464D5546515946535D465561465764455867\
435A69425A6B415B6D
415C6E425C6D445B6C455B6A465A6947596647586447566046525A48545A515B625A636A626B71\
6B747A767F85838B8F90979B9EA4A7AEB3B5BFC4C6CED4D6D9E1E4E0E9ECE7F0F3
EDF6F8F2FAFCF5FDFEF8FEFFFAFFFFFDFFFFFDFEFEFBFBFBF8F7F6F5F2F1F1EEEDEDE9E8E8E3E2\
E3DDDCDED8D5D9D1CED3CAC7CCC3BFC4BBB6B9B0ABABA29E9D94918E8784807977
716C6C63606055535449484A3D3C3D393A3D3E434840484F424C55424F5943525E435461425665\
42586741596A405B6D
405B6D415B6C425A6A43596843576543566243535F42505A404C54424B52495258525A605A6268\
656B706F75797A8085868C9092989AA0A5A7B0B5B6C1C5C6CFD3D4DCE1E2E7ECED
F0F4F5F6FBFBF9FEFEFCFFFEFFFFFEFFFEFCFFFCF9FEFAF7FCF7F4F9F2F0F4EDEAF0E7E4ECE3DF\
E6DDD9DFD5D1D8CDC8D0C5C0C6BCB6BBB0AAADA29D9F94908F8683807875716B69
625D5C5350504543453B3A3C35353836373B393D433B434A3D48513F4C56404F5B40525F405463\
405766405869405A6C
405B6D405A6B41586841576641556340535F40505B3F4C563D48503C454A3F474C474F5450575C\
596064646A6E6F74787A7F82878C8E94999BA2A6A8B1B5B6C0C3C4CFD1D1DBDDDD
E5E7E7EDEFEDF3F4F1F7F7F3F9F7F2FAF5F0FAF3EEFAF2ECFAF0EAF7EDE6F4E8E2EFE3DDE9DCD6\
E3D5CFDCCEC8D2C5BFC8BBB5BCAFA9AEA19C9F938E8F85817E76736F68655F5A58
504C4B413E3F3534342C2B2C2A2A2D30323634393F373F473A454D3C49533D4D593E505D3F5361\
3F55653F58683F5A6C
3F5A6C3F596A3F57673F55643F53603E505D3D4D583B495339444C363E45373E433E454A474E52\
4F565A575D6162676A6F73767C80828A8E8F989C9DA6AAAAB3B7B6BFC2C2CBCCCB
D5D4D2DDDBD8E4E1DDE9E5E1EBE6E1EDE6E1EFE6E0F0E5DEF0E3DBEEE1D9EBDED5E6D8D0E1D2CA\
D9CBC3D1C2BBC7B9B2BBADA6AD9F9A9F928D8F847F7E75716D66635D57554D4948
3D3A39302E2D2523241F1D1E2322242B2E3230363C343C4437424B3947513B4B573C4F5C3D5260\
3E54643F57683F596B
3F5A6C3F58693E56663E54633D515F3C4E5B3A4A56384650364149323B4230363B34393D3D4246\
454A4E4E5356585D5F65696B7175777E81838B8E8F97999AA4A5A4B0B0AEB9B9B7
C1C0BEC8C6C3CFCCC8D5D1CCD9D4CFDAD5CFDCD4CEDCD2CCDCD0C9D9CDC5D7C9C1D3C5BDCEBFB7\
C6B7AFBCAEA7B2A49EA79994998D888A7F7B7A716D6B63605B55534B46453B3737
2C292A201E1E161313171516212225272B302D343A313B4334404A374550394A563B4D5B3C515F\
3D54643E57683F596B
3F5A6C3E58693E55653D53623C505E3A4C5938495436444E333F473039402C33382C323632383B\
3B3F4244484B4F5355595C5F6366686F72737C7E7F898B8C9596969F9F9EA7A7A5
AFAEACB7B5B1BCB9B6C0BDB9C4BFBAC6C0BAC7BFB9C6BDB7C5BBB4C3B8B1C0B4ADBCAFA8B5A9A1\
AEA19AA599939C908A918680847A75756D69665F5C57514F474342373434282627
1C1A1B110D0D100C0D18181A202226262B312B333A2F3A42333F493544503849553A4D5A3B505F\
3C53633D56673E596B
3F5A6C3E57683D55653C52613B4F5D394B5837475334434D313D462E373F292F35262A2E292C2F\
303437393C3F4145474C4F51575A5B6265666D6F70797A7A8384848C8C8C949493
9B9B99A1A19FA7A5A2ABA8A4AEAAA6AFAAA6AFAAA4AEA8A2ACA69FAAA29CA69E97A198929A918B\
9389848C827D837A7579716D6E6663615A58524D4B423F3E3431312726261C1A1B
0F0C0C0C0909131214191B1E202429252C322A333B2E3A43323F4A344450374956394D5B3B505F\
3C53633D56673E596B
3E596C3E57683C54653B52613A4F5D384B5836475333424D303D462C363E272E352024281D1F22\
2426292D303236383A3F4243484B4C5154545A5D5E6467676E6F6F7879787F8080
8586868B8B8A908F8E93919094929096939196939095928E938F8B908C888B868285807C807A76\
79736F726C696A6562605B5954514F4845443A39382E2D2D2221221515160B0B0C
0908090F0E0F1516191B1E2320262C252E352A353D2E3B4431404B344551364956384D5B3A505F\
3C53643D56683E596B
3E596C3D57683C54653B5261394F5D384B5935475433424E2F3D472C373F272F3621272C1A1D20\
18191B1F2123292B2D313536393D3E414445494B4C515353595B5B616363686A6A
6E706F737373767677797A797C7C7B7D7D7C7E7D7C7D7C7A7B7A7878767474716F6C6A6764625F\
5F5D5B59585651504F4646463D3C3D3333342828291C1D1E1313140B0A0B050202
080606101114171A1E1C2228222A302630382A36402E3C4731414D344652364A57384D5C3A5060\
3B54643D56683E596B
3E5A6C3D57693C55653B5262394F5E374C5A35485533434F303E492C394227323A222A311D2226\
15181A1416171B1E202428292D3032343638383B3D3E414345484A4B4E50525455
575A5A5B5E5F5F62626265656467676567676568676567676465656263635D5F5F585A5B525556\
4A4D4F4345473B3D3F3335372C2E302325271A1B1E101113070809020000040202
0D0D0F13171A191F241F262D232D3528333D2B39432F3E4A32434F344754364B59384E5D3A5161\
3C54653D57683E596C
3E5A6C3D57693C55663B536339505F384D5B36495733455230404C2D3B4629353E242F361F272D\
1A1F24131619121416181B1D1F2324262A2C2B2F302F3233343738383C3D3B4041
3E4345424749474C4D4A4F504D51534E53544F54554F53544D52534C51534B5053484E5244494D\
4045493A3F4333373B2A2E31202427161A1D0E111406080A0000010301020A0B0E
111418171D221C252B212B3326323B2937412D3C4730414D334552354957374C5B394F5F3A5262\
3C55663D57693E596C
3E5A6C3D586A3C56673B53643A5161384E5D364B593447553243502F3F4A2B394427343D232D35\
1E262C181E2311141710121416191B1C202220242623272926292B282D2E2C3233
2F353730373832383A353C3E383F413940423941433A41453A4145384044374044363E43333B40\
2E363B262F3420272C181F2310151A0A0E1204070A000001020102090A0E101419
161D231C242B202B3325313A2836412C3B472F404C314451344755364B59384E5D3950603B5364\
3C55673D58693E5A6C
3E5A6D3E586A3D57683C54653A526339505F374D5C354A5833475431434F2E3E4A2A394427343D\
222E361D272D181F241015180B0E100F1315171C1E1D22241E23251D22231C2224
1D232621282A242C2E232C2E222B2F252F342934392B363B2B363B2C363C2B363D2A353C28333A\
232E351D272E16202610181D091116050B0F0205070506080B0F1311171D171F26
1C262E212C3525323C2837422C3C482E404D314451334755354A59374D5C3950603A52633B5465\
3C56683D586A3E5A6D
3F5B6D3E596B3D57693C56673B54653A526239505F374D5C354A593347553143502E3F4C2B3B46\
2736402330391F2A32192229131B200E13170E131612191C161C20171E21171F22
1821241822261823271A262C1E2A31202C34202D3622303925333C26333D24313A232F38212D36\
1C2830172129101A200C151A0A101405090C070B0F0F161B151D241A242C1E2A33
22303A263540293A452C3E4A2F424F314553334857354B5A374D5D3850603A52623B54653C5667\
3D57693E596B3F5A6D
3F5B6E3E5A6C3D586B3D57693C56673B54653A5263395061374E5E364C5B344958324654304350\
2D3F4B2A3A4626364022303A1E2B3319252D131C230D161C0D161C121C22162126
15202515212617242B1A282F1D2B321D2B331D2C351D2C371D2C371E2D371E2D381D2B361C2932\
1B242D172028121A200C12170A10150F161D151F271A262F1F2C3623313C263642
293A472C3E4B2F424F314553334857354A5A364D5C384F5F3951613A53633B54653C56673D5769\
3D586A3E596C3F5B6D
3F5B6D3E5A6D3E596C3E596B3D586A3C57683C55673B54653A5363395161384F5F364D5D354B5A\
3348573145532E42502C3F4B293B4726374222323D1F2E391D2B36192732182530
1927311A29321A28311B2A321E2E3621313A23333D23333F22333F22333F22333E23333F21303C\
1B283215212916212A1A26301D2A341F2E3923333E263744293C482C3F4D2E4250
304554324857344A5A364C5C374E5E3850613952623A53643B54663C56673C57683D586A3E596B\
3E596C3E5A6D3F5B6E
3F5B6E3F5B6E3F5B6D3E5A6D3E5A6C3E596C3D596B3D586A3D57693C56683B55673B54663A5364\
395263385061374F5F354D5D344B5B3249593147562F45542E43532D42512C4150
2C41502C41502C404F2B3F4E283C4B273A4A263A48263A47263947263947253846253744243643\
273A472A3E4B2B3F4D2C414F2E43522F4554314757334A59344C5C364D5E374F60
3850613952633A53643A54663B55673C56683C57693D576A3D586A3D596B3E596C3E5A6C3E5A6D\
3F5B6D3F5B6E3F5B6E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.25526 0.245293 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
677073677073677073677073677073677073677073677073687073687073687073687073687073\
687073687073687073697173697073697072697072697072697071696F70696E6E
6A7071697173697173697173697274697174697174697174697173687173687173687173687174\
6872756872756973766974776975786A75786A76796A777A6A777B6B787C6C7A7E
6E7D816C797D6B787B6A777A6A76796A7578697578697478697477697376687376687275687275\
687274677174677173
677073677073677173677073687073687173687073687073687173697173697173697173697172\
6A71726A71726A71726A71736B71726B71726B71726C70716C70706C6F6F6B6D6C
6C70706C71726C72746B72746B73746B72746A72746A72746B72746A73746A73756A73756A7375\
6A74776A75786B77796B787B6C797C6D7A7E6D7C7F6D7D816E7F836F8185718288
7284897081866F7F836E7D816D7B806D7A7E6C797D6C787C6B787B6B777A6A76796A7578697477\
687376687275677174
6770736770726870736871736870726870736970736970726971736A71726A71736A71726B7172\
6B71726B71726C71726C71726D71726D71726E71716E71716E70706F6F6E6F6E6C
6F71706F72726E73746E73746D74756D74756C73746C73746D73746C73746A74756A74766A7577\
6B76786B77796C7A7C6D7C7F6F7E8170808371818571848872868B74888E758B92
758A9074878D73858A728388718186707F846F7E826E7D816D7B7F6D7A7E6C787C6B777A6A7679\
697477687376687274
6770736770726870726871736970736970726970726A70726A71726B70726B71726C71726C7172\
6D71726D71726E71726E71726F71726F727170727171717171717072706E716F6C
7272707273737174747175757075756F74756D74746C73736C72726C71736A73736B75766B7678\
6B787A6C7A7C6D7D7F6F7F8270828572848874878B758A8F768D927890977A949C
799198788E94768B9175898E74868C738489728287718085707F836F7D816E7B7F6C797D6B777B\
6A7679697477687275
6770736870726870726970726970726A70726A70726B70726B71726C71726C71726D71726D7172\
6E71726F71726F717170727171727171727172727173727174727075726F75706D
7573717574747475767376767276767176767075766F74756E73746E73746D73746D75766D7779\
6D797C6D7C7E6E7E8170838672868A74898D778C917990967A949A7C979E7E9BA3
7D979F7B949B7A9198798E95778C9276898F75878C7384897282877180846F7E826E7B7F6C797D\
6B777A6A7578687275
6770736870736870726970726A70726A71726B71726B71726C71726D71726D71726E71716F7171\
6F7171707171717271727271737271747371757371767472777472797471797470
7975737876757777767677787578787478787377787277777177777076767076776F7778707A7C\
707C7E717F82718285738689758B8F778E937A92977D969C7E9AA1819EA681A0A8
809DA57F9AA27D979E7C949B7B9197798E94788B9176888E74868B7383887180856F7E826E7B7F\
6C787C6A7679687376
6770736870736970726970726A71726B71726C71726C71726D71726E71716E71716F7171707171\
7171717272717272717372717473717673717774717975727B76737D78757E7976
7C78767B78777A7978797979787979777A79767A7A75797A757A7A747A7A747B7B737C7C737E7F\
73808274838675868A768B8E788F937B94997E989E809CA382A1A986A6AF85A5AF
84A3AB83A0A8819CA48099A17E969D7C93997A8F96798C9277898F75868B7383887180846F7D81\
6D7A7E6B777A697376
6770736870736970726A71726B71726B71726C71726D71716E71716F7171707171707171717171\
7272717372717472717572717673717773717974717A75727E7774857D79827B78
7F7A787E7A787C7A797C7B7A7B7C7B7A7B7B797C7C797D7D787D7D787E7E777F7F778181788384\
78868779898B798B8E7B8F937D94997F989E819DA485A2AA87A7B08AADB889ABB5
88A9B286A6AF85A2AB839FA7819BA37F979F7D949A7B9096798D9277898E75858A728286707E82\
6E7B7F6B777B697477
6870736870726970726A71726B71726C71726D71726E71716F7171707171717171717171727270\
7372707472707572707773707873707973717A74717B74717D757189807B847D79
817C7A807B7A7F7C7B7E7C7B7D7D7D7D7E7D7C7E7D7B7F7E7B807F7B81817B84837B87867C8989\
7C8B8C7D8E907E91937F949881999E839DA385A3AA89A9B18CAEB88FB5C08DB2BD
8CAFBA8AACB689A8B187A4AD85A0A8829CA480989F7E949B7B9096798C9276888D748489718084\
6F7C806C787C697477
6870736970726A70726B71726C71726D71726E71716F7171707171717171727170737170747270\
7572707672707772707873707973707A73707B74707B73707F7673847B78847C79
837D7A827D7B817E7D817E7D807F7E80807F7F807F7E80807E81817E83837E87867E8A897F8E8D\
809191819395829698849A9D869EA387A3A889A7AE8CADB58FB3BD92BBC692BAC6
90B6C18EB2BD8DAEB88AAAB388A6AE86A1A9839DA481989F7E949A7B8F95788B9075868B738286\
707D816D797D6A7578
6870736970726A70726B71726C71726D71716E71716F7171707171727170737170747170757270\
7672707772707872707A73707B73707C73707D74707F7571817773837A76847C79
847D7B847E7C847F7E838080838180828181828281818281808281808685808A88818E8C829290\
839695849898869B9D889FA18AA3A78CA7AD8DACB38FB1B992B7C195BFCA97C2CE
95BDC993B9C491B4BF8EB0B98CABB489A6AE86A1A9849CA381979E7D92987A8D9377888D748488\
717F836D7A7E6A7578
6870736970726A70726B70726D71716E71716F717170717171717072717074717075717076726F\
77726F79726F7A726F7B736F7D736F7E746F7C726D827773837975847A77857C79
857D7B867E7D86817F868282868383858383858383848483828181828483828787838B8B848F8F\
869696879B9B8A9FA08CA3A58EA7AA90ABB092AFB693B4BC95B9C397BFCB9AC6D2
9AC6D397C0CC95BBC692B5C090B0BA8DABB48AA5AE87A0A8839BA280959C7C9096798A8F75858A\
7280846E7B7E6A7579
6870736970726B70726C70716D71716E717170717171717072717073717075716F76716F77726F\
78726F7A726F7B726F7D736F7E736F80746F8A7C77877A76867A76867B78877C79
877D7A877E7C88818089848389858489858488848487848485828284808184838484858685898B\
8892948A9A9B8DA1A190A6A892AAAD94AEB496B2B996B6BE97BAC499C0CB9BC5D2
9DCAD79BC6D399C1CD97BBC694B6C091B0B98DAAB28AA4AC869EA582989F7E92987A8D9276878C\
7381866F7C7F6B7679
6870726970726B70726C71716E71716F717170717072717073717074716F76716F77716F78716E\
79726E7B726E7D726E7E736E80746E81746F8A7C76897B76897B77897C78887B78
887C79887E7C8A81808C86858C87858C87858E8786888080858080827D7D827E7F838485858688\
888C8E8C949692A0A194A9AA97ADAF98B1B699B5BB99B8C09ABBC59BC0CB9DC6D2
A0CCD9A0CDDA9EC7D49BC1CD98BBC595B5BE91AFB78DA8B089A2A9859BA280959B7C8F9478898D\
7482876F7C806B767A
6870726A70726B70726D71716E707170717071717073717074716F75716F77716E78716E79716E\
7A716D7C726D7E726E80736E81726C8D7C758C7C768B7C768A7B768A7D79897B78
887A77887C798A7F7E8D8484918887897F7F8A8080887E7E867E7E857F7F837D7E828082818384\
83888A878E90929B9D99A8AA9BB0B29CB4B89DB8BE9CBAC19CBCC59DC1CB9FC6D2
A1CBD8A3CFDDA3CDD9A1C8D39DC1CB99BAC495B3BC90ACB48CA5AC879EA582979E7E9196798A8F\
758488707D816B777A
6870726A70726C70716D70716F717170717072717073716F75716F76716E78716E79716D7A716D\
7B716C7D716C7F726D82746E82736C9380788F7E778D7C778C7B768B7B778A7A77
897975887976897B7A887D7D9087878D86858B84848A848589828387828486838486888985898B\
848B8F838C8F88949794A1A39FB0B2A1B8BBA1BBC09FBCC39EBDC69EC1CBA0C6D1
A2CCD8A4D0DFA6D0DEA6CEDAA3C8D29EBFC999B7C093B0B88EA8B089A1A8849AA07F93987A8C91\
768589717E826C777A
6870726A70726C70716E70716F717071717073717074716F76716F77716E79716D7A716D7B706C\
7B706B7C706B7F716C8878728A7972907F77907D778E7D778D7D778D7C778B7A76
8977738878748776758576768B7C7C8C81808C82828C84848B8484898585898586898A8C888D8F\
89919488919489979B8D9DA19AAAAEA4B9BDA4BDC1A2BEC5A0BEC7A0C1CBA2C6D1
A4CBD7A5D0DEA7D1E0A8D0DDA8CDD7A2C4CE9CBCC597B3BC91ACB38CA4AB869CA381959A7C8D92\
77868A717F836C777B
6970726A70726C70716E707170717072717074717075716F77716E79716E7A716D7B716C7C706B\
7C6F6A7B6D68796B6484736D907C758F7D75907D76907C768F7D768F7C768D7A75
8B78738B7A778D7E7C8C7D7B8D7D7D8D7E7E8C7F7F8C7F7F8B7E7F89808189818389848689888C\
8B8F928B92968C979C8E9EA294A5AAA1B5B9A6BEC2A4BFC5A2BFC7A1C1CBA2C6D1
A5CBD7A6D0DDAAD5E3B1D8E5ACD1DCA6C9D3A0BFC99AB7BF94AFB68EA6AD899EA583979C7D8F94\
78878C727F836C787B
6970726B70726D70716F707071717073706F75716F76716E78716E7A716D7C716D7D716C7D706B\
7D6F697A6B667466607A6B668A78718F7C75917D76927C76917D76917D768F7A75
8D78738D7A7691817E9182809081809081808F81808E81808D80808C81818C83848C86888D8A8D\
8E8E9190929791969B929BA094A1A79BABB1A3B8BDA5BDC4A3BFC6A2C1CAA3C5CF
A5CAD5A6CEDAA6D0DDB5DBE7B1D5E0AACCD6A3C3CC9DBAC397B1B991A9B08BA1A784989E7F9095\
79888D7380846D787B
6970726B70726D70716F707071717073716F75716F78716E7A726E7C726D7D726D7F726C80716B\
80706A7F6E6880706984736C8C7971917D76947F77947E77947D77937D76927B75
907A74907B7793817E9586839485849384829283829183829081818E82828E85858F898A908C8E\
919093949598969A9E97A0A49AA5AB9EADB3A2B5BAA4BAC1A4BDC5A3C0C9A4C5CE
A6C9D4A6CCD9A7CFDDB8DDE8B4D8E2AECFD9A7C6CFA0BDC699B4BC93ABB28CA3A9869AA0809297\
7A898E7381856D787C
6970726B70716D70716F707072716F74716F76716E79716E7B726D7D726D80736D82736C83736C\
85736C87736B89766F8D7B73917F7796817897827A97817A978079977F78967E77
947C76947E7895817D978784978886968785958584938684928483918383918685918A8A928F8F\
93929496979A999CA09BA2A59DA7ACA0ADB3A3B5BAA4B9BFA5BCC3A4BFC8A5C4CD
A5C8D2A5CAD7A4CDDBBADFEBB9DCE7B1D3DDAAC9D3A3C0C89CB6BE95ADB58EA4AB889CA1819398\
7A8A8F7481856D797C
6970726B70716D707070707072706F75716E77716E7A726E7D726D7F736D82736D85746D87756D\
89766D8C786F8F7B72937F7796837B99847C9A857D9B857D9B837C9A827B9A817A
997F7998807A98827D9A87839B8B88998987988684968684948684938583938786938A8A958F90\
96939499999B9C9FA19FA4A7A0A8ACA2ADB1A4B3B8A5B7BDA6BBC2A6BFC7A6C3CC
A6C7D1A5C9D5A1CAD8B6DCE8BDE1ECB5D7E1ADCCD6A5C2CB9EB9C197AFB690A6AD899DA3829499\
7B8B907582866E797C
6970726B70716E707070706F73706F75716E78716D7B726D7E726D81736D85746D88756D8B776E\
8E786E927D739580779A867C9C877E9E877F9E88809F88809E877F9E857D9E857D
9D837C9C837C9C847E9D88839E8C889D8B889B8987998986978885958785958987968D8C989191\
9A95969D9B9C9FA0A3A3A6A9A4ABAEA5AFB2A6B3B7A7B6BCA8BAC1A8BFC6A8C3CB
A8C6D0A6C8D4A0C7D4A9D1DFB8DEEABADDE7AFCFD8A7C4CDA0BBC399B1B892A8AE8B9EA484959A\
7C8C907583876E797D
6970726B70716E707070706F73706E76706D79716D7C716C80726C83736C87746D8B766D8F786E\
937C719882779C877CA18B81A48B81A38B82A38B82A38B82A38A82A28981A28980
A28880A18880A08882A08A84A18C889F8C899E8B889C8B889A8A87988A87988B8999908E9B9493\
9E9998A19D9EA4A3A4A6A9ABA8ACAFA9B1B4A9B4B8A9B8BDAABCC2ABC0C7ABC4CC
ABC8D1AACBD5A8CBD6A9CFDBADD4E1B3D6E0AFCFD8A9C6CEA2BDC49BB3BA94A9B08DA0A585969B\
7D8D917683876E7A7D
6970726B70716E706F71706E73706D76706D7A706C7D716C81726C85736C89756C8E766D93786D\
987D719D8378A38C80A68F85A88F85A88E84A78E84A78E84A78D84A78D84A68D84
A68C84A58D84A58D86A58F88A5908AA38F89A08C889E8C889C8A879A8A879A8C8A9C918F9E9694\
A29B9AA4A09FA7A5A5AAAAABABAEB0ADB2B5ACB5B9ADB9BDAEBDC2AFC1C7AFC6CC
B0CAD1B0CED6B0CFD9B2D5E0B5DBE7B4D7E1B1D0DAABC8D0A4BEC69DB5BC96ABB18EA1A786979C\
7F8E927784886F7A7D
6970726B6F706E6F6F706F6E736F6D766F6C7A706B7E716B82726B86736B8B746B91776D977A6F\
9E7F74A5877BAB9084AE9488AE9388AD9287AC9186AB9086AB9087AB9087AB9087
AB9188AB9289AB928AAA948CA9948EA7928CA48F8BA18D899E8B879C8B879B8E8B9D928FA09795\
A49C9BA8A2A1ABA8A8AEADADAFB1B2B0B4B6B1B7BAB1BABEB2BEC3B3C2C8B4C7CD
B5CBD2B6D0D8B6D2DAB8D9E3BCDFEABADCE6B4D4DDAECAD2A7C1C8A0B7BD98ADB390A3A888999D\
808F937784886F7A7E
6970716B6F706E6F6E706E6D736E6C766E6B7A6F6A7E70698271698772698C746A93766A9B7D72\
A68679B08F82B69789B6988BB4978BB2958AB09489AF9388AE9288AE9288AF9389
B0948AB1968CB0978EB0988FAE9791AB958FA7928DA48F8AA18C889E8B879D8E8BA09390A39997\
A69F9DABA5A3AFAAA9B1AFAFB3B3B4B4B6B8B5B9BBB5BCBFB6BFC3B7C3C8B9C8CE
BACDD3BCD2D9BDD5DDBFDDE6C0E1EBBFE2ECB9D7E0B2CDD5ABC3CAA3B9BF9AAFB492A4A98A9A9E\
818F937885896F7B7E
696F716B6F6F6D6E6D706D6C736D6A766D69796E687E6F688270688771688D72679273679B7C70\
AA897BB79485C29E8FBE9D8FBA9A8DB7988BB4968AB29489B19388B19389B3948A
B4968BB6998FB79C92B69D94B39C94B09992AB958FA6918BA28D88A08C889F8F8BA29491A59A98\
AAA19FAEA7A5B2ACABB5B1B1B8B5B5B9B9BABABCBEBABFC1BBC2C5BCC5CABDC9CE
BFCED4C1D4DAC2D6DDC6E0E8C7E3ECC5E6EFBEDBE3B6D0D7AEC6CCA6BBC19DB0B694A6AA8B9B9F\
829094798689707B7E
686F716A6E6F6C6D6D6F6C6B726C69756C68796C677D6D66826E668870668D716691726597796B\
A8887ABA9687C8A291C4A191BF9D8FBB9A8DB7978AB49589B4958AB4958AB7988D
BA9A8FBC9D91BDA094BBA197B9A198B49E96AE9891A8928CA38D88A08C87A08F8BA39491A69A98\
ACA29FB1A8A6B5ADACB9B3B2BCB7B7BDBBBBBEBFBFBEC1C3BEC4C6C0C7CBC1CBCF
C3CFD5C5D4D9C7D8DDCDE2E8CFE8EFCCEAF2C3DEE5BBD3DAB2C8CEA9BDC2A0B2B797A7AC8D9CA0\
8491957A868A707B7E
686F706A6D6E6B6C6B6E6B69706A67736A65776A647C6B64826D64886F658E71659374689A7B6D\
AD8B7CC09989CFA694C9A393C49F90BF9C8EBA978AB49387B19185B19186B39388
BA988CC09D91C2A195BFA197BDA39AB9A29AB09992AA938CA48D87A08B86A08E89A39390A79A98\
ADA2A0B0A7A5B5ADABBAB3B2BFB9B8C1BDBCC3C1C1C3C3C4C2C5C8C3C9CCC5CCD0
C7D0D5C8D4D9CAD8DDD0E0E6D4EAEFD2EDF4C9E1E7C0D6DBB6CAD0ADBFC4A3B4B899A9AD8F9DA1\
8592967B878A717B7E
686E70696D6D6A6B6A6C69676E6865716763746761796861806B62896F6491726595766A977A6D\
AB897AC19A89D3A996CDA593C7A090C29D8EBC988AB69386AF8E81AB8B80A78A7F
AE8F84B7968ABD9B90BD9B91B99C93B69D95B09891AA928BA48C85A08A849F8D87A2938EA69996\
AFA4A1B1A8A5B7AEACBEB5B3C4BCBAC5BFBEC8C3C2C7C6C6C6C8C9C5CACCC7CDD1
CAD1D5CCD5D9CFDADED8E3E7DBEBF0D8EFF4CEE3E9C5D8DDBBCDD2B0C1C6A6B6BA9CAAAE919EA2\
8693967C878A717C7F
676E70686C6C6969696A67666B65626D646070635D75645D7D675E896E639B7B6D9C7C6E9D7E71\
AD8B7CC49B89D7AB97D0A794CAA291C49E8EBF9A8BB99588B28E81AD8B7FA5877C
A4877CA98B80B09288B6968CB6998FB49A91AF978FAA928AA48C859F89839D8A859E8F8A9F928F\
A79D9AACA29FB3A9A7BFB4B0C3BAB7C7BFBDCCC6C3CBC8C7C9CACAC6CACCC8CDD0
CBD1D4CDD5D9D4DBDFDFE7EAE5F0F3DFF2F6D4E7EBCADBDFBFD0D3B4C4C7A9B8BB9EACAF93A0A3\
8894977D888B727C7F
676D6F676B6B67676767656368625F69605C6B5E586E5D56755F5783685D99786AA58274A88576\
B5907FC79D8BD9AC98D2A895CCA392C69E8DC19C8CBC988AB69284B08C7FAB897C
AB897DAC8C80B09084B49589B5978DB3978EAF958DA99089A38B849F89829C89839C8C889E908E\
9F97959F9998A19D9DB2ABA8B8B3B1BCB8B6C5C0BEC6C3C2C6C6C6C5C8CAC7CCCE
CACFD2CDD4D7D8DEE0E4E9EBECF5F7E7F7FBDBEBEED0DFE2C4D2D5B8C6C9ADB9BCA1ADB095A1A4\
8994977E888B727C7F
666C6E65696A656565646260645F5C645B5764585365544E644F47775E558A6B609C7A6DA78475\
B89180C89E8BDAAD98D4A996CEA492C79D8DC19989BD9788BA9587B69183B38E80
B28D7FB38F82B59285B79589B7988CB3958BAE938AA98F87A38B839E89829C88829C8D879E918D\
A196949F98979B9898A29F9FAAA8A8B1B0AFBAB8B7BFBEBDC2C3C3C4C6C7C5CACC
C8CED0CBD1D4DADEE0E7EAEBF0F5F6EDFBFDE2EFF1D6E2E4C9D5D7BCC8CBB0BBBEA3AEB197A2A4\
8B95987F898B737C7F
656C6E646868636363625F5E605B585F56535E524D5C4C4658453E6C554C81655A937366A38072\
B78F7ECA9E8BDBAC97D8AB97D0A693CAA08FC29989BA9383B68F81B28D7FB08A7C
AC8779AC887BAE8B7DB18E82B29286B19288AD9187A98E85A48B839F89819B87819B8B849F928C\
A39893A49A98A49E9CA7A1A0A9A6A5AFACACB8B4B3BCBABAC0C0C0C2C4C4C5C8C9
C6CCCECBD1D3DCDEDFEBEBEAF0F2F3F3FDFEE9F3F4DCE6E7CED8DAC0CACCB3BDBFA6B0B299A3A5\
8C96987F898C737D7F
656B6D6366676161615F5D5B5C57555A524E574C475446404F3E37604C44755D538A6C609E7C6E\
B48D7CC99D8ADAAB96DAAC98D4A896CDA392C69D8DBF9686B89081B28B7DB0887A
AD8677AC8678AC8779AF8A7DB08F82B09085AD8F85AA8D85A58B83A089829B8681968580988A85\
9F948EA69B97ABA29DADA5A2AEA9A6B2AEACB7B4B2BBB9B8BEBEBEC1C2C2C1C6C6
C3C9CACBD1D3DDDEDEF0ECEBF4F4F3F9FFFFF6FCFCE3EAEBD3DBDCC4CCCDB6BEC0A8B1B29AA3A5\
8D969880898C737D7F
646B6C6165665E5F5F5C5A59595452554E4B5247434E403B49383258453D6C554B81665A967668\
AF8978C69B88D8A994DBAD99D7AB98D1A695CAA191C49C8CBE9787BA9283B68F7F
B48C7DB38C7DB28C7DB28D7FB28E81B19084AE8F85AB8E84A78D84A38C849E8A83998882948783\
948B8698918DA39B97ACA4A1B2ABA7B5AFACB8B4B2BBB8B7BDBCBCBDBFBFBEC2C3
BEC5C6CCD0D1DDDEDDF0EBE8F9F4F2F9FBFAFAFEFCE8EDECD7DDDDC7CECEB8BFC0A9B1B29BA4A5\
8E9798818A8C747D7F
636A6C6064655C5E5E59575655514F514A474D433F483C3742332E514039634E457A6055907164\
A98474C19784D6A792DDAE99DAAE9AD4AA98CEA695C9A191C49D8DC0998ABC9586
BA9283B89182B79081B69182B59183B39184B09185AD9085AA8F86A78F87A38E879E8D879A8C87\
988D89978F8C9993919E9997A6A19FABA8A6B0AEACB3B2B1B8B8B7BABCBCBCBFBF
BCC2C3CACECEDBDADAEAE5E3F7F1EEFCF9F7FEFEFBECEEEDDADEDDC9CECEBAC0C0ABB1B29CA4A5\
8E9798818A8C747D7F
636A6B5F63645A5C5C565554524E4C4D4744483F3C4338333D302A4D3D365D4A41735A4F8A6C5F\
A38070BB9380D2A48FDDAE99DDB09CD8AD9BD2A998CDA695C9A292C59E8EC29B8C
BF9889BD9687BB9585BA9485B89486B69486B49387B19387AE9389AB9289A7928AA4918BA0918C\
9E928D9C938F9D96939F9A97A29E9BA6A3A2ACA9A8B0AFAFB4B4B4B6B8B9B8BCBD
BCC1C3C9CCCCD7D7D6E4E1DFF2EDEAFCF7F4FFFDFBF0F1EFDCDFDDCBCECEBABFBFABB1B29DA3A5\
8F969881898B747D7F
62696B5D6263595B5B5453524F4C4A494441443C383E342F392B2648383258453D6C554A836659\
9D7A6AB58D7BCC9F8BDCAD97E0B29EDBB09DD5AC9BD1A999CDA696C9A292C69F8F
C49D8DC19B8BBF9989BE9888BC9788BA9689B79689B5968AB2968BB0968DAC968DA9968EA6958F\
A49690A39893A29A96A49C99A6A09DA8A4A2ACA9A7B0AEADB3B2B2B4B6B6B6B9BA
BEC1C1CACBCBD6D5D3E2DFDCEEE9E6F9F3EFFDF8F5F1F0EEDCDDDCCACDCCBABEBEABB0B09CA3A4\
8E969781898B747D7F
61696A5C61625759595151514C494846413F4039353A302C33272243352E534139664F457B5F53\
937264AC8674C49884D5A791E0B19CDDB29ED8AF9DD4AC9BD0AA9ACDA797CAA393
C8A191C69E8EC49D8DC29B8CC09A8BBE9A8BBC998BB9998DB79A8EB49A8FB29A90AF9A91AC9A92\
A99A93A89C96A89E99A89F9BA9A29FAAA6A3ACA9A7AEADACB0B0B0B1B4B4B4B8B9
BCBFC0C8C8C8D3D2D1DEDBD8E9E4E1F3ECE8F7F2EEEEECE9DADAD8C8CAC9B9BCBCAAAEAF9CA1A2\
8E959681888A747C7F
61686A5B60615558584F504F494746433F3C3C3633362D2930241F3F302A4F3D35604A4074594E\
8B6C5EA5806FBB927FCEA18CDBAD98DDB29EDAB19ED6AE9DD3AC9BD0AA9ACEA897
CCA594CAA291C8A08FC69F8FC49E8EC29D8EC09C8EBE9C90BC9D91BA9E93B69E93B49E94B19E96\
AE9E96AD9F98ACA19BACA29EACA4A0ACA7A3ADAAA7AEACABAFB0AFB0B2B2B4B7B8
BDBFBFC6C7C6D1CFCEDAD7D5E4E0DDEDE7E3F0EBE7E4E2DFD5D4D2C5C7C5B6B9B9A8ACAC9AA0A0\
8D9495808889737C7E
60686A5A5F615457574D4E4E474544403C3A393330322A262B211D3A2D274A39325A463C6D5448\
8365579B7868B48A78C99B87D6A893DCB09CDCB19ED9B09ED6AE9DD3AC9CD1AB9A
CFA898CEA695CCA493CAA392C9A292C7A192C4A092C2A193C1A194BFA195BCA196B9A197B6A198\
B3A199B2A29BB0A39DAFA49FAEA6A1AEA7A3AEAAA7AFABAAAEAEADAFB1B1B5B7B7
BCBDBDC5C5C4CECCCBD8D5D2E1DDDAEAE4E0EFEAE6DEDCD9D0CFCDC1C2C1B3B6B5A6AAAA989E9E\
8C92937F8788737B7E
60676A595F605356564C4D4D4443433D3A3835302D2D2623251C1935292344352E544138654E43\
7A5E51927161AA8371C19581D2A28DDCAE99DDB29EDBB19ED8B09ED6AF9DD4AE9D
D3AC9BD1AA99D0A897CEA796CDA695CCA595CAA495C8A597C7A698C4A599C1A59ABEA59ABBA59B\
B8A59CB5A49DB3A59EB2A6A0B1A7A2B0A8A4AFAAA7B0ACA9B0AFADB2B2B0B7B7B6
BEBDBCC6C4C3CECBC9D7D3D0E0DAD7E6E0DCE8E4E0D8D6D3CACAC8BDBEBCB0B2B2A3A7A7969C9C\
8A91927E8687727B7D
606769595E605155564A4C4C4242413A3837322E2C2923202018142E231E3D2F294D3C335E493E\
72584C896A5BA07B6AB88D7ACA9C87D9AA95DDB19CDCB19EDAB19ED9B09FD7B09E
D6AE9DD5AD9CD4AB9AD2AA98D1A897D1A998CFA999CEAA9ACCAA9BCAAA9CC7A99CC3A99DC0A89E\
BDA89EBAA89FB7A8A0B5A7A1B3A8A3B1A9A5B0AAA6B0ACA9B2AFACB4B2B0B8B7B5
BEBCBBC4C2C1CCC9C6D4D0CDDCD7D3E1DCD8DBD8D4D1CFCCC4C4C2B8B9B8ACAEAEA0A4A494999A\
898F907D8586727A7D
5F6769585E5F505455494B4B4141403837362F2C2A26201E1C1411261C1836292346352E564238\
695145806254967463AC8472C0937FD2A38DDBAE99DDB19DDCB19EDBB19FDAB19E
D9B09ED9AF9DD8AF9DD8AD9BD6AC9AD6AC9BD5AD9CD4AD9DD3AE9FD0AE9FCDADA0C9AC9FC5ACA0\
C2ABA0BEABA1BBAAA1B8A9A2B5A9A3B2A9A4B0A9A5B0ABA8B2AEACB5B2B0BAB7B4
BFBCB9C4C1BFCBC7C4D3CECBDCD6D2E3DEDAD5D2CFCAC8C6BEBEBCB3B4B3A8AAAA9CA0A1929797\
878D8E7C8385717A7C
5F6769575E5F505455484A4B3F40403636352D2A29231F1D1812101F17132D221D3D2E274E3B32\
5F493F755A4D8A6A5B9E7A69B28976C69984D6A791DCAE99DDB19CDDB29EDDB29E
DDB29FDCB29EDCB19EDCB19DDBAF9CDBAF9CDBB19EDAB1A0D8B2A1D6B2A2D3B1A2CFB0A2CAAEA2\
C7ADA2C2ADA2BEACA2BBAAA2B7AAA3B4AAA4B0A9A4B0ABA7B2ADAAB4B1AEB9B5B3
BFBBB7C4BFBCCAC5C2D1CBC8D6D1CDDCD8D4CECCC9C3C2C0B8B9B7AEAFAEA3A6A6999D9D8F9495\
858B8C7B828471797B
5F6769575D5F4F5455474A4B3E40403535352C2A29211E1C14100D150F0C241B1634272144342C\
5440376850457D6153906F60A37D6CB58C78C89C86D4A690DBAD97DDB19CDDB19D
DFB39FE0B49FE0B49FE0B39FDFB29EE0B29EE2B4A1E1B6A3DFB6A4DCB5A4D8B4A4D4B3A4CFB1A4\
CBB0A4C6AEA3C1ADA3BCABA2B7A9A1B4A9A3B0A9A3AFA9A5B0ACA8B3AFACB7B3B0
BCB7B4C0BCB9C7C2BECFC8C4D2CCC8CECBC8C6C3C1BCBBB9B2B3B1A9AAAA9FA2A2969A9A8C9192\
83898A79818370787B
5F6769575E5F4F5455474A4B3E40403535352B2A2A211E1D1511100F09071B13102B201B3B2D26\
4B39305D473C71574B826557937262A27E6DB48C79C39884CEA18CD6A994D9AD98
DEB19CE1B39EE2B49FE2B49FE1B39EE2B39EE4B4A0E5B7A3E4B8A5E1B8A6DDB5A5D8B4A5D4B3A4\
D0B2A4C9B0A4C3ADA2BEABA1B8A8A0B3A7A1B0A7A1AFA8A3AFAAA6B1ACA9B4B0AD
B9B4B1BDB8B5C3BEBAC9C3C0D0CBC8C6C3C0BDBCB9B5B4B3ACADACA3A6A59B9E9E929697898F90\
8187897880816F787A
5F6769575E604F5456474B4C3E41413536362B2B2B21201F1614130B0806100B082018132F241E\
3F3029503D34644D42745A4E846659927263A17E6DAF8977BB9380C59B87CCA18E
D2A793D8AB96DCAF99DDB09BDCAF9ADFB09AE1B19CE2B49FE4B5A2E3B7A3DFB5A3DAB4A3D5B2A2\
D0B0A2CBAFA2C4ACA1BDA99FB6A69EB2A59EADA49EACA5A1ACA6A3ADA9A6B0ACA9
B4B0ADB7B4B1BCB8B5C2BEBAC4C2BFBCBBB8B5B4B2ADAEADA6A7A79EA1A0969A9A8E9394868C8D\
7F8587777E806F777A
5F676A575E604F5557474C4D3F42433638382C2D2D2222221816150B090808050216100D251D18\
34282243342C554239665045755C5083675A927364A07E6DAA8776B28E7DBA9483
C29A87C99F8CCEA38FD3A793D3A793D5A995D8AB97DBAE99DDB09CDEB29EDBB29FD7B09FD3AF9F\
CDAD9EC8AC9FC1A99DBAA69CB3A39BAFA29BABA19CA9A29DA9A39FA9A5A2ACA8A5
AFACA9B1AFACB4B2B0BBB7B4B7B5B3B2B2B0ADADABA6A8A6A0A2A1999C9C9296968B9091848A8B\
7C8385757D7F6E7779
5F686A585F61505658484D4E404344373A3A2E2F302424251A19190E0D0D0502010B07051B1511\
2A211C382C26493A3258453C685248745C5082675A8F706299796AA28171A98778
B08D7CB89382BC9684C29B89C59E8BC8A08ECAA28FCDA592D0A694D0A896CEA997CBA898C8A798\
C4A598BEA498B8A197B3A097AC9E97A99D97A59D98A49E9AA49F9CA5A19FA7A4A2
AAA8A5ABA9A7AEADAAAEADABADACAAA9A9A8A5A6A59FA1A19A9D9C9498988E9293878D8E818788\
7A8283747C7E6D7678
5F686A586062515759494E50414547393C3D3032332728281D1D1D121111070505040201110E0B\
1F19152D24203E312B4B3C3558463E634F46725B507F6559876D61917568997C6E
A08173A98878AC8B7CB19080B59382B99685BB9887BE9A8AC09C8CC19E8EC09E8FBD9E8FBA9D90\
B79D90B39B91AD9A90A99991A59891A298929F98939E99959E9B989F9D9AA1A09E
A4A3A1A5A5A3A6A6A4A5A6A4A4A4A3A1A2A19D9F9F999C9B9498988F93948A8F8F848A8B7E8586\
798082737B7D6D7578
60686B59606352585A4A50524348493B3F403335362A2C2C2021221616170B0A0A010000080605\
15110F221C193027233E332D4B3D3655453E614F466E594F766157816A5F887064
8F766A967C6F9C8073A18476A5887AA98B7DAB8E7FAD9081B09384B09485B09487AD9387AA9387\
A79287A49188A091889D918A9C928C9A928D98928F9793909795939A99979E9D9B
A0A09EA0A09F9FA09F9E9F9E9C9E9D9A9C9B979A999397968F93938B8F90868B8C8187887C8384\
777E8071797C6C7577
60696B5A6164535A5C4C5254454A4C3E424336393B2D30312527271B1C1D101112040404000000\
0A0807171412241F1C3129253D332E453A3450433C5B4C4564544C6F5D5577645B
7E6A61846F658B746A8F786E937C709780749B83779D85799F887CA0897D9F8A7F9B887E9B897F\
98887F9487809287819088839089858F8A878E8B898F8D8B91908E919391959796
9B9E9D999B9A989A999799999598989396969194948E92928A8F8F868C8C8288897E8486798082\
757C7E70787B6B7477
61696C5B6365545C5E4E5556474D4F414647393E3F3235372A2C2E21232417191A0D0F0F020404\
0001010B0B0A18161525211F302A2738312E4038334A403B5247425C5049655851
6C5E5672635B7767607D6C6482706886746B8A786F8D7B718F7E74917F769181788D7F778A7E76\
877D76857D77837E79827F7B83807E8583818685848687868A8A898D8F8D919391
9294949295949194949194938F93938D91918B8F90898D8E868B8C8288897F85867B8283777E80\
737B7D6F777A6B7476
616A6D5C6466565E605057594A5052444A4B3D4244363B3C2F3334272B2C1F222316191A0E1010\
0405060204040C0E0E1A19182624222F2B2934302D3B3633423D3A4A4441544C47
5B524D615853675D576C615B71655F766A63796D667D71697F736C83776F847972827973807972\
7A7571777471777673777774797A787C7D7C7F807F818282828484878989898D8C
8B8E8E8B8F8F8B8F8F8A8E8F898E8E888D8D868B8C84898A8187887F85867C8284787F81757D7E\
717A7C6E76796A7376
626B6D5D6568586062535A5C4D5456484E504247493C4142353A3B2E3334272B2C202324181B1C\
10131407090A06090A1013131B1C1C2626252C2B2A312F2E3634333D3B3944423F
494744504C4956524F5B5653615B57665F5B6A635F6E6762706A64746D6878716D79736F78736F\
74726E747270737371737472737574767878787B7B7B7E7E7D8080828585838787
84888985898A858A8A858A8A84898A8388898187888085867D84857B8283798081767D7F737B7D\
70787A6D76786A7375
626B6E5E67695A6264555D5F50585A4C5254474D4F4147493C4143363B3C303436292E2F232728\
1C1F211418190B0F100B0F101418192022222728282B2D2C2E2F2F3435343B3C3B
40413F4445434748474C4C4B52514F5756545B5A57605E5B63615E6765616867646D6B686B6A68\
686A68676A69676B6B686D6C6A6E6E6C717272767675797A777B7C7B7F807D8282
7F84848085858085868085867F85867E84857D83847B82837A8082787F80767D7F737B7D71797B\
6E77796C7577697275
636C6F5F686B5C6467586062545B5E5057594C5254474E5042494A3E4345383E4033383A2D3234\
272C2E2126281B1F21121719101617161C1D222627292D2E2D31312F3232323636
363A3A3A3E3E3F4343424646444848494D4D505353565856595B5A5D5E5C5E6160646564636564\
616565616666616768636969656B6C666D6E6F747471767774797A767C7C787E7F
7A7F807B80817B81827B81827A81827A8082798081787F80767D7F757C7E737B7D71797B6F777A\
6D76786B7476697275
646D70616A6C5E66695B6365575F62545C5E51585A4D5456495052454C4E41484A3D4345393F40\
343A3C2F3536292F31242A2C1F25271A21231C2325262C2D2C3234313637333939
363C3C373D3F3A41423E454742494A454B4D4A50524E545554595A585C5C5A5E5E5C60605E6162\
5D62635C62635C64655E6566626869636A6A6A70716E737470767772797A747A7C
757C7D767D7E767D7E767D7F767D7F767D7E757C7E747B7D737B7C727A7C70787B6F77796D7678\
6C74776A7376687274
646E71626C6E60696B5E66695B6466596163565E60535B5D51585A4E55574B5254474E50444B4D\
4047493D4346393F42353C3E31383B2D3437282F322830332A333630383A373E40
3840413941423B44463F4749434A4C454D4F4850514A52544E5557505859555B5C575C5E595E5F\
5B5F615B60615D63645A60615C6364636A6B686E706B72736D74766F7678707779
71787A72797B727A7B727A7B727A7C72797B71797B70787B70787A6F77796E76796D75786C7477\
6A7376697275687174
656E71646D70626B6E616A6C5F686A5D66685C64675A6265586062565E60545C5E525A5C4F575A\
4D55574B5255485052454D50434B4D40484B3E46493D46493D45493A43473E4649
41494C41494C424A4C424A4D454E4F4B52544D55564F575952595B535A5C555C5E585E60596062\
5B6163565D5F5B61645E656761686A646B6D676E706971736B72746C74766D7577
6E75776E76786E76786E76796E76796E76786E76786D76786D75786C75776B74776B74766A7376\
697275687274677174
666F72656F71646E70646D70636C6F626B6E616A6D60696C5F686B5E676A5D66695C65675B6466\
5A6265596164576063565F61555D60545C5F535B5E525B5E525A5E515A5E525B5E
535C5F535B5F535C5F525A5E50595D515A5E525B5D535C5E545D60555E60565E60565E61586063\
5E66685F676A61696B626B6D646C6E656E70676F716870736971746972746A7275
6A73756A73756A73766A73766A73766A73766A73766A73756A7375697275697275697275687274\
687174677174677173
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.25526 0.488926 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(45) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
727576727476727476727476717475717475717475717375717374717374717374717274717273\
717273717273717272717172717172717172717171717071717070716F6F706D6C
7170707171717171727171727072737071727071727071727070726F71726F70726F71726F7173\
6F72746F737570747671757871767972777A72787A727A7C747B7E757D80767F83
788387767E82757C7F747B7D747A7C74797B73797B73787A73787A737779737779737779727678\
727678727677727577
727476727475717475717375717374717374717273717273707172707172707071707071707070\
706F6F706F6F706E6E706E6E706D6D706D6D706C6C706C6B706B6A706A68706865
706B69706C6C706D6E706D6E6F6E6F6F6E6E6E6D6E6D6D6E6D6D6E6D6D6E6C6D6E6C6E6F6D6F70\
6D71736E72746F747770767971787B727A7D737C7F747E827681867885897A888E
7C8B9179868A788287778084767E82757D80757C7F757B7E747B7D747A7C74797B73787B73787A\
737779727678727677
7274767173757173747173747172737071727071717070707070706F6F6F6F6E6F6F6E6E6F6D6D\
6F6C6C6F6C6B6E6B6A6E6B6A6E6A696E69686E68676F68656F66646F65626F635F
7066646F68676F6A696F6A6A6E6A6A6D6A6A6C6A6A6B696A6C696A6B696A6A6A6B6B6C6D6B6D6F\
6C6F716C71736E74776F777A717A7D727C8074808375838878878C7A8C927E9199
7E8F967C8B917A888D79858A788387778185768083767F82757D81757C7F747B7E747A7C74797B\
73787A737779727678
7274757173747172737072737071727070716F6F706F6E6E6F6E6E6F6D6C6E6C6C6E6B6B6E6A6A\
6E69686D68676D68666D67656D66646D65636D64626D63606E625F6E615D6E5F5A
6F63606F65636E66656E67666D67676C67676B67676A67676A66676A6667696868696A6B6A6C6E\
6B6E706B70736C74776E787B707B7F727F8375838877888D7A8C937D92998198A1
7F949B7D90977C8C927A898F79878C798589788387778286778084767E82757D80757C7E747A7D\
74797B73787A727678
7174757173747172737071727070706F6F6F6F6E6E6E6D6D6E6C6B6E6B6A6D6A696D69686D6766\
6C66656C65646C64626C63616C62606C615E6C605D6C5F5B6D5F5A6D5E586E5C56
6E605C6E625F6D63626D64636C65646B65646A6565696565696464696465686566686869696A6D\
696D6F6A70736B73776D787C707D8172818676868B798C927B91987F979F829CA6
8098A07F949B7D90977C8D947B8B917A888E79868B788489788287778184767F82757D80757B7E\
747A7C73787A737778
7174757172737071727070716F6F6F6F6E6E6E6C6C6E6B6B6D6A696D69686C67666C66656C6563\
6B64616B62606B615E6A605D6A5F5B6A5D596A5C586B5B576C5B556D5A556E5A54
6E5D596E5F5C6D615F6C62606B62616A63626A636369636368636367636367646567666768696B\
686C6E6970736A73776C797D6F7F8372838976898E798F967D959E819CA6839FA9
819BA48097A07F949C7D91987C8E957B8C927A898F7A878C79858A788387778184767F82757D80\
747B7E74797B737779
7173757172737071716F6F706F6E6E6E6C6C6E6B6A6D69696C68676C66656B65636B64626A6260\
6A615E6A5F5C695E5A695C58695B576959556958536957516A57506D57506F5A53
6E5C576D5D5A6C5E5C6C5F5E6B605F6A606069616068616167616267616266636466656667686A\
676B6E6870736A74786C7A7D6F7F8472868B768B927A929A7E99A283A1AC83A1AB
829EA7819AA38097A07F949C7E91997D8F957C8C927B898F7A878C798589788287778084767E81\
757C7F747A7C737779
7173757072727070716F6E6F6E6D6D6E6B6B6D69696C68676C66656B64636A63616A615F695F5C\
695E5A685C58685A5667595467575267555066544E66524C66514A705850715B54
6F5B566D5C586C5D5A6B5D5C6A5E5D695E5D685F5E675F5F665F5F666060656262656465666769\
676B6E6870736975786C7A7E6F818672878D778E957C959D7F9CA684A5B084A3AE
83A0AB829DA7819AA38097A07F959C7E92997D8F957C8C927B8A8F7A878C798489788185767F83\
757D80747A7D73787A
7173747071726F6F706F6E6E6E6C6C6D6A696C68676C66656B64626A626069605E695F5C685D59\
675B5767595566575266555065534E65514B644F49634D46644C44765C53715A53
6F5A556D5A566B5B586A5B59695C5B685C5B675C5C665C5D655D5D655E5F646161646465656769\
666C6E6771746976796C7B806F828773888F7790977C97A0809FA985A7B385A6B1
84A3AE83A0AB829EA7819BA48098A07F959C7E92997D8F957C8C927B898E7A868B788387778084\
767E81747B7D73787A
7173747071716F6E6F6E6D6D6D6B6A6C69686C67656B64636A626069605E685E5B685C59675A56\
66585365565165544E64524C644F49634D46634B446048406B5048745A52705852
6E58536C58546B5956695957685A59675A5A665A5A655A5A645A5A635B5D635F6063636465686A\
666D6F67727469777A6D7D81708489748A907891997C99A281A0AB85A9B585A9B5
85A6B284A4AE83A1AB829EA7829BA48198A07F949C7E91987D8E947C8B917A888D798589788285\
767E82757B7E73787A
7173747070716F6E6E6E6C6C6D6A696C67666B65646A636169605E685E5B675C58665A56665753\
65555064534D63504A634E48624C4561494260463E674C4370544B70554D6E5550
6C56516B5652695653685756675857665858655858645758635758625A5B625E5F62636464686A\
656E7067737569787C6D7E8371858A758C9379939A7C99A281A0AB84A8B487ACB9
86AAB685A7B385A4AF84A1AB839EA7829BA381979F80949B7E90977D8D937B8A8F7A868B788387\
777F83757C7F73787B
7172737070706F6D6D6D6B6B6C69686B66656A646269615F685F5C675C59665A56655753645450\
63524D624F49624D46614B4361484060463D63463D6E50476E51486D524B6C534D
6B534E69534F68545167565466565666575765565663565762555661595A615D5E626264626768\
646E706673766A7A7D6E808472878C778E947A949C7D9AA381A0AB83A7B387ADBA
88AEBB87ABB786A8B385A4AF84A1AB839EA7829AA381979E7F939A7E8F957C8B917B878C798488\
778084757C7F74797B
7172736F6F706E6D6D6D6A6A6C67666B65636A6260685F5D675D5A665A5665575364545063524C\
624F49614C46604A425F473F5F453C5E42386D4D436E4F456D50476C50496A504B
69504B67504C66524F665453665555655555655556635657615758605959615E5F616163606466\
636C6E6573756A7B7D6F828573888D788F967B959D7E9BA480A0AB83A7B286ACB8
89B1BF88AEBB87ABB787A8B386A4AF85A1AA849DA68299A181959C7F91987D8D937C898E7A858A\
788185767D8074797B
7172736F6F6F6E6C6C6D69696B66656A646269615E685E5B665B5765585464555063524D614F49\
604C465F49425E463F5D433B5D40376243387150456E4F466C4E466B4F48694E48
674D48644D49644F4D66535365545463545468595A645858625A5B605A5B5F5B5D5E5F615E6264\
61696C636F726A797C6F8386758A8E7991977C979F7E9CA480A0AA82A6B185ABB7
88B0BE89B2C089AFBC88ABB788A8B387A4AE86A0A9849CA482989F80939A7E8F957C8B907A868B\
788286767E8174797C
7072736F6E6F6E6B6B6C69686B6564696260685F5D675C5965595564565163534E614F4A604C46\
5E49425D463E5C433B5C40375A3C336C4B3F704F446E4E456B4D456A4E48674C46
654A45624A46624D4B635151675858655857685C5C645A5A625A5B605B5B5E595A5D5F615D6264\
5E66695F6A6D687579718286778C907B92987E99A07F9DA580A0AA81A4B084A9B6
86AFBD89B3C28AB2BF8BAFBC8AACB789A8B288A3AD869FA7849AA282969D8091977D8C927B888C\
798387777E81747A7C
7071726F6E6E6D6B6A6C68676A646369615F675E5B665A5765575363544F62504B604D475E4943\
5D463E5B423A5A3F365A3D345B3C32735043704F446E4E446B4D45694D47664B45
634843604845614B4A614F506B5D5C685C5B665B5B645B5C6159595F595A5D595A5D5F615D6163\
5D66695E686C6472776E7D81788B8F7D949A7F9BA1809EA67FA0A980A3AF83A8B5
85AEBC87B3C28AB3C18DB3C08EB0BC8CACB68AA7B088A2AB869DA583989F8193997E8E937C898E\
798488777F82747A7C
7071726E6E6E6D6A6A6B67666A636168605D675C5965595564555162524D614E485F4B445D473F\
5B433B583E355439305B3C33664539745145704F446D4D446A4D45684C46654A44
624742614A47624E4C635251695959675A59645959635A5A6057585E58595C585A5D5D605D6164\
5E686B5F696D63717768797E74868B7F969B819CA2809EA77F9FA97FA2AE81A7B4
84ADBB86B2C18AB5C48EB5C491B5C18FB0BA8CAAB48AA5AE879FA8859AA182959B7F8F957D8A8F\
7A8589777F83757A7D
7071726E6D6D6C69696B6664696260675E5C665B5864575363544F61504A604C465E48415C443D\
5A4038553A3150342A5E3F34724E427250446F4E446C4C446A4D45684C45654A44
624843624C486553516555536656566457576358576157575F56565D56575C585A5C5C5E5C6164\
5E676A616A6F63717768797F6F83897D9499819DA3809EA77E9EA87EA1AD80A6B3
83ABB985B0BF87B3C393BBC994B9C592B4BF8FADB88CA8B189A2AA869CA483969D8191977E8B90\
7B868A788083757A7D
7071726E6D6D6C69686A656368615F675D5A65595663555162524C604E485F4A435E473F5C433A\
5A3E3556393055372C6241366F4D416E4D426D4D436B4D45694D45674D45654A44
624944624C486654526656546556556456566257566056565E55555C55565B58595B5B5D5C6063\
5E6569626A70657277697A8070838A788F967F9AA07F9DA67E9EA87DA0AC7FA5B1
82AAB883AEBD83B1C198C0CE97BDC995B7C391B1BB8EAAB48BA4AD889EA685989F8292987E8C91\
7B868B788184757B7D
7071716E6C6C6B686769646268605D665C5864585462544F61504A604C465E48415D453D5C4138\
5B3E345A3A305D3D3162423769493E6C4C426C4D446A4D45694D45674D46654B45
634A44634C4865524F6657556557566356566156555F55555D54545B54555A57585A5B5D5B5F63\
5D6569626C706673796B7B8271848B768D947C969D7D9AA47D9CA67C9FAB7EA4B0
80A9B781ADBC82B0C19AC2D09BC0CD97BAC694B4BE90ADB78DA7B089A0A8869AA183949A7F8E93\
7C878C798185757B7E
7070716D6C6C6B6766696361675E5C655A5763565261524D604E485F4A435E463F5D433A5C4036\
5C3D325D3C2F5F3F3363443967493F6B4C426B4E456A4E46694E46674D46654C45
644A45634C4863504D6556546558576357566055545E55555C54545A5354595657595A5C5B6063\
5E6569636D7168747A6D7D8271848B768C947A949D7B97A17B9AA57B9EAA7DA3B0
7FA8B680ABBB7FAEBF9CC3D29EC3D09ABDC996B7C293B0BA8FA9B28BA2AA879CA384959B808F94\
7D888D798285757B7E
6F70716D6B6B6A6666686260665D5B64585562545060504B5F4C465D48415D443C5C41385C3E33\
5C3B2F5E3C31603F3464453B684B426B4D446B50476A5047684E47674D47664C46
644B46634D48634F4C6454526458576257566054545E55545C545459525358555759595C5B6063\
5E6569636E7268767B6E7E8472848C758C9378929B79959F7A99A37B9DA97DA2AF
7FA7B580ABBA7EACBD98C0CFA2C7D59DC1CD99BAC595B2BD90ABB48CA4AC899DA585969D819095\
7D898D798286767C7E
6F70716C6B6B6A656567605F645C5962575360524E5E4E485D49435C453E5B42395B3E355B3B31\
5C392D5E3D3160403566493F6A4D446B4F466B51486A5048694F48674E47664D47
654D47644E48624F4B6453516458566257566055545D54545B5353585253575456595A5C5B6063\
5F666A646E7369767C6F7F8573858D758B93768F9877939D7997A27B9CA87DA1AE
80A7B482ABBA82AEBD91BBCA9FC7D5A2C7D39BBDC896B5BF92ADB78EA6AE8A9FA686989E829196\
7E8A8E7A8386767C7E
6F6F706C6A6A696464665F5D635A576155515E504B5D4B465B47405A433B593F36593B315A382D\
5B382C5E3D31624539694E446C50466C51486B51496A5149695049674F48664E48
654E48644F4963504C6454516457556256555F54545D54545A5253575253565456585A5D5B6064\
60676B646F746A777D6F808673858D748A92758D9676919C7996A17B9BA77EA1AE
82A7B485ADBB88B1BF90BAC99BC5D4A2C7D49CBECA97B6C193AFB98FA8B08BA0A88799A0839297\
7F8B8F7A8387767C7F
6E6F706B6969686363645E5C6158555F534F5C4E495A494359443D584038573B3257382E583529\
5A372B5E3E33654A3F6C51476E52486D52496C52496A5149695049684F48664F48
654F4964504A65524E6455526457556256555F54545D54545A5152565253565456585A5D5B6164\
60696C6570756B787F6F808672858C748991748C9576909A7995A07C9BA77FA1AD
83A7B488AEBC8CB2C193BCCB9CC7D69DC4D29BBFCB98B8C394B1BA90A9B28CA2A9889AA1849398\
7F8B907B8487767C7F
6E6F6F6A6868666261635C5A6056545D514D5A4B4658464056413A553C3454382E543429563328\
59372C604136694E436F544970544B6E544B6D524A6B5149695049674F48674F49
664F4A65514C66544F6557536558566357566055555D5454595152555152555457575A5D5B6165\
60696E6671766B797F6F7F8671848B728790748B94758F9A79949F7C9AA680A1AD
84A8B48AAFBD8EB3C195BDCC9CC6D69EC6D39CC0CD99BAC596B2BC92ABB48EA3AB899CA2859499\
808C917B8488777D7F
6E6E6F696868656160615B595E54525A4E4A57484455433D533D3651383050342A4F2F24523127\
58392E64463A70534773574C72564D70554C6E534A6B5149695049674F48664F49
66504B66534E675651675855675A576459576157565D5454585152555152545457575A5D5B6266\
606A6F6671776A787E6D7E8570828A71878F748A94768F9979949F7C9AA680A0AD
85A7B48BAEBC8FB3C096BECD9CC5D4A1CAD89EC3D09BBCC798B4BE94ADB58FA5AD8B9DA486959B\
818D927C8589777D80
6D6E6F68676764605F5F59575B524F574B48544541513F3A4F3A334D342C4C2F264A2A1E4B2E24\
583B31684A3E78594C785B4F75594E72574D6F544B6B524A685049664F48664F49
66504B67534E6958536A5B57695C59665B5A6258585D5555585152545152535457565A5D5A6166\
606A6F64717769767D6C7D846F818A71868F748B94768F9979949F7D9AA681A0AC
86A7B48BAEBA90B2BF98BECD9FC5D4A4CEDCA1C6D39EBECA9AB7C096AFB791A7AE8C9EA587969C\
828E927D8689777D80
6D6D6E676666625E5D5D5755584F4D54484550423D4D3B364A362F493028472B2246271D472D23\
573C326A4D417F5E507D5E52795B5075594E70554C6B5149674F48644D47644E49
66504B69544F6B5A546C5D596B5F5C695E5D645B5A5E5656585253535052525356555A5D586166\
5E696E62707666757C6B7B836E818970858E748B94778F9A7A949F7D9AA6819FAC
86A6B38BACB98FB1BF9ABDCBA3C9D7A8D1E0A4C9D6A1C1CC9CB9C398B1B993A8B08EA0A689979D\
838F937D868A787E80
6C6D6E666565605D5C5B5553554D4A5045424B3E3A48373245312B442C2443281E43271E432B23\
573E346F51458663548262547D5E52785B5172564D6B514A664E47624C47614D48
64504B6B5650705C576F5E5A6E615E6D6462665E5D5E585857525352505251535553585C565F65\
5C686E5F6E7463737B6879816D808870858E768C9578909A7A949F7D99A5819FAC
86A5B38BABB88FB0BE9CBECBA8CCD9ACD5E3A8CCD8A4C4CF9FBBC59BB3BB95AAB190A1A88A999E\
8490947E878A787E80
6B6C6D6564645E5B5A585351524A484C413E46393541322D3E2B253E272040251C412820412D25\
5940367454488C68588665578060557B5D5274584F6D534C664E48634D485D4B47
624F4B6C5751715E5973605B7264616F666467605F5F5959575253514F514F515450575B525B62\
5B686E5C6B725F707965777F6D808871868E778C9579919B7B95A07C99A5819FAC
86A5B289AAB890B1BFA0C0CDADCEDBB1D8E5ACCFDAA8C6D1A3BEC79EB5BD98ACB392A3A98C9A9F\
8591957F878B787E81
6B6C6D6363635C595955504F4E4745473D3B4034313A2B2735241E341E1841271F432C24463129\
5A423977574A916C5C8A685A8463577D5F54775B5271574F6A524B66504A604D48
64514C6A5751705E5974625D7365616E656267605F5E5959575253504F514D50534E555A4F5A60\
56656C56676F586C7565777F6C808870858D788D967B919B7D96A17D9AA6809EAB
84A3B187A8B690B1BFA4C2CFB3D2DEB6DAE6B0D1DDACC9D3A7C0C9A1B7BF9BAEB594A5AB8E9BA0\
87929680888B797F81
6A6B6C6262625A5857524E4D4A4442423937392F2C3124202718142C19133E28204631284B372F\
61483D7C5B4D956F5F8E6A5C87665A7F6055795E54745B536E564F69524C66514C
67534E6B58526F5D5872625E7164616C6361665F5F5E5859565253504F514D50534D555A4F5A61\
52626A52646D52677164767E697E866E838C798D957B929B7D96A17C99A67E9DAB
81A1AF83A5B592B2C0A7C4D0B9D5E0BBDDE9B6D5DFB1CCD6ABC3CCA5BAC19EB0B797A7AC909DA1\
88939781898C797F81
696B6C6161615856564F4C4B46413F3D3634332A27281D1A1B0E0A29191437241E46322A513C33\
694D41815F51987161926D5F8A695D8263597B6056765C54715A526C56506A544F
6A56506D5A54705E5871625D7164616B6260655E5D5D58585652534F50524C50534C54594F5A61\
52616952646D5368725F727B667A836C828B768B9478909A7994A07A97A47A9BA9
7D9FAD7FA3B294B4C1ABC6D1BDD6E0C1E2EDBCD9E3B6D0D9B0C7CEA9BDC4A2B3B99AA9AE929EA3\
8A9498828A8D7A7F82
696A6B6060605655554D4A49433E3D3932312E262422181514090622161133231D443129563E36\
6E50458562549A73629571628D6C6086685D7E6259785E56735B546E59536E5952
6C58526E5C566F5E5971615D7064606A605E635B5B5C56575553544F51534C4F544A53574D5A60\
52616854656E586B745E717B62788169808A708892738C9775919E7695A27799A7
779CAB7DA2B296B5C2B2C9D3BDD5DFC6E4EEC2DDE6BDD4DCB6CAD1AEC0C6A5B5BB9DABAF94A0A4\
8C9599838A8D7B8082
686A6B5E5F5F5553534A4848403C3B35302E2A23211D15131006041D120E2F211C423029573F36\
6F52468764569A73639874659170648A6C6183675E7C635A765F58725D57725D56
6F5C556F5D576E5D586F5F5B6C605C685D5C6159585C55565653555052554D51564952574A575D\
4F5F6653646D5A6C745E727B617881667E886B848F6E8995718E9B7393A07396A4
7298A87EA3B299B7C3B5CAD4BDD4DEC7E3EDCDE5EDC4DAE1BCCED5B3C3C9A9B8BDA0ADB197A1A5\
8E969A848B8E7B8082
68696B5D5E5F5352524847463E3A3A322E2D26201F1A13110C050219100D2B1F1A402F28553F36\
6F52468664569972639A76679474678D6F65866C6280675F7B645D77615B745F59
715E58705E586E5D576C5D58695C58655B596057575B55565654565253574F53584B545A49565D\
4B5C634E616A5669725B717A617780647D8768828D6C87946F8D9A70909E6E93A2
6D96A680A5B49AB7C4B2C8D2C0D6DFCAE3ECD8ECF3CDDFE5C2D3D8B8C6CCADBABFA3AFB399A3A6\
8F979A858C8E7C8082
67696A5D5D5E5251524745453B3938302C2B241F1E1711100A0302180F0C271C183E2D26533E35\
6C50458462559771629B776997766A9072688A6F66846B637E68617A655E76625C
73605A705E596D5C576B5B57675A566458565F57565B545557545654555850555A4E565C4B585F\
4C5C634D606851666F576D775D747E617B8666818C6886936C8A996A8E9C6A91A0
6C95A582A6B499B7C3B0C7D1C4D7E0D2E6EDE0F0F6D4E3E9C8D7DCBDCACEB1BDC1A6B0B49CA4A8\
91989B868C8F7C8183
67696A5C5D5E5151514544443A38382E2B2A221E1D15100F080201160E0C251B173A2A25513B33\
684E447F5F52926E609C77699A796C93756B8C7269866E67816B647C676177645E
74615B705F596D5C576A5B566659556357555F56555B545558555755565952575B4F585E4D5A61\
4D5D654E616A516670556C7659727C5E7884627E8B648391668795668B99678E9E
6E96A684A7B59BB8C4B0C8D1C6D8E0D8E8EDE5F2F7DCE9EDCFDBDFC2CDD0B5BFC3A9B2B59EA5A8\
92999C878D8F7D8183
67696A5B5D5D5050514444443837372C2A2A201D1C130F0E060100140E0C231A163728234C3831\
634A41795B4F8D6B5D9A76689C7B6E96786D8E746B887169826D667D696278655F
74625D715F596D5C57695A566658546257555E55545B555658565856575A53585D515A5F4F5C62\
4F5F6650636B526771546C7657717C5A76825D7B885F808E618493618897648D9D
7198A888A9B79DB9C5B2C9D2C8D9E0DDE9EEEAF3F7E5EFF2D4DEE1C6CFD2B8C1C4ABB3B69FA6A9\
949A9C888D8F7D8183
66696A5B5C5D4F50514343443736372B29291E1C1C120E0E040100130D0C22191634262147352E\
5D463D73574C88675A9673659D7B6E977A6F90766D89726A836F687E6B64796661
75635E715F5A6D5C58695A566558546156545E55555B555659565957585B54595E525B61515D64\
50606851646C526871546C7656707C5775815979865C7E8C5D82915E8696658E9E
779CAB8CACB9A1BCC7B7CCD4CDDCE2E1EBEEEEF5F8EAF2F5D8E0E3C9D0D3BAC2C4ADB4B7A1A7A9\
959A9C898E907D8183
66696A5B5C5D4F50514343443736372A29291D1C1B100E0E030000110C0B21181530242042322C\
56423A6E5449826357916F629A786B977A6F90776E8A736B846F687E6C66796862
75635E705F5A6C5C58685A566558556156545E55555C56575A575A58595D555B5F545C62525F66\
51616952656D526872536C7754707B567480577886597C8B5A81905E86966991A1
7CA0AE90AFBCA7BFC9BDCFD7D2DFE5E6EDF1F5F9FBEBF1F3DAE0E2CAD0D3BCC2C4AEB4B6A2A7A9\
959A9C898E907E8183
66696A5A5C5D4F50514343443636372929291C1B1B0F0E0E020000100C0B1F17152D231F3D2F29\
513F37674F467B5E538C6C5F95746895796E90776E8A736B836F697E6C66796863
74645F70605B6C5C58685A566457556157555E56565C57585A595B585A5E565C61555E64536167\
52636A52666E536973536D7754707C547380567886577C8A5A81916188986F95A4
82A4B198B4BFADC3CCC3D3DAD8E3E7ECF1F3FAFDFFE9EEEFDADFE0CBD0D2BCC1C3AFB4B6A2A7A9\
969A9C8A8D8F7E8183
66696A5A5C5E4F505142434436363729292A1C1B1C0E0E0E0000000F0B0A1C16142B211E392D28\
4C3B35604A4273594F85675B8E6F6492766B8F776D89736B836F687D6B65786862
73645F6F605C6B5C58675A566458556157565E56575D58595B5A5D5A5C5F585E63566065546269\
54646C53676F536A74536D7853717C537481547885577C8B5C8392668C9B779AA8
8AA9B59FB8C3B4C8D0CAD7DDE0E7EBF2F5F6FBFDFEE8ECEDD9DDDECACED0BCC0C2AFB3B5A2A6A8\
969A9B8A8D8F7E8183
66696A5B5D5E4F5052434445363738292A2B1C1C1D0E0E0F0000000D0A0919151427201D352A26\
46373159463E6A534A7B615686695E8E72688D756C88726A826E677C6A65776761
72635F6E605C6A5C59665A576358566158575F58585D5A5B5C5C5F5B5E615A606558616756646A\
55666E556871546B75546E7953717D537481557886597D8C6186956E92A080A0AD
94AFB9A7BDC7BCCCD3D2DCE1E8EDEFFAFBFCF6F8F8E6E9E9D7DADBC9CCCEBBBFC0AEB2B3A2A5A7\
95999A898D8E7E8182
66696B5B5D5F4F51524345463738392A2B2C1D1E1F0F1011000102090808161312241D1B302723\
40332F51413A624E467059507D6359886D628A7268867068806C667B6964756661
71625E6C5F5C695D5A665A586258576058575F595A5E5B5D5E5E615D60645C62665A636958666C\
57686F566B73556D76546F7A54727E5475825679875C818F688B997798A58AA6B2
9EB5BEB0C3CBC4D1D7DBE2E5F0F1F3FFFFFFF1F2F3E3E5E5D5D7D8C7CACBBABDBEADB0B2A1A4A5\
959899898C8E7D8082
67696B5B5E5F505253444647383A3B2C2D2E1E20211112130203040707081311101F1A192B2421\
392F2C493C3759484266534B725C537D655C836C63826D657E6A64796862736460
6F625E6B5F5C685D5A655B59625857605858605B5B605D5F6060635F63665E64695C666B5A686E\
596A72586C75576F7855717C56747F5778855A7C8A63869471919E819EAA93ACB6
A7BAC3B9C8CFCED7DCE4E7E9F5F4F5FFFFFEEEEFEFE0E1E1D2D4D4C5C7C8B8BABCACAEB0A0A2A4\
949798888B8D7D8082
676A6B5C5E60515354454749393B3D2D2F312123241315170507080405060E0E0E1A1717272220\
332B2842373351443E5D4D4668554E715D557A655D7B665F7A676076666170625E
6C615E695E5C675D5A645B5A6059585F5959615C5D63606163636562656861676B5F696E5D6A70\
5C6C745A6F7759717A58737E5976815C7B8861828F6C8C997B98A38BA4AF9DB2BB
B0C0C7C2CED3D8DDE0ECECEDFBF9F9F9F9F8EAEAEADCDDDDCFD0D0C2C4C4B6B8B9AAACAD9EA1A2\
939697888B8C7D8081
676A6C5D5F6152545647494B3B3E3F30323424262817191B0A0D0F0104050A0B0C161515221F1E\
2D27253B322F4A3F3A5447435F504A65554F6D5C56715F5973615C70625D6B5F5C
695E5C685D5B665D5B635C5B5F595A5F5A5B625E5F65626366656865686B64696D616B70606D72\
5F6F775E727A5D747D5D76815E7A8563808C6A899476939E859EA995ABB4A7B9C0
B9C6CBCCD4D8E0E3E4F1F0F0FFFCFBF2F1F0E4E4E4D7D8D8CBCCCCBEC0C1B3B5B6A7AAAB9C9FA0\
929496878A8B7C7F81
686B6C5D6062535657484B4D3E4042333537272A2B1B1E200F121402060805080A1213131D1C1B\
282523342E2C443A374E433F564A465C4F4B62544F675854685A56675B58645B59
645B59645C5A645D5B625C5C5F5B5B605D5D636060656465676769686B6D676C70646E72647075\
63727963767D627880637B84667F896C8791758F99829AA390A5AEA0B1B9B1BFC5
C4CCD0D6DADCE6E7E7F6F3F2FBF8F7EBEAE9DEDEDED2D2D2C6C7C7BBBCBDB0B1B2A5A7A89A9D9E\
90939486898A7C7F80
686B6D5E61635457594A4D4F40434536383A2B2E3020232514171A080B0E0307080E1011191919\
2422222F2B2A3D3634473E3C4D4441534946594E4B5D524E5F55525E56545D5756
5E5857605A59605B5A605D5D5F5C5D605E5F63616265656668696B6A6D6F696F72687175687378\
68757B697980697C846B81896F868F778E9680969E8DA1A89BACB3AAB8BEBCC5C9
CED3D5DEDFDFEBEAEAF8F4F3F0EEEDE4E2E2D8D7D7CCCCCDC1C2C2B7B8B8ACAEAFA2A4A5989A9C\
8E91928588897B7E80
696C6D5F626456595B4D5051434648393C3E2F323425282A1A1D200F121504090B090D0F151718\
2020202B29283632313E393746403E4A4341514947554D4B564F4E575151585454
5955565D58595B58595E5C5D5F5D5E605F60626263656668696A6C6C6E706C71746B73776C767B\
6D797E707D8370818874868D798C9381949B8C9DA498A7ADA6B2B7B5BFC2C7CCCE
D8D9DAE3E3E2F0EEEDF0EDECE5E3E3DBDAD9D0D0D0C6C6C6BCBDBDB2B3B4A9AAAB9FA1A2969899\
8D8F908486887B7E7F
696C6E616465585B5D4F525446494B3D40423337392A2D2F20232615191C0B0F12070B0D121617\
1C1E1F262627302F2F383535403C3B433F3E4944434E49484E4B4B514F4F535152
5553555957585958595C5B5C5D5D5F6061626264656668696A6C6E6D70726E73756E757970797D\
737D8176818677858A7C8B918392978C9AA096A2A8A2ADB2B0B8BCC0C5C7D0D1D3
DEDDDDEAE8E7ECEAE9E4E2E1DBDAD9D2D1D1C9C9C9C0C0C0B7B7B8AEAFAFA5A6A79C9E9F939597\
8B8D8F8385877A7D7F
6A6D6F6265675A5D5F525557494C4E414446383B3E2F3335262A2C1C2023121719090E110F1517\
191D1E2224252B2C2D3433333A38383D3B3C4240404745454948494E4D4E4F4F51
52525455555757585A5A5B5C5C5E6060626364656767696B6C6E706E717371757872787B757C7F\
7880837A84887D888D828E938B979B959FA39FA8ACACB3B6BABEC0C8C9CBD7D6D6
E5E3E2E8E6E5E0DFDED9D8D8D2D1D1CAC9C9C1C1C2B9BABAB1B2B2A9AAABA1A2A3999B9C919394\
898B8D8184857A7C7E
6B6E6F6366685C5F615457594D505245484A3D404335383B2D303324282B1B202212171A0F1517\
161B1D1F2324272A2C2F313236363738393A3D3D3E4142444446484A4B4D4C4E50
50525452545756585B595C5E5D5F61616365656769686B6C6D707171737575787A757A7D797F81\
7C82857D8689818B8E899295929A9E9DA4A7A8ADAFB4B7B9C1C2C2CECDCDDBD9D8
E5E3E3DDDCDCD6D5D5D0CFCFC9C8C8C1C1C1BABABBB3B3B4ABACADA4A5A69D9E9F9597988E9091\
87898B808384797C7D
6B6E706468695E6163575A5C505355494C4F4246483B3E4133373A2C303324292B1D2225161B1E\
141A1D1B212424282A2D303233353736393B393C3E3E414341444746494C4B4E50
4E515452555856595B595C5F5D606261646666686A6A6C6E6F7173747677787B7C7A7E807D8183\
7E838580878A868E908E9597989D9FA3A7A9AFB1B2B9BABAC6C4C4D2CFCFDBD9D9
DAD9D9D3D2D2CCCCCCC6C6C6C0C0C0B9B9BAB3B3B4ACADAEA5A7A79FA0A1989A9B9294958B8E8F\
8587897F8183787B7D
6C6F7166696B6063655A5D5F5457594D5153474B4D4145473A3E4134383A2D3234272C2F212629\
1B21241A202321272A2A2E31313537363A3C393D3F3C40433F444844494C4A4E51
4D525552565956595D595D605E616363656867696B6C6E707072747678797B7D7F7E8082818384\
80848683898A8B90919196989A9EA0A7A9AAB3B3B3BDBCBCC7C5C4D2D0CFD3D2D2
CDCDCCC7C7C7C2C2C2BCBCBDB7B7B7B1B2B2ABACADA6A7A7A0A1A29A9C9C9496978E9092898B8C\
8385877D8081787A7C
6D7071676B6C6265675D6062575B5D5255574C5052474B4D4145473C4042363B3D3136382C3133\
272C2F21272A21272A282E32303538373C3E3A3F423D42453F4549444A4E4A4F53
4E535652575A565A5E595E615E6265636669686B6D6E70717173747779797D7E7F818182838485\
828587868A8B8D91929497989EA0A0AAAAAAB4B3B3BFBDBDC6C4C5CACAC9C5C5C5
C1C1C1BCBDBDB8B8B8B3B3B4AEAFAFA9AAABA4A5A69FA0A19A9C9C9597989092938B8D8E868889\
8183857C7F80777A7B
6D7072696C6E6468696063655B5E60565A5C5255574D5153484C4E44484A3F43463A3F41363B3D\
3237392D3336292E3129303330363A383D413E434640464942484B474C504D5255
50555854595C565C5F5A5F625F636664676A696C6E6F71727274757879797A7C7D828282828384\
838687898C8C8F9192979999A0A1A1A9A9A9B5B3B3BDBCBCBEBEBFBCBDBDB9B9BA
B5B6B6B1B2B2ADAEAFA9AAABA5A6A7A1A2A39D9E9F989A9B9496979092938C8E8F878A8B838587\
7F81837A7D7F76797B
6E71736A6E6F666A6C6366685F62645B5E60575B5D5357594F53554B4F52484C4E44484B404547\
3D4144393E41363B3E32383B343A3E393F42404549444A4D484E514C5154505558
54595C565B5E595E625D616561656764676A696C6E6F71717374767778787A7B7B818181828283\
8586878A8C8C8F9292989999A0A0A0A5A6A7B3B2B2B4B4B5B1B2B2AFB0B0ADADAE
AAABABA7A8A8A3A4A5A0A1A29D9E9F999B9C9697989294958E90928B8D8E878A8B848687808384\
7D7F81797C7D75787A
6F72746C6F71696C6E66696B6366686063655C6062595D5F565A5C5357595054564D51544A4F51\
484C4E454A4C42474A4046493F45483F454841474B494E524D535753575A555A5D
585D5F595E615D616560646763666864676A696C6F6D70717274757677777A7B7B7E7F7F828282\
858686898B8B8F91929596969C9D9EA2A3A4A8A9AAA6A7A8A4A5A6A3A4A4A0A2A2
9EA0A09C9D9E999B9C9798999496979193948E90918C8E8F898B8C8688898385878083847D8081\
7A7D7F787A7C757879
7073746D71726B6E70696C6E666A6C6467696265675F63655D61635B5E60595C5E565A5C54585A\
5256595055574F53564D52554C51544C51544B505450555853595C575B5E5C6062
5E62655E626560646762666864686A676A6C6A6E6F6D7071717474747677797A7B7C7D7D808080\
84858587888A8F9091919293959797999B9B999B9B989A9B97999A969899959697
9395969193948F91928D8F908B8D8F898B8D87898B8587898385878183857F81837D7F817A7D7F\
787B7D76797B747779
7074756F72746D71726C6F716A6D6F696C6E676A6C66696B6467696366686165666063655E6264\
5D61635C60625B5F615A5E60595D60595D60595E615B5F625C61645D6164636668
65686B64676965686A64686B666A6C6A6D6F6C6F706E7172717475737676767879797B7B7C7E7F\
838485838486888A8B898B8C898C8D8B8D8E8B8E8F8B8D8E8B8D8E8A8C8D898B8C
888A8B87898A8588898487888385878184858083847F81837D80817C7F807A7D7F797C7D787A7C\
76797B757879737678
7174767074757073746F72746E71736D70726D70716C6F716B6E706A6D6F696D6F696C6E686B6D\
676B6D676A6C666A6C66696B66696B66696B666A6C666A6C676B6D686C6E6A6D6F
6B6E706A6E706B6F706A6E706A6E706D70726F7172707374717476737577747678767879787B7C\
7D7F817C7E807D7F807D80817E80827E81827E81827E81827E81827E80827D8081
7D7F817C7F807C7E807B7E7F7A7D7F7A7C7E797C7D787B7D787A7C777A7B76797B75787A757879\
747779737678737677
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.25526 0.732558 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(90) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
89818089817F88807F88807F88807E887F7E887F7E877F7D877E7D877E7D877E7C877D7C867D7C\
867D7B867C7B867C7A867C7A867B7A857B79857B79857A78857A78857977857875
867A78857A79857B79857B79857B7A857B79857A79847A79847A79847A79837A79847A7A847B7A\
847C7B847D7C857E7D867F7E867F7F8780808781818783838884858986868A8889
8C8B8C8A87888A8585898484898383898383898383898382898282898281898281898281898281\
898281898181898180
89817F88807F887F7E877F7D877E7D867D7C867D7B867C7B857B7A857B79847A78847A78847977\
83787683787583777482767482767382757282747182747081736F81726E82706C
82726F8273718274728174728175738174738074727F73727F73717F73727E73727E74747F7575\
807777807879827A7B827C7C837E7E847F808581828684858887898A8A8C8C8E91
8D90938B8B8D8A888A898788898586898585888484888484888383888383888282898282898281\
898281898281898181
88807F887F7E877E7D867E7C867D7B857C7A857B79847978837977837775827775827674817572\
8074718073707F726F7F716E7E706D7E6F6B7E6E6A7E6D697E6C677E6A667E6963
7E6B677E6D6A7E6E6B7E6E6C7D6E6D7D6E6C7C6E6C7B6D6D7B6D6D7B6D6D7B6E6E7B70707C7272\
7D74747E75767E77787F797A807C7D817E8083828385858787898C8A8D918D9398
8D92968B8E918A8B8D89888A888788888687888586888485888484888384888383888382888282\
898282898281898281
88807F877F7D867D7C867D7B857B7A847A788379778277758176748175728074717F726F7E716E\
7E6F6C7D6E6B7C6D697B6B687B6A667A69647A67637A66617A65607A645E7A625C
7B65607A67637A68657A68667A6967796967796968796A697A6A69796A6A796B6B796C6D7A6E6F\
7A70717B71737B74767D78797E7B7D807E80828284848689868A8E898F948C959A
8B92968A8F92898C8F888A8C88888A888789878687878686888585888485888484888383888382\
888282898281898281
88807F877E7D867D7B857B7A847A788378768276748175727F73717E726F7D706D7C6E6B7C6C69\
7B6B677A696579676378666177645F76625D76615B765F5A765E58765D56765C55
775F5A77615C77625F766360766461766462756564756564756565756666756767766969776B6C\
776D6E7870717872747A75777C7A7C7D7D8080818483868A858B908891968B969C
8A9297898F93888D90878B8E87898C87888A878788878687878586878585878484888384888383\
888382888282898281
887F7E867D7C857C7A847A788378768176748074727F72707E706D7C6E6B7B6C697A6A67796864\
78666277646075625E74605B735E59725C56725A5471585271575072564F73564F
735953745B57735D59735E5B735F5D725F5E72605E71605F716060716161726363726465726667\
73696A736C6D746F7176747578787A7B7C7F7D818480868A838C9188939989959C
889297878F94878D91868B8F868A8D86888B868789868688878687878586878485878484888383\
888383888282898281
887F7E867D7B847B798378778176748074727F726F7D706D7C6D6A7A6B68796965776662766460\
75625D735F5A725D58715B557058526E564F6D534C6C514A6C4F476D4E46705149
71554F7157527058547059576F5A586E5A596E5A596E5B5A6D5B5B6D5B5B6D5D5D6D5F5F6E6162\
6E65666F686A706C6E727072757577777A7D7A7F827E858A828C9186939A86939A
869197868E94858D91858B8F858A8D85898C85888A868789868688868587878586878484878384\
888383888282898281
877F7D867C7B847A788277758075727F72707D706D7B6D6A7A6A6778686476656175635E73605B\
725D58705B556F58526D554F6C524C6A4F48694C4567494164443C6B4A416F5048
6E514C6E534E6D54506C54526B55536B55536A55546A555569555569555668575768595A685C5D\
6960616B64666C686A6E6D6F71737574787B787E827C84897F8B90849299849198
848F95848E93848C91848B8F848A8E84898C85888B85878A858789868688868586878485878485\
888484888382898281
877E7D857B7A8378778176747F73717D706E7B6D6A796A6778686476656174625D725F5A705C57\
6F59536D56506B534C6A5049684C4566494264463E624139613F37704D446E4E46
6C4F496B4F4A6A4F4C69504D68504E67504F66504F655050654F4F644F50635151635354645759\
655C5D6660626865676B6A6D6E7073717679757C807982877C888E818F96818E95
818D94828D92828C91828B90838A8E83898D84888C84878A858789858688868587868586878485\
878484888383898281
877E7D857B798278768075727E726F7C6E6B7A6B6878686476656174625D715E5A6F5B566D5852\
6B544E6A514B684E47664A4364473F62433B6140375E3B3269453B734F456D4C44
6A4B45684A46664B47654B48644B49634B4A624B4B614A4A60494A5F4A4B5F4C4D5F4F51605456\
61585A625D5F64626468686B6B6E716F7478737A7F7680857A868C7E8B927E8C93
7F8C927F8B92808B91818A90818A8E82898D83888C83888B84878A858689858687868586878485\
878484888383888282
877E7C847A798277757F73717D706E7B6D6978696676656274625E715E5A6F5B566D57526B544E\
68504A664C4564494162453D6041395E3D345B382E643F356F493F6C4940694841
6747416546416346426247446047456047465F46465E45465C43455C45475B484A5B4B4E5C5053\
5D56585E5A5D616063646669686C6F6C727670787D737E8377828979878E7C8B91
7D8B917D8B917E8A907F8A90808A8F81898E82898D83888C83878A848789858688868587868586\
878484888383888282
867D7C847A788176747E72707C6F6C796B6777676374635F725F5B6F5B566D57526A534E685049\
654C4563484061443C5E40375C3C335B382E603B306B443969443A68443B65443D
63433D61423C5F423E5E42405D43415C43425B42425A424359424358464758494A584D4F585152\
5955575A595B5E5F61616568656B6F6A71766E777C717C8175808777858C79888F
7A8A917B8A917C8A917D8A907F8A8F80898E81898D82888C83888B84878A858689858687868586\
878485888383888282
867D7C8379778075737D716E7B6D6A78696575656172605C6F5C586D58536A544E67504A654B45\
6247405F433B5D3F365B3A3158362D553127623B2F663F34654137644138614039
5F3F385C3D385A3D3A5A3F3D593F3F583F3F583F40574242564545554848564E4E565152555152\
56545657595B5B5E615F6567646A6D6871756C767B6F7B80727F8574838A76868E
798A927989917A89917C8A907D8A907F898F80898E81898D82888C83878B848789858688868586\
878485888383888282
867D7B8378778074727C6F6D796B6876676373625E705E5A6D5A556A555068514B654C46624741\
5F433B5C3E36593A3156352C5430265A3327673F33643E34623E34603E365E3D36
5B3B35583934563936563B3B553C3C523C3C564444574847564C4B564E4E564E4F534F50525152\
53575853595B575D5F5C6466626A6D6770756B767B6E7B806F7E8471828973848C
75878F7789917889917A8A917C8A907E8A907F8A8F81898E82898D83888B84878A858688868587\
878485878384888282
867C7B8278767F73707B6E6C786A6675656272605C6E5B576B575268524C654D476248425F433C\
5B3E3758393155342C5330274F2B215E372B643E32623D33603C335E3C355B3A34
5838325436325337355139385441405748475C4E4D584D4C564E4D544D4D524C4C525253535455\
525658515658545C5E5A6366616A6D65707569767B6C7A806D7D836E7F8770828A
72868E7489937589927889927B8A917D8B917F8A90808A8F82898E83898C84888B858789868687\
878586878484888282
857C7B8277757E72707A6D6A77686573635F705E5A6C595469544F664F49634A445F453E5C4038\
583A3254342C502F264F2B22502A20633C2F633D31603C325E3B335B3B34583933
553631513733523A38523E3D5B49475949475748475549485348465147464F47474F4B4D4F4D4E\
515253535657575D605A62655F686C646F7468767B6A797F6B7B826B7D856D8089
6F848D7187917388907689927A8B937D8C927F8B91808B90818A8F83898D84888B85878A868688\
878586878484888382
857C7A8176757D716F796C6975666372615D6E5C576A565267514C634C466047405D413A593C34\
55362E502F2649271D4A261C583125673F32623D325E3B325B3A32593A33563933
533732533B3756423F5949465C4D4B574B495448475247464F43434D43434C43444C47484C494A\
4E505250525554595D585F635E666B64707567767B68797F687980687B836A7F87
6C838C6E8690728993768B957B8E957D8D947F8D93808C91818B90838A8E84898C85888A868688\
878586878484888382
857C7A8076747C706E786A67746561705F5B6C595568544F654E496149435E443D5A3E37573931\
53332A4E2C2348251B532E23643C30643E325F3B325C3A32593A33563A34543833
513833513B385442405546445548465349475248475047464E46454B46454B47474A4A4A4B4E4F\
4C51524F525552585C565E625C666A64717566777B66787E66787F667A83677D86
6A818A6B838E6B848F758C957B90977D8F967F8E95808D93828C91838B8F848A8D85888B868789\
878687878485888383
847B7A8075737B6F6D77696672635F6E5D596A575366514C624C465F46405B4039583B3355362D\
523128502C23542E2261392C663F325F3C315C3A31593A33563A33543A34523934
4F3934503B3852423F5143415144434F45444E45444C44434A4242484342474545474748484B4C\
494E514C5356505B5D5662655C6B6F63737866787D65787E63787F637982657C86
67808A68828D69849079919B7C929A7E9199809097818F95828D93838C90848A8E85898C86878A\
878687878485888383
847B797F74727A6E6B75676571615E6C5B57685550634F496049435C433C583D3655383053332A\
512E24512B20542E225833285A382D5A392F583931563933533934513A344F3934
4E38344E3A374E3E3C4E413F4D42414C42414A414148414146404044404043414243444644484A\
454C4F4A52564E595D53606459686C5E6F7462757A62767E61767F617781637B85
657F8966818D66839079929D7E949E7F939B809199819096828E94838D92848B8F858A8D86888A\
878688878585888383
847A797E7472796D6A7466636F5F5C6A595565524E614C465D4540593F3955393252342C502F26\
4E2B204E291D4F2B20512E2453332A55362E5438315238325038334E38334D3733
4B37334B39364B3C394B3F3E4A403F483F3F473E3E443E3E433E3E403D3E403F4140424441464A\
444B4F4952564D595E52606557676C5B6D735E72795F737C5E747D5F7780617B85
647E8965818D6583907A939D7E959E80949D81939B829198839096838E93848C90858A8E86888B\
878788878586888383
837A797E7371786C697264626D5D5A685652634F4B5E494359423C553C3552362E4F30284C2B21\
4B261B4B261B4A271E4D2C2350322A52342D5036304F37314D37314B36324A3632
483632483834473937473C3B473F3E453E3E433D3D413D3E403C3E3D3B3D3D3D403D414440464A\
424A4F4751564B585E51606655666D596C735B70785B717A5B737D5D7680607A85
637E8966828D66839078919B7F97A081969F82959D82939A839197848F94848D91858B8F86898C\
878789878586888383
837A787D7270776A687163606B5B58655450604D485B4540563E395138314E312A4A2B2348261C\
46211745221946241B4A2D254E322B4E342D4D362F4B3530493530483430463430
453431443533433735443A39443D3D423C3C403B3B3E3A3C3C393B3A393B393A3D3A3F423C4449\
404A4F44515649585E4E5F6653656D556A72566D75576F7859727C5B757F5E7984
637E8967838F6D88937A929C8098A2839AA38397A083949C839299849096848E92858C8F868A8C\
878789888586888383
8279787C716F7569676F615E69595662514E5D4A4557423D523B354D332D492D2545261E421F16\
401B12401D1543251D482F274A322B4A342D49342E48332F46322E44312D43312E
42312F403330403534413939413B3C3F3A3B3D383A3B383A39363936363935383C373D42394247\
3D494E414F5547575E4C5F664F646C51676F526972536B75566E7959737E5D7883
627D8968838F6E899479939F849FAA89A1AA8499A283969E83939A849197848E93858C90868A8D\
87888A888687888384
8279777B706E7468666D5F5D6657545F4F4B594642533E3A4D3731482F294327213F21193C1A12\
3B19113C1F1741292147302949322C47322D46322D44312D42302C412F2C3F2E2C
3E2F2D3D302F3E33323E36373E383A3C383A3A373A39373A36353833353932373C343C41364147\
3B484E3F4F5746575F495D654B61694D636D4D65704F6873536C7856717D5B7682
607C8866838F6C879475919D7E9BA7819BA68299A282969F83949B849198848F94858D91868B8E\
87888A888687888484
8178777A6F6E7266646B5D5B6355525C4C4855433F4F3B3648322D432A243D221B381A1235160E\
3418103820183F2B2345312A46312C45312C43302C412F2B3F2D2A3D2C293B2C2A
3A2C2B3A2E2D3A30313A34353B36383A363938363936353933333830333830363B313B41354148\
39484F3E4F5742555D445962465D67485F6A49626D4B66714F6A76536F7B577581
5D7B8763818E6A8692728F9C7997A37D98A48098A28197A082949C849299849095858E92868B8F\
87898B888687888484
817877796E6D716563695C5961525059494651403C4A3733432E293D2520361C1630130C2B100A\
2B140E331F193E2B2544312B44312C43302C412F2B3E2D293B2B29392A28372929
362A2A362C2C3730303833343835373836393635393334383033372E33382D363B2F3A41324047\
36474E3A4C553D515B3F5660415964435C6745606B4864704C68754F6E7B547380
5A7986607F8C66838F6E8D997593A07C99A57F99A38197A182959D83939A859197858E93868C8F\
87898C888788888484
807776786D6C6F6462665A585E504D5546434D3C3945332F3E292536201B301712280E08220D08\
27151132201C402E2843322C43312D41302C3F2E2B3B2C29382A28352828332828
322829332A2B342E2F3631333734373635393435393234382E32372B31372A343B2C39402F3E46\
32454D354A53384E5839525D3C55613E5965415D6944616E4866734C6B7951717F
5777855C7C8A61818E6A8B9873929F7B9CA97E9AA68098A282969F83949B859298868F94878C90\
878A8C888788898484
807776766D6B6D62616458565A4D4B5143404838363F2E2B372421301B1729120E230B07200E0B\
28171434231F44322C45342E43322E41312D3E2F2C392B293428272F25252D2425
2C25272F282A322E2F35313336343736373B34373B31353A2D323829323728343A29383F2B3D46\
2E424C304751314A55344F5A37535F3957633D5C6841606D456573496A784E6F7D
537583587A885D7E8C6787967293A17B9EAB7E9CA8809AA48298A084959D859399869095878D91\
888A8D888789898484
7F7675756C6A6B615F615654574B494D403E433432392927301F1C291512220D091D0906180A08\
2217143526224836304736314535304233303E302E392D2B342A292F27282B2628
2B26292F2A2C333032353235363639383A3E35393E31373C2C333928323826333A26373F273B45\
2B414B2C45502E4854304C5832505D3554613B5A673F5F6D4263724668774A6D7C
5073825478875A7D8C6789987496A57CA0AF7F9EAA819BA68399A284969E86949A879196878E92\
888B8D888889898585
7F7675746B6A6A605E5F5453544847493C3B3E302F332422281816200F0C1C0805190907180D0B\
271C193A2B274D3A344A3A344737334335323F33313B302F372D2E362D2F312C2E
322D2F3832343B383A3D3B3D3F40433D4246373D4231393F2B343A27313924323A24353F233742\
273F4A26414D2643502847542E4D5B3253613959673C5D6C406271436776486C7C
4D7181507586567B8C6589997498A77DA3B17FA0AC829DA8849AA48598A087959B889297888F93\
898C8E89888A898585
7E7675736A69685E5D5D5351514645453A38392C2B2B1E1D1E100F11020114040215090918100F\
281E1C3D2E2A503E384D3C37493A364537354135343D33333A3232393133373133
3D3738423C3C4440414543444244473D4347373F4431393F2B343A26323924333C243740243A46\
27424E22404E1F404F2847562D4E5D2F51603758673B5D6C406271426777466B7C
496F804B7384527A8C648A9A7599A87EA3B180A1AD839EA9859CA58799A188969D899398899094\
898C8F89898A898585
7E7675726A69675E5D5B52514F45444237363429282519191106060B0000120706120B0B171112\
2A211F41322D55423C50403B4C3D3A4638374237363F36373C35363A35363A3538
3C383A403D3E4341444445474145493C4348373F45303A402A343C26333B23343D243842263C48\
28424E284350274553314E5B3352603656643E5D6B416170436676426879436B7C
456E80457083517A8C658A9A7799A87FA3B282A2AF85A0AB879EA7899BA38A989E8A959A8A9195\
8A8D908A898B8A8586
7D7675726A69665D5C5950504D43433F36353127272117170F0505110808150D0C1A1414201A1A\
34282547373258453F53433E4F413D4A3E3C463D3C41393A3D37383A3538383639
39383B3D3D403F40434043463F454A3B4349363F463039402A353D25343D23343E233743243C48\
27414E2945522E4A583853603B57643E5B6943616F436473416676406779406A7C
406C7F416E82527C8E688C9C799BA981A6B584A4B187A3AD89A0A98B9DA58C9AA08C969B8C9296\
8B8E918B8A8B8A8686
7D7574716968655D5C58504F4B43423E35352F27272017170F0707120B0B1711111F19182A2220\
3B2F2B4B3C375A48425646425144424D4341494140464041433F41403E41424043
43424445454845474A44484C42494D3B444A353E452F394129363E25353F233440213642213A47\
25404E2744522C495732505E3756643B5B6A3E606F3D61723D63763C65783C677B
3B697D3F6D82537E906D90A07A9BAA83A8B687A7B38BA5B08DA3AC8EA0A78E9CA28E989D8E9498\
8D8F928C8B8C8A8686
7D7574716968645C5C58504F4B43423D35352F272720181911090A140E0F1C1616251E1D302625\
3F33304F3F3B5B49435849455448454F46454B444548444546444646464847474A
46484B46494D454A4E43494D3E464B384148323C432D384028373F263640243743233A46233D4B\
23404F2342512947572E4D5D315262345767375B6C385E7039617439647739657A
36667C406F845780936D90A07699A87FA4B38BAAB68FAAB491A7AF92A3AA929FA5919A9F909699\
8E91938D8C8D8B8687
7D7574716968645C5C5850504B43433D36362F2829211A1B120C0D1711131F191A292121352B29\
44363351413D5C4A455A4C48564A485148484D47474A4647474548454649444649
43454941454A3F44493D4348394046343D442F39412B373F28363F253641253844243A48253E4C\
2844522947552B4A592A4C5C2C4F602E546632586A345C6F376175386378356479
33667C437287578295698E9F769AAA84A8B696B4BF96AFB997ABB396A7AE95A2A8949DA192979B\
9092948E8C8E8B8787
7D7574716968645D5C5850504B44443E373730292A221C1D150F101B1516211B1C2C2424382D2C\
45383651423E5A4A455A4D49574C4A524A494E48494A4749474648444548424447
3F43473D42463A4044373E43343C423039402C373F28343E26353F243641233744233A47233D4B\
2541502846552C4C5B305160325465335769365B6D365F72376176336277326479
34677E46768A5984976B92A27DA1AF8DAFBB9EBAC49EB5BE9DB0B89CABB19AA5AA979FA495999D\
9293958F8D8E8C8787
7D7575716969655D5D5851514B45453E3838312B2C241E1F1610121C1617231D1E2E2626392F2E\
4539364F423E5749455A4D4A584D4C534B4B4E494B4A484A4646494244473F4246
3C4044393E43363B41333A402F373E2C353D28333C25323C23333E223440213643213846213B4A\
233F4E25445429495A2D4F5F30536533586A345B6E335D72325F743061762F6379
366A804A798E5F899B7197A785A5B396B3BEA5BDC7A6BBC3A4B6BDA1AFB59EA9AE9BA2A6979C9E\
949597908E8F8D8888
7D7675716A69655E5E5952524C46463F393A322D2E2520211813141E1A1B2520212F282838302F\
4339374C413E554845594D4A594F4D544C4D4E4A4C49484A4545494042463C4044
393D42353A3F32383D2E363C2B333B27323A24303921303B20313D1F323F1E34421E37451E3A49\
1F3E4D224253254758284C5D2A50622C54672C576B2C5A6F2C5D722B5F752D637A
3A6E844F7E92638D9F779CAB8BAAB79FB9C3AEC3CCB1C4CBACBCC2A7B4B9A3ACB19EA5A89A9EA0\
969698918F908D8888
7D7675726A6A665F5F5A53534D4747413B3C342E302722231A1517211C1E282324302A2A393131\
433A394C4240554947594D4B5A504F544D4E4E4A4C48474A4344483E41453A3E43
353B4032373D2E353B2A323A263038232E37202D371E2D391D2F3B1C313E1B33411B35441B3848\
1C3C4D1F415221455723495C254D6126516527546929586E295B712A5E7531667D
43748A5784976B93A480A3B196B2BEABC1CAB9CCD4BCCDD3B4C2C7ADB8BDA7B0B4A2A7AA9D9FA2\
9898999390918E8989
7E7675726B6B6660605B54544F4849423D3E3630322924261C181A221F212A2527312B2C393232\
4139394C4240544847594D4B5A4F4E544E4F4D4A4C46464A4143473B3F44363B41
32383E2E343B293139262F37222C351F2B351C2A361A2B37192D3A192F3D183140183444193748\
193B4C1B3F511D43561F475A204B5F224E6324536825566D255A712A6077376B82
4A7A8F5F8A9D769BAB8CABB8A2BBC6B7CAD2C9D8DEC6D4D9BBC7CCB3BCC0ACB3B6A5AAAC9FA1A3\
99999A9491918E8989
7E7676736C6B6761615C5656504A4B443F403833342B26281E1A1D2521232C2729322D2E383233\
413B3B4B4242514847564D4B564E4E524E4F4B4A4D4445493E4146383D4333393F
2E353C293138252E35212B341D29321B2832182733172936162B39152D3D153040153344163748\
173A4C183D501A42551B465A1D4A5F1F4E6320526822566D265C732F647B3F7288
5382956A93A481A3B198B4BFAEC4CDC2D2D9D2DFE4C9D5D9C0CACEB7BFC2AFB5B8A8ACAEA1A3A4\
9B9A9B9592928F8989
7E7776736C6C6862625D5758524C4D4641423A36372E2A2C211E202824262E2A2B332F31393436\
413B3C4841414E4746524B4B514B4C4E4B4D48494C4244483B3F44353A412F363D
2A3139252E35202A331C2731182530162531142532122735122938122C3C122F40133244133648\
15394C163D5018415519455A1B495F1B4D631D516821566E285E7634698047798E
5D899C759AAB8BABB8A2BBC6BACCD5CFDCE1D9E4E8CDD7DBC3CCCFBAC1C4B2B7B9AAADAFA3A4A5\
9C9B9C9692928F8A89
7F7777746D6D6A63635F595A544F504944453E393B322E302522242B27292F2D2F353133393537\
3F3A3C4641414A45464D484A4C484A4B494C46474B3F4247373D4231383E2B333A
252E37202B331B273117253014232F1122300F22310E25340F28380F2B3C102E40103143113548\
13394C143D5115415617455A18495F194D641D51692258712D637B3E7187538296
6B93A481A3B398B4C0B0C5CFC9D7DEDFE9EDDEE8EBD1D9DCC6CDD0BDC2C5B4B8BAACAEAFA5A4A6\
9D9B9C969393908A89
7F7877756E6E6B6565615B5C5751524C4749413D3F3632342A27292D2B2D322F323633363A3739\
3E3B3D43404247444648464848464947474A4245493B3F45333A412D353D263039
202C361A283316253012222F0E202E0C202E0B21300B24340B27380C2B3C0D2E400E31440F3549\
11394D123D5213415615455B174A611A4F661F546C285E76376B81497A8F608B9E
789CAC8EADBAA5BDC8BECFD7D4E0E5E4EDF1DCE4E7D2D9DCC8CED0BFC3C5B6B8BAAEAEB0A6A5A6\
9E9C9C979393908A89
807878766F6F6D6667635D5E5954554F4B4C4541433B37392F2C2F302E313432353835383A393B\
3E3C3F4240434644474746494646494345493E4348373D442F373F28323B212D37
1A29341525321122300D202E091E2D061E2E0620310723350927390A2B3D0B2E410C32450E354A\
0F3A4E113E5313425815465D184B631D526924597131667D43758A5885986F95A7
86A6B59BB6C2B3C8D1CDDAE0E0E8ECEAF2F4DFE5E7D4D9DBCACED0C0C3C4B7B8BAAEAEAFA6A5A6\
9F9C9C979393908A89
8079787771706E68686560605C5758534E504A4647403D3F37343734323536353839383B3D3C3E\
3F3E4143424546454946464A45464A41444A3C4248333C442C363F24313B1B2B37
1527341023310B202F081E2E041C2D011C2D021F3105233507283A092C3F0A2F420B33470D374B\
0F3B5111405614455B174A611C4F6724576F2E62793F70865380936890A17FA0B0
95B1BEACC2CCC4D4DADBE4E8EDF4F6EEF4F6E0E5E7D5D9DACACDCFC0C2C4B7B8B9AFAEAFA7A5A5\
9F9C9C989392908A89
817A79797271706A6A6862635F5A5B5752544E4A4C4642453E3B3E36353838373A3B3A3E3E3E41\
40404343434747474A47484C46484D41464B3D434A353D462D384122313D172A38
1026340C2231082030041E2F001C2F001E30022234042639062A3D082E410A32460B364A0D394E\
103D5414435A1749601C4F6624566D2E61773C6E834F7C90638B9D799CAB8FADBA
A6BDC8BDCFD6D4DFE4E7EEF0F5F9FBEBF0F1E0E3E5D4D7D8CACCCDC0C1C2B7B7B8AFADAEA7A4A4\
9F9B9B989292908A89
817A797A7373726C6C6A6465635D5E5B5657534F514B484A4441443B393D3B3A3E3F3E41414144\
43434745454949494D494B4F474A4F42474D3E444B3840482F3B442434401A2E3C
1429380F26360B243507233503223504243706273A082B3E092E430B33470D364B0E394F113E54\
1543591A4A601F4F6626576D3060763D6D824D7A8D61899A7698A88CA9B6A2BAC4
B9CBD2D0DBE0E3EAEDF4F7F9F9FBFCEAEDEEDEE1E2D3D5D6C9CACBC0C0C0B7B6B6AEACADA7A3A3\
9F9B9A979292908A89
827B7A7B7474746D6E6D67676660615F5A5B585355514D4F4A47494341443F3D40424144444447\
47474A49494D4D4D514B4D51484B5043484E3E454C38414A313C47283843203341
1A303F172F3E122C3D0E2C3D0C2B3D0C2C3F0D2F410E324510364A123A4E143D521641561A465B\
1E4B612552682B596E356277406D804F798B6086977496A589A5B29EB6C0B5C7CF
CDD8DEE1E7EAF1F4F6FEFFFFF6F8F8E8EAEADCDDDED1D2D3C8C7C8BEBEBEB6B4B4AEABABA6A2A2\
9E9A99979291908989
837B7B7C7575766F6F6F696A696364625E5F5C5859565254504D4F4A484A44434645444748484B\
4B4B4E4C4D504E4F534C4E53494D53444A5041484F3C454E34414C2D3E49283B48
2338462138461C35451A354618354618364719384A1A3C4E1E405221455723495C254C60295165\
2F576B365F723E6779487082547A8B6487977594A389A3B09CB3BDB2C3CBC9D4D9
DFE5E8EFF2F3FEFFFFFDFEFEF0F0F0E4E4E5D9D9D9CFCECFC5C4C5BDBBBBB4B2B2ACA9A9A5A1A1\
9E9998979190908988
837C7B7D7676777171726C6C6C6667666162615C5D5B5759565355514E504B494C48474A4C4C4F\
4F4F524F50545051554F52564E5157484E54454C5340495138454F34444F30424E
2C404D2A3F4D263E4D263F4E253F4F2541512644542948582D4C5D30506133546536596A3C5E70\
4265764A6C7D5174845B7D8C6988967995A28AA2AD9CB0BAB1C0C7C6D0D5DCE1E4
EDEFF1FDFEFEFFFFFFF4F4F4E9E9E9DFDEDED5D4D4CBCACAC3C1C1BAB8B8B2AFAFABA7A7A49F9F\
9D989796908F908988
847C7C7E7877797373746E6E6F696A6A6566656061605C5D5C585A5754565351534E4D4F515153\
53535654545855565A54565B51555A4D5258495057454F573F4C563E4C563A4955
374855354854334855324856324A58344D5B37505E3A53623E5867415C6B4661704A6675506C7B\
5873815E7A8765818E6F8A977D95A18DA1AC9DAFB7B1BEC4C4CDD1D6DBDEE9EAEB
FBFAFAFFFFFEF5F5F4ECEBEBE2E1E1D9D8D8D0CECEC7C5C5BFBDBDB7B4B4B0ADACA9A5A5A29D9D\
9C9696958F8E8F8887
847D7C8079787B7474767070726C6C6D6869696465656162615D5F5E5A5C5A585A58575958575A\
59585B59595D5A5B5E595B5F585B5F55595F51575E4E565E4A545D48545D45525D
43525D41525D41535F415460435662455965485C684B5F6C5064705469755B6F7B5E7380657A86\
6B808B718691798D978497A093A3ABA2AFB6B3BCC2C4CACDD5D7D9E6E6E6F6F4F3
FEFDFCF6F5F4EDECEBE4E3E2DBDAD9D3D1D1CBC8C8C3C0C0BBB8B8B4B1B0ADA9A9A7A2A2A19B9B\
9B9594958E8D8F8887
857D7D817A797D7676797272756F6F716B6C6D68696A6566666264646061615E60605D5F5F5D60\
5F5E60605F626060636161646061655D60655A5F65595F65555D65545D66535D66
515D66515E67525F6952606A53616C55646E5867725C6B7560707A66757F6C7B8471818B798890\
7D8B948391998C9AA199A4AAA6AFB4B4BABFC4C7CAD3D4D5E2E0E0F0EDECFAF8F7
F7F6F6EDEBEBE4E2E2DCDAD9D4D2D1CCCAC9C5C2C2BEBBBAB7B4B3B1ADACABA6A6A5A09F9F9999\
999392948D8C8E8786
857E7D827B7A7E77777B7474777171746E6F716C6C6E696A6B6768696566676465666365666365\
66646666646767656867666A66676B66686C64676C64676C61666D60676E61686F
606870606971606A72616B74636D7566707869737B6D777F717B827680877C868D828B92878F95\
8C9499939BA09EA5A9A8ADB1B3B7BAC1C3C5D0CFD0DDDBDBEAE6E6F6F3F2F5F3F2
EBE9E9E3E1E0DBD9D8D4D1D0CDCAC9C6C2C2BFBCBBB9B5B5B3AFAEADA8A8A7A2A2A29D9C9D9796\
989191938C8B8E8786
867E7E837C7B8079787D76767A7474777171746F6F726D6D706B6C6E6A6B6D696A6C686A6B686A\
6B696A6B696B6C6A6C6D6C6F6E6E716F6F736E6F736E70746C70756D7176707379
70747A70757B70757C70767D72787F757B81787D847C828780858A858A8E898E928E9195929699\
94999C9B9FA3A5A9ABAFB1B4BDBDBECCC9CAD9D5D4E6E0DFEEEAE9F0EDECE7E5E4
E0DDDCD9D6D5D2CFCECBC8C7C5C1C1BFBBBAB9B5B4B3AFAEAEA9A9A9A4A3A49F9E9F9A999B9594\
96908F928B8A8D8685
867F7E847D7C817A7A7F78787C76767A7474787272767071746F6F736E6E726D6E716D6E716D6E\
716D6F716E7072707274727574737677757977777A77787C77787D797A7F7B7C81
7C7D817D7F837E80857E808681828784858A87888C8A8B8E8D8D919292949494979B9A9B9D9C9E\
A1A0A2AAA8A9B2B0B1BDBABAC9C5C4D3CECDE0D9D8E9E4E3E8E5E4E2DFDEDBD8D7
D4D1D0CECAC9C8C4C3C2BEBDBDB9B8B8B3B2B3AEADAEA9A8A9A4A3A59F9FA09B9A9C9696989291\
948E8D918A898D8584
877F7F857D7D837C7B817A797F78787D76767B7575797474787273777272767172767172757172\
7672737673747874767A77797F7C7E7F7D7F7F7D807F7E81808084848386888689
89888B88878B89888C8C8A8E908D90908D90918E919491929794959A96969C9899A29E9DA4A0A0\
A9A5A5B0ACACB9B4B4C3BDBCCDC6C5D3CDCCDFDAD8DFDBDAD8D5D4D3CFCECDC9C8
C8C4C3C3BEBEBEB9B9B9B4B4B4B0AFB0ABAAACA7A6A8A3A2A49E9EA09B9A9D9796999392968F8E\
938C8B8F88878C8584
87807F867E7E847D7C827B7B817A7A7F79787E78777D77767C76767B75757A75757A75757A7575\
7A75767B76777C78797E7A7C817D7F8481838683858885888A878A8D898C8E8B8D
8F8C8E908D8F938F91948F91948F90938F909792929893939A95949C9796A09B9AA49E9EA9A2A1\
AEA8A6B4AFAEBCB7B6C3BDBCCAC5C4D1CDCCD5D0CFCEC9C8C9C4C3C4C0BFC0BBBA
BCB7B6B7B2B2B3AEAEB0AAAAACA7A6A9A3A2A59F9FA29C9B9F99989C969599939296908F938D8C\
918A898E87868C8483
88807F877F7E857E7D847D7C837C7B827B7B817A7A8079797F79797F78787E78787E78787E7878\
7E79797F7A7A807B7B827D7D847F808682838A8586918C8D948E90938D8F948F8F
9691929791929790919690909690919791929A93939B95949F9896A19A98A39C9BA69F9DA9A3A1\
AEA8A7B2ADACBBB6B5C1BCBBC4C0BFC4C0BEC0BBBABDB8B6B9B4B3B6B0AFB2ADAC
AFAAA9ACA6A5A9A3A2A6A09FA39D9DA19B9A9E98979C9595999392979190958E8D938C8B918A89\
8F88878D86858B8382
88818087807F877F7E867E7E857E7D847D7C847D7C837C7C837C7B827B7B827B7B827B7B827B7B\
827C7C837C7C837D7D847E7F8680808882828A85858D8888908A8A938D8C989190
9892919790909891919791919690909790919791909992919B94939D96959F9897A19A98A49E9C\
ADA6A5B0AAA9B4AEACB2ADABB0ABAAB0AAA9AEA8A7ABA5A4A9A3A2A7A1A0A59E9D
A29C9BA09A999E98979D96959B9493999291979090968F8E948D8C938C8B918A899088888E8786\
8D86858C84838A8382
89818088818088807F87807F87807F877F7E867F7E867F7E867F7E867E7E867E7E857E7E857E7E\
867F7E867F7E867F7F8780808881808982818A83838B84848D86858E8786908988
908988908988918A89918A89928C8A968E8D978F8D98918F9992909A93919B94929D95949F9897\
A19A999E97969E97969D97969D96959C95949B94939A939299929198919097908F
968F8E958E8D948D8C938C8B928B8A918A899089888F88878F87868E86858D86858C85848C8483\
8B83828A83828A8281
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.25526 0.97619 0.476744 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(135) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
BFA390BFA28FBFA28FBFA28EBFA18EBEA18EBEA18DBEA08DBEA08CBDA08CBD9F8CBD9F8BBD9F8B\
BC9E8ABC9E8ABC9E89BC9D89BC9D89BB9D88BB9C88BB9C88BB9C87BB9C87BB9C87
BB9C88BB9C87BB9C87BB9C87BB9C87BB9C87BB9B87BB9B87BA9B87BA9B87BB9B87BB9B87BB9B88\
BB9C89BB9C89BB9D89BB9D8ABC9D8ABC9E8ABC9E8BBC9F8CBC9F8DBDA08EBDA18F
BDA18FBDA18EBDA08DBDA08DBDA08DBDA08DBEA18DBEA18DBEA18DBEA18EBEA18EBFA28EBFA28F\
BFA28FBFA38FBFA390
BFA28FBFA18EBEA18DBEA08DBD9F8CBD9F8BBC9E8ABC9E8ABB9D89BB9C88BB9C87BA9B86BA9A85\
B99A85B99984B89883B89782B79781B79680B79580B7957FB6957FB6947FB7957F
B7957FB6947FB6947EB6947FB6947FB6947FB6937EB5937DB5927DB5927DB5927EB5927FB69480\
B69581B79582B79683B79783B79784B89884B89985B99A87B99B89BA9D8BBB9F8E
BBA08EBB9E8BBB9D8ABB9D89BB9D89BB9E8ABB9E8ABC9E8ABC9E8BBC9F8BBD9F8CBDA08CBEA18D\
BEA18EBFA28FBFA38F
BFA28FBEA18EBEA08CBD9F8BBC9E8ABB9E89BB9C88BA9B86B99A85B99984B89882B79781B79680\
B6957FB5947EB5937DB4927BB3917AB38F78B28F77B28E76B28D76B18D75B18C75
B18C75B28D76B28D76B28D77B28D77B28D77B28D77B18D78B18C78B28C78B28C78B38D79B38F7B\
B4907CB4917DB4907DB3907DB3917DB3927EB49480B59582B69784B79987B99C8B
B99D8BB89A88B89A86B89986B89A86B99A86B99A86BA9B87BA9C88BB9D89BB9D8ABC9E8BBD9F8C\
BEA08DBEA18EBFA28F
BFA28FBEA18DBD9F8CBC9E8ABB9D88BA9B87B99A85B89984B79882B69681B5957FB4937DB4927B\
B39079B28F78B18D76B08C74AF8A72AE8970AE876FAD866DAC856CAC856CAD856C
AD856DAD856EAD866EAD866EAD866FAE8770AE8872B08974B08A75B08A76B08A76B18A76B18A76\
B18A76B18A77B18B77B08B77B08C78B08D79B18F7BB2917DB3927FB49481B59683
B59683B59682B59581B59581B59681B69782B79883B79984B89985B99A86BA9C87BB9D89BC9E8A\
BD9F8CBEA18DBFA28F
BFA28EBDA08CBC9F8BBB9D89BA9B87B99984B79882B69681B5947FB4937CB3917AB28F78B18D76\
AF8B74AE8A71AD886FAC866DAB846BAA8268A98066A87E64A77D63A77D62A77D63
A87E64A87E64A87F65A97F67A98068A9806AAA816BAA836DAB846FAB8570AC8670AD8671AD8671\
AD8671AD8771AE8772AD8672AD8773AD8974AE8975AE8B76AF8D79B0907CB1917D
B1917DB1907CB1917CB2917CB3927DB3937EB4947FB59580B69782B79883B89985BA9B87BB9D89\
BC9E8ABDA08CBEA28E
BEA18EBD9F8CBB9D89BA9C87B99985B79782B69580B4937DB3917BB28F78B08D76AF8B73AE8971\
AC876EAB846BA98269A88066A77D63A57B60A4795DA2765AA17458A17357A27458
A3765BA3775DA4785EA4795FA47961A47A62A57A63A57A64A67C65A77D68A77F69A77F69A87F69\
A87F69A88069A8806AA9816BA9816AA9826CA9846EA9856FAB8772AC8B77AD8C78
AD8B76AD8B76AE8C76AF8C77B08E78B18F79B2917BB3927DB4947EB69681B79783B89985BA9B87\
BB9D89BD9F8BBEA18E
BEA18DBC9F8BBB9C88B99A85B79882B69580B4937DB2917AB18E77AF8C74AE8971AC876EAA846B\
A98268A77F65A67D62A47A5FA2775BA174589F71549D6E509B6A4C9A68499C6A4C
9E6F529F70559F71579F7258A07359A0735AA0735BA0735CA0745CA1745DA1755EA2765FA2765F\
A27760A27861A37962A37A62A47A63A47B63A47C65A57F68A7816AA8836EA8856F
A9856EA9856EAA866FAB8771AC8973AE8B75AF8D77B18F7AB2917CB4937EB59581B79783B99985\
BA9C88BC9F8BBEA18D
BEA18DBC9E8ABA9B87B89883B69680B4937DB2917AB18E77AF8B74AD8970AB866DA9836AA78066\
A67D63A47A5FA2775CA074589E71549C6E509A6A4B976546935F3E94603F996748
9A694C9B6B4F9B6B519B6C519B6C529B6C529B6B529B6B529B6A529B6A529B6A529B6B539B6C55\
9B6D569C6F579C71589D72599E735B9F755CA0765DA17860A27A62A37C64A47D65
A47D65A57F67A68069A8826BA9846DAB8770AC8973AE8C76B08E79B2917BB4947EB69682B89985\
BA9C88BC9E8ABEA18D
BEA08DBB9D89B99A85B79782B5947EB3917BB18E77AF8B74AD8870AB856DA88269A67F65A47C61\
A2795DA075599E72559C6E519A6B4D986748966343935E3D915B3B945F3F976445
97654797654897664996654A96654A96654A96654B96634A956249956048945F47945F47946149\
95644C95674E966950976A52996C53996E549B6F559C70569C71579D72589F745A
A0765CA1785EA27A61A47D64A68068A8836BAA856EAC8872AE8B75B08E79B2917CB4957FB79883\
B99B86BB9D89BDA08D
BDA08CBB9D88B99985B69680B4927CB18F79AF8C75AD8971AA856DA88269A67F65A47B61A1785C\
9F74589D70539B6D4F98694A966545946140925D3C905A3696603D9A6644966242
946042936041925F42925F42915F43915E43915D43915C43905A418F59408F59408F59418F5A41\
8F5C438F5E4590614791634993654B95674D96694F976A4F986A4E98694D996A4D
9B6E529D71569E745AA0775EA27B62A57E66A7826AA9856EAC8972AE8C76B18F7AB3937DB69681\
B89985BB9D89BDA08C
BDA08CBA9C88B89883B5957FB3917BB08D77AD8A72AB866EA8826AA67F65A37B61A1775C9E7357\
9C6F53996B4E976749946344925F3F905B398C5531925B38996442966140935E3E
915C3D8F5B3B8E5A3A8D593B8D583B8C583C8C573C8C563C8B543A8B52398A51398A513A8A523B\
8A543C8A573E8B59408C5C428D5F448F6247916348936448936346936143946243
966648986A4D9A6E529C72579F765CA17A61A47E65A7826AA9866EAC8973AF8D77B2917BB5947F\
B79884BA9C88BDA08C
BD9F8BBA9B87B79883B4947EB19079AE8C74AC8870A9846BA68066A37C61A1775D9E73589B6F53\
986B4D966748936243905E3D8E5A388C5532915A37955F3C935D3A915C3A8F5A39
8D58378B553589533488523488523487523587513687513687533987553A86553A86563C86553C\
85533A85533A85553C87583E895B408B5D428D5F438F6044906043905E40905C3C
915D3D93634596684B986C519B71569E755CA17A61A47E66A7836BAA8770AD8B75B0907AB3947F\
B69783BA9B87BD9F8C
BD9F8BB99B86B69781B3927CB08E77AD8972AA856DA78168A47D63A1785E9E74599B7053986B4E\
9567489262438F5D3D8C58378A5431864E2A88502B8E57338E58358D57358B5635
895433865130844E2E834D2F824D30824D30824E3183503483563A835A3F835E42845F44825B40\
81563B80543981533982543A84573C86593D885B3F8A5D408C5D408C5C3E8C5A3B
8D5A3A8F5C3D91614494674A976C519A71579E765DA17B63A58068A8856EAC8973AF8E78B2927D\
B69782B99B87BC9F8B
BC9F8BB99A85B59580B2917BAF8C75AB8770A8836BA57E65A27A609E755A9B7155986C4F956749\
9262438F5D3D8B5837885331844D2988502B8D55318B55328A5432895433875333
855030824D2C7F4A2A7E482A7D482B7B482C7D5034815A3E835E4485644A856249825D43805F43\
7E5E447C593E7B52377D513680533883563B85583D875B3E885B3D895A3C895839
8855358956368C5B3D8F614493674B976D529B72599F785FA27D65A6826BAA8771AE8C76B1917C\
B59681B99A86BC9F8B
BC9E8AB89985B5947FB18F79AD8B74AA866EA68168A37C629F775D9C7257996D5195684B926345\
8F5E3E8B5838875331844E2B814A26844D29895330885330875230865231845130
824F2F804C2D7D4A2B7947287A4D2F815B3F84604582614682634882614682624682644A83644B\
8161487E5C4179563B7851367C51367F533982563A84583C85593C85583A855537
8554358554358656388A5B3E8F624693694E986F559C755CA07B63A48069A8866FAC8B75B0907A\
B49580B89A85BC9E8B
BC9E8AB89984B4947EB08F78AC8972A8846CA47F66A1795F9D74599A6F53966A4D9365478F6041\
8C5A3A875432834D2A7F4825804825844D2A86512E85512F845231835231815030
7F4F2F7D4F307D50327E53347F55378056387F57397E583A7E583B7D57397D573A7D573B7E573B\
805A3D825E42825D437C563D784F357A4F357D533780553981563A825538825436
8252338251318352328555388A5D4190654A956C529A72599E7960A37E67A7846DAB8973AF8F79\
B3947FB89985BC9E8A
BB9E8AB79883B3937DAF8D77AA8770A68269A27C639E775D9B7156976C5093674A9062438D5C3D\
89573685502E7D4622783F1981492488522F85512F83502F814F2F8050307F5031
7E51327F5538815D408564488463477F5C407D593C7B56387A5235795134795134794F31794F32\
7A53357C55387E563B7F573C7A5238784F347B51367D53377E53377F53367F5234
7F5133805031815132845537875B3E8D6247926A4F9770579C775EA17D65A5836CAA8872AE8E78\
B3937EB79984BB9E8A
BB9D89B69783B2917CAD8C75A9866EA47F67A07A609C745A986E5394694C9164468D5E408A593A\
875534844F2D804A27814B2786522E86543183512F804F307E4F317D50317C5032
7B51347B53367C563A7E5B3F7D5D417C5D407B5C407A5B3E795A3D78593B78583B77593B77593B\
7856387954387B55397D56397E573B7B54397951367A51367B52367C51357C5133
7C4F327C4E2F79492A7D4E2F85593C8A604490684D956E559A755C9F7B63A4816AA98771AD8D77\
B2937EB79884BB9E8A
BB9D89B69782B1907BAC8A74A7846CA37E659E785E9A7157956B509166498E60428A5B3C885636\
86533186512F8D5835935E3A8C583583512F7F4F2F7C50307B4F317A4F32795133
78523578533778533777543777563976573A76563A755639745438735437735437735437735437\
73543773563876593B7A5C407D5F447D5E437A583D785337785136795135795034
7A50327A4E317A4F327C513482573A885F448E664C936D5399735B9E7A62A38069A88670AC8C76\
B1927DB69883BB9D8A
BA9D89B59681B08F7AAB8972A6826AA17C639C755B976F5492684C8E62458A5C3E875737845231\
834F2C834D29854F2A85512F82502F7D4D2D7A4C2D784D2F774E31754F32754F33
755035755135734F33724E31724F337151357151357051356F51356F51346E4F336E4E326D4F33\
6E50346F513572533874563A76583D78593D78573D77543A765137765035774F34
784F33784F32784E317B513581573C865E438C654A926C5297725A9C7961A17F68A7856FAC8B76\
B1917CB69783BB9D8A
BA9C88B49580AF8E78A98770A480699E7961997259946B518F65498A5E4186583A8252337F4D2C\
7D48267C46237B46227A452278462577472975482A73492C724A2E714B2F704C30
704C32704D326F4D316E4B2F6D4A2E6D4B306C4B306B4B2F6B4C306A4C316A4C31694B306A4B31\
6B4D326D4E346E513771543A73563C74563C75553C745339735037745036765036
775035795035795034794F327E5437845C408A6349906A519671599B7860A07E67A6846EAB8B75\
B0917CB59783BA9D89
BA9C88B49480AE8D77A8866FA27E679C775E96705691684E8B6145865A3D8253357E4D2D7A4726\
77421F753F1B733E1C723F1D7341217242237043266E45286D45296C462A6B472B
6B492D6B4A2E6A4A2E69482C68472B68482C68492E67492F67492F67492F664930664A30674A31\
684B32694C346B4F366D51396F533D71553E71553D705239705037725037745037
7651367952377C53377B50337C5135835A3F8962488F6A519470589A77609F7D67A4846EAA8A75\
AF907CB59783BA9D89
B99B87B3947FAD8C76A6846DA07C659A755C936D538D654A885D418256397D4E3078472774401F\
703A196D37156B36146B3A196C3D1F6B3F216A4022694023684125674125664126
65432865442A65452B64452B64452963442963442963452A62452B62452B61442B61452C62462E\
634930654B32674C34684E376B513A6C523C6C513A6C50386D4F376F4F36714F37
7551387A543A825A3E865B3E80553981583E8963498E695193705898765F9E7D66A3836EA98A75\
AF907BB49682BA9D89
B99B87B2937EAB8B75A5836C9E7A6397725A916A508A624784593E7D513477492B7241216D3817\
68310F652D0C643011643618653A1B653C1E643C1E633B1F623B1E613B1F603B20
5F3C215F3D235F3F256041286042285F41275F40265E40265E3F265D3F265D40275D41295D422A\
5E442C5F462F614933644C36654E37664D37674C36684B35694B346B4B346E4D35
724E367752397D573F855E458B664C8B664D89654C8D6951926F5897765F9D7C66A2836DA88974\
AE907BB49682BA9D89
B99B87B1927DAA8A74A3816B9C79619570578D674E865E447F553A784D307244266B3B1C663313\
612D0E5E2D0E5E30116034156036185F371B5F371B5E361A5C361A5B35195A351A
59351A59361C5A381F5A3A225A3C235A3D255B3E265B3E275A3E265A3E26593E27593F27594029\
5A412B5C442F5E4833604934604933604833614832624731644832664832694934
6D4C35714F3876523A7C573E815C43845F4787634B8B6851906E5895755F9B7B66A1826DA78974\
AD8F7BB39682BA9D89
B89A86B1927DA98973A180699A775F926E558A644B835B417B523673482C6C3E206434145D2D0C\
582B0A562B0C572E0F5930135A32155A3317593317583216573015552F13542E13
532E15532F1653311954341B55361E563820563A22563B24563B25563B25563C25563D27563E28\
57402B58422D59432E59432E5A432E5A422D5B422D5C432E5E442F61452F634731
6749326B4B35704E3775523A78533B7C573F825F4888664F8E6D5794745E9A7A65A0816DA68874\
AD8F7BB39682B99C89
B89A86B0917CA88872A07E6898755E8F6B538762497F583E764E336E442865391C5C2E0F532405\
4B20024A22064E280C522C11542E13552F13542E13532E12522D11502B114E2A10
4C29104C2A124D2C154E2F184F321A51341D523720533822533A23523B24523B25523B25523C26\
533D28533D29533D2A533D2A523D29533D29543E2A563F2B59412D5B432E5E442F
6145306547316848316D4B33724E3578533B7E5C4685644E8B6B5692735E987A659F816CA58874\
AC8F7BB29582B99C89
B89A86AF907CA787729E7D6796735D8D6952845F467B553B724A30694024603519572B0E4C2105\
461E03451F0548240A4D290F4F2B11502C12502C124F2C114D2A114A281048270F
46260E46250E46250E4828114A2C154D301A4F341E5037215038224F38234F38234E38244E3924\
4E39254D39254C38254B37244B37244C37244E3825503A27523D29553F2B58402C
5B422E5E432E61452F6546306B4A3473523C7A5A4581634D886A558F725D9679659D806CA48773\
AB8E7BB29582B99C89
B79A86AF907CA686719D7C6694725C8B6850815D447751386D462C643B215B3115532A0F4D260C\
47220844210846240B4A280E4C2A104D2B124D2C134B2A1148270E44230A402007
3E1F073E200941220C43250F462812492E184C331E4E36224E38244E38244D38234C38234A3723\
4936234734224533214532204533204633214835224B37254E3A27503B28533D2A
563F2C58402D5A402D5E412D6547326E513C7659457E614D8669558D715D9578659C806CA38773\
AA8E7BB29582B99C89
B79986AE907BA586719C7C6693715B89664F7E5A43734E366842295E361C552C114D250B442008\
3F1E0741210945250D4828104A2A124C2C144C2D154C2D164A2C15472913422611
3C220D3B220C3E240E412611442712482D184B34204D38244D39264C39264B3825493724473522\
453321443321433120412F1E3F2D1C402E1D43311F4634224936244B38264D3A28
503C2A533E2C56402E5C43326349376B503E7359467B604D8368558B705D9378659B7F6CA28774\
AA8E7BB19582B89C89
B79986AE907BA586719C7B6692715B87654F7C5942704B33633D245730164E260D48230946240C\
45240E44240E462710482A14492C154A2D174B2E194C301C4E331F5035214F3420
4B321D48311C47311E4934214D38254E3A274D39264D3A284C3B294C3A284A3927483625453222\
42301F3F2F1E3B2B1A3828183829193B2C1B3E2E1D41301F4533224836254A3827
4C39294D3A2A4F3C2C5542325E4A3A67514070584678604E816855896F5D9277659A7F6CA18674\
A98E7BB19582B89C89
B79985AE907BA586719B7C6791715B87654F7B59426D4A325D38204B2309411A00411F0742230C\
432510442712452914472B16492D184A2E1A4A2F1B4C321E4E3624513927553D2B
5A43305A443157422E54412E51402E4F3D2C4E3C2A4D3B2A4C3B2A4C3B2B4C3B2B4B3B2B4A3C2C\
473A2B403326392C1F372A1C392B1D372A1B392A1C3E2E1E423121463526483828
483829483829493A2B4E3E2F584637634F3E6C5645765E4D7F6755886F5D907765997F6DA18674\
A98E7BB09582B89C89
B79A86AE917DA587739C7D6992725D8767517B5A446D4B3459351C4B270E401F08391A043A1E09\
40240F452914482C17492D19492F1C4A2F1D4A2F1D4B32214D3726503B2B533F30
5542325644345645365444345242334F40314E3E2E4D3D2D4C3C2D4C3D2E4C3E2F4C3F304D4030\
4D3F304D3E2F4B3C2E47392B44362844352744352746372947382B47382A46382A
45382A44362845372A4C3D2F5542335E4A3A695444735D4D7D6655866F5E8F7766987F6DA08775\
A88E7CB09583B89C89
B79B88AE927EA688749C7F6A937460886A557D5E4871513B63432C5738214D311B452A16422814\
452B16492D1A492E1B4A301D4A321F4C36244D38284B36254A35254B38284C3B2D
4E3F314F41335042344F41344F41344F42344E40314D3D2F4C3D2E4C3E304C3E324B3E324B3E31\
4B3F314E413354463858493A5445375242344F41334C3E31483B2F463A2E45392D
43372B42372B45392D4C3E315443355C4A3B665344715C4D7B6656856F5E8F7767987F6EA08775\
A88E7CB09583B89C8A
B79B88AF927FA68A769E806C9477638B6D5981634E7658436B4E3960432E553B274F36224C331F\
4B331F4A33204A321F49311F4B34234C38274F3C2D51413352433653443856493D
5A4E425A5045594F44574E43544A3F5045394D41344C3E314B3D314B3F334C40354A3E34483C32\
483C314A3E324D41345043375145395045394D4237493E34463B3245393043382E
41362C40362C443A304E423654463A59493B6351426F5C4D7A66578570608F786898806FA08876\
A88F7DB09684B89D8A
B89B88B09380A88B779F836F977A678E715E8568557C604C7358446A4F3C6147345A412E543C29\
5139264E37254B34224933224A35244C38284D3C2E50413453483C574E435A5247
5B554C5B564E5A564E575249524B404E44394B4034493E31493E324B40344D443850473D4F463D\
493F38453B32453B32483E344940354A4035483E35463C33443A31433A31423830
3F362E41372F473D344A40364E42375243365D4C3E6E5C4E7A67598571628F7A6A988271A18978\
A9907EB19684B89D8A
B89C89B19581A98D7AA18673997E6B917663896E5B816654795F4D7159476A5240634B395D4534\
58402F523B2A4E37264B35254A35264A37284C3A2C4D3E314F433751473D534B41
534C43534D45524C445049414D453C4A4136483D32473C30473C30493E334B41374F453C524A42\
554C445349414C433B453D35433B33433B33433B33433B33443C34443C35423A33
403A32433C34473F374740384B433A564B406355487060527C6A5C877365917C6D998473A28A7A\
AA9180B19785B89D8B
B99D89B29683AA8F7CA388759C816F947A688D7361866C5A7F665579614F725A496A5342644D3C\
5D46365640304E39294935254834254936274A382A4A3B2E4B3D314C40354D4238
4D443B4C443B4B433A494138473E35453C3244392F43382E44392E453A30473C334A40374D443B\
50483F534B42554C44544C445048404D453D4C443D4B443D47413A433E37413D36
423E3746413A4A453D4D4940514D455B5349675B4F7364577F6E60897769937F709B8676A38C7C\
AB9281B29886B99E8B
B99D8AB39784AC917FA58B799F8573987E6C9178678A7261846C5A7D6654776150715B4B695343\
614B3B5843334F3A2C49352647332547342647362947372B47392E473A2F473B30
473C32463C32453B3143393041372D40352B3F332A3F33293F342A40362C42382F443A31473E35\
4A41394D443D4F4840514A43524B44504A444D48424A443F46423C43403A423E38
44413B4A4741504C4656514A5B564E625A506B5E5376675B8373668D7C6E9683749E897AA58F7F\
AC9483B39988B99E8C
BA9E8BB49886AE9381A88E7CA188779B8271957D6C8F7767887262826D5E7D68597661536D5A4B\
6351435A4739513E3149362946332546332645342744342844342943352A42352A
41342A40342A3E33293D32283B30273A2F25392E24392E253A2F263B30273C322A3E352D413831\
433C34463F3849423C4A443E4A453F4A454048443F45433E43423C41413C41413D
4545414E4D4855534E5C5953635E576B645C73695F7E7166897A6E9282759A887AA18D7EA79282\
AE9686B49B89BA9F8D
BA9F8CB59A88AF9583AA907FA48B7A9F8776998272937D6D8E7869887365826E607C695B746154\
6B584B604F4257463A4D3C31473529443226433125413024402F233E2F243D2F25
3B2F253A2D24382C23372B22352A2134292033281F332820342921352B23362D263830293A332C\
3D3630403934423C37443F3A44403C44413D44413D43413D43413D42423E454542
4E4D495554505D5B5666635E6F6B6578726B807970897F7591847998897C9E8D80A49183AA9585\
B09988B59C8BBAA08D
BB9F8DB69B89B19786AC9382A78F7FA28B7B9D8677978273927E708C7A6C877568816F6279675B\
6F5E526554495B4A3F5341364A392D4432274030243E2E223C2C203A2A1F38291E
36281E34271D32261D30241B2F231A2E221A2E221A2D231B2D241C2F251F302821332A24352E28\
37312D3A35303C37333D3A363F3C383F3E3A403F3C41403D40413E4344424A4B48
5354505C5D59676661716F697B7871858079918B84978F87998E849E9084A39286A89587AD9889\
B29B8BB69E8CBBA08E
BBA08DB79D8BB39988AE9685AA9383A68F80A18B7D9C8779968375917E728B7A6D8574687D6D62\
75655B6B5C525E514754463C4A3C3343342A3E2F253B2C2138291E35261C332419
3022172E20162C1E152A1D14281C13271B13271B14271C16281F1829211B2B241E2D27222F2A25\
322E2934302D3633303837343A39373C3C3A3D3E3C3E403F414442474A48505251
5B5D5A66676471716D7C7A7586837E908C8599928B9E958DA1968CA4968BA8988BAC998CB09B8C\
B49D8DB89F8EBCA18F
BCA18EB89E8CB59B8AB19989AD9687A99485A59183A28F829D8B7E9886799180758A7B7084756B\
7A6C626F615863564D564B424A3E3641342B3B2D2437291F34251B3122172D1E13
2A1B1028190E25170D23150C21150C20150D20150F201610211813221B16251F1A27231F2A2623\
2D2A26302E2B32312F353432373736383A39393D3C3C4140414646494E4E555959
6165636E6F6E7A7A77858380908E8A9D9893A39E97A59D95A79D94AA9D92AC9D91AF9D90B39E90\
B69F90B9A190BCA290
BDA18FB99F8EB69E8DB39C8CB09A8BAD988AAA978AA79589A493879E8F8497897E908278887A71\
7E716873675E675C54594F484B413A40352E392D2534271E3022182C1D1328190F
25160B2113091F11081D10091B0F09190E08180E0919100C1A13101C17141F1A18221E1B25221F\
2826242B2A292E2F2E313332333636363A3A393D3E3D4244444B4C5056575D6263
6B6F6E797A7985858392908D9F9C98ACAAA6B0ACA7ADA69FAEA49BAFA298B1A296B3A194B5A193\
B8A292BAA291BDA391
BDA290BBA18FB8A08FB69F8FB39E8FB19D8FAF9C90AD9C90AA9B91A6988F9E9188968A818E8279\
847971786E676B625C5D544F4F4741423934372D2630251D2B1F17271A1122150D
1E110A1A0E07170C05150A04130904110904110A06120C09130F0C1512101916141C1A191F1F1E\
2323232628282A2D2D2D3232313637353B3D3A414341494B4B5355585F61666C6D
75797982858490918F9D9C99A8A6A2B0ADA8B3AEA8B3ACA5B3A9A0B4A79DB5A69AB6A598B8A496\
BAA494BCA393BEA391
BEA390BCA291BAA291B8A192B6A193B5A194B3A296B2A298B1A399ADA098A69A939D928B948A83\
8A817B7F7670736A65665E5958504B47403B39312D2F2520281C172216101D110B
180C071409051107030E05010B04010A04020905030B07060D0B0A100E0E1313121718181B1D1D\
1F2222232728272C2E2B323430373A363E403E474A485155555E61646C6E72787A
7F84858D90909B9D9CAAAAA7B5B3B0B9B6B2BAB5AFB9B2AAB9AEA6B9ACA2B9AA9EB9A89BBAA798\
BCA596BDA594BEA492
BEA391BDA392BBA493BAA495B9A596B8A699B8A79BB8A99FB9ADA5B7ABA5AEA49DA59C959D948E\
948B8589807A7C74706F6864615B58514C4A403B39312B29261E1B1F1613180F0C
1209070D05030A02010701000500000200000201010404040708090A0D0E0E1112121617171C1D\
1C222321272A262E312C3538333C403B4449464F54545D61626B6E71787B7F8688
8E93939C9F9FAAACABB6B7B5C2C3C2C6C5C2C1BCB7BFB7B0BDB3AABDB0A6BCADA1BCAB9EBDA99A\
BDA798BEA695BFA492
BFA492BEA493BDA595BCA697BCA89ABCA99DBCACA0BDAFA5BFB3ABBDB4ADB6ADA7ADA59FA59D97\
9A948F908A86857F7A79736F6D67655F5A584F4A493E3A39302C2B231E1D181312
0F0B0A09040406010103000100000100010300030601050803080B060D0F0B12150F181B131C20\
192226202A2E2732372F3A3F394349444F55525D62606B6F70797C7F878A8E9496
9DA2A3ACAFAFBABCBAC4C5C3CACAC7C9C8C4C6C2BCC4BCB5C2B7AEC0B3A9BFB0A4BFADA0BFAB9C\
BFA899BFA796BFA593
BFA492BFA594BEA797BEA899BEAA9CBFACA0BFAFA4C0B3A9C2B7AFC3BAB5C0B8B3B8B0ABAFA8A3\
A69F9B9B9591908B8785807D7873716B66645D59574E4A493F3C3B302E2E242222
1A18181210120C0B0E08080C06080D050A0F050C11050D13050F150812190B171D101C22162329\
1C2A302331372D3A4037444A435056515E63606C71707A7E81898C90979AA0A5A7
AFB3B4BEC1C0CACBCBD3D4D3D5D5D2CFCDC9CBC6C0C8C0B8C5BAB2C3B6ACC2B2A6C1AFA2C0AC9E\
C0AA9AC0A797C0A593
C0A593C0A695C0A898C0AA9BC0AC9FC1AFA2C2B2A7C4B6ACC6BBB3C9C1BAC8C1BCC1BAB5B8B1AD\
B0A9A5A8A29E9D9895908C89837F7D7571706763625955554C4849403D3D343334
2A2B2D2224271B1E22161A1E14191E12191E10191F0F1A210F1C24111E2614212A19272F1E2D35\
26343C2E3D4438464D445259526065606D72707B80818A8E92999CA2A8AAB2B6B7
C2C5C6CFD1D2DADCDBE0E2E1DCDDDBD4D1CDCFC9C3CBC3BBC8BDB4C6B8AEC4B4A8C3B0A3C2AD9F\
C1AB9BC0A897C0A694
C0A593C0A796C1A999C1AB9CC2AEA0C3B1A4C5B5A9C7B9AFC9BEB6CDC4BDCFC9C4CBC6C2C2BDB9\
BAB5B1B1ACA9A7A2A09A96948E8A88817E7C7471706866655B5A5B4F4F51464648
3E3F4137393C3033372A2E33262B30252A30232B31232D33232F3626323A28363E2C3A42314048\
3948504351584D5B6158666B667277758084858E92949C9FA4AAACB4B9BAC4C8C8
D3D6D5DFE1E1E9ECECE8EAE9DEDDDAD8D4CFD2CBC5CEC4BCCBBFB5C8BAAFC6B5A9C4B2A4C3AEA0\
C2AB9BC1A897C0A694
C0A593C1A796C1AA9AC2AC9DC3AFA1C5B3A6C7B6ABC9BBB1CCC0B8CFC6BFD3CCC7D3CDC9CDC7C4\
C4C0BDBBB7B4B0ACAAA6A3A09C9997908D8C8381807674736A696960606158585A
505153484A4E4346493F42463B4045393F453840463942483A444B3C474E3F4B524350574A565E\
515E655A666C636F756E797F7B858A8A929699A0A3A8AEB0B8BCBDC8CBCBD7D9D8
E3E5E4EEF2F2EFF3F2E7E7E5DFDDD9D9D4CED4CCC5D0C5BDCCC0B6CABBAFC7B6AAC5B2A5C4AFA0\
C3AC9CC2A998C1A694
C0A593C1A897C2AA9AC3AD9EC4B0A2C6B4A7C8B8ACCBBCB2CEC2B9D1C8C0D6D0CAD9D5D1D6D3D0\
CFCBC8C6C3C0BEBAB8B3B0AEA8A5A49D9A9992908F8685857C7B7B7373736B6B6C
6464665E5E60585A5D54575B51555950555950555B51575D535960555D635961685E676D656E74\
6C767B737D827C858A868E9291999C9EA5A7ADB2B4BDC0C1CBCECED8D9D9E3E5E4
F0F3F3F3F6F6ECEDEBE6E4E1DFDBD6DAD3CDD5CCC4D1C5BCCDC0B5CBBBAFC8B6A9C6B2A4C4AFA0\
C3AC9CC2A998C1A694
C1A693C1A897C3AB9AC4AD9EC5B0A2C7B4A7C9B8ACCCBDB2CFC2B9D3C9C1D8D1CADFDBD7E2E0DD\
DBD9D6D2CFCDC9C7C5C0BDBCB7B4B3AEABABA5A2A19B9898919090878687807F7F
7A79797474756F70716C6E6F6B6D6F696C6E696C6F6A6D716C70746F737774797D7A7F837F8589\
868C908D9396959A9D9FA4A6ABAEB0B7BABBC5C6C7D1D2D2DDDEDDEAEAE9F4F4F3
F6F7F6F0F1F0EAE9E6E4E1DCDFD9D3DAD1CAD5CAC2D1C4BBCEBFB4CBBAAEC9B6A9C7B2A4C5AFA0\
C3AC9BC2A997C1A694
C1A693C2A897C3AB9AC4AD9EC6B0A2C7B4A6CAB8ABCCBDB1D0C2B8D3C8C0D8D0C9DED8D3E5E2DF\
E7E6E4E0DEDCD6D4D2CECAC9C6C2C1BEBBBAB6B4B3AEACACA6A4A49E9C9C979595
918F908C8C8C89898886858683838482828381828382838584858787898B8B8E909395989B9DA0\
A0A2A4A6A7A9AEAFB0B9B9B9C2C3C2CCCCCBD7D7D6E3E2E1ECECEBF4F5F4FAFDFD
F7F9F9EFEEEBE8E5E1E3DDD7DDD5CFD9CFC7D5C9BFD1C3B8CEBEB2CBB9ADC9B5A8C7B2A3C5AF9F\
C4AB9BC2A997C1A694
C1A593C2A896C3AA9AC4AD9DC6B0A1C8B3A5CAB7AACCBCB0CFC1B6D3C6BDD8CDC5DDD5CEE2DDD9\
EAE7E5EBE9E8E4E1DFDBD7D6D2CFCDCBC9C7C7C4C2C1BEBCBAB7B5B4B1AFADABAA
A8A5A5A4A1A0A09D9D9D9A9A9B98989A98989A97989A98989B9A9A9D9C9CA2A0A0A7A5A4ADAAA9\
B5B2B0BCBAB8C4C2C0CCCAC8D3D1CFDCDAD8E5E4E1EFEEECF8F7F6FDFFFFFBFDFD
F2F2F0ECE8E5E6E0DBE0D9D2DCD2CAD7CCC2D4C6BCD0C1B5CDBCB0CBB8ABC9B4A6C7B1A2C5AE9E\
C3AB9AC2A897C1A693
C1A593C2A896C3AA99C4AC9CC6AFA0C7B2A4C9B6A8CCBAADCFBFB3D2C4B9D6CAC1DBD0C9E0D8D2\
E5E0DBECE9E6EDEBE9E7E4E2E0DCDBD9D5D3D4D0CFD0CDCCCBC8C7C7C3C2C4BFBE
C1BCBABDB8B6B8B3B2B5B0AFB2AEACB1ACABB0ABAAB0ACABB2ADACB3AEACB4AFACB7B1ADBBB6B2\
BFBAB6C5C0BCCCC8C4D5D1CEDFDBD8E9E5E2F1EEEBF9F7F5FFFFFEFCFEFDF5F4F1
EEEBE7E8E2DDE3DAD4DED4CCD9CDC4D6C8BED2C3B8CFBEB2CCBAADCAB6A8C8B3A4C6B0A0C5AD9D\
C3AA99C2A896C1A693
C1A593C2A795C3A998C4AC9BC5AE9EC7B1A2C9B4A6CBB8AACDBCAFD0C0B5D4C6BBD8CBC2DCD2CA\
E1D9D3E7E1DCEEEBE8EFEDEBE9E6E4E3DFDDDFDBD9DCD8D6D9D6D4D7D2D1D3CDCC
D0CAC8CFC8C7CDC7C5CAC3C1C7C0BEC6BFBDC6BEBCC5BEBAC5BEBAC7BFBBC8BFBBC9C1BCCCC4BF\
D1C9C4D9D0CBDFD8D3E7E0DCEFEAE5F5F1EDFBF8F5FFFFFEFDFEFDF6F5F1EFEBE6
E9E2DCE3DBD4DFD4CCDACEC5D7C9BED3C4B8D0BFB3CEBBAECBB8AAC9B4A6C7B1A2C6AF9FC4AC9B\
C3AA98C2A796C1A593
C1A592C1A795C2A897C3AB9AC5AD9CC6AFA0C8B2A3CAB5A7CCB8ABCEBCB0D1C1B5D5C6BBD8CBC2\
DDD1C9E2D8D2E7E0DBEFEAE7F4F1EFF0ECEAE8E3E1E2DDDBE1DCDAE2DDDCE3DDDB
E2DCD9DED7D5DBD3D1DCD3D1DDD4D0DAD0CBD6CBC6D4C9C4D4C9C4D3C9C3D4C9C2D5CAC3D7CCC5\
DCD1CAE2D8D1E9DFD9EFE7E2F6EEE9FAF4F0FDFAF8FAF9F7F4F0ECEEE8E2E8E0D9
E3D9D1DED3CADACDC3D7C8BDD3C3B7D1BFB2CEBBAECCB8AACAB5A6C8B2A3C6AF9FC5AD9CC4AB9A\
C3A997C2A795C1A592
C0A492C1A694C2A896C3A998C4AB9AC5AD9DC6AFA0C8B2A3CAB5A6CCB8AACEBCAFD1C0B3D4C4B9\
D8C9BFDCCFC6E0D5CDE6DDD6ECE4DFF1ECE8F1ECE9EDE6E3E9E3DFE8E1DEE8E0DD
E7DEDBE7DDD9E7DCD8E5D9D3E1D5CEDFD3CBDFD2C9DDCFC6DACCC3D9CCC2DBCEC5DCD0C7DED2C9\
E3D7CFE8DED6EFE5DFF3EAE5F5EFEBFAF6F3F8F4F0F0E9E4EAE2DBE5DBD3E1D5CC
DDCFC5D9CABFD6C5BAD3C1B5D0BDB0CEBAACCCB7A8CAB4A5C8B2A2C7AF9FC5AD9DC4AB9AC3A998\
C2A896C1A694C0A592
C0A491C1A593C2A794C2A896C3A998C4AB9AC5AD9CC6AF9EC8B1A1C9B3A4CBB6A7CDB9ABCFBCAF\
D2C0B4D5C5B9D9C9BFDDCFC5E1D4CCE6DAD2ECE3DCF2E9E3F2E9E3EDE3DDE9DED9
EADFDAEADED9E8DBD4E5D7D0E2D4CDE2D4CCE2D3CAE2D3C8E2D3C8E1D2C8E1D2C7E2D4C9E3D6CD\
E4DBD2E8DFD7EDE5DFF3EDE8F5EFEAF0E9E2EAE0D8E5D9D0E0D3C9DCCEC3D9C9BD
D6C5B8D3C1B4D0BDB0CEBAACCCB7A8CAB5A5C9B2A3C7B0A0C6AE9EC5AC9CC4AB9AC3A998C2A896\
C2A795C1A693C0A492
C0A492C1A592C1A693C1A694C2A795C3A897C3AA98C4AB9AC5AC9CC6AE9EC7B0A0C9B2A2CAB4A5\
CCB7A8CEBAACD1BDAFD3C0B4D6C4B8D9C8BDDDCDC2E0D1C6E2D4C9E6D8CDE7DACF
E6D8CEE5D6CDE5D7CEE4D5CDE1D1C9DECEC5DCCCC2DCCCC0DDCCC0DDCCC0DDCCC1DCCCC0DECFC3\
E4D7CDEADED6E9DED5E5D9CFE2D5CBE0D1C6DCCCC1D9C8BBD6C3B7D3C0B2D1BDAF
CFBAABCDB7A8CBB5A5C9B3A3C8B1A1C7AF9EC6AD9DC5AC9BC4AB99C3A998C3A897C2A795C1A694\
C1A693C1A592C0A491
C0A491C0A491C0A492C1A592C1A593C1A693C2A694C2A795C2A896C3A997C4AA98C4AB99C5AC9B\
C6AD9CC7AF9EC8B0A0CAB2A2CBB4A4CDB6A6CEB8A9D0BAABD1BCACD2BDAED3BEAF
D3BEAFD3BEAFD3BFB0D4C0B1D7C3B4D8C5B5D9C5B7D9C5B8D9C6B8D9C6B8DAC7B9DAC8BBDBC9BC\
D8C5B8D5C1B4D4C0B2D3BEB0D1BCADD0BAABCEB8A8CCB5A6CBB3A3C9B2A1C8B09F
C7AF9EC6AD9CC5AC9BC5AB99C4AA98C3A997C3A896C2A895C2A795C2A694C1A693C1A593C1A592\
C0A492C0A491C0A491
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[92]:=",
  ImageSize->{400, 195.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000`b000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`008P3oool809R?S0P0Uhn<00<0UXj<09J?S02FShd00P2FShd0102FShh0
UY2?09JAT@2EShh309J>S00509J=R`2FSX/0UXj;09J>R`2FSX`00`2GSX`05`2GSX/0Uhf:09N=RP2F
S8T0UX^809J:Q`2ERXL0UHV609F8Q@2ER8@0U8N309>5P@2APWh0ThJ209B7Q02ER8D0UHV609F:Q`2F
RXL0UX^709J;R02FS8T0Uhb90080Uhf:00<0Uhf;09R>R`2HSX`06@3oool0102=RXT0SH^908f;R@2=
RhT308j;RP0508j<RP2>S8/0SXb;08j<R`2>SH/00`2>SH`02`2>SHd0SXj=08j>S@2>SXd0SXj>08j?
SP2>Shl0SY2@08nBT`2>Shl0SXj>0080SXj=01/0Shf<08n>S@2?SXd0Shj=08n?S@2@SXd0T8n=092>
S@2@SX`0T8f;092<RP2?RhT0SXZ708j9QP2=R8D0SHN508f5P`2;Q840RX9o08V0O027O7P0RH5m08Z3
P02;Q880RhF308^6Q02<QX@00P2<QhD308b8QP80SHV700<0SHV808f:R03oool05`3oool01@1fOWl0
MWj007MoP01gOh00Mgn10080Mh2100P0N82207R1PP1hPH80N86307R2P`1iPX<0NH:407V3Q080NH>5
00<0NHB507Z4QP1jQ8H00P1jQHL0101jQXP0NXN:07V5Q`1jQHH207Z4QP0307Z4Q@1jQ8H0NXF600<0
NhF60180O8F607^5Q@1kQ8D0Nh>407^2P`1jPH80NH2107V0P01hOgl0N7in07QlO01gNgX0MWUi07Eg
MP1cM7<0MGQg07EjNP1fNg/307IlO00307IlO@1fOGd0MWen00@0MWen00<0MWin07InO`3oool0603o
ool02`10G6l0@5e`041ML010GG40@5ia045NL@11GW80@Emb045OL`12Gg<0@V1c0080@V1d0P13HGD0
1013HGH0@f9f04=RMP14HWL204ASM`<0A6=h00<0A6=g04ASN014HgP00`14HgP204ATN080AFAh0P14
I7P02`14I7L0A6=f04ASMP14HWH0A69e04=RM@13HGD0@f5d04=PL`13H780@Uma0080@Ui`00<0@Uia
049OLP12Gg800P12Gg83045NLP80@Eia00D0@5ea041ML010GG00@5a`041LK`0T0?ooo`008P3oool2
09R?S00409R>S02HSh`0Uhn<09N>S080Uhn<00D0Uhj<09J>S02FSX`0UXj<09J>S@0309F>S@0>09F>
S02DSXd0U8j=09B>S@2CShh0Thn?09>@T02DTY<0Thn?09>>S@2CSH/0U8f;09B<R`2DSH/209F=R`03
09B=R`2ES8/0UHb:0080UHb:01/0UH^809F:Q`2DR8H0U8N409>6P`2BQH40TX>009:2OP2AP7`0T7ij
08imM`2=NgH0Sgii0920O02APWh0TXAo09:5P@2CQX80ThN309B7Q02DR8D0UHV609F:Q`2FRhP0Uhb9
09N=RP2HSX/06@3oool0102=RhT0SH^:08j;RP2>S8X208j<R`80SXf<0P2?SXd208n?SP0308n?S`2?
T900Si2@0080Si6A0P2?TY801`2?Ti<0Si>D08nDU@2?UIL0SiNJ08nDUP2?Ti<00P2?TY400`2@TI00
T96A096BT@0309:BT@0N09>BT@2CTI00TY2?09:>S02ASH/0T8^808n9QP2>Qh@0SHF208b3P02;PGd0
RGii08MjMP25Mg40PgA^08IiM@27OGP0R7mk08V1O@2:PWl0RX>008Z4P@2;Q880RhF308^6Q02<Qh@0
S8N508b8QP2=RHL0SHV8603oool02P1fOX00Mgn007N0P@1hP880N86207V2P`1iPX@0NH>407Z4Q@1j
Q8H207^5Q`0Z07^6R01lQhT0O8N:07b8R`1mRH/0OHV<07f:S@1mRhh0OH^?07j<T01nSI40OHnC07f=
T01mS8h0OH^=07j;S@1nRX`0OX^<07n;S@20S8d0P8b>082<S@21S8d0PH^;082:RP1oR8P0OhN607f5
Q01mPh<0O86107^0O`1jOWd0NG]j07MhMP1eMG<0Lg5^079_K01dM780MGMe07IhM`1fNWT0MWYj0P1g
Ng/207MlO00307MmO@1fOGd0MWen0080MWen00<0MWin0?ooo`3oool05`3oool01P10GG00@5ia045N
LP11Gg80@V1c049PM080@f5e00l0A69f04ASM`14HgP0AFAi04EUNP16IGX0AVIk04MWO017J7d0B6Qn
04QYO`18JWl0B6Z004UZP019Jh000P18JX000`19Jh00BF^104U[P00204U[P00E04U/P@1:K880BVf2
04Y]PP1:KH40BVf004U[O`19JWh0B6Ym04QYO018J7`0B6Qk04MWN`17IWX0AVEh04ITMP15HW@0A61a
04AOL@14HG@0A69e0080A69f0P14HGD02@13HGD0@f5d04=PM012H7<0@Umc045NLP11GW40@5e`041L
L00T0?ooo`008P3oool0302HSh`0V8n=09N?S02GSX`0Uhn=09N?S02FSh`0UXn=09J>S02ESXd0UHj<
09F>S@<0U8j=0P2CSXd209:>S@80THj>00D0THn?092@T@2@TI<0T8j?092=S@02096<R`80TX^:0P2C
S8/0802BS8/0Thb;09F;RP2ERhT0UHZ809B9Q`2DR8H0ThF309:3P02@PGh0Sgml08inNP2>NgL0SGUd
08]gL@2:M6d0RWE_08]hLP2<NWD0SGag08inN@2?P7/0T85m0962OP2BQ800TXF109>7P`2DR8D0UHV6
09J;R02GS8T0Uhf;6@3oool01`2=RhT0SXb:08j<R`2>S8/0SXf<08n>S@2?SXh00P2?Shl01P2@T900
T96@092AT@2@TY80T9>C092CU080TIBE02l0TIFF096FU`2AUiP0T9NJ092IV`2@VYd0T9bP08nIV`2@
UiP0T9FF092EU@2AUID0TYFE09>EU@2DUYD0TiJE09BFU@2EUI@0U9>B09BBT02CT8h0Thj<096;R02@
R8D0SXF208f3O`2;Og`0RWag08MhL`25Lfd0PFiV085`J@23M6h0QGMb08IjM@27O7P0R7ij08UoO029
P7d0RX9n08Z3P02;Q840RhF308^6Q02<QhD0S8R608f9Q`0H0?ooo`0O07MoP01gP840N86207V1P`1i
PX@0NX>507Z4QP1kQXL0O8J807b8RP1mR8X0OHV;07j:S@1oRhh0Ohb?082=T020SY40PHnB086@U021
TID0PI:F086CV021UIT0PIJL086DV021TYD0PI6D086AT`22TI80PY6C08>AT`0308BBTP0L08BAT@24
Shl0Phf=08:;R`21RXT0PHR70826Q@1oPh80OX5o07amO01jNWP0N7Ic07EbKP1bK6L0LVeY07AaKP1e
M780MWMe07MhM`1gNGP0MgYi07MkNP1gNg/0Mgak07MlO01gO7d0Mgem07ImO@80MWen6@3oool05`10
GG00@Eia045OL`12H7@0@f5e04AQMP14HgL0AFAi04IUNP16IW/0AfMm04QXOP18JGl0BFZ004Y[P@1:
K880Bff404a^Q@1<L8L0CG2804eaR@1=LXT0CW::0080CW>:0P1=LXT404ebR00F04ibQ`1>LhL0CG>7
04ecQ`1<LXH0C72404]_P`1;KX80Bfn204a_PP1<KX80C6f104][O`1:JWd0BFQk04QVN016Hg@0AV9d
04MUM`17IGT0AfIi04MUN@80AVEi00T0AFAh04ESM`14HWH0A69e04=QM012H7<0@Emb045NL@10GG00
903oool00280oooo00D0V8n<09R?S@2GShd0Uhj<09J?S00209J?S@0409F?S@2ESXd0U8n=09B>S@80
Thj=0P2BSXd2096>S@0_092>S@2@SHh0Shf>08j>SP2>SXl0SHnA08j@T`2=SHl0SHb<08j;R`2>RXX0
ShZ:092;RP2BRh/0Thb<09>=S@2CSX`0UHb<09B:R@2DRHL0U8N509>5P`2BPX00T81m08mmNP2=NgL0
RgQd08YeL029LVd0QfmX08E[H`26KVL0Qg5[08UdKP2:MW40RgUc08akMP2=OGP0SWmj08n0O02@PWh0
THB009>6PP2DR8@0UHV609J;R02GSHX06@3oool01`2=RhX0SXb;08j=S02?SH`0Shj=08n?SP2@T8l0
0P2@TI405`2@TY<0TI>C096DU02AUID0TIJG09:GV02BUiT0TYRJ09:IV`2BVY`0TY^M09:LW`2AWJ00
TIjR096PY@2@W9l0T9ZL096IVP2AV9T0TYRH09>HV02DV9P0UIRH0080UIVH01h0UYNG09JEU02ETi40
U96?09B?S02CRhP0THN408n4P02=P7`0RWag08QgLP25Lf`0PVeV07iWGP20Jf@0PVmX08=cK@25MW00
QWQc08IjMP27O7P0R7ei08QoN`29PGd0RX9o08Z3P@2;QH80RhJ408b7Q@2=RHLH0?ooo`0n07MoP01h
P880NH:307V2Q01jQ8D0NhF707b6R01mR8X0OXV;07j:S@1oRhh0P8f@086>T@21T9<0PY6D08>BUP24
U9L0Q9FI08FFV`25V9`0QIVN08FJW`25Vj40QIfS08BJW`25V9`0QINJ08FGV@25UYP0QYJH08JFU`26
UIH0QIFF08JEU@26U9@0QY>B08FAT025Shh0Q8j<08B;R@22QhH0PHB207n1O`1mOG/0NgUf07UeL@1f
L6/0LfYU07A]J@1eL6d0MW=`07MeL`1gMgD0MgQf07QiN01hNGT0MgYj07MkNP1gNg/0Mgal07MlO@1g
OGd207ImOQT0oooo01D0@5e`045NLP12H7<0@f5e04ARM`15I7P0AVEj04MVN`18Igd0BFUn04YZP01;
K880Bff404a_QP1=L8L0CW:904mcR`1@MHd0DGJ?055hT01BNI800P1CNY<00`1BNY<0DWZB059jT@02
059iT@05059iT01AN8l0DGN=04mfR`1?MHX00P1?MHT304ieR@0904ieR01>M8P0CgB804mcQ`1?LXH0
CW2404e^PP1<KH00Bf]n0080BVUl00l0BVUm04YZOP1:JWh0BVUn04UXO@18Ig`0B6Ik04MVNP16IGT0
AF=h04ARMP13HGD0@V1c045NLP10GG00903oool00280oooo00<0V8n<09N?S@2GShd00P2FShd209F?
S@0409B?S@2DSXd0Thj=09>>S@80TXj=00@0THj=092>S@2@SXh0Shf>0P2>SHh03@2=SHh0S8f>08^=
S`2:SI00RXnB08Z<SP2:Rh/0RhZ908b9R@2=RHT0SXV908n:R@2@RhX00P2AS8/07P2BS8/0TXZ909:8
QP2BQX<0TX>10961OP2?O7T0SGUe08]fLP28Lfh0QVmY08E[I@23J640PFAL089XH024Jf@0QFiW08Ia
JP28Lfd0RGI`08YhL`2<NgH0SGeh08ioN`2@PGd0THB009>6PP2DR8D0UHZ709N=RQT0oooo0400SX^:
08j<R`2>SH`0Shj=08n?S`2@T900T96A096BTP2ATi@0TIBE09:EUP2BUYL0TYRI09>IVP2CVY/0Ti^M
09>LWP2CWIl0TijQ09>OXP2CX:@0TZ2U09:QY`2AXjT0TInS096MX02BW9d0TY^L09>JV`2DVY/0UIZJ
09JJVP2FVi/0UY^J09NJV@2GUiH0UYFB09JBT02ESh`0U8b809:7P`2?PWh0SGii08UiM026Lfd0Q6iW
081XH01mHeT0OfMO081[I022KfP0Pg9[08AdKP25Mg40QWUd08MkMP27OGP0R7ik08V0O@2:PWl0RXB1
08^5P`2<QhD0S8R7603oool07P1gOh00N86207V2Q01jQ8D0NhF707b7R@1mRH/0OXZ=082<SP21SI00
PXnB08>AU023TiH0Q9BH08FFVP26V9`0QiVN08RKX029WJ80RIjT08VPY@29XJL0RJ:Y08VSZP28X:D0
R9jS08RMX029W9l0RI^N08VKW@80RYZK0200RYZJ08ZIV@2:V9P0RIJF08RDT`28TY40Qhn>08N=R`25
RXP0PhF308:2O`1oOW/0O7Ue07YdK`1gKVT0M6US07E]J01fL6`0Mg9_07QdL@1hMW<0N7Me07QhM`1h
NGP0N7Yi07QjNP1hNg/0Mgak07MlO01gO7d0Mgem07ImOQT0oooo01P0@5ea049OL`13H7@0A69f04ET
N016IW/0B6Mm04UYOP1:Jh00Bfb304a^Q@1=L8L0CW:9051dR`1AMHh0DWN@05=iTP1DNi@0EGfG05Io
V@1GPI/0F8:L05R2W@1HPY`205N1V`0905N0VP1FP9P0EWnG05IoU@1EOY@0EGbB05AkT01DNXl0DgV?
00<0DWV>00T0DWR>055hS@1BNHd0DWR<059fR`1AMXX0DGB9051bQP1?Kh<00P1>KX803`1>Kh<0CVj3
04e^P`1<KH80C6b104][P01:JWl0BFQm04QWO017IWX0AFAh04ARMP13HGD0@Umc045ML@0T0?ooo`00
8P3oool01P2HSh`0Uhn<09N?S@2FShd0UHn=09F>S@80U8j=00@0Thj=09:>S@2BSXd0THj>0P2@SXh0
<P2?SXh0SXf>08f=SP2<SHh0Rhb>08Z<SP29Rhd0R8^=08J;SP26Rhl0QXZ<08N9RP28R8T0RHR708Z7
Q`2;QhL0S8R708f8R02>R8P0ShV908n9R02@R8L0ShF308n3P@2>P7d0SWej08aiMP2:M700R75/08E]
J022JF<0PFEN07iQF@1nGeL0Of9J081UG@22J640Pf]T08A^J026LF/0QgA^08UgL@2;NG@0S7ag08io
NP2@PGd0THB009>7P`2ERHH0Uhb96@3oool0@02>RhX0SXf<08n>S@2?Shh0T92@092AT@2ATi<0TIBD
09:EUP2BUYL0TiRI09>IVP2CVY`0U9^N09BMW`2DWZ40UInR09FPY02EXZH0UJ>W09BTZ02CY:X0TZFZ
096UZ`2AXZH0TJ2S09:NX02CWIl0U9fN09FLW@2EW9`0UYbL09NLW02HW9`0V9^J09RIV02GUY@0Ui>A
09J?S02ES8P0ThJ20920O02=O7H0RGIa08I`J@22JV40OV=I07aPEP1nI5/0OfQO081[H`22KVL0Pg5Z
08AcK@25MW00QGQc08IjM@27O7P0R7ik08V0O@2:PWl0RhB108^6Q02<R8HH0?ooo`0l07N0P@1iPX<0
NX>507^5Q`1lQhT0OXV;07n;S@20SHl0PHnB08>AU024TiH0QIFH08JGV`27VId0R9^O08ZMX@2;Wj@0
S:6V08fSZ@2=YJ/0SZN]08jX[`2=ZK00S:V`08bV[02;Y:P0S::V08bQY02<X:80SJ2Q08fOX@2>Wj00
SYnO08jNWP2=W9`0SI^J08fIV02<UYD0S9>B08^@SP29RhX0QhN508B3P022OW/0OgUe07acKP1gK6H0
MVYS07M]J01hL6/0N79^07UdL01iMG80NGMd07UhMP1iNGL0N7Uh07QjN@1hNgX0N7]k0P1gO7`00`1g
OGd0MWen0?ooo`0H0?ooo`0R045NL@12H7<0A69f04ESN016IWX0B6Qm04UZO`1;K880C6j404e`Q`1?
LXT0D7B<055fSP1CN940E7^D05ImUP1GOiT0F8:L05Z4W`1KQZ80GHVU05j;Y`1NS:P0GH^W05b9Y01L
R:80FhNQ05^6X01KQYh0FhFM05Z5W01JQI/0FH>J05R2U`80F82F0P1GP9H02P1GOiH0EgnE05InU01F
OYD0EWfC05IkT@1FNY00E7R=05=dR01BLhL2059dR@0>055cR@1@LhP0Cg6704i`QP1=KX@0C6f204][
P@19JGh0B6Ql04MVNP15I7P0A69f049PM011GW4T0?ooo`008P3oool01P2HSh`0Uhn<09J?S@2FShd0
UHj=09B>S@80Thj=00H0TXj=096>SP2ASXh0T8j>08n>SP2>SXh208f=SP0`08b=SP2;S8h0RHb>08R;
SP26RXd0Q8V<08:7RP21QXT0PhN908B7R025QXL0QXJ608N6QP28QHH0RHF508Z6Q@2:QHD0RhF508^4
Q02<Ph<0S86008aoO@2;O7T0RWUe08UdL@27L6`0Q6]V085WH@1oHe`0OEiF07UID01jFU00NeaD07aO
E`1nHe/0OfIN085YHP23K6H0QG1Y08IcK@28MW00RWUd08alM`2>Og/0T89n09:5P@2DR8D0UXb96@3o
ool0802>S8X0SXf<08n>SP2@T8l0T96A096CT`2AU9D0TYJF09>GV02CVIX0U9ZL09BKW@2EWIl0UIjQ
09FPX`2FXJD0UZ>W09JTZ02FYZX0UZN/09JX[P2EZ:l0TZR_092U[02AXjP0TZ:U09>QX`2CX:40U9nP
09FOW`2FWYl0UijN0P2HWYd07P2IW9/0VIZI09RGU@2HU940Uhn<09F;Q`2CQH80T81k08eiM029M6d0
QFeU085VG@1lGU<0O5iD07eQF01nIE`0OfQO081[H`21KVH0PW1Z08=cK@24MW00QGQc08IjMP27OGP0
R7mk08V1OP2:Ph00RhF308b8QQP0oooo01d0Mh2107V2Q01kQ8H0O8N807j9R`1oRhd0P8f@08:?TP23
TYD0QIBG08JFVP28VId0RI^O08ZMXP2<X:D0SJ:W08jTZP2?Yjd0TJV`09://`2C[[D0Tk2h09:a^@2?
[[H0SZZ`08jX[@2?Yj/0SjJX092UY`02096UYP0?096TY@2BY:@0TZBT09:RXP2BX:00TIjM096JV@2@
UiD0Si>A08f?S@2:RXP0R8F208F0O@21NWD0OG=^0080NFaU0100NFiX07UaJ`1jLVh0NWA`07YeLP1j
MW<0NWMe07UhMP1iNGL0NGYh07QjN@1hNg/0N7ak07MlO01gOGd0MWen6@3oool08`11GW80@f1d04AS
M`16IGX0B6Mm04UZO`1;K880CFj504iaR01@Lh/0DGJ>05=hT@1ENi@0EWfG05R0VP1IPYd0FhFP05f8
Y01NRjL0H8j[06:A[`1TUK<0IINf06>E/`1QT:d0H8nZ062>Z01PSJL0GhbV05n<Y@1OS:@0GhbS05n;
X`1NRj80GXZQ0080GHVP00/0GHRO05f7WP1LQYd0G8FM05^5W01KQ9`0Fh>J05Z0U`1HOYD0EgbA05Mj
T00205IjT@0>05EiT01DN8h0DgJ<055dRP1@LXP0CW2504e^P`1;K840BVYn04QXO016IWX0AF=g04=P
M011GW8T0?ooo`008P3oool0102HSh`0Uhn<09J?S@2ESXd209B>S@0409>>S@2BSXh0THj>092>SP80
Shj>03@0SXj>08f=SP2<SHh0Rhf>08Z=SP29S8h0R8b>08J;SP25RXd0PHR;07Z2QP1mQ8L0P8F70865
Q`23QHH0PhB508B3Q025Q8@0QX>308J2PP27PX80Qh6108R0P028OWh0Qgak08MiN026MW@0QWAa08A`
K022JfH0P6MQ07iRF`1jGED0N5Q?07EBA`1fE4X0MeI=07UID01jGE@0O61H07iTG020J600PV]U08A_
J@26LVd0R7Ia08YjM@2=OGT0Sh5m0964P02DR8@0UX^86@3oool0@02>S8X0Shf=08n?SP2@TI00TI:B
096DU02BUYH0TiNH09>IVP2DVi`0UIbN09FNX02FX:<0UZ6U09NSY`2GYJT0V:J[09RX[@2HZZl0VJ^a
09V]/`2I[[D0SjN_08jTZ`2@Y:T0TZ>W09>RY@2DXZ<0UJ6R09JQXP2GX:40V:2P09VPX02IWil0VYfM
09ZKVP2IV9H0V9BA09N?S02FRXL0ThF1091nN@2=N780R75Z08=ZHP20HeT0NeY?07]LD@1lGe@0OF9H
07iUG01oJ5l0P6YS085]IP22L6X0Pg=]08AeL025N7<0QW]f08MnNP29P7`0RX9o08^5PP2<QhDH0?oo
o`0L07R0PP1iPh@0NhF707f8RP1oRXd0P8f?08:?TP24TYD0QIFH08NGV`29VYh0RYbQ08bOY02=XZL0
SjBZ092W[@2BZ[00Tjfc09F`]`2F/kX0V;Jn09^k``2D]Kh0T:ng096^/`2A[;40TZ^_09>[[@80U:Z/
01d0UJZ[09FZZP2FZZX0UZZY09NXZ02GYZD0Uj>R09JOWP2DViT0TiNE096BT02>S8X0RhN408N1O@23
NgH0P7A_07]]IP1kKVL0Ng1Z07]aK01kLfh0NgA`07]eL@1kMW<0NWMd07YhM@1jN7H0NGUg07UjN@02
07QkNP0307MkN`1gO7d0MWen01T0oooo01`0@Eib04=QM@15I7P0AfMl04UYO`1;K880CFj504iaR01@
M8/0DWJ?05AiTP1FO9D0F7nI05V2W01KQJ00GHRS05n;Y`1QSZ/0Hi6_06FE]01XV[T0K:3106^O`01V
V;L0IIJc06BD/01TU:h0I9>^0P1TTjd206BD[@<0I9F]00`0I9B/06BCZP1TTZT0Hi2X06>>Y`1RSJH0
HHbT062:X`1ORJ80GXNO05f5W@1LPi/205^2VP0?05Z0V01IOiH0EgfD05IkTP1DN8l0DgJ<055cR@1?
LHH0CFj404][P@19JGd0AfIj04ESM`13HGD0@Eib02@0oooo000R0?ooo`0:09N?S02GShd0UXn=09F>
S@2DSXd0Thj=09:>S@2ASXh0T8j>08n>SP80SXj>03@0SHf?08b=S`2;SHl0RXf?08R<S`27S8l0QXb>
08F;SP24Rhh0PXZ>07IoQ01kPXH0OX>507n4Q@20Ph@0PH>408:2PP22PH80Ph6208B0P@24Oh00Q7in
08AkO024N7T0PgIf08=dL`22LFl0PFi/081[I`1nIV40O69L07YLE@1fETh0Le57071:?`1bCD80Le15
07ECB@1fEdh0N5]B07YOE`1mHe/0OfMP085[I024KfT0QW=]08UgLP2;NgH0SWmk0923O`2CQh<0UX^8
6@3oool0@02>S8/0Shj=092@S`2@TI40TI>C09:EUP2CUiP0TiVJ09BKW@2EWIl0UYnQ09JPX`2GXZH0
V:BX09RVZP2IZ:d0VJZ_09Z//@2J[[@0Vk2f09bb^@2K/k/0RJ>/08jU[02@YJX0TZFY09BTY`2EY:H0
UZ>T09NSY02HXj<0VJ>R09ZRXP2JXJ00VijN09^KVP2JV9H0VI>A09R>R`2FRHH0ThAo091mN02<Mg00
R6mX08=XG`1oH5H0NUQ<07YICP1kG540O5mD07eQF01nI5/0OfMO081ZH`21KFH0PW1Z08=cK@24MW40
QGUd08MlN028Og/0RH5n08^4PP2<QhDH0?ooo`1007R1PP1jQ8D0O8N807j9R`20S8h0PXnA08BBU@26
UIP0QiNK08VJWP2;WJ80SJ2U08nSZ02@YZ`0TZV_09B//`2E[kH0Uk>j09Vf_@2K^L40WKk609k0b02?
/[/0TK6i09>`]P2D/;D0UK2c09J_/P2G[k40V:n`09V_/02J[jl0V[2`09^`[`2L[Zh0W:b[09^XYP2J
Xj80VInM09NJV02DUI80THn<08j9QP2:Pgl0QWeh08=gL@1nL6T0OW5Z07ibJ`1mLVd0OG=^07edK`1l
MG40O7Ib07]gL`1kN7D0NWQf07YiM`1iNWP0NGYi07QkNP1hNg/0Mgal07ImOQT0oooo01/0@Emb04AR
MP16IGX0B6Qm04Y[P@1<KX@0CW68051dR`1BMhl0E7ZB05MmUP1IP9X0Fh>N05f6XP1ORZH0HHfZ06>A
[P1UU;80IiRg06VL_01/XL80KZC406^P`01XVkX0J9Zh06RJ]`1XVKH00`1YV[D0101YV[@0JIbe06ZM
]P1ZWkL206^P^00L06^N]P1ZVk<0JYRa06VF[`1XUJd0IY>/06JAZ`1TT:X0HhnY06>>Z01RSJL0H8^U
05n9X`1NQj40GHFN05^2V`1IOiL0EgbD05EjT@1CMhd0DGB:04maQP1=KX<0BfZ004QWO016I7T0A69f
049OLR@0oooo000R0?ooo`0J09N?S02FShd0UHn=09B>S@2CSXd0TXj=096>SP2@SXh0Shj>08j>SP2=
SXl0S8j?08^=S`2:SHl0RHf?08R=S`27S8l0QXb?08F<S`24Rhl0Q8b?0829S01kQ8L0Nh>607b2Q@1m
PX@207j1PP0T07n0P@1oOh00P7n0085oO`21OWh0PGal085hN@21MGH0P75b07m^KP1nK6X0OFUW07]U
HP1iHE`0N5aG07IHD@1cDTX0L4a206e4>@1]ACT0KdTn075=@P1bDDL0MEE<07MID@1iGUH0O69K07iW
H021JfD0Q71Z08MdK`2:NG@0S7ei08n2OP2BQX80UHZ76@3oool0;P2>S8/0Shj>092AT02ATY80TYBE
09>FU`2CV9X0U9^L09FMW`2FWj40Uj6T09NSYP2HYJT0VJN/09ZY[P2JZk40Vjfc09^`]P2L/[T0W;Bk
09ng_`2D[kL0RjF]08nW[@2AYj`0TjN[09BVZ@2FYZP0UjFV09RUY@2IYJD0VZFU09^UY@2LY:80W:2O
09bLV`2JUiD0VI:@09R=R`2FR8D0TX9n08mkMP2;MFl0QfiV08=VG@1nGe@207YFBP0@07YIC@1kFe40
O5iD07eQF01mI5/0OVMO081[H`21KVL0PW5[08=dKP25Mg80QWYf08MmNP29PGd0RXB108b7QAP0oooo
0400N86207Z4QP1mQhT0OhZ=086=T023TI@0QIBG08NGV`29VYh0RifR08jQY@2@Y:T0TZN]09B[/@2E
[[@0Uk6h09Ve_02K^<00WKc409job02Qa<d0U[[408b`^P2B/k/0UKBj09Ne^@2I];P0V[Bg09^d]P2L
];D0WKBd09je]@2O][D0X;Fd0:2c/P2P/:h0Wj^Y09jWY@2MXZ00VifK09NGU02DTHh0T8^708b5P029
OgX0QGUc085dK@21Lf`0P7=]081dK@1oM6h0OWE_07ieL@1mMW80O7Mc07agM01kN7D0NWUf07YiN01i
NWT0N7]j07QkN`1gO7`0Mgem6@3oool06P12Gg<0A69g04IVNP19JGl0Bff304i`QP1@LhX0DWJ>05Ej
TP1GOIH0FH2J05^4WP1NQj<0H8^W06:?[01TT[00IiJe06VJ^P1[W[l0KJ;306nUb@1YWl80IIVk06VM
_@1[Wkd0K9nn0P1]X;d01@1^X;`0KZ6l06jR_01^Xk`0KjFn0080L:Jo01d0L:Jn072U_P1`Xk`0L:6j
06nN^01^W;H0K9Zd06ZH/P1YU[00J9F`06NE/@1WU[80IYFb06BA[@1RSZT0HH^U05n8X@1MQ9d0FX6I
05QmU@1FNY40DgJ=055cR@1>L8D0C6b204UYOP17IWX0A69f049OL`0T0?ooo`008P3oool0@02GSh`0
UXn=09F?S@2DSXd0Thj=09:>SP2ASXh0T8j>08n>SP2=SXl0S8j?08^>S`2:SHl0RHf?08R=S`27SHl0
QHb?08B<S`23S8l0PX^?082:SP1nR8`0O8F907^3QP1kPX@0Nh6307^0P@1lOgl0O7io07enOP1mOGh0
OWen07mmOP1oNGX0OgEg07iaL`1mKFl0O6UZ07]WI`1iI680Mf1N07ELF01cF580LU=<071>AP1]B3h0
JT0e06Pm<@1Z@SH0K4Hk06i;@01aCdH0LeA;07IID@1iGUH0Nf=L07iXH@22KFL0QG9/08QgLP2;NgL0
SX1l09:5P@2ERXLI0?ooo`1008j<R`2?Shh0T96A096CT`2BUIH0TiRI09BJV`2EW9h0UYnQ09NQY02H
XjL0VJFY09VX[02JZZl0Vjbb09b_]@2L/KL0WK>j09jf_@2O^L40V;>l08n[]02?Z[80TJZ_09>Y[P2D
ZJd0UZV/09NXZ@2HYjP0VJNW09ZWY`2KZ:L0W:RW09fUY02MXJ00WIbK09^GU@2JTHl0V8b:09J7P`2B
PG`0SWYe08YcK026K6D0PfIM07iOE01kEd/0N5=607UEB@1jF4`0NU]@07]NE01lHEP0OFAL07iXH01o
Jf@0PFmX089bK024MG00QGUd08MlN028P7`0RX>008b7Q1P0oooo0300N86307^5QP1mR8X0P8b>08:?
T@24TYH0QiJI08VJW@2;WJ40SZ6U092TZ@2BZ:d0U:^a09N_]@2I/kX0VkJn09fj`P2O_/H0XL;;0:C7
d@2K`<X0T;K009>f_`2F]kh0V;Rn09Zi_P2L^Kd0WKRk09nh^P2O^;T0X;Vi0:6j^@2S_;X0XkZh0:Bg
]@2T];40Xjn/0::YY`2QYJ80WYnL09^IUP2GTi00Thf908n7PP2<PG`0R7ef08IhL@23M6h2089dKP0>
085eK`20MFl0OgE`07ifL@1mMW80O7Mc07ahM@1kN7H0NWUg07UjN01iNWT0N7]k07MlO01gOGdI0?oo
o`10049OL`15HgL0AfMl04YZP01<KX@0Cg:8059eS@1DNI40EgfE05V0VP1LQ9h0GXRS066<Z01ST:`0
IYBa06RH]P1[W;/0KJ3006nTaP1cZ/h0KJC706JK_@1YW[l0K:7106jS`P1`Y<@0LJG507:Va01bYl@0
LjO307>X``1cZL<0M:_507B]aP1e[/H0MJk507F]a01eZl<0MJS107BV_`1cXkd0LZ2k072M^01^W;L0
K9^g06bL^@1/W[`0Jifl06VI]`1WUK80II6]06>=Z01PRJ<0GXFN05^1VP1HOID0EWVA05=fS01@LXP0
CFj404Y[P018Ig/0AF=g049OLb@0oooo000R0?ooo`0M09N?S02FShd0UHn=09B?S@2BSXh0THj>092>
SP2?SXh0SXj?08f>S`2;SXl0RXj?08V=T028SI00QXf@08F=T024S900PXb@086;T023SI80OHR<07b6
RP1kQHP0NX>607Z2Q01iPH80NGj007UmO@1iO7`00P1jO7`08@1kNg`0OGin07ekO01mN7P0O7Ad07]`
L01iJFT0N6AT07EPG`1cG5X0LEQE06mDC`1]D4T0K4]306Y6?01X@3@0ICT]06Di;01X?c<0JT@i06e:
?`1_CdD0LUA;07EJD@1hGeL0O6AM07mZH`23KfT0QWE`08YjM@2=Og/0THB109F:QP0I0?ooo`1008j=
S02?Shl0T9:B09:DU02CUYL0U9VJ09FKW@2FWZ00Uj2S09RSYP2IYJT0VZR/09^[[`2L[K80WK2f09fb
^@2N];`0W[No09ni`P2L^L80TJnh096^]`2B[K@0Tjbb09B//@2F[;00Uj^^09RYZ`2IZJT0VJRX09ZY
Z@2LZJP0WJZY09jVY@2NXZ40WIfK09fHU`2KTHl0VHb909F5PP2AOg/0SGQc08QaJ`25Jf<0PVEL07iO
E01lF4`0N59507MAA01hE4P0NEM<07YKD01kGU@0O65H07eUG01nJ640P6aU085`JP23M6h0Q7Qc08Ik
M`28Og/0RX>008^6Q1P0oooo0400NH:307^5Q`1nRH/0PHf?08>@T`26U9P0R9RL08^LX02=X:@0T:BY
09:X[@2E[;40Ujnf09Zc^P2L]kl0W[_30:6ob02S`l`0Y<OA09o4c`2D^lH0U[_509Nka02J^l80W;c2
09jm``2P_L40XKfo0::l_P2S_;d0Y;fm0:Fm_02V_K`0YkVh0:Nf]@2W/[00Yjj]0:JZZ02UYZ@0XJ2N
09jJU`2JU900UHj90968P`2>Pgh0RWmh08QjL`26Mg00QGE^08AeKP23MFh0PWE_081eL01oMW40OWIb
07egL`1lMg@0NgQe07YiMP1jNGP0NGYi07QkNP1gO7`0Mgem6@3oool06`12H7@0AFAh04QWO01;Jh40
CVn6055cR`1CMhl0EW^D05UoV@1LPih0GXRR066<Y`1TT:`0IiBb06VH]`1/WK`0Kj72076Ua`1cZ/d0
KZG806ZP``1/X/D0KZ?5072UaP1bYlP0M:[:07J/b`0207N]b`0807R]bP1h[/T0N:k907R/aP1hZ/D0
NJ[507VY``1iZ/<207Z/a@0I07ZZ``1hYl40MZBo07BR_@1bX;`0L9nk06nO_01_XKl0Kj?306jR`P1/
W;X0JINd06NC[P1TSZT0HHZS05j5WP1KPIT0F7bD05EhS`1BM8X0Cfn504a[P019J7`0AFAh049PL`0T
0?ooo`008P3oool0702GSh`0UXn=09B?S@2CShh0TXj>096>SP2?SXh0SXj?08f>S`2<SXl0RXj@08V>
T028SI00Qhf@08F=T024SI00PXb@086<T01oRi00MH>807R5R@1iQHT0NHB707R3QP1hPXD0N86307Mn
O`1fNg`207IjN`0R07MkN`1hNg/0NWem07]oOP1kO7/0NgYi07YfM01gKF/0MFET079NGP1_FEL0KEEB
06]AB`1YCDH0JDU106Q5>`1V?c@0I3X]068e:01T>B`0IShb06Q4>@1[BCl0KTm6079EC@1eFe<0NF5J
07eWH021KFL0QG9]08UhL`2<OWT0T8>009B9QQT0oooo0400SXf<092@S`2ATY80TYFE09>HV@2DVY`0
UIfO09NPXP2HXZD0VJFY09ZX[02KZjl0W:fc09f`]P2N/kT0WkFm0:2h`02P^/<0XKg709:b_02A/;X0
TZnh09>_]P2E[k@0UZnd09R_/`2I[K00VJ^/09VZZP2JZZX0VZZY09bYZ02NZ:L0WjJV09jQX02NWY`0
Wi^I09bCT@2JS8X0UHB2091mNP2<Mg80Qg1Y08AZHP21I5/0OemD07aHC@1iDdL0MTi007MAA01hE4P0
N5M<07UKD01jGUD0Nf9I07eVGP1nJV<0P6iW089bK023MW40QGYe08MnNP29PWl0RhJ4603oool0@01i
PX<0O8J807n:S022SY40Q9:E08NFVP2:VYh0SInS092SY`2BYj`0UJ^a09R_]@2J];X0WKRo0:2la02R
`<T0Y<G>0:O9dP2Zc]P0WLC@09W0b`2J_/P0Vkk709joaP2P`<L0Xl;70:G2a@2U`<80Y/300:O0`02W
`;l0Z;fm0:Vj^P2Z]kL0ZK6a0:V^[@2Z[Zd0ZJ^Y0:RVY02TXIh0X9ZH09^ETP2GSXX0ThV40924O`2=
P7X0Rgae08UiL@26MFd0QWI^08EfKP23MFl0PWE_081fL01oMW40OWIb07egL`1lN7@0NgQf07YiM`1i
NWT0N7]j07MlO01gOGdI0?ooo`0L049PM016I7T0BFQn04a]P`1?LHP0DWJ=05EjTP1HOYL0Fh:L05j7
X@1QRjH0I8n/06ND/@1ZV;L0KIfl072R`P1cYlP0MJ_>07Vae@1g[m@0LJS<076WbP1bZ<X0M:W:07J[
c01i[/l0Nk7A07bbd080OK;?0280OK7>07b_b`1lZLD0O:G007bQ_@1kX;/0OJBo07jYa01oZlH0OZc6
07f[a@1kZ<<0NJK207NT`01eX[l0Lj:o07>S`@1cYL@0LZG5072S`P1^W[/0JiRe06RC[P1USZP0HHVR
05j4W01JOiL0EgZA05=fS01@LHL0CFf204UXO@16I7P0@f1d903oool00280oooo01`0Uhn=09J?S@2D
Shd0Thj>096>SP2@SXh0Shj?08f>S`2<SXl0Rhj@08V>T028SY00QhjA08J=T@24SI40PXfA086<T@1o
Ri40OX^@07F3R@1fQ8T0MXB807J3Q`1gQ8L0Mh>607N1P`1eOWl0LgUj0P1cN7X08P1aN7T0Mgmo07Yo
O`1mPX80OH6007akNP1jNGL0Mg=a07=[J@1]Geh0JeIE06QBD01WCTT0ITY406I7?`1UA3X0I3ld068i
;@1O<bH0Gc8U064h:`1T?S80Id@j06Y:@@1^D4P0LUM?07IMEP1jI5d0OfYT08=`J`27MW80Rgeh0923
O`2DRHDI0?ooo`1008j=S02@T900TI>C09:FUP2DVIX0UI^M09JNX@2GXJ@0VJBX09ZWZ`2KZZl0W:fb
09j`]P2O/kT0X;Jm0:6i`02R_<@0X[o809fla`2>[kX0TK2i09>a^@2D/;L0U[6g09Rb]`2K/[H0Vk2b
09V/[02JZj/0W:^[09NVY@2KYjL0WJFT09nUY02PY:80XJ2N0:6MV`2NUY<0W92=09F6P`2@O7T0RWEa
08I^J023J600PF=K07mOE@1mFDh0NUA807M?@@1fCCl0MU1307MDB01gEd`0N5]A07UOEP1kHe/0OFMP
07m/I@21L6X0PgA_08EiM027OGT0RH5n08^6PaP0oooo0400NH:407b7R01oRhd0Pi2B08JDU`29V9`0
S9fQ08nQY@2BYJX0UJZ_09N^]02J/kT0WKRn0:2la02S`LT0Y/G>0:W:d`2[cmT0YLcH09S0c02K`L/0
WL7;09o1b@2Q`/T0Y<C:0:O6b`2Ya/T0ZLC40:[3``2]`l<0ZK^k0:Rg^02Y/k@0ZK6a0:Va/02//:l0
[Jj]0:bXY`2/YZ@0Z::P0:>KV@2MUI80V8n:09B9Q02AQ7l0T85k08imMP2<Ng<0RWQ`08QfKP27MVh0
QGE^08=eK`21MFl0P7E`07ifL@1mMW80O7Md07]hM@1jNGL0NGYh07QkNP1hO7/0Mgem6@3oool0@013
H7@0AVEj04YZO`1=KX@0D7>:05AhS`1GO9@0FX6J05f5W`1QRZD0I8jZ06NC/01ZV;H0KIfl072R`P1d
YlP0Mjc>07^beP1g[m@0LZ[>07BZc@1eZld0MZ_<07R/c01j[ll0OK;C082ee@21]mD0P[OD08Bgd`22
[l/0OZG107bQ^`1jVkD0NYff07fR_01oX;`0PJ6k08>V`@24[LP0PZk907n/a`1lZL@0NZO207RT`@1g
Y<80MZG307JWaP1gZ/X0MZW907>T`P1`W[/0K9Rd06RB[@1TSJH0H8NP05f2VP1IOI@0EGR>055cR@1>
KX<0BVUn04IUN@13H7@T0?ooo`008P3oool0@02GShd0UHn=09B?S@2BSXh0THn>08n>S`2>SXl0S8j?
08^>T02:SY00R8jA08N>T@26SY40QHjB08>=TP21SI40OhbA07j=T`1bPhX0Lh>907B3R@1eQ8T0MH:6
07J4Q`1gQHP0Mh>607F0P@1bNg/0KWMh07J0P01eOgl0Mh6107V1P@1jP800O8:107eoO@1nO7/0O7Me
07QaK`1]I680IUME06A?C@1SBdL0HTM106=5?P1S@cX0HShd060i;@1N=2L0G30R05`b9P1N=b`0HShd
06I5>`1ZC4<0Ke=;07=JD`1hHEX0OFQQ085^J@26MG00RW]g08n2OP2DR8DI0?ooo`1008n=S02@TI00
TIBD09>FU`2DVY/0UYfO09NPXP2HXjH0VZJZ09^Y[P2L[;40W[2e09nc^@2Q][d0X[W10:>la02S_lP0
YL?<09>d`02?/;/0TK6j09Bb^P2E/KL0V;>i09Ze^P2M]KT0WK:d09b^[P2HYjL0VZNX09NSX`2KYJD0
WJFT09nTY02QYZD0XZ2N0::MV`2QVIH0X9FB09N:QP2>OGT0R7=_08A]I`21IUl0P69J07mOE@1nFdl0
NeI907U@@P1fC3d0MDe007A@@`1eDdP0MUM=07MLDP1iH5P0NfEM07eYHP1oKVP0PW=]08AgL`26O7P0
R85n08^5PaP0oooo0400NH>407f7R@20S8l0Q96C08NEV@2:VYd0SInS096TZ02DZ:d0Ujfc09Zb^02M
]kd0X;c30:C1b02Wa/h0Z/_C0:c?f02`e=h0XLSD09_1c@2M`/`0Wl?<0:73bP2TaL/0YlO=0:_9c@2/
b<X0[/K70:^n_`2X]kP0Xk6b0:Nb/`2Y/K80Zk:b0:fc/`2][J`0[:^Z0:fYY`2^ZJL0Zj>Q0:FLV@2N
UI80VXn:09J9Q02CQGl0TX9l0960N02?OGD0SGUa08]fK02:MVd0QgI]08AeKP22M6h0P7E_07meL01m
MW40O7Ic07]gM01jN7H0NGUh07QjN@1hNg/0Mgem6@3oool0<013HGD0AfIj04Y[P01>L8H0DWB;05Ei
T@1IOYL0G8>M0628XP1SSJP0IY:^06ZG]01]W;X0L:7107BWa`1h[<h0Nk7D07jef@1k/]H0MZc?07N/
c`1h[Ll0NJg>07^^c`1m/=00Ok?B08:ee026^=L0QK;@07jT`01kWkX0OIji07fL]`1mW[T0OIfi07fK
]@1lVk@0OYjg086S_P26ZL@0Qjk908>^b@20[<H0OJW507^W``1jY/<0NZO507ZZb080NZ_:00h0NJW7
07FT`@1`WKT0K9Ja06N@ZP1SRZ<0GhBL05]oUP1GNI00DgB:04m_Q@1;JWl0AfEj04=QM2@0oooo000R
0?ooo`1009N?S@2EShd0Thn>09:?SP2@SXh0Shj?08f>S`2<SY00RXj@08V>T@27SY40QXjB08F>TP24
SY<0PXjC082=TP1mRi40OHbC06aoQ`1`PHP0LX>807>4R@1dQ8P0MHF807J6RP1gQXT0MXB507N2PP1_
N7P0LWUj07AkN`1eNgX0MWel07QmN`1iO7/0NGMf07YfM01kM700O7=`07M[J01[GU`0H4m=05i7A01N
A3l0H4<l0652>@1Q?S@0GcT^05dc9`1K;b00FBlQ05Ta9@1L=bd0HD0f06I8?`1/CdL0LEM?07INE`1k
IEl0P6aW08EcKP29NWH0SX5m09>8QAT0oooo0400Shj=092AT@2BU9D0TiNH09FKW02FWZ00V:6T09VU
Z02JZ:`0W:^`09f_]02O/[P0XKJl0::i`@2T_LD0YL390:G2b`2T`ld0S:nl08n`^`2A/K/0U;:j09Jb
^02I];X0W;Nl09ng^P2N];D0W[2_09BRX`2GXj@0VJBT09^TX`2NYZH0X:JU0::VY@2RX9h0XYjL0::I
UP2QUi<0Vhf80962OP27M700PV]U081TGP1oHET0P5mF07mLD01lEdX0NU5307Q<?@1eC3h0LT`o075?
@`1cDdT0MEQ?07MME01iHUX0O6MP07i/IP21LF`0PgIa08IkM`28P7d0RhF3603oool0@01jPh@0OHR:
086=S`25TYD0R9NJ08bLX02?XJD0TjJ[09J[/02I/;H0W;Fk0:2j`@2S_lL0YlG=0:_;d`2_d=T0/=CM
0:oEg`2L`m00W<;>09o3c@2Qa<`0Y<C;0:O6c02ZbLh0[/S<0:g5a`2]`L80Y;Jh0:Jf^02X]kP0Z[Jg
0:bg^@2^^;T0/;Rh0;2d/P2`/[40[Zf/0:bYZ02XXYl0YIfJ0:2GT`2KT8/0UhV409F6P02DQ7d0U89j
099oMP2@Ng80SWQ^08agK`29MVd0QGA/089cK@20M6h0OgA_07ieL01lMW80NgMd07YhM@1iNGL0N7Yi
07QkN`1gO7dI0?ooo`1004=QM@17IW/0Bf^104m`Q`1CMXd0Eg^C05^0V@1NQZ00HX^V06F@[01YUK80
K9Zh072O_P1cYLD0N:_=07bbe@20]mX0OkOJ07^be@1i[]40NZk@07^]cP1l[Lh0OZo?082`d022/<l0
PZo=086/b`20Z/P0OjW7082XaP21YlD0PJO408:XaP22Z<D0PZS4086Xa01oYL80OJ6m07fR_023ZL80
Qk3:08F`bP22[<P0Oj[607jYa@1mZ/L0OJ_907f]c01m[/h0O:g=07ZZa`1eX[h0KiZe06ZC[@1USJH0
HHJO05b1V01HNi80E7J<051`QP1<Jh00AfIj04=QMB@0oooo000R0?ooo`1009N?S@2EShd0Thn>096?
SP2@SXl0SXj?08b>S`2;SY00RHj@08R>T@26SY80QHjB08B?T`24Si@0PhnD082>T`1gQhd0MHJ=06n0
R01_PXP0LH:807:2R01bPhP0M8F907J8S01gQh/0N8V:07Z9R@1dPh<0Lgio07=mO@1cNg/0M7]k07Ij
NP1fNWT0MWEc07MbL01fKV/0Mfi[07IXI01bHUh0IEEA05]6@P1K@Sh0GD4j05m1>01O?S@0GCT^05/d
:01J;b40F2hO05L_8P1G<RP0GC/a06=3>P1XC4<0KU=<07=KE01iHe`0OVYU08=bK@28NGD0SX1l09>8
Q1T0oooo0400Shj=096AT@2BUID0U9RI09FLWP2GWj80V:>V09ZVZP2KZZh0WJfb09ja]`2P];/0X[S0
0:Bla02W`LX0ZlK?0:C3c02I^/H0Rjjj08n`^`2B/[/0UK:j09Nc^@2J]K/0WKRm09je^02M/K<0W:f^
09JVYP2HYJH0VjJV09bUY@2OZ:L0XJNV0:>WY@2RXYl0XYjK0:6GU02PUY80W8j809N6P@2;NG@0P6UT
07iSG@1oHEP0P61F081MD@1nF4/0Ne9407U=?P1eBS/0LDXk06i:?P1`CdD0LeE;07EJD@1hH5L0NVEN
07eZI020L6X0PWE`08EjMP28P7`0RXF2603oool0@01jPhD0OXV:08:>T026TiH0RYVL08fNXP2AXjP0
UJV]09R^/`2L/kT0WkRo0::na@2V`l/0Z/WA0:o@f@2ff>80]MWS0:O>fP2H`<d0WL;=0:74c@2TaLd0
Y/G<0:W6c02/b<d0[<C80:Vm`02V][T0Xk:d0:Rd]P2[]kP0[KRi0;2l_02b_;`0/kbk0;>h]`2c][D0
/Jn]0:n]ZP2[YZ80Yj2L0:6IU02KShX0V8V409N6P02GQWl0UhAl09F0N02CO7<0TGU_08efK029M6X0
Q75Z089bJ`20LV`0Og=^07idK`1lMG40NgIc07YgM@1iNGL0N7Yi07QkN`1gO7dI0?ooo`0Q04AQM@18
Ig`0C6b2051bR01EN8l0FGfF05f3W01QR:80I8jY06RC[`1/V;D0Kifl07:S`P1fZ<T0NZoA08:ig@27
`>H0O[KK07N]d01j[]00O:o@07j`d01o[ll0P:o>086^c@20Z/L0OZ:o07ZK]`1kW;P0P:>o08:V``24
ZLL0QJg:0080QZk;01d0Q[3>08J`c@25[<X0Pj[7086Ya020Z<<0QJg708N`b`24[/T0PZc8086/b020
[<T0P:g;082^c01o[lh0OZk=07^Zb01hY<40LYfh06fE/01XSjP0HhRQ05j2VP1JO9<0EGN=055aQ`1<
K840B6Ik04AQM@0T0?ooo`008P3oool07P2FShd0UHn=09>?SP2AShh0Shj?08f>S`2;SXl0RXj@08R>
T@26SY40QHjB08B>T`23Si@0Pi2E08BBU`26U9/0NhbB06n3RP1`PXX0Kh:906n3R@1`PXT0L8>907:5
RP1dQh`0M8F807:1P`1cPX@0LX:207:1P@80Lh200200M86007IoOP1fOW`0MW]i07IgL`1dL6d0M6eY
07=XH`1aHEd0JeYE05i:AP1I@Cd0Fd0j05e0>01N?S@0GCT^05Xd:01I;b80EBXL04hW6P1C;R<0FCH/
05m0=P1UB400Je19075IDP1fHEX0O6QS089`J`27N7<0SH1l09>7Q1T0oooo0400Shj=096BTP2CUYH0
U9VK09JMW`2HXJ<0VJBW09^X[02LZk00WZne09nc^@2Q]kh0Xk_20:Foa`2ZaLh0[l_E0:70b`2=/Kd0
SJnk092a^`2C/k/0UK:j09Nc^P2J]K/0WKNl09fc]`2J[:h0VZZ/09VYZ@2KZ:P0W:NX09jXZ02PZJT0
XZVX0:>WY@2SXj40XijK0:6HU@2NUI00W8j809N6P02@O7H0PV]V07iRG01oHEP0PF5G085NDP1oFD`0
O5A607Y?@01hC3`0K4@f06]6>P1]Bd00L59707=GCP1fGED0NF=K07aYHP1nKVP0PGA_08AiM@27Og`0
RXF2603oool0@01jPhD0OhV;08>?T@27UIP0RiZN08nPY02CYZX0Uj^`09Za]P2N][`0XK_20:G1b02X
a/h0[<cE0;7Cg02gf^@0[=7L09_3c`2K`Ld0X<C=0:?5c@2VaL`0ZLG;0:_7c02^al`0[/C70:^m_`2Z
^K/0Z[Ni0:bf^02]]kP0[kRi0;6i^P2d^KX0];Rh0;Fe]@2d/K00/jj]0;2]ZP2]Yj<0ZJ6M0:>IU@2K
SXX0VHR409V7P@2IQh00VHEl09R2N@2EOWD0U7aa09AkL02:LfX0Q6mX089`J@20LFX0Og9/07ecKP1l
M700NgEb07YgM01iN7H0N7Uh07QkNP1gO7`I0?ooo`0S04ARMP19J7`0CFj3059cRP1FNI40Fh2H05n5
W`1SRjD0Ii6/06^F/`1^VkT0LZ6o07FVa@1hZ//0Nk3B07nef01n]=P0NJgA07V[cP1l[]00Ok3?086`
cP22[lh0Pjo=08B^b`24[<T0PjW5086T`022X[h0Pj:o08BS_`25Y<40QZG208NVa027Yl@00P28Y/@0
6`27ZLL0QZ_708BZaP22ZLH0PJS408B[aP26[/T0QJk908B]b@23[/X0Pjk<08>`c@23/M00Q[KE08:a
d01jY/<0MInk06nG/P1ZTJX0IHZS0624W01KOYD0EWR>059bR01=K840B6Mk04AQM@0T0?ooo`008P3o
ool05@2FShd0U8n=09:?SP2@Shl0SXj?08b?T02:SY00RHjA08N>T@25SY80PhjB08:>T`22Si@0PY2F
08FDV@2;VIl0QIBI07F7SP1`PhX0KX:906f3R@0206j2R@050725RP1bQh`0LXF906inP@1^OGl00P1_
OWl08P1`OWl0LGio079oO`1cOWh0Lgak07=iM`1bMG80LG5^06m]J01^JF@0KFAO06]NF01TE4h0G4M2
05Y2>`1L@3T0GChe05`j<01J=BX0FC4U05T_8P1:91P0CRXO05Dc:@1L?3<0HTDl06Q>AP1^ETl0M5iH
07]WH@20KfX0QWMb08aoN`2BQh@I0?ooo`1008n>S@2ATY80TiJG09FJW02GWZ00V::U09ZVZ@2LZZh0
WJfc09na]`2P]K`0XKS00:>la@2U`LX0ZLK?0:[8d`2M_/T0T;:n096b_@2B/[`0U;:j09Jb^P2H/[X0
V[Fk09ff^`2M/kL0VJ^]09VYZ`2JZJX0VjVY09fXZ@2OZJT0XJZZ0:>ZZ@2TYjH0Y:BR0:>OW02QVYH0
WIF?09Z=R02FQGl0Sgae08M`J@20IEl0P69I085QE`22Ge<0P5Y>07eEA`1lDD80O4hn06Lo<@1X@SH0
JTPl06i>A01aED/0M5]B07MQF@1jIf00OFeW085cKP24NG@0Qgik08Z4PQP0oooo0400NhB507n:S024
T980R9JI08fLX02AXZH0UJR/09V^/`2M/kT0X;Vo0:BoaP2Wa<`0Z/WB0:g>e`2_dm`0Zm7M09k6d`2I
`<d0X<?>0:?5cP2VaL`0ZLG<0:_5b`2]a//0/<K;0:o4a`2]_L00[[bn0:jk_02`^[/0/KZk0;>k_02e
_Kd0]kbm0;Rj^P2h^;L0]kBc0;Ja[P2c[:T0[jBR0:VMVP2SU900W8b709V7PP2JQh40W8N009b6O@2J
PgT0V7me09MmLP2FNfl0QViT08=]I@21KVH0OfmX07i`JP1mLV`0O7=_07]eL@1jMW<0NGQe07QiN01h
NgX0Mgal6@3oool06@14HWH0BFQm04i_Q01CMH/0F7^C05b1VP1QQj40IHjX06ZD[`1^VKH0LInm07FT
``1gZLT0NJc>07V^d01bYlX0K:7507>WbP1l[]00P;3@08>_c`24/<h0QK3=08J^c027[LX00P27[<P0
1P28ZlP0R:W608VXa@29ZLD0RZW608^[a`D0S:_801X0S:W708VVa025Xkl0PZ2k08:Q_025Yl80Qjc8
08N^b@26[/X0QZo;08F_c@25/Lh0QK3=08>^b`1mZ<D0Mj2k076I/`1/TZ`0IXbT0665W@1LOiH0EgV?
05=cR@1>KH80BFMl04ARMB@0oooo000R0?ooo`1009J?S@2DShd0TXn>092?S`2>SXl0S8j@08Z>T027
SY40QHfA08>=TP22SI80P8fC07n>U01oSiD0P96G07n?UP1kS9<0LhJ>06j2R@1[P8P0Jh6806^2R01/
PXT0KHB:06n5R`1_Q8P0K7j106YiO01[NW/0K7]m06elO@1^O7d0Kgin075mO@1aNWX0L7Ie06mcL@1^
Kf`0JfYW06UUH@1XGe/0IEYD065BC01MBTD0FdDn05]2>P1L?cH0FcXa05Tf:`1I<bH0F30R04LR5`1;
9ad0DC0V05Pi<01O@ST0IT]306aDC@1cG5H0NFEO07m]J025MW40S7ij09:7PaT0oooo0400Shj>096C
T`2DUiP0UY^M09NOXP2IXjL0VjN[09f[/02N[kD0Wk>i0:6g_P2R^/80Xkk70:C1b`2UaLl0X/;>09fm
b02F]/40Tk>m09>b^`2E/[X0U[:j09Rb^@2J];X0W;Fk09bc]`2J[K00VJRZ09ZXZ@2LZJT0WZVZ0:2Z
ZP2RZj/0Y:^Z0:FXY`2UY:80Y:2L0::JUP2MThl0VHb609B4O@2>Ng@0RG9[08=YHP22IE/0PV=I08=P
E021Fdl0OeI807iB@`1mCch0ICd_06@o<P1XACT0Jd]106mBB01bF4l0MUmG07UUGP1lJfD0P75/08=h
L`26OWX0RXB1603oool0@01kQ8H0P8^=08FAU02:V9X0SYjQ09>TZ02GZZl0W;2f09nf_02S_<<0Yl;9
0:[7c`2/c=D0[]7K0:kDg`2[dMd0YlcG0:G7dP2Ua]00YlK>0:W6c02/a//0[/G;0;36b`2aal/0/LG8
0;71``2a_/00/[fn0;>m_P2e_[h0]kjn0;Vo_`2k_kl0_;jm0;bk^@2k]kD0^[>`0;F]Z@2aYZ80[9nK
0:JGT`2QT8/0WHZ509f9P@2NRH00WXQn09b4NP2JP7H0VGib09UlK`26KF80PF]Q081/I01oKVH0OVmY
07eaJ`1lLVd0NgA`07YeLP1iMgD0N7Ug07QjNP1gO7`I0?ooo`0M04ERMP1:JGh0Cg2505AfS@1IOID0
GX>L06>:Y01XT:/0KINc076M^P1eXl40N:S807^]cP1l/=<0O;;F07Z`e@1j[]00OJo@08:bdP25/m80
Qk;@08RacP2:/<d0R[3<08Z_bP2:[/X0S;3<08facP2=/<`00P2>[/X08@2?[/X0T:k:092^b`2A/<`0
TK7=09:`c02A[l/0T:k:08f/a`2;ZLD0RJO208NV`P27Z<80R:_508V^b029[lX0R;3;08N`c027/<d0
Qk7>08B^bP1nZ<<0NJ6l07>J]@1]Tjd0J8fU06>6WP1NP9L0F7Z@05=dR@1>KX<0BFQl04ARM@0T0?oo
o`008P3oool0@02FShd0U8n>09:?SP2@Shl0SHj@08^>T029SY40QXjA08B=TP22SI80OhbB07f<T`1l
S9<0NXbC07R<U01fRI00LXB<06j0R01YOXL0J7f506QnQ@1XOhH0J82706V1R01[PhT0Jh6706YnPP1X
N7/0J7Mi06UhNP1ZNW/0K7Uk06ekO01^O7`0KWUj06ieM@1]L700K6e[06UXI@1VHel0I5eJ069HD`1O
DT`0G4Y505]6@01J@c`0Fd0g05Xk<P1J=bd0FSDX05/b901581@0AR<H04h/8P1E=R`0G3lg06=9@@1Z
DTX0LE]D07MSGP1nK6L0QGE`08]nNP2BQX<I0?ooo`1008n?SP2BTi<0U9RI09JLWP2HXJ<0VZFX09bY
[@2N[K80Wk6g0:2e_02Q^L00X[c50:>ob@2S`/d0X/?@0:30c02L^lH0V;K009Bc_@2D/KX0UK6i09Ja
^@2H/[T0V[>j09^e^P2L/kL0W:nb09ZYZ`2JYjP0W:RY09nZZ`2QZZX0Xj^[0:F/Z`2VZJP0YZFS0:BO
W02QVYH0W9:>09N;Q@2BPWd0SW]d08UcJ`25Jf80Q6QN08AUFP24HED0PUa?081GB@1oE4@0P55006<l
;@1Q?2l0ID8f06U8?@1/CdD0L5I=07AME@1hHe`0NfYT07m`J`22Mg80QWej08Z4PAP0oooo0400NhF6
086;S@26TYD0RiVL092PX`2EYZX0VZfa09jc^@2R^[l0Y/360:[6c@2]bm<0[m3I0;7Dg`2ae^80/=CO
0:kAf`2/c=D0Z/WA0:_7cP2]ald0[lO<0;77c02bb<`0]<S<0;C6b@2d`lH0]<310;Fo`02g`<00^<71
0;_1`@2l`L40_l;10;o0_P2o_K/0_[Ve0;^d/02f[JT0/ZJQ0:fOVP2XV9<0Y9:<0:6=QP2PS8<0XH^2
0:28O`2NQ7X0Vh5f09YnLP2JO6l0QFaR085ZH@1oJf80OVaT07e^I`1lKfT0O75/07]cK`1jMG40NGMd
07QhM`1hNWT0Mgal6@3oool08@15HgL0BfYo051aQ`1FN8l0FgnF0666WP1VSJH0JiB^072J]P1eXKh0
NJO507f]c020/]<0P[OI08>ig024^Md0QK[M08NifP28^=H0R[OE08bfd`2=]M40S[C@08ncc`2?/ld0
Sk;=092bcP2A]=00T[GA09:dc`2C]<l0U;C@09Bcc`0209FccP0M09Jdc`2E]<h0U;;=09:ab`2A[/P0
SZ_508bY``2;ZL<0RZ[308^/aP2<[lP0Rjo908V_b@28[lX0QZo:08J_b`26/<d0PJ_807^S_`1eW;H0
KiF^06V>YP1TQil0Gh6H05UkT@1DM8X0Cfj304YXO015HWH0903oool00280oooo0400UXn=09B?SP2B
Shl0Shn?08f?T02:SY40R8jA08F=T@22SI80P8bB07f<TP1jRi80N8ZB07J9TP1cQi00L8B=06b0R01Y
O8@0IW^306EjPP1TNX80I7b306EmQ01UOXD0IX2606MoQ@1WOH80IGQl06AdM`1VMWP0IgUk06UiN`1[
NG/0K7Yl06ahN@1/MGD0JW1_06U/J`1VIV@0Hf1N061KF01OEe<0GE9>05]<A`1JB480FD@m05U0>01I
?3<0FCP^05Xf:P1N=BL0BB<G048N4`1::1h0DS<Y05Xm=01QASh0J51906mIDP1fHU`0OF]V08AdK`2:
OGT0THJ36@3oool0@02@Shh0TYBD09FIV@2GWIl0VJ:T09^WZP2MZjl0Wjnd0:2c^@2R]kh0X[_30:>n
a`2S`L`0XlC@0:73cP2O`</0Vk[409Nd_@2D/[/0U:nh09F_^02G/KP0V;:h09Vc^@2K];T0W;:g09b`
/`2KZjd0VjNX09fXZ@2OZj/0XJZ[0:>[Z`2V[J`0YjZX0:JVX`2TWi`0XIZF09bAS@2GRH@0TH5k08ek
L`2:Lf`0QfeT08IZH025IU`0Q69F089MD020F4X0OeA5085C@P1W?c00GCPZ068n<P1VACX0JTe206mD
B`1cFe<0MV9J07YYHP1nKfX0PWIb08ImN@29Ph4H0?ooo`0=07b5QP21S8h0Qi>F08fKW@2BXZD0UjV]
09b`]02Q][`0Y[g30:[3bP2]bM40/<oG0;?DgP020;CIi00a0;GHh@2bdm`0[lgE0:g;dP2_bLl0/<S>
0;;8cP2dbLd0]LW=0;O9c@2gal/0^<K80;S3a02h`<40^/710;c2`P2n`/40_l?10<;4`P32`[l0`[jk
0;ni]@2m]K00^:jY0;BWX@2^WiT0ZYVB0:JCS02TShL0Y8j50:B<PP2RRGl0WhEj09b1MP2IOG80VGa_
08M^I020J5l0OVUP07eZHP1mK6D0O6iX07]`J`1kLVh0NWA`07UfL`1hN7H0N7Yi07MlO00I0?ooo`0O
04ESM`1;Jgl0DG:805MiT01MPIP0HhRQ06V?Z@1^Uk40M9jj07VU`P1m[<X0PK;B08Fhf@28_N00R/3T
08c1h`2=`>80S;kN08fmg02?_=T0TK[G09:jeP2C^MD0U;SD09BfdP2D]M40UKGA09Jgd`2G^=@0UkOC
09Nfd@0309Rfd00N09Vfc`2I]Ll0V;G>09Ndc@2F/l/0U;3909:^aP2@[<80SZ[108jZ`P2?[LH0Sjo8
08f_b02;[lP0RJk908J]b023[<P0Q:o<08>^bP1lYL00MYfg072E[P1[SjL0IHRO0622V01KNi40EGF:
051_P`1:J7`0AF9f903oool00280oooo01H0UXn=09B?SP2AShl0Shn@08b?T02:SY40QhjB08B=TP21
SI80OXbB07Z;TP1gRY80M8RA0767T@1]PX`0JWn806EiP`1SN840HGR0065gO`1PMgl0HGR00P1QNX80
:01RO8<0Hgb306=kP@1RMg`0HG=g069dM`1TMWP0IWIi06QgNP1ZN7X0JWIh06UbL`1WKVh0IFYY069T
H`1PGe`0G5UF05]DD@1JD4d0FDa805Q9@`1GACh0Ed0i05Ll=01G>Bl0FCL[05lh:`1F;R00Ab4E04DR
601@<2L0F3/b05m4?01VCTL0KEMA07AQF`1kJVD0Pg=_08YlN02AQX8I0?ooo`10092?SP2CU9@0UIZJ
09ROX02KXjH0WJR/09n]/@2Q/KL0X[Jl0:>j`@2T_LH0Y<7:0:C4cP2Sa]80XL;>09nobP2I]/00UK:k
09B`^@2D[[L0UJng09J`]`2H/KP0VK:h09Zb^02K/KL0WK2d09^/[P2KYjT0WJRY09nZZ`2RZj/0Y:b/
0:N][02XZjT0YZFS0:BOW02PVID0Vi6<09J9P`2@P7X0S7Yb08YdK029L6L0R6aR08IXG@24HeL0PUiA
07mHB`1mE4D0OE5206i4=@1P>2X0GCP/06A2=`1YBT00KE98075ID@1eH5T0NFMQ07e^J@21MG40QGai
08V3PAP0oooo0400O8F708:=S`28UIL0SYbO09BTY`2JZjl0Wk:g0:Bj_`2Y`LH0[/O>0;7>e@2ee=`0
]mWS0;WNj02jgNH0^M_T0;GBfP2acM@0/L_B0;;9d02db/l0]/[?0;O;c`2ibll0^/_>0;_:c02lb<X0
^lG60;_2`P2m`l<0_lC40<75``33a/@0aLK40<K5`P35`;d0`k^f0;ne/02k[ZT0]ZNQ0;6PV@2/VY80
ZYF=0:VBRP2XT8L0YXf30:B:P02QQW/0W85f09QlL02BMf`0QFeS07mWG@1lIE`0O6QO07a[H`1lKFH0
NfmY07]aK@1jLg00NGEc07QhMP1gNWT0Mgal6@3oool07@16I7P0C6^0059cR@1INi80Gh>J06F:X`1/
TZ`0LYZe07NR_P1mZLH0P[7?08Nhf02;_n00SlGV09;8jP2DbN/0U<GV09?2h02D`=h0UKoM09Jog02G
_]X0V;kJ09Vnf@2J_=L0V[_E09Zje02K^]@0Vk[F0080W;_F0240W;[E09fje02M^]@0W[_D09jjd`2M
^M40W;K?09Zdc@2H/l/0Uk7809B^a@2C[L<0Tjk509>_a`2B/<P0T;3908j`b02:[/L0QJ_507fU`@1i
Y<40Oj[607jW`@1fW;H0LIJ^06b?Y`1WRJ00HH:I05alT@1FMHX0D6n404]YO@15HWH0903oool00280
oooo0180UXn=09B?SP2AShl0Shn@08b?T@29Si80QXjB08>>T`1oSI<0O8bC07R;TP1dRI80L8NA06b3
SP1WOHP0HgR305idOP1KM7h305adO@0[05aeO@1MMWh0GGIo05egO`1NMgl0GgMm05meN`1NLgL0H7=f
065dM`1SM7L0IGEh06MeN01WM7H0IVma06A[K01QIVL0GV9Q05]LF`1IEU@0Ee=@05I>B`1FBdL0ETM2
05E3?@1D?cP0E3/c05@g;P1E=2X0Ec@Y05H`901B:ah0C2TO050`9`1F>C40GD8k06A<A@1[ETl0LUmJ
07YYI022LVh0RGah0965PP0I0?ooo`10092@S`2CUID0UY^K09VPXP2LYJP0WZZ^0:6_]02R];T0Y;Ro
0:Fla02V`<T0Y/C>0:G7dP2Tam<0XL;>09fjaP2F/K/0Tjni09>^]`2D[[H0UJjf09J_]P2H/;L0VK6g
09Za]`2K/;H0W:nc09^[[P2KZ:X0WJVZ0:2[Z`2RZj/0YJf/0:R][02YZjT0YjFR0:BOV`2OV9@0Vi2;
09F8PP2@OgT0S7Yb08]eK@2:LVT0RFiS08IYGP24I5P0PEiA07eHB`1jDT@0Mdi006m5=P1T>R/0GCP[
06=1=@1XBCh0K516071GC`1dGeL0N6IO07a]J020M700QGah08V3P1P0oooo0400OHJ708>>T02:UYP0
T9jQ09JVZ@2M[[40X[Fj0:Rm`P2]a<X0//cB0;KBfP2jfN40_N3Y0;oTk@2oh^X0_=[R0;O@f02ecM@0
]L_B0;K;d@2gc=00^LgA0;_>dP2lc]40_Lk@0;o<c`2ob//0_/K60;k4``30aL@0`/O50<C7a@36bLH0
bLW60<[7``38`[d0a[fh0<:f/@2n/:X0^:RQ0;>PV@2`Vi<0[YR@0:fFS@2/U8X0ZI660:J<P@2RQg`0
WH9f09MlL02AMV/0QVaP07]PE@1fGUD0NfIM07aYH@1lK6D0NfiX07]aK01jLfl0NGEb07QgM@1gNGP0
Mgak6@3oool0@016I7P0CFb105AdRP1JO9<0HHFL06R=Y@1^UJl0MIfh07^V`@22[//0R;KD08fngP2B
anP0Ulk`09[Bl`2Kcnh0VlWW09[5i02J`n40Vl?Q09c4h02Ma>40W/CP09o4g`2P`mh0X<;L0:30fP2O
_]L0WkgG0:2nf02P_mT0XKoI0:70f@2R`=T0X[oH0::neP2R_MD0XK_C0:2id02N]/`0Vk?909Zab02I
//P0V;?909NdbP2F]</0U;C;096bbP2=/LT0R:g608:X`01jXKX0M9Vc07BI/P1fV[<0LYJ^06f@Y`1X
RJ00HX>I05elTP1GMX/0DFn404]YO@15HWHT0?ooo`008P3oool04`2FShd0U8n>096?T02>Si40S8nB
08V?TP25Si<0PXjC07j=T`1jS9<0MXZC0769TP1/Qi80Ih:>069lQ`1LLgl0FG1j05M`NP1GLG/00P1H
LG/205QbN`0Y05UbN`1ILg/0FW9k05YbN@1JL7L0FVme05a`MP1OLgL0HG=g06=eN01UMGP0IG=e06=^
L01QJF/0GFAU05]OH01HFUX0EEED05AAC`1BCDX0DdY60596@P1A@Sd0D3hh050i<`1?=Bh0Cc4Y04l`
9P1=:Ql0BR@H04/X7P1>;bD0E3L_05]1>@1RBT<0JEA>075NF01iJ6<0P75]08QkM`2@QH806@3oool0
@02AT8l0U9JF09NLW02KXJ<0WZNZ0:2//02S/KH0YKJl0:Jk`P2W_lL0Z<C=0:S7d@2Wb]H0YLSD0:71
c02J]L00Tjjh096]]`2B[KH0Tjff09F^]P2F[kH0Uk2g09V`]`2J/;H0Vjne09Z]/@2KZZd0VjRZ09fY
ZP2PZj/0XZ^[0:F^[@2Y[J`0ZJ^Y0:NUXP2TWY/0WiJC09Z?RP2DQh00T7mi08ejL`2;MVh0Rg=Z08U_
I@26JUl0PfAH081NDP1lF4/0Me5307==?P1/@c@0HcPY068k;@1T@3@0IdLl06]>A@1_ETd0LeeF07MU
GP1kK6L0P7A_08AkN029Ph0H0?ooo`1007f6R024Si40RiNI09:PXP2IZ:/0X;2d0:Ji_@2/`LD0//S>
0;O@eP2lf=h0`=kV0<?Uk@34i^h0`n3X0;kFgP2hcmH0]/gC0;S=dP2icM80^lkB0;g?d`2nd=<0`=7C
0<7@dP32cm00`Lc=0<79b031alD0`lO50<G8a@36b<D0bL[70<c:aP3=b<<0bl>n0<Vn^034]k40`;2X
0;VXX02fXYX0]9jF0;:LTP2bVXl0/9N<0:bCQ`2YSX80Y8Um09n3M`2IO700TgQ[08Y^HP21I5P0OVAI
07eVG@1mJF00O6]T07]^I`1kL6/0NW9^07UdL@1hMgD0MgUh07MkNaT0oooo0180AVAh04i]PP1EMH/0
G7jD06>6WP1ZSjP0LYRa07VQ^`20Z/D0Qk;?08fkf@2Da><0VLc/09kBl@2Qd_40XLo^09o;jP2ObNL2
0:38i00<0:79i@2SbND0Y<[V0:G:i@2Vb^D0Y/WS0:G7h02UaMd0YL?L0:G2fP2T`MT0Y<7H0P2U`MT0
7P2V`MP0Y/3H0:JoeP2U_]@0Xk_@0:6gc02O]//0WkK<09ngc02N]ld0WKS>09^gc@2I]ld0U[K;09:c
bP2>/<L0RJg508>X`@1nXk`0Nj2h07RL]01dUjh0Ki6W06Z:X01TQ9T0GWfB05QfR`1BL8@0C6Um04ER
MR@0oooo000R0?ooo`0E09J?S@2DT8l0TI2@08n@T@2<T980RI2C08F?U021SY@0OHfD07V<U01dRi@0
KXRB06R5T01QP8/0FWR405A_N`1AJgL0DFag059]N01CKWT0E6mi00<0E6mh02P0E6ig05A]MP1DKGD0
EF]c05I[L@1HKG<0Fg1d05ibMP1QM7P0HgAh06AaM01RKG00GfQZ05]SI01GGEh0E5MG055BDP1@CTd0
Cd]904i8A@1>AD40CD4l04`m=`1;>380BS@]04T_9`19;BD0AbHL04<P5@158aT0Bb/R054e;@1H?SL0
GdQ206MBC01_G5L0MfIR07m`K028NgL0T8F16@3oool0@02AT900UING09VMWP2LXjD0WjV[0::^/P2U
];T0YkVo0:Vna@2Z`l/0ZlOA0:_;eP2Yc=L0Y/SC09nnb@2F/K`0T:^f08n[]02AZk@0TZfe09B^]P2F
[kH0V;2g09R`]P2I/;D0VZjc09V[/02JZ:`0VZNY09bXZ@2OZZX0XZ^[0:J^[@2Z[Zd0ZZ^X0:RUXP2T
WYX0WiJA09V>R@2DQX00T81i08ikM02=N6l0RgA[08Y`I@26Jf00PfEI07mNDP1kEd/0ME12075<?P1Z
@S<0HcTY064i;01S?c80ITDj06U=@`1]E4/0LEaD07ISG@1jJfH0Og=^08AkM`28PX0H0?ooo`1007j7
R025T940SIVK09BRY02LZZd0Xk>g0:Zl`02`a<T0]lgB0;cEf`32gN@0anG]0<[Yl@3;inl0amoW0<3D
g02jc]D0^LkC0;[>d`2lcm<0_]3D0<3Be@32dmH0a=?E0<GCe035dM80aLo>0<G;bP34bLL0aLW60<O9
aP39b/H0c<c70<o<a`3?bL@0c/Bn0<Zn]`36]k00`K2X0;fZXP2kYYd0^J:H0;NPU@2fWI80]9V>0;2E
R@2/T8@0Z8Yn0::4N02LOW40UGU]08e`H`26J5`0PVMK07mWG@1nJ5l0OF]S07]]IP1kKfX0NW5]07Ud
L01hMW@0MgUh07MkNaT0oooo0200AfEi04i]PP1FMX`0GWnF06F8X01]TJX0MI^d07bT_P24[LT0S;OC
09?1g`2Kbn/0X];c0:ODm@2Ye?<0Z=7`0:K?k02UcNX0YLcX0:K<j02WcNT0Z<oZ0:[@k02[dN`0[=7Z
0:c@j@2/c^H0Zl_T0:[9h@2Yaml0ZLGM0:W4f`80ZLCJ00D0ZL?J0:W2f02Y`ML0Z;oD0:NmdP020:Jl
d@0G0:Fld@2U_M80Y;gB0:>ld@2Q^m00W[[@09bhcP2H]/d0U;C:08nab02:[LD0Qjc408>X`01mX;L0
MiV`076BZ01[Rj40IHFJ05mnTP1IMh/0DW2404aYO@16HgH0903oool00280oooo01D0UXn>09B@S`2A
T940Si6B08bAT`29TI@0QI2E086?UP1mSYH0N8fF07>;U@1/RID0I8:=05UiQP1?L7d0BFQf04UWM01;
J7@0CFYe04m[MP1@K7L00P1AKGL0:@1@K7H0Cf]e04iYL`1?J740CfM`055XKP1DJW00F6eb05]`M@1N
LgL0HGAh069aM01OK6l0G6IX05UPHP1DFU`0D5EF04i@D01<C4/0BdU704Y6A01:@d00BD0l04Pl=`16
=c40AC8/04<]9P12:R80@28I03lN50107A<0ARPO04db:P1D?3D0G4I006E@B`1]FeH0MFEQ07i`K027
NWH0T8B101T0oooo0400TI6@09JGU`2JWYl0WZBV0:6[[@2U/KD0Z;Nk0:Zl`P2/`/T0[/O?0:o;e@2`
d=/0[LkH0:O6d@2K^LD0Sjbh08bX/`2=ZK80SjZc096/]@2D[[H0UZnf09R`]`2I/;H0VJnd09V//@2H
ZJh0V:NZ09RUZ02KYZP0WZRY0::[Z`2W[Zd0ZZj]0:^[Z02XYJ80Y9fI09nET02ISXP0UHN109:1NP2?
OGD0SWQ`08]eJ`29L6H0QV]P08=UF@1oGe80NUQ;07AA@`1`C3l0JD4b06<j:`1N=BL0HC`_06A3>01W
Bd40Je9:071JDP1dHU/0NFYT07ibK@23NWH0R89o603oool0@01nQhP0QY6B08jJW02FXjH0WZf_0:Jf
^@2^_l<0]LS<0;cAeP32f]l0bN?Y0<o/l`3DkoD0e>_a0<cPiP31e=X0^lkD0;_>d`2lcm<0_]3D0<7B
eP34e=H0a]GG0<SFeP39eMD0bM?C0<S?c`37c</0al[80<O9aP39b/H0c<_70<o<b03Ac<L0d/W40=35
_P3=_kP0bKRa0<FcZP32[Z@0`:VO0;jVV`2lXiP0^YnD0;NKS`2cUhX0/9640:^<O`2UQWT0Wh1c09Ul
L02ALVH0RVaO08=VFP20IU`0OVQN07eZHP1lK6D0NViX07YaK01iLg00N7Ic07MhM`1gNg/I0?ooo`0R
04MUN@1?KX<0EgN=05n1U`1WRZ40L9B/07RM]P20Yl40RK7<096ke`2Ja^<0Xm7`0:cKnP2dgod0]Mgi
0;7Gl`2]dnh0Zm7/0:[@k02[dN`0[=7]0:gBkP2_e>h0/MG_0;?Fk`2ceNd0/]?Z0;7@i`2`cND0[/_R
0:g8g`2/amd0[<GL0:g4f`80[LCJ00<0[L?I0:c2e`2/`]H00P2/`]D05`2]`]H0[<;F0:_1e@2Y`=@0
Y[kB0:Bld@2Q^m00W[[?09ZhcP2G]lh0T[C<08fabP27[<@0PJ>i07ZK/@1dU:T0KHbQ06N5VP1POY<0
FWN;05=`Q01=JWd0AV=f02@0oooo000R0?ooo`1009J@SP2DT900TY6B08nBT`2<TYD0RI:F08JAU`21
T9L0OHnG07R>U`1bSIP0KHbH06B3S`1EMX@0B6]j03eQL011HW00AFEb04QWM01;JGD0CF]f04i/M`1>
K7H0C6]e04]YM019IW00B6=]04URJ`1<Hf/0CfI]05AZL01IKW@0GG9g05mcM`1PL7@0GF]^05YUI`1E
GV00DEQJ04eCE01:CTh0AdY:04I6A@15@d40AD0n04@m>P13>SD0@SHa040a:`0n:bD0?BTR03TO5`0h
71<0>QT@044T7019;bP0DCTc05U4?P1RCdT0JeUE07ATH01mKf/0QWUf08n4PAT0oooo0400TY6@09NH
V02KWj00X:JX0:B]/02X];L0ZkZn0:k0a@2`aL`0//_C0;?@f@2eeN40]=7K0:O4cP2G]L40QjJc08NT
/02:Y[40SJRb092[]02D[KD0Ujnf09V`]`2I/;H0VJnd09R//@2FYj`0UJBX09JSYP2IY:D0WJNW0::Z
ZP2W[Zd0Zjj]0:b[Z02YYJ80YIjI09nET02KSXP0UXV209>2N`2@OWD0SWU`08]dJ`29L6H0QV]P089U
F@1nGe<0NEQ;07AAA@1_CD00Id4b060j:`1K<B<0GST/0651=@1UB3l0JE1806iHD@1cHEX0N6US07ea
K@22NGH0R89o603oool0@01oR8T0Qi:C092KW@2IYJL0XJnb0:Zi_02b`lH0^/c@0<7FfP39gn@0cnS]
0=Oam`3Ml_L0f>[^0<gOh`2odML0_<gC0;c>dP2ncm<0`=7D0<CCeP37eML0b]OG0<cGe`3=emH0c=GD
0<_Ad039c/`0b<_80<W:aP3;b/H0cL_70=7=b03Dc/P0eL_40=?6_`3@`KT0cKZb0<Ze[037/JL0aZfR
0<>ZWP31YYX0_Z:F0;^NT@2gVH`0/iB60:j>P02XR7X0Xh=e09inL@2EM6L0S6eP08ASEP21IET0OfMM
07eYH01lJf@0NVeW07U`J`1hLfl0N7Ec07MhM`1fNg/I0?ooo`0B04MUN@1@Kh<0F7R=0662V01YS:80
LYJ]07^P^@24Z/@0SKG?09Jof`2Ob^H0Z=Ca0;?NnP2ihO`0^^3j0;OKm@2be_00/=C^0P2_dnd01@2`
dnh0/]G^0;GGk`2gf?00^MWa0080^M[a00H0]mO^0;GCjP2bcnD0/<_Q0:o8gP2_amd20;37g0050;77
f`2aa]/0/LKJ0;;6fP2camX00P2db=/05P2cb=/0/LOJ0:o5f02]`]H0Z/3D0:Nod`2T_M40XKcA09jj
d02J^Ll0U;G;08b]``25YKX0OYbb07NEZP1`SJ80JHJJ069oT`1KN8`0E76404eZO@16HgHT0?ooo`00
8P3oool05@2GT8h0UI6@09>BTP2@Ti@0SI>F08ZCU`26TiP0PY:I07fAV@1gSiT0LXjI06j=VP1XQY@0
EgN504EYN00gGFh0>ei^041RL014IG80B6Qe04]ZMP0204]ZM@0Y04QWLP15IG00@f9^049OJ`14GVP0
AUiW04]QJ@1AIfh0Efec05abM`1OLgP0Gg1d05a[KP1IIFL0DeeP04iGF@1:DU<0ATa=04=8B012A4@0
@D10044n?011>cT0?cPd03hd<00l<2X0>R/V03PW8P0b7AL0<1L@03<E3@0l8AX0A2`U04dg<@1F@Sd0
Gde806QHD`1bHel0NfiZ08EiM@2?Q8406@3oool0@02BTY40V9VI09fQXP2RZ:X0Yk2b0:^g^P2__L80
//C90;G9d02fcmL0^=CM0;WHhP2hd]`0Z<?=09Fb_P20XJl0PZ6]08JT[`2:Y[40SjZc09B^]P2H/;L0
Vk:h09^a]P2I[k@0UZ^`09BUZ`2CXZH0U:2S09JQXP2KY:D0XJVY0:N][02/[jd0[JbY0:ZUXP2WWYT0
XIJA09f?R@2IRX<0U8Al095nMP2?NW40RgA[08Q`I@25Jf00PVEI07iPD`1iFD`0M5=6071>@01U@S@0
G3HX05L^7`1K=RT0GShc06=6?01WCTH0K5M?075OF@1fJ680O71/089iM@27PGlH0?ooo`1007n8R@29
TY@0TYfN09^WZ@2U/[@0[[bo0;O7b@30dM@0b=_N0<oTj03FkO40g?Ch0=oam03Gj>/0bmcP0;_=d`2j
bm40_<gA0;k>dP31d=<0a]CF0<_Gf03@f]X0d]_J0=?Jf03@emD0cM7@0<[>c039blP0bLS40<_8a03>
b/D0d/g70=K=b03GblD0e/O00=C2^@3A_K<0ckR^0<jeZP3;/:D0b:bP0<JXW032XiL0_YnB0;ZJS02f
UHL0/I220:b:O02WQGL0XX5c09QhJ@2=K5h0Q65D085SE`1oIE/0OFMO07]ZHP1jK6H0NFmZ07QbKP1g
MG80MgQf07IkNaT0oooo0200B6Ei051_P`1INHh0HX>I06^=X`1dUjl0OZ:k08R^a`2B^M<0VlCN0:C>
jP2/eO00/]Wc0;SMm`2kg_L0^M_d0;GGl@2ceNl0/]C]0;;Ck02deNh0]mSa0;_Lm@2ogoP0`N3h0<7O
mP2ngO<0_=[`0;WGk@2fdNL0/lcQ0;79g@80/LOK01h0//OL0;?7g02eb=`0]/WL0;S;g@2jc=h0^/gO
0;[<g`2ic=h0]l[M0;C8fP2aaMP0[lCG0:c2e@2Y`=<0YkoB0:FodP2Q_]80V[S=096^``29Y[X0PIjb
07VFZP1bSZ80JXNJ06=oT`1LN8`0EG6404eZO@16HgHT0?ooo`008P3oool0@02GT8l0UI:A09BCU02A
U9H0SiFH08bEVP28UI/0PiBK07fBV`1gT9X0LHjJ06b;U`1UQ980DWB303mVMP0`FF/0=Ua/03]PK`10
Hg40AFQe04]/N01>KWX0CVii04a/M`15Ig<0?f9^03eNJP10GVP0@UaU04IMI@1?IVd0EFac05]bN01O
M7T0Gg5f05a/K`1HIFL0DUeO04mHFP1:DU@0ADa=0416A`0n@T<0?3hn03`l>`0m>SL0?3Hc03Xc;`0h
;bX0=b/V03DW8P0_7aT0:aD@02dB2`0f7QP0?bTT04Te;`1B@3/0G4]706IFDP1`HUh0NVeY08AhM@2>
Q84I0?ooo`1009>BT@2IVYX0Wj:S0:BZ[02Z/[D0[kZm0;C1a@2gb<d0^/kD0;_Cf`2len40_=SQ0;cD
g02X`L/0T:jj07VLZ`1mWJ/0PZ6]08NT[P2=ZK80U:je09Va^02M/kP0W[:g09^_]02DZJl0Sj>X092Q
Y@2AWZ40TY^M09VQXP2QYjL0Z:f/0:f_[@2^[:X0[:NS0:VPVP2SUi40X96;09b<Q02GQWh0TWmg08mj
L@29LfX0QfmU08E[H022IUX0OV1C07UJC01dE4L0L4m106=1=01G<bH0DbXL05Lc9`1K>c00H4@j06A<
A01ZEDh0KeiG07EVH@1kKf/0PGQe08N1OaP0oooo0400P8V:08ZCU@2DWZ00WZV[0:Rd]P2b_l40_<_=
0<KFf03?h><0e^[]0=gbmP3Rm_T0ioGg0=gXj`3:fMd0]lW?0;S9cP2jb/l0_Lc?0<7?d@36d]@0bmGF
0=3He`3DfML0e=WF0=3Ed`3<cld0b/g:0<W9aP37aL40b/K10<k8``3Cc<H0elg70=W<a@3Ib<00f<Bj
0=Bn]03C^Zl0dKN[0<ncY`3=[j80bZ^N0<BUV030X980_Ib=0;VGR02eTX<0[ham0:^7N02UPW<0V7IW
08]YFP23Ge00P65E07iTF@1lIUd0NfUQ07U[I@1hKVT0N75]07MdLP1gMgH0MWYj6@3oool0@018IWT0
DFn405YiSP1SPiT0K8jT07JI/021YK`0S;7909NmeP2QbN<0Z]?^0;;Jm02kgoL0`>7h0;kNmP2jf_80
]mO_0;GEk@2cdn/0/m;Z0;?Bj@2ednX0^=K/0;gIkP33gO80a=gc0<7Kl@2nfNh0^mS]0;OBi`2dbml0
//OK0;;6f@2ca]T0]<OJ0;K8f`2hb]d0^/cN0;_<gP2lc]l0_]3Q0<3Bh`2odN80_<kP0;W;g@2fbM/0
]<OI0;;5e`2_`mD0[<7C0:Vod@2S_<d0W;K809B_`@2<Y[T0Q9nb07bGZP1dSj80K8NJ06B0T`1MN8/0
EG6404iZO@17HgHT0?ooo`008P3oool0@02GTHl0UY:B09FDU@2CUYP0TINJ08jHW02;V9h0QYNN07nD
W@1fT9/0KXfJ06Z9U@1XQI80E7J503iUMP0/EVT0<UY/03QOK`0mHW40@fMe04U/N@1@LGh0E7Ao05Qe
P01AL7/0B6Ue049TK`12I6h0AV=/04URJP1?Ifh0EFed05]cNP1OMG/0H79h05e/L@1IIVT0D5]N04iG
FP18DE<0@DY<03]3A@0j@440=c`m03Pi>@0i=cH0>SDc03Pb;P0e;RX0<bXV030U8@0W71P091@?02L@
2`0a71H0>RLR04@b;@1??ST0FDU506=ED@1^HEd0NFaY08=hM@2>Ph0I0?ooo`1009BCTP2JVi/0XJBU
0:N/[P2]]KL0/kk10;W6bP2ncM80`MCJ0<7Hg`2of^<0_]OO0;kBfP2V_lT0Rj^g07>GY`1iVZP0OinZ
08BR[@2;Yk00TZbc09Va]`2L/[L0X[Bh09f`]02CZ:h0SZ6V08bOY02=Vih0T9VK09ROX02PYZH0Z:f/
0:j`[P2`[Z/0[jRT0:fTW@2TUi40XiB=0:2?QP2JR800TWmg08iiL@28LfX0QViT08AZG`23IUX0OV1C
07UJC@1fEDL0Kdi005lo<P1B<B@0CRLJ05<`9@1G>Bh0G44h065:@P1WDd`0KEaF07=UH01jKVX0P7Qd
08N1OQP0oooo0400P8V:08^DU@2EWj40X:^/0:^g^02f`l@0`Lo@0<cKg@3GinT0go3c0>?gnP3Vm_P0
io;d0=SSiP35e=P0//G;0;G5b`2hb<`0_<[=0<3<cP34cm00b=;A0<WBd03>dm40cM;@0<O=b`34alD0
`/C20<2o_032_KT0b<:m0<k6`03DblD0f<k60=_=a@3Kb/00g<Rm0=S0]@3I_[80fKb_0=NhZ`3A/Z@0
cJbN0<JVV033XY<0_if>0;bHR@2gTh<0/Xin0:n:N@2YQ7<0VWIV08]WF022G4h0P5mC07eRE`1kIE/0
NVMO07QZI01gKFP0Mg1/07IcL@1fMgD0MWYj6@3oool0@018IWT0DFn405YiSP1SQ9T0KHjT07RJ/023
Y[d0SkC<09c2f`2XcnT0/MWb0;OLmP2ifo<0^]_a0;_Kl@2if>l0]mG[0;KCjP2ed^P0]=7V0;??h`2a
c>00[l[N0;3;g`2dcN80]lkS0;S>h@2fbmh0//OJ0;75f02ba]T0//GG0;?4eP2caML0]LKH0;O9fP2j
cMd0_LoP0<3@h@34e>D0amOW0<OFiP34dn@0`M7R0;k?h02jc=d0]lWJ0;G7f02ca]H0//GE0;33d`2Z
_Ld0XKG509R^_`2?YkT0Qina07jGZP1fT:80KHRJ06F0T`1NNH/0EW6404iZO@17HgHT0?ooo`008P3o
ool0@02HTHl0Ui>C09JFUP2EV9T0U9ZM09:KW`2?W:80RY^R08:HX@1fTI`0I8BB06>3T@1RPHh0DWB3
03]TMP0XE6P0;eQ[03EMKP0kHG40@6Ed04IZM`1=LGh0DWB005YhP`1KN8<0EWAo04m]M`19JG<0BFI`
04]UKP1@J700EFee05]cNP1PMW`0HWEj065`M@1PKG00F69U05=MH01<EUP0@4]?03a5B00h@480<cTl
03@g>00f=CD0>CDc03Lb;`0d;R/0<RXV02/T800P61D06Pl<020=2@0[61@0=B@P040_;01;>cP0ETM4
065CD01/Ge`0Mf]X089gM02=Ph0I0?ooo`1009BCTP2LW9`0XjJV0:Z_/02a^;X0^<;40;o;cP35e=P0
b]_Q0<_Qi`2nf>00_=?K0;W>eP2U_LH0R:Re06jCX`1eUjD0NibX08:PZ`28Y:d0SZR`09F]]02I[kD0
Wk:g09^^/`2EZ:h0Sj6V08^MXP2<VYh0TIZM09ROX02QYZH0Z:f/0:n`[P2b[j`0/JZU0;2UW`2YVY<0
ZIR@0:NCRP2JR800Tgmg08mjLP27LVT0Q6iT089YGP22IET0Of5D07]LCP1hEdT0Kdi005/m<01<;B40
BBDI04l^8P1C=R`0F3lf05i8@01TDDX0JeYD075TG`1hKFT0OgMd08J0OQP0oooo0400PHV:08bEUP2G
XJ80XZb^0:ji^P2jaLL0a]?D0=CQhP3Qko00k_gn0>_ko@3Zm_H0ino`0=OQh`32dMD0[l770;;3b02f
aLT0^/S:0;k:b`32c<`0aLg=0<K>c038c/`0`/S70;g3``2k_kh0^[bk0;fk^032_;P0b<2k0<k6`03D
blD0fLg60=_<``3Kb;l0flFi0=Rm/@3M_k40h;n`0=NhZ@3B/J80d:jO0<RWV034XY<0_if>0;fHR02i
U8<0]Y1o0;B<N`2]QG<0VgEU08YVE`21G4h0OeiB07aQEP1jHeX0N6IN07MYHP1fK6L0MVm[07IcL01f
MWD0MWYj6@3oool08@18IWX0DFn405YiSP1TPiP0KXjT07RJ/024Y[d0T[G=0:;7g`2dg?H0_^Go0;kP
n02mg?<0_=[_0;_Hk@2je^/0^=CY0;KBi`2edND0]M3T0;?=h@2abM/0[/KH0:[2e02U_<l0YK_>0:Rm
d@2[_]40[[oA0;32d`2a`mD0//CE0;?4e@020;?4e00=0;C4e02e`m<0^<GD0;o<f@36dn00b=GS0<KD
hP38eN@0a]GS0<7Ah@2mc]h0^L[I0;O7e`020;O7eP0>0;K5e02a`M00YkW809b``@2CZKX0RJ6b082H
ZP1gT:80KhRJ06J0TP1NNH/0EW6404mZO@17HgHT0?ooo`008P3oool0@02HTY00V9BD09RHV02HVY`0
UifP09JOX`2DXJL0TJ:Y08ZPZ01lUj80IXNE05YmR`1GNXT0BVn003QRM00VDfL0;EMZ03=LK@0iHG80
?V=c04=WM@19KG/0Cg>005AfP`1DMX80Dg=o04m_N`1;JWH0BVQb04aXL@1@JW80EVmf05adN`1PMWd0
HgIl06=cM`1QKg40H6QZ061VI`1NHV80CEAG04M<CP13AdT0>Sm103Tl?@0i>CT0>SLe03Pc<@0e<2d0
<R/X02LQ7`0K5Q@04`X801P8100T5140;b0M03/]:P17>CH0DTI305iBC`1ZGU/0MV]X085gM02=Ph0I
0?ooo`1009FDT`2MWId0YJNX0:fa/P2e^kd0_LK80<K@d`3>fml0f>O[0=?Vk031eml0^LkG0;C8d02N
]l80PjBb06Z@X01aUJ<0N9VU082OZP26XJ/0RjB/096Y/02F[K<0VJjc09R//@2DYjd0T::W08fMX@2>
Vih0TibN09VPX02QYjH0ZJf/0:n`[P2b[j`0/ZZU0;2UWP2]WID0[I^B0:fHSP2KRH40UX5i095lL`26
LVX0Q6eT089YGP23IUT0PF9D07iND01lFTX0KDdo05Pk;`16:Ql0A28F04TZ801><bT0E3`c05Y5?P1Q
CdP0J5QC06mRGP1gK6P0OWIc08J0OQP0oooo0400PHV:08fEUP2HXJ80Y:f^0;2j^`2mb<T0bmKG0=[V
iP3^nOT0m?oo0>ghn@3]m?@0j>k]0=GNh02ncM80Z[g30:noa02c`/D0^LO80;g8b@30bLP0`l[90<G:
b@35b/L0`lO50;o2`@2l_[/0^kZh0;jj]P33_;L0b<2j0<o5_`3Ebl<0fLc40=c;`P3Kakd0fL>g0=Nm
/@3G_:l0f;Z/0<jaY03<[Il0bJVK0<6RU02nWXl0_9V90;fGQP2lU8<0^Y5o0;Z?O02^QG<0VWEU08QV
E`20G4d0OEe@07YOE01hHEP0MVAL07EWH@1eJVD0MFiZ07EbK`1eMW@0MGYi6@3oool04P18IGT0DFj2
05YhS01SPYH0KHfR07RH[P24YK/0T[C;0:K:h`2df?40_n3g0<KUn`35hOH0_m_`0;[Fj`2gdnP0]];V
0;K@h`80]M3R01H0]<gN0;;8f@2_a=@0[<3?0:Zmc@2Y^l/0ZK[90:^kb`2]_L`0/;o>0;71d@2b`]80
/l?B0;?2d@2c`M00/l3?0;:oc`2b`<l0//7@0;C3d@2ha]@0^lWG0P2kb]P0502ib=H0^<OD0;S7e@2i
amD0^/OE0;_9e`2jb=D0/l;@0:Zmc02Q]LD0UZ^k08bR/P22VJX0NI2Q0728V@1WP980GgR:05MaP`1?
JW`0Af=f903oool00280oooo0400VI>A09ZFU@2JVYX0VifO09^PX`2KY:P0VjN/09Z[/@2K/;P0R:6Z
07FDW`1SQI80F7^:04M^O`0gHG@09E9W02]FJ@0aFfd0>69b03iVMP12J7L0AFYh04U^O01<LGl0CG:0
04a`O@1:KGX0B6Yf04QWL`1<JW@0DFae05I`N01LM7`0HGIm06=gO@1SLWP0HFib05iYJ`1PIfP0I6MW
05ePH01EEeL0CTm@04E7B010@D80?C`l03/i>00j=C<0=c4_03@^:`0U8Al061DD00l:2@0B10807A0>
02TM6`0f:RP0@cLd04m4@@1LDDh0J5eK07AZI`20MW@0S8>06@3oool0@02FU9<0WYjN0:NYZ@2`/k@0
^Kk00<;9b`3<eMP0en;U0>Cam@3Fi^/0b=_Q0;W=e@2^`l`0U[:n07jP[P1WSYh0KI:P07FFXP1mW:H0
Q9nY08VSZ`2>YJd0TjV_09F[/02EZJl0TZF[08nQY`2>WJ80SY^N09BMW`2JXJ80XZNW0:V][02`[jd0
/jn/0;>[YP2`YIh0[IjF0:fKTP2/Uhd0X8f409V5O02COG@0RGA[08M_I@26Jel0QFQK08ETEP22H580
P5a=06];?P1D>Bh0@RTO03hM4P139Q`0BBlV04lh<@1F@S/0GDa606EFD@1]HE`0MF]W07eeLP25P7dH
0?ooo`1008:9RP2=UIH0VJ:S0:J_[`2b_;`0`<W:0<kHf03Nj>P0l?[j0>kgm`3Zl_<0iN_[0=oUi@3;
emX0^<S=0:Nj`02/_<40/;k20;G1``2i`/<0_/K50<;8a`35b/L0alW60<K7a032`[l0`;nl0;nl^@30
^[D0a;bf0<W0^@3?a[l0eL[20=[;`P3Lbl40g<Rl0=_3]`3H_[40e[Z]0=6eY`37[9l0a:RK0<6TUP2l
WY00_9^<0;jIR@2oV8H0_iF30;nCP02nTGd0[H=a09McH`26I5H0OUU:07]KCP1hG580MUmF07ARFP1c
IEl0LfUT07=]J@1dLFh0M7Ed07EiNAT0oooo01/0B6Ag055]P@1IMh/0Hh2E06b;W`1gUJX0PZ6g08j^
a02L_=<0Z<ON0;;>i02jeNT0_MO[0;[Dj@2fd^D0]]7T0;G?hP2ecN00/lWK0;;7e`2dbMX0]L[J0;C7
e`2ca=80/L3>0;2nc02__L/00P2`_//08`2`_L/0/Ko>0;;2d02c`]40/l7?0;?1c@2d`Ld0]<7>0;C0
cP2a_/`0ZkW70:Nfa@2[^/P0[Kg;0;2nc02c`Lh0]lC@0;W5d@2ja]80_<SD0;g8e02ja]80/l7>0:^l
bP2S]L@0VJbk08jS/P24VJT0NY2Q0728V01WP940GgR:05MaP`1?JW`0Af=e02@0oooo000R0?ooo`10
09ZCT@2KUiL0W9bL09fPX@2OY:L0X:V/0:6]/P2S/kT0Yk[109>Z/`1nVZD0K8bI05aoS@18L840=F5d
02ACJ00WE6P0;eU/03EOL00mIWH0AFal04U`OP1=LX00CgF305=hQP1CMh@0DGB204iaO@1=KGT0CVeg
059^N01FLGX0FgAl061fOP1TN7h0I7Ak061]L`1LIf`0FfEW05]QH`1HGUl0EUUJ051CD`17Bd`0@dE5
03lo?`0m>c/0>SLf03Tc<@0d;R`08b4P01@D5@0?3@`0308101H<2`0S6AP0<BLU03le<`1<@T00FDm=
06ILFP1cJFL0P7Ic08b2P1T0oooo0400UYFD09nOW`2YZZX0/[Ff0;c1`P36cLh0dMWK0=gWjP3[m_T0
gNW^0<cLhP2kc]H0ZL79096_^P1jWJ/0IHbM06Z>W@1bTil0NINR086MYP27XJT0S:B[096V[02AYZd0
TjN]096SZ@2@XJH0SYjR08nKW`2EWj40W:BT0:>YZ02Z[:/0/:j/0;>`Z`2e[:P0/ZFO0:fNU`2[VY40
YiB;0:6>Q02MQgh0UWme08mgK@2<LfP0RViQ08UZG@28IUP0R6=D089MC@1YBSd0CCH/048Z800i6a40
?B8I048[8`19=Bh0DCli05Y:A01RE500JemK07=ZIP1lMG80Q7mm603oool0@022RX/0SYJG09ZRX`2W
[k00];bm0<7:bP3@f=P0gnSX0?3hn03]m?@0j>k^0>3Vi`3EgMl0a=3D0;C3b02U]kd0ZKVm0:jk_@2b
_;h0][jo0;Vo_P2l`;h0_l6n0;fo_02l_K/0^[Zg0;Zh]@2k]k<0_KJb0<Bk]@3:`KX0d<Jn0=K9`@3J
b/00g<^o0=k9_@3NaKP0f[na0=Rk[@3C]ZP0cJnQ0<RYV`34Y9D0`In@0<:NS@32W8T0`iZ70<>HQ034
UX80`99m0:b1K`2BKel0QFAE07aGB@1hF4`0M5Y?079LD`1aGeP0LF=M075WHP1aJfL0LW1]07=dL`1e
NGTI0?ooo`1004QTM`1@KH00FGF9065oT`1[R9`0M9:V07jL/@29Yk`0U;7609nld@2Za=P0/<WM0;?<
h02dc>00]LcO0;G=h02fc^00]<_L0;?7f02``m80[[k<0:flb@2/^lL0ZKK20:Fa_@2U[kX0Y[2k0:Ra
_02[]L00[k[60;:nb`2c`Lh0]<;>0;C0c02c_lX0]L7;0;O3c@2g`lh0]L7=0;:nb`2__<P0[[[60:nj
aP2b_LP0]/7;0;W4c@2ja/l0_<OA0;k9d`2obM<0^lG?0;6mb@2[^LD0Y[K409b^_@2@Xk80QIVX07Z?
W`1`QiL0Ign@05mgR@1GL880CfUk04MRMB@0oooo000R0?ooo`1009ZDTP2LVIP0WYjN0:2RY02SZ:X0
YJfa0:Rc^02[^Kl0/<7809nc^`2:XZ`0MI>O0663T@1;LX<0=V9e02EDJ@0UDfL0:eMY039LK@0iHW80
@6Ui04M_OP1=M880CgN5059iR01CNHL0DgR6051ePP1?L7d0Cfmj059`NP1ELWX0FWAl05mfO@1TNGh0
JGYo06MeNP1PJg40FFAX05AMHP1BFUd0DEII04eAD`18Bdd0A4I70451@@0n?Cd0?STi03`f=@0d;R`0
8R4Q00lC500;2``01P0000T30`0L5A@0;2@S03/c<P19@Cl0Edi=06ELFP1bJFL0OgIc08b2P1T0oooo
0400UiFD0:6PX02Z[:`0]KNg0;o3a03:cm40eMcN0>;Zk03_nO/0h^ga0=3Nh`2mcmH0Z<39092]^@1h
VjT0IHbL06N;VP1^Si/0MI>N07bHX@23W:D0RJ2W08fRZ02=XZT0T:>Z092RZ02AXZL0T:2T09>OX`2G
XZ<0WZJW0:>ZZ@2Y[:X0[jfZ0;:^Z@2f[JP0]JRR0;2PV@2/Vi80YI>;0:6=Q02NQgh0VH5g09AkL02A
MVX0SW5T08a/G`2<JE/0SFMG085LC@1VB3`0BSD[048[8@0h7180<QXB03/U7P13<BX0C3`f05I7@P1O
DTh0J5iJ075YI@1kM740Q7mm603oool0@022RX/0SYJG09^SX`2W[k00];bm0<;:bP3@f=P0gnOV0>kf
m@3[lO00hnWY0=[QhP3?fMX0`<c?0;30a02T][`0YkJj0:^g^P2`^KX0];^j0;Nk^P2i^kT0^KVg0;Rh
]@2i]k@0^KJb0;Ze/@2l][80`KVd0<Nn]`3=`k`0d/No0=O8`03IbKl0flRl0=c5^@3L`[@0g;n`0=bm
[P3F^:P0dK:R0<j]W@3;Z9P0b:BC0<NQS`36WX/0aY^80<JJQ@39VH<0_i1k0:QoK02BKel0RFIG081K
C01dEDT0L5E;06iHD01]G5D0KF1J06iUH01_JFH0LFi/079cLP1dNGPI0?ooo`0V04MTM`1?K7l0EgB8
061lT01XQIP0LHjQ07ZGZP23Wk<0S:Nk09F```2N^</0YKkA0:_3eP2^a]T0/LSJ0;C;g@2fc=d0]L[K
0;?7e`2b`m40[kk;0:bg``2X/K`0YJfh0:BZ/`2TZK40YJVa0:R]]P2]];l0/K_60;Bob`2f`Lh0]/7=
0;Bob`2b^lL0[kS20;2i`P2f`<L20;[4c@0H0;O1b`2f_lX0]Ko:0;O1bP2i`l`0^lG>0;c5cP2mall0
`<WA0;k8d02h`//0]Ko90;6mb02]_<T0X[?1096S/@25V:H0NXjM0725U@1WOHh0GWJ705I_P@1>JG/0
Af9e903oool00280oooo0400ViBC09jJV@2QX:00XjFV0:J[[@2Z/K@0[KRl0;6oa02fald0Yk[209>Z
]01nVJD0JHVG051fQ`0iI7L09eI[02ABIP0XE6L0;UUZ03ENKP0kHg<0@FQh04E]O019L800Bg>204ac
PP1=Lh80CG:004eaOP1>Kg/0DG1j05AaN`1HLW/0G7=k065eO01VMgd0JgQl06]dN@1WKW80G6AX05=K
GP1=E5P0BU1C04M;C@14AdP0@T=30490@011?C`0@CXi03<_;P0R8B803a@G00H;3@0610D01@4301LB
4`0X8R80>34a04M0?`1FCTd0I5]J075XI`1nMG<0Rh:06@3oool0@02GUY@0XZ6P0:b][@2g^;T0`LG5
0<gAdP3Ign00iNc^0??jo@3Vko80e>3U0;o@e`2Z`<T0T:fi07VKZ@1VSI`0IHVH06^;V01bT9X0NI>M
07nHX024Vj80R9jT08^PYP2>XJL0Sj6W096RZ02CXZL0UZ>W09ZTYP2OZ:P0Y:ZY0:V[Z@2][:P0/:bW
0;B[Y@2fZJ80]:>L0;6NU@2YUXd0Y8j509j8O`2KPWP0Ugeb09=hJ`2@LVD0SfmQ095/G@2BJET0OeY;
06E8>`1==bd0?bTP03DL4`0W4``0<R0J03d/9`17>C<0DTE005a@C01VG5T0L6QU07YcL@23OgdH0?oo
o`1008::R`2>UYL0Vj>S0:N_[`2d_;`0`/W90=3GeP3NiN@0kO?b0>S^k03Pi^D0e]kN0<[DeP2kbL`0
[[k20:>e^P2U/kL0ZKFg0:jg]`2b^;P0]KVh0;Rj]`2j^KH0^kVf0;bj]P2n^[D0`;^f0<:l]`36_kT0
bl:k0=36_P3Db<00elW00=[9_P3Jak/0flFg0=[1/`3G^jd0e[RZ0=BeYP3E/j<0dk2O0=6[V@3=YiD0
bj>@0<RNRP37W8L0bY^60<bIP`2lSGP0Z7eZ09IaH029IED0NeM906U;@01YD4H0J5A<06UHD@1ZGEL0
Jf9N06eXI01_KF/0LG=a07AhN1T0oooo01l0Af=f04iZOP1FLXD0GWV<06J1U01^RI`0MY6T07jIZ`26
X;80SZJh09F]_`2L]<H0X[[;0:Nod02]a=D0/LSI0;C:fP2eb]T0]LSG0;?5d`2b`Lh0/;c80:jh`P2/
];h0[;>l0:bb^P2]/k/0[kJn0;:j``2e_/T0]l;=0080^<??00P0]/7<0;Bnb02`^/<0[KFm0:Zc^`2/
][h0/kc40;[2bP@0_<C<01<0^l?;0;_3bP2maL`0_lG=0;c3b`2h`<P0^;o70;Bla@2Y];l0W:Zg08nO
[@23UJ<0N8bJ06j3TP1VNh`0GGF505E^O`1>J7X0Af9d02@0oooo000R0?ooo`1009bET`2OViX0Xj6Q
0:JXZ@2Z[[00[[Fh0;:l`02g`lP0_LcA0:joaP2L/KX0QInZ06n>V`1FNh/0?VQk02UHK@0RDFH09E5U
02]EI`0aFFX0=Ui^03]RLP0oIWD0@fYi04E]O017KWd0B6mn04U^O@1:KW`0C6ik04m^NP1BKgX0EG1i
05Q`N01LLGP0HG9h06EcN01WLWH0J71c06I/KP1QIVP0FEiP05AGF@1?DE<0C4e>04M7B015@d<0@d10
04<m?00e<C4092DU01DJ70083Q400`H80041100C4A809B4R03Ha<@15?cl0E4i=06=KFP1aJ6L0OWEc
08^2P1T0oooo0400V9JE0::RX@2][Zd0^;Zj0<C6a`3?dm@0fn3Q0>S^k`3eo?d0io3c0=SSi`31d]T0
[<7:09>_^P1kWJX0J8jM06B8UP1XRID0KhfG07F@V@1kU9`0PINN08FJX@29WJ<0S9nU08nQYP2BXjP0
U:BX09RUZ@2KYjT0X:RY0:B[ZP2XZjT0ZjZW0:nZY@2aZJ<0]:NP0;>SW02bWiL0[YV@0:RBR02RRh40
WXAi09UnL`2GNF`0TgEV09EaH`2EKUl0TfYJ07eIB`1VB3`0CcP^03/X7`0]6A807`l902/L5P0g:2<0
@SDa04i2?P1ICd/0He]G06iWI01iLg00Pgil603oool0@022RX/0SYJG09^RX`2W[jl0];^k0<78b03?
e]D0gN?R0>[`k`3Tj^T0g^CS0=?Kf`37d]<0^/O90:jm`@2U]KX0YK:f0:Rc]@2]]KH0/KNf0;Fh]P2h
^KL0^kZg0;fk^030_;P0`[fi0<Fo^`38`K`0bl>m0<o6_`3Cb<00el_10=W:`03KbKh0g<Rk0=c5^03L
`[@0f[j_0=NiZP3C/j@0cjjO0<f[VP3<Z9H0bJBB0<VPS@38WXT0c9f80<fKQP3;V840^HUe0:IkJ02D
KEd0PUi@079@A01QAC/0HDY1069?A`1SE4h0IEYE06QPF`1ZIV80KFaZ071bL@1cN7PI0?ooo`1004IR
MP1=JG`0EG2305agRP1SOY00JhFG07:<WP1iTjD0P9VZ08JN/02=YKH0UJbm09^b``2R^LT0ZKo?0;76
eP2fb]X0]l_J0;K9f02eamD0]LCA0;C2cP2c_lX0/[g70;:ka02c^l@0];c50;Jna`2h`LX0^/?=0;_6
d02lam40^lKA0;[5c`2h`l`0]Ko80;:ka02_]l00[;Bm0:Zc^`2[/k/0[kNo0;:j`P2c^l80];_20;Rn
a@2l`LP0_/;90;g1b02i_/D0]K[20;:f_`2^/[X0Y:bf09RT/02<VjP0P96O07J8UP1/P8l0I7V905ac
P`1DKGh0CFMi04IQM2@0oooo000R0?ooo`1009bEU02PW9/0YJ>S0:VZZ`2]/K<0/[Rk0;O0``2lal`0
`/oE0;;2b@2R]Kh0S:F`07FCX01LOhl0A6ao02eKL00RDFH08TmS02MBI00]EVL0<UUZ03IMK@0jHG40
?FAc041WMP12JGP0A6Yj04E[NP17JgT0BF]i04]/N01>K7P0DFaf05A]MP1HKGD0Ffid05m^L`1QKG80
Hfa`069YK01PIFP0GF5T05ULG@1CEUL0Ce1@04];B`19AdH0Ad=204<n?00f<c<0:2PY01/N800=4QD0
0`P;0002100?3Q008b0R03@a<@15@400E4i=069LFP1`JFL0OWId08^2P1T0oooo0400V9JE0:>RX@2^
[Zh0^[^k0<G7a`3Ae=D0gN7R0>[_l03goOh0jO7c0=[Tj035eMX0[/C<09Na^`20X:d0KI6O06>8UP1U
QY<0K8ZD07>=UP1iTIP0OYBK08>HWP28Vj40RijT08nPYP2BXjP0UJBY09VVZP2LZ:X0X:VZ0:B[ZP2W
ZZP0ZZVV0:fXY02`Yj40/ZFN0;:RVP2aWYD0[YV?0:ZCR@2VSH<0XHMk09f1M02KO6h0VGQZ09UdIP2H
LF40TFUI07]HBP1TAc/0CcL^03TW7`0W5a806Pd802<F4P0`9200?C8_04Y0?01FCDX0HEYG06eVH`1h
LW00PWil603oool0@022RXX0SYJF09ZRXP2W[Zh0];Zj0<77a`3>e=<0fn7P0>W_k@3SjNP0g>;Q0=7I
f@36d=40^/K90;2m`@2X][X0YK:e0:Nb/`2/];@0/KJd0;Fg]@2i^KH0_K^h0<2m^@33_k/0a/6l0<W4
_P3<aKl0d<S10=?:`P3Gc<<0f/g30=c<`@3Mbkl0g/Vl0=k7^@3Na;D0g<2a0=ZkZ`3F]ZD0d[2P0<n/
VP3<YiD0bjBA0<bRS@3=X8/0cij90=2LQP39UGl0]HIa0:1fI02>J5P0NUY<06U<@@1J@SP0FD@l05]9
@P1ND4X0HEIA06AMF@1XHf40JfYX06maL01bMgLI0?ooo`1004IRM@1<J7/0Dfj005YdQP1PNX`0Ih6C
06j7V01eSIh0Ni>U08:IZ`28WZl0SZBd09J/_02N]<@0Ykc<0;35d`2fb]T0^<cJ0;S;f@2hbMH0^<SD
0;S6d@2haM00^<C?0;S3c@2i`ld0^/C>0;c6c`2nb=80_l[D0<3<e@30c=H0`<_E0;o9d`2mam00^lG>
0;S1bP2e_/H0/[_20;2g_`2^]K`0[KBk0:ne^`2b]kd0]K_00;Vm``2l_lD0_L770;^na02e^;h0[k>i
0:V^]@2TZK40WJF_09BQ[029V:@0O8bI07:3T@1YO8/0HGJ505Y`P01CJg`0C6Ig04IQLb@0oooo000R
0?ooo`1009fFU02RWI`0YZBT0:^/[@2`/kD0][^n0;_3a`31bm00a]CI0;O7c@2W^/80TjZe07bIYP1R
QID0BW:403=PM00SDVP07deQ02A?HP0ZDf@0;UIV039IJ@0fGFd0>F1`03]RLP0nI7@0@6If045WM`13
J7L0AFUf04QYMP1:JGD0CFUd04mYLP1CJG80EVUa05UZL01KJFl0G6M/05eUJ@1KHfH0FEmR05MKG@1C
EUP0Ce5B04a=C@1;BDT0BDI5044n?P0e=3@0:BX/01dP8`0A5QT01P`@00872P0>3a408b8S03Db<`15
@D40E4m?06=LF`1aJFP0OWId08^2P1T0oooo0400V9JE0:BRXP2_[jh0^k^k0<O8b03CeMD0gn;S0>c`
l@3io_l0jo7c0=cUj@38em`0/lO>09be_P26Y;00LYBR06F9U`1SQ940JHNB076;U01gSYH0OI:I08:F
W@27VZ00RifR08jPYP2BXjP0UZFY09VWZ`2MZ:X0XJZ[0:BZZ@2WZJL0ZJRU0:bWXP2^YJ00/:>M0;2P
V@2_W9@0[IR>0:^CR@2XSX<0YHUm0::4M`2POg40WW]/09igJ02KLV80SVMG07MFB01RASX0CCH]03LV
7`0R5Q405@`801X@3@0[8Ah0>C0]04Ln>`1DC4T0H5UF06]UH`1gLW00PWil603oool0@022RHX0SYFF
09ZQX@2V[Jd0/kVi0<36a@3=d]40f]oN0>O/j`3QiN@0f]oN0=3Ge`37cm00_<K80;>n`@2Z]kX0Y[:e
0:J`/P2[/k80/KFc0;Jg]@2j^[H0_kfi0<>o^`36`[d0b/G00<g7`P3AbL<0e<c40=S=a@3KclH0g/o4
0=o>`P3PcL00hL^m0>78^P3QaKH0h<6b0=fm[03J^:L0ek>R0=F_W@3CZiP0djRD0=>UT03CXXd0e:2:
0=:LQ@35TG/0/85]09abH028He@0M5E80616?01A?3<0CS/d05=3?@1HBdH0G5=>065JE`1UHEl0JFUW
06i`K`1bMgLI0?ooo`1004EQM01;IgT0DFan05MaP`1NMhP0I7f>06Z2T`1`R9P0MhfM07fBX@22UjH0
RIj/09:U]02L[[`0YKS60:k1cP2fbMH0^LcJ0;W<f@2jbmP0^l_G0;_;eP2lb]D0_L[E0;k;e@2obmD0
`LcF0<;=e`34cmP0aM3J0<KAf`36dMX0aM3I0<C?f033cMD0`L[B0;k7cP2l`l/0^L370;Jm``2e^l40
]K[00;Fj_`2g^l00^[c10;bm``2n_/<0_[k20;Zj_P2a/[L0ZZba0:>V[02LXJP0U9^S08bFX021SYT0
MXFA06emRP1UMhD0GW:105Q]O@1AJGT0BfAf04EPLR@0oooo000R0?ooo`1009jFU@2SWYd0Z:JV0:j^
[P2c][L0^Kk00;o6bP35cm<0c=SM0;c:d@2/_/H0VK2j08BP[01/SI/0DgV;03]WN`0ZF6h07diS029=
H@0WD680:e=T02mEI@0bF6P0=Ea/03MNKP0iHG40>f9b03eTL`0oIG@0@FEd04=VM016IW80B6Ea04]U
L01=IFl0D6E^05=UK@1FIF`0Ef=Y05MQIP1GH6@0EUeP05EIG01CEUP0DE9C04m?C`1>Bd/0BdM604=0
?`0g=cL0;2d^024T9`0F6ah031<G00P=4@0A4aH09BDW03Le=P16@d<0EE5@06=NG@1aJVT0OWMe08^3
P1T0oooo0400VIJE0:BSXP2`[jh0_;bk0<S9b03De]H0hN?S0>gal@3ko_l0k?;c0=gVj@3;fMh0^<[A
0::i`P2<Z;<0MiRU06V<VP1RQ940J8F@06n9TP1fSID0O92G086DV`26VIh0RYbQ08jPY@2BXjL0UZFY
09ZWZ`2NZJ/0XJZZ0:BZZ@2VZJH0Z:NT0:^VX@2]Y9h0[Z:K0:nOU`2^Vi<0[IN>0:^CR@2YSh<0Z8Yn
0:J6N@2SPG<0XWe^0:5iJ@2JLF40R6=D07=CAP1N@cP0B3<[038S7@0N51404@X701D=2P0W7a`0=Rl/
04Dm>`1BBdP0GUQF06YUH`1fLFl0PWil603oool0@022RHX0SIFE09VPX02U[:`0/[Rh0;k4``3;dLl0
f=gL0>GZj03Nhn40emcK0<oEe@36c/h0_<G60;>m_`2Z][P0Y[:d0:F_/02[/[40/KFc0;Nh]@2l^kL0
`Kjj0<G1_03:a;l0cLS20=7:a03EcLD0fLo70=cAb03Od/P0hM;60>;@a03Sc/40i<bn0>C:^`3TakL0
hl>b0>2n[@3N^ZP0g;JS0=ZbWP3I[YX0f:^F0=JWT@3FY8h0eJ6:0<jIPP2lRgD0Z7]X09A/F`1oG4h0
JDe105@n=@16<b/0@c8/04/m>01BAd80F4m;05eHE@1RH5d0IfMV06a_KP1aMWHI0?ooo`0Z04EPL`1:
IGL0D6Yl05E_P01KM8D0H7R906ImS@1/PY80LHNF07N<VP1mTIl0PiJT08^NZ`2DYk@0Wk2m0:Ria@2b
`lh0^<[F0;_=f@2lc]X0_/oK0;o@g031d=/0`]3J0<C@fP35d]/0am?L0<SDg@3:eMh0bmKO0<cGh03<
eml0bmKN0<[Dg039d]T0aloF0<G<d`32bLl0_lK;0;g3b02k`<D0^ko30P2k_/820;bn`P0B0;fm`@2j
^[d0/K:f0:Z[[`2RY:T0VIbQ092DVP27SI@0OhJ?07J0RP1^NhH0IgJ3065bO`1KKW`0EFYj04mVM`1:
Hg@0AEmb903oool00280oooo0400WYNE0:BOWP2ZYjL0/:n`0;Jh^@2l`<<0`lW<0<WBeP3?fn00`<oE
0;32bP2O]Kl0RjJa07BCX@1JOi00A6f0035NL`0TDVL08TeQ02E>H@0YDF80;5=T02mEI@0aEfP0<eY[
03EMKP0gGg00>F1`03]QL@0mHW40?f=a045SK`13HVh0AF5/04UQK01;HF/0CV5Y055QJ@1BH6L0DeiT
05=MH@1CFel0DeQL059EF01ADe@0D4m@04m=C@1;B4L0@T1003Th>@0^<3409BPZ01/O8P0B61`03a@H
01/M800Z:bd0>SPj04U6AP1GDe<0IEmO079[JP1oMgH0S8>16@3oool0@02IUYD0Y:>R0;2_[P2l_;/0
b<W80=GFeP3Rhn@0ko7a0?coo`3^lo@0g^OZ0<oKg`2mcM<0ZKg5096[]P1mW:P0KY2M06F7U01XQI00
KhRA07F<U01kT9L0PI>I08JGW@2:W:40Sj2U09>SY`2GYJT0VZNZ09jYZ`2QZZX0XjVX0:FXY@2WYZ80
ZZBP0:^SW@2]X9T0[YjF0:fJTP2]Uhd0[9>80:^?Q02YRgl0Z8Mi0:J3M02UOVl0XGUY09I^GP23Ge40
Ke1305Q0=P12<2P0;B0J01TB3P0:1P@050h<02DO7@0e;b`0@cdk055;B@1MF5H0JVES07IaK`21OW`H
0?ooo`100869RP2=U9@0VInO0:B[Z`2`]kH0_L;10<W?c@3FfmT0hnOU0=gPgP3Ef]P0c]CC0<K=c@2n
a/H0/kfo0:^g^02V/[@0YK2a0:^a/02b]K<0^KVe0;jl^034`;/0bLBn0<g7`@3Abl@0e/k60=W@b03M
dlX0h=C:0>?Eb@3Ue<P0i];50>K@`P3Wc[l0il^k0>K8]`3Va;<0i<2^0>:lZ@3P^:D0gkBP0=faW03K
[9L0fZVB0=ZUSP3EWhP0b9Am0;F5L02PMF80RFAD07=DA`1MA3T0B3D]03HW8@0i:bH0A3Pc04a3?`1C
C4T0FUEC061NG01VIVD0Jfi^075fMQT0oooo01d0A61b04UTMP1>J7T0Dfam05Q`P01MM8@0HWV806Qm
S01]PHl0LhFC07R:U`1nT9d0QYRT092Q[@2JZkH0Y;G00:bnb@2ea]80^lgH0;o?f`31dMd0`m?O0<GE
h037e^40bMOQ0<_HhP3=fN80cm_T0=3Li@020=7Mi@0Q0=;Li03Bfn<0d=[P0<oGgP3<eM/0b]7G0<S>
dP35b/l0`lS<0<;5b@30`lL0`<750;o0``2n_l80_kk10;bk_@2e];L0[:^_0:>RYP2HVIh0SY2F08B7
SP1jOhH0KWAk06Q`N01VLG/0HFmk05a]N@1GJWP0DVMf04eTM019HG<0A5ma02@0oooo000R0?ooo`10
09nGU@2UX9h0ZjRX0;:a/@2h^[/0_l?50<K<c`3=eMT0e=kR0<GBf02ea/d0YKW309:[]`1lVZP0I8NG
04]eQ`0fI7P0:EM/02=?H`0SCV409TmQ02UAHP0/Df<0;UAU031GI`0aFFX0<e]/03ELK@0fGFd0>5i]
03]OK@0mGV`0?Ui[041NJP13GVT0AUiX04UNI`1<GVH0CEeT04mLHP1@Ff00DEUN055HG01AEEP0D5AE
055ADP1@CTh0BTQ804=2@P0j>S/0<C<d02LZ;@0N8RD05A/O010E6@0Q8bH0;c0b03hm?P1<BDX0FEEE
06MQH@1cKF`0P7Qg08b4PAT0oooo0400VIJE0:FSXP2`[jh0_;bk0<W9b03Fe]H0hnCT0?3al@3mool0
ko?d0>3XjP3Bg>00`]3F0:k0b02H/;T0Q:6/07>CX01ZRiL0JXJA06n8T@1eS9@0O92F086CV@26Ui`0
Ri^P08nOY02CXjL0UjFY09^XZP2NZ:X0XJVY0:>XY`2UYZ@0YjFQ0:VSWP2ZXI/0[9jH0:fLU@2]VI40
[9J<0:bBR02[Sh<0Zhao0:V7N@2XPgD0YGi^09igI`2@JU/0OE]>06M;@01B?3<0?2`U02LL600C3P`0
1@8001HA400U81l0=2l]04<n?01@BdT0GEQF06UUH`1eLW00PGil603oool0@021RHT0S9>D09RNWP2S
ZJT0[kFd0;_0_`37c</0e=WG0>7UhP3Jg]`0dmSF0<gBd@37cL`0_/C40;Bm_@2^]kP0ZK:d0:Va/@2]
/K00];Fb0;^j]P31_[T0al:l0<c6`03Ab/<0e/k70=[AbP3Ne</0h]K=0>CGc@3Wf<`0j=K90>WDaP3Z
d/80j/no0>[<^`3Yb;L0j<Fc0>O2[`3U_JX0i;VU0>:eX03P/I`0gjfG0=fYTP3IXh`0d9^40<2=M`2/
OFX0UFaK07iLCP1WBd00DC/b03d]9P0]81/0=RXV03le<@18@3d0D4Y705MCD@1NG5/0I6ET06Y]K@1`
MWHI0?ooo`1004AOLP18HW@0C6Ig055YNP1EK7`0FG1o05idPP1SN8H0JGb:06j1S@1dQI80NX^G08:B
W@2:VZ@0U:>]0:6^^02[^L<0]L?<0;c;e@31d=X0a=?N0<OFh@3:fN<0c=_V0<oMj03AgnT0dn7Z0=GR
j`3Ghn`0f>C/0=STj`3HhnT0en3W0=KNi03Dfn40d]SM0=3EfP3=dMH0bloB0<W<c`37b</0aLK80<?3
a@32`L<0`Ko00;jk_@2h]KL0[jf^0:BRY@2IV9/0SXjB08>5RP1iO840Kg=j06I]M01QJW80GVUc05]Y
M01GIg@0DfIc04mTL`1;HW80Af1a04=NL2@0oooo000R0?ooo`1009nHU@2VX9l0[:VY0;>b/P2k_;`0
`/G70<[?dP3BfM`0f^?V0<[Fg02kb]40Zkk709Za_025XJh0KHjN05ElSP0nJWh0;Eeb02=AIP0RCF40
94iQ02M?H@0YD680:e5R02aCI00^EFH0;eMX035HJ@0bFFX0<eYZ03EKJP0gFVP0>5UW03]JIP0nFVD0
@EYU04AJI017FV<0BU]R04aJH@1=FEl0CUQM04mGF`1@EEP0Ce=F04m@DP1=CDl0B4Q90452@`0i>c`0
<C@f02P/;`0O9BP06AlS01LK7`0W:B`0=CDg0491@`1?CDd0G5QH06USH`1eKVd0PGUh08f4PQT0oooo
0400VIJE0:FSX@2`[jh0_Kbk0<W9b03Fe]D0hnCS0?7al@3oool0l?Ce0>?Yj`3Dg^40a];G0;?4bP2O
]Kd0S:J`07ZHY01aT9/0KHVD0728TP1fS9@0O92G08:DVP27Uid0S9^P092OX`2DXjL0V:FY09^WZP2N
Z:T0XJVX0::WYP2TYJ80YJ>P0:NQW02YWiX0ZifF0:^KT`2/V900[9F;0:bBQ`2/SX<0[8]n0:^7NP2X
Pg@0Xga]09UcI028IEL0MEI:0617?01;=bl0=BPR01lH500=2PT0108101LC4P0V8R40=C4_04<o?@1@
C4X0GEUG06UUI01eLW00PGil603oool0@021R8T0S9>C09NMW@2RZ:L0[K>b0;Vn_@35bLP0dMGC0=kQ
g`3GfmT0dMGD0<c@cP36blT0_/C30;Nn_P2a^;T0[KBd0:jd/`2a];80]kJc0;fk]`34`;/0b/Fn0=39
`P3Ec/H0f]7:0=oEc03Sf<h0im[?0>WJcP3[f/d0kMS:0>gFa`3]dl<0kM2o0>c=^`3/bKL0j/Jc0>W2
[`3W_ZX0i[ZU0>BfX03T/Y`0hZjG0=jYT@3GXHT0biIo0;R6L@2RMV<0RVED07ADA`1MA3T0AC<Z030S
7P0V6aL0<RPT03`c<015?S/0CDQ605EBD01LFeX0HfAS06U]K@1`MGHI0?ooo`1004=NL@17HG<0BVAe
04iVMP1BJGP0EV]j05Y^O01ML7d0HWB106MiQP1^OhX0MHB?07^:U025Tid0T9jW09bY/P2Y];d0]L79
0;k;e034d]/0b=KP0<_Ji03>gNP0d^7/0=GTk`3Gi_40f^Sb0=cZl`3Nj_<0gn[b0=oZl03OjNl0g^O/
0=gTj@3Jh>D0f=cP0=GIg03BeMT0cm7D0<g>d03:bld0b<S90<O5aP36`/<0`kjo0;ji^@2f/K40ZZJV
09jJW02AT940QHF807YlO`1_LGD0HVM/05aQJ01JHVX0F69[05ERK@1CHVh0D69_04aQK`19H6l0AUi_
04=MKb@0oooo000R0?ooo`1009nHUP2VXIl0[ZZY0;Fc/`2m_Kh0aLO80<gAd`3Fg=l0gnO[0=7Lh@32
d=H0//?<0:6f`@2=Yk<0MYFT05n4U@17LXD0=F=h02IEJP0RCV<08diQ02E>H@0VCf00:4mQ02UAHP0Z
DV<0:eAU02eEI`0^EfP0;UIW031FIP0aEFD0<eET03EEH`0hEV<0?5IR03mGH@12Ef40AEMP04QGG`1:
F5h0C5ML04iFFP1?EET0Ce=F04e@D`1;CDl0AdQ:0453A00k?Ch0<cHi02/_<P0S:2`07R<W02@W:`0^
<3<0>c/m04M6A`1CDE40Ge]K06]VI@1fL6l0PWYi08f5PQT0oooo0400VIJE0:BRX@2`[jd0_;^j0<W8
a`3FeM@0hn?R0?7al03oool0l_Gf0>KZj`3Hgn80b]GI0;W8cP2V^L40UJbe08BNZ@1iUZ40LHfG07::
T`1gSID0OI6H08>EVP28V9h0SIbP096OX`2EXjH0VJFX09bWZ@2NYjP0X:NW0::UY02SXj00Y:6N0:FO
VP2WWYP0ZI^E0:ZIT@2ZUhh0ZiB:0:^AQP2/SX80[8]n0:Z7N@2VPW<0WWUZ095]G`1oGe80Je1605Q2
>013<b`0;B<N01LB400510<02@L701TF5P0X9B@0=S<a04A0?`1ACD`0GEYH06YVI@1fLW40PGim603o
ool0@020R8P0Ri:B09FLW02PYZD0Zk2_0;Jk^P31a/@0cM7?0=[Mf`3Df=H0d=;@0<[>c036b/P0`<G3
0;Vn_P2e^[T0/[Ne0;>g]@2d][<0^KRd0<2m^038`[d0c/O10=C<a@3JdLP0gmC<0>CHcP3Xf/l0jmc@
0>kMc`3`gLh0lM[;0?3Ga`3`e<<0km6o0>o>_03^b[L0k<Jc0>_2[P3Z_ZT0j;ZU0>NfX03V/Y/0hZjF
0=fWSP3BW8@0`Hih0:amJ@2DK5/0OUa<06M;?`1?>S00=RPQ020F4P0Q5a@0;RHS03Tb;`12?CX0BdM5
05=AD01JFeT0HVAS06U/K01_MGHI0?ooo`10049NL016H740BF5b04aSL`1?IG@0DVMe05EXM@1HJWH0
Ffah065`N`1XMX40Kgf707N5SP21SYL0S9RQ09RSZ`2V/;L0];k50;o:d@36d]X0bmSQ0<oMi`3Ch^`0
enK`0=[Ym03Nk?H0h>kg0>;_mP3Tl?H0i_7g0>OamP3Vko<0iNc_0>?Xj`3PiNL0gN7T0=[Mh03GfM/0
e=GF0=7@d@3>c<d0c<W90<W5a@36`/40`[fk0;^d/`2_ZJP0XYfL09B@T@26QHH0NWYl06e_LP1PHfL0
DeEI04mCF01BFF00DE]T051MI`1>GFT0C5i[04YNK017GFd0AEe^049LKR@0oooo000R0?ooo`100:2H
UP2WXJ00[j^Z0;Jd]02n_[l0alS90=3Ce@3Ign40hn_^0=WSi`39e]`0^L[A0:Vma`2F[[X0Oif[06V;
W01CNhd0?fb002eLLP0TDFH08TiR02=>H@0TCV009DiQ02I?H@0VD6809e1R02MBI00YDfD0:E=T02YB
H`0[DV80;55P02mAH00bDUl0=U=P03YCG`0mE5l0@EAN04AEGP17EUd0BUIL04eFF`1?EUX0CeAG04eA
D`1:CDl0ADQ;0413AP0k?T00=3Pk02`a=00S:Bd0724U02X]<00e=cT0@D5304a;C01GEED0HemN06eX
J01hLW40Pgaj08j5PaT0oooo0400VIJD0:BRX02`[Zd0_;Zi0<S7aP3Ee=<0h^7P0?3_kP3oo_d0m_Og
0>W/k@3Kh^@0cmSL0;o<d02^_/D0WK6i08nV[`22W:H0Mi:M07F=U`1iSiL0Oi>I08BFV`2:VIh0SYfQ
09>PX`2FXZD0VJFW09fWZ02OYjP0X:JU0:6TXP2QXIh0XYnK0:>MV@2UW9H0YiVC0:RGT02YU8`0ZY:9
0:^@Q@2[SH40ZhYm0:V6N02SOW00UgAV08QWFP1eFDd0HDY104ll=00k;RP091dJ00l>300000003Pd<
01`J6P0Z:2L0>3Dd04E2@@1BCdd0GU]J06YWIP1fLg40PWmm603oool0@020QhP0RY6A09BJVP2NY:<0
Z:j]0;>h]P2n`/00bLg;0=GHeP3Be=80cM3=0<W<b@35b<H0`LC20;bo_@2h^kT0]kVg0;Ni]P2h^;D0
_KZf0<C0^P3<aKh0d/[20=W?aP3OdlT0iMO<0>WJc`3]gM00lMoA0??Od@3dg/l0m=_;0?CHa`3ce<<0
l]6o0?7>^`3`b[H0k/Jb0>g2[@3/_ZT0j[ZT0>ReWP3U/9T0h:^C0=NQR@38U7h0]XE`09mdH@27He<0
LE9505Y2=`11<2P0:alJ01/B3P0S6aP0;BHS03La;`10?3X0BDM5055AC`1IFUT0HF=S06Q/K01_MGHI
0?ooo`10049MK`14GW00Aem`04UPL01<HG00CV9`051SK`1BHfl0EFA^05UWL01QKWL0JGEn075mQP1k
QXh0Qi6H09BMX`2RZk00/;Rn0;g6b`38d]T0cm[R0=CPj03HiNh0gN[b0>7^m@3UlOP0j??j0>[en`3/
m_/0k_Kk0>ken@3]loH0k?3c0>[]k`3VjN/0hnGV0>3Ph@3Lg=`0fMOG0=GBdP3BcLd0c/W80<[4`P35
_[`0_[Jd0;B/ZP2WX9h0VI>B08Z6QP1mNW/0Kfi`069SIP1GFEd0Ce9G04aAE`1<DeX0C5IO04]HHP1:
FFD0BEYW04MKJ@15Ff/0@ea/045LKR@0oooo000R0?ooo`0F0:2HUP2XXJ00[j^Z0;Ne]030_kl0bLW:
0=;EeP3Lh>80ing_0>3Xk03BgN80`]7H0;74c@2P]/00RZFb07FEY01QQIH0CGJ903UVN`0YF6h08e5V
029>H`808TeQ00@08TeP02==H@0SCV408diR0P0TD6<08P0TCV409DiO02M=GP0YCEd0;4iM031?G@0e
DEd0>59M03eBG@11Ded0A5EM04QEG01;EE/0CeIK04mDF01=DUD0BdiA04I:C010A4P0>d1303Dj?@0^
=3L0:Bhb02<W:`0a<cH0?3do04M6B01AD540G5UI06IRHP1`JfX0NWAc08AmN`2>QX@I0?ooo`1009RF
U02TXJ00[jf/0;^i^037aL@0dm;A0>7OgP3^kN`0oOck0?Shm`3/k^l0h>GV0=CKgP36d=<0]/?80:Jg
_@2I[;@0SJ>/08:JX`1lTi`0OI:J086EV`26Uid0S9^O092MX@2DX:<0Uj:U09ZTYP2MYjP0WjNW09nT
Y02OXZ00WinL0:2LV@2QViH0XiVD0:FGT@2VUHd0Yi>:0:R@Q`2ZSX<0ZH^00:R7NP2UPgD0W7U[08i^
H@1nHED0K5=905Q5?016=c00<BPS01/H5P0:2`X00001014@400O7Qh0;B/[03Xh=`17AD<0De5?05mM
F`1[J6L0MgAb089oOAP0oooo0400OhN708V@T02BVIP0W::Q0:J[ZP2`];<0^[jl0<C8aP3@dm00cm7>
0<_=bP37b/L0aLK40<73`02m_k`0^K^h0;Ri]P2i^KH0_;Zf0<6l]`38`[/0d<S00=O=a03Nd/P0iMK;
0>[Jc@3^gLl0l]oA0?KQdP3ihM40nMo>0?SLbP3ff<H0mMC20?CA_P3ccKX0lLZe0?35/@3^`J`0k;fW
0>ZiXP3W]9`0hZfF0=^VSP3>VH80_8Ye0:MjI`2@JUP0NEU:06A9?@1<=bh0<RDO01lG4`0E3@/081XH
02/V900e<Bl0?c`k04Q7A@1ADE00FEYI061SH`1XK6`0KgEf6@3oool0@011G6l0@ee^04EMKP17GVd0
BEi/04YNJ`1<GFT0CEeW04iLIP1BGfL0FFE/069]M01[MG`0MGj40829S`2<UIX0VJ6V0:N_]02h_l@0
a/kB0=3Jg`3GhnP0gNW_0>;^m03WloP0joKj0>kho03an_h0m?_n0?Gko@3fn_`0m?Si0?;dm@3_lO40
k>c]0>SWi`3Th^80h=gM0=cHe`3Hdm40e<g;0<o8a@39`Kl0`KRe0;N^ZP2ZXIh0Vi>A08f7Q@20NgX0
LVm_06ARH`1EEEP0BTa?04I9C@15BU00ATeE04IAF@16Ded0AUEQ04IGI015F6L0@eYY049JJ`11FfdT
0?ooo`008P3oool06@2PV9H0Z::P0;2[ZP2h]K@0`Kno0<[:bP3CeMH0g^7S0>__lP3Zl?<0fnCY0<_H
gP2kbm<0Zko809N_^P22WZ`0Ki2O05b2T`1:LhL0=f=i02]IK`0TDVP08TiS029>HP0PC6000P0OBf00
9@0OC60084eQ01m=H@0MBeh07TUL0219F`0SBU/09d]K02]<F`0`CU/0=4mK03UAG00nDU`0@eAM04QF
GP1;EU`0CeIL051FFP1?DeL0C51C04Q<C`13B4/0?d=603Pm@@0`=c/0;C<g034d=`0i?3h0@dA604e<
CP1FEED0H5eM06UUI@1cKVd0O7Ie08InO02?Qh@06@3oool0@02HUI@0Xj6O0:j/Z`2j^;H0a/C20=;@
cP3Ng=/0k>[X0?[hm`3kn_T0lO7a0>GXj03HgMl0c=CG0;g8c02^^l40X[:i09NZ/@2>XZX0QIZR08BI
X025V9l0RIVN08nMX@2CWZ40UZ6S09RRY@2KY:D0WjJW0:2VYP2NXj80W9nN09bLVP2MVYL0WYRD0:2F
T@2RUHl0Xi>;0:F@R02VSXD0Yhb10:J9OP2SQ7L0WWe`09=cIP24Ie`0M5]@069=A01??cP0?C4/02LR
7`0C4a8010H600H61`0E5AD08b8R030_;`0m>c/0BDM605ECDP1QGUd0K6UX07MdL`22OghH0?ooo`10
07n6Q`28SXl0TING09ZOW`2SZ:L0[;6_0;Fi^02o`/00b<_80<_=bP39b/L0a/O40<;3`@30`Kh0_;fj
0;Vj]P2i^KD0^[Ve0;jk]@33_KL0c<>k0=?9`03Kc/@0i=C80>[Hb`3_g<h0m=o@0?OQd@3khm80o^?B
0?gPcP3jg<X0n=O50?KC`03ed;d0m<bh0?;8]03`a:h0k[nY0>^jY03X]Ih0hk2H0=^XT03AWHH0`8mi
0:aoK02GKeh0P5m?06Y>@@1C?C<0>b/U02@K5`0B2`T04@/901lJ600Z9RD0=C8`03lm>`18AdH0D55@
05QJFP1PHf<0Ifa]06meMQT0oooo0400@Ea^049LK@14Ff`0AE]Z04IJJ@17FFH0AeQT04MFH016DUX0
B5AJ055KHP1JHfX0HV]a06]dNP1fOhD0Ph^?092GV`2NY:L0[[>e0;o4aP3>e=H0fN7T0>3Yk03Wl?<0
kOKh0?;jo03eoOh0n?ko0?[oo`3mool0oOkn0?_kn`3hmoH0mO;a0?7^k@3]jNP0j>?R0>?Mg03Nf=D0
fM7>0=?:a`3<`kl0a;^f0;V`Z`2[XYh0WIBA08j7Q020NGL0LFa/06=PH01EDe@0BDQ:03dl?@0i>Sd0
?T=80418C`12C5D0@TmI04=BGP13E640@UIU049HI`11FFX0@5]]903oool00280oooo01X0X9RF0:RQ
X02`ZjX0^;Fd0<6o_`3:b/X0e=GE0=kQhP3Zk^l0l?Kh0>C/k`3Dgn@0a=;I0;C6c`2R^<<0SZRd07fJ
Z01/SId0GH6B04]cQP0lIg/0<Eic02UFJ`0VDVL08DiS01i<H@807D]P02@07TaQ01e<H@0KBel06TQL
01]7FP0NAeT08TYJ02M;FP0[C5/0;deK03I?F`0lDUd0@EAN04MGG`1<F5h0CeQN051GG01@EET0CU=F
04]?DP16Bdh0@TM:03a1A@0f?3l0;c@g03Tl?`12@dH0BT]<05=BD`1LFEX0I65Q06eYJ01fL6l0OWQf
08MoOP2@QhDI0?ooo`1009RET`2RX9h0[J^Y0;Rf]034`L00clg;0=_Ie`3Xi^@0mO;`0?kknP3em?<0
jN[Z0=gPh@3Bf=X0a<g@0;G0a@2[^;`0X:ne09ZZ/02BXjT0SZ2V08bNX`2?WJ80U:2S09JQX`2GXZ@0
VJ:T09bSY02PYZD0X:FT09fQX02JWI`0VIZG09ZGU02KUY80WYB?09nBS@2PT8P0XHf50::;PP2RRGh0
XHEj09aoL`2EMV/0RFaQ07YQEP1ZE4/0F4Ho04Hi=00c:bL07a`K00h?3`000`@03@h?01/K6`0X9bL0
=3<c044o?P1<BTT0F5ED06=PG`1]JfT0N7Ed08>0OQP0oooo0400OXF608J=SP2?UID0UifL0:2UY02X
[J/0/KFc0;Vm^P31a<40bL[70<O8a@34aL40`L6n0;no_02l_;P0^;Re0;Rg/`2i]k80_[Vd0<:l]@3:
`[T0d/Nn0=g>`P3XeLL0kmW;0??McP3ggll0nn7@0?oSd03ohLl0oMg;0?_IaP3ieL80mm6n0?G=^@3d
bKD0l/Ja0>o2Z`3[_:D0j;JO0>>`V@3KZI80dIj80<>AO02`Pfl0W7AR08ISE01`DTD0FD8g048`:@0[
81/0614?00X6100D3`h07a`J02/X9`0e<c80?chm04Q8A`1@DU40F5]K061TI01WKFd0KgEf6@3oool0
@010Ffd0@E]/049JJP13FFP0@eMU04=FHP13Del0@U1J041<E012Be80BE9H059JH01JHVP0IF]`06me
N@1jP8D0QXb@09:HVP2PYJL0/;Ff0<75aP3?dm@0g>7R0>O/k@3`m?D0m__k0?WnoP3looh0ooon0?on
o03oo?T0o_[g0?cgm03il_00m>gZ0?3Wi03/hml0i]gI0=oEd@3HcLP0d<G00<Jl]P2k/:X0[J:M09nD
T02?QX<0P7Qe075[J@1RGE`0De1@04E3A@0k>S`0=CDh03Hg>`0i?D<0>d=:03e8D@0oC5H0@4mK041B
G`10E6<0@5MV041HJ@10FV`T0?ooo`008P3oool0@02PV9H0Z:6O0;2[Z@2h];<0`Kjn0<[9b@3De=@0
g]oP0>W[k03dmoT0koCg0=oWk03@fn40`<oF0:o2b`2K/[d0RjFa07^IYP1]SI`0GX6B051fR014K7l0
>VAh03=NL@0]F6`09eAY02=@IP0RCf@08e1U021?I@0NCV<07D]P01]:G@0LB5`084YL02E;G00ZCEd0
;dmM03A@G@0kDeh0@UIP04UIH@1=FV40DU]Q05=JGP1CFE`0DUII04mCEP1;Ce80B4]>04=7BP0m@DD0
>ce004=4A`1:Bdd0DU5B05UHF01QGUl0JFEU075/J`1iLg80P7Yh08R1O`2@R8DI0?ooo`0G09NDT`2R
Wid0[:VX0;Nd/P31_kd0c<[80=SEe03ThMl0l>g[0?gim`3jmoD0kNc/0>;Si03Gf]`0bm7C0;_5b02a
_<00ZKFi0:>`]02MZk00V:N[09NUZ@2HY:L00P2KY:H09`2KXjD0Vj:T09fSX`2PY:@0Wj:R09bOW`2J
ViX0V9RF09NDTP2HThl0Vi6=09^?RP2LSHH0W8V209f7O`2LQ7/0VH1f09=hKP2:L6H0OFEL06mJD@1O
CTH0CT0j03/c;`0Y9B<06APH00T<3@041`P051DF024Q8@0];Bd0>CPh04A3@P1?CTd0FUQG06ERH@1_
K6/0NGIe08>0O`0H0?ooo`1007j5QP25S8`0SI>C09FKVP2LXZ40Y:VX0:b`[P2d]kD0^kjk0<C6`P34
aL40`<6n0;jn^`2l_;P0^[Zf0;Jf/P2f];00^;F`0;fh/P31^k@0akng0=34^`3Kbkl0iM730>_Fa`3`
fLT0m=_:0?SLbP3lgLX0nm_80?WHa@3ge<40m]6l0?C<^03bbK@0lLJ`0>k1Z`3Z_:H0iKFO0>2`V@3I
Z980cin90<:BO@2bQG80WWIU08UWE`1cETT0GDDk04Hd;@0_91l071DB00/81P0610<05A8A024N7@0/
:RT0=SDd03lo?`18BDT0DE=B05QLG01PI6D0J6e]06meMQT0oooo0400@5]]041JJ`11F6P0@EMV045E
H`10Del0@51K03m<EP0mB500?4E:03m7C017Ce@0D5ML05UPI01TJVh0KgAh07YoPP27S8h0U9VK0::V
Z02a]KH0`<?40<oAd@3KgMd0iNOW0>g_k@3cm?40moOc0?WglP3jmO00n_?^0?[bk03jl>X0mngV0?CX
hP3_hmd0jMcF0>?Ec`3Lc/P0d/Fo0<Rk]@2l[jT0[Z6L09nCSP2?QH40OWIc06mXI@1OFUP0D4a;044n
?`0e=3@0;2//02XZ;@0`<SH0=3To03LoA`0jADd0?4UC03e=F@0nD5d0?e=Q03mEI@0oF6P0?eY/903o
ool00280oooo01/0X9RE0:RQW`2`ZZP0^;>b0<2m_039alL0dm;B0=gMg@3WjNX0m?Kg0?Ojo@3Yko80
f^;W0<_Gg@2lbm<0Z[g609V_^P2:Xjl0O9RU06f<V`1OPI80EGR904eaPP15Jg`0?FEh03IPL`0aG700
0P0/F6`08`0ZEVX09eAX02AAIP0RCf<08DeQ02A=H00XCf00;51P039BH@0gDf00?UIR04EIH`1<G6@0
D5eT05ANH`1FGF80EUaP05IJG@1CEeX0D5=F04i@D`1;CDl0A4Q;04Q:C01=CDl0DU9D05UGF@1OGEh0
IV=S06eYJ@1dKfh0NgEd08=lNP2:PX00THR601T0oooo0400UiBB0:6NW02[Z:H0]K:`0;nl^P39alD0
e=7?0=oLfP3[j>D0moCa0?chm`3aknh0i^KV0=_Mg@3@e=D0`/W;0;S1``2b^kh0[;Ji0:Ja]02R[K40
X:Z]0:6YZ`2RZ:T0XJNX09nUYP2OY:D0Wj:R0:2SXP2OXJ00W9jM09ZJV@2GUY@0UI:@09J@S@2GSXX0
Uhb709N:Q02FQWl0UX=k09AnMP2@NG00R75Y07mYH@1bGUL0I5=<05E7@@13>SH0<B`Z024P800D5AD0
1`/<00lA4P0K7Ad09bPX03<c<P0n?Cd0B4M705=AD01MFeX0IfES075^K@1jMgH0Q85o603oool0@01m
Q8D0Q8^;08^BT@2BV9P0VInN0:2UY02W[:X0[[:`0;Fh]P2l_[/0`<:o0;fn^`2k^kP0^;Re0;Jf/P2b
/Zh0];:^0;Nd[`2l]k40`KZc0<Nn]@3>`kP0elNl0=o<_P3Ucl00j=310>gC`P3adl80lmC20??C`03b
d;h0lLfj0>o9]@3]aK40jl:]0>VnZ@3U^J@0hKBN0=Z]U`3DYY40bYf80;nBO`2`QW@0WgUX08]YFP1f
FTd0HDTo04Xh<00b9b407QPE00h;2@0100002@L701LE5@0S8R40;Rd/03Lh=`11@D40BD];055DE01I
GEd0HFEV06Q]KP1_MWHI0?ooo`1003mJK00oFFX0?eMW03mEI00oDf00?U1M03e=F00kBE<0>DA<03Hn
A@0g?T<0?TE:04M>DP1?EUX0EeeQ069WJP1_LgH0O82208Z>S`2HW9d0YZZZ0;>g]P2o`/80blc;0=GD
dP3MfmP0i>7M0>WUh@3[i^40kNKQ0>oVh03`iMh0l>?K0>kQf@3[g]D0i]S@0>7BbP3Ibl<0dL:k0<Ni
/P2k[JH0[InJ09nBS@2?Q7l0OWEa06eVH`1MEeD0CDU803dj>@0`;Rd09B<T01lM7P0S8R@0:bhb030f
?00d?4@0=d9;03U7D@0kBeL0?4mL03eBH00nE6@0?eMX03mIJb@0oooo000R0?ooo`100:2GU@2WX9h0
[jVW0;Nb/@2o_;/0b<G50=7@c`3KfmX0iNKV0?7blP3joOh0m?Sj0>CZkP3Eg^<0am?I0;K5c@2W^/<0
Ujfg08^S[`1mV:D0L8nM06J6U@1MOXh0EWR704mbP`17K7d0@fUk03eTMP0jHG@0=ema03EML00bFVd0
;eU[02mGJ@0aEVP0=5MW03MHI`0kFVL0@E]W04MNJ01<GfP0Df5X05IRJ01JHVL0Ff5U05]PH`1JGV00
F5]M05EGFP1DEUP0DE9E055BE01BDeD0EUIG05YIFP1PGUh0IF9S06]WI`1aKF`0N79a07ihM`25OG`0
Rh>109:9QaT0oooo0400UY>B0:2MV`2YYZ@0/Zn^0;bi]`36`l40d<g;0=[Ge@3Uh]l0l>gZ0?_fm03f
l_00j^SW0=oOg`3De]L0bLg>0<76b02i_l40]Kbn0:jf^02Z/[@0ZK2a0:R^[P2WZj/0YZZY0::WYP2T
YjH0XJ>R0:2RX@2OX9l0WIfL09ZIU`2FUI<0Ti6?09>>R`2DS8P0ThV409:6P@2?PW`0Sgig08]iLP26
Lf`0OV]T07=RF`1WF580FDe804Y0?@0h<c409bHU01`L7@0?4A803a8C01XL700T9BH0;bl_03Ti>@13
@T80CDa;05IEE01PGUd0JFMV079`K`1kNGL0Q860603oool0@01lQ8@0PhZ:08V@T02@UYD0UYbK09fQ
X02SYjH0ZJf[0:nb/02e]kD0^kbi0;Zk^02g]k@0];Ba0;>b[`2a/:`0/k6/0;Jb[02k]Jl0_[N`0<>j
/@3;_[<0d/6f0=O4]`3LakT0g/Ni0>?:^P3Ub[T0ilZi0>O9^03VakD0iL>a0>6o[@3N^ZP0g;JS0=Zc
W`3F[YX0d:RD0<VPS@31V8H0]hmm0:^5M02KN6P0RV]L07ILC`1SC480CC`d03H[9P0P6QL040d<0040
00020@403`l?01/K6P0V9RH0<34`03Xk>P12A4@0Bde=05=FEP1JGUh0HFIW06Q^K`1_MWLI0?ooo`10
03mJK00oF6T0?UIV03iDH`0mDEl0?4iK03Y:EP0hAU00=T59038k@P0`=S/0=3Tm03e2AP15BTh0CU=F
05QMG`1UJF/0LGEg07j1P`2;SXl0UiVJ0:BUY02`/:h0^KVg0<70_P38a/<0clc80=GAc03Ie<l0f]G?
0=cDcP3Ld/`0g=390=W=a@3GbL40dlFm0<jo]`36]jl0_:jW0;:TWP2WVI@0VHf808YoN`1jLFd0Jf=P
05]ED`1;ATD0>cLg02`Y:P0P7Qh05Q<C01LE5P0Q8RD09b/`02dd>P0a>d<0=41:03M5D00iBUH0>deK
03aAG`0mE6@0?UMX03mIJb@0oooo000R0?ooo`100:2GU@2WWid0[ZRV0;Ja[`2n^[P0a/?20<o=c03H
emL0h^;R0>g^kP3hn_X0nogn0>kam03Pi^X0d]_O0<7>e02d`lX0YkW109b`^@2=Y:l0P9ZV07RBWP1^
RYL0IX>A05mnS01FMhL0DgB304i_O`1:K7d0AVUj04AWN011IGD0?f=c03iQL@0oHG00@V5`04ERK`18
HVl0C6A^059UK`1FIVh0FVM^05eWK@1PIf`0HFIZ065TI`1PHVD0GUmQ05]LGP1JFU`0FEUK05YIF`1K
Fe`0GUeN069PH01VHf@0JfMW071/J`1eL700NgEd085jN@26Ogd0S8B209::QaT0oooo0400UY>A09jK
VP2WY:80/:f[0;Vf]032_kd0c<S60=GBd03Og=T0j^KS0?C`k@3hm?80kNWX0>?Qh03IfMP0cm3@0<O:
bP2o`l@0_<310;Jk_02a][L0/KBd0:j`/02/[Zd0ZZbZ0:JXY`2VYjH0XjBS0::RX02OWYd0WI^J09VG
UP2ETi40TXn=096<RP2ARXH0ShJ208b2OP29OWT0R7Ye08=dKP1lKFP0LfEO06UME`1MDTd0CdM303lj
>00_;R`08B8R01DG600C5AH06adN02@U9P0];Rh0=SHf03lo?`18B4L0DE1@05YIF01SHF00K6YX07Ab
L01lNWP0QH:0603oool0@01lPh@0PXV908R>SP2=Ti<0TiVH09VNW@2NXj80Y:RV0:V/ZP2^/Jl0];Jc
0;Nh]@2c/k00/;2]0;2_Z`2_[ZX0/:fY0;6^Z02g/J/0^[>/0;nf[P37^[00bk^`0<nm/@3C_k80eL2b
0=W1/P3I`;40f/2`0=Zn[P3I^j/0e[NW0=:cXP3?[ih0c:^J0<VVU@33XHl0_IZ90;FCPP2^Rg/0Y89c
09IgJ@26JUd0MEeB06=?A@1>?cP0>BlZ02<N6`0B40h00P410000000;2`/05QHF020Q8@0Z:b/0=3De
03`n?P15AdL0CE1@05AHF01KH600HVMX06U_L01_MWLI0?ooo`1003mJK00nF6T0?UEU03eCHP0lD5h0
>TaI03Q9E00fA4h0<cm7030i@00/<cP0;38f038h>`0k?d80A4Q;04mCE@1IG5l0HfIX06mbL`1lOWl0
RH^<09FFUP2OWih0YjNU0:n^[02g]K40_;Vf0<2m^@34_kX0a/2j0<No^@36_KL0aK^d0<>h/@30]:d0
_:nX0;FYX@2^XIX0YIVC09b@RP2AQX00Q7Ye07E]J@1VGe`0Ee5?04M3@P0g=3@0:2HW01`J6`0A3@d0
40`=01PH6P0P8RH09R/a02/c>P0_>T80<cm903E4D00hBED0>TeJ03]@G`0lDf<0?EIW03iIJb@0oooo
000R0?ooo`1009nGU02VWi`0[JNU0;F_[@2l]kH0a<2o0<c:b@3Edm<0gmkM0>WYj03dmOD0o_oo0?Oi
nP3Zk_00gN?V0<oHg031c=80]<;90:Zj`@2N/;T0TJJ`08VNZ01nUJ00MhnK0729U@1YPi00Hgn<05ik
R@1JMhD0EWB205AaP01BKgh0Cfak04m[NP1?JgP0DVah05E/N01HKGP0Ffig05m^M`1RKWD0Hfec06E]
LP1WKG00J6a_06QZK01UIVP0HF9T05mOH@1OGf00H5mP065PH@1SHF80IF=T06QUIP1/J6T0L6a/07A`
K`1iM7<0OWQg08=lN`28PGl0SXJ309>:R1T0oooo0400UI:@09fJV02UXZ00[JZX0;Jc/@2n^kT0alC1
0=3<bP3IeM<0hmoL0>gXiP3flNh0l>[X0>KRh@3MfmX0e=?B0<_<c035alL0`/C30;fo_`2h^[X0][Nf
0;6b/@2`/:h0[Jf[0:ZZZ02XYjD0YJBS0:>QW`2OWI`0ViZH09RFU02CTHl0THj<08j:Q`2=Qh@0RX>0
08MoO025NgL0PWMb07eaK01dJ6@0JV1L061GD`1CC4T0AD4o03Lf=00X:BT06Q`M01LI6P0O82409RLW
02d^;P0e=SH0?Shm04I5A@1>CDd0EUED05iMG01VI6<0KVa[07IdLP1nNgX0QH>1603oool0@01kPh<0
PHN808J<S02;TI40T9JE09FJV@2JWih0Wj>R0:>WY@2XZjT0[:j/0;6b/02^[Z`0[:bY0:^[Y`2ZZJD0
ZjVT0:jZY@2b[JL0]ZnX0;Z`Z030/jT0`K>Y0<FfZP38]jX0b[N[0<bgZP3=]jT0cKFW0<^bY038[j40
aJbM0<6WV02nXi@0^Ij?0;FIRP2_Th@0Yhan0:65N02JOW40T7EX089ZGP1bGU<0HU1804i1>`0k<Rh0
:B@Q01HE50041@D0000100X:2`0C51@07AhN02HW9`0_<C40>3Xj0412@P18Bd/0Ce9C05IJFP1MHV80
HfUY06Y`L@1`MgPI0?ooo`1003mJK00nEfP0?EEU03aBH@0kCed0>D]H03M7D`0d@dd0<Ce602hg?`0Y
;cD09RX^02T/;`0`=3L0>C`o0455A`1<Ce40EeYK069UIP1]Kg00NGYj08>4Q02<S8`0U9BC09^KV@2Q
XIl0YjFR0:^XY02^ZZH0[jZV0:nZY02^Z:80[:JO0:ZRW02VWYL0XIRB09ZAR`2CRH@0S89m08=jM@1i
LFd0KVIS065JF01BCD/0@Sln03@a<@0W9RH071XK00l<300<2@T04a8D01TK7P0P92T09B`b02Xc>`0^
>T<0<Sm:03A4D00gBEH0>DeK03]@G`0lDf<0?EIW03iIJb@0oooo000R0?ooo`1009nFU02UWY/0[:FS
0;>]Z`2j]K<0`Kfl0<W6a03Bclh0f]SH0>CShP3_k^d0no_k0?ooo`3emoP0j>_]0=_Ph`3>e]X0`/cA
0;[5b`2__<<0Y;>j09^[/`2@XZX0R9^T086EWP1kT9X0M8^E0727T@1/Phl0J7n;06AlR01RNXH0H7N3
05mfPP1PMH00I7N106AfP01WMh00JgQo06ehOP1_Mg`0KgIj071eN01aM7H0L79d06i_L@1^K6h0JVQY
06AQHP1VI6D0IfEV06QVIP1ZIfL0K6UY06i[J`1aKFd0MG1`07UcL`1mMgH0PG]i08IoO@2:Ph40ShN4
09B;R1T0oooo0400U96@09bIU`2SX9h0ZjRV0;:_[@2j]kD0`[nl0<[7a03Bcl`0fmOD0>COg@3]j>D0
l>[X0>WThP3Pg=/0f=GC0=3>c@39bLP0alK50<;2`@2n_K/0^kVg0;Fd/P2c/Jl0[jf[0:f[Z02YYj@0
YZ>Q0::PWP2NW9X0VYRF09NDT`2BShh0SXb:08Z7Q@2:QH80QX1n08=mNP22NGH0OWAa07I]JP1]IF40
HU]H05MBD01;B4H0?Sdm034b<P0T9RL06Q`L028S8`0Y:RX0;c0`03Hg=`0n?Sh0ADE404a<B`1DDe80
FeYI069QH01ZJ6L0LFm^07QfM01oO7/0QX>2603oool0@01kPX<0OhJ708B;R`29Shl0SI>C09:GUP2F
ViX0VYjM09jRX02QYJ<0YJNU0:NXYP2WZ:D0YZNT0:JVXP2UY:40YZBP0:NTX02ZYZ00[ZRQ0;6YX@2e
Zj80]j^R0;Z]XP2l[J80_ZfR0;j/X02nZil0_:VM0;ZVVP2gXiL0]:2C0:nKS`2[UXX0Y9240:6<O`2J
QGT0U7md08iiKP26LVP0NfQO06aLE01MD4T0C4<m03/e<P0Z:2H06ATI00T;30010P<02@X;018C500K
71d092DV02`^;P0d=cL0?3lo04A7A`1;CTl0DUIF05QMG@1NI6@0I6Y[06YaLP1`MgPI0?ooo`1003iI
K00nEfP0?5AU03]BH@0jCed0>4]H03I7D`0c@Td0<3e602`f?P0W;SD082@X01dO8P0T9RT0;C0b03Hh
>P0o@T<0B4]<055DE01JGEh0I6MW06i_K`1hNGP0Oh2008F6QP2;RhX0T8n>09>AT02DTY00UY>A09JC
T02ETXh0Thn;092<R02;QX80QH1l081jMP1iLfl0LVaY06YUHP1PFeT0E55?04Q5A00j>CP0;Rd]028Q
8P0E5AH02`/<00T82@0?3Pl05AHI01/N8`0P9R`09Bhe02Xe?@0^>d@0<D1;03A5D@0fBEH0>4eK03Y@
G`0lDf@0?EIX03iIJb@0oooo000R0?ooo`1009jFT`2TW9X0Zj>Q0;6ZZ@2h/[00_[Vh0<K1`03=b/P0
eM?A0=kLf`3Xi^D0l_3`0?gkn`3oo_h0m?Ce0>OYjP3Jg^00cmGH0<O>d@2oal`0]Ko40:fh_@2S[kH0
VZN^09>QZ@2=W:@0R9RO08:CV`1mSiL0NH^D07F7T01bQ8h0L86;06j0R@1^OXL0LX2807F1R@1hPXT0
NX:807b1QP1mP8@0O7n107YlOP1iNW/0NGQi07EeMP1bL780KVa^06e[J`1]JV/0KV][06i[K01`K6`0
LVi^07A`K`1fLW40NGAc07egMP20NWT0Q7el08R1O`2<Q880T8R509B;RAT0oooo0400U96?09^GUP2Q
WY`0Z:FS0:n/ZP2f/k00_KVg0<C1_P3<b<D0dlo<0=_Fe03RgMX0jNCQ0>_UhP3Tg]/0fmOE0=;?c@3<
b/P0bLK40<K3`@31_[`0_[^h0;Vf/`2d/Jl0/Jj[0:fZY`2YYZ@0YZ>P0::OW@2NViT0VINE09FCT@2@
SX`0RhV808N4P`25PGl0PWil085lNP1oN7D0NG5_075ZJ01WHV00G5QF051>C@16ADD0>C/k02d`<00T
9RH09BHV02`];@0c<c<0>CTi03lo?`16ATD0C4a;05=BD@1JF5P0H5mN06MUI01]JfX0M75`07YhMP20
OW`0QhB2603oool0@01jPX80OXF608:9R@26SHd0RY2@08jDT`2BUiH0UIZI09VMV`2KWih0WZ6O09nR
X02PXYl0X:6O09nPW@2OWi`0WYjK09nNVP2RWiX0YJ2J0:JPVP2ZXYX0Zj:I0:bRV@2^XYT0[Z6H0:fP
UP2]WiD0[9jC0:ZKT@2WV8d0XiB:09n?Q@2IRX00ThAk08inM026Mfl0PWA[07a^IP1cIEh0IU]E05U@
B`1;AD00>cPe02`[:P0M7al03a8C00D720082@T04Q@D01/M7@0S9BH0:bd^03<e=P0j?Cd0@DA504Q;
C01>DU<0E5UI05YOH01PIVH0IVa]06]bL`1aN7TI0?ooo`1003iIK00mEfP0?5AU03]BH@0iCed0>4]I
03E7E00c@Th0;ce702`g?`0W;cH08BL/01XM800H6A/07b4S02T[;@0a=CH0>Cdn0454A@19Bd`0DE=C
05UKF`1QHf<0J6YZ06i`K`1cLg<0MWIg07UjN@1lO7/0OGel07imO01mO7X0NgYh07QfM01dLFl0K6YW
06ARG`1OGE/0FEQF055@C`16ATH0?C`m03<c=00X:2T071dN01<C500;2P/01@8200P61P0@4A@05aXN
01`R:00R:S009S0h02Xf@00^?4L0<D5=03A6DP0fBUL0>4eL03Y@H00kE6@0?EIX03iIJb@0oooo000R
0?ooo`0a09jETP2SViT0ZJ6O0:nXYP2e[jd0^kFd0<:m^`39a<<0d<c;0=SDd`3PgM`0jNKU0?7_k`3k
n_T0oO_k0??al@3Ui^L0fM_M0=3DeP3;cm80a<W<0;g2a@2e^kh0Zk>h0:B]/P2NYj`0V::X09>NY02>
VZ00RIFL08JBV@22SYH0P8bC07b8T01kQXd0OHJ<07n6S@25RXh0R8^>08R9S028R8/0QXF708>2P`20
Oh00OWem07ekN`1hMWH0MW9c07AaL@0207A`L00=07EaL01fLG40Mg9b07UdL`1kMWD0OWQg081jN@23
OG/0Qh1n08Z2P@2>QH<0THV609F<R@0I0?ooo`1009>@SP2IUY@0WibJ0:FRX02[Z:H0/Zj/0;Rd/P2n
^[P0aL6n0<_7a@3BcL/0f=?@0=kIeP3Tg]/0iMoL0=kHe@3EdLh0c/[80<W5``36`/00`knl0<2k]`2k
][<0]K6^0;:]ZP2]ZJH0ZJJR0:JRW`2QWY`0W9ZG09RFU02CTHl0Shf;08V7QP24PX00PGmm07ilN`1o
NgT0O7Ie07A_KP1^JFL0IF5O05QFE@1<C4`0@T=303Pj>`0];c00;2d]038b<`0h>3P0?Cdm04=3@P18
B4P0CTe=05ACDP1IF5P0GeiM06ESH`1[JFP0LFm]07IdL`1lNWP0PWmn08N5PaP0oooo00/0NX6207f4
Q@21R8P0Q8^;08R>SP2;TI00SY>C096FU@2DV9L0UYZI09RKVP0209VLVP0609VKV@2IViP0V9ZG09RI
U@2IV9@0VINC0P2KV9<0:`2NVI80WiRA09jGT02OUhl0WiJ>09nES@2NU8/0W9::09V?Q`2FS8@0TXR0
08j4O@29OgP0PgUb07edK@1hL6X0Lf]V06aTG`1QFUH0Ee9>04a8A@0n?3X0;c0_028T900E6AT02@`=
00X<3@0D5QH071hO02@V9`0[;Rl0<SDf03Tm?@10@d@0ATY:04a@D@1BEeL0F5eM05eRH`1RJ6T0Ifi^
06acM01aN7T06@3oool0@00nFV`0?EMY03aEI@0kDV80>DmN03M<FP0eB5D0<d=?030nB@0/>D809c8j
028Z<@0M8RH05APJ01@F5`0K7R0092PY02d`<P0d=SP0>3/m03i1@`15B4X0Bdi@059DE@1GFUX0FeiO
05mRHP1RIFD0I6MW06EWI`1UJ6L0IFMW06AUI@1RHf<0GEmO05QJF`1BEEH0BTe?04=5A`0k?Cl0<cDg
02`^<00S9BL06Q/N010A4`0720T00P0000@20P0=3@l04aLJ01TO900O9Rd08bde02Pc?@0[>D<0;ci:
0393C`0dAe@0=T]I03Q>G@0jDF40?5AU03eGJ00nFF`T0?ooo`008P3oool0<P2MU980XYZG0:NOW@2/
YJ<0/Z^Y0;Na[`2m^;H0`kjm0<[5a03Ac</0f=CC0=oLf`3Wi><0knc[0?Sfm@3im_D0knc/0>CSh`3I
fMX0dmCE0<k@d@39bl`0`/C60;^m`02f^;/0[k>f0:V]/02TZJ`0WZBX09VPY02EW:00TIRM08nEV`2;
TYL0QhjB08J<T027S900RhfA08^=S`2<S8h0S8^=08b:R`29QhL0QhB408B1P@22Ogl0OGYj07ahN01k
MgH0NWIe0P1jMGD0301kMWD0O7Mf07ihM`1oNWT0PW]j08AmO026Ogh0RH:008b4PP2?QhD0TXV709F<
RQT0oooo00h0TXn>09RDT`2MVYP0XYnM0:RTXP2]ZZP0/jn]0;Rd/P2n^[P0`knm0<W4`P3>bLL0dlk<
0=SCd080g]SE0300em7=0<o:a`38`l40aL2m0<:m^P30^[H0^kFa0;F`[02a[:T0[JRU0:VUX@2VXIh0
XIfJ09bIUP2GU980THn>08j<R`28QXH0PX6007inO@1lNgX0OGYh07UeM01bKVd0JfQW065OG`1EEED0
Bda<0412@P0i>cX0=CDf03Xj>P0n?Sh0@d9204M7A`1<C4/0DE1@05IEE01KFUT0H5mN06ESH`1ZJ6L0
Kfe/07AbL@1iMgH0OWaj08>0O`28QH@H0?ooo`1007V1P@1lPh@0OhJ708:9R@25Rh/0R8j>08^@T02=
TY80SiBC096EU02BUYD0TiNE09BGU@2DUYD0U9JD09>ET`2BTi00TI6>092@S02AT8`0THn;09>?RP2B
SXT0Shb608n;Q@2?RX@0ShZ308n9PP2=Qh00RXAn08N2N`23OGP0OgYe07YeL@1fLFd0LFiZ06eYIP1[
IV<0I61L05YFE01@CT/0@T9103<f=@0V:R/06AlP014E5P0?4Q<061XK01lR8`0V:BX0;C0a03@g>00j
?Sh0@4A504I:B`1<D540DEIF05IKG01KH640H6EV06AZJ`1YKg00KGAe079iNQT0oooo0400?UY/03eG
J@0lEFH0>e=S03U@G`0hCE/0=TUG03=5DP0`@4`0;C]602Te?P0T;cH07bL]01XO900C5QT04Q@F01PK
7@0O8b@09RX/02/_<00_<S<0=3Lh03Pl?@0k@440?T=50497B@17C4d0BTm@04eAD`1>De@0CeAE04mC
E01=DU<0C55C04]@D`18CU80A4U=0415B@0j?d<0<cLk02X^<@0P92L05QXM00hA500620X0000100<1
0P0:2`h04A@H01LM8P0L9B/08B/c02Hb>`0Y=d40;Ca70311C@0cAE80=DUG03M<F`0iCel0>U9R03aE
IP0mEfT0?UU/903oool00280oooo00l0WIBA0:6HUP2UWI/0ZZ:P0:nWY@2c[J/0^;:`0;jh]P33_[`0
bLC30<o;b@3FdM00g=SG0>?PgP3[inH00P3dl>l08@3[inH0gmgM0=SGe`3Dd]<0dM3@0<_:b`34`l@0
_kk00;^j_02h]kP0/k>d0:f^/02XZJ/0Y:FX09nQY02LWZ40V9ZN09NHV`2BU9L0U9FG09NEU`2HUIH0
V9BD09NBT`2ETI40Thj=08f9R@2:QXD0R8B308B0O`22OGd0P7]k07mjNP0207mjN@0<081jN@21NgX0
PWak08AmO025Ogd0Qh1o08V2P02<Q880SXJ40968QP2CRXP0UXf:6@3oool0@02BShd0UY>A09^GUP2O
W9X0Y:6O0:VUX`2]ZZP0/Zj/0;Nc/@2k]kD0`;bi0<G0_P39a<80cLS60=;<b@3FdLh0e/o<0<o9a@37
`[h0`Kbi0;ni]P2m]k@0^;>_0;:]ZP2_ZZL0ZjJS0:VSX02UX9d0X9bI09^HU@2FTi40T8j=08f;RP27
QXH0QH>207emO@1mO7/0O7Uh07IcL`1`KVd0J6IV05mNGP1FEUH0BTa<0493@`11@D00@d9204I6A@1:
BDT0CTe=059AD01FEE@0FUUH05iMG01RHF00IfET06]YJ01_KF`0Lg5`07QeM01lNWP0P7il08F2P029
QX@H0?ooo`0;07V0P@1kPX<0OXF50827Q`23RHT0QH^;08N=S@29Shh0Ri2@08bAT@2=TY400P2>TY40
<`2>TY00SY6?08f?S@2;SHX0Rhb908R:QP28R8D0R8N308R7PP26QH00Q8=n08>2OP22P7`0PGmj085o
N@1nOGP0NgYe07QgL`1eM740LW9^06e]J`1[JfP0I6ET069SH@1NGed0EEMF04e?CP12ADD0=SXk02`a
<P0O9RL05Q/L01LJ6`0M824092LX02/^;`0a=CH0=c/l03e1@P12ATL0Ada=04aADP1AEUL0EU]L05YP
H01OI6D0HfUY06M]KP1[LG80KWEf079jN`0I0?ooo`0O03iJK00mF6X0?5IW03]CI00jDF40>4iM03I;
F@0dAeD0<T=@02loBP0[>D@09c@m02<]=@0N9R`061hS014D5`0@4Q@05QTK01`P8P0P92H08bLY02HY
:`0X;Bh0;38c02le=`0`=cP0<SPj03Dl?P0h?d40>D1203U1@`0203Y1A@0O03Q0A00g@4@0=Si303<k
@00^=S/09Rld020W;00H7b<041DJ00X>4P041`X0000100810P092Ph041@I01HM8`0L92/082/c02Da
>P0X=T40;3]702m0C00aA540=4ME03I;F@0hCUd0>E1P03]CI00lEFL0?EQY03iJK00T0?ooo`008P3o
ool0<P2LTi00X9ND0:>KV02WWid0ZjBQ0:nXYP2c[J/0^;6_0;ff]@31_;X0al6o0<c7a@3BcL/0f=?A
0=kIe`3Th=h0kNSV0>oYj03Yhn80gMWH0=KBd@3Bc/h0d<g=0<g9b@39aLD0aL710<2l_02m^KT0^kNg
0;Jb/P2_[:`0ZJNY0:JTY@2RXJ<0XIjO09^JV`2LVY/0WYZJ09jIV@2NV9L0W9JF09ZDT`2ITY40T8^;
08j9R02;QXD0RH>308N1P025P7l0Q7mn0P24OWd03025OWd0QGmm08IoOP27P7l0RH:008Z3P@2<Q880
SXJ40928Q@2BRHL0U8^909J=RQT0oooo0400THj<09FAT02IUI<0W9VG0:2MV`2TXIl0Z:BR0:bXYP2`
[:X0];2]0;Nc/@2k]k@0_kZh0<:n^`36`Kh0bLC10<g7a03;aL40a/2m0;nj]P2k]K80]k6^0;>^Z`2_
ZZL0ZjJS0:VTX@2VXId0XYjJ09jJV02KV9D0UY>A092>SP2<RhT0R8N708F4Q01nOWh0OGel07YiN01e
Lg<0L6e]06MVIP1OGel0FUUH04a=C@1;BdX0CTe=051?C`1BDU40EEAD05QGE`1LFeX0GeiM069QH01V
I6<0JFQW06e[JP1aKfd0M79a07QeM01kNGP0Ogak08:0OP26Ph80RXN5603oool02P1hP800NX:207b3
Q01nQHH0P8N708:9R@24RXX0QX^;08N=S028SHd208V>S@0@08Z>S@29SH`0RHb;08N;R@25R8H0P8>1
0822P020PWl0P85n07moN`1kO7T0MgUf07IgM01gN7@0MWMc07=eL@80Kg9_0280KW5^06]^K@1XJfX0
IFUY06=WIP1MHF80FemO05IJFP1?De<0AT];03a2@`0b>CX0;38c020U9`0P92D09bX[02``<@0b=SL0
=c/l03a1@@11ATH0AT];04]?D01?E5D0DeQI05MLG@1KHF40GfAU069XJ@1VK6d0JG1a06acM01`MgP0
LgYk6@3oool07`0nFVd0?UQZ03eGJ00lE6D0>U9S03U@G`0gCE`0=DYH03=7E00a@dl0;Si:02XiA00W
=3d08Rhf01dW;@0H7b@041DH00/>400?4aD05a`N01dR900N8bD07B8S01`R900M8bH08BPZ02@/;P0S
;2h08R/_02D_=00Y=3T00P0[=S/07`0/=S`0:cHm02Xe?00X<cX08bhe01dW;P0F82H041PM00TA5P05
2`l00PD700D6200;3a<04ALM01LO9P0L9Rh08B`e02Db?00X=d80;3a802i0C@0aA540<dME03E:F@0g
CE`0>E1P03YBH`0kE6D0?5IX03eHJP0nFVd0903oool00280oooo0340Vi:?09jET`2QVIH0Y9bJ0:RP
W@2[Xj40[ZNU0;:[Z@2f[jd0^[>a0;jg]@32_;X0a/2o0<_5``3@b/T0e]3>0=_Ed`3Pf]P0iMkL0>?L
fP3Idm80dlg;0<k9b03<a/H0bL?30<S2`035_[d0`KZh0;ff]@2j];80]Jn]0;6[ZP2[YZD0Yj>S0:FQ
X@2SWil0XIjM0::MW02SWI`0Xi^J0:6JV@2MUiH0W9FE09F?SP2AS8/0ShV808f6Q@2;QH<0RX>20080
RH:10P29PX002`29PX40RX>108^4PP2<Q8<0SHF308n7Q02@R8H0TXV709>;R02ES8T0Uhf;01T0oooo
0140T8f;09>@SP2FTi40VIJD09bIU`2OW9X0XinM0:JRX02YYJ<0[:RV0:n[Z@2b[Z/0]K2^0;Nc/@2j
]K<0_KRe0;ni]P020<2j]`0]0;jh]02f/Jd0/ZbX0:bXY@2ZYJ80Yj:P0:JQWP2RWYX0Wi^H09bIU`2K
V9D0UY>@09:?SP2=RhX0RHR808F4Q021P800OGem07YiN@1fM7@0L6i]06YYJ@1SHV40GEaK05MFE@1I
F5L0FeYI05aKF`1OGEd0HEmO06=RH@1VI6<0J6MV06]YJ01^K6/0LFm^07=aL01fM7<0NGMf07ajN01o
O7/0PWmn08F2P027QH<0RXN601P0oooo00X0N7n007V1P@1kPX<0OHB407j5Q@20QXL0PHN808:8R@23
RHT0Q8Z:0`25RXX0<`25RXT0Q8V808>7QP21QH<0OX:007]nO01iO7X0MgYg07EhM@1bMW<0LGAb071c
L@1_LW00K71^06]`KP1[L6l0K71_06Q]K@1WK6`0IFY[06=XJ@1OI6D0Ff5Q05IMGP1AEeT0Be1A04=8
B@0l@T<0=CXk02hb<`0Z;c00<CHg03Hk?00k?d00?dA504=8B@18CDd0C55A04mEE@1CF5T0EUaM05YP
H01MHf@0H6IW06=YJP1VK6d0JFm`06abL`1^MGH0LGQi07=kO00I0?ooo`1003mKK@0nFF/0?EMY03aF
I`0kE6D0>U9R03U@G`0gCE`0=DYI03=7E@0a@e00;Sm<02/kAP0W=T008c0i01lZ<P0I8RT04a/P00hC
5`0>4aH04QTL01HL800G7R405alR01PQ900H8RH062<W01XV;00N:S4082`d020]=P0R<3T09C<l02Hc
?@0T<CX08blh024]=P0L:3005b4Y010J800<5AX02Q0D00D930072`l03aHK01DM900J92`07RXc028`
>P0V=D00:CY502`nBP0_@Tl0<DEC03=8E`0eBeX0=deM03Q@H00jDV80>eAU03aFI`0mEfT0?UU[03mJ
KB@0oooo000R0?ooo`0b09^ASP2MTi40WiJD0:6IUP2TViT0YYjL0:VQW`2/Y:80[ZNU0;6ZZ02d[J/0
^;6_0;^d/P2o^;H0`[bi0<K0_@3:`l40c/O40=;;b03Gd<d0elo<0=G<b@3?alD0b<6o0<No_P36_[d0
a;^i0<2h]P2l]K<0^[:`0;N_[P2e[J/0/JZX0:nWYP2ZY:<0Z:>Q0:JQX02TX9h0Y9nN0::LV`2UWih0
XibK09bEU02GTHl0U8f<09:;R@2@RHL0ShR608j7Q@2=QX@208f5Q00<08f5P`2=QX@0SXJ408n7Q02?
QhD0T8R60969QP2BRXL0Th^809F<R@2FSHX0Uhj;6@3oool04@2?S8/0TXj=09BAS`2FTi40VIFC09^H
UP2MVYP0X9bJ0::NW02TXIl0YZ>Q0:VUX`2[YjD0[JVV0:nZZ02`[:T0/ZfZ0080/jj[00D0]:n[0:nZ
Y`2/YZ<0Z:BQ0:>OW@020:6MVP0@09nKV02MVIL0ViNE09RET`2ETI00TXn>08j;R`2;RHP0QXF408>2
PP1oOgl0NgYj07QgM@1`Kfh0KVe/06YXJ080IVAT01@0IfET06QVI@1YIfH0JVUX06aZJ@1^K6/0L6i]
079`K`1dLW00MWAb07QfM01jN7H0O7Yh07ilNP20OW`0PX1n08F2P027Q880RHJ408^8QQP0oooo00X0
Mgn007R0P@1jPH80Nh:307b3Q01mQ8@0OXF507n6QP20QXH0P8N70`21QhL0<`21QXH0P8F507n4Q01m
PX80Nh1o07UmO01eNWT0KW=b06]aK`1/LW00Jg1`06U^K@1XKVd0J6m^06U_K`1YKfh0J6i]06E/K01T
JV/0H6MY05iUI`1LHf@0FF1R05ILGP1AEeP0CE9C04A9BP0n@d@0>cm003/o@@0oA4D0@TM904I;C019
Ce00CE9C051EEP1CFEX0EUaM05UOH01LHV80GVAU065WJ01SJVX0IVa]06Q^K`1ZLG80K7=d06ieMP1`
MgP0LWUj07AlO@0I0?ooo`0D03mKKP0nFV`0?EQ[03eGJ@0lEVL0>eAU03YBH`0iD640=diN03I<F`0d
BEP0<TID0313D00]?d/0:SY602Hf@00R<3X07R/c01TU;@0C72<200dF7009018L8P0F8BH05B0U01DQ
9P0G92/06RP_01d[<P0M:c<07B`e00807B`g01l07Rdg01h]>00M:cH072Tb01/T;@0G82P04QXP00`B
5`0:41D03aHM01DO9`0J9Rl07b`f02<a?00V=T80:CY702`nB`0_@Tl0<DEC03=8E`0eBUX0=TeL03Q?
G`0iDF40>U=S03]DI@0lEVL0?EMY03eHJP0nFF`0?e]]02@0oooo000R0?ooo`0H09ZASP2KTXl0WIBA
09jET`2PUiD0XYVG0:>KV02UWIX0YinM0:VQW`2[Xj40[JFS0;2XY@2bZZP0]:fZ0;N_[@2j/Zl0_;Bb
0;ng]031^KH0`[Vf0<:j]P35_;P0`KVf0P2n][<05`2m]K<0_KFb0;Za/02d[J/0/ZZY0;2XYP2]YZ@0
[:FS0:ZSX@2WXIl0YYnM0:BNW02YXZ00Y9jK0:6JV02NUiD0ViBB09RAS`2FSX`0U8f;09>;R@2BRXP0
THZ80080THV70P2ARHH20969Q`0909:9Q`2BRXL0ThZ809B;R02DRhT0UHb909J=RP2GSH/0V8j;01T0
oooo0140Sh^:092=R`2BSXd0Ti2>09FBT02FTi40V9FC09VFU02KV9H0W9VG09jJV@2OW9X0XIfK0::N
W02SWid0Y:2N0:FQW`020:JRW`0I0:JQWP2TX9d0XijK0::NV`2LVIL0VYND09^HUP2JUiD0ViND09VE
T`2ETY00Ti2?096>S@2>RhX0S8V908V7QP26Q8@0Ph6007akNP1lNgT0MgEd07IdL`1fLg80M79a07Aa
L00207AbL@0B07EcLP1fM7<0MgEd07QfM@1jMgH0NgQg07ajN01nNgX0Ogak081nO022Ogh0Ph1o08F2
P026Ph80QhF308V6Q02:QhH0S8V7603oool01@1gOWl0N7n007R0P@1iPH40NX620080Nh:300<0O8>3
07b3Q01mQ8@00`1mQ8@0<`1mPh<0O8>307b2PP1kPH00NGmo07MmO@1eNWX0LWMg06meM@1/LW<0Ifi_
06M]KP1XKfl0Ifi^06Q^KP1YKfl0J6m^06Q^K`1VKFh0I6]/069YJP1PIfP0GVEW05]QH`1BFEX0CeEF
04]AD`1=DU@0CeAE04mEEP1AEeP0E5YK05ILG@1HGUl0FV5R05eSI01OIFH0HFMX069YJP1TJf`0IVe^
06Q_K`1YL740Jg9c06acM01^MGH0KgMg075hN@1bNGX0Lg]l07ElO@0I0?ooo`0P03mKK@0nFVd0?UU/
03iIJ`0mF6X0?5MX03aEI`0kE6D0>U=S03UAH@0hCel0=TeM03E;FP0cB5L0<DEC02i2D00/?d/0:C]7
02Hg@P0R<Sd07bhi01d[=P0I9c8062D`01TW<@0J:C806RPa01/Z<P0N;SH08C4j02<c?@0S<cl2028c
?`0N028c?P0S<cl08C0l01/X<P0E8BT05R4Z01XV<00M:S@07bhi02<c?P0V=d@0:Ca802`oC@0^@U00
<4ED0398E`0dBUX0=TaL03M>GP0hD640>E9R03YCI00kE6H0?5IW03aGJ00mF6X0?UU[03iIK00nFVd0
?e]^903oool00280oooo0300VI2=09Z@SP2KTHl0Vi:?09bCT02MU940WYFB09nFT`2PUi@0XIRE0::I
UP2SVYP0Y9^I0:FMVP2VWY/0Z9nL0:VPWP2ZXYl0Zj>P0:bTX@2]Y:40[JFQ0:jUX@2]Y:40[:>P0:bT
X02/Xj00[JFQ0:nVXP2^YJ40[JBR0:bSX@2[XYl0ZZ6O0:VQW`2YXIh0YinL0:6IU`2PV9D0WYJD09fD
TP2KTi40VY6?09R@SP2GSh`0UXj;09J=R`2ESHX209F<RPD0UHb90P2ES8X309J=RP0409N=R`2GSX/0
V8j;09R>S1T0oooo0100SX^908n;RP2?S8/0T8f;096>S02BShd0TXn>09>@SP2DTHl0UI:@09JBT02F
Ti40UiBB09RDTP2HUI<0VIFC0`2IUY@209VET`0609RDTP2GTi40UI:@09BAS`2ETHl0U92?0P2ETHl0
3@2BShd0T8j=08n<R`2>RhT0S8Z808^9Q`29QhH0QhB308:0OP23PGl0PX1o089oOP21Ogd01021OWd0
4P21Ogd0PWmn08:0OP23P7l0Ph5o08B1P025PX00QH>108J3PP27Q880QhF308R5Q029QX@0RXN508Z7
QP2;R8H0S8V708b9R1P0oooo00<0MWio07MnO`1gOh000P1hOh00101hP840NH2107V0P@1iP84207V1
P@80NX610P1iP840201iP800N7mo07MnO`1fOGh0MGal07AkN`1bNGX0LGQi0`1_MWL206ieMP0:06ec
M@1YLG80J71b06M^L01VKFl0IFa^06A[K@1RJV/0H6MX05iUIP80HFQY01P0HVQY069YJP1SJV/0I6]/
06E/K@1VKFh0Ifi_06Q_L01YL740JW5b06]bL`1/Lg@0KGAe06ieMP1_MWL0L7Mh071hN@1aNGX0LWUj
07=jN`1cNg`0M7am07ElO@1eOGhI0?ooo`80?e]^01D0?e]]03iJK@0nFV`0?UU/03eIJ`0mF6X0?EMY
03aFJ00kEFL0>eAV03YCI00iDV<0>51Q03M?G`0eCEd0=4]K0399F@0aAeH0;dED02i3D`0]@U400`0/
@E001P0/@4l0:cm>02PlB`0W>TX09SY802HjA`809SU701`09CQ602DgA00T=T<09cY702XnB`0[?dd0
;45?02i3DP0_AE@0<DMG03=:F@0dC5`0=TeN03M?H00hD640>E9S03YCI00jE6H0>eEW03aFJ00lEfT0
?EMZ03eHJP0mFF/0?UU/03iJK00nFVd0?e]]0P0oFfhT0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00CP3oool2@00005L0oooo0T00001F0?ooo`900000E`3o
ool2@00003H0oooo001@0?ooo`03@000003oool0oooo05H0oooo00=000000?ooo`3oool0E@3oool0
0d000000oooo0?ooo`1F0?ooo`03@000003oool0oooo03<0oooo000Z0?ooo`E000000P3oool00d00
0000oooo0?ooo`020?ooo`03@000003oool0oooo00/0oooo0d0000020?ooo`9000000`3oool3@000
00D0oooo00=000000?ooo`3oool0:`3oool3@0000080oooo0d0000030?ooo`03@000003oool0oooo
00/0oooo0d0000020?ooo`9000000`3oool3@00000D0oooo00=000000?ooo`3oool0:P3oool3@000
00<0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`0;0?ooo`=000000P3oool2@000
00<0oooo0d0000050?ooo`03@000003oool0oooo02/0oooo0T0000020?ooo`E000000P3oool00d00
0000oooo0?ooo`0;0?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000003oool0oooo
02d0oooo000/0?ooo`07@000003oool0oooo0?oood000000oooo@00000020?ooo`03@000003ooom0
000000/0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0oooo@00003<0
oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003ooom0000000/0
oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0oooo@0000380oooo00=0
00000?ooo`3oool00`3oool01d000000oooo0?ooo`3ooom000000?oood0000002`3oool01T000000
oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000=@3oool01D000000oooo0?oo
o`3ooom0000000<0oooo00=000000?oood0000002`3oool01T000000oooo0?oood000000oooo@000
00@0oooo00A000000?ooo`3ooom00000=@3oool002`0oooo00M000000?ooo`3oool0oooo@000003o
oom000000080oooo00=000000?oood0000002`3oool01D000000oooo0?oood000000oooo00=00000
0P3oool014000000oooo0?oood00000d0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3o
ool00`3oool00d000000oooo0?ooo`090?ooo`05@000003oool0oooo@000003oool00d0000020?oo
o`04@000003oool0oooo@00003<0oooo00=000000?ooo`3oool00P3oool01d000000oooo0?ooo`3o
oom000000?oood0000002`3oool01D000000oooo0?oood000000oooo00=000000P3oool014000000
oooo0?oood00000d0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00`3oool00d00
0000oooo0?ooo`090?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0
oooo@00003D0oooo000/0?ooo`03@000003oool0oooo0080oooo00M000000?ooo`3oool0oooo@000
003ooom0000000`0oooo0d000000103ooom00000@000040000030?ooo`=00000=03oool00d000000
oooo0?ooo`020?ooo`04@000003oool0oooo0?ooo`9000003@3oool3@00000040?oood0000100000
@00000<0oooo0d00000c0?ooo`03@000003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oo
od00000<0?ooo`=0000000@0oooo@0000400001000000`3oool3@00003D0oooo00E000000?ooo`3o
ool0oooo@00000030?ooo`9000003@3oool3@00000040?oood0000100000@00000<0oooo0d00000e
0?ooo`00;03oool01d000000oooo0?ooo`3ooom000000?oood0000000P3oool00d000000oooo@000
000>0?ooo`03@000003oool0oooo03/0oooo00=000000?oood0000000P3oool00d000000oooo@000
00020?ooo`03@000003oool0oooo00h0oooo00=000000?ooo`3oool0>P3oool00d000000oooo@000
00020?ooo`03@000003ooom000000080oooo00=000000?oood0000003P3oool00d000000oooo0?oo
o`0k0?ooo`03@000003ooom0000000<0oooo00E000000?ooo`3oool0oooo@000000@0?ooo`03@000
003oool0oooo03d0oooo000[0?ooo`900000103oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo00`0oooo0T00000n0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3oool0oooo
0d00000=0?ooo`900000?@3oool014000000oooo0?ooo`3oool3@00000<0oooo00=000000?ooo`3o
ool0303oool2@00003h0oooo00A000000?ooo`3oool0oooo0T0000030?ooo`=000003@3oool2@000
03l0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo000R0?ooo`P0Ig1c201XL7<00`1YLG<0JG1c06U`
LP0206U`LP0406U`L@1YKg00JFi^06Y`L@<0JG5c00D0JG9d06UaM01YLG@0JG5d06UaL`0306QaL`0G
06QaM01XLWD0J79e06UcMP1YM7L0JGEh06YeN01ZMWT0JWMj06YgN`1[N7`0K7Yn06imP@1/NGd0JgQk
06YgNP1ZMWT0JWEh06UeN01YM7P0JGAg06UcMP1XLgH00P1XLWD00`1XLW@0Ig5d06MaL`0I0?ooo`04
079eMP1bM7H0LWAf079dMP<0LGAe00D0LG=e075cM01aLg@0LG=d075bM003075bL`0;075bLP1aLG80
LG5b075aLP1aLG40LG1a075`L01aKfl0L6e/075`L01aLG400P1aLG806`1`LW<0L75b071aLP1`LG80
L71b06maLP1_L780Kg5b06maL`1_LW@0Kg=e071dMP1aMGP0LGIi079gNP1bN7X0LWYl07AkOP1eOH00
MWn307R3Q`1fOX80MGao07AkO@1dNW`0M7Uk07=iN`0207=hNP<0LgMi0P1bMWP00`1bMWL0LWEg0?oo
o`0G0?ooo`0508V1P029PGl0R81o08R0O`28P7h00P28Ogh02027Ogd0Qgim08MnO@27OW`0Qgel08Im
O026OG/0QWak0P26O7X00`26NgX0QG]i08EkN@0208EjN00408EiM`25N7D0QWYh08EjN@80QG]i00<0
QG]j08EkN@25NWT00`24NWT04P23NWT0Q7Yj08AkNP24O7/0Q7el08EnO@26Ogh0QWmo08N0P027PH40
Qh>308R4Q@29QXH0RXR908b;S02:QhP0RXF508V4Q0<0RH>300<0RH>208V2PP29PX401029PX400`29
PH40RH600?ooo`0H0?ooo`0;0;nST02oXXl0_j:?0;nRSP2oXHh0_Z6>0;jQS@2nX8d0_Z2<0;fPS02m
Wh`00P2mWh/20;bNRP040;bNR@2lWHT0_9f90;^MR080^ib80`2kW8L00`2kW8P0^ib70;^LQ`030;^L
Q`80^i^70P2jVhL20;^KQ`0;0;^KR02kW8T0^ib90;^MR@2kWHX0_9f:0;bNRP2lWX/0_9n<0;bOS@2m
X8h00P2mXHl00`2mXHh0_J2=0;fPS@020;fPS@<0_Z6=0P2nXHh01@2oXXh0_j:?0;nRS`2oXhl0_j>@
02@0oooo000R0?ooo`80Ig1c00@0Ig5c06M`L`1XL7<0J75c0P1XL7<01@1XLG<0JG5c06UaL`1YLG<0
JG5b00<0JW5b00h0JW5c06]aLP1[LG80Jg5b06a`L@1/L700K6m_06]]K01/L700K75b06abM01[LW@0
Jg=d06]bM080JW9d00<0Jg9d06YcM01ZLgD00P1ZLgD06`1ZM7L0JWEh06]gN@1[N7/0K7Ul06ejOP1]
O7l0KGf106ioP`1_PHD0LH:807:4R@1`PHH0Kgn306imP@1]Nh00KGYn06aiO@1/N7`0JgQk06]gNP1Z
MWT0JWEh06UdM`1XLgH0J79e06MaM00I0?ooo`04079dMP1bM7D0LGAe075cM@80LG=d0P1aLW<2071a
LP80L71a00<0L71`071_K`1`Kfl00P1`KVh2071]K@07071/K01`K6/0L6]Z071ZJ01`J6D0L6]Y071/
K002071]KP0306m^K`1_KVh0KVe^00<0KFe^01h0K6e^06a^K`1]Kg00KG5c06ibM01_M7L0L7Ii075h
N`1bNWd0Lgao07AnPP1fPHH0N8F907Z8SP1lRi40NHJ:07R2Q`1gP8@0MWj207EmP01eO7l0MG]n07Ak
O@1dNW`0M7Uk07=hN`1cN7X0LgMi079fN01bMWLH0?ooo`0:08V1O`28P7l0R7mn08MoO@27OWd0QWel
08ImN`26O7/0QG]j08EkN@80Q7Yh02X0Q7Ug08=hMP23N7D0PgMd089fM022MW<0PWEb089dL@22M700
PG=_085bKP22L6`0PW9_089cL@22M780PGAb085eL`21M7<0P7Ab07mcLP1oLg40Og=b07icLP1nM7@0
OgEe081gM`20N7T0PWYk089lO023OWh0Q7n008F1PP26Q8D0R8N908Z:S02<SY40SI2C08^;S@2:R8X0
RHN808V5QP29QHD208R4Q080R8>300<0R8:208V2PP29PX400P29PX400`29PH40oooo0?ooo`0G0?oo
o`060;nRS`2oXHh0_Z6=0;jPS@2mWh`0_In;0P2lWXX03`2kWHT0^ib80;^LQ`2jVhH0^YZ50;VJQ@2i
VH@0^9R30;RGPP2gUh40]iJ00;NEP02gUGl0]YEo0;JDO`020;NEO`030;JDO`2fU7h0]YAo0080]YAo
01D0]Y=n0;FCO@2eTWd0]I9m0;FBOP2eTWl0]YB00;JEP@2gUH80]iJ30;NGP`2gUh@0^9R40;RIQ@2i
VXL0^I^90;ZMR`2kWhh0^j2>0;^NR`2kWHX00P2kWHT20;^NRP090;bNRP2lWX/0_9n;0;fOS02mX8`0
_Z6=0;jQSP2oXXl0_j>?02@0oooo000R0?ooo`0<06M`L`1WL780J71c06QaL`1XL780J71c06U`L`1Y
L780JG5c06YaLP1ZLG<0JW5b0`1[LG8206aaLP80KG5b0P1^LG401@1^L700Kfm^06m^K01_LG00Kg9b
0080KW=d0P1]M7D206acM00P06ecM01/Lg@0JWAe06YdMP1ZMGL0JgIh06]gN@1/NW`0KGao06mnP@1`
P8<0LH650764R01bQX/0M8R>07F;TP1eRY00M8N=07>5RP1bPhP0LH66071oQ01_OX80KWf106ekO`1]
NWh0K7Ql06]gNP1ZMWT0JGAg06QcMP1XLW@I0?ooo`07079dMP1aLgD0LG=d075cM01aLW<0L75b071a
L@02071`L00606m_K`1_KVl0Kfi^06m]K@1_K6`0Kfa[0P1^JfX0;`1^JVT0KVUX06iXI`1_J6D0KfIT
06mUHP1_Hel0L6IT06mXI`1_JVT0KfYZ06iZJP1]JVX0K6YZ06]YJP1/JFX0JfUZ06YZJ`1[K6d0Jfe_
06a_L@1/LG<0KWAg06mgNP1aNWd0LWb007B0P`1ePhP0N8N<07Z<TP1nTIT0OXnF07b;T@1jR8d0NHF:
07R3Q`1gPHD0MX2307IoPP1eOH40MGao07AkOP1dNW`0M7Uk07=hNP1cMgT0LWIh01P0oooo01l0R81o
08QoOP27OWd0QWil08ImN`25O7X0QG]i08AiN023NGL0PgMe089gM@22MW@0PGEb081dL@20Lg00Og9_
07maKP1nL6d0OVm[07i^JP1nKFT0OVaW07iZIP1nJF<0OV]W07i]JP1nKV/0OVi/07e^K@1mKV`0O6i/
00<0Nfe]01`0Nfi^07]`L01lLW80OGAd07ieMP1nMgP0OgUj081lO@21OX00Ph:308F5Q`27RH`0RXfA
08fCV02=TYH0RhjA08Z;S@29R8X0R8N808R6Q`28QHH0R8B508R4Q028Ph@0R8>308R3PP28PX80RH:2
0P29PX4I0?ooo`0G0;nRS`2nXHh0_Z2<0;fOR`2lWXX0^ij90;^LR02jVhH0^IZ50;VIQ02hV880]iN1
0;NFP02fUGl0]IAn0;FCO@2dTW/0/i5j0;>?N02bSgL0/Xif0;:=MP2aSGD00P2aS7D20;:=MP@0/Xeg
01H0/Heh0;6<N02bS7P0/Xah0;>=N@2cSg/0]91l0;BAO@2dT7d0/i1m0;>AO@2cTWh0]9B00;FEPP2f
Uh@0]iV70;VLR`2iWH/0^9Z80;RJQP2hVHH0^9Z60P2iVXH02@2jVhL0^Yb80;^MR@2kWHX0_9j;0;fO
S02nX8d0_Z6>0;nRS`0T0?ooo`008P3oool01@1WL7<0Ig1b06Q`LP1XLG<0JG1c0080JG1b00@0JW1b
06YaLP1[L780Jg5b0P1/LG8206eaLP80KW5b02l0Kg5b06mbL@1`LW40LG5a075aL01bL6h0LFm/079b
L01bLg<0LGAd075eM@1`MGD0KgAe06edM01/Lg<0K79b06aaL`1ZLg<0JgEf06]fN01[N7X0K7Yl06em
O`1_Oh80L8:507:4R01dQh/0MHZ?07J=TP1hT9L0NYBL07VAV01hSY@0MX^A07F9SP1dQX`0LhB907:2
Q`1aP8D0L7n306mmP@1^Ngl0K7Um06]gN`1ZMWT0JGAg06QbM@0I0?ooo`07079dM@1aLg@0LG9c071b
L`1`LG80L71a06m_L00206m^KP0G06m]K01^K6`0KV][06iZJP1^JFP0KFQW06eXIP1]IfD0KFIT06eU
H`1]I680KF=P06iRG`1^HEd0KUmJ06mSH01_IF<0KVIU06iWIP1]IfL0K6MW06]WI`1ZIfL00P1ZIVL0
7P1YJ6P0JFY[06Y/KP1[KW00Jg1c06adM`1^N7/0L7]o079oP`1ePhP0MhR=07Z<T`1mTYT0PIRQ07nD
V`1mT9L0O8bB07Z9S`1iQh`0NHF907R3Q`1gPXH0Mh2407InPP1eOH00MGan07AjO@1dNG/0LgQj079f
N1P0oooo03h0R81o08MoO@26OG`0QWek08EkNP24NWP0PgUg089gM@21MW@0PGEb081dL@1oLVl0OW5^
07i_K01mKV/0O6eY07][J01kJVH0NVUT07YWH`1jIV40NVEP07YTGP1jHU`0NfEP07YWH`1jJ6D0NVQV
07YYI`1iJFL0NFUX07UZJ@1jJVT0NFYZ07U[J`1iK6d0NVi_07Y`L@1kLG<0NgAf07ehN@1nNgd0P7j0
08:2Q024QXT0QXZ>08V?U02<UIX0Ri:F08Z?TP29S8l0R8Z<08R8RP28QhT0QhJ708N6QP28QHD0R8B5
08R4Q028Ph<0R8>208R2PP80RH:16@3oool05@2oXXl0_Z6=0;fOS02lWXX0^if80;ZKQ`2iVXD0^9V4
0;NHPP2fUX40]IEo0;BCO@2dTW/0/i1i0;:?N02aSGH0/8ad0:n:LP2^RG00[XM_0:f6K@020:b5K003
0:f5K02]QFd0[HE^0080[HI^00D0[HI_0:j7L02^R780/8Ud0;2:M@020;2:MP<0/HYf00T0/HYg0;6;
M`2`RgL0/8ah0;2=N@2aSg/0/Y5m0;>BO`2dU8400P2eUX<03`2eUX80]IF10;FEP@2eUX40]YN20;NH
P`2gVH@0^9V50;VJQP2jW8L0^if90;bNRP2mWh`0_Z6=0;nRS`0T0?ooo`008P3oool00`1WL7<0J71b
06Q`LP0206U`LP80JW1b00@0Jg1b06]aLP1/LG80K75b0P1]LG80101^LG80Kg5b06maL@1`LW42075b
L@0=079bL@1cLW40M79`07EbK`1eL6d0MG=a07EdM01dMGH0LgIf079fMP1aMWH0L7Ef06mdM@0206ic
M00N06ecM01]MGH0KGMi06eiO01]O7h0KWj10723QP1bQXX0M8V=07N<T@1iT9H0NYBJ07bGWP1nVj<0
OINO07^DV`1jTIP0NHjE07N<TP1fRHl0MHN<07>4R@1bPXL0LH2406mnPP1^Ngl0K7Um06]gNP1ZMGP0
J79e6@3oool0@01aM7D0LG=d075bL`1`LG80L71`06m_K`1_KVh0KVe]06i/J`1^JfX0KFYY06eYJ01]
IfH0K6IU06aUI01/I680K6=Q06aRH01/HEh0K61M06aOF`1]GeX0KEiH06iLEP1^H5`0KV9O06eSHP1]
I6<0K6ET06]UI01ZIFD0JFEU06UTI01YI6D0J6EV06QXJ@1YJVd0JFe_06Y`L`1[LgL0KGQl071mP@1b
PHH0MXJ;07V<TP1kTIP0OiNO08:LYP20V:00OiBK07f@U`1lSI@0Nh^A07Z8SP1iQX/0N8B907R2Q`1g
PH@0MWn207EmP01eNgh0M7Yl07=hNP1cMgPH0?ooo`0N08R0O`27OWd0QWek08EkNP24NWP0PgQf089f
M021MG80Og=a07ibK`1mL6d0O6i[07a/J@1kJfL0NVUU07UWH`1hIV40MfAO07IRG@1fHE/0MUmJ07IN
F01fGEH0MUaE07MOFP1gHE`0Mf9O07ISH01fI640MVAR0P1eIF@0801eIFD0MFIV07EWI`1fJFT0Mf]/
07M]KP1hL740N79d07YeM`1lNW`0OGf00821Q023QXX0QH^@08RAUP2;UY`0RY:G08V?T`28SI00Qh^>
08N9S027R8X0QhN808N6Q`27QHH0QhF508N4Q028Ph@0R8>308R3PP28PX80RH:16@3oool0602oXXh0
_J2<0;bOR`2kWHT0^Y^70;VIQ02gV880]YJ10;FDO`2dTg`0/i5j0;:?N02aSGH0[h]d0:j:L@2]R6l0
[8I]0:^4J`2ZPVP0ZH1V0:QnI02WOF<0YgeR0:MmH`80Z7iT00T0Z7mU0:UoI`2YP6P0ZH1Z0:Z1J`2Z
Pfd0ZhA_0:^5L02/QW000`2]QW402@2]Qg40[XMb0:f6LP2]Qg<0[HUd0:j9M@2^RgH0[hei0;2@O002
0;6AO@0?0;6@O02aTG`0/Y5l0;>BO@2cTgh0]9Ao0;FEP02fUh80]iR30;RIQ@2jVhL0^if90;bNRP2m
X8`0_Z:>02@0oooo000R0?ooo`0606M`L`1XL7<0J71b06U`LP1ZL780JW5b0P1[LG80101/LG80KG5b
06eaLP1^LG4206maL@0b071aL@1aLW40LW9a07=bL@1dLg40MG=a07IdLP1gM780NGAa07UdL01iMG<0
N7Ie07MgMP1fMgP0MGQh07AhN01cMgP0LWMg075gM`1`MWH0L7Ig06mgN01`NW`0L7an075oPP1aPXD0
LhJ907F;S`1gSY<0NY:G07fFW01nVZ40PIjV086PZ020WJD0OiZR07fGWP1lU9/0Ni6G07V>U01hRi40
MXR>07B6R`1cPhP0LH2506mnPP1^Ngl0K7Ql06YfN@1XLgHI0?ooo`10075dM@1aLW<0L75b071`L@1_
Kfl0Kfi^06i/K01^Jf/0KFYY06eYJ01/IfH0K6IU06aUH`1[I640Jf9P06]QGP1ZH5d0JUmK06YMF@1Z
G5P0Je]G06aKE@1]FUD0KUYD06iMF@1^Ge`0KF5O06aRH01[HV40JV=R06YSH`1YHf<0J6=S06MSH`1W
I6D0IfIW06QYJ`1XK6h0JG1c06YcM`1/NGd0Kgn307:3R@1fRHh0NHnF07fEWP21W:H0PinY086KY020
Uj00OiBL07fAV01lSYD0NhbB07Z9S`1jQh`0NHF:07R3Q`1gPH@0MWn207EmP01dNgh0M7Uk07=gNAP0
oooo03`0R7mn08ImO025O7X0Q7Yh08=hMP21MW@0P7Ab07mbL01nL6d0O6i[07]/J@1jJVL0NFQT07QV
HP1gI600MF9N07APF`1cGUT0LUaF079JE01aF580LEM@079FC`1cETl0LeUC07AKE`1cGET0LeiK07=O
G@1bGeh0LV1N075PG`1aH600LF5Q079SH`1bI6D0LVIW07=YJP1cK6d0M6ma07IdM@1hN7X0Ngao07f1
Q020QXX0PhbA08RCV@29UI`0R9:G08N?U027SI40QX^?08J:S@26R8/0QXN908J6R027QXL0QhF608N4
Q@27Q8@208R3P`0308R2PP29PX40oooo01P0oooo0280_Z6>0;fOS02kWHT0^Yb70;VIQ@2gUh80]YF0
0;BCO@2cTG/0/Xmh0;2=MP2_Rg<0[XUa0:b7KP2[Q6/0ZH9Y0:R0IP2WOF<0YG]P0:AiG@2RMUX0XGAH
0:5cE`2RM5P0XgIK0:=gG@2TN5h0Y7UO0:AiH@2TNV80YGYS0:EjI02VO6D0YgeX0P2WOfT20:QoJ@0:
0:R0J@2XP6X0ZH5[0:V1JP2YPV`0ZHA^0:V5K`2[Qg80[8]g0:f<N080[H]f00h0[Xaf0:n<M`2`SWP0
/Hmi0;:AN`2cTWd0]9An0;JFP@2gUh<0^9V50;ZKQ`2kWHT0_In;0;jQSR@0oooo000R0?ooo`0606M`
L`1XL7<0JG1b06U`LP1ZLG80Jg5b0P1/LG801P1]LG80KW5a06iaL@1_LG40L75a075aL@80LW9a0300
Lg9a07AcL@1fLg40MgAa07UeLP1kMW<0OGQe07iiMP1lN7H0NgQg07YiN01iNGT0N7Ui07MjN@1fNWX0
MGUj07EjNP1dNWX0M7]k07=lO01cOWl0Lh2207B3QP1eQXX0MX^>07R?T`1kU9T0OYRN082LX`22XJT0
QZJ_08FU[`24Xj/0Pj2X086LY020VJ40OYJM07bCV@1jSiH0NHbB07N9S`1eQX/0Lh>80760Q01_OH40
KGYn06]gNP1YLgHI0?ooo`0P075cM@1aLW<0L75a06m_L01_KVh0KVa/06i[JP1]JFT0K6QW06aVI@1[
IF<0JfAR06YRH01ZHEh0JUmL06UNFP1YG5P0JE]G06UIE@1YF5<0JEMA06YGD01]Ee00KeYC06iLE`1]
GEX0K5iL06aOGP1[H5l0JV1P06UQH01XHF4206MQHP0N06ISI01VIFH0IfQZ06M[KP1XL7<0JWAh06aj
O@1_Oh@0LXJ;07J;TP1jTYX0OYVR08>Q[023XJ/0PYjW086JX`20Uj00OiBL07jAV@1mSiD0O8bB07^9
S`1jQh`0NHF907R2Q`1gP8@0MWj107ElO`1dNW`0LgMi603oool07@28Ogh0QWek08AkN@23N7L0PGId
081dLP1oLVl0OG1]07a]JP1jJfP0NFUU07MVHP1fI600MF9M07=OFP1bGEP0LE]E071HDP1^ETl0KE=<
06aABP1/CdL0KDi6071AB@1aEDl0LEMB071HE01`FEL0KeYH0080KUYI00l0KU]J06eKF`1]Fe/0KEeM
06eOG`1^HF80KVEV06mXJP1`K6h0LW1b07EeM`1gNWd0NWn207j5RP22S9400P26TiX04026TIL0QXjD
08F=T@25Rhl0QHZ=08F9S025R8X0QXN908J6R026QHL0QhF608N4Q027Ph@0R8>308R2PP29PX4I0?oo
o`0S0;jQS@2lWh/0^ib80;VJQ@2gV880]YF00;BCO@2bTGX0/Hig0:n<M02^RG40[8M^0:Z4J`2YPVP0
YgmU0:ImHP2TNUl0XWMK0:5dF02OLE@0WFi@09]ZC02JJ4T0W6Y<09i_DP2OL5D0Wg5G09mbF02PLeT0
X7=J0:1cF`2PLe`0X7AL0:5dG@2QMEh00P2RMUl02`2RMf00XWQQ0:=iHP2SNV80Y7YS0:AkH`2TO6D0
YGmX0:N1JP2XPfh0Z8E_0080ZHE^00h0ZXI_0:^7L@2/RG<0[X]e0:n=M`2aSgX0/Y5l0;BCOP2eUH40
]iN30;VIQ@2jW8P0_9n;0;jQSB@0oooo000R0?ooo`0406M`L`1XL7<0JG1b06YaLP80Jg5b00@0K75b
06eaL@1^LG40Kg5a0P1`LG40=01aLG40LW9a07=bL@1dLW40MG9a07IcL@1gLg40NGAa07YeLP1nMg@0
QGei089kN01oNWP0OWYh07ajN@1lNgX0Ngak07YkN`1iO7`0NGem07QmO@1hOWh0Mgmo07N1P@1hPh@0
N8J707V9R`1iRhh0NhnC07fDV@1oV9h0PIfT08FRZP27Yk00RZfh08V[]@28ZK80QZJ_08FRZ`23WjL0
PI^S07nGW`1mU9X0Ni2F07V=TP1gRHh0MHF:07:2QP1`OX80KW]o06]gN`1YM7LI0?ooo`10075cM@1`
LW80L71a06m^K`1^KFd0KV][06eYJ@1/J6L0K6IU06]TH`1ZHf40JV5O06UOG01YGUX0J5aH06QJEP1W
FE@0IeMB06MED01VE4h0IU9<06IABP1`F500LE]D06mKEP1]G5P0K5eJ06]MG01ZGUd0JEiM06QOGP1W
Gel0IUmO06IPH01UHV80IFAU06IWJ@1WJfh0J71c06UeN01/NWh0Kh6607:7S@1gSYD0O9FM07nLYP24
YK00Q:>^08>PZ`22WJL0PIZS082GX01oUI`0OY:I07f?U@1lS980NhZ?07Z7S01iQ8T0N86507IoP`1e
OH00M7Ym07=hNQP0oooo01`0Qgmm08IlN`24NWP0PWMe081eLP1oLW00OG1]07]]JP1jJVL0N6QT07IU
H@1eHeh0Lf1K079MF01`FeD0KeQB06eEC`1/DT`0JTm806U<A@1WBD40I4@l06]:@@1_D4P0KU5<06iC
CP1]E500K5AB0P1[EE<07@1ZEE@0JUEE06UEE@1YEEH0J5MG06QIFP1XG5d0JF1Q06]TIP1/J6X0KVe_
075cM@1dN7/0N7j207b4R@1oRi00Q9:I08BAV024SiD0Q8jC08B<T@24Rhl0Q8Z>08B9S025R8/0QHN:
08F7R@26QXP0QXF60080QhB500<0R8B408R3PP29PX406@3oool0702nXHd0_9j:0;ZKQ`2hV8<0]YJ0
0;BCO@2bTGX0/Hig0:n;M02]RG00ZhI]0:V3JP2WP6H0YWeS0:AjG`2RMe`0X7AH09iaE02LKU00VVY;
09MUAP2CGch0U60o09UWB02JJD`0Vf]?09][D@2KK54209]/DP80Vf]B0`2KJU80302KJe<0VfaE09]]
EP2LKeL0W75H09ebF@2NLe/0WgEL0:1fG@2QN600XWYR0:=lI080Y7eU00l0YGmW0:J0J@2XPV/0ZHA]
0:^7L02/RG<0[Xaf0;2>N@2bTG/0]9An0;JFPP2hVHD0^Yb80;bNRP2nXHd0903oool00280oooo00X0
J71c06Q`LP1YL780JW5b06]aLP1/LG80KG5b06iaL@1_LG40L75a0P1aLG40=01bLW00Lg9`07AbL01e
LW00Mg=`07QcL01iLg40NWAa07]dL@1mMG40RH1k08AmN@21O7X0P7]j07mlN`1nO7/0OGem07enO@1l
OWd0Ngmn07^0O`1kPH40NhB307^7QP1lRHT0O8^<07f>T01nTI<0OiBH086IWP23WJ<0QJ>Z08VY/@2<
[[P0SkG008fb_@2<[kX0RZbf08VX/@27Y:d0QJ2X08:LY020V9l0OYBK07^@UP1iS980MXR=07B4R@1a
P8@0Kgb006ahO01YM7LI0?ooo`10075cM01`LG80Kfm`06m^KP1^K6`0KFYY06aXI`1/IVD0JfAR06YR
H01YH5h0JEmL06QMF@1WFeL0IeUE06IGDP1VEE00IE=>06EAB`1TCdT0Hde606A<A01fG5<0LEYC06mJ
E@1]FUH0Je]H06YKF@1YG5/0J5aK06MLG01VG5d0IEeM06ENG`1THF40I6AU06EWJ@1VK6h0Ig5d06Uf
N@1/Nh00Kh:707>8S`1gT9L0O9NP082OZ@25Yk<0QJJa08BS[P23X:/0PYjW086KY020V:00OiFL07jB
V@1mSiD0O8bB07^9SP1jQX/0N8>707N0Q01fOX40M7]m07=hNQP0oooo0400Qgim08EkNP23N7L0PGId
07mcL@1mL6h0NfeZ07UZI`1hJ6@0MVEQ07ARG@1bGeX0L5aG06mID`1]EU00Je=<06Y@B@1XC4D0ITU2
06A6?P1R@CT0HClg071=A01^CTH0K4m906]?BP1ZCd`0JE1=06Q@CP1WD4l0IU1?06E@D01UCdl0I4m@
06=AD@1SDe@0I5MI06ELG@1VH680J6EW06]ZK@1^L7<0LGIi07ElP01iPXL0O8R>086?UP21SYD0PHfD
08:=TP22S940PX^@08>:SP23RHd0Q8R<08B7RP25QhT0QHJ808J5Q`26QHH0QhB508N4Q028Ph<0RH:1
6@3oool06`2nX8d0^if90;VJQ@2gUh80]IAn0;>AN`2aSWL0[h]d0:f8L02[QFd0Z89Y0:IoI@2TO640
XWUM0:1eF@2NLUD0W6iA09Y[C@2HIdP0UV=309=N?@2AFc/0U5lo09MTA@2GIDL0UfE809MVB@0309IU
BP0409IUB`2FHdX0UF9909EPB080U5m701`0U65909ETC02EIdh0UVU@09MZDP2IK5<0VFiD09]_E@2L
L5H0W75G09ebF02OM5X0X7IL0:5hGP2RNV40Y7eT0:J0J02XPf/0ZXE^0:b8LP2^RgD0/8ii0;:AO02d
UGl0]iR30;VKQP2kWHT0_J2=903oool00280oooo01X0J71c06U`LP1ZL780Jg5b06aaLP1]LG80KW5a
06maL@1`LG40LG5a079aL01cLG00M79`07EbL01fLW00Mg9`07QcL01iLg00NW=`07]dL01kLg00OgIc
08AkN024O7T0Pgej089mN`80PGim02@0P7mn0820O`1oP7l0OX2007j1P@1nPh<0OXN607j:R@1oSXd0
P96A086CU@22UYP0Q9ZM08JNX`27XjP0RJN^08b]]@2?/kd0T[_609:jaP2@]/40S[:m08f^^02:Z[<0
R:J^08JQZ@23WJ@0PIRO07jDVP1kSiD0N8^@07F6R`1cPXH0L7f106eiO@1ZMGPI0?ooo`0^075cM01`
LG40Kfi_06i]K@1]JfX0K6UX06aWI@1[I6<0JV9P06UPGP1XGU/0J5aI06MJEP1VF5<0IEIA06EDCP1T
DT`0I4m906==AP1SBd@0H4Q006]@B01dFU80L5QB06iHD`1/F5@0JeUF06UIE`1XFUT0IeYJ06IJFP1U
FUX0I5YJ06=KG@1SGf00Hf=T06EXJP1VKFl0Ig9d06UgNP1]OH40L8B907B:T01hTIT0O9VR086PZ`80
QJVe0100QJJb08BT[P23XJ/0PYjW08:KY021V:00OiBL07jAV01mSY@0O8^A07Z8S@1iQHT0N8:507In
PP1eNgh0LgQj603oool0@027OWd0QG]i089hMP20MG80OW9_07a^J`1jJfP0N6QT07IUH@1dHUd0LEiJ
06mKEP1]F580JeA>06YAB`1XCTL0ITY306A7?`1R@c/0HD0g05hk<P1YAC/0Ldm506e<A01ZBdD0J4Y6
06I;A`1UBdP0I4]906=;BP1RBd/0HDY:0619BP1OBT/0Gda=05m?D@1PE5H0HEQJ069MG`1THV@0J6Q[
06]^L@1_M7P0LgYo07J0Q@1jQX`0OX^B07j<T`1oS980Oh^B082;T@21RY00PHZ>08:9S@23R8`0PhR;
08B7RP25QXT0QHJ708J5QP27Q8D0QhB408R3P`28PX8I0?ooo`0J0;fPS02kWHP0^IV50;JFP02dTW`0
/Hmi0:n<M@2]RG40ZXE]0:R2J@2VOfD0Y7]Q0:5hG02OM5P0WG1C09]]C`2HJDX0UVE509AQ@02BGC`0
T5Xf09IP?@2JIT@0UV9209AP@P2CH442099O@P05095O@`2AGT<0TEe3095L@`2@FT400P2?FD007@2?
FD40SeY108mL@`2?GTD0T657095SB@2CID/0UFM=09IYC`2GJTl0V6Y>09QYC@2IJTd0VfiB09eaEP2N
M5X0X7MN0:9kHP2UOVH0Yh9Z0:V5KP2/RG80[Xaf0;6?NP2cTgd0]YJ10;RIQ@2kWHT0_J2<02@0oooo
000R0?ooo`1006Q`L`1YL780JW1b06]aLP1/LG80KG5a06iaL@1_LG40L75a079aL01cLG00M75`07Eb
L01fLW00Mg9`07QbL01jLg00Ng=`07acL01mM700OgEa085gL`23NWH0Q7ai08AmN`24OW`0Q7mn08>0
P023PH00PX6108:2P@21PX40P8:10826Q@20RXP0PHj<08:BT023UYD0Q9RH08JKW@28Wj40RZ>W08bW
[@2=[;<0Sk6i09:g`@2E_lX0Ul;>09Fmb@2C^L@0TKBo08j`^@2<Zk@0RJJ^08JQZ@24W:<0PINN07fB
V01jSI<0MhR=07B4R01aOh<0KGYn06YeN1T0oooo0400LG=d071`L@1_KVh0KVa/06eZJ@1/IfH0JfET
06YSH@1YH5h0J5iK06MLF01VFUH0IUMC06EED01TDdd0He1:06=>B01RC4D0HDU20616?P1WC4<0L5A;
071EC@1^EE00K5IA06]FDP1YEU<0J5MF06MHE`1VF5P0IEQH06AGF01SEeP0HUYK069NG`1RHf@0I6QZ
06E^L01WLgD0JGQl06enP`1aQHX0MHbC07VCVP1lVJ80PJ2[08BX]027[;T0QZZf08FW/`25Y:l0Q:6[
08>NY`22Vj<0PINO082DV`1nT9L0OHfC07^:S`1jQX/0N8>707MoP`1eO7l0LgQk603oool0<027OW`0
Q7Yi089gM@1oLg40OG1^07]]J@1hJFH0MVER07ARGP1aGUX0Ke]F06eGDP1[E4h0J51:06I<A@1TBD40
HTDm0611>@1N?C@0FcP^06@o=@1_BCl0K4U006U8@@1WAd40IDI106=6@P1RAd@0H4M50617AP1OATH0
GTE605a3A@1LADL0FdQ:05];CP1LD5<0GEIH05iJG@1QH6<0I6IY06Q/K`1/LWH0L7Qm07=nP`1gPXT0
NHN>07b;T@80OH^A00h0OXZ@07n:T020RXl0PHV>08:9S@23R8`0PhN:08B7R@25QXP0QXF708J5QP27
Q8@0R8>308R2PQT0oooo0400_J2<0;ZLR02hV8<0]IEo0;>AN`2`SGL0[HYb0:^6KP2XPVX0YWmU0:=k
H@2QMe`0WW=G09a_D`2IJdh0UfM909ASA02BGcl0T5/i08aE<@2BFcP0VFA209IQ@02CGSh0TE`m08mK
>`2>FSX0SETk08eH>`2<F3`0S5Ll08aF?02;E3X0Re8i08YA>@2:DCX0RU8k08YD?02:Ech0ReU008aL
@P2=Gd@0Sf97095SB02CI4P0Tf=609=Q@`2DHT<0UVI809QZC@2JKU80W79G09mfG02QNV40Y7iU0:N2
JP2YQVh0[8Uc0:n=M`2bTG/0]IAo0;NHQ02jW8P0_J2<903oool00280oooo01d0J71c06U`LP1ZL780
Jg1b06eaL@1^LG40Kg5a071aL@1aLG00LW5`07AaL01eLG00MW9_07MbK`1iLVl0NW9_07]cK`1mLfl0
OWA_07abK@22Mg<0PgUe08AjM`25O7T0QGek08InO@26PGl0QX:208J3P`0208F3P`0Q08B4P`22PH40
PXB308:7Q`23Rh/0Q8n?08JFUP27Vi/0RYnP08bSY@2>YjX0T:^`09:_]P2C];`0UKW309Nob`2Ja]80
V/KC09O0c02E^lH0T[G0092`^P2=Zk@0RZF^08NPZ023Vj80P9FL07b@UP1iRXl0MHF:07:0Q01^Ngh0
JWEi01T0oooo0400LG9c071`L01_KFd0KF][06aYJ01[IVD0JVAR06UQG`1XGe`0IeaI06IJEP1UEe<0
I5A@06=BC@1RCdT0HTe6065;@`1QB400H4Hm06=6?@1^D4L0KU5806eBB`1/Ddd0Je=>06UCC`1XE540
IeID06IFEP1VEeL0IEIF06=FE`1REEH0HEUJ065MGP1RHV@0HVMX06A^L01VLgH0JWYm06j0Q01bQh`0
MhjD07ZDW01mVZ<0PJ2[08>W/`27[KX0R:jk08N[]`26Z;<0QJB_08BQZ`23WZL0PYZS086GWP1oTiX0
OXnE07b;T@1kQh`0NHB807N0Q01eO7l0M7Uk603oool0@026OG`0Q7Yh085fM01nLW00O6m/07U[I`1g
If<0M6=O079OF`1_FeH0KEMB06YCCP1XD4T0IDa506=8@01QA3`0GT0g05`l<`1K>2h0H3/`06]4>@1Y
A3X0J4@k06E4?@1S@cd0HD8l05m2?P1N@T00GD=105a3@P1K@T80FT9305U2@`1HATL0F4U:05Q=C`1H
DE80FEEG05YIF`1NGf40HFEX06E[K`1ZLGH0KWMl075lP@1eP8L0MhF<07V8S`1jRY40NhZA07b:T@1m
RY00OhZ?0829SP21RHd0PXR<08>8R`24QhX0QHJ908F6Q`26QHH0QhB508R3P`28PX8I0?ooo`0K0;fO
R`2jVhL0]iR30;BDOP2aT7T0[Xad0:b8L02YQ6/0YX1V0:=lH@2QMed0WW=H09]_D`2HJdd0UVM809=R
@`2@GSd0SUXh08aE<P2AFSL0UEll09=M>P2AG3X0SeXi08eH=`2;ECD0RE<d0080R58d00P0Qe8e08MA
=P27DCH0Qe<i08ME>P26ECX0QUHl08IE?080QE<j01T0QEDl08MH?P29Fd00Ree208eO@`2?H4@0T613
091N@02@G3`0TEdm09=SA@2FJ4/0V6aA09]aEP2NME`0XGYQ0:AnIP2WPf/0ZXM`0:f;M@2`T7X0/iAo
0;JGP`2jVhL0_In<02@0oooo000R0?ooo`0L06Q`L`1YL780Jg1b06a`L@1]LG40KW5a071aL@1aLG00
LW5`07=aL01eLFl0MW5_07MbK`1hLVl0NW9_07]bK`1mLfl0OW=_081dK`2:O7L0QgYf08IjMP26NgP0
Qgai08MmNP27OW`0R86008V4P`80RHF40280R8B408N4Q025PX80Q82108B3Q024QHH0QHV;08RBU02:
VY/0SJ6Q092VZ02BZZd0U:jd09Jb^@2F][h0Uk[409W0b`2KaM80WL[G09_6d`2I`Ld0Uk_609Bf`02A
/;T0SJZb08ZT[026WZD0PYRO07jBV01jSI80MXN<07>1QP1_O7l0JgIi6@3oool0@01aLW<0Kfm`06i]
K@1]JVX0K6MV06]UH`1ZHV00J5mM06MMFP1VFUH0IEMC06ADD01SDT`0HTm9065<AP1PBT80GdLo05m5
?01N@SP0KDe306i?A@1]D4L0K51906Y@B`1YD4/0Ie1<06IBC`1VE5<0IUEE06EEE@1UEEH0HeIG065G
F01PFET0HEiO065QH`1PI6H0Hfa^06EcM@1ZNgd0Kh:507>8S@1hSiH0NiFM07jKY020X:/0PjNb08J/
^029/Kl0R:jk08N[]`27Z;<0QZB_08FQZP24WJH0PYVQ086EW01oTIP0OHfC07b9SP1jQHX0N86507Im
P01dNG/H0?ooo`1008ImO023NGL0P7Ec07eaKP1kKFX0N6UU07EUH@1bH5`0KeaH06eHD`1ZE4h0Ie1:
06E;A@1RAd00Gd<k05do=P1K>S40F3H]05Da9`1R>bl0ISld06E1=`1T@CP0HD0i05lo>01L?CP0FSdj
05Xo?@1I?cl0F3lo05Po@01G@T80ETE505E8B01FCTh0EU5B05EADP1FE5H0EeUK05]NH@1OIFL0I6Y]
06QaM@1/MW/0Kg^0079oQ@1dPhX0MXJ>07V:TP1iRI40NXVA07b:T01mRY00OhV?0829SP21RHd0PXR<
08>7R`24QhT0QHJ808J5QP27Q8D0R8>308R2PQT0oooo01`0_In;0;VKQP2fUh40/i9l0;2>M`2]RG80
ZXE]0:N1J02TOF<0XGQN09idF@2KL5<0V6]>09EWB02BHT<0Sedm08aH=`2:E340QThZ08Q@:`2>Ec<0
SUPe08eG=@2;ESD0RE@c08IA<024CRh0Pdd_0P22CC008P22CS40Pe0d08=F>P23FSl0Pei208AOA022
Fd00PEHk081D>@21DcT0PU@j08AG?026FCd0R5/o08YM@02<GD00S5`n08aJ>`2=FSX0Se`m095QA02D
IdX0UfaA09YaE`2NMUd0XG]S0:F0J02XQFh0[8Uc0:n>N02bTWd0]YN20;VKQ`2lWh/T0?ooo`008P3o
ool0701XL780JG1b06]`LP1/LG40KW5a06maL@1`LG00LW5`07=aL01dLFl0MW5_07MaK`1hLFh0NG9^
07]bKP1mLVh0OW=^081dKP21M6l0RWaf08UkMP29NgL0RGah08QkN028O7T0R7il08Z1P02<QXD208b7
Q@0R08j7QP28P800QH20089mO@22OWl0PhB508F6R028S8h0S9BF09:PX@2DZJX0Ujf_09Ra]P2I]K/0
VKS009Zka@2K`</0WLKB0:3<f@2PcMX0W/OD09_1c@2H^lD0UKFn096_]`2=Z;00RJ:Y08FKXP20UI/0
O8nD07R9S@1dPXL0Kgb006]fNQT0oooo0400LG9c06m_K`1^K6`0KFUY06]VI@1ZI680JF5N06QNF`1V
FeL0IEQD06AED01SDTd0HDm9061<AP1OBD80GTHo05e3>`1M@3L0HT<h075@A@1^CdH0K4i606]?B01Y
CTP0Ide806A=B@1TCdd0IU=C06EDE01SE5@0J5UJ06AHF01RFU/0H5YK05mKG@1NGf40GV9T065YK01S
Kg80JWUl06n3QP1eRXh0NI6G07bGW`1nW:@0P:2Z08:V/@25ZkL0R;2n08Vb`029[k`0R:^g08RX/`27
Y:h0QZ2Y08BLY022V9l0P9>J07j?U@1lRi00NXJ;07R2QP1fOX40M7Ul603oool0@026OG/0PgQg081d
LP1lKfd0NF]X07IWH`1cHUh0L5iJ06eJE@1ZEE00J55;06E<AP1RAd40Gd<k05`n=P1I>S40ESD/05@`
9P1J<bL0Iclc06@n=01R?S@0H3hf05hm=P1K>cD0F3Td05Hi=P1F>c/0EC`l058l?01FA4@0EdQ705I<
B`1FCTh0ETi?05=?D01BDE80DeMH05=IF`1GGEl0G6AV069ZK@1WL7D0JgIk06ikP01_OX@0LH:907>4
S01eQhl0MhVA07R9T@1jRY40O8Z@07j:T01oRXl0PHV>08:9S@23R8/0Q8N:08F6R026QHL0QhB508N3
Q028PX8I0?ooo`100;bOR`2iVXD0]IF00;:AN`2_S7D0ZhM`0:R3J`2UOVD0XWYP09ieFP2KLED0V6a?
09EWB@2BHT<0Sedm08]H=`28Dc40Q4dY08Q@:`2=EC40ReDb08YD<P29E3<0Qe<c08E@<022CB`0OdXZ
07i8:P1mB2/0NdP/07e@=021FSh0Pei408ETBP25HTT0PUe3081O@`1nGT@0O5Tn07]B=`1mDCH0P5<h
08=F>`25F3d0Qe/n08QK?@29FS`0REPi08QE=@29ESH0S5/m08mQA02CId/0UfeB09]bF@2ON5l0XWeU
0:J2J`2ZQg40[Xaf0;6AO02eUX40^IZ60;bORb@0oooo000R0?ooo`1006Q`LP1ZL780Jg1b06eaL@1^
L740L75`075aL01cLG00M75_07EaK`1gLFh0N75^07UaKP1jLFd0O79]07ibKP20Lfh0PG9/08elM@2<
O7H0Rgaf08YkMP2:OGT0RG]h08QjM`28O7T0RWmn08f4Q02AR8L0RGmo08Z0P028OWh0QWin08EoO`23
OGh0PX220863Q023R8X0Qhj@09:KW@2IZ:X0Vk2b09bd^02M^;h0W;[109bla@2M`L/0WlKB0:7;f02S
cmd0XlgI0:78d`2M`L/0VK[409Fc_02@[;@0S:F/08NNY@22Uih0OY6F07V:S`1eQ8P0L7f106]gNQT0
oooo0400L79c06m^K`1^Jf/0K6UX06]UI01YHV00J5mM06MLF@1UFED0I5IA06=CCP1QCdX0H4a605i9
@P1MASh0G4<k05a0=`1J?3<0K4/o071?A01^CTD0Jde506Y>B01WC4H0IDY5069:AP1RCD/0He5A06MH
F01UF5L0J5aL06AJFP1RFU/0H5]K05iIFP1MGf40GF9T05iVJ@1OJVd0J7Ei0762QP1gS900Ni:H07jI
X01oWJD0P:2Z086T/024ZKH0QZnm08Vc`P2:/[l0Rjnl08Z/]`29Z;80R:>]08JOY`24VZ80PYJM082A
U`1mS980NhR<07V3Q`1gOX40M7Yl603oool0@026O7/0PWQf07mcL01kKV`0N6YV07EUHP1bH5`0KU]G
06]GDP1XDT`0IDe70698@P1O@c`0Fchg05Pi<@1E=2`0Dc0W04l[8@1N=b/0I3hb068m<`1P?3<0GS`e
05/j=01H>380E3Hb05<g=@1A>CP0E45005M8A`1LCTd0F4e<05I>C@1DCDd0DTa<059BD`1CE5D0DUIH
055FF01DG5h0FV=V065ZK@1UL7D0JGIk06ajP01]OH<0KWn70722RP1bQXh0M8VC07F9TP1hRI80NhZA
07f;T@1oRY00P8Z?08:9SP23RH`0Q8R;08F7R@26QXL0QhF608N4Q028PX8I0?ooo`0`0;bNRP2hVHD0
]IAo0;6?N@2]Rg@0ZXI^0:J1J02SO680WgMM09abE`2IKE40UFQ;099SA@2?GSh0RePh08MC<@24CR/0
PDXV08A=:@29Dc00R5<`08MB<026DS40Q54`089?;`20C2d0ODX[07U7:01jCBl0PE/o08APA@22HDH0
PV=8089QAP22HTH0PVA:08=TB`21HDP0OUa107UF>`1hDCH0O54f07mC>@22ESX0Q5Pl08EI?025F3X0
QEDg0P25E3D03P26ESP0RU/n08mRAP2CJDh0V6mE09aeG02PNf<0Y81Y0:R6K`2/RgD0/91j0;BEP02h
VXD0_9j;903oool00280oooo0400J71b06Y`LP1/L740KG1a06maL@1`LG00LW5`07=aK`1eLFl0MW5^
07QaKP1iLFd0NW5]07]aK01mLF`0Og9]089dKP22Lf`0Th1h08mnM`2=O7L0S7]f08]kM`2:NWL0RGUe
08QiMP29NgX0R7em0927Q`2=QXD0RhB408Z4Q@29PX<0Qh:408J3Q026R8T0QHV;08B;S`23S8l0R9BG
09BQX`2O/;80XKRk0:6k`02O_<<0W[g609k1b`2Pa]40X/cH0:C@g`2Vd=h0Y/kJ0:?8dP2N_lT0VKO0
09>`^02>Z;00RJ6X08BJX01oTiP0NXbA07J5R@1aOX80K7Mj6@3oool0@01`LG80Kfi^06e[JP1/J6L0
JVAS06UQG`1WGU/0IUYG06EGD`1SE4l0HU1;061=A`1NBD<0GDHn05]2>P1J?cH0FSdd05/l<P1cD4<0
L4m406i>A01[CDD0JDe706I;A@1SB4<0H4Q5065;BP1QCe00JeeL06QLF`1VFe/0I5]L065IF@1OFEX0
GEUJ05eOH@1MHF<0GFIY05iXK01TLWL0KWf107R;S`1mU9X0Oi^Q082NYP1oX:T0P:>_08>X]@25[[`0
Qk?208Zc`@2=/l00S[2l08b/]P2:Yk00R::[08JMY@23V9l0PI>I07j>T`1lRHh0NHB807MoPP1dNW`H
0?ooo`1008ElN`22MgD0OW9`07Y]JP1gJ6D0Lf=O071NFP1/FE@0JEA?06I?B@1SBT@0GdDn05a0>01H
>S80E3@/050_9P1?:b80D2XP06<l;`1S?C40H3`b05hk<`1K>c@0F3Tc05Df<@1A=c<0DSXh058n?@1K
BDL0FDU705M8A`1EBDP0DdQ60557AP1?AdL0Cd]=04m=CP1ADU<0DeIG05MMH01JHVD0GfQ/06A_M01X
MW/0JWUo06]kPP1[OHD0KH2906n4S@1aQi40LhR@07J9TP1jRi<0OHbB07n;T@20Ri00PHZ?08>9S@24
R8/0QHN:08J6R027QHH0QhB408R3PQT0oooo0400_9j:0;RIQ02dU7h0/8mh0:b9LP2XQ6`0Y7mV0:5i
G`2MM5T0VVmC09IZC@2CIDL0Sf1108aJ>P27E380PddZ07m89@20B2D0Q4dZ08IA;P25DBl0Q58a08=B
<@21D300Odl_07e?<01mD380OU<d07mE=`20ESP0OeLi07iH>P1nF3/0OELi07eG>P1mEc/0OULk081J
?@22GT80PUe307aF?@1hCcD0NTle07eC=`20ECT0PEHj089E>022E3H0PU8c089A<@23DS80QEDh08YM
@@2@IDX0UFaB09YbF@2NNF00XgiW0:N4K@2[RG<0[hmi0;>DO`2hVHD0_9j:903oool00280oooo0400
J71b06Y`LP1/L740KW1a06maL01aLG00Lg5`07AaK`1fLFl0Mg5^07UaK@1jLFd0Ng1/07]`J`1lL6/0
Og5/08QhLP2:NG80T7mg091mM`2>OGL0SGeg08elM`2;NWH0RGMc08QhM027MWD0QGIf08]lO02<PH00
S8:208b4Q02;Q8@0RHF508V5QP29RX`0R8f?08VAU028TI@0RINK08fMX@2JZZh0Y;Vm0:Bm`@2R_/D0
X;k70:31b`2Ra]40Y<_G0:G@gP2WdN00Z=3M0:S=e`2Ra<h0W;c509Nc_02A[;<0S:B[08JLX`21UIX0
O8fB07N6RP1aOh<0K7Mk6@3oool0@01`LG80KVi^06eZJP1[IfH0JV=Q06QPG@1WG5T0IEUE06AED@1R
DTd0HDi805m;A01MAcl0Fd<k05Pn=@1D>C00Fc`c06I5>@1dDDD0L4m406e=A01ZCDD0J4a606E:A01R
Ad80HDY7069>C01SDU40JEUI06MJF@1TFET0HeYJ061GF01NF5T0G5QJ05eMH01MHF@0GVQ[05mYK@1S
LGL0J7Un07B6R`1oUY/0PIbR082NY`1oWjT0Oj:^086W]024[K/0Q[;108Zea02>]L@0TKG108n`^P2<
Z[@0RZF^08NOZ025VZ40PYFK07n?U@1mRXl0NXF907MoP`1eNWdH0?ooo`1008ElNP21MWD0OG5_07U/
J@1eIV<0LV5M06iLE`1ZEU80Ie5<06=<AP1PAd00GD4j05Tl=01E=Rh0D2lV04TW7@1:9Q`0F34U06Lo
<P1R?C80GS/b05/j<P1I>S<0ESTc05<g<P1C>cL0ET8o05U9AP1LCD/0Ed]905A8A`1BAdH0Cd=304e3
@`1<@d@0C4M804a9BP1>D580D59E05AIG@1HGf<0GVI[06A`M@1WMW/0J7Uo06QiP01XNh<0JWn706b3
S01^QY00LXVC07J;U@1kSYD0OHfD07n=T`20S940PH^@08>:SP24RH`0QHR:08J6R027QHH0QhB408R3
PQT0oooo0240^ij:0;NHP`2cTgd0[heg0:Z7L02VPVT0XWaS09igG@2KLEH0Ufa@09=WBP2@HT<0SE`m
08UG=P25D2h0ODHR07Po6@21BB@0R58_08EA;`23D2l0PDl_081@<01oD340OU4b07mE>021GD00QFA8
08ASA`1oG400OETl07]F>01jDSD00P1iDC@07@1iCc40NDlb07YC=@1lECP0OUHk07mG?01jDSP0N4ld
07]A=P1mDcL0OU<g07mC=P1oDS@0Oe4c081@<@21DC80Q5Dg08MK?P2=HTL0TVY?09M`E`2LMeh0XGeU
0:F3K02ZR780[Xih0;>COP2gVH@0^ij:02@0oooo000R0?ooo`0N06U`LP1ZL780K71a06i`L@1`LG00
LW5`07AaL01eLFl0Mg5^07UaKP1jLFd0Ng5/07a`J`1lKfX0NfeX07U[I024Lfd0T7ae08mmM@2@OGH0
T7af08mmMP2?O7H0SGYe08]hL`2;NWL0SGil08amN`2=OGd0SGin0P2<Ogl0802;OWl0RH2108V1P`29
Q8H0RHR<08^?TP2;TYH0S9NL08jNXP2DYJX0XKFi0:Jn`P2T_lD0X[o70:71b`2Ra]40YL_G0:K@g@2Z
eN<0/MSU0:cAg02VbM<0X;o909Zg_`2D[kH0SZJ]08VNY@23Ui`0OHnD07R7S01bOh<0K7Qk6@3oool0
@01`LG80KVe]06aYJ@1[IV@0JF9P06MNG01VFeP0I5MC06=DC`1QD4X0H4a605i8@@1LA3d0FT0h05Dj
<@1@=2X0GSld079>@P1bD4@0Kdi406a<A01ZCDD0J4a506E:A01RB4<0HTa806ECD@1UEE<0IUIF06AG
E`1SF5L0HEMG05mFEP1MEUL0G5QJ05aLGP1LHF@0GVMZ065ZK`1SLGL0J7Uo06n3R@1mU9T0PIfS082N
Y`1nWZP0OZ6]082V/`23ZkT0QK2o08Nc``2C^lT0U;W509:d_`2?[KP0S:Ra08VRZP26W:@0PiJM086A
U`1nRi00NhJ:07R0P`1eNWdH0?ooo`1008ElNP20MW@0O71^07QZI`1dIF40L5mK06aIE@1XE4l0IDi9
0659@`1NA3d0FShg05Li<@1C<bX0CR`S04PU6`1C;R<0I3``06@n<P1O>c80G3Xb05Tj<`1F>S@0E3Pc
054h<`1A>cP0E49005E6A01EB4H0DdU70598A`1@AdH0CTI504]6A@1;AdL0BTY:04]>C`1<DE80Ce9E
059HG01FGV80G6IZ06AaM@1VMg/0IWQn06IhO`1VNX<0Igf606Z1RP1[Phh0JhB?07F<U@1kT9L0OHnF
07n>U@20SI<0PXbA08>;S`24RXd0QHR;08J7R@27QXL0QhB508R3PaT0oooo02<0^if90;JGP`2bTG`0
[Hae0:V6KP2TOfL0X7YP09adFP2HKU<0U6U<095TAP2=GT00RUTj08ME=024Cbd0P4XW085;9`26DRh0
QU@a08=A;`20Cc00OTla07e@<@1lD380Ne4d07]C=P1lESX0OU/o07eM@@1lGD00Nea007YK?P1iFSd0
N5Tk07QH>`0207MI>`0K07QF>01iE3P0NeDi07eF>@1nEc/0Ne@i07UA=P1jDCH0Ne8f07aA=@1lDC<0
O4lb07a>;`1iBBX0ODh_08EI?02:H4@0T6Q=09E^E@2JME`0Wg]S0:B1JP2YQg40[Heg0;:COP2gV8@0
^ij:02@0oooo000R0?ooo`0E06U`LP1[L780KG1a06m`L01aLG00Lg1_07EaK`1fLFh0N75^07YaK@1l
LFd0OG5/07e`J`1mKfT0NV]V07AVH01jJfH0RWQa08mlM@2AOGH0TWaf0080TGef00D0SgYe08ehL`2=
NWH0TH5n0962P0020921P00R08n1P02>PH00SH2008b1P@2<Ph@0S8J808f:S@2>SY40T9:G096FV`2B
Vj00U:6W09^[/@2S^;d0YKg40:>oaP2R`LX0XlG?0:G:e@2Vc]X0Y]3M0;GKi`2aeN00Z/cF0:?3c02M
^/<0Uk6i096Y/02;XJL0Q9RN07n@U@1iR8d0Lh2406ehNaT0oooo0400L75b06i]K@1/JFP0JVES06QQ
G`1WGEX0IEUF06=ED@1RDT`0H4i805m:@`1NAcl0G4<j05Xn=@1F>C00ECL/0691=P1_CD40KTe206e=
@`1[CDD0JDe506M=A@1UBT@0HTU4069<B01VE580IUID06EFE@1TEUH0HUMF061FEP1NEED0G5EF05]H
F@1KFed0G61S05iUJ@1RJW00IG9g06UjP01`PhX0N8nF07nJX01oWJH0OYjX07fP[01oYK40PZZh08>^
_@23/L40V<3>09Nmb@2E]l<0TK6k08jZ]02;Y:d0R9jV08FHW`22TYP0OXbA07^6R`1hPH@0MG]m603o
ool0@024NgX0P7Ec07]_K@1gJFH0LV=O06iMF@1ZEe<0IU5<069<AP1OAT00Fd0i05Pk<`1E=Rd0DS4X
050/8`1D;R80HCT/06Ho<P1O?340G3Xa05Tj<`1F>S<0E3Xd058i=01?>C@0D3/h0592?`1A@d40DDA3
04m5A01>AD@0C4A304Y2@P18@d80AdE504M7B018Bd`0BDiA04aCEP1@Fed0EV9U05a[K`1SLgP0IWQm
06EhOP1SN7l0HgV206ElQP1WP8X0J8:=06V4T01iTI/0O9:J07jAV@20T9L0PHnE08:=T`23S900Q8Z>
08F9S026QhX0QhJ708N4Q@28Ph<I0?ooo`0I0;^MR@2fUh80/I1k0:b:M02WQ6`0XgiU09ihGP2JLEL0
UF]@095VB@2>H480RU/l08QF=P26Dc40QU4_08eH=@2CGSX0S5Pe08=A;`1oCbl0O50`07]?<@1jCc80
NE4c07QB=@0207QC=`0607MD=`1gEST0MULj07IF>P1eEST0M5@h1@1cE3L06P1cESP0MUTk07YL@01m
Gd@0OEi307YH?@1hDcL0N54f07UA=@1iD3@0NU0b07Y><@1jCc80O54d089G>P28Gd@0SVI<09=]D`2I
Le/0WWYR0:>0J@2XQW00[8af0;6BO@2fV8<0^if:903oool00280oooo0400JG1b06]`LP1]L740Kg1`
075aL01cLFl0MG5_07QaKP1jLVh0O79]07ebK@1oLV`0P75[081`JP1oKVP0P71Y08AcK02<NG40TGef
09AoM`2DOWL0U7eg09=mMP2BNgD0T7Yd091kM`2CPGh0UHJ309B5Q02CQ880TX>20963PP2@PH40SX:2
08j5Q@2?RHX0T8b>096@T`2DUIP0UYZN09NPY02JYJ/0WZfc0::e^P2T^/40Y;g50:?0b@2TaLh0Y/WD
0:K<f@2Wcmd0^=gX0;CHhP2^cmT0YlK?0:2maP2I];`0Tj^b08bSZ@26VZ00P9:G07Z9SP1cPHD0KGQl
6@3oool0@01`LG40KVa/06]XI`1YI680J61M06ILF01TF5@0HUA?065@BP1PC4H0GTQ105e5?@1L@CP0
Fchd05Xj<01M?C40HT8g06U9?P1/C480K4e406Y=A@1YCDD0Ide606E;A@1SBT@0Hda806EBC`1VEeD0
IEMF06=FEP1QEUD0GeEE05eDE01KE5D0FUMH05YKG@1KGf<0GFEY069/L01VLgT0Jg^20764R`1fSI@0
O9JM07fJY01mW:H0O9n[07jT/020ZKL0PJfl08:``@2J`]00Vl3=09NjaP2D];h0T:fg08fW/029X:P0
QYZQ08>DVP1oSY<0O8N<07V1Q@1eNghH0?ooo`1008AkN@1oM780NVi[07EWI@1aHEh0K5]G06QED01S
CdT0H4U305a3?01H?CH0ECP`05<c:P1A;R@0DB/P05@^8P1H<bP0FSP]05Xi;`1H>C40ESTc05<i=01A
>S@0CcTd04hh=01>>SL0CShl04i1?`1=@T40C49104Y1@@18@D40AT1004A0@013@D80@dA604A8BP15
C4l0BU9F04iIG@1CH6@0FFQ/05i_M01RMGX0HWIn065fO`1QMh40Hg^506EoR@1VPHd0IX>@07VBW@1n
U9h0Oi>K082AV@21T9H0PXjD08>=TP24Rhl0QHZ=08J8RP27QXP0QhF508R3PaT0oooo01d0^Yf90;FF
P@2`SgX0ZhUb0:J2JP2QO6<0W7EK09M_E02BJ4`0SV9508YL?P27EcL0Q58a08=?;023CBT0QDlZ08EA
;`22D2l0ODd]07Y<;@1hCBl0Mdha07E?<P1eCc<0ME0e07EA=@1cCc<0LTha079?<`02075A=@0Q071A
=@1_DCD0Ke4d06i?<`1^CS80KDlc06i@=01_DCD0LU<h07AF>P1fF3d0N5Tm07QG?@1gE3X0MU4g07I@
=@1gCc@0N4lc07Q?<P1hCS40Ne4e085G?026GT<0S6E:099/DP2GLUX0W7UQ0:5oJ02WQFl0[8]f0;6A
O02fUh<0^if:02@0oooo000R0?ooo`1006U`LP1[L740KG1a06m`L01bLFl0M75_07IaKP1iLFh0Ng9]
07ebK@20Lfd0PW=/08=cK025Lf`0Qg=[08UfK`2=Ng<0TGmg09J1N02GPWX0Uh5j09N0N@2GOgP0UWig
09AlMP2DOWP0UH5m09N7Q02GR8H0UXN509F5Q02CQX@0TXB30963P`2AQXD0THZ:09:?S`2CTY@0UYNJ
09VLX02KXZD0WJN/0:2]/`2S]KX0Y;Vo0:Fl``2T_lP0YLC=0:G8dP2Ub]L0Y<gK0;[Oj`2ig>L0/M?M
0:[9d`2S`<P0W;Jn09F]]@2>Y:/0R9bQ086CV01jRXl0M86506eiO1T0oooo0400L71a06e/K01[IfH0
JF=Q06MNG01UFUL0HeIB065BC@1PCTP0GdY305i6?`1M@cX0G40f05`m<P1M?2l0Gclc06=4>@1WBCl0
Jda206]>A@1ZCTH0JDi606M=AP1UC4D0I4Y506=<B01SD4d0IEID06EHE`1SEeH0H5ED05iEE@1LE5@0
FU=D05UFE`1IFU`0Ff1S05iUJ@1SKG40J7Aj06emPP1aQ8/0MXbD07ZDW@1kUj40NiZU07^NZP1mXk00
OjRf082[^`1o[[l0W<?B09k3d02J_LT0U[O209>`^P2?ZK80Rj:Z08NLX`24UI/0P8nD07f8S@1iPXD0
MG]n603oool0@024NWT0OWAb07U]JP1dIV<0KemL06YIE@1UDTh0HDa605e5@01I?cT0ECTb058d;01@
;bH0CR/P04hY7@1?:b00DBhT05<c:P1E=Rh0E3Pa058h<P1@>3<0CSPc04dg<`1;=c<0BcTf04/l>@1;
?ch0BT0o04Po?`17?Sh0A3hn04<n?P10?Ch0@3m10412A011ATX0A4]?04UBEP1=FEh0DV1U05MWK01K
KG<0GW9i05mcO01NM7d0GgN0065kQ@1TOXT0IH6=06F3T01jTid0OYFN082DW@21Ti/0PY6H08>@UP23
SY<0Q8b@08F:SP26R8/0QhN808N5QP28Ph<I0?ooo`0Q0;ZLR02dUH00[hih0:V7L02TP6T0WWUQ09Ub
F@2DJe40SfE908YN@@26F3X0PU8c07m=;01mB2H0O4HS07]68P1jAB80N4HU07M7:@1eB2X0LdT/079:
;P1aBbl0L4``071<<P1`CC80Kdda06i;;`1]BRh0KD/`06a;<01[Bbl0Jd``0080JT`a01d0JD/`06Y;
<@1[CC80KDhd06iA=`1aE3X0LeHl07AF?01eEC`0M5<i07=@=`1dD3H0MU0f07M@=@1iD3D0NE0d07U?
<P1nE3L0Q5a008YSB@2@JU40UW5I09]hH02POVL0YXA^0:^;M@2`TG`0]IN30;ZMR@0T0?ooo`008P3o
ool0@01YL780Jg1a06e`L01`L700LW1_07EaKP1gLFh0NW9^07ebK@1oLfd0PW=]08EdK@27MFd0RGI]
08ahK`2?Ng80Tgmg09J3N`2IQ7`0VXEm09^5O@2KPg`0VX9k09Z1NP2IOgT0V81j09R2O@2JQh<0Vh^8
09V9Q`2HQX@0UXJ409B6Q02CQH<0ThN609>:RP2ESi00UY>D09VIV`2LWj40WjBW0:2X[02R[K40Y;>h
0:Fg_@2V^l80Y[o70:K3c02Vam40YLWE0:7:f02fg>P0_N7/0;GGh@2]c=H0YL;;09ji`@2G[kH0T:J]
08VMX`22U9T0Nh^@07F2QP1^NG`I0?ooo`1006m`L@1]Jf/0JVIV06QRH01VGE/0I5QE069DD01PD4/0
Gda605e8@@1MA3`0G44h05`n<`1L>bl0GS`a060o=01TAC/0J4]206]=A01[D4L0JU1706Q>A`1WCDL0
ITa606A;AP1SCDP0Hdm<06ADDP1TF5L0HUMF061DE01NEE@0G5AD05UBD`1HEEL0FEUL05]PH`1NIFT0
Hfib06QfN`1^OX@0LXB<07F<T`1hTY/0NIFO07ZIX`1kWJT0OJ:_07nW]@20ZkX0OZbm09S0c`2RamD0
WL7=09Vja@2E/[d0T:^d08bT[029WJD0QIJM086@U@1mRHd0NH:607IlOQP0oooo00d0PgYi07icL@1h
K6T0LVAR06eMFP1XEU80Hdm;05i9@`1I@S`0EC`e058f;P1?<2P0C2/Q0080BbHK0340BRLN04d/8`1@
<RX0DS@]050f<01?=c40CCLa04/f<P1:=S80B3Hb04Ph=017>CL0Ac`k04Lo?P15?Sh0@cdm044m?P10
?3h0?C/m03dm@00m@D@0@4I:049:C`17DEH0BeQN055PIP1EIVd0FFac05]`N01KLGX0Fg=m05efP01P
NXD0Hgj906J2S@1VPi00N96K07nGX021UYl0PYFM08:CVP23TIL0Q8nD08B=T@25Rhl0QXV<08N7R@27
QHH0R8>301T0oooo01l0^Yb80;BDP02^SGL0Z8I_0:9nI`2LMeh0UW1F095XCP2;HDD0QUXm089C=@1n
CBd0NTLV07M27`1e?a/0LchL078o7@1c@B40LT8S07139P1^ABP0KDDY06a6:P1[Ab/0JdT]06]:;P1Z
BRh0JDP/06Q7:`1XB2`0J4T^00<0IdT_01h0ITT`06I:<01WBS40J4/b06U<=01[CcH0KE4i06mC?@1a
ECh0LEDm071B>@1`D3L0LU0g07A@=`1fDCH0NE8g07aC=`1kD3<0O54e08=J?`29HTP0SfYA09A`F02J
Mf00WgeW0:B4KP2ZRWD0[i1l0;FGP`2jWHTT0?ooo`008P3oool05P1YL780Jg1a06i`L01`L6l0Lg1_
07EaKP1hLFd0Ng9]07ibK@21Lfd0QGA]08QeK@2;Mfh0SWQ^099mL`2EP7L0VXIl09b7OP2NQgl0WXR0
09n8P02NQgl209j5O@0X09f3O02LPg`0W8An09f8P`2NS8P0WH^809^9Q`2IRHH0UhR509F7Q@2ERHL0
UXf<09RAT@2JUIH0WI^L09nPX`2SYZT0Y:^^0:F_/P2V/kL0YkJl0:Rj`@2X_lH0Z<?;0:S6d02Vb=@0
X<OD0:WAg`2hg^X0^]gW0:o?f02Wa<d0X;_309Va^02BZ:h0RijT08BEVP1lS900MH>706iiOAT0oooo
0400Kg1a06a[J`1ZIFD0If1O06ALF@1REe<0H59>05i>B01MBD<0G4Dn05]2>@1K?SD0Fc/a05`i;@1N
?C40H40e06I9?`1ZCD@0Jdm606]AB01ZD4P0JDm806M>A`1VCDL0IDe706A>B01RCd/0I5=A06AHEP1R
EeH0H5ED05eDE01KDe<0F59C05MDEP1IFU`0Ff1S05mVJP1TKW<0JGIl06moQ@1cQHd0MH^C07J?V01g
Tid0NINR07^LZ01mXJh0P:Nd08:[^P22[[d0TK_:09o7e@2Ram<0Vkg809Je_`2B[KL0SZJ^08ZOYP26
V9h0PY6F07j:SP1jPhH0MWan603oool0@023NWP0OG9`07MZJ01aHf00Je]H06EDD01PCDP0FdE005Hn
>@1A>340CS4Z04X[8`189Q`0AR4G04DR6@1691/0BRdU04hb:`1>=2d0CCH_04/e<019=C00B3@`04Hd
<015=340A3Dc04<g=@14>ST0A3dm048l?010>c/0?SXl03`i>`0j>C/0>CXm03Xo@P0lA4T0@4Y?04AA
EP19F5h0CUmV05=UK@1EJW80EVee05M_N01ILW`0FgEo05iiQ01SOXT0Ih>?06f8T`1jTY`0P9RR08>J
X`23Uj00PiBL08>BV@24T9H0Q8jB08F<S`26RX`0QhN908R5QP28Ph<I0?ooo`0M0;VKQ`2cU7l0[Haf
0:J4K@2PO6D0VWEL09=]D`2=IDX0R5e1089F>@1mCS00N4LW07A07`1`>QT0KCLE06/f501[>QT0K3dO
06/o8@1Z@280JD0S06Q19@1W@BD0IT4V06E3:01UA2X0IDD[06A5:`1TABT00P1SA2T08@1SABX0HTD[
0695:`1QA2/0HDD/0696;P1SBC00ID/b06M<=01XCSL0Je4j06aB?01/DCX0K50h06e?=`1_CcH0LDlg
07EA>01jE3X0PUXn08IK?P20ECT0PEPn08USB@2>JE40Tg1H09QfG`2NOFH0Xh=^0:V:M@2_T7/0]9J2
0;ZMR@0T0?ooo`008P3oool04P1YL780Jg1a06i`L01`L6l0Lg1^07I`K@1iLFd0O75/081bK023Lf`0
QgA]08]fK@2?N6h0Tgaa09R2M`2LQg`0XH^10:B;P@<0Xh^202/0XhZ20::9P@2RRH00XXR00:68P02P
R880X8Z40:6<R02OS8T0WX^809b;R02JRXL0V8Z709R;R@2IT8h0ViBC09jIV02QWIh0Y:>T0:JYZ`2X
[:l0ZK6d0:Vd^02Y^;d0Z[c20:_0a`2[a<`0ZlSA0:[;e@2XbmH0ZLoK0:gDh@2ce^00[loH0:W6cP2R
_L@0Vk>j09BY/02=X:D0QIJK07f=T@1fPhL0KWYm01T0oooo0400Kfm`06aZJP1YI6@0IUmM06=JE`1Q
EE40GU1;05e;AP1KAd00FT<k05To=P1I>c40FSP]05/h;01N?C40HTDi06U>A01/D4H0K55806]AB@1Z
DDT0JE1906M?B01VCTP0IDi806A?B@1SD4`0I5AA06AGE@1REUD0GeAD05eDE01JDU<0Ee9C05IDEP1H
FUd0Ff1T061WJ`1TKg@0JWMm06n0QP1cQHd0M8ZB07F=UP1fTI`0NIJQ07^KY`1nXJh0PZNd08F]^`28
/Kl0T;[909_5e02Ram@0W;k:09Nf`@2C[kT0SjR`08^PZ027VJ00Pi:G07n;S`1jPhL0MWao603oool0
@022NGP0O75_07EYI`1_HEh0JEUF069ACP1MBTD0Ed8m058k=@1=<bd0BBdU04DV7P127aH0@1/B040M
5@139Ad0B2lW04Xb:`1:=2d0BC@^04Pc;`16<Rh0A34]04<a;P12<Bl0@3<`040e=011>CT0@C/l03lj
>`0m>3X0>cPj03Tf>@0f=ST0=CPl03Lm@P0i@TL0?DU>045?E@17Eeh0C5mV04mTK01AIfl0DVUb05=[
M@1FKWT0FG=n05ehP`1ROHT0J8>?06j9U01iTil0Q9nZ08VQZP24VJ80PiJN08>CVP24TIL0Q8jC08F<
T026RXd0QhR:08R6Q`28Ph@I0?ooo`100;VKQ`2bTgh0Zh]e0:F3K02NNV<0Ug9J095ZD02:HTL0Q5Tn
07eA=01gBB/0LT4Q06dh5`1X<@l0IBd<06@`4@1T=QP0ICXK06Dl7P1T?1h0Hc/O068k7P1Q>al0H3/P
05ll8@1O?B<0GclU0611:01P@RP0Gd4W05m09P1N@2H0GSlV05do9P1M@2L0GD4Y05e2:P1NA2`0GdH_
0659<`1TC3H0IDhg06I==`1WC3H0J4/e06U;=01[Bc@0KTde079>=P1gDST0OELo08ENA@2;IT`0RfI=
08UUC02=JE40TVmH09MfG`2MO6H0XX=]0:R9M02^T7/0]9J20;ZMRB@0oooo000R0?ooo`0C06U`LP1[
L740KW1_075`KP1cL6d0MW1]07Y`K01mLF`0PG9/08EcK029MF`0SWI]09=hK@2HOG40WH=h0:><P02V
ShD0Z8n50:R>Q0020:N>Q080Yhf402T0YXf40:J<Q02USH@0YHf60:F?R02UT8X0Xhn90:2<R02NS8P0
W8Z709Z:Q`2JS8X0W96?09jFU02RViX0Y:2O0:NUY@2ZZZ/0Zjj`0:fb]@2/]KT0[KVm0:jm`P2_`LL0
[lK<0;3:d@2`c]H0/<oI0;;Eh02efnL0]=OQ0;7@fP2[b=00Y;k609fe_02FZk40SZ6W08JGW01oSY80
MhB806mjO@0I0?ooo`1006i_L01[JFT0J6=S06ANG01QF5D0Ge=?05a>B@1JBD<0FD@m05Q0>01G>c80
EcP^05Pe:@1J=b/0GShc06E:?`1/DDL0KU9806eBB@1/DTT0JU5906U@B@1XCdP0ITm806E?B@1TD4X0
IE9>06AEDP1TEeD0HUIE05mDE01ME5@0FU5B05IBD`1FE5H0F5YM05]QI01PJF`0IG1e06]hO`1_P8H0
LXF<07B9T@1dS9D0MY2J07VEX01lVjL0Oj6]08>W]028[[`0S;;109>lb`2LamH0WLCB09^ob`2H^<<0
U;6j092Y/P2<XZT0R9ZQ08BCV01oRi00NhB707IlOaP0oooo0400PWUg07]`KP1dJ6H0KEmM06IGE01O
Cd/0FDI205<n>P1==c40B2lY04<W8@0o8AT0?1XB03/I4@0l7aL0@BTQ04L`:@19<R`0Ac8]04Hb;@14
<Bd0@S0/044_;00o;R`0?Rl]03d`;`0n<c80?SHg03hh>P0l>3X0>SLj03Tg>P0f=CP0<cDi038g?00d
?440=T5703]8CP0oCeL0AUMO04UMI@1;HFT0CF=]04eUL01?J7<0Dfah05IaO@1KMX80H7b806J3S`1/
Qi@0MI6M07jKY`21VjH0PYVR08:FW`23U9/0Q96H08B?U025SI40QX^>08N8RP28QXL0R8B46@3oool0
4P2iVhL0/I9m0:Z:M02SPF/0W7UQ09E`E`2=Idh0QUi407mE>P1hCC00LT@V06/k701V<a<0HBd>05h]
3P1N<140H3@E060f6080GcLK00`0GSHJ05`f6P1K=AT0FSDJ05Te6P1I=Q`0FSPO05Xj8P1J?2<0FSdU
05/n9P1K?RL205Xn9P0N05Tn9`1I?bL0FD0Y05Y1:`1LA2l0GTPc0619=01PBC<0H4Pc0658<P1RAc40
I4Pb06I8<P1YBC@0KD`e075?>01fDSX0O5Ln085L@`24GdL0Qf=;08]XD@2@KUP0UGEO09]kIP2QPVd0
YhUd0:f?N`2cUX80^Yf9903oool00280oooo01D0JG1b06]_L01^Kfl0L6m^07=_K@1fKf`0NW1[07ia
J`22LV/0QW=[08]dJ`2AMfd0UgY_09ioM02UQg/0Zi240:jDR02^ThP0[I:70:bAQP2[T8H00`2[T8L0
:02[THP0Zi:90:^BRP2ZU8`0ZIB>0:NBS02TSh/0XHf909j;Q`2LRhL0Vhj;09fBS`2PUiD0Y9bK0:RR
X@2[Z:P0[Zf]0:na/P2`];H0/KNj0;6j_P2b_/<0/l;80;C7c@2ebm80]]3H0;KBfP2hfN<0_=oZ0;[L
iP2de=d0[/[B0:O1b02P]kd0V:fc092SZ028VId0P8nC07N4R01_NWhI0?ooo`1006i_K`1ZJ6P0IV9Q
06=LFP1PEU@0GE5=05Y;AP1HAT00ET4j05Dl=01D>2h0E3@Y05Hc:01I=b`0H44f06U>@`1_E4T0L5A;
06iDB`1]DTX0Je5906U@B@1WCdP0Idm906I?BP1UDD`0IUA?06EGD`1UF5H0HeMF061EE@1ME5@0FE5B
05EADP1EE5L0EeYM05]QI@1PJFh0IW5f06]iO`1_OhH0LHB;07:7T01dRi@0MHnJ07VDW`1lVZH0P:6]
08BX]02:[kd0S[?109Fmc02La]H0W/KC09c0c@2I^/D0U[:l09:[]02>Xj/0RIbR08FDV@20S940NhB8
07MmOaP0oooo0400PGQg07Y_KP1bIV@0JeeK06=EDP1LC4P0ED<o04lk=P18<Rd0@bXT03dR6`0h6Q80
=AH>03@H400h81P0?b/S04Da:P16<B`0AC4/04<`;011;b/0?bdZ03d/:@0k;2X0>R`[03X^;@0j<340
>S@e03/f>00j=ST0>3Hi03He>@0c<cP0<3<h030f>`0a>d40=D5803U8C`0nCeL0@UEM04AIHP16GFL0
B5mZ04URK@1;IW40CfYf05=_N`1GMH40GG^706>1SP1ZQY80LXnL07VGX`1mV:@0P9RR086GX022U9`0
Q9:I08B@U@25SY80QX^?08N9R`28QXL0R8B46@3oool0802hVXH0/I9m0:V9L`2QP6T0VWMO099^E@2:
I4/0Pe]107]B=P1cB2`0K3hP06@d501M;@`0F2/:05H[301G;Pl0FC0C05Xb5@1J<aL0FC<G05Pb5P1G
<1D0EBlC05@^4`1C;QD0DblF05<a6@1D=1/0ECHN05Hh801F>R80ES/T0P1F>bD01@1F?2D0ESdW05Hn
:01G@2/0F48]0080FD<^01L0FT<^05Y2;@1K@Rd0G4<^05i4;`1QABl0HdLa06M9<P1[BcD0L4hg07EB
>P1hDc/0O5Lo089OB028ITl0SVeG09AdGP2JNVD0X85]0:J8M02]Sg/0/iJ20;VLR@0T0?ooo`008P3o
ool05@1YL740Jfm`06i_KP1`KVd0Lfi/07I^J`1jKfX0OW1Y089aJ@27LVT0S7AZ09=fJP2KOG80YXIi
0;2?PP2fUhT0]YR;0;BGR`2bUHX0/9B90:nCR0020:jBR00Y0:nCR@2`U8X0/IJ<0;2GSP2`V8l0[YNA
0:^ES`2WTXd0Y8n:0:6<R02NRhL0WHj;0:2CT02SVIL0YYnM0:^UX`2_ZZT0/Jn_0;>c]02d][P0]KVk
0;Fl_`2f_l<0]l?80;W8cP2jcM<0_=;I0;gEg@2ogNH0`>7[0;oRk02ien00//gE0:_3bP2S^Kl0VZnd
09:TZ@2:VYh0PHnC07R5R@1_Ngh06@3oool0@01^KVl0JFQX06EQH01QFeT0GUAB05Y>BP1GB4@0ED<m
05<m=P1A>300D3@Z04l_901B<BL0F3T^06A6>P1`DdL0LeM<079FC@1`ED`0KU=:06]AB@1YD4T0Idm8
06I?B@1VD4/0IU=>06MFD@1WF5D0IeYG06AIE`1QEeH0GEAD05QADP1EDE80E5AG05MJG@1KHVH0H6Y_
06IaM`1ZN7h0KGj50722RP1aQhl0M8ZD07J?V@1iU9l0O9ZV082P[@25Yk@0Rjjl08nc`02F_/d0W<GD
0:7:f02N`m00Vkc709Rd_P2D[KD0SjF]08^MY026UI/0PHfB07b5R@1gOH0H0?ooo`10085hM`1iKVd0
LFES06ULF@1QDU00FDU60550?01:=c<0@bhY03dU800f71H0<1<<02/@2P0[50h0<alI03h[9@14<B/0
A34/04<`;011;b/0?RdY03/[:@0i:RP0=bTY03HZ:P0f;2`0=c0`03Pc=00h=CL0>3Hi03He>@0c=3P0
<3<g02hc>00]=S/0;cY10390A`0fAdh0>TaE03eAF`0oEV00@EUT04=LI`15H6/0B6A`04aXM@1?KW/0
E7>005YiQP1POh`0IX>?06j=V@1eTj00O9VU07nIX`21Uj40PYFM08>CVP25TIL0QHjC08J<S`27RH`0
R8N808R4Q1T0oooo0280^9Z60;2AO02XR780X7iX09QeGP2?Je<0Qf9907mH?P1fCS<0KT@X06Di701L
;Pl0Db@504/P0P1:8PH0CRP<058/4@1D;Q<0EBlC05@^4`1C;Q80DRdA050[4@1>:Q00C2T@04`Z4P1=
;1D0CRlH04lb6P1A=1d0DSLP05<h8P1C>R<0DS/T0P1B>bD00`1B?2H0DcdX05<m:@0205<m:P0G058m
:@1C?BT0E3hZ05Ho:`1I@Bd0Fd<^05i4;`1QAC00IDLa06Q8<@1]Bc<0LThe07QC>`1nG4H0QFA>08][
EP2BLeh0V7YU09n1K02UR7@0[8mk0;:EPP2iW8T0903oool00280oooo0400JFma06]_K`1]KVd0L6e/
07=]JP1fKFT0NFiX07i_J022L6P0Qg5X08ebI`2BLfL0Vga`0:Z9N`2gU8D0`Yj?0;jMS`2jVXd0]iR;
0;BFRP2bU8T0/I>80;6CR@2cU8X0]9J;0;JIS`2gW980]YfD0;>LU02`VI80ZiF?0:JAR`2RSHP0X8b8
09n?R`2RU940YIZH0:ZQW`2^YjD0/Zb[0;Fa/@2h]KD0^KVj0;Zl_P2j_l40^l;50;c5bP2mbLh0_lkD
0<7DfP32e]d0a^3X0<OSk035i^l0_]_S0;K@e`2^a/`0Y[_109f`]P2DYZX0Ri^O08:@U01iQXT0L7]n
6@3oool0@01]KVl0J6MW06APG`1OFEL0Fe9?05M;B01DAD40DClj04lj<`1==2`0C2lV04XZ7P1;;R@0
F3/a06Q:?P1hFD`0N5]?07EICP1bEdd0KeA;06]BBP1XD4T0ITm806I?B@1VD4/0Ie=>06UHD`1ZFeL0
JEaI06IKFP1RF5P0GEEE05QADP1DDE80DeAG05IJG@1JHFH0H6Y_06AaM`1YMWd0K7f406n1RP1aQXl0
M8^D07J?V@1iU9l0OIZV086P[026Yk@0Rjjj092b_`2H_/d0WlGD0:C>g02Qa]<0W[k:09Zg`02F[kL0
TJN^08bNY@27UY`0PXjB07f6R@1gOH0H0?ooo`10081gMP1hKF`0KfAR06IJF01ND4d0EDI304dl>@15
<bl0?RTU03HP6`0`5a80:0h8028=200W5A40<R0L040^:013<R`0@c4]044`;00o;R/0>b`Y03PZ:00e
:2P0<bPX038X:@0c:R/0=2h_03Ha<`0g=3L0=SDi03@e>@0b=3P0;S8g02/a=`0Z=3/0;3U002lnAP0b
ADd0=DYC03Q>F00iDUd0?5EQ03iII@11GFT0A65^04QVL`1<JgT0DG5o05MgQ@1LO8X0HH6>06Z;V01c
TYl0NibY07jJYP20V:80PYJO08>DV`25TYP0QXnD08N<T027RX`0R8N808V4Q1T0oooo0180^9Z60:n@
O02WQg80WWeW09IcG@2=JE80Q5m607]E>`1bBS00JD0T060e6@1G:`h0C24504HN0`157`D0B2@:04dY
3`1?:a42050/4P0504l/4@1=:Q40BRP@04PW3`169Ph00P169@h01P18:140BR`E04d`6P1?=1h0D3LQ
050h8P80CcPS00D0CSPT04hi901>>BD0CCTU04`h9@0204/g900F04`g901>>2D0D3XW058m:@1E?b/0
F40/05]2;P1N@bh0HDD_06E6<01[BS@0Le8l07YJA@21Hdd0R6YE08mbG@2FNFD0WH1/0:B7L`2[SW/0
/YF20;VLRB@0oooo000R0?ooo`0E06Q_L@1ZKVl0K6e]06m/J`1bK6T0MFaX07U/I`1mKFH0PViV08Q`
IP2=LFH0TG9U09MiJ`2XR7X0^YJ70<RRT@34XI40_if?0;^JS@2gUhX0]9F90080]9F:02T0]iR=0;ZJ
S`2lWI40_J2D0;^QU`2iXIP0]9jF0:jHT@2XTX`0Xhf80:2<Q`2PSh/0XiBA0:JJV02/XYl0/JRV0;F]
[02i/k80_;Ng0;fk^`2n_kl0_/730;k4aP30al/0`L_?0<??e@35e=T0amSM0<gRj03?j>l0c>[b0<?N
i@2kdmX0//S>0:Vm`P2P/[L0UjN/08fLX024TID0NXJ:071kOP0I0?ooo`1006e]KP1WIVH0HUiM05eG
E@1HCdd0E4Q50512?@1=>cH0BSH_04T`:017:b80ARLM04L]8`1G?380JTe107mND01mGU80NE]@07EI
CP1`ED`0Je5906M?B01TCDL0I4i906I@B`1YE4l0JeYD06aMF@1[Ge`0JEiM06AKFP1NEUH0F59C05=@
DP1BDeH0EEYM05QQIP1NJFh0HW1f06IeO01[Nh<0KX690725SP1dRi@0MhnJ07ZDW`1mVZH0PIn/08JV
/`2;[;T0Sk6o09Zmb`2SbML0Z=7P0:C9eP2Q`L`0W;W309Ra^@2CZ;00SZ2V08VGW@23Si<0OHJ:07Qn
P1P0oooo0400P7Mf07I]J`1]HV40I5QF05Y=B`1A@d00B3Pf03l^:`0g9240<1/G02TB3P0S2`L080h;
02PG500d8al0A38/04Dd;P13<Rh0@C4]03h_;00i:bT0=2PW02lU9@0]92D0;2DW02lX:P0b;Rl0=C4c
03Hd=`0f=c/0=3Lk034e>P0]<SP0:C8g02Pd>P0Y>3l0:ce602i2C00`Ae40<DYE03A?FP0gDel0>EMS
03eLJ011H6d0AFEc04UZN01>Kgd0DgF305QjR01MOX`0IhNF07:CX@1kWZ/0OYbX082JY022V:00Q9FM
08FCV@26T9D0QhfA08R:S@28QhT0RHB46@3oool0802gVXH0[i1l0:J6L@2MO6H0U79L08]XD021GD@0
Me4h06e6;01T>b40Fc4E05<Z3`1=9P`0Ab8804@Q201690/0BRP>04`Z401=:a80CB`C04/Z4@189`h0
A2<:040P1`0n7`L0?R09044R30139@l0ARPB04T^601<<ah0CSHR0P1>>2@07P1=>2<0C3PS04Xg8`19
=R<0Ac@R04Dc8@15<R00AC<P04Hc8@18=B80BcLU04hj9`1@>bP0DcdZ05Ho;01H@2d0FT0]05i1;@1U
Ac80KU4l07IIA@1nHDd0QVUE08eaG@2EN6D0W81/0:>7L`2ZSW/0/YF20;VLRB@0oooo000R0?ooo`10
06Q_L01ZKFh0Jfa[06i[J@1`JVL0LfYU07MZI01lJf@0PVeT08Q_I@2>LFD0TgAX09YkK@2]Rg`0`9V9
0<nVU039Xi<0a9n@0;nLSP2jUhX0]9>70;6AQ@2aTHH0/i>80;ZHS030WI40`Z6E0;nQU`2mXiX0^J:J
0;2ITP2ZTh`0Y8f70:2;QP2PSXT0Xi>@0:NJV02]XZ00/:NU0;F]Z`2j/k80_kVh0<6m_033`L40`l?4
0<;5b033bL`0aLc@0<O@e@38e=T0b]SM0=3PiP3Dj^l0d^gd0<WQi`30e]/0]/[@0:foa02S];P0VJV]
08nMX@25TYH0NhN:075kOQT0oooo0400K6e^06IUI@1PGE`0FeEC05E=BP1@AD80Bchj04Pg<P15<B/0
A2`T04<X7P139ah0@b/S05Ln=01_DDD0QV=D089RE01mGU80N5]A079FC@1[DDX0ITi7069<A`1QCDP0
I51;06]FD01`G5L0KeiJ06iQGP1]I680IUiM05iHF01GDU<0DU1B055CE@1CF5`0EUmU05aXKP1OKW@0
Hg=k06QiP@1]P8P0L8F>07J<U@1hT9X0NYBO07fIY@21Wj`0QZFc08^[^02?/;h0W;k;0:S<f@2/eN<0
Z<cH0:C4c`2O^lD0Vk>k09FZ/@2@XJP0RYVN08B@U01nQhX0N7j0603oool0@01oMWD0MFaZ06]QG`1Q
EU@0Ed]904e0?P13=380>BTW030O700Y5A808Pd901d91P0H2PP08QLD03DV8P18=S00AcHa04De<012
<c00?S0^03T]:`0d:RT0;bLX02/V:00[9RT0;bX/03<`<P0e<SD0=SHi03Pj?P0e>Ch0<CLl02`c>@0X
<SP09S<j02Hg?`0W>dD0:d5;02a5D00^B5@0<4aH039@G@0eE640>eYW03mOK@12Hg80AVQg04Y]O01@
Lh80E7R705YmS01WRIP0M9JU07bP[`1oWZX0PI^V08>IXP24UYh0QYBJ08NAUP27SY80R8^=08R8R@29
QHDI0?ooo`100;NIQP2^T7/0YHIa09alIP2CLE/0RFI?07iJ@`1cCSH0J48Y05hf701E;140CBD;04@P
200o7PL0@B4904DU3@18:100BRXB04`/501<;AD0C2dF04X/5@17:A<0@RHA03`R3@0k8P`0?R@>044V
4@149a80B2dH04/d801=>2@0CCTV04`i9P1;>2D0BCLT04Le8P15<b40A3<Q04<a8011;ah0?bdL040^
7@13<Al0AS@R04Tf901;>2H0CCXX050l:P1C?R`0ET0^05a3<P1SBCL0Je0n07=IAP1kH4d0PfQE08]`
G@2CN6D0Vgm/0::7M02ZSW/0/IF20;RLRB@0oooo000R0?ooo`1006Q^L01YKFd0JV]Z06aYI`1^J6D0
LFMS07AWH@1iJ640P6]R08U_I02ALVD0UGIZ09MjK@2[RGX0`IZ90=>YUP3=YI<0aj2@0<:MSP2lV8X0
]Y>60:n>P@2[Rh00YhYo0:j?Q02gUXX0_I^@0;fKT@2iW9<0]YfE0;2HT@2ZTX/0Y8b50:2:Q02OSHL0
XY>>0:JIUP2_Y:40/JRU0;N^[02n]K<0a;bj0<Fo_P38`l80alK60<K8b@35b/`0algA0<[Ae@3<eMT0
cm[N0=SSi`3Kjo00f>od0<kSj@35f=d0^lgB0;31aP2V][X0W:Z^096NXP26TiH0O8N:075lOaT0oooo
0400Jfa]06ETI01NFeX0F5=A059:B01<@Ch0ASTe044b;@0n:bD0?RLP040U7011:200@BdU05U0=P1d
E4P0S6QH08IUE`20H5D0NeeB07AHC`1]Dd`0ITi806==B01MBdL0HTm;06aGD@1aGUT0Lf1K079TH@1_
IV@0If1O05mIF@1GDU<0DDmA04mAE01@Ee/0DU]R05]XKP1LJg80Gg1i06EgO`1]P8P0LHJ>07N<U@1i
TI/0NiFP07bIY@21Wj`0QZFb08VZ^02@/Kl0X<3=0:g>f`2af>D0[<oJ0:S6d@2S_/L0W[Fm09R//`2B
XjT0S9ZO08FAU@1oQh/0N7j1603oool0@01oMWD0M6]Z06YPGP1OE5<0E4Q704Tl>`0n<2l0<b@R02PH
5P0P3``070P501T91`0H3@/09a`I03X[9`1=>S@0BSXd04Lg<`13=C80?c<a03/`;`0g;Bh0=Rd_034/
;P0b;Bl0>38d03/h>P0m>cd0?d1303e2AP0g?D80<CTo02/d>P0W<CT0938j02@e?`0S=d809cm:02I1
C@0V@e00:4MD02i=F`0bDf40>EUW03aMK010HW40@fMf04Q/O01=LH40D7F605IkS01URIT0M9RW07fS
/@1oX:`0PYfX08BJY025V:00QiFK08RBU`28Si<0RHb>08V8RP29QHDI0?ooo`100;NIQP2^T7/0YHIa
09akIP2BLE/0QfE?07aI@P1`Bc<0HcdT05L`5P1>9Pd0B2<904HT301590h0A2@>04HW4018:Q@0BB`E
04X]5`1;;QT0C30L04hc7`1@=B40Cc@P04/b7@18<A`0Ac4N04Td8@1=>2D0CSXW04di9P1=>RP0C3/Y
04`j:01:>BL0B3HU04Db8P12<1l0?blN03/[6P0h:1P0>2TI03//6`0n;Qd0@C0O04Dc8P18=RD0BSPW
04`i:@1=>RX0Cc`/05E2<P1NBSX0Ie50071HAP1hH4h0PFQE08U_G@2BMfD0VWm/0:66M02YSW/0/IF2
0;RLRB@0oooo000R0?ooo`1006M^L01XK6`0JFUY06YWIP1[IF80KFAP071SG@1eI5d0OFMN08U^H`2K
Nfd0W7a^09enL@2]Rg`0a9^90=N[U`3@Yi@0bZ:A0<BNSP2oVX/0^IF80;:>P@2]Rgl0YHMl0:B7O02Y
Rh00/9:80;JFS02fVHl0]9ZA0:nGS`2ZTXX0Y8b509n9P`2MRXD0WXn:09nBS`2WWIX0[::O0;>YY`2o
];00`kZg0<No_@3<a/<0blS70<W:bP36b/`0b<g@0<_Ae03=eMT0e=_O0=oWjP3Ul?<0go;f0=CWj`3:
fml0_m3C0;C4a`2Y^;/0WZb_09>PX`28U9L0OHR;079lOaT0oooo0400Jfa]06=SH`1LFET0EE1?04i7
A@17?C/0@3@a03X[9`0e91h0=1hH044W7`13;2@0AS4Y05Y2>@1gEdX0TFaL08YXFP24HeL0OEmD07MK
DP1aEdl0JU9;06I@BP1PCDP0I55<06YGD@1`GUT0M69M07=UH@1^IF80If1O05iIF@1GDU<0D4mA04e@
D`1>EEX0CeYP05IUK01FIfl0F6ae06EgO`1/P8P0L8F=07R=UP1kTI/0OIJQ07fJYP20WZ/0Q:>a08NX
]P2@/Kl0Y<;?0;?BgP2ff^H0/=7M0:c9d`2W`<T0XKNo09^^]@2DYJ/0SY^P08NBUP20R8/0NGn1603o
ool0@01nMWD0LfYY06QNG@1MDe40DDI504Dj>00i;2/0:ahM01h@3`0A0P4050@201D92@0H40l0:1hL
03d^:P1@?SP0CC`g04Tj=P15=cD0@CDd03dc<`0j<S80>C4c03La<`0m=cP0@S`l04A0@@15@d@0@TA7
03e3A`0g?d@0<CTo02/d>P0V<ST093<l02@g@00T>TH09d9>0290CP0O@4l0:4MF02e>G@0_DF00=eQW
03]MK010HW40@VMg04I[O019Kh00Bg>4059jS01TRYX0MIVX07jS/@20XJd0PijY08FLY@27VJ40R9JM
08VCV029T9@0RHb?08V9RP29QHDI0?ooo`0Q0;NIQ@2^T7/0YHIa09]lI`2ALE/0QfE?07]I@P1]BS80
GCPP04/S2@116P00@Al7048S30139A00A2LB04DY5017:aH0BBdH04X^6P1:;a/0C38N04hf901A>BL0
ECd[05Y3<01JA340Ed8^05A1;P1A@2h0Ccd/04hl:P1=>bX0C3/Z0080C3/[00d0Bc/[04Xl;017>R/0
@3<V03T/7`0g:Q`0>B/M03LZ6`0i:Q`0?RhN048a8@16=BH0B3PX0080B3PY00h0BCX[04hn;`1HASL0
Hdln06aFA@1fGTd0OfME08Q_G@2@MfD0VGm]0:66M02YSW/0/9F20;RLRB@0oooo000R0?ooo`1006M]
K`1WJf/0IfMW06MUH`1XHUl0JF1L06]NF01^GEH0MEmG08=XG@2IN6X0YH9d0:R5MP2eT7l0aif;0=V/
V03BZ9D0c:>B0<JNS@31W8`0_9R:0;JBQ02`S7l0ZhUl0:^9O@2/S800/9240;BER@2eUhd0/iN>0:nE
S@2YT8T0Xh^409n9PP2LRH<0W8b809j@SP2OUiD0WiVH0:6MW@2bZjP0^;>a0;bh]P35`;h0a/?20<K6
aP35b<X0alc>0<[?dP3=e=L0f=kP0>CYj`3/mOL0ioOk0=_[kP3@gn80a=;E0;S6b@2]^K`0XJf`09FQ
Y029U9L0OXR;079lOaT0oooo0400JV]/069RHP1JF5L0DTi=04Y4@P12>CL0>Bl/034T800W61@0;1TC
03hX8016<BP0BcL_0658?@1lFdd0UFmO08iZG027IUX0Of1E07UNE01dFe<0KUI?06UBC01VDD`0Ie=>
06]HDP1_GEP0LV9N075TH@1/Hf40IUmO05iHF@1FDU<0D4mA04e@D`1=EEX0CeYQ059RJP1BI6d0DVMa
06AfOP1YOXH0KX><07V=U@1kTY/0OIJQ07bIYP1nWJ/0PJ6_08>U]@2B//00YlC@0;WEh02kgNT0]]GO
0;7<eP2[`l`0YK[109j`]`2GYj`0T9fQ08RCU`21RH`0NGn1603oool0@01nMWD0LVYY06MNG@1KDU40
CdE4048g=P0d:BP09ATI01461P0;00004PL6018;2`0G4A80:R4O044b;@1E@S`0D40k04`m>P16>3L0
@SLf03lf=`0l=CH0>SDf03Xe>00l>3X0@3dn04=1A014ADL0@DE903a3B00g?dD0<3Y002Xd?00V<c/0
8c@m02@h@P0V?4P0:49>02Q3D00WAE<0<DiK03=BH00fEV@0?Ue[045QL013IWH0@VQi04=[O015KX00
AG23055jS01URYX0MiVX07nS/P22XZl0QJ2[08NNY`29Vj<0RYRN08ZEVP2:TID0RXf@08Z9R`2:QHHI
0?ooo`0B0;NJQP2^TGd0YHMc09amJ@2BLUd0QfMA07]JA01]Bc@0FCDL04/W3P107`P0>AX403XN2@10
90l0ABTD04P/5`19;AT0BBlL0P1:;ad05P1;<R40CCLV050k:`1C?c00ED8b05I4=01FACH0E4@d0592
<`1?@340CSh^04dm;@1<?2d0C3d^04`n;`1<?c00CD0`04do<01=?Rl0Bc`^04Li:`14=RP204@e9`0D
04Hg:@17>2/0AcPZ04Hh:P15>2X0A3HX04Dg:P1<?Bl0ED8c05i:>P1YE4@0Lee=07eVE@26Keh0SgMV
09QoK@2PQgD0Z8il0;2EP`2hW8TT0?ooo`008P3oool0@01VK6h0IFUZ06EUI@1THV00I5mL06AKE`1T
F5<0IEA>06A?A`1gGUD0RV]P09ajK@2WQ7D0^9600<RNR`3J[IP0e:VF0<jTTP37WHd0`IV90;fGR02j
UHL0]Y630;>>P02bSGl0/hn20;FBQ@2gUHT0]iR<0;>ER`2^ThX0ZHn70:>;P`2NRH80W8R209b=Q`2N
THd0XIJD09nHU`2KV9P0XYnO0:ZXZ02a/:l0^[Rg0;nn_@32`l<0a<K70<G:c038c]00bm7D0=[Nh03W
j^/0l?Gf0>gko@3Rko40e^;T0<WEe`2lb</0/;^n0:>^/@2GXZ@0RiFH07n9R`1cO7lI0?ooo`1006U[
K01QHF40F5IF04m<B`16@Cl0?CHd03<Z9`0X7AX06`h:02TI500g91h0AS8Z054l<`1YCD40PEmA09Qa
H@2BKEl0RVUM089SF@1kH5H0MUaD075JDP1/EU00JUA?06YFD01]FU@0L5iH075RG@1aI640Jf9P06EN
G@1MF5P0EU9C04m@DP1<D5<0C5AI04mJH@1BHFT0DVA]05=XLP1OLW/0IWZ306b2R`1fRi@0N92J07VD
X01jUj@0NY^Y07fO[@1oXk80U;C10:_6d@2me^00`N;]0;cIh`2fd=T0/<O>0:Vma02R/kT0VZV^09:N
X`2:U9P0PXZ=07YoPQP0oooo0400OGIe079ZJ@1VGE`0FE1@04e3@`0o=SD0<BLW024G5`0?1@D04@P8
01D=300J51@081XJ03@X9@17=c80F4Do05=3?P1?@Cd0BShl04Hm?011>CX0?CLh03Xe>00h=ST0>CPk
03dm@00o@4<0@4=603m5BP0k@dT0=Sm6030i@00Z=Cd09C@m02<d?P0S=d<093a802M1CP0YAE80;TYH
03QCH00kEf@0?U]Y04=QK`13I7<0@FIf041WN@10JW`0@6ao045^PP1BO8h0J8bL07VKZ@21Y[D0Q:Ba
08NS[@29X:T0RifU08bJX02<UY/0S9:F08^>T@2;RX/0RXJ66@3oool06`2gVhP0[Y9n0:J8M02LOfX0
TgAP08QZE@1mGTP0LE4k06=3;01G>240CC4K04DZ5P12:1@0AB/F04T]6P19;Q/0BS0M04Xb7`1<=R@0
CCPX04/f9@1:=BD0BcPX04`k;@1>?c40Cd4c0512=00204m1=00S04m2=01>@340CCd_04`m;P1<?S00
C3hb04/n<P1;?S40Bcla04i1<`1DASP0F4Tj05A5=`1B@S@0Cd4c04`n<@18>bl0ASX^04Di;@13=b/0
@SL[04Di;@1<?S40E4<e05a:>`1VDd@0LEa=07]VEP25Keh0SgMW09QoKP2PQgD0Z8il0;2EP`2hW8X0
903oool00280oooo0400IFa^06AXJ01SHf<0HUmN061KF01OEU<0GU9=05a<AP1HACh0K5E<085UFP2C
LfH0Xh1b0;N?OP3:WX/0fjbG0=R[U`3@YY<0bZ2?0<:IR@2jTh<0]Xn10;:=O`2`RW`0[8Mi0:b8N`2^
Rgd0/Hj20;:BQP2aTXP0[I670:V>Q@2TRh<0WhV109^7P@2KRh@0Wi:<0:>HT`2TVYP0Y9jL0:NQX02Y
YZD0[jb/0;Rd/`2l^[X0`<300<;4a035b<T0a/c>0<_Ad`3Lg]l0jn_Z0?3bl`3coOh0jO?d0=cVi`3>
f=X0`<[<0;>m_`2V/;80VJ>U08bFV01oRH`0Lgeo6@3oool0@01YJV/0H61P05IEE@1=BTT0@chm03Tb
<@0^9R@08QPE01@91P0R5Q40<b<M04@a:@1F?SH0KU1508ERE02JLf80UG5R08e/H026J5d0OV9I07QN
EP1cFe@0KUUC06iIDP1/F580KUaF06mNF@1aHEd0L6AP06YPGP1SFe/0G5IG05ECE01?DE<0C4mD04YC
E`1=FV00DV5X05AUKP1HJg@0GW5k069hP@1YP8X0L8RB07><U`1eTIh0MYFR07NIY`1gW:/0OJ:b09Je
`P2bbM<0_MGO0<KTkP32gNH0_MCL0;K:d@2^`<H0YKFk09f[[`2DX:@0S9FI08>:S@1kP88H0?ooo`10
07eeM01aJFP0IEeL05Q@C`1;@d80?SDe02lW9`0P5aL03`L7018;2`0G4A407aTH02XR800k;b/0Bc`g
05Y8@P1FAT80DDA204e3@@19@D00AT1104<o@@10?T40@T1304=2A015ADP0ADM:04A8C012BDd0>dA:
03DnA@0_>D40:CHn02De?`0S=4008CI2024jA`0U@4h09dAB02a9E`0bD5h0=eIT03]KJP0nH6l0?F5b
03eSMP0lIGP0?6Mk03]YO@0oKH80Dgj@06f@X01jVjX0PjRf08NW/`2;YK00SJ>/08jPY`2>W:80SYRM
08jDV02=Si80S8^<08Z6QQT0oooo0400]i^80:nBO`2VRWH0WX1/09AgH`2;KET0PF=>07IH@`1[CST0
H4<^05Dk9`1?=R80C3<O04/c7`1:<b00BS8O04Ta7`1;=2<0C3PW04ll;@1A@C<0DT<f05=4>01FBCd0
FTi205Y@A@1ICd@0Edi305A:?`1@ACT0CD4d04`n<@1;?C40Bclc04a0=@1:?S@0B3`b04Pl<@1:?S80
CD4d0513=`1AACT0D4Di04e2=`19?S@0AS/b04Di<013>2h0@CH/040f;014>S00CT8f05A6>P1IBC/0
He5206mLC@1jIUL0QG1P08mhJ02HP6l0X8Qf0:R?O@2`UX@0^9f:903oool00280oooo0400IF]]06=V
I`1QHF40GeeK05aGE@1JDTh0Eda705A6@01??SL0H4a407EMD`2:K600WWa^0;B=O039WHX0fZ^F0=Z/
V03DZ9H0cJ>B0<JMS@2oUXH0^9210;:;O@2`R7X0[HIg0:b6N02/QgT0[hYm0;2?PP2`T8D0[Hn50:Z=
Q@2URh<0X8V209^6P@2FQH00V8Z509nDSP2VViL0Zj:M0:fUXP2^ZJH0/Zj/0;Nd/P2k^KP0_[jn0<72
`P31a/H0`lW:0<_Ad`3Mg]h0l>c[0?Cdl`3iool0m_cl0>?Zj`3Cfm`0a<c=0;Jn`02X/K80VZ>U08fF
V020RH`0Lgeo6@3oool0@01XJV/0GUmO05ECD`1:B4P0@3`k03D`;P0Z8b407ADC0106100M4Ph0;b4L
048`:@1G?cH0Ke9608MTEP2JLf<0V7AU095`I02:K640PfMN07aSFP1fGeP0LUeG079MEP1_G5D0KeeG
06iMF01_Ge/0K61L06QMG01QFEP0G5EF05ICE@1@DUD0CE5F04UBE`1:Eed0CemV05=TK@1JK7@0GW9k
065hP@1VOXP0JhB?06j9U@1aSY/0Li>P07>FY01bV:P0OZ>b09Vg``2eb]@0_MCN0<OSk@3=iNd0a=[Q
0;c>e@2c`lT0ZKRm0:2]/@2GXJD0SYJJ08B;SP1kP88H0?ooo`1007eeM01aJFP0I5aL05Q@C`1;@d80
?CDe02lW9`0P61T04@T:01@>3`0L5QH09AhM030V9@0o<c00Cclk05]9@`1HBDD0E4Q504m6A@1;A4D0
B4A504I4AP16ATP0AdM:04I8B`16BDd0ADY>04=9C@0nAT/0>458038l@`0]>400:3Lo02Hf@00T=d<0
8cY602<mB`0S@4l08d9A02U7E`0^CEd0<E9R03AGI`0gFf`0>5i`03UQM00iI7L0>FEj03IVO010Kh@0
Eh2C06f@X01fVJP0OjBc08^Z]P2?Z[@0TJN_09:SZP2BWjD0TIZO092FV@2>TI<0SHb=08^6QaT0oooo
02H0^9^80;2CP02XRgL0Wh=_09MjI`2>LEh0QFQE07aPC01cF4@0JTll0657=01J@Bh0E3`Y054i9P1>
=bD0Bc@R04Tc8P1:=B@0C3PX04dl;P1@@C@0DdPl05M>@`1JDTL0FeE<05]FCP1JETh0Ee99059;@01>
A3T0Bd0d04Tn<@19?S80Bd0d04e4>01@Acd0CdHm04To>080AC/b01P0B3hd04U0=@1:@3D0B3he04Hl
<`14>S40@cXa048h<00o=Rh0@CL_04Lm=01:@3H0CT8g0593=P1MC3h0KUa>07YWF@25LF80SgYZ09R2
L@2QRGP0ZI1n0;6FQ02hWHXT0?ooo`008P3oool0@01TJf`0HFEV05iOG`1LFUT0FEAB05E>B`1BAd<0
CT0k04Th<P1HACd0K5E;085VFP2FMVP0[hUh0<JKR03HZI@0fjfI0=N[V03AYYD0bZ6A0<BLS02nUhL0
^Y:30;J?O`2dS7d0/ham0;:<O@2bSGl0/Xj10;6@Q02^ShD0Zhj40:N=Q02SS8@0WXZ309V8PP2DQh<0
U8^609RAS@2SViL0[:BQ0;:[Y`2e[j`0^;Bb0;^h]`2m_;`0_Kno0;k2``2naLH0c=3A0=gNg@3`jnP0
nOCb0?WknP3jo_`0j>g/0=OMg@37c/h0^;o00:Va/P2KY:D0SYNH086:S01dOGlI0?ooo`1006QYJ`1M
GUl0De9B04Q7AP0n>SX0<Rh]02HP7`0J4a4030D201T@3@0[7aX0@2lX05Do=P1_DTH0QVAF09UbH`2J
MVL0U7AW08e_I@26K680P6MO07]TG@1gHE/0M5mI075NF01`GUP0KUeG06aMF01YG5P0IE]I061GE`1K
EEH0EUAF059CE`1?DeP0BeAJ04UFG@1;G6<0CV5Z05IYLP1KLGX0HGN006AmQ`1XPXd0K8ND06n=VP1`
T9h0KY>R06fFYP20YK@0V[O40;;8dP30e]l0b^?/0=S/l`3=gnD0`]?H0;S6c02]^[l0Xjnc09VSYP2?
UiX0QHb>07b0PQP0oooo0400OGEd075YJ01TG5`0F51@04]3@`0m=SH0;bPY024J6`0B30d05a4C01lI
6P0Y8B40=B/Y04@f<`1A@Cd0G4Y505Y<B01FBTP0DDQ804e7A`1:ATL0AdE804E6B@14ATT0@dE90455
BP0oA4T0?D=803U0AP0d?D@0;cU102/g?`0X=Sl09CI102DhA00T>TP09Ci<02Q4DP0YAeD0:dYI02Y<
G00/Cf00;UAV039HJP0dG6l0=f5e03QSN00eI7T0<fIl04=bQ`1GPYD0JHjO07JJZP24Z;H0U[Bo09J_
^@2GZk<0UZN^09FRZ02DWJ40TYNK092BU02>S8h0RhN76@3oool07`2hW8T0/IF10:V=NP2QQW<0VGi[
095fH`29KU/0PFID07UOC@1aFDL0JU9006=;>@1MAC@0F40_058k:P1>=bH0BcDU04Xe9P1:=bP0C3X/
04dn<@1?@cL0DDLm05=;@@1CC4<0Dde5059<A01@BD40CDDl04Y1=P18?C800P17?3002019?S<0Bd4g
04m5?01BBT80EDa405=9@@1<@c/0ACde1013>c<04`14?3@0A3`e048j<`10>S80@c`d04Lo=`17@3P0
Bd<j05I;@01SEDP0L61B07aZG027LfD0TGa]09V4L`2RRWX0ZY600;6GQ@2hWH/0903oool00280oooo
0400HfY/061TI@1LGUh0FEMF05EAC`1ABTL0CD<o04Pl=`12<bh0DD0i06=>A@1jH5D0T75T0:V4M031
Uh@0eZNB0=f^V@3J[YX0e:ZH0<jVU@39XI40a9f=0<2IRP2lUHH0^Y:30;RAPP2gT840]Y620;FAP`2c
TH@0/9650:f@Q@2ZShH0Yhn70:>>Q`2NSHL0VXb709R=R@2GSh`0VI>A09jIU`2VXIl0ZjRV0;2^[02c
/[40^;Rg0;Zl_02l_kl0_<;30<[>cP3Kf]X0j^GS0?OakP3lnOL0o_kk0>c^k@3Jg]d0bLk>0;[0`02[
/K80W:BU08jGV021RX`0M7eo6@3oool0@01WJFX0GEeN059ADP17ADD0>cTh030/:`0T7ah05a4@00X3
0P0H3``09a`H03h]9P1C?SD0K51508ARE@2GLF80VgMY09MfJP2@LVP0RVmV08A[H`1nJ640NVEN07IR
G01cH5X0L5iI06eLE`1[FeL0IeYF06AHEP1OEeH0FeAE05MDEP1DEEP0D5EJ04iFG01;F5l0C5aS04eP
J01AIVl0Efeg05edOP1QNhH0IX6<06R6T`1/RYT0JXjL06ZAX01/UJD0PZJd09Vg``2`am40a=OP0=;V
k@3Pl?H0e>?Y0<SGg02mb/h0/Kg10:J`]02LY:P0TIRK08J<S`1lPH<H0?ooo`1007eeM01aJFP0I5eL
05Q@D01;A4@0?SLg030Y:P0R71d05@l@01/E5P0Q6a`0;2@T03P];015>3H0DD8n05Y:A@1JCDT0Eda:
059:B@1>B4T0BTM904M6B014ADP0@TA703m3A`0m@TH0>T1403Ln@`0d?480<3U002`g?`0X=3h09SDo
02@f@@0S=d@08cY702<mB`0U@E00:4IE02a<F`0`DF00<UAU03=GJ@0fFfd0=Umb03MQMP0cHWL0<VAi
03AWOP16MXX0FHBG06^BXP1mXJl0SJnk09jja02N]Kh0WK2h09b[/@2JYJX0UinT09FIW@2BTiD0Shf>
08b7QaT0oooo0400^If90;:FP`2ZSg`0XhQe09b1K`2DNVP0SG=Q08I/FP1oIUD0NF5?079JB@1ZDd80
I4dl05e6=P1F@300CSTY04Te9@18=2D0BCHW04Xh:P1:>bh0Bcda04a0=@1=@SP0CD@k04a4>`1;@cX0
BD4h04Ln=@15?380A3T_04<h;P14>Bh0ACX`04Ll<`1:@3L0CD@k0518?`1CBd80EDa405A<A01@B400
CDDm04a4?@1;A3d0Ad4j04<n=`11?CH0@Shg04I1>P1:ACd0CDU0055=A@1KDdT0Ie]?07=TE`1oKV00
RGMY09=oL02KQWH0Xhal0:^BP@2bV8H0^Ij;903oool00280oooo0400HfY[05mSI01JG5`0EUED059>
C01=Ad@0B3ll04<h<`0m<2X0CCdf05e:@@1cFTl0RVaO0:>0L02kTh00dZB?0=f^V@3M/9`0f:fK0=:Y
V03=YYD0bJ:B0<FNSP32Vh`0_iR90;fFQ`2kUHD0^YB50;RDQP2fU8H0]9>70;6CQ`2^ThT0Zi:90:NB
RP2TTH/0X96<09jBS@2LThl0WIJC09nJU`2RWY/0YZ>R0:bYZ02`[jl0];Bd0;Jh^@2h_;d0_<730<W<
c03GemH0i>7O0?;]jP3lmo@0oogk0?3ak`3Lgmd0blk>0;Zo_`2[/K80WJ>U08nFV021RH/0M7eo6@3o
ool0@01WJFX0G5eN055AD@15A4@0>SPh02h[:P0R7Qd05A0?00P20@0F3P`09A/G03XZ9@1A>c<0J4i4
07mODP2BKV00W7MY09YiK02CMF/0S79Y08I^I`21Jf@0O6MQ07MTGP1dHE/0L5mI06eLE`1ZFeH0IUUE
06=GE@1OEUD0FeAE05QEE`1EEUT0DUMK04mHGP1=FV40CEeU04iQJP1AIW00EFaf05UbO01NN8@0HWj;
06B3T@1VQiD0IX^I06N>WP1^UZH0Q:Ne09^ha02`b=40a]SP0=SXk@3Ul_L0g>W]0<oKg`32cM00]Ko3
0:Vb]@2NYJP0TYVL08N=S`1mPH<H0?ooo`1007eeM@1aJFT0IEeM05QAD@1;ADD0?SPh034[;00T7Ql0
5Q0B01`F5`0S7Ah0;RHV03T_;P15>CH0Cd8n05M9A@1JCDX0F4e<05=;B`1>BD/0BTQ:04I6B@12A4L0
?d9603a0A00i?T<0=S]103<j@00_=ch0;3Dm02Pc?00U<S`08c<n028d@00Q=T<08CQ6024kBP0S?dh0
9DAD02U9FP0]Cel0<5=U03=HJP0dFfh0<eeb039OM00`HGH0;f=i03IZP01:NHh0GhVK076GY`25YK<0
U[>n0:Fma`2V^l<0Y;Jm0:6_]@2NZJh0Vj:V09NLWP2DUIL0T8j?08f8R1T0oooo0400^If:0;>GQ02/
TGl0YH]i09n5L`2HOV`0TGQW08YbH@24K5X0OFID07MQD01aFd/0JE=3065;>`1H@c<0CcX/04Te9P17
<bD0Ac@V04Lf:@17=b/0AcT^04Lj;`17>c00Ac`b04Hl<P15>c40@cT`044g;@10=B/0?c<Z03lc:@0o
=2X0@3H/048h;`14>S40Ache04Y1>@1=A3d0CdQ0055:@`1BBd@0D4Y404e8@P1:A3l0AT8l04=0>P12
?SP0A44k04Y7@@1@C4H0EU5:05]FCP1RFU00JeiC07IWF`23LfH0SGa^09J3M02NRGX0YHmo0:bDP`2c
VHP0^Ij<903oool00280oooo0400HVU[05eRH`1IFe/0E5=B04m<BP19A440A3`h03hd;`0i:bH0B3Pb
05Q5?@1/EDX0PfII09ejJP2eSG/0c9n;0=b]U`3P/Yh0fk2M0=F/V`3AZIT0cJJF0<VRTP36Whl0a9f=
0<6KR`2oVHT0_YR80;bGR02jUXT0]iJ90;FFRP2bUX/0/9J=0:bFS@2YUXh0YYF?0:BFT02SV9<0XYZF
0:BLV@2VX9d0Z:BR0:bYY`2`[Zd0/k:b0;Bf]P2f^KX0_/710<[;b`3FeM<0h]oL0>kYiP3ilnl0oOSe
0?7`kP3LgM`0b/g<0;Zn_P2[/;00W:>T08jFU`21RH/0M7eo6@3oool0@01WJFX0FeeM051@D@14A4@0
>3Lg02`Z:P0P7A`04`l>00H1000D3P`08aXF03LX8`1<>340HdY107UKC`2=Jed0VWIX09akKP2FN6d0
SWA[08QaJ@22KFH0OFUR07QUG`1dHUd0LEmI06eLE`1YFUH0IUQD069GE@1NEE@0FeEF05QFF01FEeX0
DeQM055JG`1?G680CemV051SJ`1BIg40E6af05MaO01JMX80GG^805n0SP1QQ9<0HHRG06B=W@1aV:P0
R:Vg09fia@2bbM80b=WP0=gYkP3ZloL0iNob0=CNh@36cm80^<740:^c]P2OYZT0U9ZL08R=S`1mPH<H
0?ooo`1007efM@1aJVT0IEiN05UBDP1<ATH0?cTj038];P0U824061<D01hJ6`0U8240;bPX03P`;`13
>CL0C44n05E8A@1ICDX0FDm=05A<C@1>BT`0BDQ:04E5B@10@TH0?41403Tm@P0e>Sl0<SPm02hf?00[
<c/09c8j02@`>@0Q<3/0834m01lb?`0N=4807SM501hjB@0O?Td08T9C02E7F00XC5d0:U1R02aDI`0/
Ef/0;5Y_02aMLP0[GgD0;F=j03Y^Q01?OY80HhfO07NLZ`2;Z[L0WkW30:k3c02aa</0[;c20:Nd^@2S
[;40WZFX09ZNX02FUYP0THn@08f8R1T0oooo0400^Yj;0;BHQP2^Th40Z8il0:68M`2KPW40UGe/08mg
I`28LV80PVeN07eXF@1fHE<0KEY;06=A@`1JAcT0DCha04Tf:@16<bD0AS<V04Dd9`14=2P0A3@Y04<e
:P12=BX0@C@Z040d:P0n<bT0?C8X03/`9`0j;bD0>BhT03T^9@0j;bH0>c0W03`b:P0n=Bd0@CPa04<l
=016?cP0BD8l04Y4?P1:ACl0BTE004Q4?`15@ch0@d8l0451?011@Cd0ADE104i=B01EDdh0G5UC06=N
E`1[I5`0LfUO07iaIP29NVh0TX9e09Z8NP2QSGh0Yi:20:jFQP2dVhT0^Yn=903oool00280oooo0400
HFUZ05aQHP1GFET0DE5A04a9B016@Cl0@3Te03X`;00c9b80@cD^05=1>@1VCdD0NemC09=bI02/QW@0
a9R40=FWT@3P/I`0gK:N0=R_W@3D[9/0d:ZJ0<fWU`3:Xi<0b:6A0<JNSP34WHd0`Y^<0<2JR`2nVX/0
_9V;0;VIS@2gVXh0]9Z?0;:JT02_VY40[9ZB0:VJT`2XW9H0Z9jI0:ROV`2YXYl0ZZJS0:bYY`2^[J`0
/;2`0;6d]02d^;T0_;o00<S8b03Cd]40g]_H0>WTh@3ck>P0mo;^0>k/j@3Jf]P0b<[90;Vl_02Z[Zl0
W:6R08jEUP21R8X0M7ao6@3oool0@01VJFX0FeaM04m@D@13@d@0=cHg02/Y:@0N71`04Ph>00@1000C
3@`08QTF03@V8@17=Bh0GDHm07=GC028IeX0UW=U09ekKP2GNVl0T7I]08UbJP23KfP0OV]T07UVH@1e
Heh0LEmJ06eLF01YFUH0IEQD065FE01NEED0FeEF05UFF@1GF5/0E5UN059KH@1AGF@0D61X055TK01B
J740E6af05I`O01GMH40FGV605anS01MPY40GXJF06F>WP1gW:/0S:bi0:6la`2gc=@0cMcR0>7[kP3^
mOP0j_;e0=SPh`39d=<0^/;40:fd]`2QYjT0UIZL08V>T01mPH<H0?ooo`1007efM@1bJVX0IUmO05YC
D`1=AdL0@C/l03@^<00W8R<06QDG024L7P0X8b@0<2XZ03Ta<@13>ST0C49005E9A`1ICD/0FU1?05A=
CP1>BT`0B4M:04=4B00n@DD0>Si303Dk@00b=cd0;SDk02Xb>P0V<3P08bhg020]=`0N;CT07Blk01`a
?P0K<d406cE401/hB00L?4d07d5B0255E`0SBE`09DeQ02IAI@0WE6T0:EQ^02UKL@0ZGWD0<FIm04=d
RP1GQ9L0Ji>T082S/@2F/[h0Zl7:0;W<e02lcM<0]<;70:fh_@2W/;@0XZNZ09fOXP2HV9T0Ti2A08j9
RAT0oooo02X0^Yn<0;FJR02_UH<0ZY1o0:B;NP2OQgH0VH9b09=mK@2>N6T0R7=U089^H01lJE/0M65D
06]HB`1PCd80EdHj04dl<@17=BT0A38V04<a9@11<2@0@2lS03h_900m;bD0>blU03X]900h;2<0=b/R
03DZ8@0d:B00<bPO03<X800d:B40=B/S03H]9P0h<2T0>S</03df<010>C@0@S`g04@o>P14@3`204A1
?@80@d4m0180@T8n04E5@P1>CDT0EEA@05eKEP1VHeh0Kf]U07QbJ`20NG00RGme0964N@2HRG`0WXf0
0:BAP`2ZUHD0/9V80;FLR`2jX8dT0?ooo`008P3oool0@01QJ6X0Ff1Q05EHF01?D4l0BDM604<o?00l
=S<0=RdY030T7`0o<2X0Ccde061:@01dFDh0RfaN0:F0K`2kTWl0cZ6<0=^]V03M/Yh0f[6N0=J^W@3C
[9/0d:ZJ0<jXU`3<YI@0bZ:A0<RPS`36Whl0a9j>0<:MSP30W8h0_Yb@0;bMT@2jWY<0]YjC0;BNU02a
WYH0[YjF0:fOV02/XI/0[::N0:bTX02/Yj<0[JZW0:j/Z`2_/:l0/;:b0;Bg^02m_kl0a/O60=7?cP3J
emD0i>3M0>gWh`3`jnL0i>;O0=GDdP35alD0][Vi0:R/[02JX:00SIBE0828R@1cO7hI0?ooo`1006IY
JP1KG5d0Ce1A04=3A00g=SL0:RTY01dL6`0@3Ph00`00014<2`0Q61D0<2@P048b;01F@SX0KUA9089S
E`2AKf80VWQ[09MjK`2@Mfh0RW=[08A_J01nK6H0NFQR07ESGP1`GeX0K5aH06QJEP1UF5D0HEID05iE
E@1LEUL0FUMJ05QIG@1EFel0E5aR059OIP1AHFT0DVE]059XLP1CK7L0E71k05IdP01GN8H0FGb;05Z1
T01NQYH0JI6Q07bP[P2@[k`0Yko90;g?e`3BgnD0i^ga0?Gin`3[lO<0f^3R0<[@d`2l`/@0[[Bf0::W
Z@2EVY`0RHj@07j1PaP0oooo0400OWIe079[J`1VH600FeAD04m8B@12?Ch0=S0b02TT9P0L61X08QlQ
02XU9`0a:b`0>C8b044i>@1<@T00E4Q705U=B`1JCdh0E4i?04e:C016ATX0@D=703/oA00f>d40<SPn
02hd>`0Y<CT09Rlg028/=@0O:cD072Xf01X[=`0I;CX06Blm01Pa@00H=4@06CM801TkC00K?e407D=F
01m7FP0PBel08TiS02ACJ00UEVd09EYa02YPM`0gJh80BWZ?05n:W@1fVj/0S:^h0::kaP2gb]80bMSN
0<KDf@2kal`0/kc00:bc]P2UZZ`0Wj6S09VIVP2DTI40SXV96@3oool07@2kWhd0]Y^90;6GQP2/Th80
Yhmo0::;N`2MQWL0Uh9c099nL02<NV`0QgEX085_HP1iIe/0KeiB06EDB@1KBSl0Dd4f04Xi;@14<RL0
@30T03h^8P0l;200>RXO03PY7P0f:1h0=2LM038V7@0`91/0;b<J0080;R8J0240;B<K02dT700_9Al0
<2PQ03<Z900e;RP0=c4]03Xe<00l=c<0?CXf03ll>00o?SX0@3ll0450?@10@Ch0@dA204Y;B01CE500
G5eI06MVH@1aKfT0NgQa08F0N@2ARh@0Uhn709V>Q02NT8@0Xi:60:REQ`2]V8T0/Y^;0;JNS02kX8h0
903oool00280oooo0400H6QZ05YOH@1DEeL0CDi>04M5A010?3X0>C<`038Z9P0[8Ad0>RdW04Xi<P1J
AS`0KEA808=UE`2KN6P0]8Yh0<VKQ`3FZ9<0g;2L0=baWP3I/9h0eZjM0=>/W03AZiX0cjRH0<jVU@3<
Y9<0bZ>B0<VRTP37XI80a:2B0<:QT`31XI@0_j6E0;bQUP2iXIL0]Z6H0;>QV@2bXY/0/:>M0:nTW`2^
YZ40[ZNS0:jZY`2_ZjX0[Zj]0:na/@2e]kL0_;fm0<G5a03>c</0f=GB0>7MfP3Zi>00kn[V0=kLf@3@
cld0`L;10;>f]@2VZZX0V9jN08bBT`1oQhP0Lg]n6@3oool0@01VJFX0FUaM04m@D@13@d@0=SHg02TY
:@0L6a/03`h>0080000@30/07aLE02dS7`0m;bT0DClg06M?AP1kGU<0S6aO09EdJ02ENFh0T7M^08Yc
J`23KfT0OVaV07UXH`1dI5l0L61K06aLF01XFUH0I5ME065GE@1NEUH0G5MH05YIF`1HFUh0EUaQ05EN
I01CHFL0DV=Z059VKP1CJG<0Dfeg05A`O01DLh00EWR605MlRP1JPI40HHRH06nEY022Y;40V;Bo0:g3
c033dmX0f>?W0>cal`3joOl0jNk_0=[Oh03;d=80_<730:nd]P2RYjT0UYZL08Z=S`1nPH<H0?ooo`10
07ifMP1cK6/0If5Q05aFEP1@BT/0A3m003Pc=00[9RP07QXM02DQ8`0/9bT0<Rd^03Pb<`11>c/0Bd92
0558A`1FCD/0ETi>059>C`1;BTd0A4E903i1AP0h?D<0<cTo02he?00Y<CP09Bhe024[=00M:C806bPb
01PW<`0G:CH05R/i01D]?@0E<4005C=401HgB00G>T`063e@01Y2E@0KAUX07DYO01m>H`0PDVP08UI]
02ILL`0_I7/0?g:805>2U@1ZTj@0PJ>a09Rd_`2^a<d0`];I0=;Oi039eMT0`<[>0;No`P2_]KP0Z:b^
0:6SY02KVY/0UI:B08n9RAT0oooo0400^j2=0;NMR`2cVHP0[YJ50:ZCP`2VSh00XH]m09b7N@2FPgD0
TGib08]jK@25M6P0OFeR07EUF`1[G580GU5705A6?01:?3<0@c@Z03h_9@0k;240>2TN03DV700c91T0
<28G02hP5P0/7QD0:QdD02PL4`0W6a<09a/D02LL5P0X7aP0:B4K02/T7P0]9b80;bXU038^:@0d<2d0
=S<`03Pg=00j>CL0?3`j03dn?00n@3l0@DA204M:B01@DU40FeeJ06IWI01aLFd0O7Ye08J3OP2@S8D0
VI:;09jES@2QUX`0Y9J;0:RHR`2/VH`0/9^<0;BMS@2hWhh0_:6?903oool00280oooo0400H6MZ05UO
H01CEUH0C4e=04A3@`0m>SP0=C0]02dV8`0U71T0=BTS04@e;P1D@CP0IDi307YND@2BLF40ZX=a0<6E
P@3BXXd0g:jI0=fbWP3K/Ih0f;2N0=J_W@3D[Yd0djbK0=6ZV@3@Z9L0cZNF0<fVU@3<YID0bZBE0<RU
U`37YYP0a:FI0<6UVP2nYIX0^jFK0;RUW02eY9d0/jFN0;:VX02aYj80/:RT0:nZY`2`[:T0/:n]0;:b
/02g]kH0_[fl0<K4``3>blT0em?@0>3Je`3Vh=`0j>CP0=SFd`3:b/P0_Kjl0;2b/P2SYjL0UYbL08ZA
TP1nQXL0LW]m6@3oool0@01VJFX0FUaN04m@D@12@d@0=SHg02TY:P0L6a`03Ph>0000000?2`X071HD
02/Q7P0i;BP0C3/e061:@P1cFDl0QFMK08i_I02BMV/0SgM]08UcJ`23KfP0OF]U07QXHP1cI5l0Kf1L
06]LF01WFUH0I5QE065GEP1NEUL0GEQI05]JG@1JG5l0F5iS05IPI@1DHVT0E6A/05=WK`1CJW@0Dfeh
05=aO01CM840E7R505MlR`1LPi80IXbK07NJZ02:ZKD0WkS30;C8d03:emd0h>O[0?;emP3koOh0j>c]
0=WMgP3:c]00_<320:nc]@2RYZP0UYZK08Z=S`1nPH<H0?ooo`1007igMP1cK6`0J69R05eGF01BC4d0
AT5203Xf=`0^:R`08AhP02PT9P0^:R/0<bla03Td=P11>c`0B45104i7AP1BBd/0DD]<04i;C@18BD`0
@TA803/oA00e>T40;cHm02Xa>@0U;SD082Xc01`W<@0H9C005RDa01@U<P0B9cD04RTh018/?00B;d00
4c9401<fB00E>D`05Se@01Q1E@0IAEX06dUO01]=H`0MDFP08EI^02QNMP0dJH00AgV>05f9W01eVZ/0
Rj^h0::kaP2jc=D0cmcQ0=WTj03=em/0`lc?0;[1a02b]kT0ZZf_0:>TY@2LVi`0UY:B08n:RAT0oooo
0400_:6>0;RNS02eVhX0/IV90:fFQ`2YU8D0YI630::?PP2MRgh0V8Ii0960M@2:Ng00Q7E[07Y/HP1_
HEP0HeI=05I;@P1:?SH0@C@[03/]900g:Al0=2DK034R5`0]7Q<0:Q/@02PI3P0U5`d08aD<024E300P
5@d081D?020F400Q61<08Q/F02DO6P0W8al0:RHS02dZ9P0`;R/0<S4_03Dd<P0g=cH0>3Xi03Tm?00l
@D00@DI604U>CP1EFET0HFES06i_KP1jNWL0QH>0092>RP2MV9<0XijG0:FMU@2WWI@0ZYfB0:bMT@2_
WI00/ij@0;JOT02iXI00_::@903oool00280oooo0400H6MY05UNH01AEEH0BTa<0492@@0j>3L0<Rh/
02TS800P61@0;R<N03d_:@1=?3<0GTTn079HC029JU/0X7]Z0;R=NP3:W8L0fJZE0=faW03L/Ih0f[6N
0=V`W`3G/9h0eZjM0=F]W03DZiX0dZZH0=6XU`3AZIP0cjVI0<jZVP3<ZY/0bZZL0<NYW033ZId0`:RN
0;fXWP2jZ9l0]jRP0;FWX@2cZ:<0/JVU0;2ZYP2`[:T0/Zn/0;Bb/02h]kD0_[bk0<C2`@3<bLH0e=3=
0=cGd`3Qg=P0fmSD0=7?c034a<80^;Vh0:b^[P2PY:@0U9VJ08V?T01mQHH0LWYm6@3oool0@01VJFX0
FeeN04m@DP13A4D0=SLh02TZ:`0L71d03Ph?0000000=2PT06ADD02LP7@0e:RH0ASLa05U6?P1ZDdX0
Nf5F08IYGP2>LVP0SGE/08QbJP22KVL0O6YU07MWH@1bHel0KV1L06YLF@1VFUL0HeQF065HE`1OF5P0
GEYK05aLG`1KGV40FV1U05QQI`1FI6X0EFI^05EXL@1DJgD0E6ii05=aO@1CM840EGR605UmS01QQYD0
KY:P082P[@2D[kT0Ykg70;c<d`3Bg>40j>g_0?[ko03fn?P0i^WY0=OJf`39c<h0^ko00:jb/`2RYJL0
UIVJ08V=SP1nPH8H0?ooo`1007mgM`1dKFd0JV=S05mIFP1DCe00BDA503hi>`0b;S009B8T02/W:@0_
;Bl0=C4c03Te=`0o>S`0AT5104Y5AP1=B4X0C4Q:04]9C016Ad/0?d9703Lm@P0a>3h0:c<j02D^=`0P
:c<06bLa01LU<00D8bl04B8`00lR<@0>9C@03bPh00l[?00@;T004353014eB00C>D`053eA01E1EP0G
AEX064UO01U=I00MDFT08UQa02eSN`0nLHL0Dh:F06^CY021Xk<0V;C00;35c`39emh0gnW]0=kXj`3A
fM`0a/g@0;g2a@2d^;X0[:j_0:FTYP2MVi`0UY>C092:RAT0oooo0400_J6?0;VOSP2fWXd0/ib<0;2J
R`2]V8X0ZYN:0:NER@2TThL0WXn409N9OP2@PWP0R7Ya07iaJ01cIeh0IeaD05U?B01;@CX0@3D^03T]
9@0d9ah0<28H02`M4`0X6@l09AH;024C2@0O4@P07A0901/?2@0I3PP060h901T@300J4a0071LD01lJ
600R7Q/09B8O02PV900[:RT0;Rl^034c<P0c=SH0=SXj03Tm?P0m@T@0A4]<051FE`1MHV<0Jfm^07Uj
N@25QH<0TY2=09nLV02/ZZH0/:bW0:fVW`2^Y9/0[j:H0;6RUP2cXI@0]J6C0;RRTP2jXY40_J>A903o
ool00280oooo0400GfMY05QNG`1@E5D0BD];0451@00h=cH0;b`Z02HP7P0L51409Q`H03HY8`16=Bh0
ET8h06UAA@20HU@0UWAS0:b4LP30Tgl0dZ>=0=^^V@3M/Id0g;6N0=^aW`3J/Ih0fK2N0=V_W@3H[id0
f:fK0=J/VP3F[9/0eJfL0=B]W@3C[Yl0d:jO0<f]X039[9l0aJbP0<:[X02nZj40^jZQ0;RYXP2eZJ<0
/ZVT0;2YY@2`ZjP0/Zj/0;Fb/02j]k@0_kbi0<C1_`3;al@0dlk;0=cFdP3Sg]X0eM;?0<[8aP2n_[`0
/kBc0:RZZP2LX:40TYNG08N=SP1lPhD0LGYl6@3oool0@01VJF/0FeeO04mADP13ADH0=cPi02X[;00M
7Ql03a0A00010P0920P05Q<B02@M6`0`9b<0@3<_0551>P1RCTH0L5U@07eSF@28KF80RW9X08I`J020
K6H0NfUT07EVH@1aHUh0K5mL06UMFP1VFUP0HUQG061HE`1OFEX0GU]M05iNH@1MH6@0G69V05YSJ@1H
IV`0EfQ_05I[L`1EKGH0E6mj05AbOP1DMH80EWV705b1S`1XRiT0MiRU08ZV/P2N]Kh0/<?;0<CAe`3K
h^D0l?7c0?ooo`3al_<0hnGU0=GGf037b//0^[fn0:f`/P2QY:D0UIRI08V<SP1mP88H0?ooo`1007mh
M`1eKVh0JfEU065KG01GDE80C4M9044m?`0f<S@0:RLY02d[;@0b;c80=S<f03Xg>@0n>cd0@d1204M4
AP18ATP0B4I904M7BP12ADT0>cm503<j@@0]=Cd09S0i020/=P0J:3<05RD`018R;`0>82h0320^00/Q
<00;93@02bLh00`[?00=;T003S5400leB@0A>Dd04SeB01=1EP0EAE/05dYQ01Y?IP0OE6`0:5if03M[
P@19NXl0H8^N07RL[02>[KX0YKg80;k?e`3Dh>D0i>ga0=cTi`3BfM`0b<k@0;o3a@2f^;X0[Zj`0:JU
YP2NW9`0Ui>C092:RAT0oooo0400_J:@0;^QS`2hX8l0]Yn?0;>NS`2aWHl0[ib@0:fLT02ZVi40YYR?
09jAR02FRX40SX9i08AiL@1hKVL0Jf9L05eDC`1?Ad40@STd03L]9P0`9Ad0:alG02LJ4@0R5@d07Q4:
01X>1`0G30D05@X401<9100A2@@04@X6018<2@0C3``05A8@01TF500L6QT07alN02<S8`0V:2P0:Rd]
02db<P0a=SL0=C/m03Y1@`11BD/0Be=E05QOH@1VK6d0MGUi08:5Q02@THl0WIbI0:RVXP2`[JP0/jjX
0;>/Y@2cZJ00]:NM0;FVVP2fYIP0^:BF0;ZTU02lXi<0_Z>A903oool00280oooo01H0GfMY05MNG`1@
E5D0B4Y;03m0@00f=SD0;BXY02<O7@0H4Q007aLC02dR7@0m;RL0CS/b05m9?`1eFTd0RVYK09ijJ@2b
RGH0aYV40=JWT@3L[YT0gK6L0P3M/Yh0103M/Yl0g;:N0=baWP3L/Id20=^_W00R0=^aWP3J/J00f;:Q
0=JbXP3C/J80ck2R0<Z^XP37[J80`ZfR0;j/XP2kZZ80]jZS0;BZY02`ZJ@0/:^W0;:]ZP2d/Jh0^KFc
0;nk]`34_k`0b/G20=7;b03FdLd0g=SD0<k<b@33`/00^;Vg0:j_[P2SYZH0VIfM08nDU@25Rh`0Nh:4
075iNaT0oooo0400IfU[05]NG`1@DU<0A4I703Pj>`0/;Bh07R0Q014B4`020`@01`L801<A400O6QT0
:b@Q03T_;019?3L0FDQ206ICB`1bG5<0OFEL08=/H`22KFD0OVYT07UXHP1cI600Kf9N06]OG01XGEX0
IE]I069HE`1PF5P0H5]K061MG`1PH6<0Gf=V05iTJ@1LIV/0FVQ^05UZLP1HK7D0Efmh05EaO01FM7l0
EgR505YlRP1SQY@0LI6N086NZP2C[;H0Yk[30;W8c`3>em`0i>OY0?Gdm@3oooh0k^o_0>3Qh@3Be=@0
aLO80;Rj_02/[[00X::T09BGV028Rhd0OH22603oool0@020N7P0MVm_06eVI`1SGEh0FEAE04m;C015
@D<0>cLi02l/;`0`;S40=38e03Pe>00j>C/0?S`o0490@`16A4L0AdI904I6B@13ADT0?T=803LmA00_
=cl0:38k024]=`0J:C@05BDb014R<00=82h02Ah]00HN;P0683401b<e00TW>@0::cd02bi100`bA@0>
=DX03cY>014nD`0C@UP05DIM01Q;H`0MDVT095Ua035VO@13MHX0F8FH06nEY`26Y[D0VkK20;?8d@3=
f^00h>S/0>[bm03OiNL0e=WK0<[>d030`l@0]kRj0:j^[`2VYJH0WibL09NCT`2@RXTI0?ooo`100;jS
T02lXY40^Z:A0;RQTP2fXI<0]J6D0;>RUP2bXYP0/J>I0:fPV02VVY<0WI:;09B:P`2:PG/0OgI`07=Z
I@1VGUT0F51;04M0>`0i<Bd0;bDP02PL5`0R5Q007A4;01P<1`0D2@D04@L300h50@0;10402P@200T5
0`0;1`H03@/:010>3P0C4a805aPH01/M7@0O8R808bLX02L/;P0[<S@0<3Lj03Hn@00nAdX0B55E05EN
H@1TK6h0LWQj07n4Q@2=T900VifL0:ZZY`2e/k00^KJb0;Ze[`2i/ZX0^JjV0;V/XP2iZYh0^JRK0;ZW
V02lYIH0_JFD0;jTTR@0oooo000R0?ooo`0I05mWJ@1GGEl0CeAE04M:B`0n@400=CDe02`Z:@0Q7Q`0
510=01D?300T6aH0=2LQ04@d;01D@3L0J51507eQD`2@Kf00Xge/0;F<N038W8H0e:J@0=^]U`3M/I`0
gK6M0=ncW`020>2dW`0U0>2cW`3O/Yh0h;:N0>:dX@3Q]Z<0gkJT0=beY03H]:@0e;>T0<naY03;/:@0
aZjS0<6]X`2lZj80]jVQ0;BYX`2`ZJ<0[jVU0;2/Z02c[j`0]k>`0;bg]030_;T0al:n0<o8a03Bc<P0
c/_80<K3`@2l^kT0/[>a0:VZZP2OXZ80UYZJ08bATP23RHX0NH63071hN`0I0?ooo`1006MZJ`1LGV00
DE=D04E7B@0i>cd0;Bla024S900C5AL01@L800@51P0>3Ph06QLG02LR800c:bP0@SLc0554?P1MCDH0
J5E>075ME@1jIEd0NfIO07YWH01fIV40L69N06aQGP1YGU`0IeeJ06AKFP1PFEP0GeUI065LG@1SH640
Hf=U069UJ01QIf/0GfU^05eZL01LK7@0FVmg05UaNP1HLgh0FGJ105akR01QPXl0K8bI07^HX`2;Y:l0
WK:k0;30a`32c]<0f=gP0>c/k@3knOT0nOWh0>[ZjP3LgMd0cm3@0<;4a02f^;T0ZZb]09jQXP2CUYL0
R8^<07f0PAP0oooo0400P7Uh07MaL01^J6P0IF1P05aGF01CCU00BTI7040m?`0g=3L0=38e03He>00i
>3/0?C`n03ln@@13@TD0ATE904I6BP15ATX0@DA:03a2B00c?4@0;3Ho02@a>`0K:cL05BLd010S<@0;
82l021h^00@L;@0172d00Qla00DS=@07:3X02B`o00X_@P0;<dL03CM;00lkD@0A@5H054EK01M:H@0L
CfL095M_02iRN@0oL8H0Dh2C06R@X@1oX;00UK6n0:c2c034e=X0fnCX0>gdmP3^m?H0h>GW0=GIfP3:
cLl0`<;40;Nh^@2_[Zl0YjFU09nLW02HTi80T8Z96@3oool0@02nXi40_J>B0;^TT`2jY9D0^JFF0;RV
V@2hYi/0^:VO0;V]Y@2gZjD0[ZBM0:FLU@2MU8h0U8^508V0NP1lM700KfQT065KF01AC4X0@3/i034[
:@0V7Q/07aHC01P?300B2@L03@D300X20@070@001@00008000020@4010@400L82@0:3@h03Q4B018F
5`0G71d0728S024W:P0V;S40;3Dh03<l@00kA4T0ATmD05AMH@1RJfh0LGQk07n6R02>Ti<0W9nO0:Z/
Z`2f]kD0`/?20<K5`P31_;L0_kN`0;fcZP2m/:H0_:fQ0;b[WP2mZIX0_JNH0;jVU@2oY98T0?ooo`00
8P3oool06P1OIfT0EeiO04mDE@17BT/0?T1003De=@0[:RX08AhM01DA400?2@L06a<@02/P6`0k;BH0
BcT`05e7?01aEd/0PVEG09=bHP2ROVd0]8ai0<>HQ03>XH`0eZVD0=V]V03N/I`0hK>N0P3R]9l0903Q
/ih0h[>N0>BdX03U]j<0i;RU0>6hYP3M]JD0f;BU0=BcY03@/Z@0bK2T0<>]XP2nZj40^:RP0;>WX@2`
Yj40[jRS0:nZYP2a[:T0];2]0;Vd/@2m^;D0`kjj0<W3`03@blP0a/?00;fl^@2e];<0[:f/0:>VY@2K
WYh0TYJG08V?T021QhT0N82106mhNQT0oooo0400IfY/05eOH@1BE5H0AdU;03/n?`0`<S@092HX01LI
6`0:3@l00@@500X;300F5AD08QlN02dW9@0k<Rl0BSlj05A7@`1OD4X0IEE?06eLEP1aGeT0Lf5L071R
G@1[Ge`0JEiL06QMF`1VGE/0HeaK05mIFP1OFU/0HUiO06ERH`1VIFP0IFQ[06AYK@1QJg00H6eb05m_
M`1NLWX0GGAm05efP@1NNXD0Hh2<06Z9U01fTih0QIjY09F[]02W^L00^LK;0<cDf03Phn@0lO3`0?ol
n`3blO00i>CT0=OHf03;c<`0_/310;>e]P2WZZ/0W9nP09:DUP27RX/0O7n1603oool0@021NWT0NG9a
071ZJP1XHV<0GeYK05MBE01>BT`0AT9503hk?P0f=CP0>3Lj03/j?P0n?T40@41304=3A`17AdX0AdQ<
04I8C@11AT/0?D=:03DmAP0]>4408S4m01LZ>00@9S@0328a00PP<0047Rl001`_000N<0028S@012Hi
00HZ?@08;T402S9600/fBP0=>Dh043eD01A3FP0GBF0074mV02AFK@0^HGL0?6j304mlT01SRid0NIb[
08n]^P2V_LP0_LoF0=COi03Wk_00mOWk0>_`l@3PhnD0e=OH0<[<c@30`L80]kNh0:n][P2WY:@0Wi^K
09RBTP2@RXTI0?ooo`100;nTTP2nY9<0_JFE0;bVU`2lZ9X0_:VM0;b/X02m[jD0_k>[0;fd[@2f[JL0
[JFO0:FMU`2JU8l0T8Z608EoNP1iLfl0KFMU05mJF01?BTT0?SXi030/:`0S7Qd061<B00l;2P0910@0
1P4100<00@000040004300031P011@P00`P;00H=3`0;4QD03aPK01<L800I8RH082X^02Lb=`0_>Sl0
>D=904A?E@1BGF80H6]_071iO01oQhX0SYBF09fRX`2/[jl0^[bj0<C5``3:b/L0bLS40<K2_034_;D0
`[N^0<2cZ@2o/:@0_jfP0;n[W02oZ9T0_jNF0;nUTb@0oooo000R0?ooo`1005mWJ@1GGV00CeAF04M;
C00n@D40=CHf02/[:`0Q81l05Q@C00/81P0@2`P081PC02lT7P0o<2T0D3dd06A=@P1dFTh0Q6II099b
H`2QOVd0[hUg0;^CP035VhL0c:6>0=:WT`3HZiH0g:nI0=f`V`3L[iX0gk2J0>6aW03R]9l0i;FR0>>g
X`3O]J<0f[BS0=FbXP3@/:80bjnR0<B/X@2mZIl0]ZJN0;:UWP2]Y9h0[:FQ0:bVX`2]ZJH0/:bY0;B`
[@2g];40_;Re0<:n^P34`[l0_;^h0;Fd/P2][Zd0YZNW09jQX02FVYX0SY>D08J<S@1oQHL0Mgj006mg
NQT0oooo01L0J6]/05ePHP1CEUL0B4]=03i0@P0c=CL09bX[01/N800?4Q@00PH800D82P0B4a<07A`K
02PU8`0d;R`0A3Xg04i3?`1FBTH0G4m;069DC`1WF5@0J5YF06MKF00206AKF@0W06ALFP1TGE/0HUaL
05mKF`1PGEd0Hf1P06ETI@1WIfT0J6]]06M/L01TKW80I71e06=bN@1SMWd0HWR006=kQ01VOhT0K8NA
07F?V@22VZ<0T:F^0:2a^@2a_lD0a<c@0=KJg03VinL0m_?b0?_hm`3[j^T0g]kN0=;BdP36alL0^kbm
0;2a/P2UYjP0VYfN092CU026RHX0O7n001P0oooo0400PGYi07YcL`1bK6`0JVAU06=MGP1KEUL0DdmA
04]8BP14@D@0>cTm03/j?P0o?T40@D5404=3A`15ADT0BDU=04U;C`17BTl0@TM=03i4B`0h@4P0;c]4
02@d@00J;S`052Th00lV=P0;93D01b<e00<R=@0493L01RLj00P[?P09;T<02c=700dfB`0>>Dl04CiD
01E3F@0JBV007dmV02IGK@0`H7H0?Ff204ejS@1QRIX0MYRX08bY]P2R^/@0^L_B0=3Kh03Sj^d0m?Oi
0?Wko03ZkNh0g^7R0=?EeP39b//0`<300;Nf]P2^[:d0Yj>S09nKVP2GTY80T8Z96@3oool0@02oY980
_jFD0;jWU`2nZ9T0_ZZL0;n/X02o[j@0`;>Y0<:g[`33^[D0`;Rc0;R`Z`2_Z:<0YYnK09^ET@2@RhL0
QH1m07QcL@1[IV@0GEUG04i:B@0o?3/0<2h^02@R8P0J61P04Q0B00`;3P0820`01PP=00D:3`053140
1@dC00D?5@084QT02aLM010L8P0F8bT072X`02<a=`0]>T00=dA:04=@EP1AGV<0H6aa071jOP21RH`0
T9NJ0:2UY`2_/k@0_/700<[;b`3Ce=<0eMGB0<o=b@3;a/00b<2h0<Fj/P33]Z`0`[:V0<6_XP30[9h0
`:ZJ0<2WU`30YI<T0?ooo`008P3oool06`1OIfX0EeiP04mEE`17C4d0?d9303Hh>00/;Bd08R8R01PF
5@0;2@P020D201H@3@0U7AP0=2PR04<d;01E@ST0IU1507ELD023IeX0TW=T0:1nK@2ZQgH0/Xim0;ZD
P`32VXL0bIn<0<jSS`020=>WT`0S0=FYU@3HZiL0fjjI0=f`W03N/Yh0fk:O0=N`W`3C[il0cJfN0<R/
W`31ZId0^ZJL0;>SV`2_XY/0Zj6L0:VRW@2YXil0ZJFR0:bXY@2_[:T0/Jn/0;Bb/02k]k@0]kFc0;:b
/02][J/0YZRV0:2RX@2IW9`0TYJF08^@T@24RX/0O8>507EmO`1^MgT06@3oool0@01XJfd0GV5S05AG
F@1:CDl0@4=503Hh>P0[;S0082<U01@G6P082`h00`L800h@4@0I6AT0928R02l[:P0m=S@0Achl04e4
@@1CBDH0FDi;05eBCP1OEE80GUID05eGEP1NF5L0H5YI061KFP1PGEd0GeaM061NG`1SHF80IFEV06QY
J`1ZKFl0JFmb06QaM@1XLgP0J7Ek06UiP01YO8@0Jh6906n6S`1gSYH0P9JN08fQZ02K[;<0Z[Rn0;c5
b@3>dmD0g]oO0>_ZjP3hm?<0l>k]0>CRhP3HemL0c<c=0<72`P2g^;P0[:j_0::TY@2HVY`0SY6B08F8
R@1kOX0H0?ooo`10089kNP1kM7@0M6e^06eWI`1VH640GeYK05QCE@1ACDl0BTM904=1A00o?D00@T54
04A4A`17AdX0BDU=04e=D@1;CE40B4]@04=8CP0nAD`0>45:034lA`0X>4<083=101X`?`0G;ch04R`m
00h/?@0<:cd032`o00d_@@0><TD043I:018jCP0D?E805T5F01Y6F`0NBf409E9X02]IKP0eHWL0@6f0
04miR`1PQYL0M9JU08VU/P2N]/00]LO?0<gHgP3QinX0lOCf0?koo`3fn?P0j>[Z0=cMgP3Ad]<0b<O8
0;jn_P2f];@0[Z^[0:JRXP2NVYT0Ui:A0929RAT0oooo0400`:FC0<2VU@30Z9P0`:ZK0<2/W`31[j80
`[:W0<Bf[036^k<0bL6j0<S1_031^[D0^;6]0;2YY@2XXYh0WIRE092<R@23Ogd0MG5`06MSHP1IEED0
C4Q9040m?@0d<c@0:R/]028T9`0K7R805QXN01@I7P0B6Ah041TO00lJ8@0?72@04AhV01@Q:P0I9bl0
7Rde02Hd?00^?D@0>4I=04ABF@1BH6D0H6eb071kP021RXh0TYVL0::XZP2b][L0`/G60<oAdP3Jg=/0
h>;Q0=cMf`3DdLd0clW30<_3^`38_K@0a[R^0<BdZ033/:<0`ZfO0<6[V`30Z9L0`:JD903oool00280
oooo0400GfQZ05QOH@1@EUP0B4e>0413A00g>SX0;Rl`02@T9@0J6AT03Pd=00D20@0;1`D06aDA02XQ
700h;2H0BCXb05Q5?01XDTP0M5a@089WFP2?L680VGUZ0::1L@2YQgP0/8el0;RCPP2lUX@0`Y^90<FN
R`38X8h0bZ:?0<fUTP3@YY@0d:RF0<jYU`3;Z9P0b:NH0<BUV02nY9P0^:6G0;>PU`2/WYL0ZIfG0:FM
V02TWYX0Y9nL0:FQW`2WY:80ZZRU0:^YY`2^[JX0[Zf[0:f/ZP2YZJP0YJJU09nQX@2JWI`0U9RH08jB
T`27SHh0PHN807Z2P`1dO7h0KGIh6@3oool0@01YK6d0Gf9T05IIF`1=D540@dI803Tl?P0_<S@09BPZ
01XM800?4QD010T;00T=3`0E5aP0820P02/Y:00f<S40?STg04I0?P1:@d40DDU705E=B`1FCdh0Ee5A
05QDE01IEEH0GEQI05]HF@1NG5d0GeeN061OH01RHV<0IFIX06UZK01/KW00K75d06]cM`1/MW/0KGUn
071mP`1`PHP0M8J=07V<T`21U9/0S9fT09RW[@2V/[L0]Ko20<O<cP3HfMX0hn?R0?3^k@3`kN`0iN?S
0=_Jf@3@d=00a/K60;bm_@2b/k@0ZJZ[09nQXP2FV9T0SHn@08B6R01kOWlH0?ooo`1008=kN`1lMGD0
MVm_06mYJP1YHf@0HUiO05aHF@1FDU@0D4e?04Y8BP14@dH0ADA704Q8B`1;Bdh0C4e@04i?D`1<CU<0
BDeC04A:D011B4l0?4E>03A1C00]?TT0:3]802<hAP0Q>4H073E501XeAP0H=DH063I701ThBP0J?4h0
7T1B0255E`0SBE`09DaP02UAI@0_Ef/0=Umb03iWN@18L880E7Z;06B7U`1eU:<0RJ>`09bc_@2b`l/0
bMCI0=oUj03_l_<0o_oo0?gnoP3`l?00i>CU0=WIf@3?c/l0aLC50;fk^`2d/[80[:VY0:FQX@2NVIP0
Ui6@0929R1T0oooo0400`:FC0<2WUP31ZIT0`J^L0<:^X033/J@0aKFY0<Ni[`39_[H0cLBm0<o9a03;
a/80`[fi0;Ze/@2a[:T0Yj:P09ZFU02>RXP0PGil07AaL01XIVD0FeYK04m?D@16ATP0?Sm103Li?00`
<cL0:Rhc02H[<00U:S008b/a02<]<`0S;cH09S8j02Pf?P0/>T80<D1803U8D013DEP0CE]Q05QVJ`1V
LWL0MH2408F>TP2DW9l0Y:Z/0;Bi^P34b<P0dmKE0=oQh@3Yk>`0j>[Y0=kMfP3He<l0d/_50<k4_03;
_kD0b;Z_0<JeZ@34/Z@0`jjP0<:[V`31Z9L0`:JD903oool00280oooo0400GfQZ05QPHP1AEeT0BDi@
0455A`0i?3d0<38c02LX:00M7Ad04Q4A00L51@040P404@h;01lI5@0]9200?S4[04/l=@1HASh0Hdm6
079KD01oIET0QfeQ095eJ02IO6h0X85c0:V8N02/Rg`0/I200;FCPP2iUXD0^iR70;jJRP30W8`0`Ij>
0<2NS`2mWXl0^Yf@0;NMT02cVi40[IZ@0:VIT@2UV940XYRB09nHT`2NVID0WY^H09nMVP2QX9h0Y:>Q
0:FUX`2VYZ@0YJJT0:BTX`2QXZ40WInO09VLV`2DV9P0Si>D08Z?S`24RX/0OXF607V0PP1cNgd0KGEh
6@3oool0@01YK6h0HFAU05QKG@1?DU@0ATU;03e0@P0c=cT0:Rd_020S9P0E6A`02`lB00L;3@0B5QL0
71hO02HV9`0`;bl0>3De040l>`13?ch0BDA304i9B01>Bd/0DDm?05=ADP1EDeD0FEMH05UHF@1LFe`0
GEeO061QHP1RI6D0IVQY06Y/KP1]L780KW=e06ieN@1`NGd0Lgf107J1QP1gQHX0O8^A08>BU`2<VZ00
UZ:X0::]/P2`^;`0`<G70=3Ad`3NgMd0j^SW0>cZj@3Th^40fm[I0=;Ad@39bLT0`<300;Ng^02^[jl0
YJJW09bNW`2CUIL0Rhf?08>5Q`1jOGlH0?ooo`1008=lN`1mMWH0Mg5a079/K01/IVL0IV5R065LG@1K
EeT0EU=E055>D01;BD`0B4M:04a<C`1?Ce80Ce1D051AE@1?DUH0CU5G04Q>E015C5<0@4UA03Q5C`0d
A4l0<49>02a0C@0Z?dd09Si=02HoCP0U?dl09D5A02I4E00YB5P0;DaM031@H@0cE6D0=UUZ03aNL012
IGH0BVam055dQ01KOH`0JHRF07VEXP2:XZd0W;2j0;70a`36d=D0g>7T0>g_l@3mo_h0oooo0?Cdm03Y
jNT0gmkN0=GDe03;b/X0`l710;Zh^02b[jl0ZjNW0:BOW`2MV9L0UY2?0929R1T0oooo0400`:FC0<6W
UP31ZYX0`ZbM0<>_X@35/jH0akJ[0<Vk/@3<`;P0clJo0=?<a`3CcLT0cLO40<C0_@2k]k@0/:bZ0:JS
X02LVIL0T8f<08>1P01fM7<0JVUY061PH@1HF5X0D55C04Q:CP13ATT0?d9603]0A@0i?dD0>41603U2
B00jA4/0?4M>03m;DP13D5L0BUIN055NI@1JIV`0Hfme06iiO`1kQHX0RY:F09VPX`2X[[00^;bm0<S;
b`3GfMP0hnGT0>kblP3_lo80inOU0=oMf@3Ie<h0e<c50=35_@3<`;H0b[^_0<NfZP35/ZD0a:nP0<>/
W032ZIP0`JJD903oool00280oooo0400H6Q[05UPH`1BF5X0BU1B04=8B@0k?d00<cDf02X/;00P8B80
5QHG00/:2P01000020H501DA3`0R71T0<2LS03hc;@1;?CH0EDDn065?AP1^FDl0MV5G085ZG`28L6@0
SgIZ09IlK`2LP7<0XHAf0:F8NP2YRgd0Zhio0:f@P@2`Th@0/9B50;2DQ`2]ThL0ZY>70:NBQ`2TTHP0
X96809fARP2LTX`0VY:=09RBS`2GTi00UiFC09ZIU`2NWI/0X:2N0:2PW`2OX9l0WYnN09bNW@2JW9/0
UiZI09>GUP2?Ti<0Rhn@08J;S021QhP0O8>407MnP01aNG`0K7Eg6@3oool0@01ZKFl0HVEW05YMG`1B
EEL0BDa>0454AP0h>ch0;c<e02HZ;00L82<04QLI00T>4@0?5AL06AdN028T9@0[;2d0=3<c03Xh>00m
>c`0@T1004M5A@19B4T0CTe>04m?D@1BDU@0EEEG05MHFP1JFe`0G5iP061RH`1TIFL0IfU[06a^L01^
LG<0LGEh079hN`1eO7l0N82307Z4R01mR8d0PXjC08^GV`2EWj<0WjR/0:bc]P2j_/00b<W;0=OFeP3U
hn80j>KU0>3OgP3If=P0d]7A0<[9b@31`L80^KZj0;6b/P2YZZ/0XJ:S09VKW02ATi@0RH^=0864Q@1j
O7hH0?ooo`1008AlO01nN7L0NG=c07A^KP1_JFX0JVEV06EPH@1PG5d0G5QJ05MDEP1CDE<0CTe?055A
D`1CDeH0E5AH05EFFP1DEU/0DEEJ04eBF019D5L0ADmG03m<EP0nC5H0>TUE03M8E@0eB5@0<dQE0398
EP0bBUP0=4eK03M@GP0jDf80?UQW045LJ`16HG00BVIe051/N`1HLh40GWZ706F1SP1_RYL0OIFQ08fQ
[02M[kL0/Kk40<C=d@3Ffmh0jN[[0?_jnP3oooh0mOGd0>c[j`3RhN40fMSH0=3>cP37aLD0_kfm0;Nd
]02`[J`0ZJFU0::MW@2LUYH0UHn>08n8QaT0oooo0400`:FC0<6XU`32ZYX0`jfN0<B`XP36]:L0b;R/
0<^l/P3>`[T0dLS00=K@bP3IeM40e]?@0<o;b036`l00_[Zh0;>`[P2XYJ@0WIZI09:@S`26QHD0O7]k
07=cL`1[Jf`0I6AV05iNH01HFUd0E5MK055EF@1@EET0D5EK055GG@1CFF00EEeS05UQJ01NIfd0IFid
06afN`1cOH80O8F:08J>TP2AVI`0WZFW0:fb]02m`<40blk>0=SIf@3SiN@0l??c0??fmP3/kN/0i^CQ
0=oKeP3Jdld0eLc40=75_03=`;D0bk^_0<RfZ@36/Z@0a:nP0<>/W032ZIP0`JJD903oool00280oooo
0400H6U[05YQI01CFU`0C59D04E:C00n@T<0=STk02d`<@0U9bL06a`M010A4P0410@0000000X81`0G
518091lL034Y9@0m<bh0ACXd0513?01KC4D0I5A<06mME@1gI5/0OVYQ08A_I@2;M6X0SgQ^09=lL02G
P7@0Vh=g09f5N@2OR7`0X8Um09n:O`2KR7h0VhUo09R8O`2DQh00TXN10928P`2@RHD0ShZ708j;R@2?
SH/0TI2>096CT@2EUiH0VijM09VKVP2HVYT0UiVI09FHV02CUYH0TIBD08jBTP2:Shl0QXb<08:8R@1n
Q8H0NH2207ElOP1`N7/0JgAg6@3oool0@01[KVl0HfIX05aOH@1DEeT0CE1B04E8BP0m@4<0=CPk02d`
<`0T:2/06b0R018G6P0?5AL05Q/M01lS900W:R`0;c4b03Hf=`0h>CX0?Cdn0452A014ATP0BT]=04a>
D01@DU@0DUAG05IHF`1IG5h0GEmQ065SI@1UIfT0J6]/06e`L@1aLgD0MGQj07EjO@1iOh40O8:507f6
R@21Rhh0RI:E09:JWP2MY:L0Z:f_0;Bg^@31`/80c/g=0=_If03Uhn<0gMcL0=KEe@3@cll0bLS80<71
`@2j^[/0/k>d0:^/[@2TYJH0WIjO09FGV02>T940QhV;0823Q01iO7dH0?ooo`1008AmO020NGP0NgAd
07I`L01bK6`0KFQY06UTI@1UHF80HEeO05iJG01JF5X0F5MI05QGFP1IF5/0FEUM05YKGP1IFel0F5]O
05EIG`1AEeh0CUIN04YDG@18E5d0AE9M04=BG@11DUd0@E=O045DH013EV80AEUU04QLJ01;Gf`0D6A`
05AYM@1KKg/0GW>006EjQP1[P8/0LHJA07V=U`24Uj00Tj>[0::_]P2c_<80a<[=0=GGf@3Vi^H0m_Cc
0?kmo03fmO@0kNc[0>CShP3Kf]T0dm7A0<_8b033`<00^kRh0;Ba/02]ZJT0Yj:R0:6KV`2KUI@0UHj=
08n8QaT0oooo0400`JJC0<6XU`33ZiX0a:fN0<F`XP37]:L0bKR/0<bm/P3?`[T0dlW10=SAbP3OfmL0
h^3M0=_IeP3Bcld0bLO50<2m_02g];<0[Z^[0:FRX@2KV9P0TI2@08N6Q`20Ogl0NWUi07AdM@1_L740
K6i_06]]K`1YK6h0JFa_06Y]L@1/L7@0Kg=g07AiO@1jOh<0OhF908J<T02=TiH0UIZM09nTYP2[[[00
]kZk0<G6a`3Ad]80gMkM0>[Zj@3dm?<0m_Of0?3al03ZjNH0i>7L0=oId`3JdLX0eL[20=74^`3>_k@0
bkZ^0<VfZ@37/Z@0aJnP0<>/V`32ZIL0`JJD903oool00280oooo0400HFU/05]SI@1DG5h0CUEF04M=
C`11ATL0>Cho038e=`0Z;2h08B<T01LI6P0=3`l00P@400010@0;2`X061HE02DQ7`0`:RL0>34^040h
<`1:@3/0DTM205a@B@1UF540K5iF079SF`1gIf00OFaT089`J026M6/0RWQ_08ekL@2?OW@0TGmf0961
N02=OgL0RWif08MmMP25OGL0Pgii089oN`23P7h0QH>108J5Q026QhH0RXZ908f?S@2ATi40TYBD09:E
U02AU9@0TIBC08nCT`2=TI40Rhn@08V=SP26Rh`0PXR907n5QP1kPX<0Mgj007=kO@1_MgX0JgAf6@3o
ool0@01[KW00I6QY05iQH`1GFU`0D5=E04U<C`12ATP0>ci103<g>P0/<3<092T[01dR9@0F6ah051XM
01/Q900T:2X0;C0b03<e=`0f>C/0>C`n03i1@`11A4L0ATU<04]>D01>DE@0DUEH05IIF`1IG5l0GF1R
065TIP1VJ6X0JVa^06maL`1dMWL0N7]l07YnP01mPH<0OX>50827RP26SY00SYFG09RMW`2SYjT0[k6b
0;Vj^P36a<@0d/o?0=_If@3JfMT0dm;B0<c<c036a/H0`<300;Vi^P2c/k@0[:f^0:FWY`2OX:40V9ZK
09:DU@2;SXl0QHN907n1P`1hNgdH0?ooo`1008EmO@21NWT0OGIf07UbLP1eKfl0LF]/06eXJ@1ZIFH0
IV9T06APH@1QGV00H5eO05mMH01OGV00H5mR061PH`1QHF@0H65U05ePI@1JGfD0FEmU05EMI@1DGFH0
DeeV055MIP1AGVL0DUmY059PJP1CHF`0EFA^05QWLP1LJgD0H71j06IeO`1/Nh@0LH6;07V8T01mRi@0
Pi6I08bJX@2IY:X0YZnd0;Bj_`34alX0dmCE0>;Ph03`kN`0n_Sg0?OfmP3]jn/0i>;R0=cJf@3Dd]40
c<[90<G2`P2n^kX0]kBc0;6][02[YZH0YJ2O09nIV@2ITi80U8f<08j7QQT0oooo0400`JJC0<:XU`33
ZiX0a:fN0<J`XP37]:H0b[R[0<bm/@3@`[P0dlS00=S@b@3Nf=<0iN;O0>OVi03Pg]`0e]CB0<k:b@36
`/40_[^j0;Jd/`2^[:`0YZBT09jLW02GUID0THn@08b<S029RHP0QXF608>3Q022PX<0PH:308:3Q@24
QHL0QhV;08^>T02CUIP0VifP0:2RY02VYjT0[Zn`0;Vi^@32`l80c<c;0=OGeP3Sh^40k>c[0?Cem03j
oOd0moWi0>o^j`3XiN40hmgG0=gEc`3IclL0eLVo0=73^03>_[80bkV]0<VeZ037/Z<0aJnO0<B[V`32
ZIL0`JJD903oool00280oooo0340HFY]05aTIP1FGV00D5MI04Y@DP14BT/0?D9403Hk?00_<c@09b//
01lR8`0F6AX03Q0@00@51P0210@030h>01XI600V9280;b/Y03@`;@0k=S<0@Sdj04Y4@@1DC4L0Fe9=
065HD`1WGEL0K65K075UG`1fJV<0NFeV07eaJ@1oLf`0PgM_08AiLP22NG<0P7Ub07YeL@1gM740MgIc
07MgM01iNWP0O7el07n0O`21PX80PXB408N9R@29SH`0Rhj>0080Rhn?00d0RXj?08V>SP28SHd0QX^<
08B9RP21QhP0OhF607b2Q01hOh40MGen075jO01^MWT0JW=f01T0oooo0400K6ma06IYJ`1PHfD0FUeO
05AGF@1=DE<0Ad]=0455A`0j?T40=3Pj02db=00W;2l08BHY01/Q900J82<08BLZ02X^<@0a=CL0=SXl
03Tm?`0l@4<0?dA804A9C01:CU40CE9E059FF@1FFEd0FEeP05iQH`1SIFP0IfU[06a^L01`LW@0MWQi
07]mO`1nP880PH>40824QP23RHX0Ri2A096FV02JWZ00YjVZ0;>c/`2m_;`0alG40=;@c`3Cd]80cLg<
0<O7a`32`/80_;bm0;Ng]`2a/[80Zjb]0:JWY`2PXJ80VYbL09BFU`2>T980RH^<08>5Q`1mP840N7Yl
603oool02`25OWd0PW]j07igM`1kM7@0Mg5a07A^K`1aK6`0KVUZ06]WJ01YIFH0IfAU0080IV=U00H0
IVAV06ITI`1WIFP0IfIZ06IWJ`1VJ6`206AWK00[065VK@1PIfh0HFQ_061XL01PJG40H6Yb065[M01S
KGD0IW1h06UcN`1]Mgl0LG^207J0Q`1lQXd0PX^B08N?U@2<U9T0Ti^P09jUZ@2X[K40/kNj0<73a@3@
cm00gM_K0>[ViP3flo80mO?b0>_Yj@3ShN00fmWH0=CAd03=b/T0a/;20;nl^`2i]KD0/jn^0:fXZ02W
XZ80XYfL09fGUP2HTI40Thb;08j7QP0I0?ooo`100<6UT`32Z9H0`jZJ0<B]W@36/:40b;>U0<ZgZP3<
_;00cl6f0=?6_@3HcLD0gMG>0>;Mf@3ZinD0jnWX0>CQg`3KemH0d/o=0<_9a`37a<80`Kjl0;Zg]@2d
/Jl0[J^Z0:RUY@2TXJ00X9fM09fJVP2KV9P0VYRH09ZGV02JV9P0ViZJ09fLW02RX:00YjFT0:fZZ@2e
/[00_;Zh0<C2`03<b/P0dm7?0=cJf03Ui>40knk/0?SgmP3mool0nogm0?;bl03/j>D0i^3K0>3IdP3L
d/X0elc20=C6_03@`KD0cKb`0<^hZ`39]:H0ak6R0<F^WP33ZiX0`ZRG0<6VTb@0oooo000R0?ooo`0b
069[K@1MIFP0F61R05=JG01=E5H0B4i@0497B@0l@D80=CXk02hc=00W:b`082<T01PK700@4a@01`T:
00H92P0@4a<06a`L02HV9@0/:bX0<Bl^03Hd<`0m>cT0A48o04U7A01@C4T0EU9?05]FD`1QFeL0IUmK
06YSG`1^If80L6YT07A]J01hLFd0NG=_07QcK`1dLVh0M79`07=cL@1cM780LgEd07IhN01hNg/0Ngin
07f0P022QHD0PhN708B8R@25RHX208F:RP0<08B9RP23R8T0PHN80825QP1mQ8D0Nh:307V0P@1fOGl0
Lg]m071hNP1]MWP0JW=e6@3oool03P1]L740If]/069UI`1MH680Ee]M059EE`1<D580Ad]=0455A`0l
@480=S/m034f>00/<C<09b`_0P0Q9bX0<00X;S80<3Dh03Ll?P0j?d80?D9503m5B@14BTh0BTmC04iC
EP1BEeX0EUYN05UNH@1NHVD0HfIY06Q[K@1^L740LG=d07MiN@1mOWl0PH6208>4Q@22QHL0QXZ;08fA
TP2DUiP0WZ2P0:ZZZP2d/k<0_kfm0<K4a@3:b/T0aLG50<71`@2l_Kd0^;Rh0;>c]02^[jl0ZJZ[0:BU
YP2OX:40VYbL09FGV02@TY<0Rhf>08J8R@21PhD0O7n007MjNaP0oooo0400QWin08=lN`20NGP0OGIf
07YdM01gLG40M6m_079]K@1`Jf`0KVY[06eYJP1/J6X0JfQZ06]YJP1[JF/0K6Y/06e/K`1^KW40Kfmc
06i_L`1^L7@0K71e06eaMP1`LgT0L7Aj071eN`1`MG`0L7Im079hO`1eNh40N7f407b2Q`20QHX0QHZ>
08V>TP2>TID0TYJI09BIW02KWj<0YJV[0:na]02m_Kh0c<W:0=WEe03Vh=l0k^[Y0?3]k03WiN@0h=gL
0=WFe@3Bclh0blS70<G1`@2o^kX0^KFd0;>_[P2^ZJT0ZJBS0:BOWP2OVYT0ViFD09J@S`2BRhX0SHJ5
6@3oool0@031YI<0`ZRF0<>ZV@34[9`0aZnP0<NbY039]ZP0c;Z]0<no/`3Ba;T0e/[10=_@b@3Pf=80
iN3K0>cYiP3]jnT0inCR0>3Lf`3IeM<0e=3?0=3=c03;b<L0al?20<Bo_P31_;X0_KRf0;Rc/P2e/:l0
/Zj/0;6/Z`2`ZjX0/:b[0;:][02c[Z`0]:n/0;Na[@2k][80_kZf0<G0_03<b<@0eM7>0=oKf03YiN80
lNk[0?Wgm@3oooh0o?km0?Gdl@3^jnL0j>;M0>?Je03Ne<`0fLg40=K8_P3B`kP0ckjb0<bj[@3:]ZP0
b;>T0<J`X035[Id0`jZI0<:XUP31YY<T0?ooo`008P3oool03`1RJfh0GVMY05YRI01EGEl0D5QJ04aB
E017CDl0@DM903a1@`0f>c`0<3@f02T^;`0S9bP071lQ01@H6@0200/?400Q01@H6@0P8R809bPX02/]
;00^;bl0=3Dd03/l>`10@Cl0A4E304M8A`1<C4/0DU5?05MFE01KFUL0H5iK06=QGP1WIF40J6MT06e[
J01[JVP0J6YX06MZJ@1WJf/0J6e/06Y^KP1/LG80LWIf07EiNP1gNg`0Ngn007f2PP1oQ8@0P8F50080
P8F600`0OhF607j4Q@1mPh@0Nh:307Z0PP1hOh00MWeo07=kO@1aNG/0KWMi06aeM`1YLWDI0?ooo`10
06e`LP1YK6h0I6QY061SI@1KGV00EUYL059EE`1=DE<0B4a>04A8BP0o@dH0>Sm103Hk?@0b=cT0;C<f
02T^<@0Y<3<0<3Hj03Pm@@0n@dH0@4I90498B`17C500CE9E051EF01DFE`0EUaO05YOHP1OHfH0I6MZ
06U/KP1_LG80LWAe07QiN@1jO7d0PX:208:3Q023QXL0RHb<08nATP2GVIT0X:6Q0:VYZ@2e/k<0_Kbl
0;jn_`2l_Kd0^KVj0;Ff]P2a/[80[Jj_0:VZZ`2UYZL0XJ:S09fNW`2HVY/0U9JG092BT`2<SXl0QhZ;
08>5Q`1oPH<0NWeo07IiNaP0oooo00/0QWmn08AmO021NWX0OgQh07afMP1jM7@0N79b07I`L@1dKfl0
Lfi^079]KP02075]KP0c075]K`1aKW00LW1b07AbM@1dLgH0MgEi07MgNP1gN7`0MgQm07UjO`1kO840
O7f107eoP`1nP8D0OX260862Q`24QHX0QhR<08Z;SP2=SI40TY:D09BDU`2KVY/0WIbN0:6PXP2ZZ:T0
/[2a0;fj^P39aL@0dlk=0>3If03Yi><0j>GT0>;OgP3Kf=L0e=7@0<k:b@38a<<0`[jm0;fi^02h/k80
/jj]0:jYZ02YY:<0YInO0:2KVP2LUYH0V9:A09B>S@2ARXT0SHF401T0oooo01l0`JFC0<:WU@33ZIP0
a:bK0<F^WP37/J80bKBV0<^hZP3=_:l0d<2e0=C6^`3Hbl80g=;:0>7Id`3WhM`0k^_X0>o]j`3Yi^@0
hmoM0=oKf@3Lf=H0fMKD0=OBd@3CcL`0d<[80<o8a`3=alD0b/?10<O0_P36_kd0a[jl0080aKjj01l0
aknk0<Ro^`39`K`0c<Bo0=79a03Id</0gmSC0>OPg03_j^D0mO7]0?_hm@3oooh0oOkm0?Kel@3_jnH0
jN;L0>?Ke03Oe<`0f/k50=O9_P3Ca;P0d;nc0<jk[P3;^:X0bKBV0<NaXP36[il0a:bK0<>ZV032YiH0
`JFC02@0oooo000R0?ooo`0b06=/K`1OJ6/0G6AW05QPHP1DFeh0D5MI04aBE017CU00@TU:03i3A@0h
?T00<cPj02db=00W;2h08BHX01/O8@0B5aT041HG01HL7@0R9RL0:Bd^02da<@0_<S80<SHf03Hj>P0j
?Sh0?d=30496AP14B4P0BDe=051CD`1FF5H0FE]J05eNG01NHF00I6ET06=UI01QIFD0HFIV065WJ01S
JFT0IF]/06I]KP1_M7@0LGIg07AiNP1fO7`0N7io07YoP01kP84207^1PP0<07Z1PP1jP880NH2107Qo
P01fOGl0MGan07=kO@1aNG/0KgMj06efN01[M7H0JG9e6@3oool0@01^LG<0JVi_06IZK01SIVP0Gf9T
05]NH01GFed0DeMI04mCE@1;Ce80B4a>04A8B`10ADL0?D5403Tn@@0f>ch0<SPk03@j?P0i?d80@4E9
04A:C@18CU40C55D051EF01DFE`0EU]N05UNHP1MHFD0HFEW06AWJP1YK6h0Kg5a07=dMP1gN7P0NW]k
0861P@22PX<0QHJ708Z<S02?TY80V9VI0:2PX02UYZL0/k:b0;Bd]@2a/[80[k2`0:f][P2ZZj/0YjRX
0:>TY@2PXJ80WIjO09VKW02FUiP0TYBE08j@TP2;SHh0QhZ;08B6Q`20Ph@0OGn107UlO@1eN7XH0?oo
o`0:08MoO`25OGd0Pgak085jN@1oN7P0OGIf07]eM@1iM7@0N79c07MbLP80MW5b0100MG5b07IbL`1f
Lg@0N7Af07YgN@1oO7h0Ogeo07mmP01oOX40P82408B3QP28QXT0RHR;08R7R`29R8`0S8Z>0P2@SI00
8P2ASY40U96B09NDU@2JUYH0W9RI0::NW@2TX:00ZJFU0;2/[02i];@0`kfl0<g6a@3CcL`0gm[H0=oK
fP3HeM@0dlo>0<g9b038a<<0`kjn0;ji^@2i];@0];2_0;2[ZP2/YjH0Z:>R0:BNWP2PViX0WINF09VC
TP2FShh0Thb;08n8Q`2<QH@I0?ooo`0O0<6UTP31YiD0`ZRG0<>[VP35[I`0aZnP0<RbX`3:]JL0c;R[
0<jl/03A`KD0eLJk0=S;`P3MdLT0h]SB0>OPf`3_j^L0m?7_0?3/jP3Xhn40h]gK0>7LfP3RgM`0hmgK
0>;Lf@3NemD0fm?A0=cCd@3Me=00f]3;0=K;aP020=C9a00O0=?9``3DbL80eL[30=O<a@3LdLX0h]SA
0>WOf@3_in80m^kY0?[dl03mn_P0n_Wg0?C`k03^j>80j>3I0>?Id@3NdlX0f/g30=O8_@3C`kL0dKnb
0<jk[P3<^:X0b[FV0<RbX`36[il0aJfL0<B[VP33ZIL0`ZNE0<6UTP0T0?ooo`008P3oool0<@1TKG00
HFY/05iVJ@1KHfD0EemR05ALGP1AF5X0CEAF04U@DP15C4h0@DQ:03e3A@0i?d00=3Xl02le=P0Y;c40
92X/01lU9`0J8B<072<U02H/;@0/<S@0<CHg03<i>@0f?3`0=cdo03Y1@P0nADL0@TU:04E;C@1:D580
CUAE05AIFP1HG5`0FUiN05aPH01NHF80GF9S05aRH`1LI6D0GVEV069XJ@1SJVX0JW1a06icM01`MWL0
LWUj07AjO01eO7d00P1fOGh207ImO`0;07ImOP1eO7h0M7]m07=kO01bNW`0L7Qk06mgN@1]MWP0K7Ag
06YcMP1XLW@06@3oool04@1_LW@0K6ma06U/KP1VJF/0HfIX061SI@1LH680FEeO05IJG01CEeT0D5AF
04eAE01:Ce40B4a>04E:C012AdX0@4I90080?dE802d0@DM;04U>DP1=DeL0DeMJ05EJG@1HGEl0FEiQ
05eQI@1PI6L0HfIX06AWJP1YK6l0KG1a079dM@1fMgL0NW]k07ioO`22PX80QHJ608V;R`2?TI80UIJF
09bMWP2RXj@0Z:VZ0:JWZ02TYJH0XjBT0:2RXP2NX:00W9fN09VKW02GV9T0U9JG096CU02>T940S8j?
08V;S026R8T0PhF70823Q01mP840NWeo07QjO01eN7T0603oool02P27P7l0QWin08AmO022Ng/0PGYj
07miN01nN7L0OGMf07afMP1kMGD307YeM@0c07YeMP1kMWL0O7Qi07ijO021OGl0Q86308J3Q@28QHP0
RXN:08f9S02>Rhd0Shb>092=S`2CSi40U8nA09B?T02CSi00Ui:B09RCT`2JUI@0W9NF0:2KVP2TWYh0
ZJ:Q0:jXYP2d[jh0_;Nf0<>m_03:aL@0dLg<0=G@c`3>bLP0bLC30<C0_`30^kX0_;Nf0;Nb/P2c[Zh0
/:ZZ0:bWYP2YXj80YInO0::LV`2OVIP0W9JE09VCTP2FT8l0Thf<096:R@2>QhH0S8B301T0oooo0400
`:BB0<6VU032Z9H0`jVH0<B[VP35[Id0aZnP0<RbX`3:]JH0c;RZ0<jl[`3A`;<0e<Bi0=S9_`3LclH0
h=G=0>KMeP3/i=l0lNcX0?7/j@3]i^<0jN?O0>SQgP3Xh=d0imkK0>OMf@3Wg=P0iMWC0>7EcP3Odl/0
gm;90=g?aP3Jc<<0fLc20=_>a@3Ld<L0g];90>?Gc`3Xg]H0knGO0??Zi@3ekn/0n_Kc0?Sdl03`jN@0
j^;K0>GKd`3QeL`0gLo50=W:_`3FaKX0dl6e0=2m/03>^Z`0c;NX0<ZdY@38/Z80ajnO0<F]W@34ZiX0
`jVH0<:XUP31YY@0`:FB903oool00280oooo0380I6ia069/KP1PJF/0GVIY05]TIP1IHF<0EUiP05=K
G@1AF5X0CUEG04]BE017CU00A4]=0417B@0m@dH0>Cm203Dl?P0a>3/0;C@g02P_<P0X<3<0:S<f030h
>P0g?T00>41103U1@P0kA4H0?dM904=:C015CDl0B51A04YBE01>EEL0D5QI05EKG01GG5h0FEiO05]O
H@1KH640GF=T05YPH@1LHf@0HfY[06Q^L01[LW<0KGAf06mfN01`MgT0LGQj079iN`80LWYk00`0LWYl
079iN`1aNG/0L7Qk071hNP1_MgT0KWIi06eeN01/M7L0JW=f06UbM@1XLG@I0?ooo`0A071cM01]LG80
Jfi`06U/KP1VJV`0I6MY069UI`1OHfD0GF5S05]NH01IG5h0EUYL05AHFP1BEUT0D5EG04mCEP1=DUD0
0P1<DE@01@1;D5@0D5EH05=IG01GFeh0G61R0080GV9U0100H6AW069VJ01TJ6X0IfY/06Y^K`1]L740
LGAd07AfM`1iNW/0O7em0820P024QHD0QhR:08n@T@2ATY<0UING0P2IVi/0502HVY/0UiVJ09JHV@2E
UYL0TiFF096CU02?TI80SHn@08^=S`29Rhd0QhV;08F7R@23QHL0PH>507n1P`1mOh40NWeo07QkO@1f
NG/0M7Mi603oool02P28P7l0Qgmn08EnO@24OG`0Pgak089kN`21NWX0P7Ui07miN@1oN7P307ihN00c
07iiN@1oNWX0P7]k089mO@24Oh00QX:308Z5QP2AS8d0U8j@09>=S`2DShl0UY6B09NATP2GT940UY2@
09J@T@2GTI80VY>C09^EU02OV9H0XIZH0:>LV`2VWid0ZJ>Q0:jXY`2b[J`0^kJe0<6l^`34`;l0a<2n
0<2k^P2m^;H0^KBc0;J`[`2b[J`0[jZY0:bVY@2YXj80YZ2O0:>MW@2QViX0WYRG09bEU@2ITi80Ui6@
09F>S@2CS8/0THZ908n8Q`2=QXD0Rh>201T0oooo01@0`:BA0<6UT`32Yi@0`ZRF0<>YV034ZiX0aJfL
0<J_WP38/J40bK>T0<^fY`3=^J/0ckb_0=;0]03EaKT0fLVo0=g?a@3Qe<`0i][B0>cSg080l^WS00T0
kN?M0>WNf@3ZgmX0j]kI0>SKe03Uem00h]C=0>;Dc03RdlX00P3RdlP07`3Qd/P0hM;70>;Db@3Se/d0
i=_B0>SOe`3]iMl0lngX0?G_jP3`jN80j^3H0>GId03PdlT0g<k30=W9_@3FaKP0dl6d0=2m/03>^Z`0
c;NX0<ZeY@39/Z<0ak2P0<J^WP35[9`0a:^J0<>YV032Z9H0`ZNE0<6VT`30Y980903oool00280oooo
01P0IFia06A]L01RJfh0HFY/05mXJP1MIVP0G6AW05YRI@1HH680EUiP05ALGP1BFU`0CeMJ04eEE`1;
DUD0B51B04E=D013Bdd0@4Q;03i6B@0mATT0?DE903Y3A`0nATT20459C00G049:C012BTd0ADi?04]B
E01=EEH0CeMI059IF`1CFU`0EEaN05QNH01IH680Ff5S05IMG`1KHF@0GVEW065XJP1TJfd0Ifi`06Ua
L`1[LW@0K7Af06eeM`1^MGL00P1^MWP206ifN@80KWIh00T0KGIh06eeN01/MGL0JgAg06]dMP1ZLgH0
JG9e06QbM01WLG@06@3oool04@1`M7D0Kg9d06eaLP1/Kg40JVe_06U/KP1WJV`0IVU[06AWJ@1SIVP0
HFEV061SI@1NHV@0GF5S05aPHP1KGf40FUiP0080FEeP01T0FEiQ05]OHP1LHF@0GF5T06=VJ01UJ6/0
I6MY06EXJP1TJ6/0IVY/06Y]K`1/Kg00KW5b075dM@1cMWH0MWQi07UkN`1lOWl0PhB508>4QP28RX/0
RH^<08V<S@2;SHh0Rhj?0080Rhf>0180RXb=08V;S028RX/0QhV:08F8R@24QhP0PhF70864Q@20Ph@0
Oh6307f0P@1lOh00NWeo07UlO@1hNW`0MWUk07EhN@1cMWPH0?ooo`0508R1P027P7l0Qgmn08InOP25
OWd00P24OG`00`23O7`0Pgak089kN`03089kN`0c089lO023O7`0Pgem08AnO`26P800R8:208Z5Q@2=
R8P0T8Z:09>=S02HTI00V9:A09N@T02HTI40Ui6A09J@T02GT940Ui6@09VBT@2KU9<0WIJE09nHU`2Q
VYP0Y9jL0:fVY@2`ZZT0]:j/0;:]Z`2`ZjX0/:ZY0:jXY`2[YJ@0ZJ>R0:NQX02UWYd0XYbK0:2JV@2N
V9L0WIJE09^DT`2ITY40Ui2@09J?SP2DSH`0Thb;096:R@2@R8P0SXN608f6Q@2<Q8<0RX>201T0oooo
0200`:BB0<6UTP31YY<0`JJD0<:WU@33Z9L0`jZH0<B[VP35[9`0aZjN0<N`X039/Z80b[BU0<bgZ03>
^Z`0dKf_0=?0]03Fa;P0fLRm0=g=`P3PdLH0h]C90>KHc@3Wf/l0i]S>0>GFc@3Uelh0i=G=0>7Ab@3N
c/D0g<c20=c<`080gLc001h0gLc10=c<`03Ncl<0i=O=0>[NeP3Yg]D0iMW?0>;Eb`3PdLH0g<c10=W8
^`3F`kL0dl2b0=6m[`3?^Z/0cKNX0<^eY@39/j<0b;6Q0<N_WP36[Id0aJbK0<B[V@33ZIP0`jRG0<:W
U@31YY@0`JJC0<6UTP30Y94T0?ooo`008P3oool0<01VKg80IFma06A^L01TKG00Hfa_069[KP1QJVd0
H6U/05mXJ`1NIfX0GFIY05aUI`1KI6H0FV9U05UQI01GH6<0EUmQ05EMH01DG5l0De]N059KGP1BFUh0
DEYN059KGP1CG5l0De]O05=LG`1BFUh0D5UM055JGP1BFed0DeaN05AMH01EGV00EUiP05INH@1HH6<0
GVIX05mWJP1QJF/0HV]]06A/KP1UKW00Ifma06Q`L`1YLG@0JG9d06YbM@80JW=e1@1ZLgH206YcM@<0
JG9e00@0J79d06QaM01WLG@0Ig5c6@3oool0401aM7H0L7Ae071cM01_LW@0KW5c06e`LP1]L740K6ma
06]^L01ZKFl0JFe_06U/KP1XJfd0If]]06MZK01VJV`306IYJ`80IVY/00H0If]]06Q/KP1ZKFl0Jfi`
06Y^L01[Kg0206Y^L00=06e`LP1_LG80L7=d075dMP1cMGL0M7Ih07IhN@1hNg`0OGn107anP01mOh00
OH2107j0PP0407j1PP0B07j0PP1mP840OGn107aoP01lOX00Ngio07YmO`1jO7h0NGam07QkO@1hNW`0
MgYk07IiN`1eN7X0MGQi07AgN@1cMWP0LgIg603oool00`29PH00R86008R0O`0208N0O`0408MoOP26
Ogh0QWmn08IoOP80QWin0P25OWh208IoOP0808IoO`27P800R86008V2P@2:Ph<0RhB408f6Q@2>QhH3
0929R080THZ900X0TXb:09J>S@2GShd0V96?09VBT02JTi40ViBB09fEU02OV9L0XIZI0P2NUiH0602M
UiH0WIJE09bEU02KU9<0VY>B09VBT@2HTI00Ui2?09J?SP2ESXd0U8f<09><R`2BRhX0THZ90929R02?
R8L0ShN608j6Q@2=QXD0S8F408b4P`2;Ph80RX>208Z2PAT0oooo0P30Y9405@30Y980`JFB0<6UT`31
YY<0`ZJD0<:WU@32Z9H0`jVG0<BZV034ZiT0aJbK0<J]W037[ih0b;2P0<ZbXP3;]:@0cKJV0<jhZ@3@
^Z/0dKb/0=:m[P030=>n[`060=>o/03D`;40el>d0=S5]@3IaKL0fLFh0P3Ia[P0703JakT0f/Rk0=_9
_03HaKP0eL6d0=C0/P3C_[00dKb]0=2jZ`3>^:P0c;FV0<^cX`39/Z40b;2O0<N_WP36[I`0aJbK0<F[
V@34ZYP0`jVG0<>XUP32Z9D0`ZNE0<:VU031YY<0`JFC0<6UTP30Y9820<2TTB@0oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo00180?ooo`900000FP3oool2@000
05H0oooo0T00001J0?ooo`900000=P3oool004X0oooo00=000000?ooo`3oool0F@3oool00d000000
oooo0?ooo`1E0?ooo`03@000003oool0oooo05T0oooo00=000000?ooo`3oool0<`3oool00380oooo
00=000000?ooo`3oool02@3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo
0?ooo`0e0?ooo`=000000P3oool00d000000oooo0?ooo`0:0?ooo`=000000P3oool2@00000<0oooo
0d0000050?ooo`03@000003oool0oooo0300oooo0T0000040?ooo`03@000003oool0oooo00X0oooo
0d0000020?ooo`9000000`3oool3@00000D0oooo00=000000?ooo`3oool0;@3oool5@00000030?oo
od000010000000@0oooo00=000000?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=00000
1@3oool00d000000oooo0?ooo`0]0?ooo`00<@3oool00d000000oooo@00000090?ooo`06@000003o
ool0oooo@000003ooom00000103oool014000000oooo0?oood00000n0?ooo`06@000003oool0oooo
@000003ooom000002P3oool01T000000oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3o
oom00000>P3oool01T000000oooo0?oood000000oooo@00000X0oooo00I000000?ooo`3ooom00000
0?oood0000040?ooo`04@000003oool0oooo@00003L0oooo00=000000?ooo`3oool00`3oool01T00
0000oooo0?oood000000oooo@00000/0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04
@000003oool0oooo@00003D0oooo000a0?ooo`03@000003ooom0000000T0oooo00E000000?ooo`3o
oom000000?ooo`03@0000080oooo00A000000?ooo`3ooom00000?03oool4@00000<0oooo00=00000
0?ooo`3oool0203oool01D000000oooo0?oood000000oooo00=000000P3oool014000000oooo0?oo
od00000i0?ooo`9000000P3oool00d000000oooo@000000:0?ooo`05@000003oool0oooo@000003o
ool00d0000020?ooo`04@000003oool0oooo@00003L0oooo00=000000?ooo`3oool00P3oool00d00
0000oooo0?ooo`030?ooo`03@000003oool0oooo00T0oooo00E000000?ooo`3ooom000000?ooo`03
@0000080oooo00A000000?ooo`3ooom00000=@3oool00340oooo00=000000?oood0000002P3oool3
@00000040?oood0000100000@00000<0oooo0d00000l0?ooo`03@000003ooom000000080oooo0T00
000<0?ooo`=0000000@0oooo@0000400001000000`3oool3@00003P0oooo00=000000?oood000000
0P3oool00d000000oooo@000000;0?ooo`=0000000@0oooo@0000400001000000`3oool3@00003L0
oooo00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`02@00000d0oooo0d000000103ooom0
0000@000040000030?ooo`=00000=@3oool00340oooo00=000000?oood000000303oool00d000000
oooo0?ooo`150?ooo`9000000P3oool00d000000oooo0?ooo`0=0?ooo`03@000003oool0oooo0400
oooo00=000000?oood0000000P3oool00d000000oooo@000000=0?ooo`03@000003oool0oooo03l0
oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?ooo`3oool03P3oool0
0d000000oooo0?ooo`0m0?ooo`00<P3oool00d000000oooo0?ooo`0:0?ooo`900000B03oool00d00
0000oooo0?ooo`03@00000`0oooo0T0000130?ooo`9000000`3oool00d000000oooo0?ooo`0;0?oo
o`900000@03oool2@00000@0oooo00A000000?ooo`3oool0oooo0d00000=0?ooo`900000?`3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool007`0oooo0T00002=
0?ooo`900000P`3oool007h0oooo00=000000?ooo`3oool0S03oool00d000000oooo0?ooo`200?oo
o`00L03oool3@00000<0oooo0d0000030?ooo`=000001@3oool00d000000oooo0?ooo`05@0000080
oooo00=000000?ooo`3oool01@3oool00d000000oooo0?ooo`080?ooo`=000000P3oool3@0000080
oooo0d0000030?ooo`=0000000<0oooo@000040000000`3oool3@00000<0oooo0T0000030?ooo`90
0000403oool3@00000<0oooo0T0000020?ooo`=000000`3oool2@0000080oooo0d00000=0?ooo`=0
000000L0oooo@000003ooom000000?oood000000oooo00A000000P3oool3@0000080oooo0T000002
0?ooo`900000NP3oool00740oooo00=000000?ooo`3oool00`3oool01D000000oooo0?ooo`3ooom0
00000080oooo00=000000?ooo`3oool0203oool01d000000oooo0?ooo`3ooom000000?oood000000
4P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo0080oooo00E000000?ooo`3oool0
oooo@00000020?ooo`05@000003oool0oooo0?oood0000000`3oool00d000000oooo0?ooo`020?oo
o`9000000P3oool00d000000oooo0?ooo`0@0?ooo`03@000003oool0oooo0080oooo00A000000?oo
o`3ooom000000P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3ooom00000
3`3oool02D000000oooo0?oood000000oooo@000003ooom000000?ooo`03@0000080oooo00I00000
0?ooo`3ooom000000?oood0000060?ooo`03@000003oool0oooo07L0oooo001a0?ooo`03@000003o
ool0oooo00<0oooo00E000000?ooo`3oool0oooo@00000020?ooo`03@000003oool0oooo00P0oooo
00=000000?ooo`3oool00`3oool00d000000oooo0?ooo`0@0?ooo`03@000003oool0oooo0080oooo
00=000000?ooo`3oool00P3oool01D000000oooo0?ooo`3ooom000000080oooo00A000000?ooo`3o
oom00000103oool01D000000oooo0?ooo`3ooom000000080oooo00=000000?oood0000000T00000@
0?ooo`03@000003oool0oooo0080oooo00A000000?ooo`3ooom000000P3oool01D000000oooo0?oo
o`3ooom000000080oooo00A000000?ooo`3ooom000003`3oool024000000oooo0?oood000000oooo
@000003ooom000000`3oool014000000oooo0?oood0000020?ooo`03@000003ooom0000000900000
0`3oool00d000000oooo0?ooo`1h0?ooo`00L@3oool2@00000<0oooo0T0000040?ooo`=000002P3o
ool014000000oooo0?ooo`3oool2@00001<0oooo00=000000?ooo`3oool00P3oool00d000000oooo
0?ooo`020?ooo`03@000003oool0oooo0090000000<0oooo@000040000000P3oool2@0000080oooo
0T0000020?ooo`9000000P3oool00d000000oooo@0000002@0000100oooo0d0000030?ooo`900000
0`3oool00d000000oooo0?ooo`020?ooo`9000000P3oool4@00000`0oooo0T0000020?ooo`900000
00<0oooo@000003oool00P3oool2@00000<0oooo0d000000103ooom00000@000040000030?ooo`90
0000N@3oool00740oooo00A000000?ooo`3ooom00000503oool01D000000oooo0?ooo`3ooom00000
01@0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`020?ooo`03@000003oool0oooo
03<0oooo00=000000?ooo`3oool0Z`3oool00700oooo1D0000020?ooo`03@000003oool0oooo00h0
oooo0T0000030?ooo`=000004@3oool3@0000080oooo0T0000030?ooo`9000003P3oool00d000000
oooo0?ooo`0S0?ooo`9000006@3oool00d000000oooo0?ooo`2A0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {194.313, 0}} -> {-0.309124, -0.0488477, 
  0.0115746, 0.0115746}, {{26.6875, 107.063}, {190.063, 
  109.688}} -> {-35.0999, -5.86462, 1.00336, 1.00336}, {{115.063, 195.438}, {
  190.063, 109.688}} -> {-123.772, -5.86462, 1.00336, 1.00336}, {{203.5, 
  283.875}, {190.063, 109.688}} -> {-212.507, -5.86462, 1.00336, 1.00336}, {{
  291.875, 372.25}, {190.063, 109.688}} -> {-301.179, -5.86462, 1.00336, 
  1.00336}, {{26.6875, 107.063}, {101.688, 21.3125}} -> {-35.0999, -94.5367, 
  1.00336, 1.00336}, {{115.063, 195.438}, {101.688, 
  21.3125}} -> {-123.772, -94.5367, 1.00336, 1.00336}, {{203.5, 283.875}, {
  101.688, 21.3125}} -> {-212.507, -94.5367, 1.00336, 1.00336}, {{291.875, 
  372.25}, {101.688, 21.3125}} -> {-301.179, -94.5367, 1.00336, 1.00336}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "After setting a mouse cursor on a following image, twice clicking the left \
side button of mouse animates the facial changes depending on the lighting \
angles. This is only effective on the ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Do[Show[GraphicsArray[{illusiveG[[i]]}]],{i,rotation}];", "Input",
  CellLabel->"In[93]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 12.812500 moveto
(deg) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
99.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
677073677073677073677073677073677073677073677073687073687073687073687073687073\
687073687073687073697173697073697072697072697072697071696F70696E6E
6A7071697173697173697173697274697174697174697174697173687173687173687173687174\
6872756872756973766974776975786A75786A76796A777A6A777B6B787C6C7A7E
6E7D816C797D6B787B6A777A6A76796A7578697578697478697477697376687376687275687275\
687274677174677173
677073677073677173677073687073687173687073687073687173697173697173697173697172\
6A71726A71726A71726A71736B71726B71726B71726C70716C70706C6F6F6B6D6C
6C70706C71726C72746B72746B73746B72746A72746A72746B72746A73746A73756A73756A7375\
6A74776A75786B77796B787B6C797C6D7A7E6D7C7F6D7D816E7F836F8185718288
7284897081866F7F836E7D816D7B806D7A7E6C797D6C787C6B787B6B777A6A76796A7578697477\
687376687275677174
6770736770726870736871736870726870736970736970726971736A71726A71736A71726B7172\
6B71726B71726C71726C71726D71726D71726E71716E71716E70706F6F6E6F6E6C
6F71706F72726E73746E73746D74756D74756C73746C73746D73746C73746A74756A74766A7577\
6B76786B77796C7A7C6D7C7F6F7E8170808371818571848872868B74888E758B92
758A9074878D73858A728388718186707F846F7E826E7D816D7B7F6D7A7E6C787C6B777A6A7679\
697477687376687274
6770736770726870726871736970736970726970726A70726A71726B70726B71726C71726C7172\
6D71726D71726E71726E71726F71726F727170727171717171717072706E716F6C
7272707273737174747175757075756F74756D74746C73736C72726C71736A73736B75766B7678\
6B787A6C7A7C6D7D7F6F7F8270828572848874878B758A8F768D927890977A949C
799198788E94768B9175898E74868C738489728287718085707F836F7D816E7B7F6C797D6B777B\
6A7679697477687275
6770736870726870726970726970726A70726A70726B70726B71726C71726C71726D71726D7172\
6E71726F71726F717170727171727171727172727173727174727075726F75706D
7573717574747475767376767276767176767075766F74756E73746E73746D73746D75766D7779\
6D797C6D7C7E6E7E8170838672868A74898D778C917990967A949A7C979E7E9BA3
7D979F7B949B7A9198798E95778C9276898F75878C7384897282877180846F7E826E7B7F6C797D\
6B777A6A7578687275
6770736870736870726970726A70726A71726B71726B71726C71726D71726D71726E71716F7171\
6F7171707171717271727271737271747371757371767472777472797471797470
7975737876757777767677787578787478787377787277777177777076767076776F7778707A7C\
707C7E717F82718285738689758B8F778E937A92977D969C7E9AA1819EA681A0A8
809DA57F9AA27D979E7C949B7B9197798E94788B9176888E74868B7383887180856F7E826E7B7F\
6C787C6A7679687376
6770736870736970726970726A71726B71726C71726C71726D71726E71716E71716F7171707171\
7171717272717272717372717473717673717774717975727B76737D78757E7976
7C78767B78777A7978797979787979777A79767A7A75797A757A7A747A7A747B7B737C7C737E7F\
73808274838675868A768B8E788F937B94997E989E809CA382A1A986A6AF85A5AF
84A3AB83A0A8819CA48099A17E969D7C93997A8F96798C9277898F75868B7383887180846F7D81\
6D7A7E6B777A697376
6770736870736970726A71726B71726B71726C71726D71716E71716F7171707171707171717171\
7272717372717472717572717673717773717974717A75727E7774857D79827B78
7F7A787E7A787C7A797C7B7A7B7C7B7A7B7B797C7C797D7D787D7D787E7E777F7F778181788384\
78868779898B798B8E7B8F937D94997F989E819DA485A2AA87A7B08AADB889ABB5
88A9B286A6AF85A2AB839FA7819BA37F979F7D949A7B9096798D9277898E75858A728286707E82\
6E7B7F6B777B697477
6870736870726970726A71726B71726C71726D71726E71716F7171707171717171717171727270\
7372707472707572707773707873707973717A74717B74717D757189807B847D79
817C7A807B7A7F7C7B7E7C7B7D7D7D7D7E7D7C7E7D7B7F7E7B807F7B81817B84837B87867C8989\
7C8B8C7D8E907E91937F949881999E839DA385A3AA89A9B18CAEB88FB5C08DB2BD
8CAFBA8AACB689A8B187A4AD85A0A8829CA480989F7E949B7B9096798C9276888D748489718084\
6F7C806C787C697477
6870736970726A70726B71726C71726D71726E71716F7171707171717171727170737170747270\
7572707672707772707873707973707A73707B74707B73707F7673847B78847C79
837D7A827D7B817E7D817E7D807F7E80807F7F807F7E80807E81817E83837E87867E8A897F8E8D\
809191819395829698849A9D869EA387A3A889A7AE8CADB58FB3BD92BBC692BAC6
90B6C18EB2BD8DAEB88AAAB388A6AE86A1A9839DA481989F7E949A7B8F95788B9075868B738286\
707D816D797D6A7578
6870736970726A70726B71726C71726D71716E71716F7171707171727170737170747170757270\
7672707772707872707A73707B73707C73707D74707F7571817773837A76847C79
847D7B847E7C847F7E838080838180828181828281818281808281808685808A88818E8C829290\
839695849898869B9D889FA18AA3A78CA7AD8DACB38FB1B992B7C195BFCA97C2CE
95BDC993B9C491B4BF8EB0B98CABB489A6AE86A1A9849CA381979E7D92987A8D9377888D748488\
717F836D7A7E6A7578
6870736970726A70726B70726D71716E71716F717170717171717072717074717075717076726F\
77726F79726F7A726F7B736F7D736F7E746F7C726D827773837975847A77857C79
857D7B867E7D86817F868282868383858383858383848483828181828483828787838B8B848F8F\
869696879B9B8A9FA08CA3A58EA7AA90ABB092AFB693B4BC95B9C397BFCB9AC6D2
9AC6D397C0CC95BBC692B5C090B0BA8DABB48AA5AE87A0A8839BA280959C7C9096798A8F75858A\
7280846E7B7E6A7579
6870736970726B70726C70716D71716E717170717171717072717073717075716F76716F77726F\
78726F7A726F7B726F7D736F7E736F80746F8A7C77877A76867A76867B78877C79
877D7A877E7C88818089848389858489858488848487848485828284808184838484858685898B\
8892948A9A9B8DA1A190A6A892AAAD94AEB496B2B996B6BE97BAC499C0CB9BC5D2
9DCAD79BC6D399C1CD97BBC694B6C091B0B98DAAB28AA4AC869EA582989F7E92987A8D9276878C\
7381866F7C7F6B7679
6870726970726B70726C71716E71716F717170717072717073717074716F76716F77716F78716E\
79726E7B726E7D726E7E736E80746E81746F8A7C76897B76897B77897C78887B78
887C79887E7C8A81808C86858C87858C87858E8786888080858080827D7D827E7F838485858688\
888C8E8C949692A0A194A9AA97ADAF98B1B699B5BB99B8C09ABBC59BC0CB9DC6D2
A0CCD9A0CDDA9EC7D49BC1CD98BBC595B5BE91AFB78DA8B089A2A9859BA280959B7C8F9478898D\
7482876F7C806B767A
6870726A70726B70726D71716E707170717071717073717074716F75716F77716E78716E79716E\
7A716D7C726D7E726E80736E81726C8D7C758C7C768B7C768A7B768A7D79897B78
887A77887C798A7F7E8D8484918887897F7F8A8080887E7E867E7E857F7F837D7E828082818384\
83888A878E90929B9D99A8AA9BB0B29CB4B89DB8BE9CBAC19CBCC59DC1CB9FC6D2
A1CBD8A3CFDDA3CDD9A1C8D39DC1CB99BAC495B3BC90ACB48CA5AC879EA582979E7E9196798A8F\
758488707D816B777A
6870726A70726C70716D70716F717170717072717073716F75716F76716E78716E79716D7A716D\
7B716C7D716C7F726D82746E82736C9380788F7E778D7C778C7B768B7B778A7A77
897975887976897B7A887D7D9087878D86858B84848A848589828387828486838486888985898B\
848B8F838C8F88949794A1A39FB0B2A1B8BBA1BBC09FBCC39EBDC69EC1CBA0C6D1
A2CCD8A4D0DFA6D0DEA6CEDAA3C8D29EBFC999B7C093B0B88EA8B089A1A8849AA07F93987A8C91\
768589717E826C777A
6870726A70726C70716E70716F717071717073717074716F76716F77716E79716D7A716D7B706C\
7B706B7C706B7F716C8878728A7972907F77907D778E7D778D7D778D7C778B7A76
8977738878748776758576768B7C7C8C81808C82828C84848B8484898585898586898A8C888D8F\
89919488919489979B8D9DA19AAAAEA4B9BDA4BDC1A2BEC5A0BEC7A0C1CBA2C6D1
A4CBD7A5D0DEA7D1E0A8D0DDA8CDD7A2C4CE9CBCC597B3BC91ACB38CA4AB869CA381959A7C8D92\
77868A717F836C777B
6970726A70726C70716E707170717072717074717075716F77716E79716E7A716D7B716C7C706B\
7C6F6A7B6D68796B6484736D907C758F7D75907D76907C768F7D768F7C768D7A75
8B78738B7A778D7E7C8C7D7B8D7D7D8D7E7E8C7F7F8C7F7F8B7E7F89808189818389848689888C\
8B8F928B92968C979C8E9EA294A5AAA1B5B9A6BEC2A4BFC5A2BFC7A1C1CBA2C6D1
A5CBD7A6D0DDAAD5E3B1D8E5ACD1DCA6C9D3A0BFC99AB7BF94AFB68EA6AD899EA583979C7D8F94\
78878C727F836C787B
6970726B70726D70716F707071717073706F75716F76716E78716E7A716D7C716D7D716C7D706B\
7D6F697A6B667466607A6B668A78718F7C75917D76927C76917D76917D768F7A75
8D78738D7A7691817E9182809081809081808F81808E81808D80808C81818C83848C86888D8A8D\
8E8E9190929791969B929BA094A1A79BABB1A3B8BDA5BDC4A3BFC6A2C1CAA3C5CF
A5CAD5A6CEDAA6D0DDB5DBE7B1D5E0AACCD6A3C3CC9DBAC397B1B991A9B08BA1A784989E7F9095\
79888D7380846D787B
6970726B70726D70716F707071717073716F75716F78716E7A726E7C726D7D726D7F726C80716B\
80706A7F6E6880706984736C8C7971917D76947F77947E77947D77937D76927B75
907A74907B7793817E9586839485849384829283829183829081818E82828E85858F898A908C8E\
919093949598969A9E97A0A49AA5AB9EADB3A2B5BAA4BAC1A4BDC5A3C0C9A4C5CE
A6C9D4A6CCD9A7CFDDB8DDE8B4D8E2AECFD9A7C6CFA0BDC699B4BC93ABB28CA3A9869AA0809297\
7A898E7381856D787C
6970726B70716D70716F707072716F74716F76716E79716E7B726D7D726D80736D82736C83736C\
85736C87736B89766F8D7B73917F7796817897827A97817A978079977F78967E77
947C76947E7895817D978784978886968785958584938684928483918383918685918A8A928F8F\
93929496979A999CA09BA2A59DA7ACA0ADB3A3B5BAA4B9BFA5BCC3A4BFC8A5C4CD
A5C8D2A5CAD7A4CDDBBADFEBB9DCE7B1D3DDAAC9D3A3C0C89CB6BE95ADB58EA4AB889CA1819398\
7A8A8F7481856D797C
6970726B70716D707070707072706F75716E77716E7A726E7D726D7F736D82736D85746D87756D\
89766D8C786F8F7B72937F7796837B99847C9A857D9B857D9B837C9A827B9A817A
997F7998807A98827D9A87839B8B88998987988684968684948684938583938786938A8A958F90\
96939499999B9C9FA19FA4A7A0A8ACA2ADB1A4B3B8A5B7BDA6BBC2A6BFC7A6C3CC
A6C7D1A5C9D5A1CAD8B6DCE8BDE1ECB5D7E1ADCCD6A5C2CB9EB9C197AFB690A6AD899DA3829499\
7B8B907582866E797C
6970726B70716E707070706F73706F75716E78716D7B726D7E726D81736D85746D88756D8B776E\
8E786E927D739580779A867C9C877E9E877F9E88809F88809E877F9E857D9E857D
9D837C9C837C9C847E9D88839E8C889D8B889B8987998986978885958785958987968D8C989191\
9A95969D9B9C9FA0A3A3A6A9A4ABAEA5AFB2A6B3B7A7B6BCA8BAC1A8BFC6A8C3CB
A8C6D0A6C8D4A0C7D4A9D1DFB8DEEABADDE7AFCFD8A7C4CDA0BBC399B1B892A8AE8B9EA484959A\
7C8C907583876E797D
6970726B70716E707070706F73706E76706D79716D7C716C80726C83736C87746D8B766D8F786E\
937C719882779C877CA18B81A48B81A38B82A38B82A38B82A38A82A28981A28980
A28880A18880A08882A08A84A18C889F8C899E8B889C8B889A8A87988A87988B8999908E9B9493\
9E9998A19D9EA4A3A4A6A9ABA8ACAFA9B1B4A9B4B8A9B8BDAABCC2ABC0C7ABC4CC
ABC8D1AACBD5A8CBD6A9CFDBADD4E1B3D6E0AFCFD8A9C6CEA2BDC49BB3BA94A9B08DA0A585969B\
7D8D917683876E7A7D
6970726B70716E706F71706E73706D76706D7A706C7D716C81726C85736C89756C8E766D93786D\
987D719D8378A38C80A68F85A88F85A88E84A78E84A78E84A78D84A78D84A68D84
A68C84A58D84A58D86A58F88A5908AA38F89A08C889E8C889C8A879A8A879A8C8A9C918F9E9694\
A29B9AA4A09FA7A5A5AAAAABABAEB0ADB2B5ACB5B9ADB9BDAEBDC2AFC1C7AFC6CC
B0CAD1B0CED6B0CFD9B2D5E0B5DBE7B4D7E1B1D0DAABC8D0A4BEC69DB5BC96ABB18EA1A786979C\
7F8E927784886F7A7D
6970726B6F706E6F6F706F6E736F6D766F6C7A706B7E716B82726B86736B8B746B91776D977A6F\
9E7F74A5877BAB9084AE9488AE9388AD9287AC9186AB9086AB9087AB9087AB9087
AB9188AB9289AB928AAA948CA9948EA7928CA48F8BA18D899E8B879C8B879B8E8B9D928FA09795\
A49C9BA8A2A1ABA8A8AEADADAFB1B2B0B4B6B1B7BAB1BABEB2BEC3B3C2C8B4C7CD
B5CBD2B6D0D8B6D2DAB8D9E3BCDFEABADCE6B4D4DDAECAD2A7C1C8A0B7BD98ADB390A3A888999D\
808F937784886F7A7E
6970716B6F706E6F6E706E6D736E6C766E6B7A6F6A7E70698271698772698C746A93766A9B7D72\
A68679B08F82B69789B6988BB4978BB2958AB09489AF9388AE9288AE9288AF9389
B0948AB1968CB0978EB0988FAE9791AB958FA7928DA48F8AA18C889E8B879D8E8BA09390A39997\
A69F9DABA5A3AFAAA9B1AFAFB3B3B4B4B6B8B5B9BBB5BCBFB6BFC3B7C3C8B9C8CE
BACDD3BCD2D9BDD5DDBFDDE6C0E1EBBFE2ECB9D7E0B2CDD5ABC3CAA3B9BF9AAFB492A4A98A9A9E\
818F937885896F7B7E
696F716B6F6F6D6E6D706D6C736D6A766D69796E687E6F688270688771688D72679273679B7C70\
AA897BB79485C29E8FBE9D8FBA9A8DB7988BB4968AB29489B19388B19389B3948A
B4968BB6998FB79C92B69D94B39C94B09992AB958FA6918BA28D88A08C889F8F8BA29491A59A98\
AAA19FAEA7A5B2ACABB5B1B1B8B5B5B9B9BABABCBEBABFC1BBC2C5BCC5CABDC9CE
BFCED4C1D4DAC2D6DDC6E0E8C7E3ECC5E6EFBEDBE3B6D0D7AEC6CCA6BBC19DB0B694A6AA8B9B9F\
829094798689707B7E
686F716A6E6F6C6D6D6F6C6B726C69756C68796C677D6D66826E668870668D716691726597796B\
A8887ABA9687C8A291C4A191BF9D8FBB9A8DB7978AB49589B4958AB4958AB7988D
BA9A8FBC9D91BDA094BBA197B9A198B49E96AE9891A8928CA38D88A08C87A08F8BA39491A69A98\
ACA29FB1A8A6B5ADACB9B3B2BCB7B7BDBBBBBEBFBFBEC1C3BEC4C6C0C7CBC1CBCF
C3CFD5C5D4D9C7D8DDCDE2E8CFE8EFCCEAF2C3DEE5BBD3DAB2C8CEA9BDC2A0B2B797A7AC8D9CA0\
8491957A868A707B7E
686F706A6D6E6B6C6B6E6B69706A67736A65776A647C6B64826D64886F658E71659374689A7B6D\
AD8B7CC09989CFA694C9A393C49F90BF9C8EBA978AB49387B19185B19186B39388
BA988CC09D91C2A195BFA197BDA39AB9A29AB09992AA938CA48D87A08B86A08E89A39390A79A98\
ADA2A0B0A7A5B5ADABBAB3B2BFB9B8C1BDBCC3C1C1C3C3C4C2C5C8C3C9CCC5CCD0
C7D0D5C8D4D9CAD8DDD0E0E6D4EAEFD2EDF4C9E1E7C0D6DBB6CAD0ADBFC4A3B4B899A9AD8F9DA1\
8592967B878A717B7E
686E70696D6D6A6B6A6C69676E6865716763746761796861806B62896F6491726595766A977A6D\
AB897AC19A89D3A996CDA593C7A090C29D8EBC988AB69386AF8E81AB8B80A78A7F
AE8F84B7968ABD9B90BD9B91B99C93B69D95B09891AA928BA48C85A08A849F8D87A2938EA69996\
AFA4A1B1A8A5B7AEACBEB5B3C4BCBAC5BFBEC8C3C2C7C6C6C6C8C9C5CACCC7CDD1
CAD1D5CCD5D9CFDADED8E3E7DBEBF0D8EFF4CEE3E9C5D8DDBBCDD2B0C1C6A6B6BA9CAAAE919EA2\
8693967C878A717C7F
676E70686C6C6969696A67666B65626D646070635D75645D7D675E896E639B7B6D9C7C6E9D7E71\
AD8B7CC49B89D7AB97D0A794CAA291C49E8EBF9A8BB99588B28E81AD8B7FA5877C
A4877CA98B80B09288B6968CB6998FB49A91AF978FAA928AA48C859F89839D8A859E8F8A9F928F\
A79D9AACA29FB3A9A7BFB4B0C3BAB7C7BFBDCCC6C3CBC8C7C9CACAC6CACCC8CDD0
CBD1D4CDD5D9D4DBDFDFE7EAE5F0F3DFF2F6D4E7EBCADBDFBFD0D3B4C4C7A9B8BB9EACAF93A0A3\
8894977D888B727C7F
676D6F676B6B67676767656368625F69605C6B5E586E5D56755F5783685D99786AA58274A88576\
B5907FC79D8BD9AC98D2A895CCA392C69E8DC19C8CBC988AB69284B08C7FAB897C
AB897DAC8C80B09084B49589B5978DB3978EAF958DA99089A38B849F89829C89839C8C889E908E\
9F97959F9998A19D9DB2ABA8B8B3B1BCB8B6C5C0BEC6C3C2C6C6C6C5C8CAC7CCCE
CACFD2CDD4D7D8DEE0E4E9EBECF5F7E7F7FBDBEBEED0DFE2C4D2D5B8C6C9ADB9BCA1ADB095A1A4\
8994977E888B727C7F
666C6E65696A656565646260645F5C645B5764585365544E644F47775E558A6B609C7A6DA78475\
B89180C89E8BDAAD98D4A996CEA492C79D8DC19989BD9788BA9587B69183B38E80
B28D7FB38F82B59285B79589B7988CB3958BAE938AA98F87A38B839E89829C88829C8D879E918D\
A196949F98979B9898A29F9FAAA8A8B1B0AFBAB8B7BFBEBDC2C3C3C4C6C7C5CACC
C8CED0CBD1D4DADEE0E7EAEBF0F5F6EDFBFDE2EFF1D6E2E4C9D5D7BCC8CBB0BBBEA3AEB197A2A4\
8B95987F898B737C7F
656C6E646868636363625F5E605B585F56535E524D5C4C4658453E6C554C81655A937366A38072\
B78F7ECA9E8BDBAC97D8AB97D0A693CAA08FC29989BA9383B68F81B28D7FB08A7C
AC8779AC887BAE8B7DB18E82B29286B19288AD9187A98E85A48B839F89819B87819B8B849F928C\
A39893A49A98A49E9CA7A1A0A9A6A5AFACACB8B4B3BCBABAC0C0C0C2C4C4C5C8C9
C6CCCECBD1D3DCDEDFEBEBEAF0F2F3F3FDFEE9F3F4DCE6E7CED8DAC0CACCB3BDBFA6B0B299A3A5\
8C96987F898C737D7F
656B6D6366676161615F5D5B5C57555A524E574C475446404F3E37604C44755D538A6C609E7C6E\
B48D7CC99D8ADAAB96DAAC98D4A896CDA392C69D8DBF9686B89081B28B7DB0887A
AD8677AC8678AC8779AF8A7DB08F82B09085AD8F85AA8D85A58B83A089829B8681968580988A85\
9F948EA69B97ABA29DADA5A2AEA9A6B2AEACB7B4B2BBB9B8BEBEBEC1C2C2C1C6C6
C3C9CACBD1D3DDDEDEF0ECEBF4F4F3F9FFFFF6FCFCE3EAEBD3DBDCC4CCCDB6BEC0A8B1B29AA3A5\
8D969880898C737D7F
646B6C6165665E5F5F5C5A59595452554E4B5247434E403B49383258453D6C554B81665A967668\
AF8978C69B88D8A994DBAD99D7AB98D1A695CAA191C49C8CBE9787BA9283B68F7F
B48C7DB38C7DB28C7DB28D7FB28E81B19084AE8F85AB8E84A78D84A38C849E8A83998882948783\
948B8698918DA39B97ACA4A1B2ABA7B5AFACB8B4B2BBB8B7BDBCBCBDBFBFBEC2C3
BEC5C6CCD0D1DDDEDDF0EBE8F9F4F2F9FBFAFAFEFCE8EDECD7DDDDC7CECEB8BFC0A9B1B29BA4A5\
8E9798818A8C747D7F
636A6C6064655C5E5E59575655514F514A474D433F483C3742332E514039634E457A6055907164\
A98474C19784D6A792DDAE99DAAE9AD4AA98CEA695C9A191C49D8DC0998ABC9586
BA9283B89182B79081B69182B59183B39184B09185AD9085AA8F86A78F87A38E879E8D879A8C87\
988D89978F8C9993919E9997A6A19FABA8A6B0AEACB3B2B1B8B8B7BABCBCBCBFBF
BCC2C3CACECEDBDADAEAE5E3F7F1EEFCF9F7FEFEFBECEEEDDADEDDC9CECEBAC0C0ABB1B29CA4A5\
8E9798818A8C747D7F
636A6B5F63645A5C5C565554524E4C4D4744483F3C4338333D302A4D3D365D4A41735A4F8A6C5F\
A38070BB9380D2A48FDDAE99DDB09CD8AD9BD2A998CDA695C9A292C59E8EC29B8C
BF9889BD9687BB9585BA9485B89486B69486B49387B19387AE9389AB9289A7928AA4918BA0918C\
9E928D9C938F9D96939F9A97A29E9BA6A3A2ACA9A8B0AFAFB4B4B4B6B8B9B8BCBD
BCC1C3C9CCCCD7D7D6E4E1DFF2EDEAFCF7F4FFFDFBF0F1EFDCDFDDCBCECEBABFBFABB1B29DA3A5\
8F969881898B747D7F
62696B5D6263595B5B5453524F4C4A494441443C383E342F392B2648383258453D6C554A836659\
9D7A6AB58D7BCC9F8BDCAD97E0B29EDBB09DD5AC9BD1A999CDA696C9A292C69F8F
C49D8DC19B8BBF9989BE9888BC9788BA9689B79689B5968AB2968BB0968DAC968DA9968EA6958F\
A49690A39893A29A96A49C99A6A09DA8A4A2ACA9A7B0AEADB3B2B2B4B6B6B6B9BA
BEC1C1CACBCBD6D5D3E2DFDCEEE9E6F9F3EFFDF8F5F1F0EEDCDDDCCACDCCBABEBEABB0B09CA3A4\
8E969781898B747D7F
61696A5C61625759595151514C494846413F4039353A302C33272243352E534139664F457B5F53\
937264AC8674C49884D5A791E0B19CDDB29ED8AF9DD4AC9BD0AA9ACDA797CAA393
C8A191C69E8EC49D8DC29B8CC09A8BBE9A8BBC998BB9998DB79A8EB49A8FB29A90AF9A91AC9A92\
A99A93A89C96A89E99A89F9BA9A29FAAA6A3ACA9A7AEADACB0B0B0B1B4B4B4B8B9
BCBFC0C8C8C8D3D2D1DEDBD8E9E4E1F3ECE8F7F2EEEEECE9DADAD8C8CAC9B9BCBCAAAEAF9CA1A2\
8E959681888A747C7F
61686A5B60615558584F504F494746433F3C3C3633362D2930241F3F302A4F3D35604A4074594E\
8B6C5EA5806FBB927FCEA18CDBAD98DDB29EDAB19ED6AE9DD3AC9BD0AA9ACEA897
CCA594CAA291C8A08FC69F8FC49E8EC29D8EC09C8EBE9C90BC9D91BA9E93B69E93B49E94B19E96\
AE9E96AD9F98ACA19BACA29EACA4A0ACA7A3ADAAA7AEACABAFB0AFB0B2B2B4B7B8
BDBFBFC6C7C6D1CFCEDAD7D5E4E0DDEDE7E3F0EBE7E4E2DFD5D4D2C5C7C5B6B9B9A8ACAC9AA0A0\
8D9495808889737C7E
60686A5A5F615457574D4E4E474544403C3A393330322A262B211D3A2D274A39325A463C6D5448\
8365579B7868B48A78C99B87D6A893DCB09CDCB19ED9B09ED6AE9DD3AC9CD1AB9A
CFA898CEA695CCA493CAA392C9A292C7A192C4A092C2A193C1A194BFA195BCA196B9A197B6A198\
B3A199B2A29BB0A39DAFA49FAEA6A1AEA7A3AEAAA7AFABAAAEAEADAFB1B1B5B7B7
BCBDBDC5C5C4CECCCBD8D5D2E1DDDAEAE4E0EFEAE6DEDCD9D0CFCDC1C2C1B3B6B5A6AAAA989E9E\
8C92937F8788737B7E
60676A595F605356564C4D4D4443433D3A3835302D2D2623251C1935292344352E544138654E43\
7A5E51927161AA8371C19581D2A28DDCAE99DDB29EDBB19ED8B09ED6AF9DD4AE9D
D3AC9BD1AA99D0A897CEA796CDA695CCA595CAA495C8A597C7A698C4A599C1A59ABEA59ABBA59B\
B8A59CB5A49DB3A59EB2A6A0B1A7A2B0A8A4AFAAA7B0ACA9B0AFADB2B2B0B7B7B6
BEBDBCC6C4C3CECBC9D7D3D0E0DAD7E6E0DCE8E4E0D8D6D3CACAC8BDBEBCB0B2B2A3A7A7969C9C\
8A91927E8687727B7D
606769595E605155564A4C4C4242413A3837322E2C2923202018142E231E3D2F294D3C335E493E\
72584C896A5BA07B6AB88D7ACA9C87D9AA95DDB19CDCB19EDAB19ED9B09FD7B09E
D6AE9DD5AD9CD4AB9AD2AA98D1A897D1A998CFA999CEAA9ACCAA9BCAAA9CC7A99CC3A99DC0A89E\
BDA89EBAA89FB7A8A0B5A7A1B3A8A3B1A9A5B0AAA6B0ACA9B2AFACB4B2B0B8B7B5
BEBCBBC4C2C1CCC9C6D4D0CDDCD7D3E1DCD8DBD8D4D1CFCCC4C4C2B8B9B8ACAEAEA0A4A494999A\
898F907D8586727A7D
5F6769585E5F505455494B4B4141403837362F2C2A26201E1C1411261C1836292346352E564238\
695145806254967463AC8472C0937FD2A38DDBAE99DDB19DDCB19EDBB19FDAB19E
D9B09ED9AF9DD8AF9DD8AD9BD6AC9AD6AC9BD5AD9CD4AD9DD3AE9FD0AE9FCDADA0C9AC9FC5ACA0\
C2ABA0BEABA1BBAAA1B8A9A2B5A9A3B2A9A4B0A9A5B0ABA8B2AEACB5B2B0BAB7B4
BFBCB9C4C1BFCBC7C4D3CECBDCD6D2E3DEDAD5D2CFCAC8C6BEBEBCB3B4B3A8AAAA9CA0A1929797\
878D8E7C8385717A7C
5F6769575E5F505455484A4B3F40403636352D2A29231F1D1812101F17132D221D3D2E274E3B32\
5F493F755A4D8A6A5B9E7A69B28976C69984D6A791DCAE99DDB19CDDB29EDDB29E
DDB29FDCB29EDCB19EDCB19DDBAF9CDBAF9CDBB19EDAB1A0D8B2A1D6B2A2D3B1A2CFB0A2CAAEA2\
C7ADA2C2ADA2BEACA2BBAAA2B7AAA3B4AAA4B0A9A4B0ABA7B2ADAAB4B1AEB9B5B3
BFBBB7C4BFBCCAC5C2D1CBC8D6D1CDDCD8D4CECCC9C3C2C0B8B9B7AEAFAEA3A6A6999D9D8F9495\
858B8C7B828471797B
5F6769575D5F4F5455474A4B3E40403535352C2A29211E1C14100D150F0C241B1634272144342C\
5440376850457D6153906F60A37D6CB58C78C89C86D4A690DBAD97DDB19CDDB19D
DFB39FE0B49FE0B49FE0B39FDFB29EE0B29EE2B4A1E1B6A3DFB6A4DCB5A4D8B4A4D4B3A4CFB1A4\
CBB0A4C6AEA3C1ADA3BCABA2B7A9A1B4A9A3B0A9A3AFA9A5B0ACA8B3AFACB7B3B0
BCB7B4C0BCB9C7C2BECFC8C4D2CCC8CECBC8C6C3C1BCBBB9B2B3B1A9AAAA9FA2A2969A9A8C9192\
83898A79818370787B
5F6769575E5F4F5455474A4B3E40403535352B2A2A211E1D1511100F09071B13102B201B3B2D26\
4B39305D473C71574B826557937262A27E6DB48C79C39884CEA18CD6A994D9AD98
DEB19CE1B39EE2B49FE2B49FE1B39EE2B39EE4B4A0E5B7A3E4B8A5E1B8A6DDB5A5D8B4A5D4B3A4\
D0B2A4C9B0A4C3ADA2BEABA1B8A8A0B3A7A1B0A7A1AFA8A3AFAAA6B1ACA9B4B0AD
B9B4B1BDB8B5C3BEBAC9C3C0D0CBC8C6C3C0BDBCB9B5B4B3ACADACA3A6A59B9E9E929697898F90\
8187897880816F787A
5F6769575E604F5456474B4C3E41413536362B2B2B21201F1614130B0806100B082018132F241E\
3F3029503D34644D42745A4E846659927263A17E6DAF8977BB9380C59B87CCA18E
D2A793D8AB96DCAF99DDB09BDCAF9ADFB09AE1B19CE2B49FE4B5A2E3B7A3DFB5A3DAB4A3D5B2A2\
D0B0A2CBAFA2C4ACA1BDA99FB6A69EB2A59EADA49EACA5A1ACA6A3ADA9A6B0ACA9
B4B0ADB7B4B1BCB8B5C2BEBAC4C2BFBCBBB8B5B4B2ADAEADA6A7A79EA1A0969A9A8E9394868C8D\
7F8587777E806F777A
5F676A575E604F5557474C4D3F42433638382C2D2D2222221816150B090808050216100D251D18\
34282243342C554239665045755C5083675A927364A07E6DAA8776B28E7DBA9483
C29A87C99F8CCEA38FD3A793D3A793D5A995D8AB97DBAE99DDB09CDEB29EDBB29FD7B09FD3AF9F\
CDAD9EC8AC9FC1A99DBAA69CB3A39BAFA29BABA19CA9A29DA9A39FA9A5A2ACA8A5
AFACA9B1AFACB4B2B0BBB7B4B7B5B3B2B2B0ADADABA6A8A6A0A2A1999C9C9296968B9091848A8B\
7C8385757D7F6E7779
5F686A585F61505658484D4E404344373A3A2E2F302424251A19190E0D0D0502010B07051B1511\
2A211C382C26493A3258453C685248745C5082675A8F706299796AA28171A98778
B08D7CB89382BC9684C29B89C59E8BC8A08ECAA28FCDA592D0A694D0A896CEA997CBA898C8A798\
C4A598BEA498B8A197B3A097AC9E97A99D97A59D98A49E9AA49F9CA5A19FA7A4A2
AAA8A5ABA9A7AEADAAAEADABADACAAA9A9A8A5A6A59FA1A19A9D9C9498988E9293878D8E818788\
7A8283747C7E6D7678
5F686A586062515759494E50414547393C3D3032332728281D1D1D121111070505040201110E0B\
1F19152D24203E312B4B3C3558463E634F46725B507F6559876D61917568997C6E
A08173A98878AC8B7CB19080B59382B99685BB9887BE9A8AC09C8CC19E8EC09E8FBD9E8FBA9D90\
B79D90B39B91AD9A90A99991A59891A298929F98939E99959E9B989F9D9AA1A09E
A4A3A1A5A5A3A6A6A4A5A6A4A4A4A3A1A2A19D9F9F999C9B9498988F93948A8F8F848A8B7E8586\
798082737B7D6D7578
60686B59606352585A4A50524348493B3F403335362A2C2C2021221616170B0A0A010000080605\
15110F221C193027233E332D4B3D3655453E614F466E594F766157816A5F887064
8F766A967C6F9C8073A18476A5887AA98B7DAB8E7FAD9081B09384B09485B09487AD9387AA9387\
A79287A49188A091889D918A9C928C9A928D98928F9793909795939A99979E9D9B
A0A09EA0A09F9FA09F9E9F9E9C9E9D9A9C9B979A999397968F93938B8F90868B8C8187887C8384\
777E8071797C6C7577
60696B5A6164535A5C4C5254454A4C3E424336393B2D30312527271B1C1D101112040404000000\
0A0807171412241F1C3129253D332E453A3450433C5B4C4564544C6F5D5577645B
7E6A61846F658B746A8F786E937C709780749B83779D85799F887CA0897D9F8A7F9B887E9B897F\
98887F9487809287819088839089858F8A878E8B898F8D8B91908E919391959796
9B9E9D999B9A989A999799999598989396969194948E92928A8F8F868C8C8288897E8486798082\
757C7E70787B6B7477
61696C5B6365545C5E4E5556474D4F414647393E3F3235372A2C2E21232417191A0D0F0F020404\
0001010B0B0A18161525211F302A2738312E4038334A403B5247425C5049655851
6C5E5672635B7767607D6C6482706886746B8A786F8D7B718F7E74917F769181788D7F778A7E76\
877D76857D77837E79827F7B83807E8583818685848687868A8A898D8F8D919391
9294949295949194949194938F93938D91918B8F90898D8E868B8C8288897F85867B8283777E80\
737B7D6F777A6B7476
616A6D5C6466565E605057594A5052444A4B3D4244363B3C2F3334272B2C1F222316191A0E1010\
0405060204040C0E0E1A19182624222F2B2934302D3B3633423D3A4A4441544C47
5B524D615853675D576C615B71655F766A63796D667D71697F736C83776F847972827973807972\
7A7571777471777673777774797A787C7D7C7F807F818282828484878989898D8C
8B8E8E8B8F8F8B8F8F8A8E8F898E8E888D8D868B8C84898A8187887F85867C8284787F81757D7E\
717A7C6E76796A7376
626B6D5D6568586062535A5C4D5456484E504247493C4142353A3B2E3334272B2C202324181B1C\
10131407090A06090A1013131B1C1C2626252C2B2A312F2E3634333D3B3944423F
494744504C4956524F5B5653615B57665F5B6A635F6E6762706A64746D6878716D79736F78736F\
74726E747270737371737472737574767878787B7B7B7E7E7D8080828585838787
84888985898A858A8A858A8A84898A8388898187888085867D84857B8283798081767D7F737B7D\
70787A6D76786A7375
626B6E5E67695A6264555D5F50585A4C5254474D4F4147493C4143363B3C303436292E2F232728\
1C1F211418190B0F100B0F101418192022222728282B2D2C2E2F2F3435343B3C3B
40413F4445434748474C4C4B52514F5756545B5A57605E5B63615E6765616867646D6B686B6A68\
686A68676A69676B6B686D6C6A6E6E6C717272767675797A777B7C7B7F807D8282
7F84848085858085868085867F85867E84857D83847B82837A8082787F80767D7F737B7D71797B\
6E77796C7577697275
636C6F5F686B5C6467586062545B5E5057594C5254474E5042494A3E4345383E4033383A2D3234\
272C2E2126281B1F21121719101617161C1D222627292D2E2D31312F3232323636
363A3A3A3E3E3F4343424646444848494D4D505353565856595B5A5D5E5C5E6160646564636564\
616565616666616768636969656B6C666D6E6F747471767774797A767C7C787E7F
7A7F807B80817B81827B81827A81827A8082798081787F80767D7F757C7E737B7D71797B6F777A\
6D76786B7476697275
646D70616A6C5E66695B6365575F62545C5E51585A4D5456495052454C4E41484A3D4345393F40\
343A3C2F3536292F31242A2C1F25271A21231C2325262C2D2C3234313637333939
363C3C373D3F3A41423E454742494A454B4D4A50524E545554595A585C5C5A5E5E5C60605E6162\
5D62635C62635C64655E6566626869636A6A6A70716E737470767772797A747A7C
757C7D767D7E767D7E767D7F767D7F767D7E757C7E747B7D737B7C727A7C70787B6F77796D7678\
6C74776A7376687274
646E71626C6E60696B5E66695B6466596163565E60535B5D51585A4E55574B5254474E50444B4D\
4047493D4346393F42353C3E31383B2D3437282F322830332A333630383A373E40
3840413941423B44463F4749434A4C454D4F4850514A52544E5557505859555B5C575C5E595E5F\
5B5F615B60615D63645A60615C6364636A6B686E706B72736D74766F7678707779
71787A72797B727A7B727A7B727A7C72797B71797B70787B70787A6F77796E76796D75786C7477\
6A7376697275687174
656E71646D70626B6E616A6C5F686A5D66685C64675A6265586062565E60545C5E525A5C4F575A\
4D55574B5255485052454D50434B4D40484B3E46493D46493D45493A43473E4649
41494C41494C424A4C424A4D454E4F4B52544D55564F575952595B535A5C555C5E585E60596062\
5B6163565D5F5B61645E656761686A646B6D676E706971736B72746C74766D7577
6E75776E76786E76786E76796E76796E76786E76786D76786D75786C75776B74776B74766A7376\
697275687274677174
666F72656F71646E70646D70636C6F626B6E616A6D60696C5F686B5E676A5D66695C65675B6466\
5A6265596164576063565F61555D60545C5F535B5E525B5E525A5E515A5E525B5E
535C5F535B5F535C5F525A5E50595D515A5E525B5D535C5E545D60555E60565E60565E61586063\
5E66685F676A61696B626B6D646C6E656E70676F716870736971746972746A7275
6A73756A73756A73766A73766A73766A73766A73766A73756A7375697275697275697275687274\
687174677174677173
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooolO06M`Lal0J71c0`1Y
LG<406U`L``0JG1b101YL74306U_L0@0JFi^101ZL74<06UaL`<0JG9d301YLG@406UaL`/0J75c101X
LG@806QbM@@0JG=f101YM7L306UeN0@0JWEh101ZMWT406YgNP@0JWMk101[N7`406ajOP<0KWf1101/
NGd406]hN`@0JWMj101ZMWT406YeN0<0JGEh101YM7P406UdM`@0JG=f101XLgH706QbM@@0J79d101W
LG@406MaLaH0oooo000D0?oooal0Ig1c7`1XL7<306UaL`@0JG1c301YL78406U`L@<0JFm`101YKVh4
06Y`L@`0JG5c0`1YLW@<06UaM0@0JG5c2`1XLG<406QaM0P0J79e101YLgH406UdM`<0JGEh101ZMGP4
06YfN@@0JWMj101ZMg/406]hO0@0K7Yn0`1^OH4406aiO@@0JgQk101ZMgX406YfN@@0JWEh0`1YMGP4
06UdN0@0JGAg101YLgH406QcMPL0J79e101XLW@406MaM0@0Ig5c5P3oool001@0oooo7`1WL7<O06Q`
L`<0JG5c101YL7<<06U`LP@0JG1a0`1YKg0406U^KP@0JW1a301YLG<306UbM0`0JG5d101YLG<;06Qa
L`@0J75d201XLWD406UcMP@0JGAg0`1YMGP406YeN0@0JWIi101ZMgX406YgN`@0JgQl101/NWh306im
P@@0K7Um101[N7/406YgNP@0JWIi101ZMGP306UeN0@0JGAh101YM7L406UcMP@0J7=f1`1XLWD406Qb
M0@0Ig5d101WLG<F0?ooo`00503ooolO06M`Lal0J71c0`1YLG<406U`L``0JG1b101YL74306U_L0@0
JFi^101ZL74<06UaL`<0JG9d301YLG@406UaL`/0J75c101XLG@806QbM@@0JG=f101YM7L306UeN0@0
JWEh101ZMWT406YgNP@0JWMk101[N7`406ajOP<0KWf1101/NGd406]hN`@0JWMj101ZMWT406YeN0<0
JGEh101YM7P406UdM`@0JG=f101XLgH706QbM@@0J79d101WLG@406MaLaH0oooo000D0?ooo`P0Ig1c
101WLG<306M`L`@0J71c101XLG<806Q`L`@0J75c2`1YLG<406UaLP`0JW5b0`1ZLG<<06]aLP@0K71a
101/L70306a_K`@0Jfe/101/L70406aaLP@0K79d101[LW@306]cM0@0Jg9d201ZLW@406]bM0@0JW=d
2`1ZLgD406YdM`@0JWEh101[MgT406]hN`<0K7Ul101]NWh406elO`@0KGf1101^Oh<406n1Q@@0LH:8
0`1bQ8T40721QP@0Kgn3101^OH4406ekP0@0KGYn0`1/NGd406ahO0@0JgQk101[MgX406YfN@@0JWEh
0`1YM7L406QcMP@0J79e101WLG@F0?ooo`00503oool806M`L`@0Ig5c0`1WL7<406Q`L`@0J75c201X
L7<406QaL`/0JG5c101YLG8<06YaLP<0JW5c301[LG8406a`L@@0K71`0`1/Kfl406]]K0@0K71`101/
LG8406abM0@0Jg9d0`1[Lg@406]bM0P0JW9d101[LW@406YcM0/0JW=e101ZM7L406YeN0@0JgMi101[
N7/306aiO0@0KGYn101]O7l406emP@@0KWn3101_PHD40762R0<0LXB9101`PHH406moP`@0KWf1101]
Nh0406ejOP<0K7Um101/N7`406]hN`@0JgMj101ZMWT406YeN0<0JGAg101XLgH406QbM@@0Ig5d5P3o
ool001@0oooo201WL7<406MaL`<0Ig1c101XL7<406QaL`P0J71c101XLG<;06UaL`@0JG5b301ZLG83
06YaL``0Jg5b101/L74406a`L0<0K6m_101[KF`406a`L0@0K75b101/LW@406]bM0<0Jg=d101[LW@8
06YbM0@0Jg9d101ZLg@;06YcM@@0JWAg101ZMGP406]gN@@0JgQk0`1/NG`406ejOP@0KGao101]OH44
06ioP`@0Kh65101aPXP307:4R@@0L866101_Oh<406imP@@0KG^0101]NWh306aiO@@0K7Ql101[N7/4
06]gNP@0JWIi101ZMGP306UdM`@0J7=f101XLWD406MaM1H0oooo000D0?ooo`P0Ig1c101WLG<306M`
L`@0J71c101XLG<806Q`L`@0J75c2`1YLG<406UaLP`0JW5b0`1ZLG<<06]aLP@0K71a101/L70306a_
K`@0Jfe/101/L70406aaLP@0K79d101[LW@306]cM0@0Jg9d201ZLW@406]bM0@0JW=d2`1ZLgD406Yd
M`@0JWEh101[MgT406]hN`<0K7Ul101]NWh406elO`@0KGf1101^Oh<406n1Q@@0LH:80`1bQ8T40721
QP@0Kgn3101^OH4406ekP0@0KGYn0`1/NGd406ahO0@0JgQk101[MgX406YfN@@0JWEh0`1YM7L406Qc
MP@0J79e101WLG@F0?ooo`00503oool406M`L`@0Ig1b101XL7<306QaL`@0J71b101XL7<406U`L`@0
JG1b101YLG<306YaLP@0JW5c101ZLG8<06]aLPL0K75b201]LG8806iaL@@0KW1`0`1_Kfh406m^K0@0
Kg5`101_LW8806icM0L0KGAe201/Lg@406ecM0@0K7=d101ZM7D306YdMP@0JWEg101[MWP406]gN@@0
K7Yl101]O7l306mnP@@0L823101aPHD40764R0@0LXJ;101dR8h407F;TP<0MHZ@101dQhd407>5RP@0
LX>8101aPHH4071oQ0<0Kgj2101^OH4406ekO`@0KGYn101/N7`406]gNP<0JWIi101YM7L406QcMP@0
J79d5P3oool001@0oooo101WL7<406M`LP@0J71c0`1XLG<406Q`LP@0J71c101YL7<406U`LP@0JG5c
0`1ZLG8406YaL`@0JW5b301[LG8706aaLPP0KG5b201^LG4406i`L0<0Kfm^101_KV`406maL0@0Kg9b
201^Lg@706edM@P0K7=d101]Lg@406acM0@0JWAe0`1ZM7H406YeM`@0JgIh101[MgT406ajO0@0KGao
0`1_OX440720P`@0LH65101aQ8P407:6R`@0M8R>101eRi8307F:T0@0M8N=101cQHX407:3R0@0LH66
101`Oh@306mnPP@0KWf1101]Ngl406ejOP@0K7Ql101[MgX306YfN@@0JGAg101XLgH406QbM1H0oooo
000D0?ooo`@0Ig1c101WL78406Q`L`<0J75c101XL78406Q`L`@0JG1c101YL78406UaL`<0JW5b101Z
LG<406YaLP`0Jg5b1`1/LG8806eaLPP0KW5a101^L70306m_KP@0Kfi/101_LG0406mbLPP0KW=d1`1]
M7D806acM0@0KG=d101/Lg@406YdM@<0JWAf101ZMGL406]fN0@0JgMi101/NW`406elO`<0Kgj1101`
P8<40761Q@@0LHB8101bQX/407B8SP@0MH^B0`1eRY0407B7S@@0LhF:101bPhP40761QP@0L7n40`1_
OX8406imP@@0KG]o101]NWh406ahO0@0JgMj0`1ZMWT406UdM`@0J7=f101XLW@F0?ooo`00503oool4
06M`L`@0Ig1b101XL7<306QaL`@0J71b101XL7<406U`L`@0JG1b101YLG<306YaLP@0JW5c101ZLG8<
06]aLPL0K75b201]LG8806iaL@@0KW1`0`1_Kfh406m^K0@0Kg5`101_LW8806icM0L0KGAe201/Lg@4
06ecM0@0K7=d101ZM7D306YdMP@0JWEg101[MWP406]gN@@0K7Yl101]O7l306mnP@@0L823101aPHD4
0764R0@0LXJ;101dR8h407F;TP<0MHZ@101dQhd407>5RP@0LX>8101aPHH4071oQ0<0Kgj2101^OH44
06ekO`@0KGYn101/N7`406]gNP<0JWIi101YM7L406QcMP@0J79d5P3oool001@0oooo101WL7<406M`
LP@0J71b0`1XLG<406U`L`P0JG1b101ZL78406YaLP<0Jg1b101[LG8806aaLPP0KG5b1`1^LG8406ma
LP@0Kg9a101`LW44075aL@@0LG5`0`1bL6h4075_K0@0LW9`101bLg<4075dM0@0LGEe0`1`MGD406md
M@@0KGAd101/Lg<406abLP@0K75c101ZLg<306]eMP@0JgIh101[N7X406ajO0@0KGeo101_Oh830722
Q@@0LXB8101dQh/407F:S`@0MXfB101hT9L407ZDW0<0NI6H101hSY@407J;T@@0MHV>101dQX`407>4
R@<0LX:7101aP8D4071oP`@0Kgf1101^Ngl406aiO@<0JgMk101ZMWT406UdM`@0J79e5P3oool001@0
oooo101WL7<406M`LP@0J71b0`1XLG<406U`L`P0JG1b101ZL78406YaLP<0Jg1b101[LG8806aaLPP0
KG5b1`1^LG8406maLP@0Kg9a101`LW44075aL@@0LG5`0`1bL6h4075_K0@0LW9`101bLg<4075dM0@0
LGEe0`1`MGD406mdM@@0KGAd101/Lg<406abLP@0K75c101ZLg<306]eMP@0JgIh101[N7X406ajO0@0
KGeo101_Oh830722Q@@0LXB8101dQh/407F:S`@0MXfB101hT9L407ZDW0<0NI6H101hSY@407J;T@@0
MHV>101dQX`407>4R@<0LX:7101aP8D4071oP`@0Kgf1101^Ngl406aiO@<0JgMk101ZMWT406UdM`@0
J79e5P3oool001@0oooo101WL7<406M`LP@0J71b0`1XLG<406U`L`P0JG1b101ZL78406YaLP<0Jg1b
101[LG8806aaLPP0KG5b1`1^LG8406maLP@0Kg9a101`LW44075aL@@0LG5`0`1bL6h4075_K0@0LW9`
101bLg<4075dM0@0LGEe0`1`MGD406mdM@@0KGAd101/Lg<406abLP@0K75c101ZLg<306]eMP@0JgIh
101[N7X406ajO0@0KGeo101_Oh830722Q@@0LXB8101dQh/407F:S`@0MXfB101hT9L407ZDW0<0NI6H
101hSY@407J;T@@0MHV>101dQX`407>4R@<0LX:7101aP8D4071oP`@0Kgf1101^Ngl406aiO@<0JgMk
101ZMWT406UdM`@0J79e5P3oool001@0oooo101WL7<806Q`LPL0JG1b201ZL78406]`LP@0Jg5b1`1/
LG8806eaLP@0KW5b101_LG8406maL@<0L79a201aLW44079bL@@0Lg9a101dLW0307EbK`@0MG1]101e
Lg4407EdM0@0M7Ef101cMWH3079fMP@0LGIf101`MGH406mdM@P0KW=d101]Lg@306eeMP@0KGMi101]
NG`406elOP@0KWj1101`PhH307:6RP@0M8V=101gS94407V@UP@0NYBJ101lUih407jKX`<0OINO101k
U9/407ZAV0@0NHjE101gS98407J9S`<0MHN<101cQ8T407:2Q`@0LH24101_OX8406ikO`<0K7Um101[
MgX406YeN0@0J79e5P3oool001@0oooo101WL7<806Q`LPL0JG1b201ZL78406]`LP@0Jg5b1`1/LG88
06eaLP@0KW5b101_LG8406maL@<0L79a201aLW44079bL@@0Lg9a101dLW0307EbK`@0MG1]101eLg44
07EdM0@0M7Ef101cMWH3079fMP@0LGIf101`MGH406mdM@P0KW=d101]Lg@306eeMP@0KGMi101]NG`4
06elOP@0KWj1101`PhH307:6RP@0M8V=101gS94407V@UP@0NYBJ101lUih407jKX`<0OINO101kU9/4
07ZAV0@0NHjE101gS98407J9S`<0MHN<101cQ8T407:2Q`@0LH24101_OX8406ikO`<0K7Um101[MgX4
06YeN0@0J79e5P3oool001@0oooo101WL7<806Q`LPL0JG1b201ZL78406]`LP@0Jg5b1`1/LG8806ea
LP@0KW5b101_LG8406maL@<0L79a201aLW44079bL@@0Lg9a101dLW0307EbK`@0MG1]101eLg4407Ed
M0@0M7Ef101cMWH3079fMP@0LGIf101`MGH406mdM@P0KW=d101]Lg@306eeMP@0KGMi101]NG`406el
OP@0KWj1101`PhH307:6RP@0M8V=101gS94407V@UP@0NYBJ101lUih407jKX`<0OINO101kU9/407ZA
V0@0NHjE101gS98407J9S`<0MHN<101cQ8T407:2Q`@0LH24101_OX8406ikO`<0K7Um101[MgX406Ye
N0@0J79e5P3oool001@0oooo101WL7<806Q`LPL0JG1b201ZL78406]`LP@0Jg5b1`1/LG8806eaLP@0
KW5b101_LG8406maL@<0L79a201aLW44079bL@@0Lg9a101dLW0307EbK`@0MG1]101eLg4407EdM0@0
M7Ef101cMWH3079fMP@0LGIf101`MGH406mdM@P0KW=d101]Lg@306eeMP@0KGMi101]NG`406elOP@0
KWj1101`PhH307:6RP@0M8V=101gS94407V@UP@0NYBJ101lUih407jKX`<0OINO101kU9/407ZAV0@0
NHjE101gS98407J9S`<0MHN<101cQ8T407:2Q`@0LH24101_OX8406ikO`<0K7Um101[MgX406YeN0@0
J79e5P3oool001@0oooo101WL7<406Q`L`@0J71b0`1YL78406Y`LP@0JW5b201[LG8406aaLPL0KG5b
101^LG4806maL@@0L75a101aLW43079bL@@0Lg9a101dLg4407EcL@@0MWAb101gM78307UdL@@0NGA`
101iMG<407QfM@@0MgMf101fMgP307EhN0@0M7Qh101cMgP4079gM`@0LGMg101`MWH4071fM`<0KgMh
101`NW`4071lOP@0LGn2101aPXD407>6R@<0MH^?101gSY<407ZBU`@0OIJL101nVZ44086NYP@0PJ2X
0`20WJD407nJXP@0OINN101lU9/407^AU`@0NHjD0`1hRi4407J8SP@0M8J;101cPhP40760Q@@0Kgj2
0`1^Ngl406ahO0@0JWIi101XLgHF0?ooo`00503oool406M`L`@0J71c101XL78306U`LP@0JW1b101Z
LG8806]aLP@0K75b1`1]LG8406iaL@P0Kg5a101`LG44075bL@<0LW9a101cLW4407AcL@@0MG=a101f
M78407MdLP<0NGAa101iM70407UeL`@0N7Ie101gMgH407IgN0<0MGQh101dN7P407=gN0@0LWMg101a
MgL4071fMP@0L7Ig0`1_MgP4071jO0@0L7an101aOh840762Q@@0LhJ90`1eRhl407N>T`@0NY:G101m
UY`407jJX@@0PIjV1021X:P3082MY@@0OiZR101mUih407bDV`@0Ni6G101iSY@307R;T@@0MXR>101d
QX/407>3R0@0LH25101_OX8306ikO`@0K7Ql101ZMWT406QcMQH0oooo000D0?ooo`@0Ig1c101XL7<4
06Q`LP<0JG1b101ZL78406YaLPP0Jg5b101/LG8706eaLP@0KW5a201_LG44071aL@@0LG9a0`1bLW44
07=bL@@0M7=a101eLg4407IdLP@0MgAb0`1iM74407UdL0@0NGEc101hMWD407MgMP@0MWMh0`1eN7P4
07AhN0@0LgMh101bMgL4075gM`@0L7If101`MWL306mgN0@0L7Yl101`O7h4075oPP@0LH:5101cQXT3
07F;S`@0MhjC101jTYL407fFW0@0OYZQ1021WZH4086PZ0<0P9fU101oVZ8407fGWP@0O9BK101kTIL4
07V>U0<0N8^A101fR8h407B6R`@0Lh>8101aP8D406mnPP<0KW]o101/N7`406YfN@@0J7=f5P3oool0
01@0oooo101WL7<406Q`L`@0J71b0`1YL78406Y`LP@0JW5b201[LG8406aaLPL0KG5b101^LG4806ma
L@@0L75a101aLW43079bL@@0Lg9a101dLg4407EcL@@0MWAb101gM78307UdL@@0NGA`101iMG<407Qf
M@@0MgMf101fMgP307EhN0@0M7Qh101cMgP4079gM`@0LGMg101`MWH4071fM`<0KgMh101`NW`4071l
OP@0LGn2101aPXD407>6R@<0MH^?101gSY<407ZBU`@0OIJL101nVZ44086NYP@0PJ2X0`20WJD407nJ
XP@0OINN101lU9/407^AU`@0NHjD0`1hRi4407J8SP@0M8J;101cPhP40760Q@@0Kgj20`1^Ngl406ah
O0@0JWIi101XLgHF0?ooo`00503oool406M`L`@0J71c1`1YL78406YaLP@0Jg5b201/LG8406eaLPL0
KW5a101_LG44071aL@@0LG5a201bLW4307=bL@@0M7=a101fLg4407MdL@@0NGEb101kMW<307ehM@@0
OWUf101lN7H407]hM`@0NWUh101iNGT307QiN@@0MgYi101fNWX407EiNP@0MGYj101dNWX407AkN`<0
Lgal101cOWl407>0PP@0M8>6101eQXX407J;SP<0N8nC101kU9T407jHWP@0P9bS1022XJT408JV[`@0
QJF_0`24Xj/408>PZ0@0PIbT1020VJ4407jFW@@0O9>I0`1jSiH407V<TP@0MhV?101eQX/407>3R0@0
LH240`1_OH4406ejOP@0JgMj101YLgHF0?ooo`00503oool406M`L`@0J71c1`1YL78406YaLP@0Jg5b
201/LG8406eaLPL0KW5a101_LG44071aL@@0LG5a201bLW4307=bL@@0M7=a101fLg4407MdL@@0NGEb
101kMW<307ehM@@0OWUf101lN7H407]hM`@0NWUh101iNGT307QiN@@0MgYi101fNWX407EiNP@0MGYj
101dNWX407AkN`<0Lgal101cOWl407>0PP@0M8>6101eQXX407J;SP<0N8nC101kU9T407jHWP@0P9bS
1022XJT408JV[`@0QJF_0`24Xj/408>PZ0@0PIbT1020VJ4407jFW@@0O9>I0`1jSiH407V<TP@0MhV?
101eQX/407>3R0@0LH240`1_OH4406ejOP@0JgMj101YLgHF0?ooo`00503oool406M`L`@0J71c1`1Y
L78406YaLP@0Jg5b201/LG8406eaLPL0KW5a101_LG44071aL@@0LG5a201bLW4307=bL@@0M7=a101f
Lg4407MdL@@0NGEb101kMW<307ehM@@0OWUf101lN7H407]hM`@0NWUh101iNGT307QiN@@0MgYi101f
NWX407EiNP@0MGYj101dNWX407AkN`<0Lgal101cOWl407>0PP@0M8>6101eQXX407J;SP<0N8nC101k
U9T407jHWP@0P9bS1022XJT408JV[`@0QJF_0`24Xj/408>PZ0@0PIbT1020VJ4407jFW@@0O9>I0`1j
SiH407V<TP@0MhV?101eQX/407>3R0@0LH240`1_OH4406ejOP@0JgMj101YLgHF0?ooo`00503oool4
06M`L`@0J71c1`1YL78406YaLP@0Jg5b201/LG8406eaLPL0KW5a101_LG44071aL@@0LG5a201bLW43
07=bL@@0M7=a101fLg4407MdL@@0NGEb101kMW<307ehM@@0OWUf101lN7H407]hM`@0NWUh101iNGT3
07QiN@@0MgYi101fNWX407EiNP@0MGYj101dNWX407AkN`<0Lgal101cOWl407>0PP@0M8>6101eQXX4
07J;SP<0N8nC101kU9T407jHWP@0P9bS1022XJT408JV[`@0QJF_0`24Xj/408>PZ0@0PIbT1020VJ44
07jFW@@0O9>I0`1jSiH407V<TP@0MhV?101eQX/407>3R0@0LH240`1_OH4406ejOP@0JgMj101YLgHF
0?ooo`00503oool406M`L`@0J71c101YL78306YaLPP0Jg5b101/LG8406eaL@@0KW5a0`1_LG48071a
L@@0LG5a101bLW4407=bL@@0M79a0`1eLW4407IcL@@0Mg=a101iM74407YeLP@0OWMd0`25OGT4089k
N0@0OgYh101nNWP407ajN@@0O7]j0`1kO7/407YkN`@0NGal101iOGd407QmO@@0N7in101gOgl307N1
P@@0N8>4101hQXL407V9R`@0NH^>101kSi<307fDV@@0OiRN1021WJ@408FRZP@0QjN`102:[KP408V[
]@<0R:Vb1026YZl408FRZ`@0PinW1021Vj<407nGW`<0OIBJ101kT9H407V=TP@0MhV>101eQHX407:2
QP<0L7j2101^Ngl406]gN`@0JGAg5P3oool001@0oooo101WL7<406Q`L`@0JG1b0`1ZLG8806]aLP@0
K75b101]LG4406iaL@<0Kg5a201`LG44075aL@@0LW9a101cLW4407AbL@<0MG9a101fLg4407McL@@0
NGAa101jMG8407igM0<0QGei1022NgP407mjN0@0OWYh101lNWT407akNP<0Ngak101jNg/407UlO0@0
NGem101hOGd407QnOP@0Mgmo0`1gPH4407R3Q0@0N8J7101iRH/407V;SP@0NhnC0`1mU9T407nHWP@0
PIfT1025XZX408NW/0@0RZfh1029ZkD308RY/P@0QZJ_1025XZ/408>OY`@0PI^S101oUil307fDVP@0
Ni2F101iSI8407N9SP@0MHF:101bPXH3071nPP@0KW]o101[Mg/406UdMaH0oooo000D0?ooo`@0Ig1c
101XL7<406U`LP<0JW5b201[LG8406aaLP@0KG5a101^LG4306maL@P0L75a101aLG44079bL@@0Lg9a
101dLW4307EbL@@0MW=a101gLg4407UdL@@0NWEb101nMg@308EmN@@0PW]h101oNWP407ijN0@0O7Yi
101lNgX307]lN`@0NW]k101iO7`407UmO@@0N7em101hOWh407MoO`<0Mh61101hPh@407R6Q`@0NHV;
101iRhh407^?T`<0OIBI101oV9h4086MY0@0QJ:Z1027Yk0408Z]^0@0RJ^e0`28ZK8408JV[`@0QJ:[
1023WjL4086KX`@0OiNO0`1mU9X407^@UP@0NHfB101gRHh407F5RP@0LX:60`1`OX8406ikO`@0JgMk
101YM7LF0?ooo`00503oool406M`L`@0J71c101YL78306YaLPP0Jg5b101/LG8406eaL@@0KW5a0`1_
LG48071aL@@0LG5a101bLW4407=bL@@0M79a0`1eLW4407IcL@@0Mg=a101iM74407YeLP@0OWMd0`25
OGT4089kN0@0OgYh101nNWP407ajN@@0O7]j0`1kO7/407YkN`@0NGal101iOGd407QmO@@0N7in101g
Ogl307N1P@@0N8>4101hQXL407V9R`@0NH^>101kSi<307fDV@@0OiRN1021WJ@408FRZP@0QjN`102:
[KP408V[]@<0R:Vb1026YZl408FRZ`@0PinW1021Vj<407nGW`<0OIBJ101kT9H407V=TP@0MhV>101e
QHX407:2QP<0L7j2101^Ngl406]gN`@0JGAg5P3oool001@0oooo101XL7<406Q`LP@0JG1b0`1ZLG84
06]aLP@0K75b101]LG8406iaL@@0Kg5a0`1`LG48075aL@@0LW9`101cLW0407AbL0@0MG9`0`1gLg04
07QcL0@0NG=a101jM74407]dL@@0OGEa0`29P7/408AmN@@0PGaj1020NgX407mlN`@0OWak0`1mOGd4
07enO@@0O7im101kOgh407^0O`@0Nh61101kQ8<307^7QP@0O8V9101lRh`407f>T0@0OY6C101oU9P3
086IWP@0PifS1025XjX408VY/@@0S:jh102?]L0408fb_@<0S:nj102:[;H408VX/@@0QjB]1025X:P4
08:LY0<0P9RO101nU9/407^@UP@0NHbB101fR8d407B4R@<0LH24101_O80406ahO0@0JGAg5P3oool0
01@0oooo101XL7<406Q`LP@0JG1b0`1ZLG8406]aLP@0K75b101]LG8406iaL@@0Kg5a0`1`LG48075a
L@@0LW9`101cLW0407AbL0@0MG9`0`1gLg0407QcL0@0NG=a101jM74407]dL@@0OGEa0`29P7/408Am
N@@0PGaj1020NgX407mlN`@0OWak0`1mOGd407enO@@0O7im101kOgh407^0O`@0Nh61101kQ8<307^7
QP@0O8V9101lRh`407f>T0@0OY6C101oU9P3086IWP@0PifS1025XjX408VY/@@0S:jh102?]L0408fb
_@<0S:nj102:[;H408VX/@@0QjB]1025X:P408:LY0<0P9RO101nU9/407^@UP@0NHbB101fR8d407B4
R@<0LH24101_O80406ahO0@0JGAg5P3oool001@0oooo101XL7<406Q`LP@0JG1b0`1ZLG8406]aLP@0
K75b101]LG8406iaL@@0Kg5a0`1`LG48075aL@@0LW9`101cLW0407AbL0@0MG9`0`1gLg0407QcL0@0
NG=a101jM74407]dL@@0OGEa0`29P7/408AmN@@0PGaj1020NgX407mlN`@0OWak0`1mOGd407enO@@0
O7im101kOgh407^0O`@0Nh61101kQ8<307^7QP@0O8V9101lRh`407f>T0@0OY6C101oU9P3086IWP@0
PifS1025XjX408VY/@@0S:jh102?]L0408fb_@<0S:nj102:[;H408VX/@@0QjB]1025X:P408:LY0<0
P9RO101nU9/407^@UP@0NHbB101fR8d407B4R@<0LH24101_O80406ahO0@0JGAg5P3oool001@0oooo
101XL7<406Q`LP@0JG1b0`1ZLG8406]aLP@0K75b101]LG8406iaL@@0Kg5a0`1`LG48075aL@@0LW9`
101cLW0407AbL0@0MG9`0`1gLg0407QcL0@0NG=a101jM74407]dL@@0OGEa0`29P7/408AmN@@0PGaj
1020NgX407mlN`@0OWak0`1mOGd407enO@@0O7im101kOgh407^0O`@0Nh61101kQ8<307^7QP@0O8V9
101lRh`407f>T0@0OY6C101oU9P3086IWP@0PifS1025XjX408VY/@@0S:jh102?]L0408fb_@<0S:nj
102:[;H408VX/@@0QjB]1025X:P408:LY0<0P9RO101nU9/407^@UP@0NHbB101fR8d407B4R@<0LH24
101_O80406ahO0@0JGAg5P3oool001@0oooo101XL7<406U`LP@0JW1b0`1[LG8406aaLP@0KG5b101^
LG4406maL@@0L75a0`1aLG44079aL0@0Lg5`101dLW0407EbL0@0MW9`101gLW0307QcL0@0NG=`101j
Lg0407]dL0@0Ng=`101oMW<308AkN0@0Q7ai1023OGX4089mN`P0PGim0`20Ogh40820O`@0Oh1o101n
P80407j1P@@0OX>3101nQhH307j:R@@0Ohj=1020TI44086CU@@0PYJH1024VYd308JNX`@0Qj>X1029
Yjh408b]]@@0Sk>m102B^lH409:jaP<0T;K1102>/[d408f^^0@0RZZc1028YZh408JQZ@<0PifT1021
V9l407jDVP@0NhnE101hRi0407F6R`<0Lh:6101`OH4406eiO@@0JWEh5P3oool001@0oooo101XL7<4
06U`LP@0JW1b0`1[LG8406aaLP@0KG5b101^LG4406maL@@0L75a0`1aLG44079aL0@0Lg5`101dLW04
07EbL0@0MW9`101gLW0307QcL0@0NG=`101jLg0407]dL0@0Ng=`101oMW<308AkN0@0Q7ai1023OGX4
089mN`P0PGim0`20Ogh40820O`@0Oh1o101nP80407j1P@@0OX>3101nQhH307j:R@@0Ohj=1020TI44
086CU@@0PYJH1024VYd308JNX`@0Qj>X1029Yjh408b]]@@0Sk>m102B^lH409:jaP<0T;K1102>/[d4
08f^^0@0RZZc1028YZh408JQZ@<0PifT1021V9l407jDVP@0NhnE101hRi0407F6R`<0Lh:6101`OH44
06eiO@@0JWEh5P3oool001@0oooo101XL7<406U`LP@0JW1b0`1[LG8406aaLP@0KG5b101^LG4406ma
L@@0L75a0`1aLG44079aL0@0Lg5`101dLW0407EbL0@0MW9`101gLW0307QcL0@0NG=`101jLg0407]d
L0@0Ng=`101oMW<308AkN0@0Q7ai1023OGX4089mN`P0PGim0`20Ogh40820O`@0Oh1o101nP80407j1
P@@0OX>3101nQhH307j:R@@0Ohj=1020TI44086CU@@0PYJH1024VYd308JNX`@0Qj>X1029Yjh408b]
]@@0Sk>m102B^lH409:jaP<0T;K1102>/[d408f^^0@0RZZc1028YZh408JQZ@<0PifT1021V9l407jD
VP@0NhnE101hRi0407F6R`<0Lh:6101`OH4406eiO@@0JWEh5P3oool001@0oooo101XL7<406U`LP@0
JW1b0`1[LG8406aaLP@0KG5a101^LG4406maL@@0L75a0`1bLG0407=aL0@0M75`101eLW0407IbL0@0
Mg9`101hLW0307YcL0@0Ng=`101lLg0407edL0@0OgEa1021Mg<308=jMP@0Q7ai1024OG/408AnO0@0
Q7mn1023P80308>1P0@0PX611022PX440862P@@0P8:11020QXD4082:R0<0PHj<1022TY0408>FU@@0
Q9RH1026Vid408ROX@<0RZ>W102<Yjd408f//`@0Sk6i102B]l4409FobP@0Ul;>0`2E_LT409>ia0@0
TKBo102>/;T408b[]0@0RJJ^0`26XJT408BLX`@0PINN101mTYP407Z=T`@0MhR=0`1dQ8P4075oP`@0
KGYn101ZMGPF0?ooo`00503oool406Q`L`@0JG1b101ZL78306]aLP@0K75b101]LG4406iaL@@0Kg5a
101`LG43079aL0@0Lg5`101dLG0407EbL0@0MW9`101gLW0407QbL0<0NW=`101kLg0407acL0@0OGA`
101oMG44085gL`<0PgYf1024O7T408AmN`@0Q7il1024Ogh408>0P0<0Ph601022PH4408:2P@@0PH:1
1020PX440826Q@@0P8Z80`21SX`408:BT0@0PiJE1024V9P408JKW@@0R9nQ0`2:XjL408bW[@@0SJbc
102?/KT409:g`@@0UKo:102G`/h309Fmb@@0TkW4102A];l408j`^@@0S:^d1029YZh308JQZ@@0Q9bS
1021Uih407fBV0@0NXfC101gR8d307B4R0@0LGn3101]NWh406YeN1H0oooo000D0?ooo`@0J71c101Y
L78406Y`LP<0Jg5b101/LG8406eaL@@0KW5a101_LG44071aL@<0LW5`101cLG0407AaL0@0MG9`101f
LW0407MbL0@0N79`0`1jLg0407]cL0@0O7=`101mM70407meL@@0PGMc0`23NWH408AlN@@0Q7ek1024
OW`408AoOP@0Ph200`23PH0408:1P@@0PX:11021PX440822P@@0P8J51020RXP3086>S0@0PY:@1023
UYD408BHV0@0QY^M1028Wj4308ZSY`@0S:N]102=[;<408na^@@0T[O1102E_lX409O2cP<0UKg9102C
^L@4096d_`@0S[2i102<Zk@408VV[P<0QZ6Y1024W:<4086GWP@0OI:H101jSI<407N8S@<0M8B8101a
Oh<406ejOP@0JWEh5P3oool001@0oooo101XL7<406U`LP@0JW1b0`1[LG8406aaLP@0KG5a101^LG44
06maL@@0L75a0`1bLG0407=aL0@0M75`101eLW0407IbL0@0Mg9`101hLW0307YcL0@0Ng=`101lLg04
07edL0@0OgEa1021Mg<308=jMP@0Q7ai1024OG/408AnO0@0Q7mn1023P80308>1P0@0PX611022PX44
0862P@@0P8:11020QXD4082:R0<0PHj<1022TY0408>FU@@0Q9RH1026Vid408ROX@<0RZ>W102<Yjd4
08f//`@0Sk6i102B]l4409FobP@0Ul;>0`2E_LT409>ia0@0TKBo102>/;T408b[]0@0RJJ^0`26XJT4
08BLX`@0PINN101mTYP407Z=T`@0MhR=0`1dQ8P4075oP`@0KGYn101ZMGPF0?ooo`00503oool406Q`
L`@0JG1b101ZL78306]`LP@0KG5a101^LG4406maL@@0L75a101aLG03079aL0@0M75`101eLG0407Ib
K`@0Mg9_101iLVl407YbK`<0Ng=_101mLfl407idK`@0O79]1022Mg<408=iM@<0Q7Yg1025O7T408Em
N`@0QWim1026PGl408J2PP<0QX>32025Ph<408B4P`@0PX611022Q8<408:7Q`<0Ph^;1024Shl408JF
UP@0Qi^K102:Wj0408bSY@<0SZNZ102@Zk0409:_]P@0TkBl102E^L<409Nob`@0V/KB0`2Ja]<409O0
c0@0UK_6102B]L04092`^P@0SJ^d0`2:YJh408NPZ0@0Pi^R1020UI`407b@UP@0NHZ?0`1eQHX407:0
Q0@0KW]n101ZMGTF0?ooo`00503oool406Q`L`@0JG1b101ZL78306]`LP@0KG5a101^LG4406maL@@0
L75a101aLG03079aL0@0M75`101eLG0407IbK`@0Mg9_101iLVl407YbK`<0Ng=_101mLfl407idK`@0
O79]1022Mg<408=iM@<0Q7Yg1025O7T408EmN`@0QWim1026PGl408J2PP<0QX>32025Ph<408B4P`@0
PX611022Q8<408:7Q`<0Ph^;1024Shl408JFUP@0Qi^K102:Wj0408bSY@<0SZNZ102@Zk0409:_]P@0
TkBl102E^L<409Nob`@0V/KB0`2Ja]<409O0c0@0UK_6102B]L04092`^P@0SJ^d0`2:YJh408NPZ0@0
Pi^R1020UI`407b@UP@0NHZ?0`1eQHX407:0Q0@0KW]n101ZMGTF0?ooo`00503oool406Q`L`@0JG1b
101ZL78306]`LP@0KG5a101^LG4406maL@@0L75a101aLG03079aL0@0M75`101eLG0407IbK`@0Mg9_
101iLVl407YbK`<0Ng=_101mLfl407idK`@0O79]1022Mg<408=iM@<0Q7Yg1025O7T408EmN`@0QWim
1026PGl408J2PP<0QX>32025Ph<408B4P`@0PX611022Q8<408:7Q`<0Ph^;1024Shl408JFUP@0Qi^K
102:Wj0408bSY@<0SZNZ102@Zk0409:_]P@0TkBl102E^L<409Nob`@0V/KB0`2Ja]<409O0c0@0UK_6
102B]L04092`^P@0SJ^d0`2:YJh408NPZ0@0Pi^R1020UI`407b@UP@0NHZ?0`1eQHX407:0Q0@0KW]n
101ZMGTF0?ooo`00503oool406Q`L`@0JG1b101ZL78306]`LP@0KG5a101^LG4406maL@@0L75a101a
LG03079aL0@0M75`101eLG0407IbK`@0Mg9_101iLVl407YbK`<0Ng=_101mLfl407idK`@0O79]1022
Mg<408=iM@<0Q7Yg1025O7T408EmN`@0QWim1026PGl408J2PP<0QX>32025Ph<408B4P`@0PX611022
Q8<408:7Q`<0Ph^;1024Shl408JFUP@0Qi^K102:Wj0408bSY@<0SZNZ102@Zk0409:_]P@0TkBl102E
^L<409Nob`@0V/KB0`2Ja]<409O0c0@0UK_6102B]L04092`^P@0SJ^d0`2:YJh408NPZ0@0Pi^R1020
UI`407b@UP@0NHZ?0`1eQHX407:0Q0@0KW]n101ZMGTF0?ooo`00503oool406Q`L`@0JG1b101[L783
06a`L@@0KG5a101^LG44071aL@@0LG5`101bLG0307=aL0@0MG5_101fLFl407MbK`@0N79_101jLVl4
07]bK`<0OG=_101nLfl4081dK`@0RWag1027NWH408IjMP<0QW]h1027O7T408MmNP@0Qgil1028PH04
08V4P`L0RHF41028Q8@408N4Q0@0QH:21024P84408B3Q0<0Q8F61025RH/408RBU0@0RYZK102=XJ44
092VZ0<0TZZ]102D[[@409Jb^@@0U[Jn102G^/@409W0b`@0VlGB0`2Mb]L409_6d`@0VL7=102G^lH4
09Bf`0@0TK2i0`2=Z[8408ZT[0@0QYjU1022V9l407jBV0@0NXfB0`1fQh`407>1QP@0Kgao101[MWTF
0?ooo`00503oool406Q`L`@0JG1b101[L78306a`L@@0KG5a101^LG44071aL@@0LG5`101bLG0307=a
L0@0MG5_101fLFl407MbK`@0N79_101jLVl407]bK`<0OG=_101nLfl4081dK`@0RWag1027NWH408Ij
MP<0QW]h1027O7T408MmNP@0Qgil1028PH0408V4P`L0RHF41028Q8@408N4Q0@0QH:21024P84408B3
Q0<0Q8F61025RH/408RBU0@0RYZK102=XJ44092VZ0<0TZZ]102D[[@409Jb^@@0U[Jn102G^/@409W0
b`@0VlGB0`2Mb]L409_6d`@0VL7=102G^lH409Bf`0@0TK2i0`2=Z[8408ZT[0@0QYjU1022V9l407jB
V0@0NXfB0`1fQh`407>1QP@0Kgao101[MWTF0?ooo`00503oool406Q`L`@0JG1b101[L78306a`L@@0
KG5a101^LG44071aL@@0LG5`101bLG0307=aL0@0MG5_101fLFl407MbK`@0N79_101jLVl407]bK`<0
OG=_101nLfl4081dK`@0RWag1027NWH408IjMP<0QW]h1027O7T408MmNP@0Qgil1028PH0408V4P`L0
RHF41028Q8@408N4Q0@0QH:21024P84408B3Q0<0Q8F61025RH/408RBU0@0RYZK102=XJ44092VZ0<0
TZZ]102D[[@409Jb^@@0U[Jn102G^/@409W0b`@0VlGB0`2Mb]L409_6d`@0VL7=102G^lH409Bf`0@0
TK2i0`2=Z[8408ZT[0@0QYjU1022V9l407jBV0@0NXfB0`1fQh`407>1QP@0Kgao101[MWTF0?ooo`00
503oool406Q`L`@0JG1b101[L78306a`L@@0KG5a101^LG44071aL@@0LG5`101bLG0307=aL0@0MG5_
101fLFl407MbK`@0N79_101jLVl407]bK`<0OG=_101nLfl4081dK`@0RWag1027NWH408IjMP<0QW]h
1027O7T408MmNP@0Qgil1028PH0408V4P`L0RHF41028Q8@408N4Q0@0QH:21024P84408B3Q0<0Q8F6
1025RH/408RBU0@0RYZK102=XJ44092VZ0<0TZZ]102D[[@409Jb^@@0U[Jn102G^/@409W0b`@0VlGB
0`2Mb]L409_6d`@0VL7=102G^lH409Bf`0@0TK2i0`2=Z[8408ZT[0@0QYjU1022V9l407jBV0@0NXfB
0`1fQh`407>1QP@0Kgao101[MWTF0?ooo`00503oool406Q`LP@0JG1b101[L78306aaL@@0KW5a101_
LG44071aL0@0LW5`101cLG0307AaK`@0MW5_101gLFl407QaKP@0NG9^101kLVh407ebKP<0OW=^1020
M6h4085dK`@0RWaf1029NgH408UkM`<0RGah1028NgP408QlN@@0R7il102:PH0408b6Q@L0S8N5102>
QhH408R0P0@0QH201022OGd4089nO`<0PhB51025QXP408R<SP@0S9BF102BX:4409BYZP<0Ujf_102H
/KH409Ve^`@0VKS0102J^lD409_0b`@0WLKB0`2Pc=T40:3=fP@0W/OD102K`Ld409Rka@@0UKFn0`2A
[kL408fX/0@0RJ:Y1025Vj84082EV`@0O8nD0`1hRHd407B2Q`@0Kgb0101[MWXF0?ooo`00503oool4
06Q`LP@0JG1b101[L78306aaL@@0KW5a101_LG44071aL0@0LW5`101cLG0307AaK`@0MW5_101gLFl4
07QaKP@0NG9^101kLVh407ebKP<0OW=^1020M6h4085dK`@0RWaf1029NgH408UkM`<0RGah1028NgP4
08QlN@@0R7il102:PH0408b6Q@L0S8N5102>QhH408R0P0@0QH201022OGd4089nO`<0PhB51025QXP4
08R<SP@0S9BF102BX:4409BYZP<0Ujf_102H/KH409Ve^`@0VKS0102J^lD409_0b`@0WLKB0`2Pc=T4
0:3=fP@0W/OD102K`Ld409Rka@@0UKFn0`2A[kL408fX/0@0RJ:Y1025Vj84082EV`@0O8nD0`1hRHd4
07B2Q`@0Kgb0101[MWXF0?ooo`00503oool406Q`LP@0JG1b101[L78306aaL@@0KW5a101_LG44071a
L0@0LW5`101cLG0307AaK`@0MW5_101gLFl407QaKP@0NG9^101kLVh407ebKP<0OW=^1020M6h4085d
K`@0RWaf1029NgH408UkM`<0RGah1028NgP408QlN@@0R7il102:PH0408b6Q@L0S8N5102>QhH408R0
P0@0QH201022OGd4089nO`<0PhB51025QXP408R<SP@0S9BF102BX:4409BYZP<0Ujf_102H/KH409Ve
^`@0VKS0102J^lD409_0b`@0WLKB0`2Pc=T40:3=fP@0W/OD102K`Ld409Rka@@0UKFn0`2A[kL408fX
/0@0RJ:Y1025Vj84082EV`@0O8nD0`1hRHd407B2Q`@0Kgb0101[MWXF0?ooo`00503oool406Q`LP@0
JG1b101[L78306aaL@@0KW5a101_LG44071aL0@0LW5`101cLG0307AaK`@0MW5_101gLFl407QaKP@0
NG9^101kLVh407ebKP<0OW=^1020M6h4085dK`@0RWaf1029NgH408UkM`<0RGah1028NgP408QlN@@0
R7il102:PH0408b6Q@L0S8N5102>QhH408R0P0@0QH201022OGd4089nO`<0PhB51025QXP408R<SP@0
S9BF102BX:4409BYZP<0Ujf_102H/KH409Ve^`@0VKS0102J^lD409_0b`@0WLKB0`2Pc=T40:3=fP@0
W/OD102K`Ld409Rka@@0UKFn0`2A[kL408fX/0@0RJ:Y1025Vj84082EV`@0O8nD0`1hRHd407B2Q`@0
Kgb0101[MWXF0?ooo`00503oool406Q`LP@0JW1b101[L78306eaL@@0KW1a101`LG04075aL0@0Lg5`
101dLFl307EaK`@0Mg5^101hLFh407UaKP@0NW5]101lLVd407ibKP<0P7=^1021LV`408elM@@0S7af
102;O7H408YkMP<0RWei1029NgP408QjM`@0R7ai102:Ogh408f4Q0<0THR71029Ogl408Z0P0@0R7in
1026OWh408EoO`@0Pgen0`22P8840863Q0@0PhR:1027SY0409:KW@@0VJRZ0`2K/;8409bd^0@0WKRn
102L^/4409bla@@0WL7;102Oa]830:7;f0@0XloM102ScMT40:78d`@0WL7;102I^/@309Fc_0@0T:bd
102<YJ`408NNY@@0PYNN101nTIH307V:S`@0MHB8101`OH4406]gNQH0oooo000D0?ooo`@0J71b101Z
L78406]`LP<0KG5a101^L744071aL0@0LG5`101cLG0407AaK`<0MG5_101gLFh407QaKP@0NG5^101j
LFd407abK@@0OW9^0`20Lfh4085bK0@0SGae102<O7H408]lMP@0RW]f0`2:OGT408UkN0@0R7Yg1028
O7T408YoOP@0SHB40`2AR8L408UoO`@0RX201028OWh408InOP@0QGmo1023OGh308:0PP@0PH>41023
R8X408N>T0@0TY^M102IZ:X309^`/P@0W;Bh102M^;h409bj`@@0W;c5102M`L/409o6dP<0XL_H102S
cmd40:?=f@@0XLSC102M`L/409Vja0<0UK>l102@[;@408bU[0@0QijU1022Uih407jAUP<0NHZ?101e
Q8P4071mP@@0JgMj5P3oool001@0oooo101XL78406Y`LP@0Jg1b0`1]LG4406i`L@@0L75`101aLG04
07=aL0@0M75_0`1eLFl407MaKP@0N75^101iLFh407YaK@@0O79]101nLVh3081cKP@0PG9/102=O7D4
08alMP@0Rgaf102:NgH308YmN@@0RG]h1028NWL408QlN@@0RWmn102=Q8@30968Q`@0RGmo102:P804
08QnOP@0QWin1025Ogl408=mOP<0PX221021Ph@408>8RP@0Qhj@102BVid409VXZP<0Vk2b102L];P4
09fh_P@0W;[1102L_<D409g1b`@0WlKB0`2QbmP40:??g@@0XlgI102Qb=<409g1b`@0VK[40`2E/k`4
092/]0@0S:F/1027WZD408:GWP@0OY6F0`1iRXl407F4R0@0L7f1101[MgXF0?ooo`00503oool406Q`
LP@0JW1b101[L78306eaL@@0KW1a101`LG04075aL0@0Lg5`101dLFl307EaK`@0Mg5^101hLFh407Ua
KP@0NW5]101lLVd407ibKP<0P7=^1021LV`408elM@@0S7af102;O7H408YkMP<0RWei1029NgP408Qj
M`@0R7ai102:Ogh408f4Q0<0THR71029Ogl408Z0P0@0R7in1026OWh408EoO`@0Pgen0`22P8840863
Q0@0PhR:1027SY0409:KW@@0VJRZ0`2K/;8409bd^0@0WKRn102L^/4409bla@@0WL7;102Oa]830:7;
f0@0XloM102ScMT40:78d`@0WL7;102I^/@309Fc_0@0T:bd102<YJ`408NNY@@0PYNN101nTIH307V:
S`@0MHB8101`OH4406]gNQH0oooo000D0?ooo`@0J71b101ZL78406a`L@<0KG1a101_LG44071aL0@0
LW5`101cLFl407EaK`<0MW5^101hLFh407UaK@@0NW5]101kLF`407eaK0@0Og9]0`22M6h4089cK0@0
Th1h102?OWL408elM`@0S7]f0`2;NgL408YjM`@0RGUe1028NGH408UkNP@0R7em0`2@QhL408f6Q@@0
RhB4102:Q8D408V2P`@0Qh:41026Ph@308J8R@@0QHV;1024Rhl408><S`@0R9BG102DXJ<309n`/P@0
XKRk102Q^l0409nl``@0W[g6102N`L/40:36d@<0X/cH102Td=l40:K@gP@0Y/kJ102Sb=8409job@<0
VKO0102C/;P408jX/0@0RJ6X1024VZ0407nCV0<0NXbA101fQHT4075nPP@0K7Mj5P3oool001@0oooo
101XL78406Y`LP@0K71a0`1]L74406maL@@0L75`101bLG0407=aK`@0MG5_0`1fLFh407QaKP@0NG5]
101jLFd407]aK0@0OG5/101oLVd3089dKP@0PW=/102CP7P408mnM`@0SGag102<NgH308]kM`@0RWYg
1029NGD408QiMP@0RG]j1028OGd30927Q`@0SHJ5102;Q8@408Z4Q@@0RH:31027PX@408J3Q0<0QXR9
1025RH/408B;S`@0Phb?1028U9L409BQX`<0Wk2b102Q^;/40:6k`0@0Wkc3102N_LH409k1b`@0X<KA
0`2Rc=P40:C@g`@0Y]3N102Vc]X40:?8dP@0W[o90`2I]l0409>`^0@0SZR`1029XJP408BJX0@0Oi>H
0`1jS94407J5R@@0LGj2101/MgXF0?ooo`00503oool406Q`LP@0JW1b101/L74306e`L@@0Kg5a101`
LG04079aL0@0Lg5_101eLFl307IaKP@0N75^101iLFd407YaK@@0Ng5/101mLF`407mbK@<0PWA^1022
Lf`409>0N0@0Sgig102=O7L408akMP<0Rg]g102:NWL408UiM@@0R7Uf1029NgX408QmO@<0T8N7102=
QXD408^4Q0@0RXB51029PX<408N2Q0@0QX>40`26R8T408F9R`@0Q8^?1023S8l408RDU`@0U:6S0`2O
/;840:6h^`@0XK_0102O_<<409jmaP@0W/7;102Pa]430:;<f0@0Y=3O102Vd=h40:K>fP@0XlSB102N
_lT309Vg`0@0Tk2h102>Z;0408VQZ0@0Q9ZP101oTiP307Z<T@@0MXF9101aOX8406agNQH0oooo000D
0?ooo`@0J71b101ZL78406a`L@<0KG1a101_LG44071aL0@0LW5`101cLFl407EaK`<0MW5^101hLFh4
07UaK@@0NW5]101kLF`407eaK0@0Og9]0`22M6h4089cK0@0Th1h102?OWL408elM`@0S7]f0`2;NgL4
08YjM`@0RGUe1028NGH408UkNP@0R7em0`2@QhL408f6Q@@0RhB4102:Q8D408V2P`@0Qh:41026Ph@3
08J8R@@0QHV;1024Rhl408><S`@0R9BG102DXJ<309n`/P@0XKRk102Q^l0409nl``@0W[g6102N`L/4
0:36d@<0X/cH102Td=l40:K@gP@0Y/kJ102Sb=8409job@<0VKO0102C/;P408jX/0@0RJ6X1024VZ04
07nCV0<0NXbA101fQHT4075nPP@0K7Mj5P3oool001@0oooo101XL78406Y`LP@0K71a0`1^L74406ma
L0@0LG5`101cLG0407AaK`@0MW5_0`1gLFh407UaK@@0NW5]101kL6`407]`J`@0O71[101oLF`308Qh
LP@0RWUb102@OgL4091mM`@0SWeg102=OGL308elM`@0RgYf1029Mg<408QhM0@0QgIe1025MWH308]l
O0@0S860102<PX8408b4Q0@0RhB41029QHD408V5QP<0RHZ<1028SHl408VAU0@0R96D1029Ui/408fM
X@<0VZZ^102T^Kd40:Bm`@@0X[k5102P_/L40:31b`@0X/KA0`2TbmL40:G@gP@0Ym7P102Xd=d40:S=
e`@0X/C>0`2L_<D409Nc_0@0TJbc102<Y:/408JLX`@0PIFJ0`1lSI8407N6RP@0LGn3101/Mg/F0?oo
o`00503oool406Q`LP@0JW1b101/L74306i`L@@0Kg5`101aLG0407=aL0@0M75_101fLFl307MaKP@0
NG5]101jLFd407]`K0@0Ng1[101lL6/407maK0<0R7Qb102:NG84091oM`@0T7eg102>OGL408emM`<0
SGag102;NWH408UgL`@0R7Qd1027MWD408EfMP<0Rgal102<PH0408b2PP@0S8B4102;Q8@408V5Q@@0
RHF60`29RX`408R=S`@0RI6D1028TI@408VGV`@0SIfQ0`2JZZh40:Bi_@@0Y;g1102R_/D40:2na`@0
X<7;102Ra]430:C;e`@0YM3N102WdN040:S@g@@0Z<gG102Ra<h309bla@@0Uk>l102A[;<408bTZ`@0
QYbS1021UIX307b=TP@0MhJ:101aOh<406agNaH0oooo000D0?ooo`@0J71b101ZL78406a`L@<0KW1a
101_LG04075aL0@0Lg5`101dLFl407IaK`<0Mg5^101iLFd407YaK@@0Ng1/101kL6/407a`J`@0Og5/
0`28N78408YiLP@0T7mg102@OGL408imM`@0SGeg0`2=O7L408]jMP@0RGMc1028N7@408MfM@@0QGIf
0`2;O7`408b1P0@0S8:2102<Q8@408^4Q0@0RHF51029QHH308V:S0@0R8f?1029TI@408RAU0@0RINK
102=WJ4309ZZ[P@0Y;Vm102T_L440::na@@0X;k7102P`L/40:;6d@<0Y<_G102Ud=h40:OAh0@0Z=3M
102XcML40:;4cP<0W;c5102G/k`4096//`@0S:B[1026W:<4086EVP<0O8fB101gQXX4075oP`@0K7Mk
5P3oool001@0oooo101YL78406Y`LP@0K71a0`1^L744071aL0@0LW5`101dLG0407EaK`@0Mg5^0`1i
LFh407YaK@@0Ng5/101lL6/407a_JP@0NfeX101iJf@308AcK@@0T7ae102?OGD4091mMP@0T7af102?
OGH308mlMP@0SGYe102;N7<408]jM`@0SGil102<OG/308emO@@0SGin202<Ogl408]nO`@0RH211029
PH<308V4QP@0RHR<102;Si8408^BUP@0S9NL102>WZ8309BUZP@0XKFi102V_/840:Boa@@0X[o7102Q
`L/40:;6d@<0YL_G102Vd=d40:[Eh`@0/MSU102/dM`40:K9d`<0X;o9102J]kl409B_]P@0SZJ]1029
WZD408>GW0<0OHnD101hQh`4079oP`@0K7Qk5P3oool001@0oooo101YL78406Y`LP@0K71a0`1^L744
071aL0@0LW5`101dLG0407EaK`@0Mg5^0`1iLFh407YaK@@0Ng5/101lL6/407a_JP@0NfeX101iJf@3
08AcK@@0T7ae102?OGD4091mMP@0T7af102?OGH308mlMP@0SGYe102;N7<408]jM`@0SGil102<OG/3
08emO@@0SGin202<Ogl408]nO`@0RH211029PH<308V4QP@0RHR<102;Si8408^BUP@0S9NL102>WZ83
09BUZP@0XKFi102V_/840:Boa@@0X[o7102Q`L/40:;6d@<0YL_G102Vd=d40:[Eh`@0/MSU102/dM`4
0:K9d`<0X;o9102J]kl409B_]P@0SZJ]1029WZD408>GW0<0OHnD101hQh`4079oP`@0K7Qk5P3oool0
01@0oooo101YL78406Y`LP@0K71a0`1^L744071aL0@0LW5`101dLG0407EaK`@0Mg5^0`1iLFh407Ya
K@@0Ng5/101lL6/407a_JP@0NfeX101iJf@308AcK@@0T7ae102?OGD4091mMP@0T7af102?OGH308ml
MP@0SGYe102;N7<408]jM`@0SGil102<OG/308emO@@0SGin202<Ogl408]nO`@0RH211029PH<308V4
QP@0RHR<102;Si8408^BUP@0S9NL102>WZ8309BUZP@0XKFi102V_/840:Boa@@0X[o7102Q`L/40:;6
d@<0YL_G102Vd=d40:[Eh`@0/MSU102/dM`40:K9d`<0X;o9102J]kl409B_]P@0SZJ]1029WZD408>G
W0<0OHnD101hQh`4079oP`@0K7Qk5P3oool001@0oooo101YL78406Y`LP@0K71a0`1^L744071aL0@0
LW5`101dLG0407EaK`@0Mg5^0`1iLFh407YaK@@0Ng5/101lL6/407a_JP@0NfeX101iJf@308AcK@@0
T7ae102?OGD4091mMP@0T7af102?OGH308mlMP@0SGYe102;N7<408]jM`@0SGil102<OG/308emO@@0
SGin202<Ogl408]nO`@0RH211029PH<308V4QP@0RHR<102;Si8408^BUP@0S9NL102>WZ8309BUZP@0
XKFi102V_/840:Boa@@0X[o7102Q`L/40:;6d@<0YL_G102Vd=d40:[Eh`@0/MSU102/dM`40:K9d`<0
X;o9102J]kl409B_]P@0SZJ]1029WZD408>GW0<0OHnD101hQh`4079oP`@0K7Qk5P3oool001@0oooo
101YL78406]`LP@0KG1a0`1_L704075aL0@0Lg1_101eLFl407IaKP@0N75^0`1jLFd407aaK@@0OG5/
101mL6/407e_J@@0NV]V101dIV0307Y[IP@0RWQa102?O7D4095mMP@0TWaf1`2AOGH408mjM@@0SGQc
102=NWH40961OP@0TH:01`2@PH0408n1P0@0SX60102=P80408b1P@@0S8>40`2<QXP408f:S@@0SXjA
102@TYL4096FV`@0TY^P0`2DXJL409^[/@@0XkRm102U_L@40:>oaP@0X/7:102SaLl30:G:e@@0Y/kJ
102Vd=d40;GKi`@0/MGP102Zc=H30:?3c0@0WK[3102G/KT4096Y/0@0Rj6W1024V9h307n@U@@0NHR=
101cP8@406ehNaH0oooo000D0?ooo`@0JG1b101[L78406e`L@<0Kg1`101aLG0407=`K`@0MG5_101f
LFh407QaKP<0NW5]101lLFd407eaK0@0OG1[101mKfT407Y[IP@0M6IP0`1jJfH408YhL@@0Sgae102A
OGH4099lMPL0TGef102?NWD408ehL`@0SGYf102APGh40962P0L0T860102?PH0408j1P0@0SH20102<
PH4408b3Q0<0S8J8102=RXd408j>T@@0T9:G102AUY/409:KX0<0U:6W102KZk440:>h_@@0YKg4102S
_lH40:;1bP@0XlG?0`2Ub]D40:K>fP@0Y]3M102efnL40;7Eh0@0Z/cF0`2S`l`409fj``@0Uk6i102A
ZK0408^QY`@0Q9RN0`1oT9D407V8S@@0Lh24101]N7/F0?ooo`00503oool406U`LP@0Jg1b101]L743
06m`L0@0LG5`101cL6l407EaK`@0MW5^101hLFh307YaK@@0O75]101mLF`407e`J`@0OFmY101jJfH4
07AVH0<0NV]V102:N74408mlM@@0TGef102BO7H7095mMP@0SgYe102=N7<408ejMP@0TH5n102APX07
0921P0@0Sh60102>PH0408f0P0@0S861102<Ph@308b6R0@0SHZ=102>SY44092BU`@0TIJK102BVj03
09BQY`@0Vj^a102S^;d40:Fma0@0Xko6102R`LX40:?5c`<0YL[E102Vc]X40:K@g@@0]M_W102aeN04
0:[<eP<0Xl?<102M^/<409Na^@@0TJV`102;XJL408BHWP<0Oi2E101iR8d407>0Q0@0KGQk5P3oool0
01@0oooo101YL78406]`LP@0KG1a0`1_L704075aL0@0Lg1_101eLFl407IaKP@0N75^0`1jLFd407aa
K@@0OG5/101mL6/407e_J@@0NV]V101dIV0307Y[IP@0RWQa102?O7D4095mMP@0TWaf1`2AOGH408mj
M@@0SGQc102=NWH40961OP@0TH:01`2@PH0408n1P0@0SX60102=P80408b1P@@0S8>40`2<QXP408f:
S@@0SXjA102@TYL4096FV`@0TY^P0`2DXJL409^[/@@0XkRm102U_L@40:>oaP@0X/7:102SaLl30:G:
e@@0Y/kJ102Vd=d40;GKi`@0/MGP102Zc=H30:?3c0@0WK[3102G/KT4096Y/0@0Rj6W1024V9h307n@
U@@0NHR=101cP8@406ehNaH0oooo000D0?ooo`@0JG1b101[L78406e`L@<0Kg1`101aLG0407=aK`@0
MG5_101hLFh407YbKP<0O79]101mLVd407mbK0@0P75[1020L6X407m^J0@0P71Y0`24Lf`408aiL@@0
TGef102DOgL409AnM`@0U7eg0`2COGH4099kM@@0T7Yd102@NgL409>1OP@0UHJ30`2DQH@409>4PP@0
TX>2102APh840921P@@0SX:2102>QHD308n9RP@0T8b>102AT9<409BEV0@0UYZN102GX:@309ZUZ`@0
WZfc102R]KX40:Bj`@@0Y;g5102S`<T40:C5cP<0Y/WD102Vc=T40:O?g@@0^=gX102df>840:k?f@<0
YlK?102P_LH409Vd_0@0Tj^b102<XjT408JJX0<0P9:G101jRHh407>1Q@@0KGQl5P3oool001@0oooo
101YL78406]`LP@0KG1a0`1_L704075aL0@0Lg5_101eLFl407QaKP@0NW9^0`1lLVd407ebK@@0Og9/
1020LF/4081`JP@0OfiX1020L6T308AcK0@0S7Ua102AOGH409AoM`@0U7ig102DOGL309=mMP@0TW]e
102@NW@4091kM`@0Th5n102EQX<309B5Q0@0ThB2102BPh840963PP@0T861102>PX8408j5Q@<0ShV:
102@S8h4096@T`@0U9FH102FVYh409NPY0<0VZF[102N[K<40::e^P@0Y;[1102T_LD40:?0b@@0Y<G>
0`2VbM@40:K<f@@0YloM102hgNP40;CHhP@0[/oI0`2Wa/l40:2maP@0VKBl102CZk8408bSZ@@0QYZP
0`20TYL407Z9SP@0Lh65101]N7`F0?ooo`00503oool406U`LP@0Jg1b101]L74306m`L0@0LG5`101c
LFl407EaK`@0N75^101jLVh307abK@@0OG9]101oLV`4081aJ`@0P71Z101oKVP4081`J@<0Q7=/102<
NG44095mMP@0U7mg102DOWL409AmM`<0Tgef102BNgD4091jM0@0T7]g102CPGh409F6P`<0U8F4102C
Q88409:3PP@0TH>2102@PH4408j2PP@0SXF50`2?RHX4092<SP@0TI2C102DUIP409JJWP@0Uj2T0`2J
YJ/409j]/`@0X[Fj102T^/440:Bma@@0Xl39102TaLh30:K9e0@0Y/cI102Wcmd40;SMj0@0]=SR102^
cmT30:O6c`@0X;g6102I];`409>[/P@0S:>Y1026VZ03082BU`@0NXV>101cPHD406ehO1H0oooo000D
0?ooo`@0JG1b101[L78406e`L@<0Kg1`101aLG0407=aK`@0MG5_101hLFh407YbKP<0O79]101mLVd4
07mbK0@0P75[1020L6X407m^J0@0P71Y0`24Lf`408aiL@@0TGef102DOgL409AnM`@0U7eg0`2COGH4
099kM@@0T7Yd102@NgL409>1OP@0UHJ30`2DQH@409>4PP@0TX>2102APh840921P@@0SX:2102>QHD3
08n9RP@0T8b>102AT9<409BEV0@0UYZN102GX:@309ZUZ`@0WZfc102R]KX40:Bj`@@0Y;g5102S`<T4
0:C5cP<0Y/WD102Vc=T40:O?g@@0^=gX102df>840:k?f@<0YlK?102P_LH409Vd_0@0Tj^b102<XjT4
08JJX0<0P9:G101jRHh407>1Q@@0KGQl5P3oool001@0oooo101YL78406]`L@@0KG1a0`1_L704079a
K`@0M75_101fLFh407UaKP@0Ng9]0`1mLVd4081cK@@0PW=/1023Lf`408EcK0@0Qg=[1029MVl308ek
L`@0TGmg102FPGP409N2NP@0Uh5j102GP7T309MoN0@0UWig102DO7H409AnN0@0UH5m102GQh@309N8
QP@0UXN5102EQH@409>6Q0@0TXB3102APh<40966Q@<0THZ:102BShl409>BU0@0UYNJ102IW:0409^R
Y@<0WJN/102P[K<40:>e^P@0Y;Vo102U_<<40:Bob0@0YLC=0`2Ub=840:G:e`@0Y<gK102jgn/40;WL
i`@0/M?M0`2ZbM<40:?0b0@0W;Jn102E[KD408jTZ`@0R9bQ0`21TiP407Z:S`@0M865101]NG`F0?oo
o`00503oool406U`LP@0Jg1a101]L74306m`L0@0LW5_101dLFl407IaKP@0NG5^101kLVd307ebK@@0
P7=]1022Lf`408=cK0@0QG=/1027Lf/408UfK`<0SG]c102AOgL409J1N0@0Uh9j102GPGX409N0N@<0
Ugmh102FOWL409AlMP@0U7ih102EPGd409N7Q0<0UhR6102FQhD409F5Q0@0ThJ4102BQ8<40963P`@0
THJ50`2ARXX409:?S`@0Ti:D102FUiX409VLX0@0Vj:U0`2MYj`40:2]/`@0XkFj102T^Kl40:Fl``@0
Y;o8102Ua<d30:G8dP@0YL[G102TcM/40;[Oj`@0^McW102admd30:[9d`@0Xl38102L][h409F]]@@0
SZB[1028W:43086CV0@0NXZ?101dPHD406eiO1H0oooo000D0?ooo`@0JG1b101[L74406e`L@<0Kg1`
101bLFl407AaK`@0MW5^101iLFh407]bK@<0OG9]1020Lfd4089cK0@0Pg=/1025Lf`408McJ`@0RGI_
0`2=Ng<4095oM`@0UX5h102GPWX409N1NP@0Uh1i0`2GOgP409InM`@0U7af102DOWP409F1O@@0UhN4
0`2GR8H409J7Q@@0UHF4102CQX@409:4P`@0TH>3102AQXD3096:RP@0TXn?102CTY@409JGVP@0VIbP
102KXZD309fW[0@0X:fc102S]KX40:Bi_`@0YKc3102T_lP40:G4c@<0YLSB102Ub]L40:C=f`@0^]o[
102ig>L40;7Cg@<0Z/WC102S`<P409bf_P@0UJfe102>Y:/408RLX@<0PI>H101jRXl407B1Q@@0KGUl
5P3oool001@0oooo101YL78406]`L@@0KG1a0`1_L704079aK`@0M75_101fLFh407UaKP@0Ng9]0`1m
LVd4081cK@@0PW=/1023Lf`408EcK0@0Qg=[1029MVl308ekL`@0TGmg102FPGP409N2NP@0Uh5j102G
P7T309MoN0@0UWig102DO7H409AnN0@0UH5m102GQh@309N8QP@0UXN5102EQH@409>6Q0@0TXB3102A
Ph<40966Q@<0THZ:102BShl409>BU0@0UYNJ102IW:0409^RY@<0WJN/102P[K<40:>e^P@0Y;Vo102U
_<<40:Bob0@0YLC=0`2Ub=840:G:e`@0Y<gK102jgn/40;WLi`@0/M?M0`2ZbM<40:?0b0@0W;Jn102E
[KD408jTZ`@0R9bQ0`21TiP407Z:S`@0M865101]NG`F0?ooo`00503oool406U`LP@0Jg1a101]L703
071`L0@0LW1_101eLFh407MaKP@0NW9^101mLVd307mcK@@0PW=]1025M6d408MeK@@0RGI]102<N6l4
08mkLP<0Tgmg102FPg/409V4O0@0VXEm102KQGd409^3O0<0VX9k102JPGX409UoN@@0V81j102HPWd4
09Z7P`<0Vh^8102IRHL409R6Q0@0UXJ4102DQX@409>5P`@0ThN60`2CRXX409F?T0@0UY>D102IVI/4
09bOX@@0WjBW0`2PZ:`40::]/@@0Y;>h102U]kd40:Jk`P@0Y[o7102V`l`30:K7d@@0YLWE102Qb]P4
0;KLj0@0_N7/102een430:g<eP@0YL;;102N^L4409N_]P@0T:J]1029WJ<308:DV@@0Nh^@101ePXH4
06iiO1H0oooo000D0?ooo`@0JG1b101[L74406e`L0<0L71`101bL6l407EaKP@0Mg5^101jLVh407eb
K@<0Og=]1022Lfd408EdK@@0QgE]1029MVd408ahK`@0Sg]b0`2COgL409J3N`@0VHAl102JQGd409^5
O@@0Vh=l0`2JPW/409Z1NP@0VGmi102HP7X409R2O@@0VXN30`2KRhP409V9Q`@0V8J4102FQX@409B6
Q0@0ThF3102CQhH309>:RP@0UHn@102FTi@409VIV`@0W9nQ102OY:L30:2X[0@0XZfa102T/kP40:Fg
_@@0Y[_2102V_lL40:K3c0<0Y/OA102UbMD40:7:f0@0]]cX102mhN`40;GGh@<0[LcF102U`//409ji
`@@0Ujnf102@YZd408VMX`<0PYBI101kRi0407F2QP@0KWUl5P3oool001@0oooo101YL78406]`L@@0
KG1`0`1`L704079`K`@0MG5^101gLFh407YbKP@0OG9]0`1oLfd4089cK@@0QGA]1027MFd408UfK@@0
S7Q_102?Ng8309=oM`@0UX=k102IQ7`409Z5O@@0VhEm102KPg`309Z2N`@0VX5j102IOgT409R0NP@0
V89m102JQh<309^;R0@0VHV7102HQX@409J6Q0@0U8J4102CQH<409>7QP<0ThZ:102ESi0409JCU0@0
VIVK102LWj4409nTY`<0X:R/102R[K440:Bc^0@0YKNm102V^l840:Joa`@0Y/?<0`2Vam440:G9e@@0
XL[H102fg>P40;gQk0@0]MOQ0`2]c=H40:G2b`@0W[W1102G[kH4092V[@@0RIfS0`22U9T407^;T0@0
MH:6101^NG`F0?ooo`00503oool406U`LP@0Jg1a101]L703071`L0@0LW1_101eLFh407MaKP@0NW9^
101mLVd307mcK@@0PW=]1025M6d408MeK@@0RGI]102<N6l408mkLP<0Tgmg102FPg/409V4O0@0VXEm
102KQGd409^3O0<0VX9k102JPGX409UoN@@0V81j102HPWd409Z7P`<0Vh^8102IRHL409R6Q0@0UXJ4
102DQX@409>5P`@0ThN60`2CRXX409F?T0@0UY>D102IVI/409bOX@@0WjBW0`2PZ:`40::]/@@0Y;>h
102U]kd40:Jk`P@0Y[o7102V`l`30:K7d@@0YLWE102Qb]P40;KLj0@0_N7/102een430:g<eP@0YL;;
102N^L4409N_]P@0T:J]1029WJ<308:DV@@0Nh^@101ePXH406iiO1H0oooo000D0?ooo`@0JG1b101[
L74406i`L0<0L71_101cL6l407EaKP@0N75]101kLVd407ibK@<0PG=]1025M6d408QeK@@0RgM^102>
N6h4099mL`@0UH1g0`2JQW`409b7OP@0WXMo102NR80409n8P0@0WXMo1`2NQGd409f3O0@0W8=l102L
Q7h409f8P`<0WXb8102MRhP409^9Q`@0VHV6102GR8D409F7Q@@0UHV70`2FSH`409RAT@@0VYFF102M
Vi`409nPX`@0XjJY0`2TZjh40:F_/P@0Y[>g102W][`40:Rj`@@0Z;o6102X`l/30:S6d0@0Y/SD102P
am@40:WAg`@0^=kZ102jgNL30:o?f0@0YlC=102P^l<409Va^0@0TZR^102;WZ@308BEVP@0O8b@101e
PhL406iiOAH0oooo000D0?ooo`@0JG1b101[L74406i`L0<0L71_101cL6l407EaKP@0N75]101kLVd4
07ibK@<0PG=]1025M6d408QeK@@0RgM^102>N6h4099mL`@0UH1g0`2JQW`409b7OP@0WXMo102NR804
09n8P0@0WXMo1`2NQGd409f3O0@0W8=l102LQ7h409f8P`<0WXb8102MRhP409^9Q`@0VHV6102GR8D4
09F7Q@@0UHV70`2FSH`409RAT@@0VYFF102MVi`409nPX`@0XjJY0`2TZjh40:F_/P@0Y[>g102W][`4
0:Rj`@@0Z;o6102X`l/30:S6d0@0Y/SD102Pam@40:WAg`@0^=kZ102jgNL30:o?f0@0YlC=102P^l<4
09Va^0@0TZR^102;WZ@308BEVP@0O8b@101ePhL406iiOAH0oooo000D0?ooo`@0JG1b101[L74406i`
L0<0L71_101cL6l407EaKP@0N75]101kLVd407ibK@<0PG=]1025M6d408QeK@@0RgM^102>N6h4099m
L`@0UH1g0`2JQW`409b7OP@0WXMo102NR80409n8P0@0WXMo1`2NQGd409f3O0@0W8=l102LQ7h409f8
P`<0WXb8102MRhP409^9Q`@0VHV6102GR8D409F7Q@@0UHV70`2FSH`409RAT@@0VYFF102MVi`409nP
X`@0XjJY0`2TZjh40:F_/P@0Y[>g102W][`40:Rj`@@0Z;o6102X`l/30:S6d0@0Y/SD102Pam@40:WA
g`@0^=kZ102jgNL30:o?f0@0YlC=102P^l<409Va^0@0TZR^102;WZ@308BEVP@0O8b@101ePhL406ii
OAH0oooo000D0?ooo`@0JG1b101[L74406i`L0<0L71_101cL6h407I`K@@0NG5]101lLF`4081bK0<0
Pg=/1027M6d408]fK@@0SgQ^102CO74409R2M`@0W8Ml0`2QRh440:B;P@`0Xh^2102SRX830::9P@@0
XXV0102RR8040:68P0@0X8R2102PRX@30:6<R0@0Whb9102NRhP409b;R0@0VXZ7102HRXL409R;R@<0
VI2>102KU9<409jIV0@0XIfN102TXj@40:JYZ`<0Z:b_102Y/K@40:Vd^0@0ZKRm102Z_<840:_0a`@0
ZlC<0`2[b=440:[;e@@0Z<_F102Ycm/40:gDh@@0/mKP0`2_cmP40:W6cP@0X[g4102K/kX409BY/0@0
SJ2U0`25UY/407f=T@@0MX>7101^NWdF0?ooo`00503oool406U`LP@0Jg1a101^L703071`K`@0Lg1^
101fL6d407UaK@@0O75/1020LV`308=cK0@0QgA]102;MVd408mhKP@0Tgaa102HPWL409b7O0<0XH^1
102TRh4<0:>;PP@0XhZ20`2RRH440::9P0@0XXR0102QR8040:28PP@0X8Z40`2QS8P409n<R@@0WX^8
102LRhP409Z:Q`@0V8Z7102HRhT309V@SP@0ViBC102NVIP40:6MWP@0Y:>T102VZJ/30:R/[`@0ZK6d
102Y];P40:Vh_@@0Z[c2102[`<L40:_4c0<0ZlSA102ZbmD40:S;eP@0ZLoK102]e>440;?Fh0<0[loH
102Ya/h40::ma0@0Vk>j102DZK0408fPY@<0QIJK101mSI4407J3Q`@0KWYm5P3oool001@0oooo101Y
L78406]`L@@0KW1`0`1`L6l407=`KP@0MW1]101iLFd407aaK0@0P79/0`23Lf`408MdK@@0RgI]102?
N6h409=lL@@0V89g102LQg`30:6;P@@0Y8^1302SRh840:>:PP<0XXV1102RRH040::8P0@0XHR0102P
R8840:2:Q0<0XHb8102OS8T409j;R0@0W8^8102JRXL409R:Q`@0V8^90`2IT8h409^DT`@0WYVH102Q
WIh40:BSY0@0YZV[0`2X[:l40:Va]0@0ZKBh102Y^;d40:Zl`P@0Zl37102[a<`30:_8d@@0Z/_E102X
bmH40:W?f`@0[MCQ102ce^030:o?f0@0ZLK>102R_L@409^c^P@0U:V`102=X:D308FFV`@0OHfA101f
PhL406ijOAH0oooo000D0?ooo`@0JG1b101[L74406i`L0<0L71_101cL6h407I`K@@0NG5]101lLF`4
081bK0<0Pg=/1027M6d408]fK@@0SgQ^102CO74409R2M`@0W8Ml0`2QRh440:B;P@`0Xh^2102SRX83
0::9P@@0XXV0102RR8040:68P0@0X8R2102PRX@30:6<R0@0Whb9102NRhP409b;R0@0VXZ7102HRXL4
09R;R@<0VI2>102KU9<409jIV0@0XIfN102TXj@40:JYZ`<0Z:b_102Y/K@40:Vd^0@0ZKRm102Z_<84
0:_0a`@0ZlC<0`2[b=440:[;e@@0Z<_F102Ycm/40:gDh@@0/mKP0`2_cmP40:W6cP@0X[g4102K/kX4
09BY/0@0SJ2U0`25UY/407f=T@@0MX>7101^NWdF0?ooo`00503oool406U`LP@0Jg1a101^L6l3075`
KP@0Lg1]101fL6d407Y`K0@0OG5/1021LV`308EcK0@0RGE/102>MVd409=hK@@0V7ea102MPgP40:><
P0<0YXn5102XShD40:R>Q0P0Yhj41`2WSH@40:J=Q0@0YXb4102USH@40:F=QP@0YHn80`2UT8X40:>?
R@@0X8b8102NS8P409b:Q`@0VXZ7102JS8X309bAS`@0WYJD102RViX40:BPW`@0YjFU102ZZZ/30:^^
/0@0[K:e102/]KT40:fi_@@0[[g2102_`LL40:o6c0<0/<[A102`c]H40;3?f@@0/]GP102efnL40;CG
h@<0/M3J102[b=040:BnaP@0WKFl102FZk4408jQY`<0QYNL101oSY8407N4R0@0KgYm5P3oool001@0
oooo101YL78406]`L@@0KW1_0`1aL6h407=`K@@0MW1]101jL6`407eaK0@0PG9/0`25Lf`408UeK0@0
SWI]102CN6d409QmL@@0WH=h102SS8030:J?Q@@0Z8n5102XSX@80:N>Q0L0Yhf4102VSH@40:J<Q0@0
YHf4102USHH40:F?R0<0YI2:102SShT40:2<R0@0WXb8102LRXL409Z:Q`@0VXb:0`2LTHl409jFU0@0
XY^J102TX9l40:NUY@@0ZZZ[0`2[[[040:fb]@@0[;Fi102]^Kd40:jm`P@0[l77102_a/`30;3:d@@0
/<kF102`cmT40;;Eh0@0]M_W102den430;7@fP@0ZlS@102T_/H409fe_0@0UZ^a102>XJL308JGW0@0
OhjB101gQ8P406mjOAH0oooo000D0?ooo`@0JG1b101[L74406i`K`<0LG1^101cL6d407I`K@@0NW1/
101mLF`4085bK0<0QG=/1029MF`408ifK@@0TgQ]102HOG4409f3N0@0Xhb00`2VShD40:R?Q@@0Z8j4
202WSX@70:N=Q0@0YXf4102VS8@40:F=Q0@0YHf6102UShP30:F@RP@0Xhn9102PS8P409j<R0@0W8Z7
102JRXL409Z<RP<0W96?102NUY@40::KVP@0Y:2O102WYJD40:ZZZ`<0Zjj`102]/[D40:be^@@0[KVm
102^_L840:o1a`@0[lK<0`2`b]440;3>eP@0/<oI102beN040;GKi`@0]=OQ0`2ad=X40:_8d0@0Y;k6
102M]K`409J[/@@0SZ6W0`26Ui`407n>TP@0MhB8101_NWdF0?ooo`00503oool406U`LP@0Jg1a101^
L6l3075`KP@0Lg1]101fL6d407Y`K0@0OG5/1021LV`308EcK0@0RGE/102>MVd409=hK@@0V7ea102M
PgP40:><P0<0YXn5102XShD40:R>Q0P0Yhj41`2WSH@40:J=Q0@0YXb4102USH@40:F=QP@0YHn80`2U
T8X40:>?R@@0X8b8102NS8P409b:Q`@0VXZ7102JS8X309bAS`@0WYJD102RViX40:BPW`@0YjFU102Z
ZZ/30:^^/0@0[K:e102/]KT40:fi_@@0[[g2102_`LL40:o6c0<0/<[A102`c]H40;3?f@@0/]GP102e
fnL40;CGh@<0/M3J102[b=040:BnaP@0WKFl102FZk4408jQY`<0QYNL101oSY8407N4R0@0KgYm5P3o
ool001@0oooo101YL78406]_L0@0KVm_0`1`Kfh407=_K@@0MVm/101jL6/407iaJ`@0PW9[0`26Lf/4
08]dJ`@0TGM]102GNVl409ioM0@0YHMk102[T8@30:jDR0@0[Y>8102]TXL40:bAQP@0Zi262`2[T8L4
0:^AR0@0Zi:9102[TXX40:ZDS0<0ZIB>102WTX`40:B?R`@0XHf9102NRhL409b;Q`@0Vhj;0`2MTXl4
0:2GU@@0Y9bK102XXZ440:^XZ0@0[Zf]0`2_/K840;2d]P@0/KNj102a^[h40;:n``@0/l;8102dald3
0;G;dP@0]]3H102fd]X40;SIh`@0_=oZ102jg>H30;CDg@@0[/[B102W`LP40:2g_@@0V:fc102@XjP3
08RIW@@0P8nC101gQ8P406mjOQH0oooo000D0?ooo`@0JG1b101[Kg0406i_K`<0L6m^101cKfd407I_
K0@0NW1[101nLF/4089bJ`<0QW=[102;M6/4095gK@@0UgY_102NOg@40:F7N`@0Zi240`2^U8P40:jC
R0@0[I:7102/THH40:^@QP/0Zi27102[THP40:^BR@@0Zi::102ZU8`30:VDSP@0Yi:<102TSh/40:6=
R@@0WX^7102LRhL409^>R`<0WI:?102PUiD40:BLV`@0Z::Q102[Z:P40:j][@<0[k6b102`];H40;6g
^P@0/KZn102b_/<40;?2b0@0]<O=0`2ebm840;K@f0@0]];J102hfN<40;cOjP@0^]cV0`2de=d40:k:
dP@0Yl78102P]kd409R]/`@0T:>X0`28VId4082?T`@0MhB8101_NWhF0?ooo`00503oool406U`LP@0
Jfm`101^Kfl3071_KP@0Lfm]101fKf`407Y`J`@0OW5[1022LV/308IcJ`@0RgA[102AMfd409MjK`@0
WWmd102UQg/40:^@Q0<0[YB8102^ThP40:fBQ`@0[966102[T8H;0:^@Q`@0Zi68102[TXT40:^BRP@0
ZYB<0`2YU8h40:NBS0@0Y8n;102QSHT409j;Q`@0W8^7102KSX/309fBS`@0X9NE102TW9/40:RRX@@0
ZjRX102^[Jd30:na/P@0/;Bf102a]kX40;6j_P@0/[k3102c`/P40;C7c@<0]L_B102fd=P40;KBfP@0
^=WS102lgnX40;[LiP<0]=CM102^b]840:O1b0@0X;Nm102H[K<4092SZ0<0R9VM1020Si<407N4R0@0
KgYn5P3oool001@0oooo101YL78406]_L0@0KVm_0`1`Kfh407=_K@@0MVm/101jL6/407iaJ`@0PW9[
0`26Lf/408]dJ`@0TGM]102GNVl409ioM0@0YHMk102[T8@30:jDR0@0[Y>8102]TXL40:bAQP@0Zi26
2`2[T8L40:^AR0@0Zi:9102[TXX40:ZDS0<0ZIB>102WTX`40:B?R`@0XHf9102NRhL409b;Q`@0Vhj;
0`2MTXl40:2GU@@0Y9bK102XXZ440:^XZ0@0[Zf]0`2_/K840;2d]P@0/KNj102a^[h40;:n``@0/l;8
102dald30;G;dP@0]]3H102fd]X40;SIh`@0_=oZ102jg>H30;CDg@@0[/[B102W`LP40:2g_@@0V:fc
102@XjP308RIW@@0P8nC101gQ8P406mjOQH0oooo000D0?ooo`@0JG1a101[Kg0406i_KP<0L6i]101c
KV`407I^J`@0NVmZ101nL6T4089aJ@<0Qg9Y102<M6X409=fJP@0Vgeb102VQWT40;2?PP@0]YN90`2f
V8/40;BGR`@0/YF:102`U8T40:nCR0L0[Y:8102_ThT40;2DRP@0/IJ<102`Uhh40;2HS`<0[YNA102[
UHl40:NBS@@0Y8n:102QS8P409j;Q`@0WHj;0`2PTi040:>IU`@0YYnM102[YJ<40:nZZ@@0/Jn_0`2c
/k@40;Bf^0@0]KVk102e_;l40;Jo``@0]l?8102ib<h30;[=d`@0_=;I102meMd40;oMiP@0`>7[102o
h^`30;WGh0@0//gE102[`lX40:>i_`@0VZnd102BY:T308ZJWP@0PHnC101hQHT406mkOQH0oooo000D
0?ooo`@0JG1a101[Kg0406i_KP<0L6i]101cKV`407I^J`@0NVmZ101nL6T4089aJ@<0Qg9Y102<M6X4
09=fJP@0Vgeb102VQWT40;2?PP@0]YN90`2fV8/40;BGR`@0/YF:102`U8T40:nCR0L0[Y:8102_ThT4
0;2DRP@0/IJ<102`Uhh40;2HS`<0[YNA102[UHl40:NBS@@0Y8n:102QS8P409j;Q`@0WHj;0`2PTi04
0:>IU`@0YYnM102[YJ<40:nZZ@@0/Jn_0`2c/k@40;Bf^0@0]KVk102e_;l40;Jo``@0]l?8102ib<h3
0;[=d`@0_=;I102meMd40;oMiP@0`>7[102oh^`30;WGh0@0//gE102[`lX40:>i_`@0VZnd102BY:T3
08ZJWP@0PHnC101hQHT406mkOQH0oooo000D0?ooo`@0JG1a101[Kg0406i_KP<0L6i]101cKV`407I^
J`@0NVmZ101nL6T4089aJ@<0Qg9Y102<M6X409=fJP@0Vgeb102VQWT40;2?PP@0]YN90`2fV8/40;BG
R`@0/YF:102`U8T40:nCR0L0[Y:8102_ThT40;2DRP@0/IJ<102`Uhh40;2HS`<0[YNA102[UHl40:NB
S@@0Y8n:102QS8P409j;Q`@0WHj;0`2PTi040:>IU`@0YYnM102[YJ<40:nZZ@@0/Jn_0`2c/k@40;Bf
^0@0]KVk102e_;l40;Jo``@0]l?8102ib<h30;[=d`@0_=;I102meMd40;oMiP@0`>7[102oh^`30;WG
h0@0//gE102[`lX40:>i_`@0VZnd102BY:T308ZJWP@0PHnC101hQHT406mkOQH0oooo000D0?ooo`@0
JG1a101[Kg0406i_KP<0L6i]101cKV`407I^J`@0NVmZ101nL6T4089aJ@<0Qg9Y102<M6X409=fJP@0
Vgeb102VQWT40;2?PP@0]YN90`2fV8/40;BGR`@0/YF:102`U8T40:nCR0L0[Y:8102_ThT40;2DRP@0
/IJ<102`Uhh40;2HS`<0[YNA102[UHl40:NBS@@0Y8n:102QS8P409j;Q`@0WHj;0`2PTi040:>IU`@0
YYnM102[YJ<40:nZZ@@0/Jn_0`2c/k@40;Bf^0@0]KVk102e_;l40;Jo``@0]l?8102ib<h30;[=d`@0
_=;I102meMd40;oMiP@0`>7[102oh^`30;WGh0@0//gE102[`lX40:>i_`@0VZnd102BY:T308ZJWP@0
PHnC101hQHT406mkOQH0oooo000D0?ooo`@0JFma101[Kfl406e^K@<0L6e/101cKFX407I]J@@0NFiX
101nKfP4089`J0<0Qg5X102=LVL4099cI`@0Vga`102ZRG/40;NDQ@@0`Yj?0`2nWHl40;ZJS@@0]iR;
102dUXX40;:DR@@0/I>80`2aThT40;>DRP@0]9J;102fVHl40;NLTP@0]YfD0`2cW9@40;2ITP@0ZiF?
102VTH/40::=R0@0X8b8102OSh/30::DT@@0YIZH102ZXIl40:jWY@@0/Zb[102e/K430;Re]@@0^KVj
102j_;h40;Zo`@@0^l;5102laLX40;g9cP<0_lkD1031e=X40<;Fg@@0a^3X1037hn`40<GVk`<0_]_S
102fd=L40:k6c0@0Y[_1102M/;H409BVZP<0Ri^O1022T9@407V6R@@0L7]n5P3oool001@0oooo101Y
Kg4406]_K`@0KFi]0`1`KF`407=]JP@0MVeY101iKVP407i_J0@0PW1X0`27LFP408ebI`@0TW=W102K
O7040:Z9N`@0]iB51032WXl30;jMS`@0^YZ=102gV8/40;BFRP@0/YB9102aThP30;6CR@@0/iB:102d
UX/40;JIS`@0]ibB102fWI@30;>LU0@0/9VB102[UHl40:JAR`@0XXf8102PS8P409n?R`<0XYBA102U
VYP40:ZQW`@0[ZNU102b[:/40;Fa/@<0^;Fe102i^KX40;Zl_P@0^[o1102k`/D40;c5bP@0_LW>0`2o
c]@40<7DfP@0`]KM1036h>P40<OSk0@0aNK_0`2nfn<40;K@e`@0[/K<102V^l4409f`]P@0U:JZ0`2;
Vil408:@U0@0NHJ9101`NghF0?ooo`00503oool406U_L@@0Jfm_101]KVd3071]K0@0LfeZ101fKFT4
07U^J0@0OVmX1022L6P308MaJ0@0SG9W102BLfL409]lL0@0ZXUk102gU8D40<:NS`<0_Yf?102jVXd4
0;NHR`@0]9J:102bU8T40;6CR0<0/I>9102cU8X40;BFR`@0]YV?102gW9840;JMU0<0/ibD102`VI84
0:^ES`@0YY6;102RSHP40:2<R0@0Whn;0`2RU9440:FJV0@0ZZ6O102^YjD40;:/Z`@0]K6a0`2h]KD4
0;Vi^P@0^[bn102j_l440;_2a@@0_<G:102mbLh30;o>e0@0`MCJ1032e]d40<KPj0@0an?/1035i^l3
0;kKh`@0]]3G102^a/`40:Jk`@@0WK2f102DYZX308^KW`@0PY2D101iQXT4071kOQH0oooo000D0?oo
o`@0JFma101[Kfl406e^K@<0L6e/101cKFX407I]J@@0NFiX101nKfP4089`J0<0Qg5X102=LVL4099c
I`@0Vga`102ZRG/40;NDQ@@0`Yj?0`2nWHl40;ZJS@@0]iR;102dUXX40;:DR@@0/I>80`2aThT40;>D
RP@0]9J;102fVHl40;NLTP@0]YfD0`2cW9@40;2ITP@0ZiF?102VTH/40::=R0@0X8b8102OSh/30::D
T@@0YIZH102ZXIl40:jWY@@0/Zb[102e/K430;Re]@@0^KVj102j_;h40;Zo`@@0^l;5102laLX40;g9
cP<0_lkD1031e=X40<;Fg@@0a^3X1037hn`40<GVk`<0_]_S102fd=L40:k6c0@0Y[_1102M/;H409BV
ZP<0Ri^O1022T9@407V6R@@0L7]n5P3oool001@0oooo101XKg4406Y^K`@0K6e]0`1_K6/4079/J@@0
MFaX101iK6L407e]IP@0PViV0`28L6H408eaIP@0TG9U102GNF/40:R8NP@0^YJ71038XY430<BQT@@0
_if?102kVXd40;NGRP@0]9F91`2dUHX40;NHS@@0^YZ?102lWI440;fPU0@0^j6G0`2iXIP40;BNUP@0
[YRA102XTX`40:>=R0@0X8b7102PSh/30:>DT@@0YYZH102/XYl40;6XYP@0]Jf/102i/k830;bg]`@0
_K^k102n_kl40;k1``@0_/C61030al/40<7;c`<0`loE1035e=T40<OHg@@0cN;X103?j>l40<cZlP<0
`mkU102kdmX40;;8cP@0ZKg2102P/[L409NW[0<0SIbP1024TID407Z6RP@0L7]n5P3oool001@0oooo
101XKg4406Y^K`@0K6e]0`1_K6/4079/J@@0MFaX101iK6L407e]IP@0PViV0`28L6H408eaIP@0TG9U
102GNF/40:R8NP@0^YJ71038XY430<BQT@@0_if?102kVXd40;NGRP@0]9F91`2dUHX40;NHS@@0^YZ?
102lWI440;fPU0@0^j6G0`2iXIP40;BNUP@0[YRA102XTX`40:>=R0@0X8b7102PSh/30:>DT@@0YYZH
102/XYl40;6XYP@0]Jf/102i/k830;bg]`@0_K^k102n_kl40;k1``@0_/C61030al/40<7;c`<0`loE
1035e=T40<OHg@@0cN;X103?j>l40<cZlP<0`mkU102kdmX40;;8cP@0ZKg2102P/[L409NW[0<0SIbP
1024TID407Z6RP@0L7]n5P3oool001@0oooo101XKg4406Y^K`@0K6e]0`1_K6/4079/J@@0MFaX101i
K6L407e]IP@0PViV0`28L6H408eaIP@0TG9U102GNF/40:R8NP@0^YJ71038XY430<BQT@@0_if?102k
VXd40;NGRP@0]9F91`2dUHX40;NHS@@0^YZ?102lWI440;fPU0@0^j6G0`2iXIP40;BNUP@0[YRA102X
TX`40:>=R0@0X8b7102PSh/30:>DT@@0YYZH102/XYl40;6XYP@0]Jf/102i/k830;bg]`@0_K^k102n
_kl40;k1``@0_/C61030al/40<7;c`<0`loE1035e=T40<OHg@@0cN;X103?j>l40<cZlP<0`mkU102k
dmX40;;8cP@0ZKg2102P/[L409NW[0<0SIbP1024TID407Z6RP@0L7]n5P3oool001@0oooo101XKg04
06Y]KP@0Jfa[0`1^JfT4071ZI`@0LfYU101gJV@407a[I0@0PVeT0`28KfD408iaI@@0TgAX102JNfd4
0:f;O0@0`9V9103?YY@30<VST`@0a9n@102oW8h40;ZGRP@0]9>7102aTHD30;6AQP@0/i>8102jV8`4
0<2MT@@0`Z6E102oXIL30;fSVP@0^J:J102`VI840:ZCS0@0Y8f7102PRhH40:2>R@<0Xi>@102WVYP4
0:fRX0@0/:NU102e[J/40;Zc/P<0_kVh1031_K`40<?1`@@0`l?41032aLP40<?9c0@0aLc@0`37d=D4
0<SDf@@0b]SM103@h>H40=CZk`@0d^gd0`39hNL40<3Ff`@0]/[@102]_l@40:>d^0@0VJV]0`2?WJ44
08FBUP@0NhN:101aNghF0?ooo`00503oool406Q_L0@0JVe^101[K6/306i[J@@0L6YW101cJVD407MZ
I0@0O6]T1022KF@308Q_I@@0SW5U102CM6P409YkK@@0[H]l1030VHT40<nVU0<0bJ>C1034Wi040;nL
SP@0^YN:102dThL40;6AQ@<0/I66102cThP40;ZHS0@0`9fA1032XID40;nQU`<0_J>J102iXYX40;2I
TP@0ZY><102TSHL40:2;QP@0X8j90`2STi040:NJV0@0[J:P102`YjD40;F]Z`@0^[>b0`2o^KP40<6m
_0@0`l711033`l@40<;5b0@0`lW<1035c=030<O@e@@0b=CI103:f=d40=3PiP@0e>[_103BkO@30<WQ
i`@0`=KK102fb]040:foa0@0XkBh102IZJd308nMX@@0QI:F101kQhX4075kOQH0oooo000D0?ooo`@0
J6m`101ZKFh406]/J`<0KV]Y101`JVL407=ZI@@0MfYT101lJf@4089]I0<0R6mU102>LFD409=dJ0@0
VW]]102]Rg`40<2IR@@0cjJD0`39Xi<40<BOT0@0_ib>102jUhX40;BCQ`@0/I650`2aTHH40;>CR0@0
^YR<1030WI440<:QU@@0_j6G0`2mXiX40;VRVP@0/9VB102ZTh`40:B=Q`@0X8^6102PSXT30:>CT0@0
YiZH102]XZ040;2WY@@0]Jf[102j/k830;ni^0@0`Kfl1033`L440<?3a0@0`/G81033bL`40<G<d0<0
am3E1038e=T40<[Hg@@0d>3V103Dj^l40=;]m0<0bN7W1030e]/40;K:d0@0[Ko4102S];P409VY[@<0
SifQ1025TYH407^7RP@0LG]n5P3oool001@0oooo101XKg0406Y]KP@0Jfa[0`1^JfT4071ZI`@0LfYU
101gJV@407a[I0@0PVeT0`28KfD408iaI@@0TgAX102JNfd40:f;O0@0`9V9103?YY@30<VST`@0a9n@
102oW8h40;ZGRP@0]9>7102aTHD30;6AQP@0/i>8102jV8`40<2MT@@0`Z6E102oXIL30;fSVP@0^J:J
102`VI840:ZCS0@0Y8f7102PRhH40:2>R@<0Xi>@102WVYP40:fRX0@0/:NU102e[J/40;Zc/P<0_kVh
1031_K`40<?1`@@0`l?41032aLP40<?9c0@0aLc@0`37d=D40<SDf@@0b]SM103@h>H40=CZk`@0d^gd
0`39hNL40<3Ff`@0]/[@102]_l@40:>d^0@0VJV]0`2?WJ4408FBUP@0NhN:101aNghF0?ooo`00503o
ool406Q^L0@0JFe]101ZJfX306aYI`@0KVQU101aIf<407AWH@@0NFQQ1020Jf8308U_I0@0TG9U102E
MVX409MjK@@0ZhUj1031VXT40=>YUP<0cJFC1037X9040<:MSP@0_9R:102fThH40:n>P@<0Zh^0102W
RWl40:j?Q0@0]iJ:102mVi040;fKT@<0^IbC102fWID40;2HT@@0ZY:;102TS8D40:2:Q0@0Whf70`2R
Thh40:JIUP@0[jBQ102aZ:D40;N^[0@0_[Fc0`34_;X40<Fo_P@0b<?21037a/H40<K8b@@0aL[<1037
cM430<[Ae@@0c=GI103?f]h40=SSi`@0fn_`103Hko@30<kSj@@0aMSM102kcM840;31aP@0Y[Jj102L
ZZh3096NXP@0QY>F101lQhX4075lOaH0oooo000D0?ooo`@0J6i`101YKFd406Y[JP<0K6UW101^J6D4
075WH`@0M6MQ101iJ644081[HP<0RFmT102ALVD409EfJP@0UgY]102[RGX40<6JR@@0djVF0`3=YI<4
0<NPT0@0`Yf>102lV8X40;JCQP@0[hj10`2[Rh040:N:O`@0[Xn4102gUXX40;fKT0@0_I^A0`2iW9<4
0;JMU@@0/9RA102ZTX/40:B<Q@@0X8Z4102OSHL30::CSP@0YYVF102_Y:440;6XY@@0]jj/102n]K<3
0<Bl^P@0aKnn1038`l840<O6aP@0a/S91035b/`40<O=d@<0b]7E103<eMT40<oJgP@0f>?W103Kjo04
0=S_m0<0c^?Y1035f=d40;_=dP@0/<76102V][X409bZ[P<0TIjR1026TiH407b7RP@0LGao5P3oool0
01@0oooo101XKW0406U]K@@0JV]Z0`1/JFL406iXI@@0LFMS101dIf4407UXH@@0P6]R0`29Kf@4095b
I@@0UGIZ102GNVd40:^9NP@0`IZ9103CZIH30<fUT`@0aj2@1032WHh40;bHRP@0]Y>6102_SX430:^;
P0@0YhYo102^Sh@40;NFRP@0_I^@102mVi430;VLT`@0]YfE102`V9440:ZBR`@0Y8b5102PRX@409n=
Q`<0XY>>102VVIH40:nTX@@0/JRU102g[Z`40;je/`<0a;bj1035_kh40<S3`P@0alK61036b<T40<G:
c0@0algA0`3:dMD40<cEf@@0cm[N103HhnL40=_[l0@0f>od0`3>hnT40<GHg@@0^lgB102``LH40:Jf
^P@0W:Z^0`2AWZ8408JCUP@0O8N:101aO7lF0?ooo`00503oool406Q^L0@0JFe]101ZJfX306aYI`@0
KVQU101aIf<407AWH@@0NFQQ1020Jf8308U_I0@0TG9U102EMVX409MjK@@0ZhUj1031VXT40=>YUP<0
cJFC1037X9040<:MSP@0_9R:102fThH40:n>P@<0Zh^0102WRWl40:j?Q0@0]iJ:102mVi040;fKT@<0
^IbC102fWID40;2HT@@0ZY:;102TS8D40:2:Q0@0Whf70`2RThh40:JIUP@0[jBQ102aZ:D40;N^[0@0
_[Fc0`34_;X40<Fo_P@0b<?21037a/H40<K8b@@0aL[<1037cM430<[Ae@@0c=GI103?f]h40=SSi`@0
fn_`103Hko@30<kSj@@0aMSM102kcM840;31aP@0Y[Jj102LZZh3096NXP@0QY>F101lQhX4075lOaH0
oooo000D0?ooo`@0Ifi`101XK6`406UYJ@<0JVMV101[IF8406eTH0@0L6=M101eI5d407eWGP<0RFiS
102KNfd409alKP@0WGia102]Rg`40<BKR@@0ej^G0`3@Yi@40<ZRT@@0a9j>102oVX/40;VER0@0/Xj1
0`2]Rgl40:F7O0@0Y8Ml102YRh040;2BR0@0]YJ<0`2fVHl40;BJT@@0[iN?102ZTXX40:B<Q@@0WhV3
102MRXD309j?RP@0Wi:?102WWIX40:bRW`@0/jVW102o];030<>j]`@0aknm103<a/<40<_8a`@0bL[:
1036b/`40<S=d0<0bm7D103=eMT40=CKg`@0gnOZ103Ul?<40=obmP<0e>O[103:fml40;o@d`@0]<C7
102Y^;/409j/[`<0Tj2S1028U9L407f8R`@0LWao5P3oool001@0oooo101WKW0406Q/K0@0JFUY0`1Z
IfH406]UHP@0KFAP101`Hed407ETG@@0OFMN0`29KV<409]kK@@0W7a^102MOW440:f;O0@0a9^9103G
ZiL30=2WU0@0bZ:A1034WXh40;nJR`@0^IF8102bSX430:f;O`@0YHMl102TQg`40:V;P0@0/9:8102f
UX`30;JIS`@0]9ZA102_Uhl40:ZBRP@0Y8b5102ORH<409f:Q@<0WXn:102OTXl40:NMVP@0[::O102c
ZJL40;nd/0<0`kZg1037_kd40<c6``@0blS71039b/X40<K:c0@0b<g@0`3;dM@40<gEf@@0e=_O103O
inX40>G`l`@0go;f0`3Din/40<[Kg`@0_m3C102da<L40:Vh^`@0WZb_0`2CX:<408RDU`@0OHR;101b
O7lF0?ooo`00503oool406M^L0@0J6a/101YJFT306YWIP@0JfER101]I604071SG@@0MFAM101mIeh3
08U^H`@0Vg]]102LO6h409enL@@0[H]l1034VhT40=N[U`<0d:ND103:XY440<BNSP@0_iZ;102iUHP4
0;:>P@<0[H]o102UQg`40:B7O0@0ZH^0102`TXP40;JFS0<0]YV?102dVY440:nGS`@0ZY::102TS8D4
09n9P`@0WHZ50`2NShX409nBS`@0YifJ102/XYl40;>YY`@0_kB`0`33^[L40<No_@@0c<K3103;b<L4
0<W:bP@0a/[<1038cM030<_Ae0@0cMGI103Dfml40=oWjP@0iO3c103Ol_H30=CWj`@0b]_O102od=<4
0;C4a`@0ZKRk102N[:l309>PX`@0R9BG101mR8/4079lOaH0oooo000D0?ooo`@0Ifi`101XK6`406UY
J@<0JVMV101[IF8406eTH0@0L6=M101eI5d407eWGP<0RFiS102KNfd409alKP@0WGia102]Rg`40<BK
R@@0ej^G0`3@Yi@40<ZRT@@0a9j>102oVX/40;VER0@0/Xj10`2]Rgl40:F7O0@0Y8Ml102YRh040;2B
R0@0]YJ<0`2fVHl40;BJT@@0[iN?102ZTXX40:B<Q@@0WhV3102MRXD309j?RP@0Wi:?102WWIX40:bR
W`@0/jVW102o];030<>j]`@0aknm103<a/<40<_8a`@0bL[:1036b/`40<S=d0<0bm7D103=eMT40=CK
g`@0gnOZ103Ul?<40=obmP<0e>O[103:fml40;o@d`@0]<C7102Y^;/409j/[`<0Tj2S1028U9L407f8
R`@0LWao5P3oool001@0oooo101WKFl406M[J`@0IfMW0`1WIF<406QRG`@0JF1L101[GUP406iMEP@0
MEmG0`23J5d409UhJP@0YH9d102XQGH40;F@O`@0aif;103I[9P30=:XU@@0c:>B1036WXd40<6LS0@0
_9R:102fTX@30;2<O`@0ZhUl102[RGd40:b<P0@0/924102dUHT30;FGS@@0/iN>102_UHd40:V@R@@0
Xh^4102ORH8409b9P`<0W8b8102NT8h409nGU@@0WiVH102QWId40;:[Z0<0^;>a102l^;H40<G0_P@0
a/?21036a/H40<G8bP@0alc>0`3:cm840<gDe`@0f=kP103TjN/40>cem`@0ioOk0`3Kjnh40=3OhP@0
a=;E102ha/T40:fi_0@0XJf`0`2EXJ@408VDU`@0OXR;101bO7lF0?ooo`00503oool406M]K`@0If][
101WIfL306MUH`@0J69O101YH5`406]NF0@0KUeF101eGeL308=XG@@0VGQZ102UPW@40:R5MP@0]I1o
1037WH/40=V/V0<0dZRE103<Xi840<JNS@@0`Ib<102lV8X40;JBQ0<0/8ao102[RG`40:^9O@@0[8b0
102`T8@40;BER@<0]IN=102cUhh40:nES@@0ZI29102SRh@409n9PP@0W8V30`2LS8P409j@SP@0WiNE
102OVIP40:6MW@@0/Z^X0`2h/k440;bh]P@0aL2n1036`l840<K6aP@0aLS:1037c<h30<[?dP@0cMCG
103Hg^040>CYj`@0k?Gg103Wmo/30=_[kP@0d=oR1034d]D40;S6b@@0[KVl102Q[K0309FQY0@0RIBG
101nR8/4079lOaH0oooo000D0?ooo`@0Ife_101WJf/406MWI`<0IfES101XHUl406UPG0@0JeiH101^
GEH407EOE`<0PfQM102IN6X40:F2M0@0Z8Ef102eT7l40<NMR`@0fJbH0`3BZ9D40<bSTP@0aYj=1031
W8`40;bHRP@0]Y:40`2`S7l40:^9O0@0ZhUm102/S8040;2@Q0@0]9F90`2eUhd40;>GSP@0[iF=102Y
T8T40:>;Q0@0WhV2102LRH<309b<R0@0WY2>102OUiD409nIV0@0XIfM102bZjP30;Rc/@@0_;Rf1035
`;h40<K3`P@0a/K61035b<X40<O<cP<0b/oB103=e=L40=SNh0@0i>W[103/mOL40>Ogn`<0fn_^103@
gn840<CBe@@0^<K9102]^K`40:6]/0<0UJ6T1029U9L407j8R`@0LWao5P3oool001@0oooo101WKFl4
06M[J`@0IfMW0`1WIF<406QRG`@0JF1L101[GUP406iMEP@0MEmG0`23J5d409UhJP@0YH9d102XQGH4
0;F@O`@0aif;103I[9P30=:XU@@0c:>B1036WXd40<6LS0@0_9R:102fTX@30;2<O`@0ZhUl102[RGd4
0:b<P0@0/924102dUHT30;FGS@@0/iN>102_UHd40:V@R@@0Xh^4102ORH8409b9P`<0W8b8102NT8h4
09nGU@@0WiVH102QWId40;:[Z0<0^;>a102l^;H40<G0_P@0a/?21036a/H40<G8bP@0alc>0`3:cm84
0<gDe`@0f=kP103TjN/40>cem`@0ioOk0`3Kjnh40=3OhP@0a=;E102ha/T40:fi_0@0XJf`0`2EXJ@4
08VDU`@0OXR;101bO7lF0?ooo`00503oool406I/KP@0IFUZ101UIFD306ARH0@0I5mL101TFeL406AH
D`@0IEA>101TCdL307MNE@@0RV]P102LNVd40:N4M@@0^9601038WX/40=Z]V0<0e:VF103>Y9840<NM
S@@0`IV9102mUhP40;ZEQ`<0]Y63102cSX040;:=O`@0/hn2102eTXD40;NER@<0]iR<102cUH/40:jC
RP@0ZHn7102SRh<409j9PP@0W8R20`2LSHL409jAS@@0XIJD102OV9L409^HV0@0XYnO0`2ZZ:P40;6`
[`@0^[Rg102o_[d40<;3``@0a<K71035b/`30<S>d0@0bm7D103Jg^040>OZj`@0l?Gf103]nod30>;_
l@@0e^;T1039eML40;c8b`@0/;^n102S[[4309NRY0@0RiFH101oRH/407=lOaH0oooo000D0?ooo`@0
IVa^101UJFX406EUI@<0I69P101TGe`406AKE`@0I5QC101UE4h406A?A`<0MeiE102:Jf0409ajK@@0
YhAe102hTH040<RNR`@0fZfH0`3DZIH40<jTTP@0aif=1031VHT40;fGR0@0^YF70`2fTH<40;>>P0@0
/Xeo102cSh840;FBQ@@0]iF90`2gV8`40;>ER`@0[Y>:102YShL40:>;P`@0WXV2102LR88309b=Q`@0
WY6=102QUY@409nHU`@0ViRH102RWil30:ZXZ0@0/K2_102j^;L40;nn_@@0`/?31034a/L40<G:c0<0
b<k@103;dM@40=[Nh0@0in[[103`mOH40>gko@<0h^oa103Fh^@40<WEe`@0_<S;102`^kh40:>^/@<0
Uj:T102;UIP407n9R`@0Lgao5P3oool001@0oooo101VK6h406EYJP@0IFEU0`1THV0406AOG0@0I5]G
101TF5<406EDCP@0I4m70`1gGUD408Y[H0@0W7Y]102WQ7D40;RAP0@0b9j;103J[IP30=BYUP@0cZBB
1037WHd40<6IR@@0_IN8102jUHL30;JAP`@0/hj0102bSGl40;>?PP@0]I:5102gUHT30;NHS0@0/iF;
102^ThX40:V?Q`@0Xh^3102NRH8409b8PP<0W8f7102NTHd40:6FU0@0WiRG102KV9P40::OW`<0ZZRX
102a/:l40;Zh]`@0_kjm1032`l<40<C6a`@0aL[<0`38c]040<_Ae0@0f]kP103Wj^/40?3emP@0kO_m
0`3Rko440=KRi0@0bMGG102lb</40;2k_P@0Xjja0`2GXZ@408^EV0@0OhV;101cO7lF0?ooo`00503o
ool406I/KP@0IFUZ101UIFD306ARH0@0I5mL101TFeL406AHD`@0IEA>101TCdL307MNE@@0RV]P102L
NVd40:N4M@@0^9601038WX/40=Z]V0<0e:VF103>Y9840<NMS@@0`IV9102mUhP40;ZEQ`<0]Y63102c
SX040;:=O`@0/hn2102eTXD40;NER@<0]iR<102cUH/40:jCRP@0ZHn7102SRh<409j9PP@0W8R20`2L
SHL409jAS@@0XIJD102OV9L409^HV0@0XYnO0`2ZZ:P40;6`[`@0^[Rg102o_[d40<;3``@0a<K71035
b/`30<S>d0@0bm7D103Jg^040>OZj`@0l?Gf103]nod30>;_l@@0e^;T1039eML40;c8b`@0/;^n102S
[[4309NRY0@0RiFH101oRH/407=lOaH0oooo000D0?ooo`@0IFa^101TJ6P406=SH`<0HUmN101PFeP4
05mFD`@0GU9=101LC4H405Q5?P<0K5E<1021IEX409=cIP@0Xh1b102gSgh40<ZNR`@0fjbG0`3HZiL4
0=2VT`@0bZ2?1032VHT40;ZCP`@0]Xn10`2bSGl40;2:O0@0[8Mi102/R7/40:j;O@@0/Hj20`2bTXH4
0;6BR0@0[I67102YSXD40:B;P`@0WhV1102KQh4309^;Q0@0Wi:<102SV9<40:BJV0@0Y9jL102WXJ03
0:VVY@@0[jb/102h];<40;bj^P@0`<301032a<@40<G8b@<0a/c>103;dM<40=cNg`@0jn_Z103`l_<4
0??moP<0jO?d103Li^L40<kHfP@0`<[<102c_Kl40:J`/P<0VJ>U102<UYP407n9S0@0Lgeo5P3oool0
01@0oooo101UK6h406AXJ0@0Hf=S0`1RGeh4061KF0@0GeIC101NDTd405a<AP@0F4Dn0`1/ED`4085U
FP@0Tg=V102SP7840;N?OP@0bYj;103K[9L30=R[U`@0d:JC103:X8l40<:IR@@0^Y>3102fSh430;:=
O`@0/8Yl102/QgT40:b8N`@0[X]m102aSX830;:BQP@0/I:8102]THL40:V>Q@@0Y8^3102ORH4409^7
P@<0Vh^4102OTX`40:>HT`@0Y9ZH102TWY`40:NQX0<0ZJJU102_[:`40;Rd/`@0_;Zj1030`<040<;4
a0@0aLS90`36c<h40<_Ad`@0g=kO103[jnX40?3bl`@0logn0`3Ylo@40=cVi`@0c]SJ1030b/`40;>m
_`@0Y[2b0`2IXjD408bFV0@0OhV<101cOGlF0?ooo`00503oool406E/KP@0I6QX101SHf<3069OGP@0
H5]H101OEU<405iBC@@0G4a6101HACh306aEC0@0PFEJ102CLfH40:>0LP@0]hmn103:WX/40=^/U`<0
f:^G103@YY<40<ZPS`@0`YV9102jTh<40;J?P@<0/Xeo102`RW`40:b7N@@0[8Qk102^Rgd40;6>PP<0
/Y:6102aTXP40:fAQ`@0ZHj5102TRh<409n9P@@0VhN10`2KRh@409nBS0@0XiRC102TVYP40:BNW0@0
Yj6P0`2YYZD40:n/[0@0^;Bc102l^[X40<30`0@0`/C41035b<T30<K<cP@0bm7C103Lg]l40>_[jP@0
l?;c103coOh30>Wcm0@0g>KW103>f=X40<3:c0@0/kfo102V/;8309VSY@@0S9JH101oRH`407=mOaH0
oooo000D0?ooo`@0IFa^101TJ6P406=SH`<0HUmN101PFeP405mFD`@0GU9=101LC4H405Q5?P<0K5E<
1021IEX409=cIP@0Xh1b102gSgh40<ZNR`@0fjbG0`3HZiL40=2VT`@0bZ2?1032VHT40;ZCP`@0]Xn1
0`2bSGl40;2:O0@0[8Mi102/R7/40:j;O@@0/Hj20`2bTXH40;6BR0@0[I67102YSXD40:B;P`@0WhV1
102KQh4309^;Q0@0Wi:<102SV9<40:BJV0@0Y9jL102WXJ030:VVY@@0[jb/102h];<40;bj^P@0`<30
1032a<@40<G8b@<0a/c>103;dM<40=cNg`@0jn_Z103`l_<40??moP<0jO?d103Li^L40<kHfP@0`<[<
102c_Kl40:J`/P<0VJ>U102<UYP407n9S0@0Lgeo5P3oool001@0oooo101UJfd406=VI`@0HF5Q0`1O
GE/405aGE@@0FU9>101GC4L405A6@0@0Cchg0`1PC4@407EMD`@0RVaP102NO6h40;B=O0@0bIf:103J
ZiH30=Z/V0@0e:RF103=Xi840<JMS@@0_iJ6102hT8430;:;O@@0/8Qj102]QWL40:b6N0@0[8Mi102_
RWd30;2?PP@0/925102]ShD40:Z=Q@@0YH^3102PRH8409^6P@<0UXF0102HRXD409nDSP@0YY^G102[
XYd40:fUXP<0[ZVV102b[Z`40;Nd/P@0^kVh102n_[h40<72`P@0`LK60`33bLX40<_Ad`@0gMkN103`
k>/40?Cdl`@0nOoo0`3fo?`40>?Zj`@0dm_L1034c<d40;Jn`0@0Z;6b0`2JXjD408fFV0@0P8V<101c
OGlF0?ooo`00503oool406E[K@@0HfIW101QHF4305mMF`@0G5ME101JDTh405M<A`@0E4I0101??SL3
061<A0@0MEeC102:K60409ilKP@0]8el1039WHX40=Z[UP<0fZbH103DZ9H40<fSTP@0aYf=102oUXH4
0;R@P@<0/X]m102`R7X40:f6M`@0[8Ih102/QgT40:n:O@<0/8n2102`T8D40:f?Q@@0ZXf5102URh<4
0:29PP@0VhJ10`2FQH0409R:Q@@0WiB>102VViL40:^RW@@0[JFR0`2^ZJH40;:^[0@0]kBb102k^KP4
0;jn_P@0`L;21031a/H30<?9bP@0bm7C103Mg]h40?3/j`@0m?Cc103iool30?Klo0@0hn[[103Cfm`4
0<C<c@@0][k0102X/K8309ZSY@@0SIJH1020RH`407=mOaH0oooo000D0?ooo`@0IF]]101SIVL4065Q
H@<0GeeK101LEeD405YBCP@0Eda7101DAT0404ln=`<0H4a4101eGE<408Y/H0@0WWa^102dSG`40<VM
RP@0fZ^F0`3J[9P40=BXUP@0cJ>B1036WHd40;nFQP@0^9210`2bRgd40;28NP@0[HIg102/QWP40:b7
N@@0[hYm0`2`Sh840;2@Q@@0[Hn5102ZSHD40:F;P`@0X8V2102KQX4309J5P0@0V8Z5102OU8h40:JK
U`@0Zj:M102]YJ830:jYYP@0/Zj/102g];840;^i^0@0_[jn1031`/840<76aP<0`lW:103;dM<40=gN
gP@0l>c[103dm?<40?Woo`<0m_cl103Sj^/40=?Kg0@0a<c=102f_/040:Ra/P<0VZ>U102=UYP40829
S0@0Lgeo5P3oool001@0oooo101TJf`4065UIP@0GUmO0`1LFUT405UDDP@0EDi;101BAd<404i0>`@0
BCPb0`1HACd406aEB`@0PFIJ102FMVP40:n9N0@0aY^8103HZI@30=^]V@@0ej^H103AYYD40<ZQT@@0
a9b<102nUhL30;ZBP`@0]Xmo102dS7d40;><O@@0/Xam102bSGl30;:>P@@0/I24102^ShD40:^>Q0@0
Yhf4102SS8@409j:P`<0VHR2102DQh<409B;QP@0V96=102SViL40:bTX@<0/Z^W102e[j`40;Rd/P@0
^kRg102m_;`40;fo_`@0_/;30`2naLH40<c@d@@0gMkM103`jnP40?WdlP@0nO_j0`3jo_`40>S]k0@0
emgM1037c/h40;Ro`0@0ZK6b0`2KY:D408jGV0@0PHZ<101dOGlF0?ooo`00503oool406A[K0@0HFEV
101NGel305aJF@@0FEAB101ECT/40597@`@0CT0k1019>38305Q5?@@0K5E;1021IUX409IfJ0@0[hUh
1036VhP40=RYU0<0fjfI103GZiP40=6VU@@0bZ6A1034W8`40;jGQ`<0^Y:3102fSgl40;B<O@@0/ham
102bS7d40;:=O`<0/Xj1102aT8@40:j?Q@@0Zhj4102WSH@40:><Q0@0WXZ30`2IR88409B7P`@0U8^6
102HTHd40:>KU`@0[:BQ0`2bZjL40;F_[0@0^;Bb102k^;L40;fl_0@0_Kno102n`/<30;k5aP@0c=3A
103Mg]d40?3[j0@0nOCb103inoX30?[no0@0j>g/103GgMd40<O>cP@0^;o0102Y/K8309^TY@@0SYNH
1021RX`407AmOaH0oooo000D0?ooo`@0I6]/101QIFH405iOG`<0G5YI101IE58405E>B`@0DTM3101>
@3/404Th<P<0F4Dm101/ED/4085VFP@0UWIX102_RGP40<JKR0@0f:VD0`3K[IT40=N[V0@0dJJE103:
XI440<BLS0@0_YN70`2jTX<40;J?O`@0]8am102cS7d40;:<O@@0/Xeo0`2bSX440;6@Q0@0[Xn5102[
SX@40:N=Q0@0Xhb4102NRX<309V8PP@0U8N3102DRhH409RAS@@0Xi^G102/Y:430;:[Y`@0]Jn/102h
];840;^h]`@0_Kbl102m_kl40;k2``<0_/G6103<d=440=gNg@@0l>_X103im?840?WknP<0n_kl103X
kN`40=OMg@@0alk>102h_l040:Va/P<0VjBU102>UiP4086:S0@0M7eo5P3oool001@0oooo101TJf`4
065UIP@0GUmO0`1LFUT405UDDP@0EDi;101BAd<404i0>`@0BCPb0`1HACd406aEB`@0PFIJ102FMVP4
0:n9N0@0aY^8103HZI@30=^]V@@0ej^H103AYYD40<ZQT@@0a9b<102nUhL30;ZBP`@0]Xmo102dS7d4
0;><O@@0/Xam102bSGl30;:>P@@0/I24102^ShD40:^>Q0@0Yhf4102SS8@409j:P`<0VHR2102DQh<4
09B;QP@0V96=102SViL40:bTX@<0/Z^W102e[j`40;Rd/P@0^kRg102m_;`40;fo_`@0_/;30`2naLH4
0<c@d@@0gMkM103`jnP40?WdlP@0nO_j0`3jo_`40>S]k0@0emgM1037c/h40;Ro`0@0ZK6b0`2KY:D4
08jGV0@0PHZ<101dOGlF0?ooo`00503oool406=ZK0@0H6AU101LGUh305UGEP@0EE5?101ABTL404e3
?`@0B3`g1012<bh30550>@@0Hdi5101jH5D4091aI0@0ZHAd1031Uh@40=JWTP<0gJjI103J[YX40=BZ
V0@0cZJE1039XI440<BMS@<0`9V:102lUHH40;ZBP`@0^962102gT8440;JAPP<0]I63102cTH@40;2A
Q@@0[I25102ZShH40:N?Q`@0Xhj70`2NSHL409Z<Q`@0V8f9102GSh`409VCT@@0WYVG0`2VXIl40:^X
YP@0/:j/102c/[440;Rh]`@0^[bl102l_kl30;c2``@0b/k>103Kf]X40>[Uh`@0mo7^103lnOL30?kn
n`@0k>k]103Jg]d40<W>cP@0^/30102[/K8309bTY@@0SYNH1021RX`407AmOaH0oooo000D0?ooo`@0
HfY/101PI6D405aNGP<0FEMF101EDDl4055:A`@0CD<o1018?3L4048c;P<0DD0i101SCTD407YPE@@0
T75T102YQ7@40<6GQ0@0eZNB0`3M[YT40=Z^VP@0e:ZH103>YYD40<VQT@@0a9f=0`30VHX40;bEQP@0
^Y:3102hTH840;N@P@@0]Y620`2eTH<40;>AQ0@0/965102]T8D40:Z?QP@0Yhn7102SSXL309j=Q`@0
VXb7102HSHT409N?S0@0VI>A102NVIL30:JQW`@0ZjRV102`[Z`40;>b/@@0^;Rg102j_;`40;bo_`<0
_<;3103:c/h40=_JfP@0j^GS103glNh40?cim`<0o_kk103/k^d40=[Ng@@0bLk>102j`<040:^a/P<0
W:BU102>UiP4086:S0@0M7eo5P3oool001@0oooo101SJV`4061TI@@0G5iN0`1IEeH405EAC`@0DDY7
101=@cl404Pl=`@0@S<^0`1A@3T406=>A@@0NV1E102@LF@40:V4M0@0`IN4103FYi830=f^V@@0fZjJ
103DZYP40<jVU@@0bJ6A1034WHd30<2IRP@0_9F6102jTX<40;RAPP@0]i21102fTH830;FAP`@0/i64
102`THD40:f@Q@@0ZXn6102WShL40:>>Q`<0WXf7102JS8L409R=R@@0Uhn<102ITi4409jIU`<0YZ6O
102[Z:H40;2^[0@0/k:a102h^;L40;Zl_0@0_;no0`2l`/<40<[>cP@0fm[J103ZiN<40?OakP@0o?Wg
0`3no_/40>c^k@@0f]kM1039c/h40;[0`0@0Zk6b0`2LY:D408jGV0@0PHZ<101dOGlF0?ooo`00503o
ool406=ZK0@0H6AU101LGUh305UGEP@0EE5?101ABTL404e3?`@0B3`g1012<bh30550>@@0Hdi5101j
H5D4091aI0@0ZHAd1031Uh@40=JWTP<0gJjI103J[YX40=BZV0@0cZJE1039XI440<BMS@<0`9V:102l
UHH40;ZBP`@0^962102gT8440;JAPP<0]I63102cTH@40;2AQ@@0[I25102ZShH40:N?Q`@0Xhj70`2N
SHL409Z<Q`@0V8f9102GSh`409VCT@@0WYVG0`2VXIl40:^XYP@0/:j/102c/[440;Rh]`@0^[bl102l
_kl30;c2``@0b/k>103Kf]X40>[Uh`@0mo7^103lnOL30?knn`@0k>k]103Jg]d40<W>cP@0^/30102[
/K8309bTY@@0SYNH1021RX`407AmOaH0oooo000D0?ooo`@0HfY[101OHf@405YLG0<0EUED101BCT`4
04e7A0@0B3ll1013>3<403d`:P<0CCdf101MBT4407=JC`@0RVaO102SP7040;^CP0@0dZB?0`3M[YT4
0=f`W0@0f:fK103BZIP40<fVU@@0bJ:B0`35WXh40<:KS0@0_iR9102mUXL40;^EQ@@0^YB50`2hU8H4
0;JDQP@0]9>7102aThL40:jCR@@0Zi:9102WTXX30:BAR`@0X96<102NTXd409bCS`@0WIJC102OVYL3
0::NV`@0YZ>R102/ZJP40;2_[`@0];Bd102f^;T40;Rl_@<0_<731039c<`40=OGeP@0i>7O103bkNX4
0?cgm0<0oogk103`lNl40=cOg@@0blk>102j_kl40:^a/P<0WJ>U102?UYP40869R`@0M7eo5P3oool0
01@0oooo101SJV/405mSI0@0FUaL0`1FEE@4059>C0@0CDM41018?c`404<h<`@0?C0Z0`1=?CH405e:
@@@0LeY?102:K5l40:>0L0@0^i>0103BY8l30=f^V@@0gK2L103H[I/40=:YV0@0cJJE1039XY830<FN
SP@0`Y^<102oV8T40;fFQ`@0^iF5102jU8D30;RDQP@0]YB6102dThL40;6CQ`@0[Y>9102[TXT40:NB
RP<0Y96;102PTH`409jBS@@0W9>?102MUY<409nJU`<0XYjK102VXj840:bYZ0@0/:n_102d];@40;Jh
^@@0^;bm0`2l`L<40<W<c0@0emOF103ThMl40?;]jP@0o?Od0`3ooO/40?3ak`@0g=oM103;c/h40;Zo
_`@0Zk6b0`2MXjD408nFV0@0PHV;101dOGlF0?ooo`00503oool406=ZJ`@0Gf=T101JG5`305IEE0@0
DTi<101=Ad@404Po?0@0@cPc100m<2X304dm=P@0GDY1101cFTl408Y/G`@0Xh1`102kTh040=:TS`<0
gJjI103M/9`40=R]V`@0dZVH103=YYD40<VRTP<0aIj>1032Vh`40;nHR@@0_IJ7102kUHD40;ZDQ@<0
^9B6102fU8H40;BCQ`@0/I>7102^ThT40:^BR@@0Yi::0`2TTH/40:2AS0@0WY:=102LThl409fFT`@0
WiZG0`2RWY/40:JSXP@0[:VX102`[jl40;Bd]0@0][Ri102h_;d30;c1``@0bLc<103GemH40>CQg`@0
l^gZ103lmo@30?omn`@0l?7_103Lgmd40<_>cP@0^[no102[/K8309fSY@@0SiJH1021RH/407AmOaH0
oooo000D0?ooo`@0HfY[101OHf@405YLG0<0EUED101BCT`404e7A0@0B3ll1013>3<403d`:P<0CCdf
101MBT4407=JC`@0RVaO102SP7040;^CP0@0dZB?0`3M[YT40=f`W0@0f:fK103BZIP40<fVU@@0bJ:B
0`35WXh40<:KS0@0_iR9102mUXL40;^EQ@@0^YB50`2hU8H40;JDQP@0]9>7102aThL40:jCR@@0Zi:9
102WTXX30:BAR`@0X96<102NTXd409bCS`@0WIJC102OVYL30::NV`@0YZ>R102/ZJP40;2_[`@0];Bd
102f^;T40;Rl_@<0_<731039c<`40=OGeP@0i>7O103bkNX40?cgm0<0oogk103`lNl40=cOg@@0blk>
102j_kl40:^a/P<0WJ>U102?UYP40869R`@0M7eo5P3oool001@0oooo101RJF/405eRH`@0FE]K0`1D
De8404m<BP@0BDA11014?3P403hd;`@0>B/V0`18>38405Q5?@@0K5E:1023IUT409ejJP@0]Hek103<
Wh/30=b]U`@0h;:N103K/9d40=F/V`@0dJVI103=YYH30<VRTP@0aYn?1034WHd40<6KR`@0_iV9102n
V8P30;bGR0@0^YJ9102gUXT40;FFRP@0/YJ;102`UXd40:bFS@<0ZIJ>102VUHl40:BFT0@0XiRC102R
VYH40:BLV@<0YZ2M102XY:840:bYY`@0/:j]102c/[840;Bf]P@0][Vj0`2n`L440<[;b`@0e]GC103R
gm`40>kYiP@0nO?_0`3mn?D40?7`kP@0g=gL103:cL`40;Zn_P@0Zk2`0`2LXj@408jFU`@0PHV;101d
OGlF0?ooo`00503oool4069YJ`@0GF9S101IFe/305ACDP@0Cda:1019A44404@l>0@0?S@_100i:bH3
04Ph<P@0F4Dm101/EDX408=VF@@0WGYZ102eSG/40<bOR`<0g:fG103P/Yh40=^`W@@0eJbK103AZIT4
0<fVUP<0bJ:B1036Whl40<BMS@@0`I^;102oVHT40;jHR0<0_9N8102jUXT40;NFR@@0]IJ:102bUX/4
0;2FS@@0[9J=0`2YUXh40:JES`@0Y9J@102SV9<40::JUP@0Y9bI0`2VX9d40:RTXP@0[:VW102`[Zd4
0;>b/P@0];Jf102f^KX30;k1`@@0b/_;103FeM<40>;Og0@0k^WV103ilnl30?ghm@@0lO3^103LgM`4
0<[=c0@0^[jn102[/;0309bSY0@0SYJG1021RH/407AmOaH0oooo000D0?ooo`@0HVU[101MHV<405UK
F`<0E5=B101?C4X404U4@@@0A3`h100n=2l403T[9P<0B3Pb101HACd406aEBP@0PfII102MNVX40;F=
N`@0c9n;0`3L[IL40>2bWP@0fk2M103E[9/40=6YV@@0cJJF0`39XY840<JOS`@0a9f=1031Vh/40;nI
R@@0_YR80`2lUhP40;ZFR@@0]iJ9102eUXX40;:FR`@0/9J=102/UXd30:VFSP@0YYF?102TUY040:>H
T`@0XYZF102TW9T30:JPW@@0Z:BR102/ZJL40;2^[@@0/k:b102d][H40;Ji^P<0_/71103:bl/40=KE
d`@0h]oL103^jNH40?Wck`<0oOSe103al>h40=cMg0@0b/g<102j_[h40:^`/0<0W:>T102>UYL40869
R`@0M7eo5P3oool001@0oooo101RJF/405eRH`@0FE]K0`1DDe8404m<BP@0BDA11014?3P403hd;`@0
>B/V0`18>38405Q5?@@0K5E:1023IUT409ejJP@0]Hek103<Wh/30=b]U`@0h;:N103K/9d40=F/V`@0
dJVI103=YYH30<VRTP@0aYn?1034WHd40<6KR`@0_iV9102nV8P30;bGR0@0^YJ9102gUXT40;FFRP@0
/YJ;102`UXd40:bFS@<0ZIJ>102VUHl40:BFT0@0XiRC102RVYH40:BLV@<0YZ2M102XY:840:bYY`@0
/:j]102c/[840;Bf]P@0][Vj0`2n`L440<[;b`@0e]GC103Rgm`40>kYiP@0nO?_0`3mn?D40?7`kP@0
g=gL103:cL`40;Zn_P@0Zk2`0`2LXj@408jFU`@0PHV;101dOGlF0?ooo`00503oool4065YJP@0G65R
101GFET3055AD@@0C4U81016@Cl4040i=@@0>S0/100c9b8304<e;P@0Dd4i101VCdD407]OD`@0Tg9T
102/QW@40<BHQ0<0eJNA103P/I`40=fbWP@0f:nM103D[9/40=2ZVP<0cJNG103:Xi<40<RQT@@0aYj>
1034WHd40<:KS0<0`9Z;102nVX/40;bIR`@0^IV=102gVXh40;BJS`@0/YZ@0`2_VY440:bJTP@0ZIZC
102XW9H40:RNV@@0Z9nK0`2YXYl40:ZVX`@0[:VW102^[J`40;2`/0@0/KBd102d^;T30;bo`0@0b<S8
103Cd]440=kKf0@0jNCQ103ck>P30?ObkP@0k^cY103Jf]P40<S:b@@0^Kbl102Z[Zl309bQXP@0SYFF
1021R8X407AlOaH0oooo000D0?ooo`@0HFUZ101LHF8405MIF@<0DE5A101<BDP404I1?`@0@3Te100j
<2`403<W8P<0@cD^101C@CT406I?A@@0NemC102CLV@40:b6M0@0a9R40`3EYi440>2aW0@0gK:N103H
[id40=B/V`@0d:ZJ0`3=YiL40<ZST`@0b:6A1036WXh40<BMS@@0`Y^<0`30VX/40;jJR`@0_9V;102i
VHd40;NJSP@0]9Z?102bVY030:nJT@@0[9ZB102YVY<40:RLUP@0Z9jI102XWi/30:VRW`@0ZZJS102/
ZJL40:j][0@0/;2`102a];@40;Bh^@<0_;o01038b<P40=?Bd@@0g]_H103Yi>440??/j0<0mo;^103^
k>T40=[Jf0@0b<[9102i_;`40:Z^[`<0W:6R102>UIH40868RP@0M7ao5P3oool001@0oooo101QJFX4
05aQHP@0EeUI0`1ADE4404a9B0@0AT4o1010>CD403X`;0@0<bLR0`13=Bh405=1>@@0ITm5101kGe<4
09=bI0@0[8Id1034V8@30=FWT@@0h;6L103M/Yh40=R_W@@0e:bK103@ZYX30<fWU`@0bZ>C1038XI44
0<JNSP@0a9f=1032Vh`30<2JR`@0_YZ;102lVH/40;VIS@@0]iZ>102dVXl40;:JT0<0[iZA102/VY84
0:VJT`@0Z9bF102XWYT40:ROV`<0ZJ:O102ZYZ<40:bYY`@0[Zf/102`/;040;6d]0@0];Ri0`2l_l04
0<S8b0@0dm;A103NfmP40>WTh@@0lncX0`3gl^h40>k/j@@0f][H1038b/T40;Vl_0@0ZZj_0`2LXJ84
08jEUP@0PHR:101dO7lF0?ooo`00503oool4065YJP@0G65R101GFET3055AD@@0C4U81016@Cl4040i
=@@0>S0/100c9b8304<e;P@0Dd4i101VCdD407]OD`@0Tg9T102/QW@40<BHQ0<0eJNA103P/I`40=fb
WP@0f:nM103D[9/40=2ZVP<0cJNG103:Xi<40<RQT@@0aYj>1034WHd40<:KS0<0`9Z;102nVX/40;bI
R`@0^IV=102gVXh40;BJS`@0/YZ@0`2_VY440:bJTP@0ZIZC102XW9H40:RNV@@0Z9nK0`2YXYl40:ZV
X`@0[:VW102^[J`40;2`/0@0/KBd102d^;T30;bo`0@0b<S8103Cd]440=kKf0@0jNCQ103ck>P30?Ob
kP@0k^cY103Jf]P40<S:b@@0^Kbl102Z[Zl309bQXP@0SYFF1021R8X407AlOaH0oooo000D0?ooo`@0
HFQZ101KH64405EHF0<0Ce1?1019AdH404<o?0@0?3Hc100f;BT4030T7`<0?c0Z101??CD4061:@0@0
M5U>102;K5h40:F0K`@0^i9o0`3>XH`40=^]V0@0gK:N103J/Ih40=J^W@@0djbK0`3@ZYX40<jXU`@0
c:FD103:XY440<RPS`@0aYn?0`34WXh40<:MSP@0`9b>102nW9040;bMT@@0^YjC102fWY<30;BNU0@0
/IjF102^WYH40:fOV0@0[:6K102/XYh30:bTX0@0[:NS102]ZZL40:j/Z`@0[k2_102`/[840;Bg^0<0
_Kno1036alH40=7?cP@0f]OE103Th=d40>gWh`<0l>_W103Th]l40=GDdP@0aLO5102f^KT40:R/[0<0
VZ2P102=U9D40828R@@0Lgan5P3oool001@0oooo101QJ6X405]PH@@0EEQH0`1?D4l404U7AP@0@cll
100l=S<403H]:@@0<2@O0`0o<2X404lm=@@0H4Y0101dFDh408]/GP@0YH1_102kTWl30<jQS0@0fjfH
103M/Yh40=ZaWP@0eZjM103C[9/30=2ZVP@0cZRG103<YI@40<ZRT@@0b:2?1036Whl30<BNSP@0`Yf>
1030W8h40;jLT0@0_9fA102jWY<40;JNT`<0]9jD102aWYH40:jNUP@0[InH102/XI/40:bRWP<0[:BP
102/Yj<40:fZY`@0[Zb[102_/:l40;2b/P@0];Nh0`2m_kl40<K7aP@0dLo>103JemD40>CPg@@0kNOS
0`3`jnL40>CRg`@0eMCB1035alD40;Ji^@@0Z:b/0`2JX:0408fDU@@0P8R9101cO7hF0?ooo`00503o
ool4065XJP@0Ff1Q101EF5P304m@C`@0BDM61013?c`403`f<`@0=RdY100`91l303l`:P@0Ccde101P
BT0407AICP@0RfaN102UP6l40;^BO`<0cZ6<103K[IP40=fbWP@0f[6N103F[Yd40=>/V`<0d:ZJ103>
Z9L40<bUU0@0bZ:A1038X8l40<JOS`<0a9j>1032WHh40<2LSP@0_Yb@102lWI440;ZNT`@0]YjC0`2d
WY@40;6NUP@0[YjF102]WiP40:bQV`@0[::N0`2/Y:040:bWX`@0[JZW102^[:/40:n`[`@0/;:b102d
]kP30;fo_`@0a/O6103Aclh40=[Ge@@0i>3M103]in<30?3[i`@0i>;O103Ee=840<G7a@@0][Vi102X
[:`309ZPX0@0SIBE1020R8T407=lOQH0oooo000D0?ooo`@0H6QZ101JGf4405AGE`<0CDi>1017AD@4
040l>P@0>C<`100b:RH402/Q7@<0>RdW101:>C8405Y6?0@0KEA81023IEL409]hJ0@0]8Yh0`39VhL4
0=JXT`@0g;2L103L/Ih40=V`WP@0eZjM0`3C[9`40=6[VP@0cjRH103>YYD40<bTT`@0bZ>B0`39XY84
0<NQTP@0a:2B1032XI<40<6QU0@0_j6E102lXIH30;VQU`@0]Z6H102cXIT40;:RV`@0/:>M102_Y9l3
0:jVX@@0[ZNS102^ZZL40:n[ZP@0[Zj]102_/K440;Fg]`<0_;fm1035aL@40<k<b`@0f=GB103QgMX4
0>[Th0<0kn[V103Ng=T40=3?c@@0`L;1102c][D40:JZZP<0V9jN102<TY<407n7R0@0Lg]n5P3oool0
01@0oooo101PJ6X405YOH@@0E5MG0`1=CTh404M5A0@0@3`j100i<c04038Z9P@0:b4M0`0j;BL404Xi
<P@0FTHl101]E4P408=UE`@0VgQX102dRWP30<VKQ`@0eZRC103L/9`40=baWP@0fK2N103F[Yd30=>/
W0@0dJ^J103?Z9P40<jVU@@0c:BC103:Xi830<VRTP@0aj6B1034X9840<:QT`@0`J6D102oXID40;bQ
UP<0^J6G102fXIP40;>QV@@0/Z:K102`Xid40:nTW`<0[ZJQ102^Yj<40:jZY`@0[j^Z102^[Zd40:na
/@@0]KNg0`2l_Kd40<G5a0@0c/c;103HeM840>7MfP@0j^CP0`3_j^H40=kLf@@0d<o=1031`/440;>f
]@@0YZZZ0`2HWYh408bBT`@0OhN8101cNghF0?ooo`00503oool4061XJP@0FUmQ101DEeL304e>CP@0
AdE41010?3X403Tc<0@0<RXV100[8Ad303X]9`@0BSTb101JAS`406eDB0@0PfEG102KN6P40;B:N0<0
bI^7103FZ9<40=b`W0@0g;6N103I/9h40=J^W@<0djbL103AZiX40<nXV0@0cZJE103<Y9<40<ZSTP<0
bJ:B1037XI840<BPTP@0`Z6C1031XI@40;nQU@@0_:6F0`2iXIL40;JQV0@0/j6I102bXY/40;2SW@@0
[jBO0`2^YZ440:jWX`@0[ZZW102_ZjX40:j^[@@0[k6a102e]kL30;bm_@@0aLG4103>c</40=SEdP@0
hMgJ103Zi>030>oZiP@0g]cI103@cld40<72`@@0/kJe102VZZX309RNWP@0S9:C101oQhP407=kOQH0
oooo000D0?ooo`@0H6QZ101JGf4405AGE`<0CDi>1017AD@4040l>P@0>C<`100b:RH402/Q7@<0>RdW
101:>C8405Y6?0@0KEA81023IEL409]hJ0@0]8Yh0`39VhL40=JXT`@0g;2L103L/Ih40=V`WP@0eZjM
0`3C[9`40=6[VP@0cjRH103>YYD40<bTT`@0bZ>B0`39XY840<NQTP@0a:2B1032XI<40<6QU0@0_j6E
102lXIH30;VQU`@0]Z6H102cXIT40;:RV`@0/:>M102_Y9l30:jVX@@0[ZNS102^ZZL40:n[ZP@0[Zj]
102_/K440;Fg]`<0_;fm1035aL@40<k<b`@0f=GB103QgMX40>[Th0<0kn[V103Ng=T40=3?c@@0`L;1
102c][D40:JZZP<0V9jN102<TY<407n7R0@0Lg]n5P3oool001@0oooo101PIfX405UOH0@0DeIF0`1<
CDd404A3@`@0?CXh100e<2d402dV8`@09A`I0`0e:B<404@e;P@0E44h101UCT<407YND@@0TW5Q102Z
Pg430<6EP@@0dZ:=103L[YT40=fbWP@0fk6N103H/9h30=J_W@@0e:jM103C[9/40=6ZV@@0d:RG103>
YiH30<fVU@@0c:FE103:Y9D40<RUU`@0ajJH1034YIT40<6UVP<0_ZFJ102kYI/40;RUW0@0]JBM102c
YIh40;:VX0<0/JNR102`Z:@40:nZY`@0/:bY102`[jd40;:b/0@0]kNf0`2n_K`40<K4``@0c/_9103G
dm040>3Je`@0i^3L0`3Xi>040=SFd`@0b/[8102m_[`40;2b/P@0XjNW0`2FW9`408ZATP@0OXJ7101b
NgdF0?ooo`00503oool4061WJP@0FEmP101CEUH304a=C@@0A4=3100m>SP403D`;@@0;BHS100U71T3
03DY8`@0A3D^101D@CP406E>@`@0NUiA102BLF440:Z3L@<0`IF1103BXXd40=b^V@@0gK:N103K/Ih4
0=R`WP<0eZnM103D[Yd40=>/V`@0dJZI103@Z9L40<jWUP<0cJJE103<YID40<ZTU@@0b:FG1037YYP4
0<BUV@@0`JFJ0`2nYIX40;^UV`@0^:FL102eY9d40;>UWP@0/ZJP0`2aYj840;2XY0@0[jZW102`[:T4
0;2_[@@0/[:`102g]kH30;jm_0@0a/C3103>blT40=OCd0@0h=[G103Vh=`30>STh0@0f=KC103:b/P4
0;fn_0@0/;:b102SYjL309JLW0@0RY6B101nQXL4079kOAH0oooo000D0?ooo`@0H6MZ101IGf0405=F
EP<0C4e=1014@d<403dj>0@0=C0]100]9R<402DL6@<0=BTS1014=Bh405A1>0@0IDi3101jGU44099a
H@@0ZX=a0`31UH440=:RS@@0g:jI103M/Yh40=^aWP@0f;2N0`3F[id40=B^W@@0djbK103AZYT40=2X
U`@0cZNF0`3=YYD40<bUU@@0bZBE1038YIL40<NVV0@0a:FI1031YIX30;jUVP@0^jFK102hYI`40;FT
W@@0/jFN102bYZ030;6WXP@0/:RT102_ZZL40;2/Z@@0/:n]102b/[040;Ng]P<0_[fl1036a<<40<k;
b@@0em?@103Pf]L40>KPg0<0j>CP103He]<40<[:b0@0_Kjl102`/[840:>WY`<0UYbL102:TI8407j6
Q`@0LW]m5P3oool001@0oooo101PIfX405UOH0@0DeIF0`1<CDd404A3@`@0?CXh100e<2d402dV8`@0
9A`I0`0e:B<404@e;P@0E44h101UCT<407YND@@0TW5Q102ZPg430<6EP@@0dZ:=103L[YT40=fbWP@0
fk6N103H/9h30=J_W@@0e:jM103C[9/40=6ZV@@0d:RG103>YiH30<fVU@@0c:FE103:Y9D40<RUU`@0
ajJH1034YIT40<6UVP<0_ZFJ102kYI/40;RUW0@0]JBM102cYIh40;:VX0<0/JNR102`Z:@40:nZY`@0
/:bY102`[jd40;:b/0@0]kNf0`2n_K`40<K4``@0c/_9103Gdm040>3Je`@0i^3L0`3Xi>040=SFd`@0
b/[8102m_[`40;2b/P@0XjNW0`2FW9`408ZATP@0OXJ7101bNgdF0?ooo`00503oool4061WJ@@0FEiP
101AEEH304Y<C0@0@T91100j>3L4038^;0@0:B<P100P61@302hS7P@0?BlY101=?3<405i9?P@0LUQ<
1029JU/40:1kJP<0^8ej103:W8L40=VZU@@0gK6L103L/Ih40=ZaWP<0fK2O103G/9h40=J^W@@0eJfL
103DZiX40=:ZV0<0dJRG103AZIP40<nYV@@0cZZJ103<ZY/40<ZZW0@0ajVL0`33ZId40<2XWP@0_JRN
102jZ9l40;NXX0@0]JNQ0`2cZ:<40;6YY@@0/:ZV102`[:T40;:_[0@0];:`102h]kD30;jl^`@0a<;1
103<bLH40=C@c@@0g=OC103Qg=P30=_He0@0dLo<1034a<840;Ri^0@0[:j^102PY:@309BIVP@0RHn@
101mQHH4079jOAH0oooo000D0?ooo`@0H6MY101IGV04055EEP<0BTa<1012@T4403Xh=`@0<Rh/100Y
8b04020H50<0;R<N100m;bT404dl<`@0GTTn101bF4`408UZF`@0X7]Z0`2hSGX40<ZLQ`@0fJZE103M
/I`40=baWP@0f[6N0`3I/9l40=N`WP@0eZjM103E[I`40=B[VP@0dZZH0`3AZ9L40=6YV0@0cjVI103>
ZYX40<bZV`@0bZZL1037ZI`30<>YW@@0`:RN102mZ9h40;ZXW`@0]jRP102eYj430;>XX`@0/JVU102`
ZZH40;2/Z@@0/Zn/102d/[040;Rg]@<0_[bk1034`/440<c9aP@0e=3=103Lem<40>7Lf0<0fmSD103A
cl`40<C4`P@0^;Vh102/[Zh40:2TY0<0U9VJ1029Si0407f5QP@0LWYm5P3oool001@0oooo101PIfT4
05UNH0@0DEEF0`1:C4`40492@@@0>SPg100b;R`402TS80@081PD0`0^8ah403d_:@@0CC`c101NBCh4
079HC0@0RFYK102PNfX30;R=NP@0bYb7103IZYD40=faW0@0g;6N103J/Ih30=V`W`@0ek2N103F[Yd4
0=F]W0@0e:^J103BZYP30=6XU`@0dJVH103?ZIT40<jZVP@0c:ZK103:ZY`40<NYW0<0`jVM1030Z9h4
0;fXWP@0^ZRO102gZ:040;FWX@<0/jRS102aZJD40;2ZYP@0/:bY102b[j`40;Bb/0@0^;Ne0`2n_;/4
0<C2`@@0c<W6103Dd<d40=cGd`@0hMcH0`3Kf=@40=7?c0@0a<C2102h^KP40:b^[P@0X:BT0`2DVIX4
08V?T0@0OHF6101bNWdF0?ooo`00503oool4061WJ@@0FEiP101AEEH304Y<C0@0@T91100j>3L4038^
;0@0:B<P100P61@302hS7P@0?BlY101=?3<405i9?P@0LUQ<1029JU/40:1kJP<0^8ej103:W8L40=VZ
U@@0gK6L103L/Ih40=ZaWP<0fK2O103G/9h40=J^W@@0eJfL103DZiX40=:ZV0<0dJRG103AZIP40<nY
V@@0cZZJ103<ZY/40<ZZW0@0ajVL0`33ZId40<2XWP@0_JRN102jZ9l40;NXX0@0]JNQ0`2cZ:<40;6Y
Y@@0/:ZV102`[:T40;:_[0@0];:`102h]kD30;jl^`@0a<;1103<bLH40=C@c@@0g=OC103Qg=P30=_H
e0@0dLo<1034a<840;Ri^0@0[:j^102PY:@309BIVP@0RHn@101mQHH4079jOAH0oooo000D0?ooo`@0
GfMY101HGUl4051DE@<0BD];1011@D0403Pg=P@0;b`Z100V81h401`D4@<09Q`H100f:B<404He;P@0
ET8h101YDDD4081RE0@0UWAS0`2/Q7840<2CO`@0dZ>=103K[YT40=faW@@0g;6N0`3K/Il40=ZaWP@0
fK2N103I[id40=R_W@@0f:fK0`3F[9X40=J/V`@0eJfL103D[Id40=>^W`@0d:jO103=[J030<V/W`@0
aJbP1032Zj040;j[X@@0^jZQ102hZJ830;FYX`@0/ZVT102`ZJD40;2[Z0@0/Zj/102e/[040;Zg]0<0
_kbi1034`Kl40<_7a0@0dlk;103Le]840>?NfP<0eM;?103:b<H40;jn_0@0/kBc102XZZX409bPX@<0
TYNG1027SHh407b3Q@@0LGYl5P3oool001@0oooo101OIfT405QNG`@0D5AE0`19Bd/40451@0@0>3Lf
100_;2X402HP7P@071@A0`0V71P403HY8`@0ASD^101F@SP406UAA@@0P69D102FM6<30:b4LP@0`9=o
103BXhd40=^^V@@0gK6M103L/Ih30=^aW`@0f[6N103I/9h40=V_W@@0f:nM103H[I/30=J/VP@0eZbK
103E[I`40=B]W@@0djjO103@[Yl40<f]X0<0bJbO1035[:040<:[X0@0_Z^Q102kZZ440;RYXP<0]JVS
102bZJ@40;2YY@@0/:^X102b[Z`40;Fb/0@0^[Nd0`2o_;T40<C1_`@0blO4103Cc//40=cFdP@0hmkJ
0`3Ed/l40<[8aP@0_[jl102c];<40:RZZP@0W:2Q0`2BUiL408N=SP@0O8>5101aNW`F0?ooo`00503o
ool405mWJ@@0F5iO101@E5D304U;B`@0@D50100h=cH402l/:P@09R0N100L514302HL60@0=RTS1016
=Bh405I2>0@0JE551020HU@409IdH`<0[8Ab1030Tgl40=:SS@@0fjjI103M/Id40=baWP<0fk6O103J
/Ih40=V`WP@0fJnM103H[id40=R]V`<0eZbJ103F[9/40=F]W0@0e:fM103C[Yl40=2^W`@0cJfP0`39
[9l40<F/X0@0`Z^P102nZj440;^ZX@@0^:VR0`2eZJ<40;:YY0@0/:VU102`ZjP40;:^[0@0]K:`102j
]k@30;nl^@@0a<6o103;al@40=?>b`@0g=KB103Sg]X30=GBc`@0b/S6102n_[`40;>d/`@0Z:ZZ102L
X:4309:GU`@0Qhf>101lPhD4075jO1H0oooo000D0?ooo`@0GfMY101HGUl4051DE@<0BD];1011@D04
03Pg=P@0;b`Z100V81h401`D4@<09Q`H100f:B<404He;P@0ET8h101YDDD4081RE0@0UWAS0`2/Q784
0<2CO`@0dZ>=103K[YT40=faW@@0g;6N0`3K/Il40=ZaWP@0fK2N103I[id40=R_W@@0f:fK0`3F[9X4
0=J/V`@0eJfL103D[Id40=>^W`@0d:jO103=[J030<V/W`@0aJbP1032Zj040;j[X@@0^jZQ102hZJ83
0;FYX`@0/ZVT102`ZJD40;2[Z0@0/Zj/102e/[040;Zg]0<0_kbi1034`Kl40<_7a0@0dlk;103Le]84
0>?NfP<0eM;?103:b<H40;jn_0@0/kBc102XZZX409bPX@<0TYNG1027SHh407b3Q@@0LGYl5P3oool0
01@0oooo101OIfT405MNG`@0D5AE0`18BT/403m0@0@0=SHe100]:RT402<O7@@0618@0`0O5a<402dR
7@@0?BhW101>>c8405m9?`@0MEY=102:JU/309ijJ@@0/XUf1036VH@40=JWT@@0g:jI103M/I`70=fb
WP@0gK:O103L/Yh40=baWP@0g;6M1`3K[i`40=^aWP@0f[6P103H/Z440=JbXP@0dk6R0`3?/:840<Z^
XP@0ajfR1032[J840;j/XP@0^jZR0`2gZZ<40;BZY0@0/:VT102`ZjL40;:]ZP@0];6^102i]K<30;nk
]`@0a;nl103:aL840=7;b0@0e]7=103Lf=@30<k<b@@0`l;0102h^KL40:j_[P@0XjJV102IWId308nD
U@@0QH^<101kPX@4075iNaH0oooo000D0?ooo`@0GfMY101GGUl4051DE@<0B4Y;100o@40403Hf=@@0
;BXY100S7ad401PB40<07aLC100]8Qd403d^9`@0CS/b101OBCl407EJC@@0RVYK0`2NNVT40;:9MP@0
aYV4103FYi440=b^V@@0gK6L1`3M/Yh40=fbW`@0g;:N103L/Ih40=baW@L0fjnL103K/Ih40=ZaX0@0
f;:Q103F/Z840=>aXP<0ck2R103:[Z840<N]XP@0`ZfR102n[:840;^ZXP<0]jZS102dZZ@40;2YY0@0
/:^W102b[JX40;Ba[P@0^KFc0`2o^kL40<Bo_0@0b/G2103AblP40=KAc@@0g=SD0`3>c<T40<?2`0@0
^;Vg102^[jh40:>VYP@0VIfM0`2?U9D408F;S0@0Nh:4101aNG/F0?ooo`00503oool405mWJ@@0EeiO
101@E5D304Q:B`@0?d10100f=SD402dZ:@@08alM100H4Q0301lG4`@0;B8M100m;RL404hk<P@0GdTo
101eFTd408YZF`<0WWYY102bRGH40<JIQ0@0eZNA103L[YT40=faW0L0gK:N103M/Yl40=bbWP@0g;6N
103L/Id70=^_W0@0fk6N103J/J040=RbX@@0e[:R103C/J830<n`XP@0bZjR1037[J840<:]XP@0_ZbR
102kZZ830;NZX`@0]:ZT102`ZJ@40;2[Y`@0/ZfZ102d/Jh40;Ve/`<0_k^g1034_k`40<[5`P@0dL_8
103FdLd40=cHe0<0c/c91033`/040;Ri]`@0[Zn^102SYZH409VMW@<0SiBE1025Rh`407^2Q0@0LGUk
5P3oool001@0oooo101OIfT405MNG`@0D5AE0`18BT/403m0@0@0=SHe100]:RT402<O7@@0618@0`0O
5a<402dR7@@0?BhW101>>c8405m9?`@0MEY=102:JU/309ijJ@@0/XUf1036VH@40=JWT@@0g:jI103M
/I`70=fbWP@0gK:O103L/Yh40=baWP@0g;6M1`3K[i`40=^aWP@0f[6P103H/Z440=JbXP@0dk6R0`3?
/:840<Z^XP@0ajfR1032[J840;j/XP@0^jZR0`2gZZ<40;BZY0@0/:VT102`ZjL40;:]ZP@0];6^102i
]K<30;nk]`@0a;nl103:aL840=7;b0@0e]7=103Lf=@30<k<b@@0`l;0102h^KL40:j_[P@0XjJV102I
WId308nDU@@0QH^<101kPX@4075iNaH0oooo000D0?ooo`@0GfMY101GGEl404mDE@<0AdY;100n@404
03De=@@0;2XY100Q7Q`401@@3@<05@l<100T6aH403@W8@@0A3@/101D@3L406Q@A@@0OF5C0`2@Kf04
0:=mK0@0]Hah1038W8H40=BVT0@0fjfG0`3M/I`40=faW@@0gk>O203P]9l40>2cW`<0gk:N103P/Yh4
0>:dX@@0hKJS103O]Z@40=beY0@0f;BT0`3D/j@40<naY0@0bk2T1036[Z<40<6]X`@0_:^R0`2gZJ44
0;BYX`@0/:VS102_ZJD40;2/Z0@0/jn/102g/k030;bg]0@0`;bi1037`[h40<o8a0@0d/c8103>blP3
0<K3`@@0_;^i102b/k440:VZZP@0Wj:R102FVYX308bATP@0PhV:101iPH<4071hNaH0oooo000D0?oo
o`@0GfMY101GGEl404mDE@<0AdY;100n@40403De=@@0;2XY100Q7Q`401@@3@<05@l<100T6aH403@W
8@@0A3@/101D@3L406Q@A@@0OF5C0`2@Kf040:=mK0@0]Hah1038W8H40=BVT0@0fjfG0`3M/I`40=fa
W@@0gk>O203P]9l40>2cW`<0gk:N103P/Yh40>:dX@@0hKJS103O]Z@40=beY0@0f;BT0`3D/j@40<na
Y0@0bk2T1036[Z<40<6]X`@0_:^R0`2gZJ440;BYX`@0/:VS102_ZJD40;2/Z0@0/jn/102g/k030;bg
]0@0`;bi1037`[h40<o8a0@0d/c8103>blP30<K3`@@0_;^i102b/k440:VZZP@0Wj:R102FVYX308bA
TP@0PhV:101iPH<4071hNaH0oooo000D0?ooo`@0GfMY101GGEl404mDE@<0AdY;100n@40403De=@@0
;2XY100Q7Q`401@@3@<05@l<100T6aH403@W8@@0A3@/101D@3L406Q@A@@0OF5C0`2@Kf040:=mK0@0
]Hah1038W8H40=BVT0@0fjfG0`3M/I`40=faW@@0gk>O203P]9l40>2cW`<0gk:N103P/Yh40>:dX@@0
hKJS103O]Z@40=beY0@0f;BT0`3D/j@40<naY0@0bk2T1036[Z<40<6]X`@0_:^R0`2gZJ440;BYX`@0
/:VS102_ZJD40;2/Z0@0/jn/102g/k030;bg]0@0`;bi1037`[h40<o8a0@0d/c8103>blP30<K3`@@0
_;^i102b/k440:VZZP@0Wj:R102FVYX308bATP@0PhV:101iPH<4071hNaH0oooo000D0?ooo`@0GfMY
101GGEl404mDE@<0AdY;100n@40403De=@@0;2XY100Q7Q`401@@3@<05@l<100T6aH403@W8@@0A3@/
101D@3L406Q@A@@0OF5C0`2@Kf040:=mK0@0]Hah1038W8H40=BVT0@0fjfG0`3M/I`40=faW@@0gk>O
203P]9l40>2cW`<0gk:N103P/Yh40>:dX@@0hKJS103O]Z@40=beY0@0f;BT0`3D/j@40<naY0@0bk2T
1036[Z<40<6]X`@0_:^R0`2gZJ440;BYX`@0/:VS102_ZJD40;2/Z0@0/jn/102g/k030;bg]0@0`;bi
1037`[h40<o8a0@0d/c8103>blP30<K3`@@0_;^i102b/k440:VZZP@0Wj:R102FVYX308bATP@0PhV:
101iPH<4071hNaH0oooo000D0?ooo`@0GfMY101GGUl404mDE@<0AdY;100n@40403De=@@0:bXZ100Q
7Qd401DA40<03`T7100K4a0402/P6`@0>bdV101;>C0405e7?0@0LEM;0`22IEL409=bHP@0XWi]102d
S7T40<>HQ0@0cZ6<0`3FZI@40=V]V0@0g[6L103Q/ih80>:dW`<0hK>N103R/ih40>BdX0@0iKNS103T
^:D40>6hYP@0gKFU0`3H]:D40=BcY0@0d;:T1039/:@40<>]XP@0_Z^Q0`2hZ:040;>WX@@0/:NQ102_
Z:<40:nZYP@0/JbY102d/:d30;Vd/@@0_KRe1033_[X40<W3`0@0d<_81036`l030;fl^@@0]KBc102/
[J`40:>VY@@0VijN102BUYL308V?T0@0PHN9101hP84406mhNQH0oooo000D0?ooo`@0GfMY101GGUl4
04mDE@<0AdY;100n@40403De=@@0:bXZ100Q7Qd401DA40<03`T7100K4a0402/P6`@0>bdV101;>C04
05e7?0@0LEM;0`22IEL409=bHP@0XWi]102dS7T40<>HQ0@0cZ6<0`3FZI@40=V]V0@0g[6L103Q/ih8
0>:dW`<0hK>N103R/ih40>BdX0@0iKNS103T^:D40>6hYP@0gKFU0`3H]:D40=BcY0@0d;:T1039/:@4
0<>]XP@0_Z^Q0`2hZ:040;>WX@@0/:NQ102_Z:<40:nZYP@0/JbY102d/:d30;Vd/@@0_KRe1033_[X4
0<W3`0@0d<_81036`l030;fl^@@0]KBc102/[J`40:>VY@@0VijN102BUYL308V?T0@0PHN9101hP844
06mhNQH0oooo000D0?ooo`@0GfMY101GGUl404mDE@<0AdY;100n@40403De=@@0:bXZ100Q7Qd401DA
40<03`T7100K4a0402/P6`@0>bdV101;>C0405e7?0@0LEM;0`22IEL409=bHP@0XWi]102dS7T40<>H
Q0@0cZ6<0`3FZI@40=V]V0@0g[6L103Q/ih80>:dW`<0hK>N103R/ih40>BdX0@0iKNS103T^:D40>6h
YP@0gKFU0`3H]:D40=BcY0@0d;:T1039/:@40<>]XP@0_Z^Q0`2hZ:040;>WX@@0/:NQ102_Z:<40:nZ
YP@0/JbY102d/:d30;Vd/@@0_KRe1033_[X40<W3`0@0d<_81036`l030;fl^@@0]KBc102/[J`40:>V
Y@@0VijN102BUYL308V?T0@0PHN9101hP84406mhNQH0oooo000D0?ooo`@0GfMY101GGV0404mDEP<0
Ad]<100n@D4403Df=P@0:b/[100Q81l401HD4`<02`P6100@2`P4020H4`@0;b@N100o<2T4050m=0@0
I4e20`1dFTh408AVF@@0TW9S102QOVd40:n9M`@0^i>00`35VhL40<bQSP@0dZNC103HZiH40=b_V@@0
gK2K0`3L[iX40=n`VP@0hK6L103R]9l40>BeXP@0hkNS103O]J<30=ZdX`@0eK:R103@/:840<^_XP@0
a:bQ102mZIl30;JVWP@0/ZFN102]Y9h40:bUX@@0[:JS102]ZJH40;2/Z@<0];2]102g];440;bh]@@0
`[jj1034`[l40;bk^0<0]KBb102][Zd40:JWY`@0WZ6P102FVYX408jCU0<0QXb=101oQHL407MnP0@0
KgMj5P3oool001@0oooo101OIfT405MNH0@0CeAF0`17Bd`403i1@@@0=CHf100[:b/4024P7`@05Q@C
0`0;20H4010;20@081PC100_91h403l`:@@0D3dd101TCD8307AJCP@0Q6II102BLV<40:5nK@@0[hUg
102kTh030<FKQ`@0c:6>103BYi<40=R[UP@0g:nI103M/9/30=b_VP@0gk2J103Q/I`40>:dW`@0i;FR
103S]j<40=neX`<0f[BS103E/Z840=2`XP@0bjnR1034[:440;fYW`<0]ZJN102bYIh40:fTWP@0[:FQ
102/YZ<40:fYYP@0/:bY0`2d/:d40;Nd/@@0_;Re1032_[X40<C2_`@0_;^h0`2e];840:f^[@@0YZNW
102NXJ0409JJVP@0SY>D0`26S8d407n5Q`@0Mgj0101_MgXF0?ooo`00503oool405mWJ@@0EeiP101?
E5H304M;C0@0?T51100e=SH402/[:`@08B0O100F51<300/81P@040/8100P61<402lT7P@0?c0Y101@
?C@406A=@P<0M5Y>1024IUT4099bH`@0XGi]102_RGL40;^CP0<0aI^7103<XHh40=:WT`@0f:^F103L
[iT40=f`V`<0g:nJ103O/9X40>6aW0@0h[BO103T]J840>>gX`@0gkFS0`3J]:<40=FbXP@0d;2R103;
[j840<B/X@@0_JVO0`2fYYh40;:UWP@0[JBN102/YJ440:bVX`@0[JVV102`[:T30;B`[@@0]kBa102l
^;D40<:n^P@0a<:o102l^kP30;Fd/P@0[Jj]102VYjL409jQX0@0UYZJ102>Ti@308J<S@@0OhF7101g
OX0406mgNQH0oooo000D0?ooo`@0GfMY101GGV0404mDEP<0Ad]<100n@D4403Df=P@0:b/[100Q81l4
01HD4`<02`P6100@2`P4020H4`@0;b@N100o<2T4050m=0@0I4e20`1dFTh408AVF@@0TW9S102QOVd4
0:n9M`@0^i>00`35VhL40<bQSP@0dZNC103HZiH40=b_V@@0gK2K0`3L[iX40=n`VP@0hK6L103R]9l4
0>BeXP@0hkNS103O]J<30=ZdX`@0eK:R103@/:840<^_XP@0a:bQ102mZIl30;JVWP@0/ZFN102]Y9h4
0:bUX@@0[:JS102]ZJH40;2/Z@<0];2]102g];440;bh]@@0`[jj1034`[l40;bk^0<0]KBb102][Zd4
0:JWY`@0WZ6P102FVYX408jCU0<0QXb=101oQHL407MnP0@0KgMj5P3oool001@0oooo101OIfX405MN
H0@0CeEG0`17C4d403m2@`@0=SPh100/;Bd4028R8P@061HE0`0;2@P400P50P@05Q0=100U7AP403@X
8P@0@c@/101E@ST306I@A@@0MEa@1023IeX4099cI0@0X7i]102ZQgH30;:>O@@0^YB31032VXL40<VO
S0@0cZ>?1`3CYi<40=FYU@@0f:^G103K[YT40=f`W0@0g[:N103K/Yl30=N`W`@0djnO103=[Ih40<R/
W`@0`JVM102jYY`30;>SV`@0[j:K102[XI`40:VRW@@0ZJ>O102YYJ840:bXY@<0[jbY102a[j`40;Bb
/0@0^kNd102g]K<40;:b/0<0[Jf[102VZ:H40:2RX@@0VIbL102BUYH408^@T@<0Q8Z;101lPhD407Em
O`@0KWMi5P3oool001@0oooo101OIfX405MNH0@0CeEG0`17C4d403m2@`@0=SPh100/;Bd4028R8P@0
61HE0`0;2@P400P50P@05Q0=100U7AP403@X8P@0@c@/101E@ST306I@A@@0MEa@1023IeX4099cI0@0
X7i]102ZQgH30;:>O@@0^YB31032VXL40<VOS0@0cZ>?1`3CYi<40=FYU@@0f:^G103K[YT40=f`W0@0
g[:N103K/Yl30=N`W`@0djnO103=[Ih40<R/W`@0`JVM102jYY`30;>SV`@0[j:K102[XI`40:VRW@@0
ZJ>O102YYJ840:bXY@<0[jbY102a[j`40;Bb/0@0^kNd102g]K<40;:b/0<0[Jf[102VZ:H40:2RX@@0
VIbL102BUYH408^@T@<0Q8Z;101lPhD407EmO`@0KWMi5P3oool001@0oooo101OIfX405MNH0@0CeEG
0`17C4d403m2@`@0=SPh100/;Bd4028R8P@061HE0`0;2@P400P50P@05Q0=100U7AP403@X8P@0@c@/
101E@ST306I@A@@0MEa@1023IeX4099cI0@0X7i]102ZQgH30;:>O@@0^YB31032VXL40<VOS0@0cZ>?
1`3CYi<40=FYU@@0f:^G103K[YT40=f`W0@0g[:N103K/Yl30=N`W`@0djnO103=[Ih40<R/W`@0`JVM
102jYY`30;>SV`@0[j:K102[XI`40:VRW@@0ZJ>O102YYJ840:bXY@<0[jbY102a[j`40;Bb/0@0^kNd
102g]K<40;:b/0<0[Jf[102VZ:H40:2RX@@0VIbL102BUYH408^@T@<0Q8Z;101lPhD407EmO`@0KWMi
5P3oool001@0oooo101OIfX405MNH0@0CeEG0`17C4d403m2@`@0=SPh100/;Bd4028R8P@061HE0`0;
2@P400P50P@05Q0=100U7AP403@X8P@0@c@/101E@ST306I@A@@0MEa@1023IeX4099cI0@0X7i]102Z
QgH30;:>O@@0^YB31032VXL40<VOS0@0cZ>?1`3CYi<40=FYU@@0f:^G103K[YT40=f`W0@0g[:N103K
/Yl30=N`W`@0djnO103=[Ih40<R/W`@0`JVM102jYY`30;>SV`@0[j:K102[XI`40:VRW@@0ZJ>O102Y
YJ840:bXY@<0[jbY102a[j`40;Bb/0@0^kNd102g]K<40;:b/0<0[Jf[102VZ:H40:2RX@@0VIbL102B
UYH408^@T@<0Q8Z;101lPhD407EmO`@0KWMi5P3oool001@0oooo101OJ6X405QOH@@0D5IH0`18CDh4
0413A0@0=cXj100^;c0402@T9@@06QTI0`0>3@d400D20@@02`L5100K5A4402XQ70@0>2`V1019>S83
05Q5?0@0J598101dG504089WFP@0Sg1R102INFX30::1L@@0ZHMh102`SG`40;RCPP@0_9J41032VhT3
0<FNR`@0b:2>103:XXl40<fUTP@0d:JD103@Z9H40<jYU`<0bjRH1038YiP40<BUV0@0_ZBH102hXIL4
0;>PU`<0[9jG102YWIL40:FMV0@0Y9jJ102TWi`40:FQW`@0YjBR0`2ZZ:D40:^YY`@0[ZfZ102^[J/4
0:f/ZP@0ZJVX0`2UYZD409nQX@@0VYfL102DV9P408jBT`@0Qhf>0`21QhP407Z2P`@0M7an101]MWPF
0?ooo`00503oool405mXJP@0F5mQ101@EUP304Q=CP@0@4=4100g>SX402h_<0@092@U100J6AT300h=
3@@01@81100;1`D401/E4@@0:R4L100h;2H404Tj<P<0F4Dl101XDTP407ALD0@0PVMJ102?L68409Ui
JP<0XX5a102YQgP40;2=O0@0^9>2102lUX@40<:KR@<0aIj;1038X8h40<ZRS`@0cJFB103@YY@40=2X
UP@0cZVG0`3;Z9P40<RWV0@0a:FH102nY9P40;RQU`@0/j2G0`2/WYL40:VMU`@0YIfH102TWYX40:BO
W0@0YJ6O102WY:830:ZXY@@0ZjVW102^[JX40:j]Z`@0[JbZ102YZJP30:FVY@@0Wj6Q102JWI`409BH
V0@0SY:C1027SHh30867R0@0NX:3101dO7h406efN1H0oooo000D0?ooo`@0GfQZ101HGf44051FF0<0
B4e>1010@d@403Lj>P@0;Rl`100T92D401XI6@<03Pd=10050P4400/71@@06aDA100Z8A`403P/9P@0
BCXb0`1HAC`406QBB0@0M5a@1022IeX408m`HP@0VGUZ0`2RPG440:V7N0@0/8el102hTh840;bFQ0@0
`Y^90`35WX/40<RPSP@0bZ:?103=YI840=2VU0@0d:RF103>ZIL30<^XV0@0b:NH1034YIP40;jTV0@0
^:6G102cX9L30:bNU`@0ZIfG102UWIP40:BNVP@0Y9nL102UXIl40:NTXP<0ZZRU102[ZJL40:j]ZP@0
[Zf[102][:X40:VYZ0<0YJJU102OXJ4409ZMW0@0U9RH102>TY<408N=SP<0PHN8101jPX<407AlOP@0
KGIh5P3oool001@0oooo101OJ6X405QOH@@0D5IH0`18CDh40413A0@0=cXj100^;c0402@T9@@06QTI
0`0>3@d400D20@@02`L5100K5A4402XQ70@0>2`V1019>S8305Q5?0@0J598101dG504089WFP@0Sg1R
102INFX30::1L@@0ZHMh102`SG`40;RCPP@0_9J41032VhT30<FNR`@0b:2>103:XXl40<fUTP@0d:JD
103@Z9H40<jYU`<0bjRH1038YiP40<BUV0@0_ZBH102hXIL40;>PU`<0[9jG102YWIL40:FMV0@0Y9jJ
102TWi`40:FQW`@0YjBR0`2ZZ:D40:^YY`@0[ZfZ102^[J/40:f/ZP@0ZJVX0`2UYZD409nQX@@0VYfL
102DV9P408jBT`@0Qhf>0`21QhP407Z2P`@0M7an101]MWPF0?ooo`00503oool405mXJP@0F61R101A
EeT304U>D0@0@DE7100i?3d4030b<`@09bPX100M7Ad3018A4@@01`D510040P44014>2`@07aTE100]
920403ha:`<0Bc`e101HASh406=?AP@0LU]@101oIET408M]H@<0TGEX102IO6h40:21L`@0ZHQh102/
Rg`40;6@P0<0]I>2102iUXD40;^HQ`@0_YZ:1030W8`40<6NSP@0`9j?0`2mWXl40;ZMT0@0]if@102c
Vi440:fJT0@0ZIVA0`2UV9440::HTP@0WiRC102NVID409jKV0@0WifJ102QX9h30:BSX@@0YJFS102V
YZ@40:FVY0@0Y:BS102QXZ4309fOW`@0VIbK102DV9P408nCU0@0RXn?1024RX/307j5QP@0NH22101c
Ngd406eeN1H0oooo000D0?ooo`@0GfQZ101HH684055GF@<0BDi@1011ADL403Tl?@@0<38c100W:2P4
01dM7@<04Q4A10071@D400@20@@04@h;100O6AD402dT80@0?S4[0`1;?3D405Q6?P@0Hdm6101bFe04
07mUF@@0QfeQ0`2AMFP409UlKP@0X85c102YR7P40:b;O0@0/I200`2eTh840;VFQ@@0^iR7102nVXX4
0<2LS0@0`Ij>1030WXl30;fNS`@0^Yf@102gWI040;>KT@@0[IZ@102YVI430:FHT@@0XYRB102OV9<4
09jIU@@0WY^H102OWIX40:6PWP<0Y:>Q102UYJ<40:JVY0@0YJJT102TY:<40:6RX@<0WInO102IW9/4
09BHV0@0Si>D102:Shl408B:R`<0OXF6101iP88407=kO@@0KGEh5P3oool001@0oooo101OJ6X405QP
HP@0DEMI0`19CU040455A`@0>C`m100`<S<402LX:0@07AdM0`0B4A4400L51@@01081100A3P/401lI
5@@0;B@P100n<B/304/l=@@0F4Hn101SCdH4079KD0@0OfEI1027KF43095eJ0@0VGa^102PPG<40:V8
N0@0[8]l102aT8030;FCPP@0^IJ5102kV8L40;jJRP@0`9b<1031WXh40<2NS`<0_Ij?102jWI040;NM
T0@0/i^A102]VY040:VIT@<0YIRA102RV98409nHT`@0WYVE102NViP409nMVP@0XJ2N0`2TXj440:FU
X`@0YZJT102UYZ@40:BTX`@0XJ:Q0`2MWil409VLV`@0U9RH102?Ti@408Z?S`@0Q8Z;0`1nQHH407V0
PP@0Lg]m101]MGPF0?ooo`00503oool405mXJP@0F61R101AEeT304U>D0@0@DE7100i?3d4030b<`@0
9bPX100M7Ad3018A4@@01`D510040P44014>2`@07aTE100]920403ha:`<0Bc`e101HASh406=?AP@0
LU]@101oIET408M]H@<0TGEX102IO6h40:21L`@0ZHQh102/Rg`40;6@P0<0]I>2102iUXD40;^HQ`@0
_YZ:1030W8`40<6NSP@0`9j?0`2mWXl40;ZMT0@0]if@102cVi440:fJT0@0ZIVA0`2UV9440::HTP@0
WiRC102NVID409jKV0@0WifJ102QX9h30:BSX@@0YJFS102VYZ@40:FVY0@0Y:BS102QXZ4309fOW`@0
VIbK102DV9P408nCU0@0RXn?1024RX/307j5QP@0NH22101cNgd406eeN1H0oooo000D0?ooo`@0H6Q[
101IH6<4059HFP<0BU1B1013B4T403/o@0@0<cDf100Z;2`4020Q8P<05QHG100;2PX4004000@020H5
100E4@l4028L6@@0<2LS0`0n<bd404/m=P@0EDDn101QCdH406iIC`@0MV5G0`21JUl408Q`I0@0SgIZ
102FO6l409b0L`@0XHAf0`2UR7X40:V;O@@0Zhio102]T8440;2CQ0@0/9B5102`U8L30:fCQ`@0ZY>7
102WTXL40:BAR0@0X968102MTHX309bBS0@0VY:=102HTXl409NCT0@0UiFC102JVIL409jMV`<0X:2N
102PX9l409nPW`@0WYnN102LWYd409ZLV`<0UiZI102CUiH408nCT`@0Rhn@1026Rh`40867R0<0O8>4
101gOX04075iO0@0K7Eg5P3oool001@0oooo101PJ6/405UPH`@0DUQJ0`1:D58404=8B@@0>cm0100c
=CH402X/;0@0824R0`0F5QL400/:2P@00@0010081PD401DA3`@08Q`I100`9b<303hc;@@0Bcdf101E
ACh4065?AP@0KUU?101fHEL3085ZG`@0R71T102?MVX409IlK`@0W81c102QQ7H30:F8NP@0ZH]m102[
SWl40:f@P@@0/9>4102`U8D40;2DQ`<0[I>7102ZThL40:NBQ`@0Y968102PTHP409fARP<0W9:<102J
TXd409RBS`@0Ui>@102GUI<409ZIU`@0WYfK0`2PX9h40:2PW`@0Wj2O102NWih409bNW@@0VYbK0`2G
VYT409>GUP@0Si>C102;Si0408J;S0@0PHN80`1lPh@407MnP0@0LGUl101/MGLF0?ooo`00503oool4
061XJ`@0FF1S101BF5X304Y@DP@0@dQ9100k?d0403<e=P@0:R`/100P8B8301HF5`@02`X:10010004
00P61@@05A4?100R71T4030W8`<0?S<]101;?CH405E5?P@0HDm6101^FDl407IQE`<0PFYO1028L6@4
08mfJP@0UWa_102LP7<40:64MP<0YHQj102YRgd40:^>O`@0[I21102`Th@40;2DQ@@0/9B70`2]ThL4
0:ZCQ`@0Yi:7102TTHP40:2AR0@0WI6:0`2LTX`409ZBS@@0V9:?102GTi0409NET`@0VYVG102NWI/3
0:2PWP@0X:2O102OX9l409jOWP@0W9jM102JW9/309NJV@@0TiNF102?Ti<408^?T0@0QX^<1021QhP3
07b3Q0@0Mgj0101aNG`406aeMaH0oooo000D0?ooo`@0H6Q[101IH6<4059HFP<0BU1B1013B4T403/o
@0@0<cDf100Z;2`4020Q8P<05QHG100;2PX4004000@020H5100E4@l4028L6@@0<2LS0`0n<bd404/m
=P@0EDDn101QCdH406iIC`@0MV5G0`21JUl408Q`I0@0SgIZ102FO6l409b0L`@0XHAf0`2UR7X40:V;
O@@0Zhio102]T8440;2CQ0@0/9B5102`U8L30:fCQ`@0ZY>7102WTXL40:BAR0@0X968102MTHX309bB
S0@0VY:=102HTXl409NCT0@0UiFC102JVIL409jMV`<0X:2N102PX9l409nPW`@0WYnN102LWYd409ZL
V`<0UiZI102CUiH408nCT`@0Rhn@1026Rh`40867R0<0O8>4101gOX04075iO0@0K7Eg5P3oool001@0
oooo101PJF/405YQI0@0DeYL0`1<DU@404E:C0@0?T93100f>C/402d`<@@09BLW0`0K71d4010A4P@0
10@41000000400X81`@05a@B100T7a`3034Y9@@0?C<^1015>S@40513?0@0Fda5101TE4`306mME@@0
MfAK101nJV4408A_I@@0RgAZ102?N6h309=lL0@0Uh1d102KPgL409f5N@@0WhQl102PRGd409n:O`<0
VhQn102KRGl409R8O`@0U8N0102BQh440928P`<0T8V5102?RXL408j;R@@0Shf;102AT8h4096CT@@0
UINF0`2KWYd409VKVP@0V9ZI102GVIT409FHV0@0TiJF0`2AU9@408jBTP@0RXn?1026S8`408:8R@@0
OXB60`1iP88407ElOP@0L7Qk101[M7LF0?ooo`00503oool4061YJ`@0FV5T101CFU`304aBE0@0ADY<
100n@T<403Hi>`@0;C0a100U9bL301/L7@@0414B100410@4000000@02PP7100G518402@O70<0<BTU
100m<bh404Dj=0@0D4<l101KC4D406ADC0<0KeeE101gI5/407iZH@@0Q6mU102;M6X408mhKP<0Tga`
102GP7@409^3M`@0WHEi102OR7`40:29O@@0WhYo0`2KR7h409^9O`@0V8Qo102DQh0409:7P@@0T8R3
0`2@RHD408n:Q`@0SX^9102?SH/4096@SP@0TI>A102EUiH309^NW@@0VI^J102HVYT409NIV@@0UIRH
102CUYH3096DU0@0SY:B102:Shl408J<S0@0PXR9101nQ8H307V0PP@0MGan101`N7/406]dMaH0oooo
000D0?ooo`@0H6U[101JHF@405=JG0<0C59D1015BT`403i2@`@0=STk100]<34402DW9`<06a`M100@
4A8400@410@00000100:20L401LD4P@091lL0`0a:BD403dc;P@0ACXd101@@c`405]<A@@0I5A<0`1_
GED407MTF`@0OVYQ1024KfD408]dJP@0SgQ^0`2CO70409N0M0@0Vh=g102MQGT409n8O0@0X8Um102O
RWl309^8OP@0VhUo102HR7l409B7P0@0TXN1102@R8<30929Q@@0ShZ7102>RhT408n=R`@0TI2>102A
Ti4409FGUP<0VijM102IViX409RJV@@0UiVI102EV9P409>FUP<0TIBD102>TY8408Z?S`@0QXb<1022
R8T407j4QP<0NH22101eO7h4071hN`@0JgAg5P3oool001@0oooo101QJF`405]SI@@0E5aN0`1>EEH4
04M=C`@0@DI7100i?Sl4038e=`@0:R`^0`0Q8b@401LI6P@03@l?100210@400010@@02`/:100H5QD3
02DQ7`@0<2XW100h<Bh4040h<`@0BT0k101BAd8305a@B@@0IEQA101/GUH4079SF`@0MfMP101mK6@3
089`J0@0QWA[102:N6l408ekL@@0Sgid102AOgH40961N0<0SGmg102:OWH408MmMP@0QGeg1023OWT4
089oN`<0Ph1n1025Ph4408J5Q0@0QXN6102:RXT408f?S@@0TI>A0`2BU9@409:EU0@0TIBD102AU9<4
08nCT`@0SI6A0`2;Si0408V=SP@0QX^<1022R8T407n5QP@0Nh:30`1gOX0407=kO@@0KgMj101[M7HF
0?ooo`00503oool4065YK0@0Ff=U101DG5h304iEEP@0Ade?1011ATL403Tn?`@0<SDg100Z;2h3024S
90@05aTJ100=3`l4008410@00041100;2`X401PF5@<09B4O100`:RL403Pa;P@0@3Pc101:@3/40597
@P<0G519101UF54406aNEP@0LV=K101gIf0407e/I0<0PW1X1026M6/408YhK`@0SG]a102?OW@4095o
MP@0TH5h0`2=OgL408YnMP@0Qgef1025OGL408=nN@@0PWmk0`23P7h408F3P@@0QXF41026QhH408Z:
R@@0SHn=102ATi4309:DU0@0TYFD102AU9@4096DT`@0Si>C102=TI4308^?T0@0RHf>1026Rh`408:8
R@@0OhF6101kPX<307MnP0@0Lg]m101_MgX406]dMQH0oooo000D0?ooo`@0HFU/101KHfD405ALGP<0
CUEF1017CDl40456A`@0>Cho100b=CL402X/;P<08B<T100G6AX400d?3`@00P@410000@4400/;2P@0
61HE0`0U8Al4030Z9`@0>34^1010>3<404Y0>`@0DTM20`1LD4T406EHD@@0K5iF101bHe/407MWH0@0
OFaT0`22L6P408IdJ`@0RWQ_102=Ng4408mnM0@0TGmf102APGP308eoM`@0RWif1027OGH408EmM`@0
Pgii1022Og/308>0OP@0QH>11026QH@408J7QP@0RXZ9102=Shd4096CT@<0TYBD102BUI@4096DU0@0
TIBC102?Ti<408fAT@<0Rhn@1029SHh408J;S0@0PXR9101oQHH407^2P`<0Mgj0101cNgd406mgNP@0
JgAf5P3oool001@0oooo101QJF`405]SI@@0E5aN0`1>EEH404M=C`@0@DI7100i?Sl4038e=`@0:R`^
0`0Q8b@401LI6P@03@l?100210@400010@@02`/:100H5QD302DQ7`@0<2XW100h<Bh4040h<`@0BT0k
101BAd8305a@B@@0IEQA101/GUH4079SF`@0MfMP101mK6@3089`J0@0QWA[102:N6l408ekL@@0Sgid
102AOgH40961N0<0SGmg102:OWH408MmMP@0QGeg1023OWT4089oN`<0Ph1n1025Ph4408J5Q0@0QXN6
102:RXT408f?S@@0TI>A0`2BU9@409:EU0@0TIBD102AU9<408nCT`@0SI6A0`2;Si0408V=SP@0QX^<
1022R8T407n5QP@0Nh:30`1gOX0407=kO@@0KgMj101[M7HF0?ooo`00503oool4065ZK@@0G6AV101F
GV03051GF@@0BU1B1014BT/403e2A0@0=S/l100_<c@302L[;0@07b8S100F6AX400h@40@010D61002
10@400`>3P<06QTH100V928402l[:@@0=30]100k=S<4048m>P<0BTA1101DC4L405]BC@@0HEQC101W
GEL406aQF`<0LFEO101fJV<407U]IP@0OG5Y101oLf`408=gK`@0Q7Ub0`22NG<4081iLP@0NWEa101g
M74407MfL`@0MgMd0`1iNWP407amO0@0Oh1o1021PX8408:4Q0@0QhV91029SH`308^>SPP0Rhn?102:
SXl408V>SP@0R8f=0`26Rh`408B9RP@0PHN8101oQHH407b2Q0@0N7n10`1eOGh4075jO0@0KWIi101Z
LgHF0?ooo`00503oool4065ZK@@0G6AV101FGV03051GF@@0BU1B1014BT/403e2A0@0=S/l100_<c@3
02L[;0@07b8S100F6AX400h@40@010D6100210@400`>3P<06QTH100V928402l[:@@0=30]100k=S<4
048m>P<0BTA1101DC4L405]BC@@0HEQC101WGEL406aQF`<0LFEO101fJV<407U]IP@0OG5Y101oLf`4
08=gK`@0Q7Ub0`22NG<4081iLP@0NWEa101gM74407MfL`@0MgMd0`1iNWP407amO0@0Oh1o1021PX84
08:4Q0@0QhV91029SH`308^>SPP0Rhn?102:SXl408V>SP@0R8f=0`26Rh`408B9RP@0PHN8101oQHH4
07b2Q0@0N7n10`1eOGh4075jO0@0KWIi101ZLgHF0?ooo`00503oool4065ZK@@0G6AV101FGV03051G
F@@0BU1B1014BT/403e2A0@0=S/l100_<c@302L[;0@07b8S100F6AX400h@40@010D6100210@400`>
3P<06QTH100V928402l[:@@0=30]100k=S<4048m>P<0BTA1101DC4L405]BC@@0HEQC101WGEL406aQ
F`<0LFEO101fJV<407U]IP@0OG5Y101oLf`408=gK`@0Q7Ub0`22NG<4081iLP@0NWEa101gM74407Mf
L`@0MgMd0`1iNWP407amO0@0Oh1o1021PX8408:4Q0@0QhV91029SH`308^>SPP0Rhn?102:SXl408V>
SP@0R8f=0`26Rh`408B9RP@0PHN8101oQHH407b2Q0@0N7n10`1eOGh4075jO0@0KWIi101ZLgHF0?oo
o`00503oool4065ZK@@0G6AV101FGV03051GF@@0BU1B1014BT/403e2A0@0=S/l100_<c@302L[;0@0
7b8S100F6AX400h@40@010D6100210@400`>3P<06QTH100V928402l[:@@0=30]100k=S<4048m>P<0
BTA1101DC4L405]BC@@0HEQC101WGEL406aQF`<0LFEO101fJV<407U]IP@0OG5Y101oLf`408=gK`@0
Q7Ub0`22NG<4081iLP@0NWEa101gM74407MfL`@0MgMd0`1iNWP407amO0@0Oh1o1021PX8408:4Q0@0
QhV91029SH`308^>SPP0Rhn?102:SXl408V>SP@0R8f=0`26Rh`408B9RP@0PHN8101oQHH407b2Q0@0
N7n10`1eOGh4075jO0@0KWIi101ZLgHF0?ooo`00503oool4069[K@@0GFEX101HH68305=JG0@0CEAF
1018CU040497B@@0?452100e>S/302hc=0@09b//100P8b@401PK70@041<D10072@X400H92P<041<C
100K71`402HV9@@0;2/Z100a;bh403Hd<`<0?C/i1014@Sl404U7A0@0D4a9101FDTl405]FD`<0HE]G
101VGe/406YSG`@0KVMR101`JV@407A]J0@0N75]0`1iLfl407QcK`@0M79^101dLW0407=cL@@0LgAb
0`1cMG@407IhN0@0N7]k101kOWh407f0P0@0PXF51023QhL308B8R@@0QHV:2025RXX408B9RP@0PhR9
0`21QhP40825QP@0OHB5101kPX<407V0P@@0MWeo0`1cNgd4071hNP@0KGIh101ZLgDF0?ooo`00503o
ool4069[K@@0GFEX101HH68305=JG0@0CEAF1018CU040497B@@0?452100e>S/302hc=0@09b//100P
8b@401PK70@041<D10072@X400H92P<041<C100K71`402HV9@@0;2/Z100a;bh403Hd<`<0?C/i1014
@Sl404U7A0@0D4a9101FDTl405]FD`<0HE]G101VGe/406YSG`@0KVMR101`JV@407A]J0@0N75]0`1i
Lfl407QcK`@0M79^101dLW0407=cL@@0LgAb0`1cMG@407IhN0@0N7]k101kOWh407f0P0@0PXF51023
QhL308B8R@@0QHV:2025RXX408B9RP@0PhR90`21QhP40825QP@0OHB5101kPX<407V0P@@0MWeo0`1c
Ngd4071hNP@0KGIh101ZLgDF0?ooo`00503oool4069[K@@0GFEX101HH68305=JG0@0CEAF1018CU04
0497B@@0?452100e>S/302hc=0@09b//100P8b@401PK70@041<D10072@X400H92P<041<C100K71`4
02HV9@@0;2/Z100a;bh403Hd<`<0?C/i1014@Sl404U7A0@0D4a9101FDTl405]FD`<0HE]G101VGe/4
06YSG`@0KVMR101`JV@407A]J0@0N75]0`1iLfl407QcK`@0M79^101dLW0407=cL@@0LgAb0`1cMG@4
07IhN0@0N7]k101kOWh407f0P0@0PXF51023QhL308B8R@@0QHV:2025RXX408B9RP@0PhR90`21QhP4
0825QP@0OHB5101kPX<407V0P@@0MWeo0`1cNgd4071hNP@0KGIh101ZLgDF0?ooo`00503oool4069[
K@@0GFEX101HH68305=JG0@0CEAF1018CU040497B@@0?452100e>S/302hc=0@09b//100P8b@401PK
70@041<D10072@X400H92P<041<C100K71`402HV9@@0;2/Z100a;bh403Hd<`<0?C/i1014@Sl404U7
A0@0D4a9101FDTl405]FD`<0HE]G101VGe/406YSG`@0KVMR101`JV@407A]J0@0N75]0`1iLfl407Qc
K`@0M79^101dLW0407=cL@@0LgAb0`1cMG@407IhN0@0N7]k101kOWh407f0P0@0PXF51023QhL308B8
R@@0QHV:2025RXX408B9RP@0PhR90`21QhP40825QP@0OHB5101kPX<407V0P@@0MWeo0`1cNgd4071h
NP@0KGIh101ZLgDF0?ooo`00503oool4069[KP@0GVMY101JHV@305EMG`@0D5QJ101<DU@404M=C`@0
@DM9100l@D<303Hk?0@0<3@f100Y;Rl402<W:0@071lQ100D61T700/?40@051PI100P8R8402LX:0@0
:bd/100^;bl303@e=0@0>c`k1010@Cl404A5@`@0AdQ7101<C4/3059AC`@0EeID101KFUL4061NF`@0
Hf5N101WIF4406QWI0<0KF]X101[JVP406QZJ0@0IfYY101WJf/406Q]K0<0JVi^101/LG84079fMP@0
MGUj101gNg`407]oP0@0OH:20`1oQ8@40825Q@P0P8F6101oQHH407j4Q@<0OH>4101kPX<407Z0PP@0
N7n0101fOGl407=kO@<0LGUk101^MgT406aeM`@0JG9e5P3oool001@0oooo101RJfh405iWJ@@0FV9T
0`1EGEl4051HFP@0C59D1017CDl40457B@@0?4530`0f>c`4030d=P@0:Bh_100S9bP401`O8@@051PI
1`0;3a0401@H6@@0828R100W:2P402/];0@0;Rl_0`0d=C@403/l>`@0@44o1014AD<404M8A`@0C4a;
0`1BDDl405MFE0@0FeYG101PGU/406=QGP@0IfEQ101XIf@306e[J0@0JfYX101XJVP406MZJ@@0If][
101XKF`306Y^KP@0K75b101bMWH407EiNP@0Mg]l101kOh0407f2PP<0OhB41020QHD80825QP@0OhF6
101nQ8D307f3Q0@0Nh:3101jP88407QoP0@0MWeo101cNgd3075iN`@0KWMi101/MGL406UbMAH0oooo
000D0?ooo`@0HV]^101NIfT405YRI0<0EEeO101@F5X404aBE0@0Ade?1011AdT403a1@`<0=S/l100`
=3H402T^;`@08bLX100L7b4401@H6@L02`l@100D61T4020R8P@09bPX100[;B`402h_;`<0=3Dd100k
?3/40411?`@0A4E31017B4L404a<B`<0DU5?101GEU@405]JE`@0H5iK101SHEh406MUH@@0J6MT0`1]
JfP406]ZJ0@0J6YX101WJVT406M[J`@0J6e/0`1ZKVh406aaLP@0LWIf101eNGX407MkO0@0Ngn0101m
PX8307n4Q0@0P8F52020QHH407n5QP@0OXB50`1mPh@407^2P`@0NX22101hOh0407ImO`@0Lg]m0`1a
NG/406igN@@0K7Eg101YLWDF0?ooo`00503oool4069[KP@0GVMY101JHV@305EMG`@0D5QJ101<DU@4
04M=C`@0@DM9100l@D<303Hk?0@0<3@f100Y;Rl402<W:0@071lQ100D61T700/?40@051PI100P8R84
02LX:0@0:bd/100^;bl303@e=0@0>c`k1010@Cl404A5@`@0AdQ7101<C4/3059AC`@0EeID101KFUL4
061NF`@0Hf5N101WIF4406QWI0<0KF]X101[JVP406QZJ0@0IfYY101WJf/406Q]K0<0JVi^101/LG84
079fMP@0MGUj101gNg`407]oP0@0OH:20`1oQ8@40825Q@P0P8F6101oQHH407j4Q@<0OH>4101kPX<4
07Z0PP@0N7n0101fOGl407=kO@<0LGUk101^MgT406aeM`@0JG9e5P3oool001@0oooo101SK6l405mX
J`@0G6AW0`1HH68405AKGP@0D5MI101<DU@404M>D0@0@TU:0`0n@dD403Pn@0@0<cPj100]<S@402L/
;P@08BHX100K7b43018G6@@041HG100F71d4028V9`@0:Bd^100]<C4302lb<P@0<SHf100f>SX403Xn
?P@0?d=31012ATH304A8B0@0BDe=101@De<405IHEP@0FE]J101MGU`405iQH0<0I6ET101SIF@4065U
I@@0HFIV101QIfP406=YJ@<0IF]/101VKFh406mdM0@0LGIg101dNGX407IlO0@0N7io0`1jOh0407^0
P@P0Nh62101jPH8407Z0PP<0NH21101hOh0407ImO`@0MGan101cNgd4075iN`<0KgMj101]MWP406]d
MP@0JG9e5P3oool001@0oooo101SK6l405mXJ`@0G6AW0`1HH68405AKGP@0D5MI101<DU@404M>D0@0
@TU:0`0n@dD403Pn@0@0<cPj100]<S@402L/;P@08BHX100K7b43018G6@@041HG100F71d4028V9`@0
:Bd^100]<C4302lb<P@0<SHf100f>SX403Xn?P@0?d=31012ATH304A8B0@0BDe=101@De<405IHEP@0
FE]J101MGU`405iQH0<0I6ET101SIF@4065UI@@0HFIV101QIfP406=YJ@<0IF]/101VKFh406mdM0@0
LGIg101dNGX407IlO0@0N7io0`1jOh0407^0P@P0Nh62101jPH8407Z0PP<0NH21101hOh0407ImO`@0
MGan101cNgd4075iN`<0KgMj101]MWP406]dMP@0JG9e5P3oool001@0oooo101SK6l405mXJ`@0G6AW
0`1HH68405AKGP@0D5MI101<DU@404M>D0@0@TU:0`0n@dD403Pn@0@0<cPj100]<S@402L/;P@08BHX
100K7b43018G6@@041HG100F71d4028V9`@0:Bd^100]<C4302lb<P@0<SHf100f>SX403Xn?P@0?d=3
1012ATH304A8B0@0BDe=101@De<405IHEP@0FE]J101MGU`405iQH0<0I6ET101SIF@4065UI@@0HFIV
101QIfP406=YJ@<0IF]/101VKFh406mdM0@0LGIg101dNGX407IlO0@0N7io0`1jOh0407^0P@P0Nh62
101jPH8407Z0PP<0NH21101hOh0407ImO`@0MGan101cNgd4075iN`<0KgMj101]MWP406]dMP@0JG9e
5P3oool001@0oooo101SK6l405mXJ`@0G6AW0`1HH68405AKGP@0D5MI101<DU@404M>D0@0@TU:0`0n
@dD403Pn@0@0<cPj100]<S@402L/;P@08BHX100K7b43018G6@@041HG100F71d4028V9`@0:Bd^100]
<C4302lb<P@0<SHf100f>SX403Xn?P@0?d=31012ATH304A8B0@0BDe=101@De<405IHEP@0FE]J101M
GU`405iQH0<0I6ET101SIF@4065UI@@0HFIV101QIfP406=YJ@<0IF]/101VKFh406mdM0@0LGIg101d
NGX407IlO0@0N7io0`1jOh0407^0P@P0Nh62101jPH8407Z0PP<0NH21101hOh0407ImO`@0MGan101c
Ngd4075iN`<0KgMj101]MWP406]dMP@0JG9e5P3oool001@0oooo101TKG04065ZK0@0GVIY0`1KHfD4
05MOHP@0E5aN101AF5X404eDEP@0BE1B0`15C4h40458BP@0?D=5100i?d0403@j?0@0;cDf100Y;c43
02@Z;0@07bDW100J8B<401`S9@@09R`]100/<S@3034f=`@0<cTi100f?3`403Lm?`@0>T52100nADL3
0499BP@0AD]=101:D58404iDE@@0E5UJ101HG5`405YNGP<0G61P101NHF8405eRH`@0G69S101LI6D4
05iUIP<0HVQY101SJVX406Y`L@@0KW=d101`MWL4079iNP@0M7Yl0`1eO7d807ImOPP0MWeo101fOGh3
07ElOP@0M7]m101cNg`4079jO0@0L7Qk101_MgT306efN0@0K7Ag101ZLgH406QbM1H0oooo000D0?oo
o`@0I6e`101QJV`405iVJ@<0Ff=U101GGf8405ALGP@0DEQJ101=E5H404U@DP<0ADa>1011B4X403e3
A@@0>Cm0100d>S`402le=P@0:Bla0`0T:R`401lU9`@06R4S100L8bD402H/;@@0;38d0`0a=SL403<i
>@@0=S`l100g?Cl403Y1@P@0?TE70`12BDX404E;C@@0BU1B101>E5D405AIFP@0F5aL101JGUh305aP
H0@0GV5R101MHV<405aRH`@0G6AU101NIFH3069XJ@@0HfYZ101ZL74406icM0@0L7Ig101bNGX407Aj
O0<0MGam201fOGh807ImO`@0MWen0`1eO7h407AkO@@0Lg]l101bNW`4071hN`@0KgMi0`1]MWP406ad
M`@0JW=f101XLW@F0?ooo`00503oool406A]L0@0HFY/101NIVT305]SI@@0EemR101DG5h4055HFP@0
CEAF1019D58304E<CP@0@DQ:100m@dD403To@0@0=3Xl100_=CH402T_<@<092X/100O9BL401XQ8`@0
72<U100V;2d402`b=0<0<CHg100c>CT403Hl?0@0=cdo100j@D8403i5A`<0@TU:1015Bdd404Y@DP@0
CUAE101DFEX405QLG0@0FUiN0`1LH60405iQHP@0GF9S101LHV<405aTI@@0GVEV0`1RJ6T406=ZJP@0
JW1a101^Lg@4071fM`@0LWUj101dNW`307ElO@P0MWen201fOGl407ImOP<0MGan101dNgd407=kO0@0
LWYl101`N7/406mgN@<0KGIh101/M7L406YcMP@0J79d5P3oool001@0oooo101TKW44069/KP@0H6U[
0`1NIVT405]TIP@0FF5S101FGV0405=KG@@0DEQJ0`1>EEL404]BE0@0Adi@1014Bdd40417B@@0?D=6
100i?d8303Dl?P@0<CPk100]=3L402P_<P@0:30c100Z<cH3030h>P@0=ci0100h@44403U1@P@0>dA6
100oAdT304=:C0@0ADe?1018D54404YBE0@0CUEG101@F5T405EKG0<0EeaN101IGUl405]OH@@0Ff1Q
101MHf@405YPH@<0G6=T101SJV/406Q^L0@0Jg9c101]M7H406mfN0@0L7Mi0`1aN7X4079iN`P0LWYk
101bNW`4079iN`<0LGUk101`N7/4071hNP@0KgMi101^MWT406eeN0<0K7Ag101ZLgH406UbM@@0J75d
5P3oool001@0oooo101TKW44069/KP@0H6U[0`1NIVT405]TIP@0FF5S101FGV0405=KG@@0DEQJ0`1>
EEL404]BE0@0Adi@1014Bdd40417B@@0?D=6100i?d8303Dl?P@0<CPk100]=3L402P_<P@0:30c100Z
<cH3030h>P@0=ci0100h@44403U1@P@0>dA6100oAdT304=:C0@0ADe?1018D54404YBE0@0CUEG101@
F5T405EKG0<0EeaN101IGUl405]OH@@0Ff1Q101MHf@405YPH@<0G6=T101SJV/406Q^L0@0Jg9c101]
M7H406mfN0@0L7Mi0`1aN7X4079iN`P0LWYk101bNW`4079iN`<0LGUk101`N7/4071hNP@0KgMi101^
MWT406eeN0<0K7Ag101ZLgH406UbM@@0J75d5P3oool001@0oooo101TKW44069/KP@0H6U[0`1NIVT4
05]TIP@0FF5S101FGV0405=KG@@0DEQJ0`1>EEL404]BE0@0Adi@1014Bdd40417B@@0?D=6100i?d83
03Dl?P@0<CPk100]=3L402P_<P@0:30c100Z<cH3030h>P@0=ci0100h@44403U1@P@0>dA6100oAdT3
04=:C0@0ADe?1018D54404YBE0@0CUEG101@F5T405EKG0<0EeaN101IGUl405]OH@@0Ff1Q101MHf@4
05YPH@<0G6=T101SJV/406Q^L0@0Jg9c101]M7H406mfN0@0L7Mi0`1aN7X4079iN`P0LWYk101bNW`4
079iN`<0LGUk101`N7/4071hNP@0KgMi101^MWT406eeN0<0K7Ag101ZLgH406UbM@@0J75d5P3oool0
01@0oooo101TKW44069/KP@0H6U[0`1NIVT405]TIP@0FF5S101FGV0405=KG@@0DEQJ0`1>EEL404]B
E0@0Adi@1014Bdd40417B@@0?D=6100i?d8303Dl?P@0<CPk100]=3L402P_<P@0:30c100Z<cH3030h
>P@0=ci0100h@44403U1@P@0>dA6100oAdT304=:C0@0ADe?1018D54404YBE0@0CUEG101@F5T405EK
G0<0EeaN101IGUl405]OH@@0Ff1Q101MHf@405YPH@<0G6=T101SJV/406Q^L0@0Jg9c101]M7H406mf
N0@0L7Mi0`1aN7X4079iN`P0LWYk101bNW`4079iN`<0LGUk101`N7/4071hNP@0KgMi101^MWT406ee
N0<0K7Ag101ZLgH406UbM@@0J75d5P3oool001@0oooo101UKW4406A]L0@0HV]^0`1QJV`405mXJP@0
GFIX101LI6L405YRI@@0F61R0`1FGV0405ALGP@0DUYL101?EeX404eEE`@0Be9E1018D58304E=D0@0
@d]=1010B4/403i6B@@0?DI9100mADT303Y3A`@0?TI92011BD`4049:C0@0@TY=0`15CTl404]BE0@0
CEEF101?EeT4059IF`@0DeYL101EG5h305QNH0@0FF1R101KHF<405IMG`@0Ff5T101NIFL3065XJP@0
I6]]101WKW0406UaL`@0Jg9d101/M7H406eeM`<0KWEg201^MWP806ifN@L0KWIh101]MWP406eeN0@0
K7Eg101[M7L406]dMP<0JW=f101YLWD406QbM0@0Ig5d5P3oool001@0oooo101UKW4406A]L0@0HV]^
0`1QJV`405mXJP@0GFIX101LI6L405YRI@@0F61R0`1FGV0405ALGP@0DUYL101?EeX404eEE`@0Be9E
1018D58304E=D0@0@d]=1010B4/403i6B@@0?DI9100mADT303Y3A`@0?TI92011BD`4049:C0@0@TY=
0`15CTl404]BE0@0CEEF101?EeT4059IF`@0DeYL101EG5h305QNH0@0FF1R101KHF<405IMG`@0Ff5T
101NIFL3065XJP@0I6]]101WKW0406UaL`@0Jg9d101/M7H406eeM`<0KWEg201^MWP806ifN@L0KWIh
101]MWP406eeN0@0K7Eg101[M7L406]dMP<0JW=f101YLWD406QbM0@0Ig5d5P3oool001@0oooo101U
KW4406A]L0@0HV]^0`1QJV`405mXJP@0GFIX101LI6L405YRI@@0F61R0`1FGV0405ALGP@0DUYL101?
EeX404eEE`@0Be9E1018D58304E=D0@0@d]=1010B4/403i6B@@0?DI9100mADT303Y3A`@0?TI92011
BD`4049:C0@0@TY=0`15CTl404]BE0@0CEEF101?EeT4059IF`@0DeYL101EG5h305QNH0@0FF1R101K
HF<405IMG`@0Ff5T101NIFL3065XJP@0I6]]101WKW0406UaL`@0Jg9d101/M7H406eeM`<0KWEg201^
MWP806ifN@L0KWIh101]MWP406eeN0@0K7Eg101[M7L406]dMP<0JW=f101YLWD406QbM0@0Ig5d5P3o
ool001@0oooo101UKW4406A]L0@0HV]^0`1QJV`405mXJP@0GFIX101LI6L405YRI@@0F61R0`1FGV04
05ALGP@0DUYL101?EeX404eEE`@0Be9E1018D58304E=D0@0@d]=1010B4/403i6B@@0?DI9100mADT3
03Y3A`@0?TI92011BD`4049:C0@0@TY=0`15CTl404]BE0@0CEEF101?EeT4059IF`@0DeYL101EG5h3
05QNH0@0FF1R101KHF<405IMG`@0Ff5T101NIFL3065XJP@0I6]]101WKW0406UaL`@0Jg9d101/M7H4
06eeM`<0KWEg201^MWP806ifN@L0KWIh101]MWP406eeN0@0K7Eg101[M7L406]dMP<0JW=f101YLWD4
06QbM0@0Ig5d5P3oool001@0oooo101VKg8406E_L@@0I6i`0`1TKG0406=/K`@0HV]^101QJVd4061Y
K0@0GfQ[0`1NIfX405eVJ@@0G6EW101KI6H405YRI@@0FF5T101GH6<305IOH@@0EEeP101DG5l405=K
GP@0DU]N101BFUh3055JGP@0DU]N101CG5l405=KG`@0DeaO101BFUh3051IG@@0DEYN101BFed405=L
GP@0E5eP101EGV0405INH0<0EUiQ101HH6<405iVJ0@0GfMZ101QJF/4069[K@<0I6a^101UKW0406M_
L@@0J71c101YLG@406UbM0@0JW9e1`1ZLgDC06YcMPP0JW=e301YLWD306QbM0@0J75d101WLG@406Ma
LaH0oooo000D0?ooo`@0IVmb101UKg4406A^L0<0I6e`101SK6l4069[KP@0HFY]101PJF`405mXJ`<0
GVMZ101MIVT405aUI`@0FfAV101JHVD405UQI0@0Ef1S0`1FGf4405EMH0@0E5aO101CFeh4059KGP@0
DUYN0`1AFUh4059KGP@0DeaO101CFel405=LG`@0DUYN0`1@FEd4055JGP@0DU]M101CG5h405AMH0@0
EEiP101FGV0305INH@@0F61S101NIVP405mWJP@0HFU[101RJfd306A/KP@0IFi`101WKg4406Q`L`@0
JG5d101YLW@406YbM@L0JW=e4`1ZLgH806YcM@`0JG9e0`1XLW@406QaM0@0Ig5d101WLG<F0?ooo`00
503oool406I_LP@0IFma101TKW0306A]L0@0Hfa_101RJfh4065ZK@@0H6U/101OJ6/305iWJP@0GFIY
101LIFL405]TIP@0FV9U101IHF@405MPH`<0EUmQ101EGF0405ALG`@0De]N101BFeh4059JGP<0DEYN
101BFeh405=LG`@0De]O101CG5l4059JGP<0D5UM101AFUh4059KG@@0DeaN101DGF0405ENH0@0EUiP
0`1FGV4405QPH`@0GVIX101OIfX4065YJ`@0HV]]0`1TK6h406E^L0@0Ifma101XL7<406UaM0@0JG9d
101ZLWD706YcMA<0JW=f201ZLgD<06UbM@<0J79d101XLG@406MaM0@0Ig5c5P3oool001@0oooo101V
Kg8406E_L@@0I6i`0`1TKG0406=/K`@0HV]^101QJVd4061YK0@0GfQ[0`1NIfX405eVJ@@0G6EW101K
I6H405YRI@@0FF5T101GH6<305IOH@@0EEeP101DG5l405=KGP@0DU]N101BFUh3055JGP@0DU]N101C
G5l405=KG`@0DeaO101BFUh3051IG@@0DEYN101BFed405=LGP@0E5eP101EGV0405INH0<0EUiQ101H
H6<405iVJ0@0GfMZ101QJF/4069[K@<0I6a^101UKW0406M_L@@0J71c101YLG@406UbM0@0JW9e1`1Z
LgDC06YcMPP0JW=e301YLWD306QbM0@0J75d101WLG@406MaLaH0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002E0?oo
o`900000R@3oool009L0oooo00=000000?ooo`3oool0QP3oool007l0oooo00=000000?ooo`3oool0
2@3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo0?ooo`200?ooo`00OP3o
ool00d000000oooo@00000090?ooo`06@000003oool0oooo@000003ooom00000103oool014000000
oooo0?oood0000280?ooo`00OP3oool00d000000oooo@00000090?ooo`05@000003oool0oooo@000
003oool00d0000020?ooo`04@000003oool0oooo@00008P0oooo001n0?ooo`03@000003ooom00000
00X0oooo0d000000103ooom00000@000040000030?ooo`=00000R03oool007h0oooo00=000000?oo
od000000303oool00d000000oooo0?ooo`2@0?ooo`00O`3oool00d000000oooo0?ooo`0:0?ooo`90
0000TP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(45) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
727576727476727476727476717475717475717475717375717374717374717374717274717273\
717273717273717272717172717172717172717171717071717070716F6F706D6C
7170707171717171727171727072737071727071727071727070726F71726F70726F71726F7173\
6F72746F737570747671757871767972777A72787A727A7C747B7E757D80767F83
788387767E82757C7F747B7D747A7C74797B73797B73787A73787A737779737779737779727678\
727678727677727577
727476727475717475717375717374717374717273717273707172707172707071707071707070\
706F6F706F6F706E6E706E6E706D6D706D6D706C6C706C6B706B6A706A68706865
706B69706C6C706D6E706D6E6F6E6F6F6E6E6E6D6E6D6D6E6D6D6E6D6D6E6C6D6E6C6E6F6D6F70\
6D71736E72746F747770767971787B727A7D737C7F747E827681867885897A888E
7C8B9179868A788287778084767E82757D80757C7F757B7E747B7D747A7C74797B73787B73787A\
737779727678727677
7274767173757173747173747172737071727071717070707070706F6F6F6F6E6F6F6E6E6F6D6D\
6F6C6C6F6C6B6E6B6A6E6B6A6E6A696E69686E68676F68656F66646F65626F635F
7066646F68676F6A696F6A6A6E6A6A6D6A6A6C6A6A6B696A6C696A6B696A6A6A6B6B6C6D6B6D6F\
6C6F716C71736E74776F777A717A7D727C8074808375838878878C7A8C927E9199
7E8F967C8B917A888D79858A788387778185768083767F82757D81757C7F747B7E747A7C74797B\
73787A737779727678
7274757173747172737072737071727070716F6F706F6E6E6F6E6E6F6D6C6E6C6C6E6B6B6E6A6A\
6E69686D68676D68666D67656D66646D65636D64626D63606E625F6E615D6E5F5A
6F63606F65636E66656E67666D67676C67676B67676A67676A66676A6667696868696A6B6A6C6E\
6B6E706B70736C74776E787B707B7F727F8375838877888D7A8C937D92998198A1
7F949B7D90977C8C927A898F79878C798589788387778286778084767E82757D80757C7E747A7D\
74797B73787A727678
7174757173747172737071727070706F6F6F6F6E6E6E6D6D6E6C6B6E6B6A6D6A696D69686D6766\
6C66656C65646C64626C63616C62606C615E6C605D6C5F5B6D5F5A6D5E586E5C56
6E605C6E625F6D63626D64636C65646B65646A6565696565696464696465686566686869696A6D\
696D6F6A70736B73776D787C707D8172818676868B798C927B91987F979F829CA6
8098A07F949B7D90977C8D947B8B917A888E79868B788489788287778184767F82757D80757B7E\
747A7C73787A737778
7174757172737071727070716F6F6F6F6E6E6E6C6C6E6B6B6D6A696D69686C67666C66656C6563\
6B64616B62606B615E6A605D6A5F5B6A5D596A5C586B5B576C5B556D5A556E5A54
6E5D596E5F5C6D615F6C62606B62616A63626A636369636368636367636367646567666768696B\
686C6E6970736A73776C797D6F7F8372838976898E798F967D959E819CA6839FA9
819BA48097A07F949C7D91987C8E957B8C927A898F7A878C79858A788387778184767F82757D80\
747B7E74797B737779
7173757172737071716F6F706F6E6E6E6C6C6E6B6A6D69696C68676C66656B65636B64626A6260\
6A615E6A5F5C695E5A695C58695B576959556958536957516A57506D57506F5A53
6E5C576D5D5A6C5E5C6C5F5E6B605F6A606069616068616167616267616266636466656667686A\
676B6E6870736A74786C7A7D6F7F8472868B768B927A929A7E99A283A1AC83A1AB
829EA7819AA38097A07F949C7E91997D8F957C8C927B898F7A878C798589788287778084767E81\
757C7F747A7C737779
7173757072727070716F6E6F6E6D6D6E6B6B6D69696C68676C66656B64636A63616A615F695F5C\
695E5A685C58685A5667595467575267555066544E66524C66514A705850715B54
6F5B566D5C586C5D5A6B5D5C6A5E5D695E5D685F5E675F5F665F5F666060656262656465666769\
676B6E6870736975786C7A7E6F818672878D778E957C959D7F9CA684A5B084A3AE
83A0AB829DA7819AA38097A07F959C7E92997D8F957C8C927B8A8F7A878C798489788185767F83\
757D80747A7D73787A
7173747071726F6F706F6E6E6E6C6C6D6A696C68676C66656B64626A626069605E695F5C685D59\
675B5767595566575266555065534E65514B644F49634D46644C44765C53715A53
6F5A556D5A566B5B586A5B59695C5B685C5B675C5C665C5D655D5D655E5F646161646465656769\
666C6E6771746976796C7B806F828773888F7790977C97A0809FA985A7B385A6B1
84A3AE83A0AB829EA7819BA48098A07F959C7E92997D8F957C8C927B898E7A868B788387778084\
767E81747B7D73787A
7173747071716F6E6F6E6D6D6D6B6A6C69686C67656B64636A626069605E685E5B685C59675A56\
66585365565165544E64524C644F49634D46634B446048406B5048745A52705852
6E58536C58546B5956695957685A59675A5A665A5A655A5A645A5A635B5D635F6063636465686A\
666D6F67727469777A6D7D81708489748A907891997C99A281A0AB85A9B585A9B5
85A6B284A4AE83A1AB829EA7829BA48198A07F949C7E91987D8E947C8B917A888D798589788285\
767E82757B7E73787A
7173747070716F6E6E6E6C6C6D6A696C67666B65646A636169605E685E5B675C58665A56665753\
65555064534D63504A634E48624C4561494260463E674C4370544B70554D6E5550
6C56516B5652695653685756675857665858655858645758635758625A5B625E5F62636464686A\
656E7067737569787C6D7E8371858A758C9379939A7C99A281A0AB84A8B487ACB9
86AAB685A7B385A4AF84A1AB839EA7829BA381979F80949B7E90977D8D937B8A8F7A868B788387\
777F83757C7F73787B
7172737070706F6D6D6D6B6B6C69686B66656A646269615F685F5C675C59665A56655753645450\
63524D624F49624D46614B4361484060463D63463D6E50476E51486D524B6C534D
6B534E69534F68545167565466565666575765565663565762555661595A615D5E626264626768\
646E706673766A7A7D6E808472878C778E947A949C7D9AA381A0AB83A7B387ADBA
88AEBB87ABB786A8B385A4AF84A1AB839EA7829AA381979E7F939A7E8F957C8B917B878C798488\
778084757C7F74797B
7172736F6F706E6D6D6D6A6A6C67666B65636A6260685F5D675D5A665A5665575364545063524C\
624F49614C46604A425F473F5F453C5E42386D4D436E4F456D50476C50496A504B
69504B67504C66524F665453665555655555655556635657615758605959615E5F616163606466\
636C6E6573756A7B7D6F828573888D788F967B959D7E9BA480A0AB83A7B286ACB8
89B1BF88AEBB87ABB787A8B386A4AF85A1AA849DA68299A181959C7F91987D8D937C898E7A858A\
788185767D8074797B
7172736F6F6F6E6C6C6D69696B66656A646269615E685E5B665B5765585464555063524D614F49\
604C465F49425E463F5D433B5D40376243387150456E4F466C4E466B4F48694E48
674D48644D49644F4D66535365545463545468595A645858625A5B605A5B5F5B5D5E5F615E6264\
61696C636F726A797C6F8386758A8E7991977C979F7E9CA480A0AA82A6B185ABB7
88B0BE89B2C089AFBC88ABB788A8B387A4AE86A0A9849CA482989F80939A7E8F957C8B907A868B\
788286767E8174797C
7072736F6E6F6E6B6B6C69686B6564696260685F5D675C5965595564565163534E614F4A604C46\
5E49425D463E5C433B5C40375A3C336C4B3F704F446E4E456B4D456A4E48674C46
654A45624A46624D4B635151675858655857685C5C645A5A625A5B605B5B5E595A5D5F615D6264\
5E66695F6A6D687579718286778C907B92987E99A07F9DA580A0AA81A4B084A9B6
86AFBD89B3C28AB2BF8BAFBC8AACB789A8B288A3AD869FA7849AA282969D8091977D8C927B888C\
798387777E81747A7C
7071726F6E6E6D6B6A6C68676A646369615F675E5B665A5765575363544F62504B604D475E4943\
5D463E5B423A5A3F365A3D345B3C32735043704F446E4E446B4D45694D47664B45
634843604845614B4A614F506B5D5C685C5B665B5B645B5C6159595F595A5D595A5D5F615D6163\
5D66695E686C6472776E7D81788B8F7D949A7F9BA1809EA67FA0A980A3AF83A8B5
85AEBC87B3C28AB3C18DB3C08EB0BC8CACB68AA7B088A2AB869DA583989F8193997E8E937C898E\
798488777F82747A7C
7071726E6E6E6D6A6A6B67666A636168605D675C5965595564555162524D614E485F4B445D473F\
5B433B583E355439305B3C33664539745145704F446D4D446A4D45684C46654A44
624742614A47624E4C635251695959675A59645959635A5A6057585E58595C585A5D5D605D6164\
5E686B5F696D63717768797E74868B7F969B819CA2809EA77F9FA97FA2AE81A7B4
84ADBB86B2C18AB5C48EB5C491B5C18FB0BA8CAAB48AA5AE879FA8859AA182959B7F8F957D8A8F\
7A8589777F83757A7D
7071726E6D6D6C69696B6664696260675E5C665B5864575363544F61504A604C465E48415C443D\
5A4038553A3150342A5E3F34724E427250446F4E446C4C446A4D45684C45654A44
624843624C486553516555536656566457576358576157575F56565D56575C585A5C5C5E5C6164\
5E676A616A6F63717768797F6F83897D9499819DA3809EA77E9EA87EA1AD80A6B3
83ABB985B0BF87B3C393BBC994B9C592B4BF8FADB88CA8B189A2AA869CA483969D8191977E8B90\
7B868A788083757A7D
7071726E6D6D6C69686A656368615F675D5A65595663555162524C604E485F4A435E473F5C433A\
5A3E3556393055372C6241366F4D416E4D426D4D436B4D45694D45674D45654A44
624944624C486654526656546556556456566257566056565E55555C55565B58595B5B5D5C6063\
5E6569626A70657277697A8070838A788F967F9AA07F9DA67E9EA87DA0AC7FA5B1
82AAB883AEBD83B1C198C0CE97BDC995B7C391B1BB8EAAB48BA4AD889EA685989F8292987E8C91\
7B868B788184757B7D
7071716E6C6C6B686769646268605D665C5864585462544F61504A604C465E48415D453D5C4138\
5B3E345A3A305D3D3162423769493E6C4C426C4D446A4D45694D45674D46654B45
634A44634C4865524F6657556557566356566156555F55555D54545B54555A57585A5B5D5B5F63\
5D6569626C706673796B7B8271848B768D947C969D7D9AA47D9CA67C9FAB7EA4B0
80A9B781ADBC82B0C19AC2D09BC0CD97BAC694B4BE90ADB78DA7B089A0A8869AA183949A7F8E93\
7C878C798185757B7E
7070716D6C6C6B6766696361675E5C655A5763565261524D604E485F4A435E463F5D433A5C4036\
5C3D325D3C2F5F3F3363443967493F6B4C426B4E456A4E46694E46674D46654C45
644A45634C4863504D6556546558576357566055545E55555C54545A5354595657595A5C5B6063\
5E6569636D7168747A6D7D8271848B768C947A949D7B97A17B9AA57B9EAA7DA3B0
7FA8B680ABBB7FAEBF9CC3D29EC3D09ABDC996B7C293B0BA8FA9B28BA2AA879CA384959B808F94\
7D888D798285757B7E
6F70716D6B6B6A6666686260665D5B64585562545060504B5F4C465D48415D443C5C41385C3E33\
5C3B2F5E3C31603F3464453B684B426B4D446B50476A5047684E47674D47664C46
644B46634D48634F4C6454526458576257566054545E55545C545459525358555759595C5B6063\
5E6569636E7268767B6E7E8472848C758C9378929B79959F7A99A37B9DA97DA2AF
7FA7B580ABBA7EACBD98C0CFA2C7D59DC1CD99BAC595B2BD90ABB48CA4AC899DA585969D819095\
7D898D798286767C7E
6F70716C6B6B6A656567605F645C5962575360524E5E4E485D49435C453E5B42395B3E355B3B31\
5C392D5E3D3160403566493F6A4D446B4F466B51486A5048694F48674E47664D47
654D47644E48624F4B6453516458566257566055545D54545B5353585253575456595A5C5B6063\
5F666A646E7369767C6F7F8573858D758B93768F9877939D7997A27B9CA87DA1AE
80A7B482ABBA82AEBD91BBCA9FC7D5A2C7D39BBDC896B5BF92ADB78EA6AE8A9FA686989E829196\
7E8A8E7A8386767C7E
6F6F706C6A6A696464665F5D635A576155515E504B5D4B465B47405A433B593F36593B315A382D\
5B382C5E3D31624539694E446C50466C51486B51496A5149695049674F48664E48
654E48644F4963504C6454516457556256555F54545D54545A5253575253565456585A5D5B6064\
60676B646F746A777D6F808673858D748A92758D9676919C7996A17B9BA77EA1AE
82A7B485ADBB88B1BF90BAC99BC5D4A2C7D49CBECA97B6C193AFB98FA8B08BA0A88799A0839297\
7F8B8F7A8387767C7F
6E6F706B6969686363645E5C6158555F534F5C4E495A494359443D584038573B3257382E583529\
5A372B5E3E33654A3F6C51476E52486D52496C52496A5149695049684F48664F48
654F4964504A65524E6455526457556256555F54545D54545A5152565253565456585A5D5B6164\
60696C6570756B787F6F808672858C748991748C9576909A7995A07C9BA77FA1AD
83A7B488AEBC8CB2C193BCCB9CC7D69DC4D29BBFCB98B8C394B1BA90A9B28CA2A9889AA1849398\
7F8B907B8487767C7F
6E6F6F6A6868666261635C5A6056545D514D5A4B4658464056413A553C3454382E543429563328\
59372C604136694E436F544970544B6E544B6D524A6B5149695049674F48674F49
664F4A65514C66544F6557536558566357566055555D5454595152555152555457575A5D5B6165\
60696E6671766B797F6F7F8671848B728790748B94758F9A79949F7C9AA680A1AD
84A8B48AAFBD8EB3C195BDCC9CC6D69EC6D39CC0CD99BAC596B2BC92ABB48EA3AB899CA2859499\
808C917B8488777D7F
6E6E6F696868656160615B595E54525A4E4A57484455433D533D3651383050342A4F2F24523127\
58392E64463A70534773574C72564D70554C6E534A6B5149695049674F48664F49
66504B66534E675651675855675A576459576157565D5454585152555152545457575A5D5B6266\
606A6F6671776A787E6D7E8570828A71878F748A94768F9979949F7C9AA680A0AD
85A7B48BAEBC8FB3C096BECD9CC5D4A1CAD89EC3D09BBCC798B4BE94ADB58FA5AD8B9DA486959B\
818D927C8589777D80
6D6E6F68676764605F5F59575B524F574B48544541513F3A4F3A334D342C4C2F264A2A1E4B2E24\
583B31684A3E78594C785B4F75594E72574D6F544B6B524A685049664F48664F49
66504B67534E6958536A5B57695C59665B5A6258585D5555585152545152535457565A5D5A6166\
606A6F64717769767D6C7D846F818A71868F748B94768F9979949F7D9AA681A0AC
86A7B48BAEBA90B2BF98BECD9FC5D4A4CEDCA1C6D39EBECA9AB7C096AFB791A7AE8C9EA587969C\
828E927D8689777D80
6D6D6E676666625E5D5D5755584F4D54484550423D4D3B364A362F493028472B2246271D472D23\
573C326A4D417F5E507D5E52795B5075594E70554C6B5149674F48644D47644E49
66504B69544F6B5A546C5D596B5F5C695E5D645B5A5E5656585253535052525356555A5D586166\
5E696E62707666757C6B7B836E818970858E748B94778F9A7A949F7D9AA6819FAC
86A6B38BACB98FB1BF9ABDCBA3C9D7A8D1E0A4C9D6A1C1CC9CB9C398B1B993A8B08EA0A689979D\
838F937D868A787E80
6C6D6E666565605D5C5B5553554D4A5045424B3E3A48373245312B442C2443281E43271E432B23\
573E346F51458663548262547D5E52785B5172564D6B514A664E47624C47614D48
64504B6B5650705C576F5E5A6E615E6D6462665E5D5E585857525352505251535553585C565F65\
5C686E5F6E7463737B6879816D808870858E768C9578909A7A949F7D99A5819FAC
86A5B38BABB88FB0BE9CBECBA8CCD9ACD5E3A8CCD8A4C4CF9FBBC59BB3BB95AAB190A1A88A999E\
8490947E878A787E80
6B6C6D6564645E5B5A585351524A484C413E46393541322D3E2B253E272040251C412820412D25\
5940367454488C68588665578060557B5D5274584F6D534C664E48634D485D4B47
624F4B6C5751715E5973605B7264616F666467605F5F5959575253514F514F515450575B525B62\
5B686E5C6B725F707965777F6D808871868E778C9579919B7B95A07C99A5819FAC
86A5B289AAB890B1BFA0C0CDADCEDBB1D8E5ACCFDAA8C6D1A3BEC79EB5BD98ACB392A3A98C9A9F\
8591957F878B787E81
6B6C6D6363635C595955504F4E4745473D3B4034313A2B2735241E341E1841271F432C24463129\
5A423977574A916C5C8A685A8463577D5F54775B5271574F6A524B66504A604D48
64514C6A5751705E5974625D7365616E656267605F5E5959575253504F514D50534E555A4F5A60\
56656C56676F586C7565777F6C808870858D788D967B919B7D96A17D9AA6809EAB
84A3B187A8B690B1BFA4C2CFB3D2DEB6DAE6B0D1DDACC9D3A7C0C9A1B7BF9BAEB594A5AB8E9BA0\
87929680888B797F81
6A6B6C6262625A5857524E4D4A4442423937392F2C3124202718142C19133E28204631284B372F\
61483D7C5B4D956F5F8E6A5C87665A7F6055795E54745B536E564F69524C66514C
67534E6B58526F5D5872625E7164616C6361665F5F5E5859565253504F514D50534D555A4F5A61\
52626A52646D52677164767E697E866E838C798D957B929B7D96A17C99A67E9DAB
81A1AF83A5B592B2C0A7C4D0B9D5E0BBDDE9B6D5DFB1CCD6ABC3CCA5BAC19EB0B797A7AC909DA1\
88939781898C797F81
696B6C6161615856564F4C4B46413F3D3634332A27281D1A1B0E0A29191437241E46322A513C33\
694D41815F51987161926D5F8A695D8263597B6056765C54715A526C56506A544F
6A56506D5A54705E5871625D7164616B6260655E5D5D58585652534F50524C50534C54594F5A61\
52616952646D5368725F727B667A836C828B768B9478909A7994A07A97A47A9BA9
7D9FAD7FA3B294B4C1ABC6D1BDD6E0C1E2EDBCD9E3B6D0D9B0C7CEA9BDC4A2B3B99AA9AE929EA3\
8A9498828A8D7A7F82
696A6B6060605655554D4A49433E3D3932312E262422181514090622161133231D443129563E36\
6E50458562549A73629571628D6C6086685D7E6259785E56735B546E59536E5952
6C58526E5C566F5E5971615D7064606A605E635B5B5C56575553544F51534C4F544A53574D5A60\
52616854656E586B745E717B62788169808A708892738C9775919E7695A27799A7
779CAB7DA2B296B5C2B2C9D3BDD5DFC6E4EEC2DDE6BDD4DCB6CAD1AEC0C6A5B5BB9DABAF94A0A4\
8C9599838A8D7B8082
686A6B5E5F5F5553534A4848403C3B35302E2A23211D15131006041D120E2F211C423029573F36\
6F52468764569A73639874659170648A6C6183675E7C635A765F58725D57725D56
6F5C556F5D576E5D586F5F5B6C605C685D5C6159585C55565653555052554D51564952574A575D\
4F5F6653646D5A6C745E727B617881667E886B848F6E8995718E9B7393A07396A4
7298A87EA3B299B7C3B5CAD4BDD4DEC7E3EDCDE5EDC4DAE1BCCED5B3C3C9A9B8BDA0ADB197A1A5\
8E969A848B8E7B8082
68696B5D5E5F5352524847463E3A3A322E2D26201F1A13110C050219100D2B1F1A402F28553F36\
6F52468664569972639A76679474678D6F65866C6280675F7B645D77615B745F59
715E58705E586E5D576C5D58695C58655B596057575B55565654565253574F53584B545A49565D\
4B5C634E616A5669725B717A617780647D8768828D6C87946F8D9A70909E6E93A2
6D96A680A5B49AB7C4B2C8D2C0D6DFCAE3ECD8ECF3CDDFE5C2D3D8B8C6CCADBABFA3AFB399A3A6\
8F979A858C8E7C8082
67696A5D5D5E5251524745453B3938302C2B241F1E1711100A0302180F0C271C183E2D26533E35\
6C50458462559771629B776997766A9072688A6F66846B637E68617A655E76625C
73605A705E596D5C576B5B57675A566458565F57565B545557545654555850555A4E565C4B585F\
4C5C634D606851666F576D775D747E617B8666818C6886936C8A996A8E9C6A91A0
6C95A582A6B499B7C3B0C7D1C4D7E0D2E6EDE0F0F6D4E3E9C8D7DCBDCACEB1BDC1A6B0B49CA4A8\
91989B868C8F7C8183
67696A5C5D5E5151514544443A38382E2B2A221E1D15100F080201160E0C251B173A2A25513B33\
684E447F5F52926E609C77699A796C93756B8C7269866E67816B647C676177645E
74615B705F596D5C576A5B566659556357555F56555B545558555755565952575B4F585E4D5A61\
4D5D654E616A516670556C7659727C5E7884627E8B648391668795668B99678E9E
6E96A684A7B59BB8C4B0C8D1C6D8E0D8E8EDE5F2F7DCE9EDCFDBDFC2CDD0B5BFC3A9B2B59EA5A8\
92999C878D8F7D8183
67696A5B5D5D5050514444443837372C2A2A201D1C130F0E060100140E0C231A163728234C3831\
634A41795B4F8D6B5D9A76689C7B6E96786D8E746B887169826D667D696278655F
74625D715F596D5C57695A566658546257555E55545B555658565856575A53585D515A5F4F5C62\
4F5F6650636B526771546C7657717C5A76825D7B885F808E618493618897648D9D
7198A888A9B79DB9C5B2C9D2C8D9E0DDE9EEEAF3F7E5EFF2D4DEE1C6CFD2B8C1C4ABB3B69FA6A9\
949A9C888D8F7D8183
66696A5B5C5D4F50514343443736372B29291E1C1C120E0E040100130D0C22191634262147352E\
5D463D73574C88675A9673659D7B6E977A6F90766D89726A836F687E6B64796661
75635E715F5A6D5C58695A566558546156545E55555B555659565957585B54595E525B61515D64\
50606851646C526871546C7656707C5775815979865C7E8C5D82915E8696658E9E
779CAB8CACB9A1BCC7B7CCD4CDDCE2E1EBEEEEF5F8EAF2F5D8E0E3C9D0D3BAC2C4ADB4B7A1A7A9\
959A9C898E907D8183
66696A5B5C5D4F50514343443736372A29291D1C1B100E0E030000110C0B21181530242042322C\
56423A6E5449826357916F629A786B977A6F90776E8A736B846F687E6C66796862
75635E705F5A6C5C58685A566558556156545E55555C56575A575A58595D555B5F545C62525F66\
51616952656D526872536C7754707B567480577886597C8B5A81905E86966991A1
7CA0AE90AFBCA7BFC9BDCFD7D2DFE5E6EDF1F5F9FBEBF1F3DAE0E2CAD0D3BCC2C4AEB4B6A2A7A9\
959A9C898E907E8183
66696A5A5C5D4F50514343443636372929291C1B1B0F0E0E020000100C0B1F17152D231F3D2F29\
513F37674F467B5E538C6C5F95746895796E90776E8A736B836F697E6C66796863
74645F70605B6C5C58685A566457556157555E56565C57585A595B585A5E565C61555E64536167\
52636A52666E536973536D7754707C547380567886577C8A5A81916188986F95A4
82A4B198B4BFADC3CCC3D3DAD8E3E7ECF1F3FAFDFFE9EEEFDADFE0CBD0D2BCC1C3AFB4B6A2A7A9\
969A9C8A8D8F7E8183
66696A5A5C5E4F505142434436363729292A1C1B1C0E0E0E0000000F0B0A1C16142B211E392D28\
4C3B35604A4273594F85675B8E6F6492766B8F776D89736B836F687D6B65786862
73645F6F605C6B5C58675A566458556157565E56575D58595B5A5D5A5C5F585E63566065546269\
54646C53676F536A74536D7853717C537481547885577C8B5C8392668C9B779AA8
8AA9B59FB8C3B4C8D0CAD7DDE0E7EBF2F5F6FBFDFEE8ECEDD9DDDECACED0BCC0C2AFB3B5A2A6A8\
969A9B8A8D8F7E8183
66696A5B5D5E4F5052434445363738292A2B1C1C1D0E0E0F0000000D0A0919151427201D352A26\
46373159463E6A534A7B615686695E8E72688D756C88726A826E677C6A65776761
72635F6E605C6A5C59665A576358566158575F58585D5A5B5C5C5F5B5E615A606558616756646A\
55666E556871546B75546E7953717D537481557886597D8C6186956E92A080A0AD
94AFB9A7BDC7BCCCD3D2DCE1E8EDEFFAFBFCF6F8F8E6E9E9D7DADBC9CCCEBBBFC0AEB2B3A2A5A7\
95999A898D8E7E8182
66696B5B5D5F4F51524345463738392A2B2C1D1E1F0F1011000102090808161312241D1B302723\
40332F51413A624E467059507D6359886D628A7268867068806C667B6964756661
71625E6C5F5C695D5A665A586258576058575F595A5E5B5D5E5E615D60645C62665A636958666C\
57686F566B73556D76546F7A54727E5475825679875C818F688B997798A58AA6B2
9EB5BEB0C3CBC4D1D7DBE2E5F0F1F3FFFFFFF1F2F3E3E5E5D5D7D8C7CACBBABDBEADB0B2A1A4A5\
959899898C8E7D8082
67696B5B5E5F505253444647383A3B2C2D2E1E20211112130203040707081311101F1A192B2421\
392F2C493C3759484266534B725C537D655C836C63826D657E6A64796862736460
6F625E6B5F5C685D5A655B59625857605858605B5B605D5F6060635F63665E64695C666B5A686E\
596A72586C75576F7855717C56747F5778855A7C8A63869471919E819EAA93ACB6
A7BAC3B9C8CFCED7DCE4E7E9F5F4F5FFFFFEEEEFEFE0E1E1D2D4D4C5C7C8B8BABCACAEB0A0A2A4\
949798888B8D7D8082
676A6B5C5E60515354454749393B3D2D2F312123241315170507080405060E0E0E1A1717272220\
332B2842373351443E5D4D4668554E715D557A655D7B665F7A676076666170625E
6C615E695E5C675D5A645B5A6059585F5959615C5D63606163636562656861676B5F696E5D6A70\
5C6C745A6F7759717A58737E5976815C7B8861828F6C8C997B98A38BA4AF9DB2BB
B0C0C7C2CED3D8DDE0ECECEDFBF9F9F9F9F8EAEAEADCDDDDCFD0D0C2C4C4B6B8B9AAACAD9EA1A2\
939697888B8C7D8081
676A6C5D5F6152545647494B3B3E3F30323424262817191B0A0D0F0104050A0B0C161515221F1E\
2D27253B322F4A3F3A5447435F504A65554F6D5C56715F5973615C70625D6B5F5C
695E5C685D5B665D5B635C5B5F595A5F5A5B625E5F65626366656865686B64696D616B70606D72\
5F6F775E727A5D747D5D76815E7A8563808C6A899476939E859EA995ABB4A7B9C0
B9C6CBCCD4D8E0E3E4F1F0F0FFFCFBF2F1F0E4E4E4D7D8D8CBCCCCBEC0C1B3B5B6A7AAAB9C9FA0\
929496878A8B7C7F81
686B6C5D6062535657484B4D3E4042333537272A2B1B1E200F121402060805080A1213131D1C1B\
282523342E2C443A374E433F564A465C4F4B62544F675854685A56675B58645B59
645B59645C5A645D5B625C5C5F5B5B605D5D636060656465676769686B6D676C70646E72647075\
63727963767D627880637B84667F896C8791758F99829AA390A5AEA0B1B9B1BFC5
C4CCD0D6DADCE6E7E7F6F3F2FBF8F7EBEAE9DEDEDED2D2D2C6C7C7BBBCBDB0B1B2A5A7A89A9D9E\
90939486898A7C7F80
686B6D5E61635457594A4D4F40434536383A2B2E3020232514171A080B0E0307080E1011191919\
2422222F2B2A3D3634473E3C4D4441534946594E4B5D524E5F55525E56545D5756
5E5857605A59605B5A605D5D5F5C5D605E5F63616265656668696B6A6D6F696F72687175687378\
68757B697980697C846B81896F868F778E9680969E8DA1A89BACB3AAB8BEBCC5C9
CED3D5DEDFDFEBEAEAF8F4F3F0EEEDE4E2E2D8D7D7CCCCCDC1C2C2B7B8B8ACAEAFA2A4A5989A9C\
8E91928588897B7E80
696C6D5F626456595B4D5051434648393C3E2F323425282A1A1D200F121504090B090D0F151718\
2020202B29283632313E393746403E4A4341514947554D4B564F4E575151585454
5955565D58595B58595E5C5D5F5D5E605F60626263656668696A6C6C6E706C71746B73776C767B\
6D797E707D8370818874868D798C9381949B8C9DA498A7ADA6B2B7B5BFC2C7CCCE
D8D9DAE3E3E2F0EEEDF0EDECE5E3E3DBDAD9D0D0D0C6C6C6BCBDBDB2B3B4A9AAAB9FA1A2969899\
8D8F908486887B7E7F
696C6E616465585B5D4F525446494B3D40423337392A2D2F20232615191C0B0F12070B0D121617\
1C1E1F262627302F2F383535403C3B433F3E4944434E49484E4B4B514F4F535152
5553555957585958595C5B5C5D5D5F6061626264656668696A6C6E6D70726E73756E757970797D\
737D8176818677858A7C8B918392978C9AA096A2A8A2ADB2B0B8BCC0C5C7D0D1D3
DEDDDDEAE8E7ECEAE9E4E2E1DBDAD9D2D1D1C9C9C9C0C0C0B7B7B8AEAFAFA5A6A79C9E9F939597\
8B8D8F8385877A7D7F
6A6D6F6265675A5D5F525557494C4E414446383B3E2F3335262A2C1C2023121719090E110F1517\
191D1E2224252B2C2D3433333A38383D3B3C4240404745454948494E4D4E4F4F51
52525455555757585A5A5B5C5C5E6060626364656767696B6C6E706E717371757872787B757C7F\
7880837A84887D888D828E938B979B959FA39FA8ACACB3B6BABEC0C8C9CBD7D6D6
E5E3E2E8E6E5E0DFDED9D8D8D2D1D1CAC9C9C1C1C2B9BABAB1B2B2A9AAABA1A2A3999B9C919394\
898B8D8184857A7C7E
6B6E6F6366685C5F615457594D505245484A3D404335383B2D303324282B1B202212171A0F1517\
161B1D1F2324272A2C2F313236363738393A3D3D3E4142444446484A4B4D4C4E50
50525452545756585B595C5E5D5F61616365656769686B6C6D707171737575787A757A7D797F81\
7C82857D8689818B8E899295929A9E9DA4A7A8ADAFB4B7B9C1C2C2CECDCDDBD9D8
E5E3E3DDDCDCD6D5D5D0CFCFC9C8C8C1C1C1BABABBB3B3B4ABACADA4A5A69D9E9F9597988E9091\
87898B808384797C7D
6B6E706468695E6163575A5C505355494C4F4246483B3E4133373A2C303324292B1D2225161B1E\
141A1D1B212424282A2D303233353736393B393C3E3E414341444746494C4B4E50
4E515452555856595B595C5F5D606261646666686A6A6C6E6F7173747677787B7C7A7E807D8183\
7E838580878A868E908E9597989D9FA3A7A9AFB1B2B9BABAC6C4C4D2CFCFDBD9D9
DAD9D9D3D2D2CCCCCCC6C6C6C0C0C0B9B9BAB3B3B4ACADAEA5A7A79FA0A1989A9B9294958B8E8F\
8587897F8183787B7D
6C6F7166696B6063655A5D5F5457594D5153474B4D4145473A3E4134383A2D3234272C2F212629\
1B21241A202321272A2A2E31313537363A3C393D3F3C40433F444844494C4A4E51
4D525552565956595D595D605E616363656867696B6C6E707072747678797B7D7F7E8082818384\
80848683898A8B90919196989A9EA0A7A9AAB3B3B3BDBCBCC7C5C4D2D0CFD3D2D2
CDCDCCC7C7C7C2C2C2BCBCBDB7B7B7B1B2B2ABACADA6A7A7A0A1A29A9C9C9496978E9092898B8C\
8385877D8081787A7C
6D7071676B6C6265675D6062575B5D5255574C5052474B4D4145473C4042363B3D3136382C3133\
272C2F21272A21272A282E32303538373C3E3A3F423D42453F4549444A4E4A4F53
4E535652575A565A5E595E615E6265636669686B6D6E70717173747779797D7E7F818182838485\
828587868A8B8D91929497989EA0A0AAAAAAB4B3B3BFBDBDC6C4C5CACAC9C5C5C5
C1C1C1BCBDBDB8B8B8B3B3B4AEAFAFA9AAABA4A5A69FA0A19A9C9C9597989092938B8D8E868889\
8183857C7F80777A7B
6D7072696C6E6468696063655B5E60565A5C5255574D5153484C4E44484A3F43463A3F41363B3D\
3237392D3336292E3129303330363A383D413E434640464942484B474C504D5255
50555854595C565C5F5A5F625F636664676A696C6E6F71727274757879797A7C7D828282828384\
838687898C8C8F9192979999A0A1A1A9A9A9B5B3B3BDBCBCBEBEBFBCBDBDB9B9BA
B5B6B6B1B2B2ADAEAFA9AAABA5A6A7A1A2A39D9E9F989A9B9496979092938C8E8F878A8B838587\
7F81837A7D7F76797B
6E71736A6E6F666A6C6366685F62645B5E60575B5D5357594F53554B4F52484C4E44484B404547\
3D4144393E41363B3E32383B343A3E393F42404549444A4D484E514C5154505558
54595C565B5E595E625D616561656764676A696C6E6F71717374767778787A7B7B818181828283\
8586878A8C8C8F9292989999A0A0A0A5A6A7B3B2B2B4B4B5B1B2B2AFB0B0ADADAE
AAABABA7A8A8A3A4A5A0A1A29D9E9F999B9C9697989294958E90928B8D8E878A8B848687808384\
7D7F81797C7D75787A
6F72746C6F71696C6E66696B6366686063655C6062595D5F565A5C5357595054564D51544A4F51\
484C4E454A4C42474A4046493F45483F454841474B494E524D535753575A555A5D
585D5F595E615D616560646763666864676A696C6F6D70717274757677777A7B7B7E7F7F828282\
858686898B8B8F91929596969C9D9EA2A3A4A8A9AAA6A7A8A4A5A6A3A4A4A0A2A2
9EA0A09C9D9E999B9C9798999496979193948E90918C8E8F898B8C8688898385878083847D8081\
7A7D7F787A7C757879
7073746D71726B6E70696C6E666A6C6467696265675F63655D61635B5E60595C5E565A5C54585A\
5256595055574F53564D52554C51544C51544B505450555853595C575B5E5C6062
5E62655E626560646762666864686A676A6C6A6E6F6D7071717474747677797A7B7C7D7D808080\
84858587888A8F9091919293959797999B9B999B9B989A9B97999A969899959697
9395969193948F91928D8F908B8D8F898B8D87898B8587898385878183857F81837D7F817A7D7F\
787B7D76797B747779
7074756F72746D71726C6F716A6D6F696C6E676A6C66696B6467696366686165666063655E6264\
5D61635C60625B5F615A5E60595D60595D60595E615B5F625C61645D6164636668
65686B64676965686A64686B666A6C6A6D6F6C6F706E7172717475737676767879797B7B7C7E7F\
838485838486888A8B898B8C898C8D8B8D8E8B8E8F8B8D8E8B8D8E8A8C8D898B8C
888A8B87898A8588898487888385878184858083847F81837D80817C7F807A7D7F797C7D787A7C\
76797B757879737678
7174767074757073746F72746E71736D70726D70716C6F716B6E706A6D6F696D6F696C6E686B6D\
676B6D676A6C666A6C66696B66696B66696B666A6C666A6C676B6D686C6E6A6D6F
6B6E706A6E706B6F706A6E706A6E706D70726F7172707374717476737577747678767879787B7C\
7D7F817C7E807D7F807D80817E80827E81827E81827E81827E81827E80827D8081
7D7F817C7F807C7E807B7E7F7A7D7F7A7C7E797C7D787B7D787A7C777A7B76797B75787A757879\
747779737678737677
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool4079eMP/0LWAf301a
M7D4075cM@/0LG=d101aLW@<075bL`@0LG9b2`1aLG84075aL@@0LG1a101aL703075_K`@0L6e/101a
L704075aL@P0LG5b0`1`LW<<071aLP@0L71b101_LG8406m`LP<0Kg5b101_LG<406mbM0@0Kg=e101`
M7H4075eN0<0LGIi101bMgX4079hNP@0LWYl101dNgh407EmP0@0MWn30`1hPhL407InPP@0MGao101d
Ngd407AjO0@0M7Uk0`1cNG/807=hNP`0LgMi1`1bMWP4079fM`@0LWEg5P3oool001@0oooo101bMGH;
079dMP`0LGAe101aLgD;075cM0@0LG9d301aLW<4075bLP/0LG5b101aLG44075`L@@0LG1`0`1aKfl4
071]K0@0LG1`101aLG48075aLP<0L79c301`LG84071`LP@0Kg5b101_L78306maLP@0Kg5c101_LW@4
06mcM@@0L7Af101aMGP3075fN@@0LWMj101bN7X4079jO0@0M7]n101eOH0407IoP`<0N8>7101fOX84
07ElO`@0M7]m101dNW`407AiN`<0LgUk201cN7X<07=gN@L0LWIh101bMWL4079eMaH0oooo000D0?oo
o`@0LWEf2`1bM7H<075dM@@0LG=e2`1aLg@4075bM0`0LG9c101aLW8;075aLP@0LG5a101aL744075`
L0<0LFm_101`KF`4075`L0@0LG5a201aLG83071bL``0L75b101`L78406maLP@0Kg1b0`1_LG8406ma
L`@0Kg9d101_LgD4071dMP@0LGEh0`1aMWT4079gNP@0LWQj101bNW`407AkOP@0MGf0101fOh<307R3
Q`@0MWj2101eO7l407AkO@@0M7Yl101dNG/307=iN`P0LgQj301cMgT7079fN0@0LWIg101bMGLF0?oo
o`00503oool4079eMP/0LWAf301aM7D4075cM@/0LG=d101aLW@<075bL`@0LG9b2`1aLG84075aL@@0
LG1a101aL703075_K`@0L6e/101aL704075aL@P0LG5b0`1`LW<<071aLP@0L71b101_LG8406m`LP<0
Kg5b101_LG<406mbM0@0Kg=e101`M7H4075eN0<0LGIi101bMgX4079hNP@0LWYl101dNgh407EmP0@0
MWn30`1hPhL407InPP@0MGao101dNgd407AjO0@0M7Uk0`1cNG/807=hNP`0LgMi1`1bMWP4079fM`@0
LWEg5P3oool001@0oooo101bM7H4079dM@@0LGAe0`1aLgD8075cM0P0LG9c1`1`LG88071`L@@0L71`
201`Kfl7071^KPP0L6e]101`K6`4071/J`@0L6]Z0`1`JVP4071XI@@0L6]Y101`K6`8071]KP<0Kfi_
101_KVh406i]KP`0KFe^101/KFh306a^K`@0KFm`101]LG<406ibM0@0KgAg101`MWT3075hN`@0LWYm
101cO7l407AnPP@0MX66101hQHT407Z8SP<0O8^A101iQXX407R2Q`@0Mh24101fOX8407EmP0<0MGao
101eNgh407AkO@@0M7Yl101dNG/407=hN`<0LgQj101cMgT4079fN0@0LWIg5P3oool001@0oooo101b
M7H4079dM@@0LGAe0`1aLgD8075cM0P0LG9c1`1`LG88071`L@@0L71`201`Kfl7071^KPP0L6e]101`
K6`4071/J`@0L6]Z0`1`JVP4071XI@@0L6]Y101`K6`8071]KP<0Kfi_101_KVh406i]KP`0KFe^101/
KFh306a^K`@0KFm`101]LG<406ibM0@0KgAg101`MWT3075hN`@0LWYm101cO7l407AnPP@0MX66101h
QHT407Z8SP<0O8^A101iQXX407R2Q`@0Mh24101fOX8407EmP0<0MGao101eNgh407AkO@@0M7Yl101d
NG/407=hN`<0LgQj101cMgT4079fN0@0LWIg5P3oool001@0oooo101bM7H4079dM@@0LGAe0`1aLgD8
075cM0P0LG9c1`1`LG88071`L@@0L71`201`Kfl7071^KPP0L6e]101`K6`4071/J`@0L6]Z0`1`JVP4
071XI@@0L6]Y101`K6`8071]KP<0Kfi_101_KVh406i]KP`0KFe^101/KFh306a^K`@0KFm`101]LG<4
06ibM0@0KgAg101`MWT3075hN`@0LWYm101cO7l407AnPP@0MX66101hQHT407Z8SP<0O8^A101iQXX4
07R2Q`@0Mh24101fOX8407EmP0<0MGao101eNgh407AkO@@0M7Yl101dNG/407=hN`<0LgQj101cMgT4
079fN0@0LWIg5P3oool001@0oooo101bM7H4079dM@@0LGAe0`1aLgD8075cM0P0LG9c1`1`LG88071`
L@@0L71`201`Kfl7071^KPP0L6e]101`K6`4071/J`@0L6]Z0`1`JVP4071XI@@0L6]Y101`K6`8071]
KP<0Kfi_101_KVh406i]KP`0KFe^101/KFh306a^K`@0KFm`101]LG<406ibM0@0KgAg101`MWT3075h
N`@0LWYm101cO7l407AnPP@0MX66101hQHT407Z8SP<0O8^A101iQXX407R2Q`@0Mh24101fOX8407Em
P0<0MGao101eNgh407AkO@@0M7Yl101dNG/407=hN`<0LgQj101cMgT4079fN0@0LWIg5P3oool001@0
oooo101bM7H4075cM@L0LG=d101aLW<4071aLP@0L75a201`L70306m_K`@0Kfi_101_KVh406m]K@@0
Kfa/101_K6/706i[JP@0KVYY101^JFP406iXI`@0KfQU101_IV@306mUHP@0Kf=O101`IV@406mXI`@0
KfYY101_JVX306iZJP@0KFYZ101/JVX406]YJP@0K6UZ101[JFX406YZJ`<0Jfa]101[KFl406a_L@@0
K75c101^M7L406mgNP<0LGYm101bO80407B0P`@0MH>8101hQh`407Z<TP@0OY6I0`1nSiH407b;T@@0
NXR=101iQHX407R3Q`@0Mh650`1fP8<407IoPP@0MGf1101eO7l407AkOP@0M7Yl0`1dNG/407=hNP@0
LgMi101bMWPF0?ooo`00503oool4079dMP@0LG=e1`1aLg@4075bL`@0L75b101`LG48071`L0<0Kfm_
101_KVl406m^KP@0Kfe]101_K6`406m/J`L0KV]Z101^JVT406iYJ0@0KVQW101_J6D406mVI0<0KfER
101_Hel4071VI0@0KfQW101_JVT406mZJP<0KVYZ101]JVX406aZJP@0JfUZ101/JFX406]YJP@0JVY[
0`1[K6d406]]K`@0K6ma101/LG<406idM`@0KgMj0`1aNWd4079lP0@0M823101ePhP407R7S0@0NXbB
101nTIT307j?UP@0O8^A101jR8d407V5RP@0N8>7101gPHD307J0P`@0MWn2101eOH4407ElO`@0M7]n
101dNW`307AiN`@0LgQj101cMgT4079fN1H0oooo000D0?ooo`@0LWAf101aLgD7075cM0@0LG9c101`
LG84071aL@P0L71`0`1_Kfl406m^K`@0Kfi^101_KFd406m/K0@0Kfa[1`1^JfX406iZJ@@0KVUX101^
J6L406mXI@@0KfIT0`1_IF8406mSG`@0L6IT101_J6L406mZJ@@0KfYZ0`1^JVX406eZJP@0K6YZ101[
JFX406aYJP@0JfUZ101ZJV/306]/K@@0Jfe_101/Kg4406aaL`@0KWAg101_MgX3075jO@@0LWb0101d
P8<407F3R0@0N8N<101jS98407jAV@<0OXnF101lRi4407Z8S@@0NHF:101hPhL407N1Q@<0MX23101f
Oh8407EmP@@0MGao101dNgh407AjO0<0M7Uk101cN7X407=gN@@0LWIh5P3oool001@0oooo101bM7H4
075cM@L0LG=d101aLW<4071aLP@0L75a201`L70306m_K`@0Kfi_101_KVh406m]K@@0Kfa/101_K6/7
06i[JP@0KVYY101^JFP406iXI`@0KfQU101_IV@306mUHP@0Kf=O101`IV@406mXI`@0KfYY101_JVX3
06iZJP@0KFYZ101/JVX406]YJP@0K6UZ101[JFX406YZJ`<0Jfa]101[KFl406a_L@@0K75c101^M7L4
06mgNP<0LGYm101bO80407B0P`@0MH>8101hQh`407Z<TP@0OY6I0`1nSiH407b;T@@0NXR=101iQHX4
07R3Q`@0Mh650`1fP8<407IoPP@0MGf1101eO7l407AkOP@0M7Yl0`1dNG/407=hNP@0LgMi101bMWPF
0?ooo`00503oool4079dM@@0LG=d101aLW<3071bL`@0L75b101`L74406m_L0P0Kfi^0`1_KF`406i/
K0@0KV][101^JVX406iYJ0@0KFQW101]J6H306eWI@@0KFIT101]IF<406eTHP@0KF=P101^HUl306iQ
G@@0KUmJ101_Hf0406mUH`@0KVIU101^IfH306eWI`@0K6MW101[IfL406YWI`P0JVIW101YJ6P306UZ
J`@0JVa^101[KW0406]`L`@0K7Ag101^N7/3071kO`@0LWn3101ePhP407N8S@@0NXbC101mTYT4086H
X@<0OiBK101mT9L407b<TP@0NXV?101iQh`407V5R@<0N8>7101gPXH407N0Q0@0MWj2101eOH0407El
OP<0M7Ym101dNG/407=hNP@0LWIh5P3oool001@0oooo101bM7D4075cM0@0LG9c0`1`LW<4071aLP@0
L71a101_Kg0806m^KP<0Kfe/101^K6`406i[J`@0KVYZ101^JFP406eXI`@0KFQV0`1]IfD406eVI0@0
KFES101]I68406eSH0@0KV9O0`1^HEd406iOFP@0Kf=P101_IF<406iVI@@0KVMV0`1]IfL406aWI`@0
JfMW101ZIfL806YVI`@0JFQX0`1YJV/406Y/KP@0Jfi`101[L7<406adM`@0KWQk0`1`Ngl4079oP`@0
MH>8101gR8d407Z<T`@0OI:I1021V:4307nDV`@0OI2G101lS98407Z9S`@0NHN<101iQHT307R3Q`@0
Mh:6101gP8@407InPP@0MGf0101eO7h307AjO@@0M7Uk101cN7X4079fN1H0oooo000D0?ooo`@0LWAe
101aLg@4075bL`<0L79c101`LG84071`L@@0Kfm`201_KVh306m]K0@0KVa/101^Jf/406iZJP@0KVUX
101]J6L406eXIP<0KFMU101]IV@406eUH`@0KFAR101]Hf0406iRG`<0KV5M101^GeX406mSH0@0KfES
101^IVD406iWIP<0KFMW101/IfL406]WI`@0JVMW201ZIVL406UXJ0<0JFY[101ZK6h406]^L0@0Jg1c
101/M7L406ihN`<0L7]o101bOh<407F3R0@0MhR=101jS9<407fBV@@0PIRQ0`1oU9/407f@U`@0O8bB
101jRHl407V7S0@0NHF90`1hPhL407N2QP@0Mh24101fOX8407EmP0@0MGan0`1dNWd407AiN`@0LgQj
101bMWPF0?ooo`00503oool4075dM@@0LG=d101aLW<3071aLP@0L71`101_Kfl406m^KP@0KVe]101^
K6/306i[JP@0KFYY101]JFP406eWIP@0K6IU101/IF@406aTHP<0K6=Q101/HV0406aQGP@0K61M101/
Ge/406eOFP<0KEiH101^G5H406iPG0@0KV9O101]Hf8406eTH`<0K6ET101[IF@406YUI@@0JFEU101Y
I6@406UTI@@0J6EV0`1XJ6T406UZK@@0JFe_101ZL7<406]cM`@0KGQl0`1`OH4407:1QP@0MXJ;101i
S98407^AV0@0OiNO1022W:H3082HX0@0OiBK101mT9L407b=U0@0Nh^A101jR8h307V6R`@0N8B9101h
PXL407N1Q0@0MWn2101eOH0307EkOP@0M7Yl101cN7X407=gN1H0oooo000D0?ooo`@0LGAe101aLg@4
075bL`<0L75b101`L70406m_K`@0Kfi^101^KFd406i/J`<0KV]Z101]JVT406eYJ0@0KFMV101/IVD4
06aUI0@0K6AR0`1/Hf4406aRH0@0K65N101/H5d406aOF`@0KEmJ0`1]GUP406iLEP@0KV1L101^HUl4
06eSHP@0KFAS0`1/IF@406]UI0@0JVEU101YIFD406UTI0@0JFAU101XIFH306QXJ@@0JFY]101YKFl4
06Y`L`@0Jg=g101]N7`3071mP@@0LX66101fQX/407V<TP@0Ni6H101oUil408:LYP<0P9RP101oU9/4
07f@U`@0O8fD101kRi4407Z8SP<0NHJ;101hQ8T407R2Q`@0Mh64101fOh8407EmP0<0MG]n101dNW`4
07=hNP@0LgMh5P3oool001@0oooo101aM7D4075cM0@0LG9c0`1`LG84071`L0@0Kfm_101_KVh406i]
K@@0KVa[0`1^JfX406eZJ@@0KFUX101]IfH406aVI@@0K6ET101/I68306aSH@@0K69P101/HEh406aP
G@@0K5mK101]GeX306eNF0@0KUaF101^H5`406iRG`@0KF=R101]I6<306aUI0@0JfET101ZIFD406UU
I@@0JFAT101YI6D406QUIP<0J6QY101YJVd406U]K`@0JW1c101[LgL406ehO0<0L7f1101bPHH407J6
R`@0NHbB101kTIP407nGW`@0PYbV0`20V:0407nDV`@0OI2G101lSI@407^;T@@0NXR>0`1iQX/407R4
R@@0N8:7101gPH@407IoPP@0MGf00`1eNgh407AjO0@0LgQj101cMgPF0?ooo`00503oool4075dM@@0
LG=d101aLW<3071aLP@0L71`101_Kfl406m^KP@0KVe]101^K6/306i[JP@0KFYY101]JFP406eWIP@0
K6IU101/IF@406aTHP<0K6=Q101/HV0406aQGP@0K61M101/Ge/406eOFP<0KEiH101^G5H406iPG0@0
KV9O101]Hf8406eTH`<0K6ET101[IF@406YUI@@0JFEU101YI6@406UTI@@0J6EV0`1XJ6T406UZK@@0
JFe_101ZL7<406]cM`@0KGQl0`1`OH4407:1QP@0MXJ;101iS98407^AV0@0OiNO1022W:H3082HX0@0
OiBK101mT9L407b=U0@0Nh^A101jR8h307V6R`@0N8B9101hPXL407N1Q0@0MWn2101eOH0307EkOP@0
M7Yl101cN7X407=gN1H0oooo000D0?ooo`@0LGAe101aLW<4071aLP<0L71a101_Kfl406m^KP@0KVa/
101^Jf/406eZJ@<0KFUX101/IfH406aVI@@0K6ES101[I64406]RH0@0Jf5N0`1ZH5d406YOF`@0JUeI
101ZG5P406]KE`@0K5]E0`1]FUD406iJE0@0KUeI101^Ge`406eQG`@0K69P0`1[HV4406YSHP@0JV=S
101YHf<406QSH`@0If=S101WI6D306MVI`@0J6U[101XK6h406U`L`@0JW=g101/NGd306moP`@0LX>9
101fRHh407V?UP@0OIFN1021W:H408>OZ@<0PI^T1020Uj0407nDW0@0OI6H101lSYD407^<TP<0NXV?
101jQh`407V5RP@0N8>7101gPH@407IoPP<0MGf0101dNgh407AiN`@0LgMi5P3oool001@0oooo101a
M7D4075bL`@0L75b0`1`L74406m_K`@0Kfi^101^K6`406i[J`@0KFYY0`1]JFP406aWIP@0K6IU101/
IF<406]TH@@0Jf9P101[HEh306YPG@@0JUmK101ZGET406YLF0@0Je]G101/FeD306eJE@@0KUYD101^
GET406iOG0@0KF5O101/HV0306]RH@@0JV=R101ZHf<406USH`@0J6=S101WHf<406MTI@<0IfIW101X
JF/406Q/KP@0JG1c101ZLgL406aiO@<0Kgn3101bPhT407J9SP@0NHnF101mUIh4086LYP@0PinY0`21
Vj@4082GX0@0OiBL101mTIP407b>U@@0NhbB0`1jRHl407Z7S0@0NHF:101hPhL407N1Q0@0MWn20`1e
OH0407AkOP@0M7Uk101cMgTF0?ooo`00503oool4075dM@@0LG9c101`LG83071`L@@0Kfm_101_KVh4
06i/K0@0KV][101]JVT306eYJ0@0K6MV101/IVD406aUH`@0JfAQ101[HV0406]QGP<0JV1M101ZGe/4
06YMF@@0JUaH101[FeL406aKE@<0KEYE101^FU@406iMF@@0KUmL101]HEl406aRH0<0Jf9Q101ZHf84
06YSH`@0JF=S101XHf<406MSH`@0IfAU0`1WIVL406QYJ`@0J6a^101YL7<406YcM`@0K7Um0`1_Oh<4
07:3R@@0MXV>101iSiH407fEWP@0PIbV1023WjT3086KY0@0P9NP101oU9`407fAV0@0O8jE101kS983
07Z9S`@0NXN<101iQHX407R3Q`@0Mh64101fOh8307EmP0@0M7]n101dNG/407=gNAH0oooo000D0?oo
o`@0LGAe101aLW<4071aLP<0L71a101_Kfl406m^KP@0KVa/101^Jf/406eZJ@<0KFUX101/IfH406aV
I@@0K6ES101[I64406]RH0@0Jf5N0`1ZH5d406YOF`@0JUeI101ZG5P406]KE`@0K5]E0`1]FUD406iJ
E0@0KUeI101^Ge`406eQG`@0K69P0`1[HV4406YSHP@0JV=S101YHf<406QSH`@0If=S101WI6D306MV
I`@0J6U[101XK6h406U`L`@0JW=g101/NGd306moP`@0LX>9101fRHh407V?UP@0OIFN1021W:H408>O
Z@<0PI^T1020Uj0407nDW0@0OI6H101lSYD407^<TP<0NXV?101jQh`407V5RP@0N8>7101gPH@407Io
PP<0MGf0101dNgh407AiN`@0LgMi5P3oool001@0oooo101aLgD4075bL`@0L75a0`1_Kg0406m^KP@0
KVa/101^JfX406eYJ@@0K6QW0`1/IVD406]UH`@0JfAR101ZHV0406YQGP@0JUmL101YGUX306ULF0@0
JE]G101YFED406UHD`@0JEMA101ZEe0306eGD0@0KeYC101^G5L406eMFP@0K5iL101/Geh306]PG`@0
JV1P101YHF0406QQH@P0If5R101VHf@306IUIP@0IfQZ101WJfh406Q`L`@0JWAh101/NWd306moQ0@0
LXJ;101fRi8407ZBVP@0OYVR1023XJ`408>QZ`<0PYjW1021VZ<4082GX0@0OiBL101nTIT407f?U@<0
O8bB101kRHl407Z7S0@0NHF9101hPXL407N0Q0<0MWj1101eO7l407AjO0@0LgMi5P3oool001@0oooo
101aLgD4075bL`@0L75a0`1_Kg0406m^KP@0KVa/101^JfX406eYJ@@0K6QW0`1/IVD406]UH`@0JfAR
101ZHV0406YQGP@0JUmL101YGUX306ULF0@0JE]G101YFED406UHD`@0JEMA101ZEe0306eGD0@0KeYC
101^G5L406eMFP@0K5iL101/Geh306]PG`@0JV1P101YHF0406QQH@P0If5R101VHf@306IUIP@0IfQZ
101WJfh406Q`L`@0JWAh101/NWd306moQ0@0LXJ;101fRi8407ZBVP@0OYVR1023XJ`408>QZ`<0PYjW
1021VZ<4082GX0@0OiBL101nTIT407f?U@<0O8bB101kRHl407Z7S0@0NHF9101hPXL407N0Q0<0MWj1
101eO7l407AjO0@0LgMi5P3oool001@0oooo101aLgD4075bL`@0L75a0`1_Kg0406m^KP@0KVa/101^
JfX406eYJ@@0K6QW0`1/IVD406]UH`@0JfAR101ZHV0406YQGP@0JUmL101YGUX306ULF0@0JE]G101Y
FED406UHD`@0JEMA101ZEe0306eGD0@0KeYC101^G5L406eMFP@0K5iL101/Geh306]PG`@0JV1P101Y
HF0406QQH@P0If5R101VHf@306IUIP@0IfQZ101WJfh406Q`L`@0JWAh101/NWd306moQ0@0LXJ;101f
Ri8407ZBVP@0OYVR1023XJ`408>QZ`<0PYjW1021VZ<4082GX0@0OiBL101nTIT407f?U@<0O8bB101k
RHl407Z7S0@0NHF9101hPXL407N0Q0<0MWj1101eO7l407AjO0@0LgMi5P3oool001@0oooo101aLgD4
075bL`@0L75a0`1_Kg0406m^KP@0KVa/101^JfX406eYJ@@0K6QW0`1/IVD406]UH`@0JfAR101ZHV04
06YQGP@0JUmL101YGUX306ULF0@0JE]G101YFED406UHD`@0JEMA101ZEe0306eGD0@0KeYC101^G5L4
06eMFP@0K5iL101/Geh306]PG`@0JV1P101YHF0406QQH@P0If5R101VHf@306IUIP@0IfQZ101WJfh4
06Q`L`@0JWAh101/NWd306moQ0@0LXJ;101fRi8407ZBVP@0OYVR1023XJ`408>QZ`<0PYjW1021VZ<4
082GX0@0OiBL101nTIT407f?U@<0O8bB101kRHl407Z7S0@0NHF9101hPXL407N0Q0<0MWj1101eO7l4
07AjO0@0LgMi5P3oool001@0oooo101aLgD4071bLP@0L71a0`1_KVl406i]K@@0KV][101]JFT406aX
I`@0K6IU0`1[I6<406YSH@@0JV5O101YGe`406UNFP@0J5aH101XFUH306MIE0@0IeMB101WEE0406ID
CP@0IU9<101VDDX3071HD0@0LE]D101_FeH406eLF0@0K5eJ101[GE`306YNG@@0JEiM101XGeh406MO
G`@0IUmO101VH60406ERHP<0IFAU101VIfT406M[KP@0J71c101YMGP406ajOP<0Kh66101bQhd407N>
U@@0O9FM101oW:H408BU/0@0Q:>^0`23X:/408:MY`@0PIZS1020Uj0407nEW0@0OY:I0`1mSiD407b<
TP@0NhZ?101jQh`407V4R@@0N8650`1fOh<407EmP0@0M7Ym101cN7XF0?ooo`00503oool4075cM@@0
L79b101`L74306m^K`@0KVe]101^Jf/406eYJ@@0K6QW101/IVD306]TH`@0JV=Q101ZHEl406UOG0@0
JEiJ101XG5P406QJEP<0IeUD101WEe8406MED0@0IUA>101VDT`406IABP<0L5Q@101aFe@406mKEP@0
KEaH101/GEX406]MG0<0JUiM101YGUd406QOGP@0IemO101VGel406IPH0@0IF9R0`1UI6D406IWJ@@0
If]^101XL7<406UeN0@0K7Yn0`1_PHH407:7S@@0MhjE101lUId407nLYP@0Q:F`1024Xjh308>PZ`@0
PYfW1021VZ<4082GX0@0OiFL101nTYT307f?U@@0O8bB101kRXl407Z7S0@0NHB9101hPHD307IoP`@0
MGf0101dNWd407=hNQH0oooo000D0?ooo`@0LG=e101`LW84071`L@<0Kfi_101^KFd406i[J`@0KFUY
101/J6L406aVI@<0JfAS101ZHf4406YQG`@0JEmL101YGUX406QLF0@0J5YF0`1WFE@406MGDP@0IeE@
101VE4h406IBC0@0IU5:0`1`F504075KE0@0Ke]F101]G5P406aMFP@0JeeL0`1ZGUd406UNG@@0J5mN
101WGel406IOG`@0IV1P101UHV8306ETI@@0IVMY101WJfh406Q`L`@0JGEh101/NWh306n1QP@0LXN=
101gSYD407bEW@@0OibV1024YK0408BS[P<0Pj2[1022WJL4086JX`@0P9NP101oUI`407jBV@<0OHnE
101lS98407^:S`@0NXN<101iQ8T407R1Q@<0MWn3101eOH0407AjO@@0LgQj5P3oool001@0oooo101a
LgD4071bLP@0L71a0`1_KVl406i]K@@0KV][101]JFT406aXI`@0K6IU0`1[I6<406YSH@@0JV5O101Y
Ge`406UNFP@0J5aH101XFUH306MIE0@0IeMB101WEE0406IDCP@0IU9<101VDDX3071HD0@0LE]D101_
FeH406eLF0@0K5eJ101[GE`306YNG@@0JEiM101XGeh406MOG`@0IUmO101VH60406ERHP<0IFAU101V
IfT406M[KP@0J71c101YMGP406ajOP<0Kh66101bQhd407N>U@@0O9FM101oW:H408BU/0@0Q:>^0`23
X:/408:MY`@0PIZS1020Uj0407nEW0@0OY:I0`1mSiD407b<TP@0NhZ?101jQh`407V4R@@0N8650`1f
Oh<407EmP0@0M7Ym101cN7XF0?ooo`00503oool4075cM0@0L75b101_Kg0306m^KP@0KVa/101]JVT4
06aXI`@0K6IU101[I68306YRH0@0JF1N101YGe`406QMF@@0Ie]G101WFED406IGDP<0IUE@101UDdh4
06EAB`@0I4m9101SCDH406A<A0<0MUaC101aFU<406mJE@@0KEYF101[FeP406YKF@<0JEaK101XG5/4
06MLG0@0IUaM101UGEd406ENG`@0I65Q0`1TI6D406EWJ@@0IVa^101WLG@406UfN@@0K7^00`1_PXL4
07>8S`@0Mi2G101lUj04082OZ@@0QJNc1025Y[4308BS[P@0Pj2[1022WZL4086KY0@0P9RP101oUI`3
07jBV@@0OHnE101lS98407^9SP@0NXJ;101hPhL307N0Q0@0MWj1101dNgd407=hNQH0oooo000D0?oo
o`@0LG=d101`LG8406m_L0<0Kfi^101^K6`406eZJ@@0K6QW101/IVD406]THP<0JV9P101YH5h406UO
G0@0J5eI101WFeL406MIE@@0IUMB0`1VEE0406ECCP@0IE5;101TCdT406==AP@0I4a40`1fG5<4075J
D`@0KeYE101]FUH406]KF0@0JU]I0`1YG5/406QLF`@0IeaL101VG5d406EMG@@0IEiO101THF4306AT
I@@0IFMY101VK6h406MaM0@0JGIi101/Nh0306n2Q`@0LhR?101gT9L407bGX0@0P9nY1025Yk<408FV
/@<0Q:>^1023X:/408:NY`@0PI^T1020V:0407nEW0<0OY:I101mSiD407b<TP@0NhV>101jQX/407R3
Q`<0Mh24101fOX4407AkO@@0LgQj5P3oool001@0oooo101aLg@4071aLP@0Kfm`0`1_KVh406i/K0@0
KFYY101/J6L406aVI@@0JfAR0`1ZHV0406UPGP@0JEmL101XGET406MKE`@0IeUE101VEe8306IED0@0
IE=>101UDD/406A?B@@0Hde6101TC4@307ILD`@0LEYC101_FUD406eJEP@0Je]H101ZFeT306ULF`@0
J5aK101WG5`406ILG@@0IEeM101UGUl406AQH@<0I6AU101UIfT406I/KP@0Ig5d101YMWT406akP0<0
Kh:7101cR8l407N@U`@0O9NP1020WjT408FW/`@0QJJa0`24Xjh408>PZ`@0PYjW1021Vj@4082HX0@0
OiFL0`1nTYT407f?U@@0O8bB101kRHh407Z6R`@0N8>70`1gP8@407InP@@0M7]m101cN7XF0?ooo`00
503oool4075cM0@0L75b101_Kg0306m^KP@0KVa/101]JVT406aXI`@0K6IU101[I68306YRH0@0JF1N
101YGe`406QMF@@0Ie]G101WFED406IGDP<0IUE@101UDdh406EAB`@0I4m9101SCDH406A<A0<0MUaC
101aFU<406mJE@@0KEYF101[FeP406YKF@<0JEaK101XG5/406MLG0@0IUaM101UGEd406ENG`@0I65Q
0`1TI6D406EWJ@@0IVa^101WLG@406UfN@@0K7^00`1_PXL407>8S`@0Mi2G101lUj04082OZ@@0QJNc
1025Y[4308BS[P@0Pj2[1022WZL4086KY0@0P9RP101oUI`307jBV@@0OHnE101lS98407^9SP@0NXJ;
101hPhL307N0Q0@0MWj1101dNgd407=hNQH0oooo000D0?ooo`@0LG=d101`LG4406m^K`<0KVe]101]
JfX406aYJ0@0K6MU101[I6<406YRH0<0JF1N101XGU/406QLF@@0IeYF101VF5<406EFD@@0IEA>0`1T
DT`406A?B@@0Hde6101SBd@40618@0@0Je180`1dFU84071HDP@0KUQC101/F5@406]IEP@0JEUG0`1X
FUT406MJFP@0IUYJ101UFUX406AJFP@0He]M101SGf0306=SI0@0IFQZ101VKFl406MbM0@0JGMj101]
OH430724R@@0M8Z@101hTIT407bIXP@0PJ2[2025ZKD308FV/P@0Q:B^1023XJ/408:NY`@0PY^T1021
V:0307nDW0@0OY6H101mSY@407b;T@@0NXR=101iQHT307R2Q@@0MWj2101eNgh407=hNQH0oooo000D
0?ooo`@0LG=d101`LG4406m^K`<0KVe]101]JfX406aYJ0@0K6MU101[I6<406YRH0<0JF1N101XGU/4
06QLF@@0IeYF101VF5<406EFD@@0IEA>0`1TDT`406A?B@@0Hde6101SBd@40618@0@0Je180`1dFU84
071HDP@0KUQC101/F5@406]IEP@0JEUG0`1XFUT406MJFP@0IUYJ101UFUX406AJFP@0He]M101SGf03
06=SI0@0IFQZ101VKFl406MbM0@0JGMj101]OH430724R@@0M8Z@101hTIT407bIXP@0PJ2[2025ZKD3
08FV/P@0Q:B^1023XJ/408:NY`@0PY^T1021V:0307nDW0@0OY6H101mSY@407b;T@@0NXR=101iQHT3
07R2Q@@0MWj2101eNgh407=hNQH0oooo000D0?ooo`@0LG=d101`LG4406m^K`<0KVe]101]JfX406aY
J0@0K6MU101[I6<406YRH0<0JF1N101XGU/406QLF@@0IeYF101VF5<406EFD@@0IEA>0`1TDT`406A?
B@@0Hde6101SBd@40618@0@0Je180`1dFU84071HDP@0KUQC101/F5@406]IEP@0JEUG0`1XFUT406MJ
FP@0IUYJ101UFUX406AJFP@0He]M101SGf0306=SI0@0IFQZ101VKFl406MbM0@0JGMj101]OH430724
R@@0M8Z@101hTIT407bIXP@0PJ2[2025ZKD308FV/P@0Q:B^1023XJ/408:NY`@0PY^T1021V:0307nD
W0@0OY6H101mSY@407b;T@@0NXR=101iQHT307R2Q@@0MWj2101eNgh407=hNQH0oooo000D0?ooo`@0
LG=d101`L74406m^KP<0KVa/101]JVT406aWIP@0JfET101ZHf4406UPGP<0J5iK101WG5P406IJEP@0
IUMC101UEE0406ACC@@0He1:0`1SCTP4069<A@@0HDU2101PASh406M<@`@0L5A;0`1`EDd406iED0@0
K5IA101[EU8406UFD`@0J5MF0`1WF5L406IHF0@0IEQH101TEeP406=GF0@0HUYK101RGUl3069SI0@0
I6QZ101UKW0406McM@@0JGQl101]OX<30765RP@0MHbC101iTiX407bIXP@0PJ2[1024Z;@408N/^@<0
QZZf1025Yk<408FT[`@0Q:6[1023WZL408:KX`<0PINO1020U9/407j@U`@0OHfC101kRXl407Z6R`<0
N8>7101gOh<407ElO`@0LgQk5P3oool001@0oooo101aLg@4071`L@@0Kfi^0`1^K6`406eZJ@@0K6MV
101[IF@406YSH@@0JF1N0`1XGU/406MLF0@0IUYF101VEe<406EED0@0I5==101SD4X306=>B0@0HTa5
101QBD840616?P@0Ida3101`E4/3071EC@@0KUE@101/EU4406]FDP@0JEIC101XEeH306MHE`@0IUQH
101UF5P406AGF0@0HeMH101RFU/4069NG`<0HV=T101TJ6X406E^L0@0Ig=e101YN7`406enP`<0LHF:
101eS9<407VCVP@0O9VR1021X:/408BX]0@0Qjbi0`26Z[H408FW/`@0QJB_1024XJ/408>NY`@0PY^S
0`21Uil4082DV`@0OY2G101mSI<407^:S`@0NXJ;0`1hPhL407MoP`@0MGao101cN7/F0?ooo`00503o
ool4075cM0@0L71a101_KVh306i/K0@0KFYY101/IfH406]UI0@0JV=Q101YH5h306QNF`@0IeaH101V
FUH406IGD`@0IEE@101TDdd406=@BP<0Hdi8101RC4D40659@P@0H4Hn101WC4<4071DB`<0L5E=101^
EE0406aFD@@0JeIB101YEU<406QGEP<0IeQG101VF5P406EHF0@0I5MH101SEeP4069JF`@0HUiO0`1R
Hf@406AXJP@0IFi`101WLgD406UhO0@0KGj30`1aQHX407F<T`@0NI>J101lVJ84086PZ`@0Q:Rd1027
[;T308JZ]P@0QJNc1025Y:l408BQZ`@0PijW1022Vj<3086GW`@0P9BK101nT9L407f=T`@0NhZ?101j
QX/307R3Q`@0Mgn3101eO7l407=hNaH0oooo000D0?ooo`@0LG=d101`L74406m^KP<0KVa/101]JVT4
06aWIP@0JfET101ZHf4406UPGP<0J5iK101WG5P406IJEP@0IUMC101UEE0406ACC@@0He1:0`1SCTP4
069<A@@0HDU2101PASh406M<@`@0L5A;0`1`EDd406iED0@0K5IA101[EU8406UFD`@0J5MF0`1WF5L4
06IHF0@0IEQH101TEeP406=GF0@0HUYK101RGUl3069SI0@0I6QZ101UKW0406McM@@0JGQl101]OX<3
0765RP@0MHbC101iTiX407bIXP@0PJ2[1024Z;@408N/^@<0QZZf1025Yk<408FT[`@0Q:6[1023WZL4
08:KX`<0PINO1020U9/407j@U`@0OHfC101kRXl407Z6R`<0N8>7101gOh<407ElO`@0LgQk5P3oool0
01@0oooo101aLW<4071`L0@0Kfe]0`1]Jf/406aYJ0@0JfIU101ZI68406UQG`@0J5mL0`1WG5T406IJ
EP@0IEMC101TE50406=BC@@0HTm9101RCDH3065;@`@0HDQ0101PASd406=6?@@0KU17101^DDP306eB
B`@0K5==101[Ddh406UCC`@0J5AA101WEU@306IFEP@0IUMG101UEUH406=FE`@0HUEF101QFEX4065M
GP<0HV9T101RIfP406A^L0@0IW=f101ZNWd406j0Q0<0LXN<101gSY@407ZDW0@0OIZS1021X:/408>W
/`@0Qjfj0`28[[/408N[]`@0QZRc1025Y:l408BQZ`@0PijW0`22VZ<4086GWP@0Oi>J101nSiD407b;
T@@0NhN<0`1iQ8P407N0Q0@0MGao101dNG/F0?ooo`00503oool4075bL`@0L71`101_KFd306e[J`@0
K6UX101[IVD406YTHP@0JF5O101XGe`306MLF@@0IUYF101UEe<406ADD0@0He9=101RCdT4069=AP<0
HD]3101QB4040616?@@0HdHm101^D4L406iAB0<0KE9;101/Ddd406]CCP@0JE=?101XE54406MFE0<0
IUIF101VEeL406EFEP@0HeIG101REEH4065IFP@0HEeN0`1RHV@4069WJ0@0I6i`101VLgH406YjO@@0
KX240`1bQh`407N>U0@0NYBL101mVZ<4086PZ`@0PjNc1027[KX308R^^`@0Qj^g1026Z;<408FT[`@0
Q:6[1023WZL308:JX`@0PINN101oTiX407j?U@@0O8^A101kQh`307V4R0@0Mh24101eO7l407AiNaH0
oooo000D0?ooo`@0LG9c101`L70406m]K@<0KF][101/JFP406]VI@@0JVAR101YHEl406QOG0<0IeaI
101VFUH406EGD`@0I5A@101SDTd4069?B@@0HTe60`1QBd<40658@0@0H4Hm101SASd406i@A`@0KU58
0`1]DT/406aCC@@0Je=>101YDdl406QDD@@0IeID0`1VEUH406IGE`@0IEIF101SEUL4069EEP@0HEUJ
101QGEh3069RI0@0HVMX101TKW0406IcMP@0JWYm101^P8@307:7S0@0MhjD101jU9`407fJX`@0PJ2[
1023Yk<408N]^P<0R:jk1027ZkL408JX/`@0QJB_1024XJ/408>NY`<0PYZS1021Uih407nCVP@0OXnE
101lRi4407^7S0<0NHB8101gP8@407ElO`@0M7Uk5P3oool001@0oooo101aLW<4071`L0@0Kfe]0`1]
Jf/406aYJ0@0JfIU101ZI68406UQG`@0J5mL0`1WG5T406IJEP@0IEMC101TE50406=BC@@0HTm9101R
CDH3065;@`@0HDQ0101PASd406=6?@@0KU17101^DDP306eBB`@0K5==101[Ddh406UCC`@0J5AA101W
EU@306IFEP@0IUMG101UEUH406=FE`@0HUEF101QFEX4065MGP<0HV9T101RIfP406A^L0@0IW=f101Z
NWd406j0Q0<0LXN<101gSY@407ZDW0@0OIZS1021X:/408>W/`@0Qjfj0`28[[/408N[]`@0QZRc1025
Y:l408BQZ`@0PijW0`22VZ<4086GWP@0Oi>J101nSiD407b;T@@0NhN<0`1iQ8P407N0Q0@0MGao101d
NG/F0?ooo`00503oool4075bL`@0Kfm`101^KFd306eZJP@0K6MV101[IF<406YRH0@0J5mM101WGEX3
06IJEP@0IEMC101TE50406=BC0@0HTm9101QC4H4061:@P<0GdLo101OAC`405i2>0@0KDe3101^CdD4
06e@A`<0K519101ZD4/406U@B`@0Ie1<101VDTl406IDD`<0IUEE101UEED406EEEP@0HeIG101QEeP4
061IF@@0HEiO0`1QHF<4061TIP@0Hfa^101ULgD406YkO@@0Kh:50`1cR8d407R?UP@0NiFM101nVj@4
082PZ`@0PjNb1026[;P308Va_`@0R:jk1027ZkL408NX/`@0QZB_1025XJX308BMYP@0PYVQ1021UI`4
07nAV0@0OHfC101lRHh307Z5RP@0N865101fOH0407AiNaH0oooo000D0?ooo`@0LG9c101_Kg0406i]
K@<0KFYZ101/IfH406]UH`@0JV9P101XGed406MMFP<0IUYF101UEe<406ADD0@0He9<101RCdT4065<
AP@0H4Y20`1OAcl405m5?0@0GT8h101]CD<406i?A@@0KE170`1/D4T406Y@B`@0JE1;101WD4`406IB
C`@0IUAC0`1VEED406EEE@@0IEEF101SEUL4065GF0@0H5UI101QGUl3065QH`@0H6AV101SK6h406Ec
M@@0JW]m101_PXD307>8S@@0N8nF101kUId407jKY0@0P:2[1023Yk8408J/^0<0RK6o1028[[/408N[
]`@0QjRc1026Y:l408FQZP<0Q9fV1022VJ44086EW0@0Oi6H101mSI<407b9SP<0NXF:101hPHD407Im
P0@0M7Uk5P3oool001@0oooo101aLW<406m_L0@0KVe]0`1]JVX406aWIP@0JfES101ZHV0406QOG@@0
IeeJ0`1VFUH406EGD`@0I5A@101SDT`4069?B@@0HDa6101PBT8305m7?`@0GdDl101N@SP406e=@`@0
KTm5101]D4L306a@B@@0JU1;101YD4/406M@C0@0IU9?101VE5<306IEE@@0IEEE101UEEH406=FE`@0
HEMH101PFET4065NG`<0HF5S101PI6H406=/KP@0IG=e101ZNgd406n2Q@<0LhR=101hSiH407^EW@@0
OY^T1020X:/408>W/P@0QZbh0`29/Kl408R^^`@0Qj^g1027Z;<408JT[`@0QJ6Z0`24WJH408:IX@@0
PIFL101oTIP407f=T`@0O8V>0`1jQHX407R1Q@@0MWf0101dNG/F0?ooo`00503oool4075bL`@0Kfm`
101^KFd306eZJP@0K6MV101[IF<406YRH0@0J5mM101WGEX306IJEP@0IEMC101TE50406=BC0@0HTm9
101QC4H4061:@P<0GdLo101OAC`405i2>0@0KDe3101^CdD406e@A`<0K519101ZD4/406U@B`@0Ie1<
101VDTl406IDD`<0IUEE101UEED406EEEP@0HeIG101QEeP4061IF@@0HEiO0`1QHF<4061TIP@0Hfa^
101ULgD406YkO@@0Kh:50`1cR8d407R?UP@0NiFM101nVj@4082PZ`@0PjNb1026[;P308Va_`@0R:jk
1027ZkL408NX/`@0QZB_1025XJX308BMYP@0PYVQ1021UI`407nAV0@0OHfC101lRHh307Z5RP@0N865
101fOH0407AiNaH0oooo000D0?ooo`@0LG9c101_Kfl406i/K0<0KFUY101[IVD406YTHP@0JF5N101X
GU/406IKE`<0IEQD101TEE0406=BC@@0HDm9101PC4H405m9@P@0GTHo0`1M@c/405e0=`@0HT<h101a
D4D406i?AP@0K4i60`1[CdP406U>B0@0Ide8101TCDT406A?C@@0IU=C0`1UE5@406=DE0@0J5UJ101T
F5P4069JF`@0H5YK101OFed305iOH@@0GV9T101QJF`406=_LP@0JWUl101_PhH307F:SP@0NI6G101l
Uil407jLY0@0P:2Z1022Y[4408F[]`<0R;2n1029//0408V__0@0R:^g1028Z;<408NT[P<0QZ2Y1024
W:@408:HW`@0P9>J101nSiD407b;T0<0NXJ;101hPXH407InP@@0M7Ul5P3oool001@0oooo101aLW<4
06m_K`@0KVa/0`1]JFT406]VI@@0JVAR101YHEh406QNF`@0IU]G0`1UF5@406AED0@0He9=101QCdT4
061<AP@0GdU2101NASl305e3>`@0GD0g101R@cP4075@A@@0KTm6101/CTH306]?B0@0JDi8101WCDP4
06A=B@@0I4m=101VDe<306EDE0@0HeAD101XFEX406AHF0@0HUYK101PFU/405mKG@<0GUmQ101NHV@4
065YK0@0Hfmb101ZNG`406n3QP<0MHZ>101iTIL407bGW`@0OYbT1020X:X408:V/@@0QJ^g0`28/;h4
08Vb`0@0RJnl1028ZkL408RX/`@0QjB^0`26X:T408BLY0@0PYRO1020TiX407j?U@@0O8^@0`1jQX/4
07R2QP@0MWj1101dNG`F0?ooo`00503oool4075bL`@0Kfm_101^K6`306eYJ@@0JfIU101ZI68406UQ
GP@0J5iK101VFeL306EHE0@0I5E@101SDTd4065?B@@0H4a6101OBD8405i6?`<0GD<k101M@3L40693
>0@0LE15101^CdH406a>AP<0Jdm8101YCTP406M=B0@0I4e9101TCdd406ICD`<0IEAD101SE5@406QI
FP@0I5QH101RFU/4061JF`@0Ge]M0`1NGf4405iRI0@0HFU/101SKg8406YiO0@0Kh>60`1eRXh407VA
U`@0O9NO101nW:@4082PZP@0PZJa1025ZkL308R`_P@0RK;01029[k`408R[]`@0R:Rc1027Y:h308JP
Z@@0Q9bT1022V9l4082CVP@0OXnE101lRi0307Z6R`@0N8:6101fOX4407AiO1H0oooo000D0?ooo`@0
LG9c101_Kfl406i/K0<0KFUY101[IVD406YTHP@0JF5N101XGU/406IKE`<0IEQD101TEE0406=BC@@0
HDm9101PC4H405m9@P@0GTHo0`1M@c/405e0=`@0HT<h101aD4D406i?AP@0K4i60`1[CdP406U>B0@0
Ide8101TCDT406A?C@@0IU=C0`1UE5@406=DE0@0J5UJ101TF5P4069JF`@0H5YK101OFed305iOH@@0
GV9T101QJF`406=_LP@0JWUl101_PhH307F:SP@0NI6G101lUil407jLY0@0P:2Z1022Y[4408F[]`<0
R;2n1029//0408V__0@0R:^g1028Z;<408NT[P<0QZ2Y1024W:@408:HW`@0P9>J101nSiD407b;T0<0
NXJ;101hPXH407InP@@0M7Ul5P3oool001@0oooo101`LW<406m^K`@0KV][0`1/JFP406]UI0@0JF9P
101XGed406MLF@@0IEUE0`1TEU4406=CCP@0HDm:101PC4H405i9@P@0GDHn101L@c/305a0=`@0FS`c
101/Bcl4071?A0@0KTi5101[CDD306Y>B0@0Ida6101UBTD4069:AP@0HTe;101SDE4306MHF0@0IEQG
101XG5`406AJFP@0HUYK101PFe/405iIFP<0GEmQ101MHV@405iVJ@@0GfY]101XMGT40762QP<0Mhb@
101kTYP407jIX0@0OifU1020X:X4086T/0@0Q:Vf0`26[kd408Vc`P@0R[:o102;[k`408Z/]`@0RJRb
0`28Xjd408JOY`@0Q9ZR1022UYd4082AU`@0OHbB0`1kR8`407V3Q`@0Mgj1101dNW`F0?ooo`00503o
ool4071bL`@0Kfi_101^Jf/306aYJ0@0JfET101YHV0406QOG@@0IeaI101UFED306AFD@@0He=>101Q
CdX4061<AP@0GTU2101MASh405a3>`<0G40g101J?3<406a;?`@0L4m4101^CTD406]=A@<0JTi8101W
C4H406E:A@@0HTY6101RCD/406=AD@<0IeQH101UF5L406QLG0@0I5YJ101RFU/4061KF`@0GUUJ0`1M
Gf4405eRI0@0GVIY101OJVd406QeN@@0LH:60`1gS90407^BV0@0OYVP101oWJD4082PZP@0PJB`1024
ZKH308J__@@0RK?2102:/[l408^__0@0RZbg1029Z;8308RS[@@0QYnW1024VZ8408:FW@@0P96G101m
S98307^8S0@0NH>7101gOX4407AjO1H0oooo000D0?ooo`@0L79c101_KVl406i[J`<0K6UX101[IF@4
06URH0@0J5mM101WG5T406EIE@<0I5IA101SDdh4065?BP@0H4a6101NBD8405e6?P@0G4<k0`1L@3L4
05Xl<`@0K4/o101`Cd@406i>A@@0Jde50`1ZCTP406M<AP@0IDY5101RBTH4069=B`@0He5A0`1WF5P4
06EHE`@0J5aL101TFUX4069JF`@0H5]K101NFEX305eOH@@0GF9T101NIVT405mZK@@0J7Ei101aPXH3
07N<T0@0Ni:H101nVJ0407nMY@@0P:2Z1021Y;0408BY]P<0QZnm1029/l8408Zb_`@0Rjnl102:[;L4
08VX/P<0R:>]1026WjL408BJXP@0PYJM1020TIL407f<TP<0NhR<101iPhL407MnP@@0M7Yl5P3oool0
01@0oooo101`LW<406m^K`@0KV][0`1/JFP406]UI0@0JF9P101XGed406MLF@@0IEUE0`1TEU4406=C
CP@0HDm:101PC4H405i9@P@0GDHn101L@c/305a0=`@0FS`c101/Bcl4071?A0@0KTi5101[CDD306Y>
B0@0Ida6101UBTD4069:AP@0HTe;101SDE4306MHF0@0IEQG101XG5`406AJFP@0HUYK101PFe/405iI
FP<0GEmQ101MHV@405iVJ@@0GfY]101XMGT40762QP<0Mhb@101kTYP407jIX0@0OifU1020X:X4086T
/0@0Q:Vf0`26[kd408Vc`P@0R[:o102;[k`408Z/]`@0RJRb0`28Xjd408JOY`@0Q9ZR1022UYd4082A
U`@0OHbB0`1kR8`407V3Q`@0Mgj1101dNW`F0?ooo`00503oool4071aLP@0Kfi^101]JfX306aXI`@0
JVAS101YHEl406MNF`@0IUYG101UEe<306=DC`@0HU1;101PCDL405i9@`@0GDHn101K@SX405Xo=P<0
FSdd101K?38407=@@`@0L4m4101^CT@406]=A@<0JDe7101VBdD406=8@`@0H4Q5101QBdX4065?D0<0
JeeL101XG5/406IKF`@0I5]L101QFET405mIFP@0GEUJ0`1MGf4405eQH`@0GFIY101NJ6`406AbM`@0
KWf10`1hRhl407fDVP@0Oi^Q1020WZH407nPZ@@0P:>_1023Z;D308F^_0@0Qk?2102:/l4408fc`0@0
S[2l102<[;H308ZW/0@0R::[1026WJD408>HW`@0PI>I101nSY<307b9SP@0NHB8101gOh8407AjO1H0
oooo000D0?ooo`@0L75b101_KVh406e[JP<0K6QW101ZI6<406UQG`@0IeiK101VFUL406EGD`<0HeA?
101RD4/4061=A`@0GTU3101MASh405]2>P@0FSlf0`1J?C@405/l<P@0Le13101`Cd@406i>A0@0Jde5
0`1YCDL406I;A@@0HdQ3101PB4D4065;BP@0HDm@0`1[GE`406QLF`@0IU]K101TFe`4065IF@@0GeUJ
101MFEX305eOH@@0GF5S101MIVT405iXK0@0I79g101^OH4307R;S`@0OIBJ101oVj44082NYP@0Oj2Y
1020Xjl408>X]@<0QJjl1027/l8408Zc`@@0SK?0102>/;`408b/]P<0RZN`1028XZ/408JMY@@0PiRO
1021TiT407j>T`<0O8V>101iQ8P407MoPP@0M7Yl5P3oool001@0oooo101`LG8406m^KP@0KF]Z0`1/
J6L406YTH`@0JF5O101WGU/406IJE`@0IEMC0`1SE4l4069@B`@0H4e7101NBD<405e6?P@0Fd8j101J
?cH305Xm=0@0Fc`b101cD4<4071?A0@0KTi4101[CDD306U=A`@0IT]5101SB4<40618A@@0HD]:101Q
Ce0306]MG0@0J5aK101VFe/406AKG0@0HEUI101OFEX405eIFP<0GEmQ101MHF<405eVJ@@0GVQ/101T
LWL406imP@<0N8^?101mU9X407nKX@@0P9jV101oX:T4082S[`@0PjRe0`25[[`408Nc`P@0R[?1102=
/l0408j`_0@0S:bf0`2:Yk0408RRZ`@0QYfU1023V9l4086CV@@0OXjC0`1lRHh407V4R0@0Mgn2101d
NW`F0?ooo`00503oool4071aLP@0Kfi^101]JfX306aXI`@0JVAS101YHEl406MNF`@0IUYG101UEe<3
06=DC`@0HU1;101PCDL405i9@`@0GDHn101K@SX405Xo=P<0FSdd101K?38407=@@`@0L4m4101^CT@4
06]=A@<0JDe7101VBdD406=8@`@0H4Q5101QBdX4065?D0<0JeeL101XG5/406IKF`@0I5]L101QFET4
05mIFP@0GEUJ0`1MGf4405eQH`@0GFIY101NJ6`406AbM`@0KWf10`1hRhl407fDVP@0Oi^Q1020WZH4
07nPZ@@0P:>_1023Z;D308F^_0@0Qk?2102:/l4408fc`0@0S[2l102<[;H308ZW/0@0R::[1026WJD4
08>HW`@0PI>I101nSY<307b9SP@0NHB8101gOh8407AjO1H0oooo000D0?ooo`@0L75b101^KVh406eZ
JP<0JfMV101ZHf4406QPG@@0IeaI101UFED406AED@<0HU9=101QCTP405m;A0@0GDLo101K@c/405Pn
=@@0E3T`0`1K?3<406I5>@@0M555101`Cd@406e=A0@0JTe50`1XC4H406E:A0@0HTM2101QBTL4069>
C0@0He9A0`1YFET406MJF@@0I5UI101SFUX4061GF0@0GUQI101LF5X305eMH0@0GF5T101NJ6/405mY
K@@0Hg5g101XNGh307B6R`@0OiJK1021W:84082NY`@0OinY101oXZh4086W]0<0Q:fk1026//4408Ze
a0@0S[G4102A]L4408n`^P<0S:Zd102:YJh408NOZ0@0QIZQ1022UI/407n?U@<0OHZ?101jQHT407Mo
P`@0MGYm5P3oool001@0oooo101`LG8406i^KP@0KFYZ0`1[IfH406YSH@@0J61M101WG5T406EIE@@0
I5EA0`1RDTd4065>B0@0Gd]4101MAcl405]3>`@0F3he101D>C0305/l<`@0ITDi101dDDD4071?A0@0
KDe4101ZCDD306Q<AP@0IDY4101RAd84065:A`@0HTi<101SDU4306UIF@@0IeYI101TFET406=JFP@0
H5MH101NF5T405aHFP<0GEeP101MHF@405iXJ`@0GfU]101SLGL406QiOP<0M8J;101oUY/4086LXP@0
P9jW101oWjT407nR[P@0PJNd0`24[K/408Jb`@@0R[G4102>]L@4096e`@@0Sk2j0`2<Z[@408ZU[P@0
QinX1025VZ4408:EV`@0OhnE0`1mRXl407Z5R@@0Mgn3101eNWdF0?ooo`00503oool4071aLP@0KVi^
101]JVX306]WIP@0JV=Q101XH5d406MLF@@0IEUE101TEE43069BC@@0HDi8101OBd@405e7?`@0Fd<k
101H?SD405@i<0<0Fc`c101VACT407AAA@@0L4m4101]CD@406Y=A@<0J4a6101UBT@40697@P@0HDY7
101RCT`406=BD@<0JEUI101WFUT406AIF@@0HeYJ101PEeP405iHF@@0G5QJ0`1MGF0405eQI0@0GVQ[
101OJFd406=aM`@0J7Un0`1dQX/407nFV`@0PIbR1020WZL407nOZ@@0Oj:^1021Yk@308B]^`@0Q[;1
102:]L@408jea0@0TKG1102?/;X308bZ]0@0RZF^1027WjP408FJX@@0PYFK101oSiD307f:S`@0NXF9
101gOh<407EjOAH0oooo000D0?ooo`@0L75b101^KFd406aYJ@<0JfIT101YHV0406MNG0@0IU]H101T
Ee<406=DC`<0HE1:101PC4H405i8@@@0G4@m101J@3P405Dj<@@0D3@Z0`1N?c@4079>@P@0LU14101_
CT@406a<A0@0JTe50`1XC4D406E:A0@0HTQ3101RC4P406ECD@@0IEEC0`1VEUH406AGE`@0HeQG101Q
EeL405mFEP@0GEIG101LF5X305aLGP@0G65T101NIfX4065ZK`@0Hg5g101XNGl306n3R@@0OIBI1021
WJ<4082NY`@0OYjX101nXJd4082V/`<0Pj^i1025/;l408Nc``@0Tk_9102D^LD409:d_`<0Sjfh102<
Z;4408VRZP@0QYbT1023UYd4086AU`<0OX^@101kQXX407R0P`@0MGYm5P3oool001@0oooo101`LG84
06i]K@@0K6UY0`1[IV@406URH0@0IeiL101VFeP406AGD`@0HeA?0`1QD4X4061<AP@0GTQ1101LA3d4
05Y0>0@0ECXa101@=2X305ho=0@0LTi2101bD4@406m>A0@0K4a4101ZCDD306Q<A@@0IDY4101RB4<4
069<B0@0IE=A101UEE<306IFEP@0I5MG101SF5L4065GE`@0GeIF101MEUL405aHFP<0G5aN101LHF@4
05iWJP@0HFY_101SLGL406QiO`<0Kh>9101mU9T4086MX`@0P9jW101nWZP407jQ[@@0P:Jc0`23ZkT4
08F`_`@0Qk?3102C^lT409Bia@@0T[Bo0`2?[KP408bX/@@0RJ:Z1026W:@408>FW@@0PI6G0`1nRi04
07^6RP@0N823101eNWdF0?ooo`00503oool4071aLP@0KVe]101/JFT306]VI0@0JF9P101WGU`406IK
F0@0I5MC101SE4l3065@BP@0H4a6101NB44405a4?@@0FT0h101E>S44050d:P<0GSld101bCT84079@
A0@0Kdi4101/C4@406Y=A@<0J4a5101UBT@40698@`@0HTa8101UDe4406EED`<0IUIF101TEeL406=H
E`@0HEMG101OEUH405eFE`@0G5QJ0`1LG5h405aQI0@0GVMZ101QJVl406=aM`@0J7Uo0`1_PhT407fD
V@@0PIfS1020WZL407jNZ0@0OZ6]1020Y[<308>[^@@0QK2o1027/l<409>kb@@0U;W5102B];l308n]
^0@0S:Ra1029XZX408JLY0@0PiJM1021TIL307j;T0@0NhJ:101hP8<407EjOAH0oooo000D0?ooo`@0
L75b101^KFd406aYJ@<0JfIT101YHV0406MNG0@0IU]H101TEe<406=DC`<0HE1:101PC4H405i8@@@0
G4@m101J@3P405Dj<@@0D3@Z0`1N?c@4079>@P@0LU14101_CT@406a<A0@0JTe50`1XC4D406E:A0@0
HTQ3101RC4P406ECD@@0IEEC0`1VEUH406AGE`@0HeQG101QEeL405mFEP@0GEIG101LF5X305aLGP@0
G65T101NIfX4065ZK`@0Hg5g101XNGl306n3R@@0OIBI1021WJ<4082NY`@0OYjX101nXJd4082V/`<0
Pj^i1025/;l408Nc``@0Tk_9102D^LD409:d_`<0Sjfh102<Z;4408VRZP@0QYbT1023UYd4086AU`<0
OX^@101kQXX407R0P`@0MGYm5P3oool001@0oooo101`LG8406i]K@@0K6UX0`1ZIF<406QQG`@0IeeJ
101UFEH406=ED@@0HU9<0`1PCTP405m:@`@0GTLo101L@cX405Xn=@@0EST`101E=b`30691=P@0Kde1
101^CD8406e=@`@0Jde5101YCDD306M=A@@0IDY4101RBD@4069<B0@0IUAB101VEU@306EFE@@0I5IF
101REeH4061FEP@0GUEE101LEEH405]HF@<0Fe]M101LH6<405iUJ@@0HVY`101ULWL406UjP0<0L8>:
101hSiH407nJX0@0OifV101nWZP407fP[0@0OjFa0`22Z[P408>^_@@0Pk71102H`<h409Nmb@@0UKO3
0`2A/K/408jZ]0@0RjB]1028WZH408FHW`@0PY:H0`1nS94407^6R`@0N864101eNgdF0?ooo`00503o
ool4071aLP@0KVe]101/JFP306YUH`@0J65O101WGEX406EIEP@0HeEA101RDT`3061>B0@0GdY3101N
Acl405a3>P@0FShe101F>C0405Dg;0<0HT4f101_CD4406i=@P@0KDe3101[CDD406U=A@<0Ide5101U
BT@40699A0@0HTa8101VE58406IFE0<0IEIE101TEUH4069GEP@0H5IF101NEED405aEEP@0FeQI0`1K
Fed405aPH`@0GVEY101RJW0406EbM`@0JGZ00`1`PhX407R?UP@0OiZP101oWJH407jNZ0@0OJ2/101o
YK4308:Z^0@0Pjjm1023/L4409S0cP@0Ukg9102E]l<3096a^`@0SZZd102;Y:d408RNYP@0QIRO1022
TYP307j<T@@0NhJ;101hPH@407EkOAH0oooo000D0?ooo`@0L75b101^KFd406aYJ0<0JVES101XHEl4
06MMFP@0IEUF101SEE44069BC0<0H4i8101OBT<405i7?`@0G4<j101J?SD405Hi<0@0ECL/0`1R@CH4
06m=@@@0KTe2101]CD<406]=A@@0JDe50`1WCDD406E:A0@0HTU4101RC4P406IDDP@0IUID0`1UEUD4
06AFEP@0HUMF101PEUH405iEE@@0G5EF101KF5T305]KG@@0G61S101NIFT4069ZL0@0IG9g101YNX03
0723RP@0N8nF101oVZ0407nMYP@0OYjX101mX:`407nU/@<0PZZh1023[[d408>a`@@0V<3>102G_LT4
09Fg``<0TK6k102>Z[@408^T[@@0R9jV1025V9l408:BV0<0OXbA101kQX/407R1Q0@0MG]m5P3oool0
01@0oooo101`LG8406i]K@@0K6UX0`1ZIF<406QQG`@0IeeJ101UFEH406=ED@@0HU9<0`1PCTP405m:
@`@0GTLo101L@cX405Xn=@@0EST`101E=b`30691=P@0Kde1101^CD8406e=@`@0Jde5101YCDD306M=
A@@0IDY4101RBD@4069<B0@0IUAB101VEU@306EFE@@0I5IF101REeH4061FEP@0GUEE101LEEH405]H
F@<0Fe]M101LH6<405iUJ@@0HVY`101ULWL406UjP0<0L8>:101hSiH407nJX0@0OifV101nWZP407fP
[0@0OjFa0`22Z[P408>^_@@0Pk71102H`<h409Nmb@@0UKO30`2A/K/408jZ]0@0RjB]1028WZH408FH
W`@0PY:H0`1nS94407^6R`@0N864101eNgdF0?ooo`00503oool4071aL@@0KVa/101[J6L306UTHP@0
J61M101VG5P406AHE0@0HUA?101QD4X3061<AP@0GTQ1101MACd405a1>0@0Fchd101J>S0405dm<@<0
HT8g101YBCh406a<@P@0K4e4101ZCDD406U=A@<0Ide6101UBdD406=:A0@0Hda8101UDTl406IGE@<0
IEMF101SEUH4065FE@@0GeEE101ME5@405]DE@@0FUMH0`1JFed405]OH`@0GFEY101RK70406IcN@@0
Jg^20`1aQ8/407J=U0@0O9JM101mVZ@407fLYP@0O9n[101nY;03082Y]`@0PJfl1022/<4409[2d0@0
Vl3=102G^/H309Bd_P@0T:fg102=Yk0408VPZ0@0QYZQ1023U9X307n>T`@0O8N<101iPHD407EkOQH0
oooo000D0?ooo`@0L75a101^K6`406]XI`<0JFAR101XH5d406ILF0@0I5QD101RE4l4065@BP<0H4a6
101NB44405e5?@@0G44h101K?S@405Xj<0@0GCda0`1R@SL406U9?P@0K4a2101/CD@406Y=A@@0JDe5
0`1WCDH406E;A@@0HdY4101SC4P406EBC`@0IUME0`1UEeH406=FEP@0HEIE101OEED405eDE0@0FeAE
101JEeP305YKG@@0FemS101MIFT4069/L0@0IW=i101[Nh830764R`@0MXfD101lUYd407fJY0@0OIbV
101lWj/407jT/0<0P:Vg1021[K`408:``@@0V/;@102K`<d409NjaP<0U;Bn102@[KL408fW/0@0RJ2X
1026VZ4408>DVP<0OhjC101lQh`407V1Q@@0MG]n5P3oool001@0oooo101`LG4406i/K0@0JfQW0`1Y
I68406QPG@@0IUaH101TF5@4069DC`@0HE1:0`1PC4H405i8@@@0GDDm101L@CP405/n=0@0FSX`101M
?C430692=`@0JDTn101/C48406a=A0@0JTe5101YCDD306M=AP@0ID]5101SBT@406=<B0@0IE9?101V
EeD306EGEP@0HeIF101QEUD405mEE@@0GEAD101KE5D405YGF0<0FU]M101KGf<405eUJ@@0HVa`101V
LgT406]kPP<0LHB;101fSI@407bFW@@0OIZT101mW:H407bOZ`@0OZB`0`20ZKL4086]_0@0P[31102J
`]0409_0c@@0Uk[60`2D];h4092]]`@0SJN`1029X:P408JJX@@0PiBJ0`1oSY<407b7S0@0NH65101e
NghF0?ooo`00503oool4071aL@@0KVa/101[J6L306UTHP@0J61M101VG5P406AHE0@0HUA?101QD4X3
061<AP@0GTQ1101MACd405a1>0@0Fchd101J>S0405dm<@<0HT8g101YBCh406a<@P@0K4e4101ZCDD4
06U=A@<0Ide6101UBdD406=:A0@0Hda8101UDTl406IGE@<0IEMF101SEUH4065FE@@0GeEE101ME5@4
05]DE@@0FUMH0`1JFed405]OH`@0GFEY101RK70406IcN@@0Jg^20`1aQ8/407J=U0@0O9JM101mVZ@4
07fLYP@0O9n[101nY;03082Y]`@0PJfl1022/<4409[2d0@0Vl3=102G^/H309Bd_P@0T:fg102=Yk04
08VPZ0@0QYZQ1023U9X307n>T`@0O8N<101iPHD407EkOQH0oooo000D0?ooo`@0L71a101]K6`406]W
IP<0JF=Q101WGU`406EJE`@0HeIB101QDTd4061>B0<0GdY3101NASl405e3>P@0G40f101L?C8405dl
;`@0Gclc0`1SA3T406M9?`@0Jda2101[CTD406Y>AP@0JDi60`1WCDH406E<A@@0I4Y5101SC4P406=@
C@@0IEID0`1UF5L406=GEP@0H5ED101NEED405aDE0@0FU=D101IEUL305UJG0@0Ff1S101NIFT406=]
L@@0J7Aj101]OH830764R`@0MXbD101jU9d407^GX@@0NiZU101kWZX407fS/0<0OjRf1020Zk/407n^
_`@0W<?B102N`m0409Zmb@<0U[O2102C/;X408nY/P@0Rj:Z1027W:<408BEV`<0P8nD101mR8d407V2
Q@@0MG]n5P3oool001@0oooo101`L74406e/K0@0JfMV0`1YHf4406MNG0@0IEYG101SEU84065BC@@0
H4i80`1OBT<405i6?`@0GD<j101L@3H405`m<P@0GC`_101O?c<306=4>@@0IdTo101[C48406]>A@@0
JTi6101YCTH306M=AP@0IDa5101TBTD406=<B0@0He1=101UEU@306EHE`@0HeMF101PEE@405iEE@@0
G5AD101JDe@405UFE`<0FEYL101KH6<405iUJ@@0Hfea101XM7X406emPP<0LHB;101fS9@407ZDW@@0
NiNQ101kVZD407^NZP@0OJ>`0`1oZ;H4082[^`@0Ojjo102L`m8409k3d0@0V[g90`2F]l8409>`^P@0
SjVb102;XZX408NLX`@0Q9FK0`20Si@407f8S@@0NH:5101eNghF0?ooo`00503oool4071`L@@0KFa/
101[IfH306USH@@0IeiL101UFUL406=FDP@0HE9=101PCTP305m:@`@0GTHo101M@cX405a0=P@0G3db
101M?2l405lo<`<0Hd@i101WBCl406]<@P@0Jdi5101ZCTH406U>AP<0Ide6101UC4D406A:A@@0Hda8
101SD4d406EFE0<0IEQG101SEeH4061EE0@0GUEE101LE5@405YCE0@0FEIG0`1IFU`405]PH`@0GVEY
101SKG4406QdNP@0KGf20`1aQ8/407J<U0@0NYBM101kUj4407^JY@@0NijZ101mXk0307nX]P@0P:^k
101o[[l409c3dP@0W/?@102J_LT309Jg`P@0Tk2j102?ZK8408^RZP@0QibS1024UI/3082?U0@0OHR=
101iPXD407EkOQH0oooo000D0?ooo`@0L71a101]K6`406]WIP<0JF=Q101WGU`406EJE`@0HeIB101Q
DTd4061>B0<0GdY3101NASl405e3>P@0G40f101L?C8405dl;`@0Gclc0`1SA3T406M9?`@0Jda2101[
CTD406Y>AP@0JDi60`1WCDH406E<A@@0I4Y5101SC4P406=@C@@0IEID0`1UF5L406=GEP@0H5ED101N
EED405aDE0@0FU=D101IEUL305UJG0@0Ff1S101NIFT406=]L@@0J7Aj101]OH830764R`@0MXbD101j
U9d407^GX@@0NiZU101kWZX407fS/0<0OjRf1020Zk/407n^_`@0W<?B102N`m0409Zmb@<0U[O2102C
/;X408nY/P@0Rj:Z1027W:<408BEV`<0P8nD101mR8d407V2Q@@0MG]n5P3oool001@0oooo101_L744
06e[J`@0JVIV0`1XHV0406IMF`@0I5QE101RE504061@B`@0Gda60`1MB44405e4?0@0G44h101L?S<4
05`k;`@0GS`a101P?c@306A5>`@0J4]2101[CD@406]@A`@0JU17101XCTL306M=A`@0ITa6101TBdH4
06==B0@0Hdm<101TE58306AHE`@0HUMF101PE5@405iEE0@0G5AD101IDU<405QEE`<0FEUL101KH6<4
05iUJ@@0Hfib101XMW/406inQ0<0LXB<101eS9<407RBV`@0NIFO101jVJ<407^MZ@@0OJ:_0`1oYkD4
082[^P@0OZbm102H`<l40:;7e@@0WL7=0`2I^/D409Fb_@@0T:^d102<Y:`408VMY@@0QIJM0`21T9D4
07f9S@@0NH:6101fO7hF0?ooo`00503oool406m`L@@0KF][101ZIVH306QRH0@0IUeK101TF5D4069D
D0@0H51;101OC4H305e8@@@0GD@l101L@CP405`n<`@0G3/_101N?344060o=0<0I4Dk101XBd8406]=
A0@0Je17101ZD4L406Q>A`<0Ide7101VC4H406A;AP@0Hde8101SCd`406ADDP<0I5QG101REeH4061D
E0@0GUED101LE5@405UBD`@0F5EG0`1IFE`405]PH`@0GVEY101SKW8406QfN`@0KWj40`1bQ8`407F<
T`@0N9:K101iUIl407ZIX`@0NifY101mXZl307nW]@@0P:^j101n[;d409S0c`@0X/OE102M`Ld309Vj
a@@0UK:m102@Zk@408bT[0@0RIfU1025UYd3086@U@@0OHV=101iPXH407IlOQH0oooo000D0?ooo`@0
Kg1a101]Jf/406YVIP<0J69P101VGE/406AHE@@0HUA@101PD4/405m<AP<0GDQ1101MA3`405a1>0@0
G3hc101L>bl405hl<@@0H3ld0`1TAC/406Q;@P@0Jde4101[D4L406Y@A`@0J4i70`1WCDL406I<AP@0
I4]6101SCDP406=?C0@0I5AB0`1TF5L4069GEP@0H5AD101NEE@405aDE0@0FE9C101HEEL305UIG0@0
Ff1S101NIFT406=^LP@0J7Ik101^OX@307:4S0@0MHbC101hTY/407VEW`@0NYVS101kWJT407fR[`<0
OjNe1020ZkX407j/_@@0V<3?102RamD409g1c@<0VK[5102E/[d4092[]0@0S:B/1029WJD408FFW@<0
PI2E101mRHd407V2QP@0MWan5P3oool001@0oooo101_L74406e[J`@0JVIV0`1XHV0406IMF`@0I5QE
101RE504061@B`@0Gda60`1MB44405e4?0@0G44h101L?S<405`k;`@0GS`a101P?c@306A5>`@0J4]2
101[CD@406]@A`@0JU17101XCTL306M=A`@0ITa6101TBdH406==B0@0Hdm<101TE58306AHE`@0HUMF
101PE5@405iEE0@0G5AD101IDU<405QEE`<0FEUL101KH6<405iUJ@@0Hfib101XMW/406inQ0<0LXB<
101eS9<407RBV`@0NIFO101jVJ<407^MZ@@0OJ:_0`1oYkD4082[^P@0OZbm102H`<l40:;7e@@0WL7=
0`2I^/D409Fb_@@0T:^d102<Y:`408VMY@@0QIJM0`21T9D407f9S@@0NH:6101fO7hF0?ooo`00503o
ool406m`L@@0K6][101ZIFD306MPG`@0I5aI101REe<4061BCP@0GTi8101MBD<305a5?P@0Fd8i101K
?SD405/k<@@0G3T]101N?C440610=@<0ITTo101ZCD@406]?AP@0Je58101ZD4P406U?B0<0Idi7101V
CDL406E=A`@0I4i8101RCd/406ACD@<0I5QF101REeH4061EE0@0GEAD101KDe<405QBD`@0EeAF0`1I
FU`405]PH`@0GfIZ101TKW<406UfO0@0Kgn50`1cQHd407F;T`@0MXnH101gTid407VGXP@0NibX101m
XJh3082W]0@0PZ^j1022[[d4096kbP@0WlOE102Ram<309^mb0@0U[Fo102B[KL408jV[P@0RYnV1026
V9h308:AUP@0OXZ>101jPhH407IlOQH0oooo000D0?ooo`@0Kg1a101/Jf/406YUI@<0If1O101TG5T4
069GD`@0H59>101NCTP405e9@`<0G4Dn101K@ST405/n=@@0Fc/a101L>Bd405hm<@@0H40e0`1VBCl4
06Y=A0@0Jdm6101[DDP406Y@B0@0JDm80`1WCTL406I=A`@0IDe7101TCTP4069?B`@0I5=A0`1TF5H4
069GEP@0H5ED101ME5@405]CD`@0F59C101GE5H305UJG0@0Ff1S101OIVX406A^L`@0JGIl101_OhD3
07>5S@@0MH^C101fSiP407NCW@@0NINR101kW:P407fQ[P<0P:Nd1022ZkX408:^_@@0TK_:102OamD4
0:;7d`<0Vkg8102F]Kl409:]]`@0SZJ^102:WjH408JHWP<0PY6F101nRXh407Z3QP@0MWan5P3oool0
01@0oooo101_L74406a[J`@0JVEU0`1WH5l406ALF@@0HUMC101PDTh405i>B0@0GDU30`1LACh405]2
>@@0Fche101K>c4405`i;@@0GSda101P@3D306I9?`@0JTe4101[CdH406]AB0@0JU18101YCdP306M>
A`@0ITe7101UCDL406A>B0@0HTm;101TDe4306AHEP@0HUMF101PEE@405eDE0@0Fe=C101HDU<405MD
EP<0FEYL101KH6<405mVJP@0I6ic101YMW`406moQ@<0LhF=101eRi<407J?V0@0Mi>M101iUj8407^L
Z0@0OJ6^0`20Yk@408:[^P@0PZjm102A^lX409o7e@@0X/OC0`2K_LP409Je_`@0TZfg102>YZh408ZO
YP@0QYRN0`22TIH407j:SP@0NX>6101fO7hF0?ooo`00503oool406m_L0@0K6YZ101YI6@306IOG@@0
HeYG101QEE4405i@B`@0GD]6101KAd0305Y3>`@0FClf101I>c4405Xh;@@0FcP/101N?C440695>@<0
JDi4101/D4H406aAB0@0Je59101ZDDT406U@B@<0Idm8101VCTP406E>B0@0I4m9101SD4`406ADD@<0
I5ME101REUD405mDE0@0GEAD101JDU<405MBD`@0EUAF0`1HFUd405]PI0@0H6M[101TKg@406YgO@@0
Kh260`1cQHd407B:TP@0MHfF101fTI`407VFX@@0Ni^W101nXJh308:W]0@0QJfk1028/Kl4092jb@@0
VlGD102Ram@309bnbP@0UkK1102C[kT408nX/0@0Rj2X1027VJ0308>BU`@0Oh^?101jPhL407IlOaH0
oooo000D0?ooo`@0Kfm`101/JVX406UTI0<0IUmM101SFUL4065ED@@0GU1;101MBdH405]7@0<0FT<k
101I?cH405Tk<@@0FSP]101K>2`405hm<@@0HTDi0`1YCT@406a@AP@0K558101[DDT406YAB@@0JE19
0`1WCdP406I>B0@0IDi8101TCdT406=@C0@0I5AA0`1TEeD4069FE@@0GeAD101ME5@405YBD`@0Ee9C
101FE5H305QJG@@0Ff1T101PIf/406A_M0@0JWMm101_P8H307>5S@@0M8ZB101eSIH407JAW0@0NIJQ
101kVjL407jQ[P<0PZNd1025[K/408Ra_`@0T;[9102KaM@40:;7e0<0W;k:102G]/4409>_^@@0SjR`
102;X:P408NIX0<0Pi:G101oRhl407Z3Q`@0MWao5P3oool001@0oooo101_Kg0406aZJP@0JFAT0`1V
Ged406=JE`@0HEEA101ND4/405e;AP@0FdM00`1J@c/405To=P@0FC/a101J>2d405/h;0@0GSda101R
ACT306U>A0@0K516101/DDP406]AB@@0JU59101YD4T306M?B0@0ITi8101UCTP406A?B@@0He1<101T
E54306AGE@@0HUIE101OE5@405eDE0@0FU9C101GDU<405IDEP<0F5YM101KH6@4061WJ`@0I6md101Z
Mgd406n0QP<0LhF=101dRY8407F=UP@0MY6L101iUZ4407^KY`@0OZ6^0`22Yk@408F]^`@0R;6o102@
^/T409_5e0@0X/OD0`2L_/X409Nf`@@0Tjni102?Z;0408^PZ0@0QiVP0`23TYL407n;S`@0NX>7101f
O7lF0?ooo`00503oool406m_L0@0K6YZ101YI6@306IOG@@0HeYG101QEE4405i@B`@0GD]6101KAd03
05Y3>`@0FClf101I>c4405Xh;@@0FcP/101N?C440695>@<0JDi4101/D4H406aAB0@0Je59101ZDDT4
06U@B@<0Idm8101VCTP406E>B0@0I4m9101SD4`406ADD@<0I5ME101REUD405mDE0@0GEAD101JDU<4
05MBD`@0EUAF0`1HFUd405]PI0@0H6M[101TKg@406YgO@@0Kh260`1cQHd407B:TP@0MHfF101fTI`4
07VFX@@0Ni^W101nXJh308:W]0@0QJfk1028/Kl4092jb@@0VlGD102Ram@309bnbP@0UkK1102C[kT4
08nX/0@0Rj2X1027VJ0308>BU`@0Oh^?101jPhL407IlOaH0oooo000D0?ooo`@0KVm`101[JFT406QS
H`<0I5iL101QF5D405mCC`@0G4i9101JBD<405U4?@<0F40h101G>c8405Lh;P@0F3DY101J=b/405hn
<`@0IDXo0`1/DDL406iBB0@0KE99101/DTT406YAB@@0JE190`1XCdP406I?B0@0IDm9101TD4X406EB
CP@0I5EB0`1TEeD4069FE@@0GeAD101ME5@405YADP@0EU9C101FE5H305QJG@@0Ff5T101PJF`406E`
M@@0JgQo101_P8H307:5S0@0M8VA101dS9D407J@VP@0NIFP101lVjL407nQ[@<0PjNd1028[[`408bb
`@@0Tkc;102LamH409g4dP<0Vko;102H^<<409Ba^P@0T:Vb102<XZT408RJX@<0Q9>H101oRi0407^4
Q`@0MWao5P3oool001@0oooo101^Kg0406]YJ@@0J6=S0`1TGU`4065HE@@0Ge=?101LCTT405Y9@`@0
FD@m0`1H@3P405Lk<P@0EcP^101H=BT405Xg:`@0GShc101UBSl306aAA`@0KU98101]DTT406aBB@@0
JU59101YD4T306Q?B0@0ITm8101UCdT406A@BP@0IE9>101TEE8306AGE@@0HUIE101OE5@405eDE0@0
FU5B101FDU<405IDEP<0F5YM101KHF@4061YK0@0IG1e101[N7l406n0QP<0LXF<101dRI4407B<U@@0
MY2J101iUJ0407bKY`@0Oj6]0`23Yk@408R^_0@0S;;1102C_</409c7eP@0WLCB0`2K_l/409Rh``@0
U;6j102@ZK8408bRZ@@0R9ZQ0`24TiP407n;T0@0NhB7101fO7lF0?ooo`00503oool406i_L0@0JfUY
101XHf<306ANG0@0HEQE101ODdl405a>B@@0FTU3101IA3d305Q0>0@0Ec/b101G>2h405Pe:@@0FSL[
101N?S<406E:?`<0K557101^DTP406eBB@@0K599101ZDDT406U@B@<0J4m8101VCdP406E?B@@0I51:
101UDTh406AEDP<0I5ME101REUD405mDE0@0GEAD101JDE8405IBD`@0EUAF0`1HFUd405]QI0@0H6U/
101UL7D406]hO`@0Kh260`1bQH`407B9T@@0M8bE101fT9X407VEX0@0O9^W101oXJd308>W]0@0R:jl
102<//4409>lb`@0W<OF102Ma=8309^ob`@0V;S3102D/KX4092Y/P@0S::Y1028VZ4308BCV0@0Oh^@
101kQ8L407IlOaH0oooo000D0?ooo`@0KVm`101[JFT406QSH`<0I5iL101QF5D405mCC`@0G4i9101J
BD<405U4?@<0F40h101G>c8405Lh;P@0F3DY101J=b/405hn<`@0IDXo0`1/DDL406iBB0@0KE99101/
DTT406YAB@@0JE190`1XCdP406I?B0@0IDm9101TD4X406EBCP@0I5EB0`1TEeD4069FE@@0GeAD101M
E5@405YADP@0EU9C101FE5H305QJG@@0Ff5T101PJF`406E`M@@0JgQo101_P8H307:5S0@0M8VA101d
S9D407J@VP@0NIFP101lVjL407nQ[@<0PjNd1028[[`408bb`@@0Tkc;102LamH409g4dP<0Vko;102H
^<<409Ba^P@0T:Vb102<XZT408RJX@<0Q9>H101oRi0407^4Q`@0MWao5P3oool001@0oooo101^Kfl4
06YXJ0@0IV9Q0`1SG5X4061FE0@0GE5=101JBdH405Q6@0@0ET4j0`1E?3@405@h;P@0E3@Y101F<bP4
05Tg;0@0H44f101YCT<306mDB@@0L5A;101^E4/406eBBP@0Je59101YD4T306M?B0@0Idm9101VCdX4
06EAC0@0IUA?101UEe<306EHEP@0HeMF101PEED405eDE0@0FE5B101EDE8405EDE`<0EeYM101KHFD4
061YKP@0IW5f101[NGl406moQP<0LHB;101bQi0407B;U0@0MHnJ101iU9l407bJYP@0P:6]0`24Z;@4
08Z__@@0S[?1102E_L`409c6eP@0W/KC0`2L`<d409Vja@@0U[:l102BZk@408jSZ`@0RIbR0`25U9T4
082<T@@0NhB8101gOGlF0?ooo`00503oool406i_K`@0JVQX101VHV4306=LFP@0H5ID101MDDd405Y;
AP@0F4I0101F@CX305Dl=0@0E3P^101D=2T405Hc:0@0FCL/101P@CH406U>@`<0KeA9101`E4/406iD
B`@0KE9:101[DDT406U@B@<0Idm8101WCdT406I?BP@0IE5<101VE4l406EGD`<0IEQF101SEeH4061E
E@@0GEAD101IDE8405EADP@0EEAG0`1GFUd405]QI@@0H6U^101VLGH406]iO`@0Kgn60`1aQ8/407:7
T0@0M8^D101eSiX407VDW`@0O9ZV1020XJd308BX]0@0RZnm102>/l4409Fmc0@0W<KF102Na]<309c0
c@@0VK[5102F/[`409:[]0@0SZ>[1029W:8308FDV@@0P8bA101kQ8P407MmOaH0oooo000D0?ooo`@0
KVm_101ZJ6P406IRH@<0HeaJ101PEU@405eAC@@0FT]6101HAT0405I1>P<0EC`d101D>2h405@d:@@0
ES<X101I=b`40611=P@0JDi30`1_E4T4071DB`@0KUA;101]DTX406]AB@@0JE190`1WCdP406M?B@@0
ITm:101UDD`406IDC`@0IEMC0`1UF5H406=GEP@0H5EE101ME5@405UADP@0EE5B101EE5L305MJG@@0
Ff5U101PJFh406IaMP@0JgUo101_OhH30764R`@0LXN@101dRi@407F?VP@0NIBO101lVZH4082Q[@<0
Q:Rd102:[kd408jc`@@0UKg<102La]H409k6d`<0W<3=102I^/D409Jb_0@0TZ^d102>Xj/408VLXP<0
QIBI1020S94407^4R0@0Mgeo5P3oool001@0oooo101^Kfl406YXJ0@0IV9Q0`1SG5X4061FE0@0GE5=
101JBdH405Q6@0@0ET4j0`1E?3@405@h;P@0E3@Y101F<bP405Tg;0@0H44f101YCT<306mDB@@0L5A;
101^E4/406eBBP@0Je59101YD4T306M?B0@0Idm9101VCdX406EAC0@0IUA?101UEe<306EHEP@0HeMF
101PEED405eDE0@0FE5B101EDE8405EDE`<0EeYM101KHFD4061YKP@0IW5f101[NGl406moQP<0LHB;
101bQi0407B;U0@0MHnJ101iU9l407bJYP@0P:6]0`24Z;@408Z__@@0S[?1102E_L`409c6eP@0W/KC
0`2L`<d409Vja@@0U[:l102BZk@408jSZ`@0RIbR0`25U9T4082<T@@0NhB8101gOGlF0?ooo`00503o
ool406i^K`@0JFQX101UHF03065KF@@0GUAB101JCTX405M8A0@0ED<m101C?CH3054h<0@0D3@Z101?
;b@4058a9`@0F3T^101TASX4071CA`<0LeM<101bETd4071EC0@0KU=:101[DDT406U@B@<0Idm8101V
CdT406I@B`@0IU=>101WEU4406MHE@<0IeYG101TFEL4065GEP@0GEAD101HDE8405EADP@0E5AG0`1G
FUd405]RIP@0H6Y_101VLGL406YhOP@0KGj50`1`PXX40767S`@0M8ZD101fSiT407VDW`@0O9ZV1020
X:d308FW]0@0Rjjl102?/l0409Jnc@@0W<GD102Qb]P309k3d0@0Vkc7102H];h409B]]@@0SjF]102;
WJ@308JEV`@0PHfB101lQHT407MmP1H0oooo000D0?ooo`@0KVi_101YJ6P406EQH0<0HE]I101NE584
05Y>BP@0EdQ4101E@cd405<m=P<0DCP`101@=2X404l_90@0DS4W101H>Bh406A6>P@0L5=70`1cEd`4
079FC@@0L5E<101^DdX406]AB@@0JE190`1WCdP406I?B@@0IU1;101VDdh406MFD@@0IeQE0`1WFUL4
06AIE`@0HEMF101ME5@405QADP@0EE5B101DE5L305MJG@@0Ff9V101PJVl406IaM`@0JWQn101]OXD3
0722RP@0LHN?101dRY@407J?V@@0NIBO101lVZH4082P[@<0QJNd102;[[`408nc`0@0U[k=102LaM@4
0:7:f0<0W/?@102K_<L409Rd_P@0U:fe102?YJd408^MY0<0QYFK1021SI8407b5R@@0Mgf05P3oool0
01@0oooo101^KVl406UXJ0@0IF5P0`1QFeT405iDDP@0FTi:101GB4@405E3?@@0Dcdf0`1A>304050d
:P@0CblT101B<BL405Pi;P@0I4Hj101`DdL307=GC0@0LUI=101`ED`406iCBP@0Je59101YD4T306M?
B0@0ITm9101VD4/406ICCP@0IeIA101WF5D306MJE`@0I5UG101QEeH405eDE0@0F55B101EDE8405AD
E`<0EeYM101KHVH4061ZK`@0IW5g101ZN7h406enQ@<0L8::101aQhl407B:U0@0MXnI101iU9l407bJ
YP@0P:2]0`25Yk@408^^_0@0Sk?0102F_/d409c5e0@0XL[H0`2N`m0409^la`@0V;Bn102D[KD408nU
[@@0RifT0`26UI/4086=TP@0O8F9101gOH0F0?ooo`00503oool406i^K`@0JFQX101UHF03065KF@@0
GUAB101JCTX405M8A0@0ED<m101C?CH3054h<0@0D3@Z101?;b@4058a9`@0F3T^101TASX4071CA`<0
LeM<101bETd4071EC0@0KU=:101[DDT406U@B@<0Idm8101VCdT406I@B`@0IU=>101WEU4406MHE@<0
IeYG101TFEL4065GEP@0GEAD101HDE8405EADP@0E5AG0`1GFUd405]RIP@0H6Y_101VLGL406YhOP@0
KGj50`1`PXX40767S`@0M8ZD101fSiT407VDW`@0O9ZV1020X:d308FW]0@0Rjjl102?/l0409Jnc@@0
W<GD102Qb]P309k3d0@0Vkc7102H];h409B]]@@0SjF]102;WJ@308JEV`@0PHfB101lQHT407MmP1H0
oooo000D0?ooo`@0KFi_101XIfL406APG`<0GeUG101KDTl405M;B0@0E4E1101A?cX404lj<`<0CC@/
101<;bH404XZ7P@0BbhT101H>c4406Q:?P@0N5U<0`1hFdl407EICP@0LUM=101_E4/406]BBP@0J519
0`1VCdP406I?B@@0IU1;101WDdh406UHD`@0JU]G0`1YG5T406IKFP@0HUQH101MEED405QADP@0E55B
101CE5L305IJG@@0FV5V101PJVl406AaM`@0JGIm101/OH@306n1RP@0LHJ?101dRi@407J?V@@0NIBO
101mVZH4086P[0<0QZNd102;[[X4092b_`@0V;k=102OaM@40:C>g0<0XLKC102N_/X409Zg`0@0UZng
102AYjh408bNY@<0QiJL1022SY8407f6R@@0Mgf05P3oool001@0oooo101]KVl406QWI`@0I61O0`1O
FEL405]BC`@0Ed]8101DAD44054o>P@0CcXc0`1==2`404`_9P@0BRXN101;;R@405Pk<@@0J4Xn101h
FD`307QKC`@0MEU>101bEdd406mDB`@0Je9:101XD4T306I?B0@0ITm9101VD4/406MCCP@0JEQC101Z
FeL306ULF@@0IU]J101RF5P405eEE@@0F55B101DDE8405=DE`<0EUYM101JHFH4061ZK`@0I75g101Y
MWd406amQ0<0Kh6:101aQXl407B;U0@0MXnI101iU9l407fJYP@0PJ2/0`26Yk@408^^^P@0T;:o102H
_/d409o5e0@0Y<kL0`2Qa]<409jnbP@0V[O0102F[kL4096W[P@0S9jU0`27UY`408:>TP@0OHJ9101g
OH0F0?ooo`00503oool406e^K`@0J6MW101TH5l305mIE`@0Fe9?101GBdP405A5@@@0DClj101?>S<3
04dd;0@0C2lV101::Qh404/^90@0F3/a101XBSh407QIC0<0N5]?101eFDh4079GC@@0KeA;101[DTX4
06Q@B@<0ITm8101VCdT406I@B`@0Ie=>101YF5<406YKE`<0JEaI101VFeX4069HF0@0GEEE101HDE84
05AADP@0DeAG0`1FFUd405YQIP@0H6Y_101TLGL406UfO@@0K7f40`1_PHX40766S`@0M8^D101fSiT4
07VDW`@0OIZV1021X:`308JW]0@0Rjjj102@/[l409Rnc@@0WlGD102Tc]`30:76d`@0W[k:102J]l04
09J_]`@0TJN^102<WZD308NFW0@0PXjB101mQXT407MmP1H0oooo000D0?ooo`@0KFi_101XIfL406AP
G`<0GeUG101KDTl405M;B0@0E4E1101A?cX404lj<`<0CC@/101<;bH404XZ7P@0BbhT101H>c4406Q:
?P@0N5U<0`1hFdl407EICP@0LUM=101_E4/406]BBP@0J5190`1VCdP406I?B@@0IU1;101WDdh406UH
D`@0JU]G0`1YG5T406IKFP@0HUQH101MEED405QADP@0E55B101CE5L305IJG@@0FV5V101PJVl406Aa
M`@0JGIm101/OH@306n1RP@0LHJ?101dRi@407J?V@@0NIBO101mVZH4086P[0<0QZNd102;[[X4092b
_`@0V;k=102OaM@40:C>g0<0XLKC102N_/X409Zg`0@0UZng102AYjh408bNY@<0QiJL1022SY8407f6
R@@0Mgf05P3oool001@0oooo101]KFh406MVIP@0HUiM0`1MEeD405Q?C@@0E4Q5101@@Sd404dk=P@0
BSH_0`19<2P404L[8P@0ARLM1017;B<405Ll<P@0JTe1101oGU0307eNDP@0NE]@101eFDh4071EC0@0
Je59101WCdP306A=A`@0I4i9101VD4/406UDC`@0JeYD101/GET306]OG0@0JEiM101TFeX405iFEP@0
F59C101CD584059CEP<0EEYM101HHFH405iYKP@0HW1f101VMG`406]kP`<0KX69101`QHh407B;U0@0
MhnJ101jU9l407fJYP@0PIn/0`26Y[<408^/^@@0Sk6o102J_L/40:?9e`@0Z=7P0`2TbMH40:71c0@0
W;W3102H/KT409>X/0@0SZ2V0`29Uid408>?T`@0OHJ:101hOX0F0?ooo`00503oool406e]KP@0IfIV
101RGUd305eGE@@0F4m=101DB4D40512?@@0CC/f101:=Rl304T`:0@0Ab/R10169ad404L]8`@0Ec`b
101ZCD4407mND0<0OEiB101iFe0407EICP@0L5E<101[DDT406M?B0<0I4e7101TCTT406I@B`@0JEA?
101[FU@406aMF@<0JemL101YGUd406AKFP@0GUIF101HDU<405=@DP@0DU=F0`1EFUd405QQIP@0GVU^
101RL7H406IeO0@0Jg^30`1^PHT40725SP@0M8^D101gSiX407ZDW`@0OIZV1021Wj`308JV/`@0Rjbi
102?/Kl409Zmb`@0XlWG102XdN030:C9eP@0XL7<102L^L<409Ra^@@0TjR`102>X:H308VGW@@0PhnC
101mQXX407QnP1H0oooo000D0?ooo`@0KFe^101WIVH4069NG@<0GEME101HCdd405A8A@@0D48m101=
>cH404Xf;`<0BC0X1017:b8404HW7@@0AbdS101G?38406Y=@@@0Oei@0`1mGU8407UKD0@0MEU>101`
ED`406]AB@@0Idm80`1TCDL406A>B@@0IU1;101YE4l406]JE0@0K5eI0`1[Ge`406UNG@@0I5]J101N
EUH405QBD`@0De1B101BDeH305EJG@@0F65V101NJFh4069`MP@0IWEl101[Nh<306j1R@@0L8F>101d
Ri@407N?VP@0NYBO101mVZH4086O[0<0QZJc102;[;T408na_`@0V[g;102SbML40:SAh0<0Y<WF102Q
`L`409bi``@0V;6i102CZ;0408jPYP<0RINM1023Si<407f6RP@0N7j05P3oool001@0oooo101/KFh4
06IUI@@0H5eL0`1KEE<405E=BP@0D4E2101;?SX404Pg<P@0AC4[0`14;2@404<X7P@0@bLN1013:b<4
05Ln=0@0Ke551026He@3089RE0@0OEiB101hFe44079FC@@0Je5:101VCTL3069<A`@0HDe8101TD4/4
06]FD0@0L5aG101_GUX306iQGP@0KFAR101VGUd405iHF0@0Ee9C101BD584055CE@<0DeQL101FGfD4
05aXKP@0Gfid101SLg/406QiP@<0KH28101`QHh407J<U@@0N92J101jU9l407fIY@@0PIn/0`26YK<4
08^[^0@0Sk2n102L_//40:S<f@@0[=GS0`2Xc=P40:C4c`@0Wk_5102K/k/409FZ/@@0T:6X0`2:VIh4
08B@U0@0OXN:101hOX0F0?ooo`00503oool406a]KP@0IVEU101PGE`305]ED`@0EDe:101@AD8404/n
>P@0B3Lb1015<B/304@/90@0@bPN10139ah404<[8`@0Echd101_DDD408ISE0<0PV9D101mGU8407QK
D@@0LUI=101[DDX406I>A`<0HTa7101QCDP406A@B`@0JeI@101`G5L406mNFP<0KV5N101]I68406IN
G@@0GUQH101GDU<4059@DP@0DE=E0`1CF5`405IOI@@0G6Q^101OKW@406=cN`@0J7V10`1]P8P40725
SP@0MXbE101hT9X407ZDW`@0OIVU1021Wj`308JU/`@0Rj^h102?/;h409bnb`@0Z<cI102/eN<30:S<
f0@0Y<C?102O^lD409^c^`@0UJZa102@XJP308ZIWP@0Q92D101nQhX407QnP1H0oooo000D0?ooo`@0
K6e^101VIFD4061MG0<0FeEC101ECDX40515@P@0Bchj1018=c8404Da:`<0A2`T1013:1h404<W7P@0
@b/S101G?S@406mAA@@0QV=D0`22HU@407eNDP@0N5]A101bETd406]ABP@0ITi70`1RC4L4065=B0@0
I51;101[EU04071LE`@0KeiJ0`1^HEh406eTHP@0IUiM101NF5P405MBD`@0DU1B101ADeD305=HG0@0
EUmU101LJ6h405m^M0@0Hg=k101XNH4306f0R0@0L8F>101fS9D407R@VP@0NYBO101mVJD4086O[0<0
QZFc102;ZkP408n`_P@0W;k;102Xc=T40:cEh`<0Z<cH102Ta<l409nka@@0Vk>k102EZ[44092QZ0<0
RYVN1024T9@407j7RP@0N7j05P3oool001@0oooo101/KFh406IUI@@0H5eL0`1KEE<405E=BP@0D4E2
101;?SX404Pg<P@0AC4[0`14;2@404<X7P@0@bLN1013:b<405Ln=0@0Ke551026He@3089RE0@0OEiB
101hFe44079FC@@0Je5:101VCTL3069<A`@0HDe8101TD4/406]FD0@0L5aG101_GUX306iQGP@0KFAR
101VGUd405iHF0@0Ee9C101BD584055CE@<0DeQL101FGfD405aXKP@0Gfid101SLg/406QiP@<0KH28
101`QHh407J<U@@0N92J101jU9l407fIY@@0PIn/0`26YK<408^[^0@0Sk2n102L_//40:S<f@@0[=GS
0`2Xc=P40:C4c`@0Wk_5102K/k/409FZ/@@0T:6X0`2:VIh408B@U0@0OXN:101hOX0F0?ooo`00503o
ool406]/K@@0IFAT101NFeX305QCD@@0DTY8101<@Ch404Hi=@@0@C8]100n:bD303hW80@0@2DL1011
:204044]9@@0FD0f101dE4P408aXF0<0QVEG1020H5D407]MDP@0M5Q?101]Dd`406I>B0<0Hde8101M
BdL4069?B`@0K5MA101aGUT407=PF`<0LVAQ101_IV@406MPG`@0GeUI101GDU<4055?D@@0Ce5D0`1@
Ee/4059KHP@0FfQ^101LJg8405m`N@@0IGMo0`1]P8P40766SP@0MhbE101iTI/407^EX0@0O9VU1021
Wj`308JU/P@0RJZh102@/Kl40:30c@@0[LkK102af>D30:c?fP@0Z<KA102S_/L409je_@@0V:bc102B
XjT308bJW`@0QI6E101oQh/407QnPAH0oooo000D0?ooo`@0Jfa]101UI6@405iKFP<0F5=A101BBTP4
04a1?P@0ASTe1011<Rd403h[9@<0?RLP10109A`4044X80@0@BdU101I@3H407ADB0@0S6QH0`26IEL4
081PE@@0NeeB101dF4l406eCC0@0ITi80`1SCDP405e;A`@0HTm;101/Ee44075NF@@0Lf1K0`1bI644
06mVI0@0If1O101OFET405MBD`@0DDmA101?DE@3051GF`@0DU]R101KJ6h405a[LP@0Gg1i101UMgl3
06f0R0@0LHJ>101gS9D407VAV`@0NiFP101lVJD4086O[0<0QZFb1029Z[P4092a_`@0X<3=102]c]/4
0;7Hi@<0[<oJ102Xa]440:>na`@0W[Fm102H[;<409:SZ@<0S9ZO1025TID407n7R`@0N7j15P3oool0
01@0oooo101[K6d406ETI0@0GU]J0`1HDe44059:B0@0C44n1016>CD4044b;@@0?R/U0`0n9b04040U
70@0@BPP1011;BD405U0=P@0M5A8102<J5P308IUE`@0P61E101kGE8407AHC`@0KE=<101VCTP306==
B0@0GD]7101RCd/406aGD@@0LEiI101cH5/3079TH@@0KfIT101WH5l405mIF@@0Ee9C101ACe4404mA
E0<0D5MK101BFf8405]XKP@0G6]b101OL7T406EgO`<0KH28101aQXh407N<U@@0NI6K101kUJ0407bI
Y@@0PIn/0`26YK8408VZ^0@0T;6o102P`<d40:g>f`@0/MSU0`2/cmX40:S6d@@0Xkk7102N]Kd409R/
/`@0TZ>Y0`2<VYl408FAU@@0OhN;101hOX4F0?ooo`00503oool406]/K@@0IFAT101NFeX305QCD@@0
DTY8101<@Ch404Hi=@@0@C8]100n:bD303hW80@0@2DL1011:204044]9@@0FD0f101dE4P408aXF0<0
QVEG1020H5D407]MDP@0M5Q?101]Dd`406I>B0<0Hde8101MBdL4069?B`@0K5MA101aGUT407=PF`<0
LVAQ101_IV@406MPG`@0GeUI101GDU<4055?D@@0Ce5D0`1@Ee/4059KHP@0FfQ^101LJg8405m`N@@0
IGMo0`1]P8P40766SP@0MhbE101iTI/407^EX0@0O9VU1021Wj`308JU/P@0RJZh102@/Kl40:30c@@0
[LkK102af>D30:c?fP@0Z<KA102S_/L409je_@@0V:bc102BXjT308bJW`@0QI6E101oQh/407QnPAH0
oooo000D0?ooo`@0Jfa]101SHf<405aIF@<0EE1?101>AdD404Lm>`@0@3@a100j:bL403DT7P<0=1hH
10119al404</90@0AS4Y101J@ST407MGBP@0TFaL0`2:J5X408ASE`@0OEmD101gFe84075GC`@0JU9;
0`1VD4X4061=B0@0I55<101ZEe44071NF@@0M69M0`1cIF4406iUHP@0If1O101NFET405MBD`@0D4mA
101=D5<304iEFP@0CeYP101FIF`405IWK`@0F6ae101UMgl306b0R0@0L8F=101hSIH407^AV`@0OIJQ
101mVZH4082NZ`<0Q:>a1027Z;H4092a_`@0Y<;?102cd]h40;KJiP<0/=7M102/bM<40:O0b@@0XKNo
102K[[D409BUZ`<0SY^P1027TYH40828R`@0NGn15P3oool001@0oooo101[K6d406=SH`@0G5UI0`1E
D4l404i7A@@0Acdk1010=34403X[9`@0=B@N0`0d7QP4044W7`@0@b`T1016<BT405Y2>@@0MeM:102A
K5`308YXFP@0Q6=G101mGe@407MKDP@0LEM?101ZDT/306I@BP@0H4e8101TDD`406YGD@@0L5iI101d
HUd307=UH@@0KVER101WH5l405iIF@@0Ee9C101@Ce4404e@D`<0CUEJ101?FV0405IUK0@0EVM_101H
K7D406EgO`<0K828101`QHd407R=UP@0Ni6K101mUZ4407fJYP@0P9j[0`24Xk4408NX]P@0T;6o102T
`/l40;?BgP@0]][V0`2`dMd40:c9d`@0Yl39102Q]kl409^^]@@0U:F[0`2>Vj0408NBUP@0P8R;101i
Oh4F0?ooo`00503oool406]/K@@0Hf=S101LFET305E@C`@0CTM51017?C/4040d<@@0>R/W100e91h3
03@N60@0@BLO1013;2@404Ha:@@0FT8i101gEdX4095/G0<0RVQJ1024HeL407eOE0@0Me]B101aEdl4
06YBB`<0IU1:101PCDP406AAC0@0JUMA101`GUT407ARG@<0LfEQ101^IF8406MPG`@0GUUI101GDU<4
051?D@@0CE1C0`1>EEX404mJH0@0EVE/101FIfl405Q/M@@0IGMo0`1/P8P40725S@@0N8fF101kTI/4
07fFX@@0OIZV1020WZ/308BS/@@0QjRf102@/Kl40:C2c`@0/m;N102ff^H30;3Ag@@0[<WC102W`<T4
0:6g_`@0Vjje102DYJ/308jKX0@0Qi:F1020R8/407UoPAH0oooo000D0?ooo`@0Jfa]101SHf<405aI
F@<0EE1?101>AdD404Lm>`@0@3@a100j:bL403DT7P<0=1hH10119al404</90@0AS4Y101J@ST407MG
BP@0TFaL0`2:J5X408ASE`@0OEmD101gFe84075GC`@0JU9;0`1VD4X4061=B0@0I55<101ZEe44071N
F@@0M69M0`1cIF4406iUHP@0If1O101NFET405MBD`@0D4mA101=D5<304iEFP@0CeYP101FIF`405IW
K`@0F6ae101UMgl306b0R0@0L8F=101hSIH407^AV`@0OIJQ101mVZH4082NZ`<0Q:>a1027Z;H4092a
_`@0Y<;?102cd]h40;KJiP<0/=7M102/bM<40:O0b@@0XKNo102K[[D409BUZ`<0SY^P1027TYH40828
R`@0NGn15P3oool001@0oooo101ZJf`4069RHP@0FUQG0`1BCTd404Y4@P@0@STg100i;b`4034T80@0
9aPD0`0/6A<403hX80@0AS4X101;=bl40658?@@0O5]=102EKel308iZG0@0QfIJ101oH5D407UNE0@0
M5]C101^ETl306UBC0@0IU5<101WDdh406]HDP@0KeeH101bHUh3075TH@@0K6=Q101VGel405iHF@@0
EU9C101@Ce4404e@D`<0CEEJ101?FV44059RJP@0DVA]101BIg4406AfOP<0JGj6101^Ph`407V=U@@0
Ni:K101mUZ4407bIYP@0OYf[0`21XJl408>U]@@0T[;0102Wa=040;WEh0@0^mgY0`2feMl40;7<eP@0
Zl?<102U^/4409j`]`@0UjN/0`2@WJ4408RCU`@0PHV<101iOh4F0?ooo`00503oool406Y[K0@0HV9R
101JF5L3059>C@@0BTA21012>CL403T_;0@0<B@P100W61@302`I4`@0?RPP1016<BP404/g;`@0HDPm
101lFdd409E_G`<0SVYL1027IUX407mPE@@0NEiD101dFe<406iFC`<0JE9<101VDD`406MCCP@0JeQB
101_GEP4079RGP<0LFAQ101/Hf4406IOG`@0GUQI101FDU<4051?D@@0CE1C0`1=EEX404mJH@@0DV9Z
101BI6d4059WL@@0I7In0`1YOXH406j3S0@0NHfE101kTY/407fFX@@0O9VV101nWJ/3086Q[`@0PjFe
102B//040:O4d0@0^MGP102kgNT30;KEg`@0/LcF102[`l`40:Fj`@@0W[2g102GYj`3092MX@@0R9>G
1021RH`407UoPAH0oooo000D0?ooo`@0JV]/101RHV8405YHE`<0DTi=101:A484048i=`@0>Bl/100a
920402LH50<0;1TC100n:20404Ha:0@0BcL_101QB3d407aKC@@0UFmO0`2>JU`408MVFP@0Of1E101i
GU@407AKD`@0KUI?0`1YDT`406IAC0@0Ie=>101[F58406mMF0@0LV9N0`1aI64406aSH@@0IUmO101N
F5T405IBD`@0D4mA101=D5<304eEFP@0CeYQ101BHVX4059TK@@0DVMa101TMWh306UnQP@0KX><101i
SID407^BV`@0OIJQ101lVJH407jMZ`<0PJ6_1023YKD409:b`0@0YlC@102ieN040;_Mj@<0]]GO102a
c=H40:_3c0@0YK[1102N/;L409NW[0<0T9fQ1028TiL40869S0@0NGn15P3oool001@0oooo101ZJf`4
069RHP@0FUQG0`1BCTd404Y4@P@0@STg100i;b`4034T80@09aPD0`0/6A<403hX80@0AS4X101;=bl4
0658?@@0O5]=102EKel308iZG0@0QfIJ101oH5D407UNE0@0M5]C101^ETl306UBC0@0IU5<101WDdh4
06]HDP@0KeeH101bHUh3075TH@@0K6=Q101VGel405iHF@@0EU9C101@Ce4404e@D`<0CEEJ101?FV44
059RJP@0DVA]101BIg4406AfOP<0JGj6101^Ph`407V=U@@0Ni:K101mUZ4407bIYP@0OYf[0`21XJl4
08>U]@@0T[;0102Wa=040;WEh0@0^mgY0`2feMl40;7<eP@0Zl?<102U^/4409j`]`@0UjN/0`2@WJ44
08RCU`@0PHV<101iOh4F0?ooo`00503oool406U[K0@0HF5Q101HEUH304m<B`@0AT4o100m=S@403<Z
9`@0:1dJ100K3PX302TI50@0=b@N1016<RX4054l<`@0JDe11021Ge4409QaH@<0TVeO102:JEd4089S
F@@0Nf1F101fG5@4075JDP<0K5I@101ZE4l406YFD0@0KEYD101`GUP4075RG@<0LFAQ101[HV0406EN
G@@0GEQH101FDU<404m@DP@0C51C0`1<E5T404mJH@@0DV5Y101BI6d405=XLP@0Gg9k0`1VNX<406b2
R`@0MX^D101hT9X407VDX0@0NYNT101jVjT307fO[@@0Oj>b102D]<440:_6d@@0_MKP1031h^d30;cI
h`@0]]3I102`alh40:Vma0@0X[>i102JZJh309:NX`@0RYBH1022RXd407YoPQH0oooo000D0?ooo`@0
JF]/101QHF4405QFEP<0Cda;1016@Cl403df=0@0<bXW100X7AX401/>2P<0:ATD100g91h404Hb:P@0
DC`c101YCD44085OD@@0V75Q0`2BKEl408YYG@@0PV=I101kH5H407ILE0@0LEYB0`1/EU0406YDC`@0
JUI@101]FU@4071NF0@0LF9M0`1aI64406]RH0@0IEiM101MF5P405IBD`@0Ce1B101<D5<304aDF@@0
CeYQ101BHFT4059TK@@0DfQb101OLW/306IjP`@0K8:;101fRi@407R@VP@0NIBP101jUj@407ZKZ@<0
OIn]101oXk8409Bd`@@0ZlKA102me^040<7Rk@<0_=WS102fd=T40;37cP@0ZKg4102R/kT409ZY[P<0
TYjS102:U9P408::S@@0NWn25P3oool001@0oooo101YJf`4065QH@@0F5IF0`1?C4/404I1?`@0?CHd
100c:RL402PM6P@06`h:0`0Y6A@403LT7P@0AS8Z101A?3<406U=@@@0PEmA102HLF43099]G`@0RVUM
1022HeT407]PEP@0MUaD101aFU8306aFD0@0JUA?101ZEU0406eJE0@0L5iH101aHUd3075TH@@0Jf9P
101UGUd405eHF0@0EU9C101?D58404a@D`<0C5AI101?FV44059QJ@@0DVA]101CJ78405mbN`<0IWZ3
101/PX/407J;U0@0N92J101iU:0407ZGY0@0NY^Y0`1mWjd407nS/P@0U;C1102[a]440;gFh0@0`N;]
0`2lfN<40;K@f@@0/<O>102Y_L@40::c^@@0VZV^0`2BWZ<408ZDV0@0PXZ=101jOh8F0?ooo`00503o
ool406U[K0@0HF5Q101HEUH304m<B`@0AT4o100m=S@403<Z9`@0:1dJ100K3PX302TI50@0=b@N1016
<RX4054l<`@0JDe11021Ge4409QaH@<0TVeO102:JEd4089SF@@0Nf1F101fG5@4075JDP<0K5I@101Z
E4l406YFD0@0KEYD101`GUP4075RG@<0LFAQ101[HV0406ENG@@0GEQH101FDU<404m@DP@0C51C0`1<
E5T404mJH@@0DV5Y101BI6d405=XLP@0Gg9k0`1VNX<406b2R`@0MX^D101hT9X407VDX0@0NYNT101j
VjT307fO[@@0Oj>b102D]<440:_6d@@0_MKP1031h^d30;cIh`@0]]3I102`alh40:Vma0@0X[>i102J
ZJh309:NX`@0RYBH1022RXd407YoPQH0oooo000D0?ooo`@0JFY[101PH60405IEE@<0CDY91013?Sd4
03Tb<@@0;RHT100R61D401@91P<08QHA100c8ad404@a:@@0EShf101^D4D408ERE0@0VW=R0`2ELF84
08e/H0@0QVQM101nHUT407QNEP@0Le]D0`1^FE<406iIDP@0K5QB101^G5H406mNF@@0LF5M0`1`I604
06YPGP@0He]K101LEUL405ECE0@0Ce5C101<Ce@304YCE`@0CEYP101BHFP405AUKP@0F6]d101NLG/3
069hP@@0JH2:101`R98407><U`@0MI6N101fUJ8407NIY`<0Mib[101mX[8409Je`P@0//WC102meMl4
0<KTkP<0`]gV102me=`40;K:d@@0[/36102U]K/409f[[`<0U:2T102<UIT408>:S@@0Nh225P3oool0
01@0oooo101YJV/4061PH0@0EUEE0`1=BTT404<n?@@0>C8a100^9R@4028H5@@050T60`0R5Q4403<S
7@@0A34Y101F?SH406i@A@@0QF9D102JLf8309EaHP@0SFaP1026J5d407iRF@@0N5iF101cFe@306iI
D`@0KUUB101/F58406iLEP@0KeiI101aHEd3071TH0@0JV1N101SFe/405aFE`@0EE=D101?DE<404a?
E0<0BU=G101=FV04059QJ0@0E6E^101HJg@405iaN`<0HWR1101YP8X40728TP@0LhbG101eTIh407JE
XP@0MiVW0`1gW:/407fR/P@0U[G2102bbM<40;gEg`@0a^C^0`32gNH40;gDg0@0]/[A102^`<H40:Fe
^`@0WJ^_0`2DX:@408bEV@@0PhZ=101kP88F0?ooo`00503oool406UZJ`@0H61P101FEED304e:B@@0
@chm100i<S4402hV90@08QPE100D2@H3028F4@@0<b<M1014<BT405Hn=P@0KU151025HU@409YcHP<0
UG5R102=K60408IXG@@0OV9I101hGUH407=KE0<0KUUC101^FE8406aHDP@0KUaF101_GUT4075QG@<0
L6AP101ZH5h406=KF`@0G5IG101EDe@404mAD`@0C4mD0`1:DeL404eJH0@0DV5X101DIFh405Q[M0@0
GW5k0`1RN84406V0RP@0L8RB101cS9L407FAWP@0MYFR101gVJL307NLZ`@0OJ:b102F]L840;;9d`@0
_MGO1036i>h30<;MiP@0_MCL102fb]440:k0aP@0YKFk102MZjl309BPY0@0S9FI1023RXd407^0PQH0
oooo000D0?ooo`@0JFY[101PH60405IEE@<0CDY91013?Sd403Tb<@@0;RHT100R61D401@91P<08QHA
100c8ad404@a:@@0EShf101^D4D408ERE0@0VW=R0`2ELF8408e/H0@0QVQM101nHUT407QNEP@0Le]D
0`1^FE<406iIDP@0K5QB101^G5H406mNF@@0LF5M0`1`I60406YPGP@0He]K101LEUL405ECE0@0Ce5C
101<Ce@304YCE`@0CEYP101BHFP405AUKP@0F6]d101NLG/3069hP@@0JH2:101`R98407><U`@0MI6N
101fUJ8407NIY`<0Mib[101mX[8409Je`P@0//WC102meMl40<KTkP<0`]gV102me=`40;K:d@@0[/36
102U]K/409f[[`<0U:2T102<UIT408>:S@@0Nh225P3oool001@0oooo101XJV/405iOG`@0EE=C0`1:
B4P4040l>`@0=C0^100Z8b4401dE4`@040H40`0M4Ph402lQ70@0@S0Y101G?cH406mBAP@0QfAF102J
Lf<309QdI@@0TG1T102:K64408=WGP@0O6=J101fGeP3079ME`@0LUeF101_G5D406mME`@0KUeH101_
Ge/306aPG0@0J5eL101QFEP405aEEP@0EU=E101@DUD404eAEP<0BE9G101:Eed404mOIP@0DfA]101J
K7@405ibN`<0HGR1101VOXP406^4S`@0KXVE101aSY/407>CX0@0LiJT0`1bV:P407jS/P@0VKO3102e
b]@40;gDgP@0an?]0`3=iNd40<CJh@@0_<kE102c`lT40:Vh_@@0X:fa0`2GXJD408jFVP@0Q8^>101k
P88F0?ooo`00503oool406QZJ`@0GUmO101EDe<304Y8B0@0@3`k100e<2h402XS8@@07ADC100@1P@3
01dB3P@0;b4L1012<2T405Lo=P@0Ke961027I5H409YcH`<0V7AU102AL6@408Y/H@@0PfMN101lHeX4
07IOF0<0LUeG101bGEH406mLE@@0KeeG101^GEP406mOF`<0K61L101XGE`4065IF0@0G5EF101FDeD4
051BE@@0CE5F0`19DUL404YGG@@0CemV101CI6d405Y/M0@0GW9k0`1QN84406InR0@0JhB?101^RID4
076>V`@0Li>P101cUZ@307:HZ0@0OZ>b102I]l<40;G:e0@0_MCN1037hnd30<gUk@@0a=[Q102lc]D4
0;?3b@@0ZKRm102P[K4309NQY@@0SYJJ1024Rhh407^0PQH0oooo000D0?ooo`@0J6Y[101NGel405EC
D`<0BTQ81010?3/403D`;P@0:R<Q100M5A<4010610<07A8>100_8A`4048`:@@0Eclf101_DTH408MT
EP@0VW=S0`2HM6D4095`I0@0RVaQ1023Ieh407aSFP@0MUmH0`1bGEL4079MEP@0KeaE101_GEL406iM
F0@0KemK0`1/H5`406QMG0@0HEUH101LEEH405ICE@@0D59E101=DEH304UBE`@0BUMM101?GfH405=T
K@@0FVad101NLW/3065hP@@0IWj8101[Q8l406j9U@@0LHjK101cTj0407>FY0<0LYRX101nXk8409Vg
``@0]L[D102me=h40<OSk@<0cNG]1034f^440;c>e@@0/l?9102Y^;d40:2]/@<0Uj6U102>UYX408B;
SP@0Nh225P3oool001@0oooo101XJF/405eNG`@0De9B0`18AdH403hj>P@0<Rh]100V81l401XC4@@0
30D20`0I40d402/O6P@0@2lX101E?cH406mBAP@0QVAF102ILV<309YfI`@0U7AW102=KfD408I/HP@0
P6MO101kI5d307MQF`@0M5mI101aGUP4071NF0@0KUeG101/GEP306ULF0@0IE]I101PEeL405]EEP@0
EUAF101BDeL404mCF0<0BeAJ1019EUd404]LH`@0CV5Z101FJG8405]aNP<0HGN0101TOHL406R2S@@0
K8ND101_SIX4072@WP@0KY>R0`1]UZH4082U]0@0V[O4102bb=840<3Fg`@0b^?/0`3Hk?<40<gOi@@0
`]?H102ha/`40:fj_`@0Xjnc0`2IXjH408nGVP@0QHb>101lP88F0?ooo`00503oool406QYJ`@0GEiO
101CDU8304Q7AP@0?SXj100b;Rd402HP7`@06Q<A100<1@8301T@3@@0:alJ1010;bP405Do=P@0Ke96
1026I5H409UbH`<0VWIW102DM6L408e_I@@0QVaR1020Iel407]TG@<0Mf5K101dGeT4075NF0@0L5iH
101^GEL406aMF0<0JEaH101UFeT4061GE`@0FeEF101FE5H4059CE`@0Ce=H0`1;E5X404UFG@@0BeaS
101>HFX405IYLP@0Fg5j0`1QMh0406AmQ`@0J8:=101/Qi@406n=VP@0L92N101^Tj8306fFYP@0P:Fd
102J]l@40;;8dP@0`=KO103:hn`30=S/l`@0cMoU1032dmP40;S6c0@0[KZo102S[k<309VSYP@0SiNJ
1025S8h407b0PQH0oooo000D0?ooo`@0J6U[101MGUl405=BDP<0B4M6100n>SX4038^;@@09R0O100J
4a4400`50P<06A0=100[7aX4040_:0@0EClf101_DTH408ITEP@0VG9S0`2JMVL409AdI`@0SFmU1026
K684081WG`@0NfAM0`1gHE/407AOF@@0LEiH101`GUP406iME`@0K5eH0`1YG5P406EKF@@0H5MG101K
EEH405IDEP@0DU=G101?DeP304]DFP@0BEIM101;G6<404iQJP@0EVUb101KLGX3065gP0@0I7f7101X
PXd406b7U0@0KhfJ101`T9h406jCXP<0KIJV1020YK@409Zga0@0//SB1030e]l40<[Sk0<0f>cc103=
gnD40<;Cf0@0^<K<102]^[l40:>_/`<0VJ>V102?UiX408F<SP@0O8225P3oool001@0oooo101XJF/4
05eNG`@0De9B0`18AdH403hj>P@0<Rh]100V81l401XC4@@030D20`0I40d402/O6P@0@2lX101E?cH4
06mBAP@0QVAF102ILV<309YfI`@0U7AW102=KfD408I/HP@0P6MO101kI5d307MQF`@0M5mI101aGUP4
071NF0@0KUeG101/GEP306ULF0@0IE]I101PEeL405]EEP@0EUAF101BDeL404mCF0<0BeAJ1019EUd4
04]LH`@0CV5Z101FJG8405]aNP<0HGN0101TOHL406R2S@@0K8ND101_SIX4072@WP@0KY>R0`1]UZH4
082U]0@0V[O4102bb=840<3Fg`@0b^?/0`3Hk?<40<gOi@@0`]?H102ha/`40:fj_`@0Xjnc0`2IXjH4
08nGVP@0QHb>101lP88F0?ooo`00503oool406MYJP@0GEeN101BDE8304M5A@@0>cTh100`;2/402@O
7P@05a4@100:0`8301P?30@09a`H100n;BH405<n=@@0K5151024HUD409MaHP<0VgMY102GMVX4091b
J0@0RVmV1024Jf<407iXH@<0NVEN101fHU`407=PFP@0L5iI101]G5L406]KE`<0IeYF101TF5H405mG
EP@0FeAE101GE5H405AEF0@0D5EJ0`1>EU`404]HG`@0C5aS101=H6P4055VK`@0Efeg0`1MM7h4065k
QP@0IX6<101XQY<406b:V@@0JXjL101ZTJ0306bEY@@0PZJd102I]l<40;37d@@0a=OP103Bi^d30>3`
mP@0e>?Y1038em`40;g:cP@0/Kg1102V/;@309bTZ0@0TIRK1026S8l407b1PaH0oooo000D0?ooo`@0
IfUZ101MGEh4059ADP<0AdE5100k>CP4030/:`@091lN100G4A0400X30P<060l<100W71P403h]9P@0
Dche101/D4D408ARE@@0Ug5R0`2KMfT409MfJP@0T79X102:KfH408A[H`@0OVQQ0`1jIEh407IRG0@0
Lf1J101`GUT406eLE`@0Je]G0`1WFUH406AHEP@0GeMF101KE5D405MDEP@0E5EH101@EEX304iFG0@0
BeQO101<G6<404ePJ0@0DFI_101GKGL305edOP@0HG^6101VPH`406R6T`@0K8ZI101ZSY`406ZAX0<0
K9FU1022Y[@409Vg``@0/<OA1034en040=;Vk@<0h?3f103DhnT40<SGg0@0_L[>102a_L440:J`]0<0
W:BX102AV9/408J<S`@0O8635P3oool001@0oooo101WJFX405eMGP@0DU5B0`17ADD403/i>0@0<2`[
100T7ah401LA40@02P<20`0H3``402LL60@0?RdV101C?SD406a@A@@0Q69E102GLF8309]gJ@@0UgIZ
102@LVP408Y_IP@0Q6]S101nJ64307YUGP@0MV9L101cH5X4071NF@@0KEaG101[FeL306MJEP@0I5QF
101OEeH405]DE@@0EeAF101DEEP4051EFP<0CUIL101;F5l404aLH`@0CF1X101AIVl405M]M`<0GGAn
101QNhH406J1S0@0J8JC101/RYT406Z>W0@0JY6P0`1/UJD408:V]0@0VKO3102`am440<CGh0@0d^K]
0`3Pl?H40=CSj@@0b=OL102mb/h40;6m`@@0Y[2d0`2LY:P4096HV`@0QXb?101lPH<F0?ooo`00503o
ool406MYJP@0GEeN101BDE8304M5A@@0>cTh100`;2/402@O7P@05a4@100:0`8301P?30@09a`H100n
;BH405<n=@@0K5151024HUD409MaHP<0VgMY102GMVX4091bJ0@0RVmV1024Jf<407iXH@<0NVEN101f
HU`407=PFP@0L5iI101]G5L406]KE`<0IeYF101TF5H405mGEP@0FeAE101GE5H405AEF0@0D5EJ0`1>
EU`404]HG`@0C5aS101=H6P4055VK`@0Efeg0`1MM7h4065kQP@0IX6<101XQY<406b:V@@0JXjL101Z
TJ0306bEY@@0PZJd102I]l<40;37d@@0a=OP103Bi^d30>3`mP@0e>?Y1038em`40;g:cP@0/Kg1102V
/;@309bTZ0@0TIRK1026S8l407b1PaH0oooo000D0?ooo`@0IfUZ101LGEh4055AD@<0ADA4100j>3P4
02h[:P@08QhM100E40l400P20@<05Ph<100U6aL403XZ9@@0DC/c101XCT@407mODP@0TViP0`2LMfT4
09YiK0@0TgE[102<LVT408I^I`@0PF]T0`1lIf4407MTGP@0M65K101`GeT406eLE`@0JU]F0`1VFED4
06=GE@@0GeIE101KE5D405QEE`@0EEII101BEe/304mHGP@0CEYQ101=GFD404iQJP@0DFI`101EK7H3
05UbO0@0GWR4101ROX/406B3T@@0IXNE101VRiT406N>WP<0KYJV1024YkD409^ha0@0/<SA1036f>04
0=SXk@<0iO;g103LjNd40<oKg`@0`/g@102e_l<40:Vb]@<0WZFX102BVI`408N=S`@0OH635P3oool0
01@0oooo101WJFX405aMGP@0DE5A0`15A4@403Xh>0@0;R/Z100R7Qd401D@3`@020810`0F3P`402DK
5`@0>RXU101A>c<406Q>A0@0OemB102BKV0309agJ@@0VWU/102CMF/408abJ@@0QViW1021Jf@307aW
H@@0MfAN101dHE/4071OF@@0KEaG101ZFeH306IIE@@0HeME101OEUD405]DE@@0F5EG101EEUT4059G
F`<0CeQN101=FV4404eMI@@0CV5Z101AIW0405E/MP<0FG9l101NN8@4069nR`@0I8>A101VQiD406J;
V@@0IhjN0`1^UZH408BW]@@0VkS4102`b=440<KHh0@0f>S]0`3Ul_L40=cYk@@0cm_O1032cM040;Fo
``@0ZK:e0`2NYJP409:IW0@0Qhf?101mPH<F0?ooo`00503oool406MYJP@0G5eN101ADE4304E4A0@0
>SPh100^:bX4028N7@@05A0?10080P4301H>30@09A/G100j:RD4054k<`@0J4i4101oGe84099^H0<0
W7MY102JNF`409=eJ`@0S79Y1026KVL4085[I0<0O6MQ101gI5h407AQF`@0L5mI101]G5L406YKEP<0
IUUE101SEeD405mFE@@0FeAE101HEEL405EFF@@0DUMK0`1?F5h404eJH@@0CEeU101>HFX4055VL0@0
EFaf0`1ILW`405ihQ0@0HWj;101TPi4406J7U@@0IX^I101WSYh306jFYP@0Q:Ne102K^<@40;38d@@0
a]SP103Hj>d30>Gbm`@0g>W]103?fml40<;=d0@0]Ko3102Y/[D309jUZ0@0TYVL1027SHl407f1PaH0
oooo000D0?ooo`@0IfUZ101LGEh4055AD@<0ADA4100j>3P402h[:P@08QhM100E40l400P20@<05Ph<
100U6aL403XZ9@@0DC/c101XCT@407mODP@0TViP0`2LMfT409YiK0@0TgE[102<LVT408I^I`@0PF]T
0`1lIf4407MTGP@0M65K101`GeT406eLE`@0JU]F0`1VFED406=GE@@0GeIE101KE5D405QEE`@0EEII
101BEe/304mHGP@0CEYQ101=GFD404iQJP@0DFI`101EK7H305UbO0@0GWR4101ROX/406B3T@@0IXNE
101VRiT406N>WP<0KYJV1024YkD409^ha0@0/<SA1036f>040=SXk@<0iO;g103LjNd40<oKg`@0`/g@
102e_l<40:Vb]@<0WZFX102BVI`408N=S`@0OH635P3oool001@0oooo101WJFX405]MG@@0D51A0`14
A4@403Pg=`@0;2XZ100P7A`401<?3P@01P400`0D3P`402<J5P@0=bPS101<>34406=:@@@0NE]?102=
Jed309YfJ0@0W7]^102FN6d408idJ`@0R75Y1022KFH307eYHP@0N6EO101dHUd4075OF@@0KEaG101Y
FUH306IHE0@0HUME101NEE@405]EEP@0F5IH101FEeX405=HG@<0DEYO101?G68404mOIP@0D6=[101B
Ig4405A/MP<0Eg5l101JMX8405ekR0@0Gh2>101QQ9<40668U`@0I8fM0`1aV:P408RY]`@0WKW5102b
bM840<SIh0@0gNW^0`3ZloL40>G_lP@0e=kQ1036cm840;S1a0@0Zk>f0`2OYZT409BJW0@0R8f?101m
PH<F0?ooo`00503oool406MYJP@0FeeM101@D54304A4A0@0>3Lg100/:RX4020M70@04`l>10060@03
01@>30@08aXF100g:2<404`h<@@0HdY1101iFdl408e[G@<0VWIX102LNfh409IhK@@0SWA[1028LFT4
089]IP<0OFUR101hIEl407ARG@@0LEmI101]G5L406UJEP<0IUQD101REeD405iEE0@0FeEF101HEUP4
05IGFP@0DeQM0`1AFUl404mLHP@0CemV101@Hf/4059WL@@0E6af0`1GLG`405YfPP@0GG^8101OP8h4
0664T`@0HHRG101TSId3076HZ0@0R:Vg102M^LD40;;9dP@0b=WP103MjNh30>[cm`@0iNob103Dg^44
0<K?dP@0^<74102[/kH309nVZ@@0U9ZL1028SHl407f1PaH0oooo000D0?ooo`@0IfUZ101KGEd4051@
D@<0A4A4100h=cL402`Z:P@081dL100C3`h400H100<050h<100S6QH403LX8`@0C3Pa101SBT4407UK
C`@0SF]M0`2JMVP409akKP@0UWQ]102>M6/408QaJ@@0PVeV0`1mJF8407QUG`@0M69M101aGeT406eL
E`@0JEYF0`1VF5@4069GE@@0GUED101KEEH405QFF0@0EUMJ101CF5d3055JG`@0CeaR101?GfH4051S
J`@0DVMa101DK7H305MaO0@0FWJ2101MNhP405n0SP@0HHBC101QR9L406B=W@<0LIRX1028ZKL409fi
a@@0//WB1038fN040=gYkP<0j_?g103Uko840=CNh@@0a/oB102h`L@40:^c]P<0WjJY102DVY`408R=
S`@0OH635P3oool001@0oooo101WJFX405]MG@@0D51A0`14A4@403Pg=`@0;2XZ100P7A`401<?3P@0
1P400`0D3P`402<J5P@0=bPS101<>34406=:@@@0NE]?102=Jed309YfJ0@0W7]^102FN6d408idJ`@0
R75Y1022KFH307eYHP@0N6EO101dHUd4075OF@@0KEaG101YFUH306IHE0@0HUME101NEE@405]EEP@0
F5IH101FEeX405=HG@<0DEYO101?G68404mOIP@0D6=[101BIg4405A/MP<0Eg5l101JMX8405ekR0@0
Gh2>101QQ9<40668U`@0I8fM0`1aV:P408RY]`@0WKW5102bbM840<SIh0@0gNW^0`3ZloL40>G_lP@0
e=kQ1036cm840;S1a0@0Zk>f0`2OYZT409BJW0@0R8f?101mPH<F0?ooo`00503oool406IYJP@0FeaM
101?D54304=3A0@0=cHg100[:BT401hL70@04Ph>10040@0301<=30@08QTF100d9R4404Le;P@0GDHm
101cEd`408QWFP<0UW=U102MNfh409MjK`@0T7I]1029LVX408=_J0<0OV]T101iIV4407ESGP@0LEmJ
101]G5P406UJEP<0IEQD101QEU@405iEE@@0FeEF101IEUT405MHF`@0E5UN0`1BFf44055MI0@0D61X
101AI6`4059XL@@0E6af0`1FL7`405MeP@@0FGV6101LOX`405f2T@@0GXJF101USYh307NLZ`@0S:bi
102Q_<L40;O<e0@0cMcR103Qjnh30>ken0@0j_;e103Hh><40<W@d`@0^/;4102]];L30:6WZ@@0UIZL
1029SY0407f1PaH0oooo000D0?ooo`@0IVUZ101KG5d404m@D@<0@d=4100g=SL402/Y:@@07Q`L100B
3Ph400@100<04`d<100R6AH403@V8@@0AcD^101MASd407=GC0@0R6MJ0`2FLfD409ekKP@0UgY_102@
MVd408UbJP@0PfmX0`1nJf@407UVH@@0MF=N101aGeX406eLF0@0JEYF0`1UF5@4065FE0@0GUEE101K
EEH405UFF@@0EeQK101DFEh3059KH@@0DEeT101@H6P4055TK0@0DVQa101DK7H305I`O0@0EgF1101I
NHH405anS0@0GH:A101NQYH406F>WP<0Mib[102<[;T40:6la`@0]lcD103=g>840>7[kP<0k_Gh103Z
l_D40=SPh`@0bM3C102j`/@40:fd]`<0XJNY102EVY`408V>T0@0OH635P3oool001@0oooo101VJFX4
05]LG@@0Ce1A0`13@d@403Lf=`@0:bTY100N71`4018>3P@010400`0C3@`4028I5P@0=2HQ1017=Bh4
05e6?@@0LeM<1028IeX309IcI@@0WG]^102GNVl4091fK@@0RG9Z1023KfP307i[I0@0NFIQ101eHeh4
075OFP@0KEaH101YFUH306EHE0@0HEID101NEED405]EEP@0FEII101GF5/405AIGP<0DU]Q101AGF@4
051PJ0@0DFA/101BJ74405A/MP<0EW1l101GMH4405UiQP@0G7j<101MPY4405j6UP@0IHjN0`1gW:/4
08b/^@@0XKc7102gc=@40<gLhP@0hN_^0`3^mOP40>[bm@@0f>3S1039d=<40;[2a0@0[KBg0`2QYjT4
09FJW0@0RHj@101mPH<F0?ooo`00503oool406IYJP@0FeaM101?D54304=3A0@0=cHg100[:BT401hL
70@04Ph>10040@0301<=30@08QTF100d9R4404Le;P@0GDHm101cEd`408QWFP<0UW=U102MNfh409Mj
K`@0T7I]1029LVX408=_J0<0OV]T101iIV4407ESGP@0LEmJ101]G5P406UJEP<0IEQD101QEU@405iE
E@@0FeEF101IEUT405MHF`@0E5UN0`1BFf44055MI0@0D61X101AI6`4059XL@@0E6af0`1FL7`405Me
P@@0FGV6101LOX`405f2T@@0GXJF101USYh307NLZ`@0S:bi102Q_<L40;O<e0@0cMcR103Qjnh30>ke
n0@0j_;e103Hh><40<W@d`@0^/;4102]];L30:6WZ@@0UIZL1029SY0407f1PaH0oooo000D0?ooo`@0
IVUZ101KG5d404m@D@<0@d=4100g=SL402XY:@@07A`K100@3Ph400<000<04@`;100Q61D4030T80@0
@S8/101F@SX406iDB@@0PV=G0`2AKf8409YhJ`@0UgY_102@Mfh408YcJ`@0Q6mX0`1nK6H407UXHP@0
MF=N101`GeX406aLF0@0J5YF0`1UF5D4065FE0@0GUEE101LEUL405YGFP@0F5UM101EFel305ALHP@0
DUmV101AHFT4059UK@@0DVQb101CK7L305A`N`@0EWB0101GN8H405UlR`@0FX6@101NQYH406VAX@<0
O:2^102@[k`40:Nob@@0_LoG103BgnD40>K]l@<0mOWk103[lO<40=[PhP@0b]3C102l`/@40:jd]P<0
XZNY102EVY`408V>T0@0OX635P3oool001@0oooo101VJFX405]LG@@0Ce1A0`13@d@403Lf=`@0:RTY
100M71/4010>3P@00`000`0A30/4024H5@@0<2@P1012<R`405I2>P@0KUA91022HeL3095_HP@0VWQ[
102GNVl4091gKP@0RW=[1024KfP307i/IP@0NFQR101eHeh4071OFP@0K5aH101XFUH306EHE@@0HEID
101NEED405aFE`@0FUMJ101HFEd405EKG`<0E5aR101BGfH4055QJ@@0DVE]101BJ78405=/M`<0E71k
101FM80405MhQP@0FGb;101JPI0405j6UP@0JI6Q0`1lX:h4092__0@0Yko9102mcmL40=;Oi@@0i^ga
0`3enO/40>_al`@0f^3R103:d=<40;c2a0@0[[Bf0`2RYjT409FJW0@0RHj@101nPH<F0?ooo`00503o
ool406IYJP@0FeaM101?D54304=3A0@0=cHg100Z:BT401dL6`@040h>10030003014<2`@08APE100`
9204048b;0@0ET8j101^E4T4089SE`<0TFmR102JN6/409MjK`@0T7M^102:Lf/408A_J0<0OVaV101i
J68407ESGP@0L5mJ101/G5P406QJEP<0IEQE101QEU@405iEE@@0G5IG101JEeX405QIG@@0EE]O0`1D
G684059OIP@0DF5Y101BIFd4059XLP@0Dfag0`1DL7/405IdP0@0EgR6101IO8/405Z1T0@0GXJF101Y
TJ4307bP[P@0T:nl102W_lT40;g?e`@0d]oU103VkO430?Gin`@0jo7c103Jh>840<[@d`@0_<;4102^
];H30::WZ@@0UIZL1029SY0407j1PaH0oooo000D0?ooo`@0IVUZ101JG5d404m@D@<0@d=4100f=SL4
02TY:@@071/K100?3Ph4008000<040`;100O5aD402dS7`@0?BlY101A?cL406M?AP@0NeiC0`2<K5l4
09EdJ0@0UGU^102@Mfh408YcJ`@0PfmY0`1nK6H407UXH`@0M6AO101`H5/406aLF0@0J5YF0`1TEeD4
065GE@@0GUIF101LEeP405YIF`@0F5YN101FG64305ENI0@0Df5W101BHfX4059VKP@0DfUc101CKGL3
05A`O0@0E7>0101FN8H405MlRP@0FX6A101QR9P406nEY0<0PZBa102H];l40:g3c0@0`m?J103HhnL4
0>cal`<0n_go103Yk^l40=[Oh0@0bm3B102l`L<40:nd]P<0XZNY102FVY`408Z=S`@0OX635P3oool0
01@0oooo101VJFX405YLG@@0Ce1A0`13@d@403Hf=`@0:BTY100L6a/400l>3P@00P000`0@30/401lG
5@@0;B<O100m;bT4054o=`@0Idm6101kGU<308a/G`@0UGAX102ENFh4091gKP@0RW=[1023KfT307i/
IP@0NFQS101dI5l4071PF`@0K5aH101XFUH306AGE@@0HEME101NEUH405aGF0@0FUUK101HFUh405IL
H@<0EEiT101CHFL4059SJP@0DVI^101CJG<405=]M`<0E71l101DLh0405IhQP@0Egb:101JPI440668
V0@0KiFT0`22Y;4409Rd_`@0[L?<1033dmX40=SSi`@0k?7c0`3joOl40>W^k`@0f]oP103;d=840;c1
``@0[kBf0`2RYjT409JJW0@0RXf?101nPH<F0?ooo`00503oool406IYJP@0FUaM101?D54304=3A0@0
=SHg100Y:BT401`K6`@03`h>10020003010<2`@07aLE100]8al403d_:@@0DClg101WCdH407]ND`<0
S6aO102EM6P409EiKP@0T7M^102:Lf/408=_J@<0OVaV101iJ6<407ATG`@0L61K101/G5P406QJEP<0
I5ME101QEeD405iFEP@0G5MH101JFE/405QJGP@0EUaQ0`1EGV@405=QI`@0DV=Z101BIVh405=YL`@0
Dfeg0`1DL7`405AcP0@0EWR6101GO8X405Z1T@@0HHRH101_UJ@308:T/@@0V;Bo102]`l`40<?CfP@0
f>?W103/lO<30?[mo`@0jNk_103Jgn040<_@dP@0_<73102_];H30::WZ@@0UYZL102:SHl407j1PaH0
oooo000D0?ooo`@0IVUZ101JG5d404m@D@<0@d=4100f=SL402TY:@@071/K100?3Ph4008000<040`;
100O5aD402dS7`@0?BlY101A?cL406M?AP@0NeiC0`2<K5l409EdJ0@0UGU^102@Mfh408YcJ`@0PfmY
0`1nK6H407UXH`@0M6AO101`H5/406aLF0@0J5YF0`1TEeD4065GE@@0GUIF101LEeP405YIF`@0F5YN
101FG64305ENI0@0Df5W101BHfX4059VKP@0DfUc101CKGL305A`O0@0E7>0101FN8H405MlRP@0FX6A
101QR9P406nEY0<0PZBa102H];l40:g3c0@0`m?J103HhnL40>cal`<0n_go103Yk^l40=[Oh0@0bm3B
102l`L<40:nd]P<0XZNY102FVY`408Z=S`@0OX635P3oool001@0oooo101VJFX405YLGP@0Ce1A0`12
@d@403Hf=`@0:BTZ100L6a`400h>3P@000000`0?2`X401`F50@0:b4N100i;BP404`k=@@0H4Y2101c
FDl308EWF`@0SVmT102BMV/408mgK@@0RG=[1023KfP307e[I@@0N6QR101cI5l406mPG0@0JeaH101W
FUH306AHE@@0HEMF101NEUL405eHF@@0FeYM101JG5l405QNH`<0EV1U101DHVT405ATK0@0DfM_101C
JW@405=]N0<0Dg5l101CM84405AhQ@@0Egb;101LPi8406J<V`@0MiZX0`2:ZKD409nh``@0]<S@103:
emd40>3Wj`@0l_Gf0`3koOh40>S/k@@0fMgN103:c]040;c0`P@0[k>e0`2RYZP409JJV`@0RXf?101n
PH<F0?ooo`00503oool406IYJP@0FUaN101?D5430493A0@0=SHg100Y:BX401`K70@03Ph>10000003
00l;2P@071HD100[8Ah403T]:0@0C3/e101PBT8407=IC`<0QFMK102>Kf@4099fJ`@0SgM]1029Lf/4
08=_J0<0OF]U101hJ68407=TG`@0Kf1L101[G5P406MJEP<0I5QE101QEeH405iFE`@0GEQI101KFUd4
05YLG`@0F5iS0`1FH6D405ARJ@@0E6A/101CIfl405=ZM0@0Dfeh0`1CLG`405=dP@@0E7R5101GO8/4
05b3TP@0IXbK101gVZP308ZY]@@0WkS3102db=040<[Gg@@0h>O[103bmOH30?_moP@0j>c]103IgMh4
0<[>d0@0_<32102_/kD30::VZ0@0UYZK102:SHl407j1PaH0oooo000D0?ooo`@0IVUZ101JG5h404m@
D@<0@T=4100f=SL402TY:P@071/L100>3Ph4000000<03`/:100L5Q@402/Q7P@0>BdX101<>cD4061:
@P@0LeU?0`25Ie/408i_I0@0TWI[102?Mfd408UcJ`@0PfmX0`1mJfD407QXHP@0LfAO101_H5`406]L
F0@0IeYF0`1TF5D4065GEP@0GUIG101MF5T405]JG@@0FUaO101HGV<305IPI@@0E69Y101DI6`405=W
K`@0DfYd101CKGP305=aO0@0DgB1101DN8D405MlR`@0G8>B101VS9/407NJZ0<0RZVe102O^<<40;C8
d0@0b]OM103Pin/40?;emP<0nogn103Xk>d40=WMgP@0b/k@102l`<840:nc]@<0XZJX102FVY/408Z=
S`@0OX635P3oool001@0oooo101VJFX405YLGP@0Ce1A0`12@d@403Hf=`@0:BTZ100L6a`400h>3P@0
00000`0?2`X401`F50@0:b4N100i;BP404`k=@@0H4Y2101cFDl308EWF`@0SVmT102BMV/408mgK@@0
RG=[1023KfP307e[I@@0N6QR101cI5l406mPG0@0JeaH101WFUH306AHE@@0HEMF101NEUL405eHF@@0
FeYM101JG5l405QNH`<0EV1U101DHVT405ATK0@0DfM_101CJW@405=]N0<0Dg5l101CM84405AhQ@@0
Egb;101LPi8406J<V`@0MiZX0`2:ZKD409nh``@0]<S@103:emd40>3Wj`@0l_Gf0`3koOh40>S/k@@0
fMgN103:c]040;c0`P@0[k>e0`2RYZP409JJV`@0RXf?101nPH<F0?ooo`00503oool406IYJP@0FeeN
101?D58304=4A@@0=SLh100Y:R/401`L7@@03Ph?1000000300d:2@@06ADD100W81d403DZ9P@0ASLa
101IASh406YCBP<0Nf5F1026JEh408ibJ0@0SGE/1028LVX4089^I`<0O6YU101gIf44079SG`@0KV1L
101ZG5T406IJE`<0HeQF101QF5L405mHF0@0GEYK101LG5l405]NH@@0FV1U0`1HHFL405ITJP@0EFI^
101EJ74405A[M@@0E6ii0`1CLGd405=dP@@0EGR6101IOH`40666U@@0KY:P1020X:d309B_^@@0Ykg7
102lc=<40=;Lh@@0j>g_103jno`30?Khn0@0i^WY103Gf]/40<W<cP@0^ko0102^/[<30::UY`@0UIVJ
1029SHh407j1PQH0oooo000D0?ooo`@0IVUZ101KGEh404m@DP<0@dA5100f=cP402TZ:`@071`M100>
3Pl4000000<03@X9100I5A@402LP7@@0=BXV1016=c4405U6?P@0JU=:0`1kHEH408IYGP@0SW9X102=
MF`408QbJP@0PViW0`1lJVD407MWH@@0LV=O101^H5`406YLF@@0IUYG0`1SF5H4065HE`@0GeQH101M
FU/405aLG`@0FeiQ101JH6D305QQI`@0EVAZ101EIVh405EXL@@0E6]e101DKWT305=aO@@0DgB1101E
N8H405UmS0@0HHJE101^TZ04082P[@<0U:ni102W_LL40;c<d`@0d]cQ103XkNl40?[ko0<0m_Sh103V
jNT40=OJf`@0bLc>102k_l040:jb/`<0XZFW102EVIX408V=SP@0OX625P3oool001@0oooo101VJFX4
05]MGP@0Ce1B0`13A4D403Hg>0@0:BX[100L71d400h>3`@000000`0=2PT401TE50@09b0M100e:RH4
04Hg<@@0FDHn101ZDdX307]QEP@0QVUN102>LVP408eeK0@0R79Z1022KVL307aZI@@0MfMQ101bHel4
06iPG0@0JUaI101VFUL306=HEP@0HEQG101OF5P405eJF`@0G5aO101KGV4405YPI@<0F65W101FI6X4
05EVKP@0EFQa101DJgD405A^N@<0Dg5m101CM84405EhQP@0FGf<101QQYD406jBX0@0P:2]0`2D[kT4
0:Nma`@0_<cC103Bg>440>S]k`@0n__l0`3fn?P40>KYj@@0em[K1039c<h40;^o`0@0[[:c0`2RYJL4
09FIVP@0RHf>101nPH8F0?ooo`00503oool406IYJP@0FeeN101?D58304=4A@@0=SLh100Y:R/401`L
7@@03Ph?1000000300d:2@@06ADD100W81d403DZ9P@0ASLa101IASh406YCBP<0Nf5F1026JEh408ib
J0@0SGE/1028LVX4089^I`<0O6YU101gIf44079SG`@0KV1L101ZG5T406IJE`<0HeQF101QF5L405mH
F0@0GEYK101LG5l405]NH@@0FV1U0`1HHFL405ITJP@0EFI^101EJ74405A[M@@0E6ii0`1CLGd405=d
P@@0EGR6101IOH`40666U@@0KY:P1020X:d309B_^@@0Ykg7102lc=<40=;Lh@@0j>g_103jno`30?Kh
n0@0i^WY103Gf]/40<W<cP@0^ko0102^/[<30::UY`@0UIVJ1029SHh407j1PQH0oooo000D0?ooo`@0
IVU[101KGEl404mADP<0@dE6100g>3T402X[;0@07AhO100?414400010P<02@P8100F4a8402@M6`@0
<2LS1010<bl40551>P@0HTi60`1`FE0407eSF@@0R6eR102:LVP408I`J0@0P6aV0`1kJF@407EVH@@0
LF9N101/Ge`406UMFP@0IUYH0`1RF5L4061HE`@0GeUJ101NFed405iNH@@0GF1T101LHVH305YSJ@@0
F6I/101GJ6l405I[L`@0EFef101DKgX305AbOP@0E7F2101FNHL405b1S`@0J8^I101gV:D408ZV/P<0
W[Fn102``l/40<CAe`@0fn;U103`lO<40?ooo`<0lO;c103SiND40=GGf0@0al[;102j_Kh40:f`/P<0
XJBU102EV9T408V<SP@0OH225P3oool001@0oooo101VJF/405]MG`@0Ce5B0`13ADH403Lh>@@0:R//
100M7Ql400l@4@@000420`0920P401HC4P@091dK100`9b<4040c;`@0DD4j101RCTH3071ID0@0OF=I
1028KF8408YbJ0@0QW1X1020K6H307]YI0@0MFIQ101aHUh406aOG0@0JEeJ101VFUP3069HE`@0H5QG
101OFEX405iKG@@0GUiQ101MH6@405aRIP<0FV=Y101HIV`405MXK`@0EV]c101EKGH405A_NP<0E79n
101DMH8405IiQ`@0G86?101XRiT407NHY@@0RZJb0`2N]Kh40;33b`@0a=7G103Kh^D40?3al`@0oooo
0`3al_<40>?Ui@@0eMOH1037b//40;Zm_P@0[K2b0`2QY:D409FHV@@0RHb>101mP88F0?ooo`00503o
ool406IYJ`@0FeeO101?DE8304=5AP@0=cPi100Z:b`401dN7`@03a0A10000@8300T820@05Q<B100T
7A/4030W8`@0@3<_101A@CX4069>AP<0L5U@101mHeT408Q]HP@0RW9X1026L6P4081/IP<0NfUT101e
IV44075RGP@0K5mL101YGEX406IJF0<0HUQG101PF5L405mIFP@0GU]M101NGV4405ePI0@0G69V0`1J
HfT405QVK0@0EfQ_101FJg<405E]MP@0E6mj0`1DLWh405AePP@0EWV7101LPHl406R;V@@0MiRU102:
Y[8309je_P@0/<?;1034dML40=_Ri@@0l?7c103oool30?7bl`@0hnGU103EemP40<O:b`@0^[fn102]
/;830:6TY@@0UIRI1029S8h407f0PQH0oooo000D0?ooo`@0IVU[101KGEl404mADP<0@dE6100g>3T4
02X[;0@07AhO100?414400010P<02@P8100F4a8402@M6`@0<2LS1010<bl40551>P@0HTi60`1`FE04
07eSF@@0R6eR102:LVP408I`J0@0P6aV0`1kJF@407EVH@@0LF9N101/Ge`406UMFP@0IUYH0`1RF5L4
061HE`@0GeUJ101NFed405iNH@@0GF1T101LHVH305YSJ@@0F6I/101GJ6l405I[L`@0EFef101DKgX3
05AbOP@0E7F2101FNHL405b1S`@0J8^I101gV:D408ZV/P<0W[Fn102``l/40<CAe`@0fn;U103`lO<4
0?ooo`<0lO;c103SiND40=GGf0@0al[;102j_Kh40:f`/P<0XJBU102EV9T408V<SP@0OH225P3oool0
01@0oooo101WJF/405]NG`@0D59C0`14ATL403Pj>`@0;2d^100N8244014B4`@00P<40`071`P401<A
40@07aXI100[924403T_;0@0BC`g101IB48306ICB`@0LUaC101mIE`408=/H`@0PVeU101nJV@307UX
HP@0LfAP101_HUh406]OG0@0J5eJ101UFeT3069HE`@0H5QH101PFe/4061MG`@0H61S101OHfH405iT
J@<0G6I[101JJ6h405UZLP@0F6ae101GKgP405EaO0<0EWAo101GN8D405YlRP@0HhJD101aTIh4086N
ZP@0Tjbf0`2W^/<40;W8c`@0c]OL103TinT40?Gdm@@0ooon0`3^knl40>3Qh@@0d]CD1035alP40;Rj
_0@0[:j`0`2PXZ@409BGV0@0R8^=101mP88F0?ooo`00503oool406MYJ`@0FeiO101@DU<304A6A`@0
>3Xk100/;Bh401hP8@@04A8C10020`@300L720@04a4@100O6QT402/T8@@0>Bl/1019?3L405U8@P<0
IU=;101bG5<407eUG0@0PfaS1022KFD407iZI0<0NFQR101cI60406mRGP@0JemL101XGEX406EKF@<0
HUQG101PF5P4061KF`@0H5eO101PH6<405mSIP@0GVAY0`1LIV/405YXKP@0FFYb101HK7D405M_N0@0
EG5l0`1FM7l405MhQ@@0FWb:101SQY@4076AWP@0PIjZ102C[;H30:Nj``@0^LS?103>em`40>CWj@@0
mOCe103oooh30>k_k`@0h>7Q103Be=@40<G7b0@0^;Zl102/[[030:2RY0@0U9NH1028Rhd407f0PQH0
oooo000D0?ooo`@0IfU[101KGUl4051BD`<0A4I7100h>S/402`];P@07R0Q100A4Q<4008310<01`L8
100C4A0401lJ6@@0:b@Q100i;b`404Tl=`@0FDQ20`1VDd/4079LD`@0OFEL1023K6<4089]I@@0OVYT
0`1iJ68407=TH0@0Kf9N101[Ge`406QMFP@0IE]I0`1RF5L4061HF0@0H5]K101PGEl4061PH`@0Gf=V
101NI6T305aVJ`@0FVQ^101IJW8405Q/M@@0Efmh101ELG`305IdO`@0EgR5101JO8X406>6U0@0LI6N
1021WZX409>/]P<0Yk[3102ib<l40<kGg0@0i>OY103em?D40?oooP<0k^o_103PhN440=;De0@0aLO8
102h^[`40:b^/0<0X::T102DUiP408R;S@@0OH225P3oool001@0oooo101WJF/405]NG`@0D59C0`14
ATL403Pj>`@0;2d^100N8244014B4`@00P<40`071`P401<A40@07aXI100[924403T_;0@0BC`g101I
B48306ICB`@0LUaC101mIE`408=/H`@0PVeU101nJV@307UXHP@0LfAP101_HUh406]OG0@0J5eJ101U
FeT3069HE`@0H5QH101PFe/4061MG`@0H61S101OHfH405iTJ@<0G6I[101JJ6h405UZLP@0F6ae101G
KgP405EaO0<0EWAo101GN8D405YlRP@0HhJD101aTIh4086NZP@0Tjbf0`2W^/<40;W8c`@0c]OL103T
inT40?Gdm@@0ooon0`3^knl40>3Qh@@0d]CD1035alP40;Rj_0@0[:j`0`2PXZ@409BGV0@0R8^=101m
P88F0?ooo`00503oool406MZJ`@0G5iP101ADe@304E7B@@0>C/m100];c44024S90@04aDG10051`P3
00@51P@03Ph>100J5aL402LR80@0<b/X1012=c<40554?P<0GDe6101XEDh4075ME@@0NVEM101kIUl4
07YWH0<0MVIQ101`HUh406aQGP@0JEiL101WGEX406AKFP<0H5UH101OFET4065LG@@0Hf1Q101SHfD4
069UJ0@0HFM[0`1OJFh405eZL0@0G6ad101JKgL405UaNP@0F7=n0`1IMX4405akR0@0HH:?101/S9T4
07^HX`@0RjB_102M/[/30;30a`@0`/kC103HgN040>c/k@@0noWi103inOP30>[ZjP@0g=gM103?d=04
0<;4a0@0][Ri102Z[:d309jQXP@0TiJG1028Rh`407f0PAH0oooo000D0?ooo`@0IfY[101LGV04055C
E0<0ADM9100i>cd402d_<@@08B<T100C5AL400D720<010D6100>3Ph401XG5`@09b8P100c:bP4048g
<`@0DD@n0`1MCDH406QECP@0LEeE101jIEd407]VG`@0NVMP0`1fIV44071RGP@0K65N101YGU`406MM
FP@0I5]J0`1PFEP405mIF@@0HEaM101SH64406=SI@@0HVEX101QIf/305mYKP@0GFY`101LK7@405Y_
M`@0FG5j101HLgh305UfP@@0G7^8101QPXl406b<V@@0NiRS102;Y:l409fb^`<0/<371032c]<40=SM
h0@0k>c]103knOT40?Win0<0j^[Z103LgMd40<o@d0@0`/C4102f^;T40:Z/[@<0WZ6R102CUYL408R;
S0@0OH215P3oool001@0oooo101WJV/405aNH0@0DE=D0`15AdT403Tk?@@0;Bla100Q8b@401<E5`@0
1@L80`041@H400h>3P@06QLG100W8R0403<[:0@0@SLc101AA3h305e=AP@0J5E>101aGED407YUG@@0
NfIO101jIf0307IVH@@0L69N101/HEh406UNG0@0IeeJ101TFeX3061IF0@0GeUI101QG5d406=PH@@0
Hf=U101RIFP4065WJ`<0GfU^101MJW0405a/M0@0FVmg101ILGX405QcOP<0FGJ1101LNhP40662S`@0
K8bI101kV:<408^T[`@0WK:k0`2``<L40<;>d`@0f=gP103/k>d40?_in@@0nOWh0`3Zj^X40=cMg@@0
cm3@1032a<@40;Jh^@@0ZZb]0`2NXJ8409>FU`@0R8^<101mP84F0?ooo`00503oool406MZJ`@0G5iP
101ADe@304E7B@@0>C/m100];c44024S90@04aDG10051`P300@51P@03Ph>100J5aL402LR80@0<b/X
1012=c<40554?P<0GDe6101XEDh4075ME@@0NVEM101kIUl407YWH0<0MVIQ101`HUh406aQGP@0JEiL
101WGEX406AKFP<0H5UH101OFET4065LG@@0Hf1Q101SHfD4069UJ0@0HFM[0`1OJFh405eZL0@0G6ad
101JKgL405UaNP@0F7=n0`1IMX4405akR0@0HH:?101/S9T407^HX`@0RjB_102M/[/30;30a`@0`/kC
103HgN040>c/k@@0noWi103inOP30>[ZjP@0g=gM103?d=040<;4a0@0][Ri102Z[:d309jQXP@0TiJG
1028Rh`407f0PAH0oooo000D0?ooo`@0IfY/101MGf44059DEP<0AdU;100k?Sl4030b=0@092HX100G
6A/400X=3`<00@@5100:2``401HE5@@08QlN100]9bD403/b;`@0BSlj0`1DAd<405m@BP@0IEE?101]
G5H4075OF@@0Lf5L0`1`HUd406]OG0@0JEiL101XGE/406IMF`@0HeaK0`1OFEX405mJF`@0HUiO101U
HV<406IUJ0@0IFQ[101TJFd3065[L0@0H6eb101OKgL405ibNP@0GGAm101MMX4305ijQ@@0Hh2<101Z
RI@407JCWP@0QIjY102EZk@40:Ni`0<0^LK;103<e=P40>3Si0@0lO3`103oo?/40?;al0<0i>CT103G
f=P40<_<c0@0_/31102c]KH40:NZZ`<0W9nP102BU9H408N:R`@0O7n15P3oool001@0oooo101WJV`4
05eOH@@0DUAF0`17BD/403/n?`@0<38d100T9RP401LI6`@02Pd?0`0110D400X;30@05QDE100R7ah4
02dW9@@0>c8_101:?cX305A7@`@0Ge1:101UEDl406eLEP@0LEmI101cHE`3071RG@@0JemL101YGU`4
06QMF`@0IUeK101SG5/305mIFP@0GeYK101RGUl406ERH`@0IVEX101UJ6/406AYK@<0HF]`101PKG84
05m_M`@0GW9j101MM7d405efP@<0GWZ5101SP8`406Z9U0@0MY>N1025WZT409F[]0@0YkW00`2ia//4
0<cDf0@0h>?T103al?040?oln`@0l_7`0`3Ti>@40=OHf0@0blc<102n`<440;>e]P@0YjZ[0`2LWj04
09:DUP@0QhZ;101lOh4F0?ooo`00503oool406MZK0@0GEmQ101BE5H304M9B`@0>cho100`<S@402@V
:0@05aTK100:3@l300441@@02P/<100F5AD4028O7P@0;BLU100k<Rl404Xo>P<0E4M3101OD4X406EE
C`@0KEaF101aGeT407=QG0<0L69M101[Ge`406UNG0@0J5eK101VGE/406=LF`<0GeUJ101OFU/4069N
G`@0IF9S101VIFP406EXJ`@0I6U]0`1QJg04061]LP@0Gfmg101NLWX405edO@@0GGJ10`1NNXD406>0
S0@0JXVD101fTih408FNZ@@0UJ^d102W^L030;W6b`@0c=CH103Phn@40?7`l0@0oock103blO030>CT
i0@0emSH103;c<`40;k0`@@0/kFf102WZZ/309bOX0@0TYBF1027RX/407aoPAH0oooo000D0?ooo`@0
J6]/101MH68405=FE`<0B4]=100n@48403<e=`@09bX[100K7R0400lB50<00PH8100520X4018C4`@0
7A`K100X9B<403@^;0@0A3Xg0`1>@cl405I:AP@0G4m;101RE4l406MHE0@0J5YF0`1WFeP806AKF@@0
I5aJ101TGE/4069LG0<0Ge]K101PGEd406=PH0@0IFAU101WIfT406Q[K@@0Ifa`0`1TKW8406A`M@@0
Hg9i101SMWd4069hP0@0Hg^40`1VOhT406b7T@@0MHnI1022VZ<4092U[P@0X;6i102a_lD30<C<d0@0
e][L103VinL40?KclP@0noSg103[j^T30=kNgP@0d];B1036alL40;^l_@@0/;6b102UYjP309ZMWP@0
T9>D1026RHX407aoP1H0oooo000D0?ooo`@0J6]/101MH68405=FE`<0B4]=100n@48403<e=`@09bX[
100K7R0400lB50<00PH8100520X4018C4`@07A`K100X9B<403@^;0@0A3Xg0`1>@cl405I:AP@0G4m;
101RE4l406MHE0@0J5YF0`1WFeP806AKF@@0I5aJ101TGE/4069LG0<0Ge]K101PGEd406=PH0@0IFAU
101WIfT406Q[K@@0Ifa`0`1TKW8406A`M@@0Hg9i101SMWd4069hP0@0Hg^40`1VOhT406b7T@@0MHnI
1022VZ<4092U[P@0X;6i102a_lD30<C<d0@0e][L103VinL40?KclP@0noSg103[j^T30=kNgP@0d];B
1036alL40;^l_@@0/;6b102UYjP309ZMWP@0T9>D1026RHX407aoP1H0oooo000D0?ooo`@0J6]/101M
H68405=FE`<0B4]=100n@48403<e=`@09bX[100K7R0400lB50<00PH8100520X4018C4`@07A`K100X
9B<403@^;0@0A3Xg0`1>@cl405I:AP@0G4m;101RE4l406MHE0@0J5YF0`1WFeP806AKF@@0I5aJ101T
GE/4069LG0<0Ge]K101PGEd406=PH0@0IFAU101WIfT406Q[K@@0Ifa`0`1TKW8406A`M@@0Hg9i101S
MWd4069hP0@0Hg^40`1VOhT406b7T@@0MHnI1022VZ<4092U[P@0X;6i102a_lD30<C<d0@0e][L103V
inL40?KclP@0noSg103[j^T30=kNgP@0d];B1036alL40;^l_@@0/;6b102UYjP309ZMWP@0T9>D1026
RHX407aoP1H0oooo000D0?ooo`@0J6]/101MH68405=FE`<0B4]=100n@48403<e=`@09bX[100K7R04
00lB50<00PH8100520X4018C4`@07A`K100X9B<403@^;0@0A3Xg0`1>@cl405I:AP@0G4m;101RE4l4
06MHE0@0J5YF0`1WFeP806AKF@@0I5aJ101TGE/4069LG0<0Ge]K101PGEd406=PH0@0IFAU101WIfT4
06Q[K@@0Ifa`0`1TKW8406A`M@@0Hg9i101SMWd4069hP0@0Hg^40`1VOhT406b7T@@0MHnI1022VZ<4
092U[P@0X;6i102a_lD30<C<d0@0e][L103VinL40?KclP@0noSg103[j^T30=kNgP@0d];B1036alL4
0;^l_@@0/;6b102UYjP309ZMWP@0T9>D1026RHX407aoP1H0oooo000D0?ooo`@0J6]]101NHF<405AG
F@<0BTe?1010@dD403Hh>P@0:bh`100P8bD401@G6P<020/>10031`P400h@4@@06ATI100T8R8402l[
:P@0?CHd0`17?S`404e4@@@0DdU6101ICT/405eBCP@0GeEB0`1NEU@405eGEP@0GUQG101PFUT4061K
FP@0H5eM0`1OG5d4061NG`@0Hf5R101UIFH406QYJ`@0JVe_101YKg8306QaM@@0J7=h101XMG/406Ui
P0@0JGb4101[PHT306n6S`@0MhjF1020UYh408fQZ0@0Vjbc102Z^;h40;c5b@<0c]?E103Ngml40>_Z
jP@0n?Cc103`k^d40>CRhP<0f=OG103<c<d40<72`P@0]kRh102/[Zl40::TY@<0V9ZL102>TI8408F8
R@@0Ngj05P3oool001@0oooo101XJfd405iQH`@0E5MI0`1:CDl40413A@@0=SPj100[;S04020S9@@0
51LJ0`082`h400<720@03Q0A100I6AT402@R8P@0;b/Z100m=S@304Ln?0@0CDA1101CBDH405U>B`@0
GE9>101OEE8305iFE0@0GEMF101NF5L4061JF@@0H5]J101PGEd305mLG@@0H5iO101SHF8406EUIP@0
J6U[101ZKFl406U_LP<0J75e101XLgP406QeN`@0JGV0101YO8@406^1R@<0KhJ?101gSYH4082FWP@0
SJ6X102K[;<40:Zh_P@0_<G90`3>dmD40=kOg`@0jn[Z103hm?<40?3^k@@0i>;R0`3HemL40<c<c@@0
`L;2102g^;P40:b^[`@0XZBU0`2HVY`408jATP@0QHR9101kOX0F0?ooo`00503oool406Q[K@@0GV5S
101DEeT304Y=C`@0@4=5100f>3X402/^<0@082<U100D5aX300P;3P@00`L8100>414401TI6@@0928R
100_:bX403df=0<0Achl101=A44405=9AP@0FDi;101MDTh405mEDP<0GUID101MEeH405iHE`@0H5YI
101PFeX4061MG@<0GeaM101PGUl406=QHP@0IFEV101XJF/406Y]K`@0JFmb0`1XLGD406QcN0@0J7Ek
101YNH0406UlQ0@0Jh690`1_QXl407N>UP@0P9JN102=XJP409^//`@0Z[Rn102laLT30<kCe@@0g]oO
103[j^X40?Sdl`@0l>k]103Th^830=SGe`@0c<c=1031`/840;Nh^0@0[:j_102RY:D309RJW0@0SY6B
1025R8T407]nP1H0oooo000D0?ooo`@0J6]]101NHF<405AGF@<0BTe?1010@dD403Hh>P@0:bh`100P
8bD401@G6P<020/>10031`P400h@4@@06ATI100T8R8402l[:P@0?CHd0`17?S`404e4@@@0DdU6101I
CT/405eBCP@0GeEB0`1NEU@405eGEP@0GUQG101PFUT4061KFP@0H5eM0`1OG5d4061NG`@0Hf5R101U
IFH406QYJ`@0JVe_101YKg8306QaM@@0J7=h101XMG/406UiP0@0JGb4101[PHT306n6S`@0MhjF1020
UYh408fQZ0@0Vjbc102Z^;h40;c5b@<0c]?E103Ngml40>_ZjP@0n?Cc103`k^d40>CRhP<0f=OG103<
c<d40<72`P@0]kRh102/[Zl40::TY@<0V9ZL102>TI8408F8R@@0Ngj05P3oool001@0oooo101YK6d4
05mRI0@0EUUK0`1=D54404=6B0@0>C`n100_<S@402DX:P@06QdP0`0?4QD400@92`@02@d?100E5aP4
020P80@0:bTX100f<S4303hi=`@0AT0n101:@d440559A`@0EDe;101FCdh305MAD@@0F5AD101IEEH4
05eHF@@0FeQI101NG5d305mMGP@0H5mP101RHV<406EVJ0@0JFY/101/KW0406aaM0<0Jg=g101/MW/4
06eiOP@0L7f3101`PHP407B6S@<0NHbC1021U9/408bMY0@0V:N]102V/[L40;Fo`P@0alc>0`3HfMX4
0>?ShP@0l>k]103`kN`40>GSh`@0fm[I0`3@d=040<K6aP@0_;fm102b/k@40:VZZ`@0Wj6R0`2FV9T4
08f?T0@0Q8J8101kOWlF0?ooo`00503oool406U/K@@0Gf9T101FFE/304e@D@@0@dI8100i?3h402lb
=0@09BPZ100J7B0300lB5@@010T;10093@l401DG60@0820P100[:BP403Hb<@<0?STg1016@3h404Y3
@@@0DDU7101ECD/405I?CP<0Ee5A101HE5@405UEEP@0GEQI101KF5T405iLG@<0GeeN101PGf04069R
H`@0IFIX101YJV`406a^L0@0K75d0`1[LgL406afN`@0KGUn101`OH<40721R0@0M8J=0`1iS9<4086D
V`@0S9fT102HYjd40:Jb]`@0]Ko21037c<h30=SIfP@0hn?R103`k^d40?3]k0@0iN?S103Kf]T30=3@
d0@0a/K6102l_Kd40;:c]0@0ZJZ[102OXJ8309JHV@@0SHn@1024QXP407]nOaH0oooo000D0?ooo`@0
JFa]101OHV@405IIF`<0CE1A1013ATP403Tl?P@0;c8d100U:2X401XM80<03a8E10042@/400T=3`@0
5ALH100P820402/Y:0@0=S8a0`0n>CL404I0?P@0BT=1101ABDL405E=B`@0ETm>0`1GDE4405QDE0@0
FEEF101MF5T405]HF@@0GUaM0`1OGEh4061OH0@0HV9S101UIVP406UZK0@0K6i`101/LG@306]cM`@0
K7Ik101]NGh4071mP`@0L868101dQXd307V<T`@0PIBK102<WJ@409RW[@@0Y[:g102e_l840<O<cP<0
f=WJ103Shn840?3^k@@0l>g/103Uhn<40=_Jf@<0d=3@1036a/H40;bm_@@0/[>d102YZZ/409nQXP<0
UYRI102=Si0408B6R0@0Ngio5P3oool001@0oooo101YK6d405mRI0@0EUUK0`1=D54404=6B0@0>C`n
100_<S@402DX:P@06QdP0`0?4QD400@92`@02@d?100E5aP4020P80@0:bTX100f<S4303hi=`@0AT0n
101:@d440559A`@0EDe;101FCdh305MAD@@0F5AD101IEEH405eHF@@0FeQI101NG5d305mMGP@0H5mP
101RHV<406EVJ0@0JFY/101/KW0406aaM0<0Jg=g101/MW/406eiOP@0L7f3101`PHP407B6S@<0NHbC
1021U9/408bMY0@0V:N]102V/[L40;Fo`P@0alc>0`3HfMX40>?ShP@0l>k]103`kN`40>GSh`@0fm[I
0`3@d=040<K6aP@0_;fm102b/k@40:VZZ`@0Wj6R0`2FV9T408f?T0@0Q8J8101kOWlF0?ooo`00503o
ool406U/KP@0HFAU101HFed304mBE0@0ATU;100m@48403<g>@@0:Rd_100P8bH301DI70@02`lB1007
2`d4018F5`@071hO100V9RL4030_;`<0>3De1010?3/404<o?P@0BDA3101>BDP404i;B`<0DDm?101C
DE8405ECE@@0FEMH101IF5T405aKG0<0GEeO101PHF84069TI@@0IVQY101ZK6h406e`LP@0KW=e0`1^
MGT4071iO@@0Lgf1101fPHH407N5RP@0O8^A0`23TYL408bJX0@0UZ:X102R[K840;2h_0@0`<G7103@
dM<30=kMg@@0j^SW103/j^T40>CRh@@0fm[I103BdM430<W9b@@0`<30102g]kP40:j_[`@0YJJW102L
WYl309>EU`@0Rhf?1023QHL407YmOaH0oooo000D0?ooo`@0JFa^101QI6D405QKG@<0Ce9D1016BD/4
03e0@P@0<cLi100Z;Bl4020S9P<05ATL100;3a8400L;3@@04QHG100L7Ql402HV9`@0<2l_0`0h=CD4
040l>`@0@cln1019A4<404i9B0@0CT];0`1ACdl405=ADP@0EE=E101IEeP405UHF@@0G5]L0`1MGEl4
061QHP@0HVAU101VJ6T406Y/KP@0KG1b101^LgD306ieN@@0L7Um101cOH4407J1QP@0MhF:101lRi43
08>BU`@0S9ZP102FXZP40::]/P@0/;Rl1030aLL40=3Ad`<0g]gM103Zj>L40>cZj@@0i>;Q103Kf]T4
0=;Ad@<0bLW91030`<040;Ng^0@0[Zn_102UYZL409bNW`<0TiFG102;SHl408>5Q`@0NWeo5P3oool0
01@0oooo101YK6h4065TI@@0F5]M0`1?DU@404I9B`@0?D12100c=cT402X];`@082<V0`0E6A`400/?
4P@01`/=100B5QL401`N7`@09RHW100`;bl303Pe=@@0@3`k1013?ch404U4@`@0CTU8101>Bd/3055?
C`@0De5B101EDeD405UGF0@0FEQI101LFe`305eMG`@0H65R101RI6D406IXJ@@0JVa^101]L78406ic
M@<0KWEi101`NGd407=mP@@0MX66101gQHX407b;T@<0Pi:G102<VZ0409JRZ0@0XZfb102`^;`40<35
a`@0d=7C0`3NgMd40>[Xi`@0k>[Y103Th^440=_Jf@@0d]7A0`39bLT40<30`0@0]kNh102^[jl40:FV
Y`@0W9jO0`2CUIL408^=S`@0PhF7101jOGlF0?ooo`00503oool406U/KP@0HFAU101HFed304mBE0@0
ATU;100m@48403<g>@@0:Rd_100P8bH301DI70@02`lB10072`d4018F5`@071hO100V9RL4030_;`<0
>3De1010?3/404<o?P@0BDA3101>BDP404i;B`<0DDm?101CDE8405ECE@@0FEMH101IF5T405aKG0<0
GEeO101PHF84069TI@@0IVQY101ZK6h406e`LP@0KW=e0`1^MGT4071iO@@0Lgf1101fPHH407N5RP@0
O8^A0`23TYL408bJX0@0UZ:X102R[K840;2h_0@0`<G7103@dM<30=kMg@@0j^SW103/j^T40>CRh@@0
fm[I103BdM430<W9b@@0`<30102g]kP40:j_[`@0YJJW102LWYl309>EU`@0Rhf?1023QHL407YmOaH0
oooo000D0?ooo`@0JVe_101RIFL405YMG`<0DUEG1019C4h40454AP@0>3/n100_<cD402HZ;0<0720S
100B5aT400T>4@@03aDG100I7Ah4028T9@@0:b`]0`0d<c<403Xh>0@0?C/l1012@40404M5A@@0BDQ9
0`1>CDh404m?D@@0DU9D101EEEL405MHFP@0FU]L0`1LGV04061RH`@0I6EW101WJF/406a^L0@0KW5c
101aMGP3079hN`@0MGao101hP8<407Z4R0@0OHR=1022SY<308^GV`@0UInS102OZ:`40:bc]P@0^[k0
1038bL/40=OFeP<0iN?R103Xi^D40>3OgP@0fMSH103BdM440<[9b@<0`L72102i^[X40;6b/P@0ZJZ[
102QXZ<409VKW0<0TI>D1029Rhd40864Q@@0NWan5P3oool001@0oooo101ZKFl4069UI`@0FUeO0`1B
EEL404U<CP@0@DA6100h>ch402lc=@@09RX/0`0L82<4018G6@@02@hA100?5AL401TM7P@08R@U100[
;2d303@c<`@0>SPh100m>c`40490@0@0AdE51019B4T304i=CP@0CdmA101BDU@405EEE`@0EeQJ101J
Fe`305aNH0@0H69S101TIFL406MYJ`@0K6i`101^LG<4075eN0<0LWQk101eO7l407R0P`@0NXB8101m
R8d408:>T`<0RiNK102EWj<409nX[0@0[;>f102j_/040<S9b`@0emKF0`3Uhn840>SVi@@0h=oN103I
f=P40=;Ad@@0b/W90`31`L840;Vj^P@0/K:b102YZZ/40:6RX`@0VI^L0`2ATi@408V;S@@0PHB5101j
O7hF0?ooo`00503oool406Y]K`@0HVEW101JGEl3059EE`@0BDa>1011A4H403Pk?P@0;c<e100V:R`3
01`P8`@04QLI10093Q4400lE5`@06AdN100R92D402//;@<0=3<c100j>3P403dk?0@0@T101017ADD4
04U8B@<0CTe>101?Ce44059BE0@0EEEG101GF5X405YKG0<0G5iP101PHV<406AUI`@0IfU[101/KW04
06iaL`@0LGEh0`1bN7/407ElO`@0N823101jQ8P407f8S@@0PXjC0`2;Ui/409FOX`@0WjR/102//kH4
0;Zn`0@0b<W;103Ge]H30>GShP@0j>KU103Pgmh40=WHf0@0d]7A103:bLT30<71`P@0^KZj102a/[84
0:VZZ`@0XJ:S102IVi`3096CU0@0RH^=1021Q8D407YlOQH0oooo000D0?ooo`@0JVe_101RIFL405YM
G`<0DUEG1019C4h40454AP@0>3/n100_<cD402HZ;0<0720S100B5aT400T>4@@03aDG100I7Ah4028T
9@@0:b`]0`0d<c<403Xh>0@0?C/l1012@40404M5A@@0BDQ90`1>CDh404m?D@@0DU9D101EEEL405MH
FP@0FU]L0`1LGV04061RH`@0I6EW101WJF/406a^L0@0KW5c101aMGP3079hN`@0MGao101hP8<407Z4
R0@0OHR=1022SY<308^GV`@0UInS102OZ:`40:bc]P@0^[k01038bL/40=OFeP<0iN?R103Xi^D40>3O
gP@0fMSH103BdM440<[9b@<0`L72102i^[X40;6b/P@0ZJZ[102QXZ<409VKW0<0TI>D1029Rhd40864
Q@@0NWan5P3oool001@0oooo101[KVl406=VJ0@0G5mQ0`1DEeT404e@DP@0ADQ:100m@4<403Dh>`@0
;C0c0`0T:2/401/P8P@04QLJ100?5AL401HK7@@07b<T100W:R`302la<P@0=SHg100h>CX403dm?P@0
@D941014ATP304Y;C@@0C4i@101@DU@4059DE`@0EUQK101IG5h305eOH@@0HF=U101UIfT406Q[K0@0
KG1a101aLgD407EhNP<0MGYm101iOh4407b2Q@@0OHJ91021Rhh408VBU@<0TYZN102MY:L40:R][`@0
];Ni1031`/840<k=c@@0fmWH0`3Uhn<40=gLg0@0e]GE103@cll40<W8b0@0`L710`2j^[/40;>c]0@0
Zjb]102TYJH409fNW`@0UINH0`2>T94408N9R`@0P8>4101iO7dF0?ooo`00503oool406]^K`@0HfIX
101LGf4305AGF@@0CE1B1015B4X403e0@`@0=CPk100]<3<302@X:`@06b0R100B5aX400lE5`@05Q/M
100O8b@402LZ;0<0;c4b100f=SL403Pi>P@0?Cdn1011@T@404A6B0<0BT]=101<CU04051BE0@0DUAG
101FF5/405ULGP<0GEmQ101QHfD406EWJ@@0J6]/101]L744075cM@@0MGQj0`1eNWd407UoP@@0O8:5
101mQXT4086;SP@0RI:E0`2BVYh409fTY`@0Z:f_102d]kT40<72`P@0c/g=103KfMP30>GSh`@0gMcL
103FeMD40=3?c`@0bLS81031`L430;Zj^`@0/k>d102[[:d40:BUYP@0WIjO102EUiP308j@T@@0QhV;
1020Ph@407UlOAH0oooo000D0?ooo`@0Jfi_101SIVP405aOH@<0E5MI101=D58404E8BP@0?D13100e
>3/402d`<`<092P[100K8284018G6P@03aDG100F6ad401lS90@09bX/0`0_<C8403Hf=`@0>3Tj100m
?Ch40452A0@0A4I80`1:Bdd404a>D0@0D59D101BE5L405IHF`@0FEaN0`1MGf44065SI@@0IFMY101X
Jf`406e`L@@0LG=e101eN7X307EjO@@0NGn1101lPXD407f6R@@0PH^>1029TYD309:JWP@0WJBW102X
[Jl40;Bg^@@0`L;2103>cLd40=_If0<0iN?S103Mg=`40=KEe@@0d<o?1039b<P40<71`@<0^[Zk102c
/k@40:^/[@@0Y:FV102MWYl409FGV0<0SY2A1027RH/40823Q0@0NGam5P3oool001@0oooo101[KW04
06AXJ@@0GV5S0`1GFU`4051CE@@0BDa?1012ATP403/n@@@0<cLj0`0/<3<402@Y:`@07B8U100F6ah4
01@J7@@06b4T100T:2X302d`<P@0<cDg100f>C/403Tl?P@0?T531011A4L304I9C0@0Bdi@101>DE@4
059EF0@0EUUK101IG5l305ePHP@0HFAV101VJ6X406Y/KP@0Kg5c101dMWL407QkO0<0NWj0101mPH<4
07j3Q@@0P8N:1026SY0408jEU`<0V9fO102SYjT40:na/P@0^KZj1036a<@40=;?c`@0fmWI0`3JfMT4
0=?BdP@0c<c<1036a/H40<30`0@0^KVj0`2c/k@40:b][P@0YJNW102OX:4409RJV`@0TYBE0`2;SXl4
08F7R@@0Oh63101hNgdF0?ooo`00503oool406]^L0@0I6QY101NHF<305MJG0@0D5=E1019C4l40496
B0@0>ci1100c=cX302``<`@092T[100M8RD401HK7P@051XM100K8B@402@X:P<0;C0b100c=CL403Hi
>`@0>C`n100n@D<40454A`<0ATU<101;CU0404iAE0@0DUEH101FFE/405ULG`<0GF1R101QI6H406IX
JP@0JVa^101_LG<407AfM`@0N7]l0`1jOX0407f1P`@0OX>51020QhX408J>T0@0SYFG0`2HWIl40:>W
Z@@0[k6b102i^[X40<K4a0@0d/o?103KfMT30=[If@@0dm;B103<c<`40<K6aP@0`<30102i^KX30;>c
]0@0[:f^102UYjL409nPX@@0V9ZK102BU9D308^>S`@0QHN9101oPH<407QkOAH0oooo000D0?ooo`@0
Jfi`101TJ6T405iQH`<0EeYL101@DeD404U<C`@0@TI8100k?T4403<g>P<0;30c100T:B/401dR9@@0
5Q/N100D6Qd401/Q90@092PZ0`0]<38403<e=`@0=STk100i?3h403i1@`@0@DA70`16BD`404]>D0@0
CU5D101BEEP405IIF`@0FEaO0`1MH684065TIP@0IVQZ101ZK6h406maL`@0M7Ig101hNg`307YnP0@0
OH63101nPhD40827RP@0QXj@102>UIL309RMW`@0XjNY102_/K840;Vj^P@0a/C4103Bcll40=_If@<0
f]WI103Cd]840<c<c0@0a/K61030`<040;Vi^P<0/k>d102/[Jh40:FWY`@0Wj2Q102HVY/409:DU@<0
Rhj?1025QhT407n1P`@0N7]m5P3oool001@0oooo101[KW0406AXJ@@0GV5S0`1GFU`4051CE@@0BDa?
1012ATP403/n@@@0<cLj0`0/<3<402@Y:`@07B8U100F6ah401@J7@@06b4T100T:2X302d`<P@0<cDg
100f>C/403Tl?P@0?T531011A4L304I9C0@0Bdi@101>DE@4059EF0@0EUUK101IG5l305ePHP@0HFAV
101VJ6X406Y/KP@0Kg5c101dMWL407QkO0<0NWj0101mPH<407j3Q@@0P8N:1026SY0408jEU`<0V9fO
102SYjT40:na/P@0^KZj1036a<@40=;?c`@0fmWI0`3JfMT40=?BdP@0c<c<1036a/H40<30`0@0^KVj
0`2c/k@40:b][P@0YJNW102OX:4409RJV`@0TYBE0`2;SXl408F7R@@0Oh63101hNgdF0?ooo`00503o
ool406a_L@@0IVU[101PHfD305YMG`@0E5MI101=DE<404M;C@@0@DE7100j?T4303@h>P@0;C8d100W
;2l4024V:@@06b4T100J82<4024W:P<0:Rha100a=CL403Hj?0@0>Cdo100l@4<403m4B0<0A4U<101:
CU4404eBE@@0DUII101FFEd405UMH0<0GV5S101SIFP406MYJ`@0K6i`101`LW@407IhN@@0Ngeo0`1n
P8840863Q0@0P8B61023RHX408^@T@@0TIJH0`2JWZ040:NYZP@0/k>c102m_;`40<O5a0@0d]3?103C
d]830<g=c0@0alO71032`/840;bl_@@0]kNg102a/[830:^/[@@0YZNW102PXJ8409ZLW0@0U9JG102>
T98308V;S0@0PhF7101mP84407QjO1H0oooo000D0?ooo`@0K6ma101VJF/4061SI@<0FUeO101DEeT4
04eAD`@0Ad]=1011ADL403Xn@@<0=3Pj100]<S@402L/;`@08BHY100K8B@401XP8`@08BLZ0`0Z;S44
034e=`@0=SXl100i?Cl403a0@`@0?dA80`14BD`404Y>D@@0CE9E101BEUT405IIG@@0FEeP0`1NHF<4
06=UJ0@0IfU[101/KW04071bM0@0MWQi101kOGl307j0PP@0PH>41020Q8H408>9RP@0Ri2A102AUYP3
09ZNX0@0YjVZ102c/k<40;fl_0@0alG4103Bd<l40=?BdP<0cLg<1037alL40<;2`P@0_;bm102g]kL4
0;6b/P<0Zjb]102VYjL40:2QXP@0VYbL102DUYL408j@TP<0RH^<1023QHL407f0P@@0N7Yl5P3oool0
01@0oooo101/Kg4406IYJ`@0H6=U0`1JGEl405AGF@@0CE5C1017Bdd40455A`@0>Si10`0d>3X402db
=0@09b`_100Q9RT401/Q90@06R0S100Q9bX302X^<@@0<CDg100f>S`403Tm?`@0?413100oA4P304A9
C0@0BTiA101=DUD4059FF@@0EUUM101IGF0305iQH`@0HfEX101WJF/406a^L0@0L79d101fN7T407]m
O`<0OX221021Ph@40824QP@0PhV:102;T944096FV0<0VYjP102WZJX40;>c/`@0_Kbl1037aL@40=;@
c`@0dm;B0`3=cL`40<O7a`@0`/;2102l_;d40;Ng]`@0/K:b0`2[[:d40:JWY`@0X:6R102JW9`409BF
U`@0SY2B0`29Rh`408>5Q`@0OH21101hNW`F0?ooo`00503oool406a_L@@0IVU[101PHfD305YMG`@0
E5MI101=DE<404M;C@@0@DE7100j?T4303@h>P@0;C8d100W;2l4024V:@@06b4T100J82<4024W:P<0
:Rha100a=CL403Hj?0@0>Cdo100l@4<403m4B0<0A4U<101:CU4404eBE@@0DUII101FFEd405UMH0<0
GV5S101SIFP406MYJ`@0K6i`101`LW@407IhN@@0Ngeo0`1nP8840863Q0@0P8B61023RHX408^@T@@0
TIJH0`2JWZ040:NYZP@0/k>c102m_;`40<O5a0@0d]3?103Cd]830<g=c0@0alO71032`/840;bl_@@0
]kNg102a/[830:^/[@@0YZNW102PXJ8409ZLW0@0U9JG102>T98308V;S0@0PhF7101mP84407QjO1H0
oooo000D0?ooo`@0KG1a101WJf`4069UI`<0GF1R101GFed4059EE`@0C51B1017Bdd40455A`<0?412
100f>cd4034f>0@0;34c100W;2l8024W:P<0:2hb100`=CP403Ll?P@0>Sm2100m@TD403m5B@<0A4Y>
101:Ce<404iCEP@0DUMJ101FFUh405UNH@<0GV9U101SIVT406Q[K@@0KW1a101aLg@407MiN@@0OGio
0`21PH8408>4Q@@0PXF71026RX/408fATP@0U9NH0`2NX:040:ZZZP@0];>c102o_Kd40<K4a@@0b/[9
1035aLD30<71`@@0_;fm102h^;P40;>c]0@0[Zn_102YZZ/30:BUYP@0Wj2Q102JW9`409FGV0@0T9:C
102;SHh308J8R@@0PH>5101lOh0407MjNaH0oooo000D0?ooo`@0KG1a101WJf`4069UI`<0GF1R101G
Fed4059EE`@0C51B1017Bdd40455A`<0?412100f>cd4034f>0@0;34c100W;2l8024W:P<0:2hb100`
=CP403Ll?P@0>Sm2100m@TD403m5B@<0A4Y>101:Ce<404iCEP@0DUMJ101FFUh405UNH@<0GV9U101S
IVT406Q[K@@0KW1a101aLg@407MiN@@0OGio0`21PH8408>4Q@@0PXF71026RX/408fATP@0U9NH0`2N
X:040:ZZZP@0];>c102o_Kd40<K4a@@0b/[91035aLD30<71`@@0_;fm102h^;P40;>c]0@0[Zn_102Y
ZZ/30:BUYP@0Wj2Q102JW9`409FGV0@0T9:C102;SHh308J8R@@0PH>5101lOh0407MjNaH0oooo000D
0?ooo`@0KG1a101WJf`4069UI`<0GF1R101GFed4059EE`@0C51B1017Bdd40455A`<0?412100f>cd4
034f>0@0;34c100W;2l8024W:P<0:2hb100`=CP403Ll?P@0>Sm2100m@TD403m5B@<0A4Y>101:Ce<4
04iCEP@0DUMJ101FFUh405UNH@<0GV9U101SIVT406Q[K@@0KW1a101aLg@407MiN@@0OGio0`21PH84
08>4Q@@0PXF71026RX/408fATP@0U9NH0`2NX:040:ZZZP@0];>c102o_Kd40<K4a@@0b/[91035aLD3
0<71`@@0_;fm102h^;P40;>c]0@0[Zn_102YZZ/30:BUYP@0Wj2Q102JW9`409FGV0@0T9:C102;SHh3
08J8R@@0PH>5101lOh0407MjNaH0oooo000D0?ooo`@0KG1a101WJf`4069UI`<0GF1R101GFed4059E
E`@0C51B1017Bdd40455A`<0?412100f>cd4034f>0@0;34c100W;2l8024W:P<0:2hb100`=CP403Ll
?P@0>Sm2100m@TD403m5B@<0A4Y>101:Ce<404iCEP@0DUMJ101FFUh405UNH@<0GV9U101SIVT406Q[
K@@0KW1a101aLg@407MiN@@0OGio0`21PH8408>4Q@@0PXF71026RX/408fATP@0U9NH0`2NX:040:ZZ
ZP@0];>c102o_Kd40<K4a@@0b/[91035aLD30<71`@@0_;fm102h^;P40;>c]0@0[Zn_102YZZ/30:BU
YP@0Wj2Q102JW9`409FGV0@0T9:C102;SHh308J8R@@0PH>5101lOh0407MjNaH0oooo000D0?ooo`@0
KG1b101YK6h406AXJ@<0H6=U101KGV0405IJG0@0DUEG101=DE<404Q<CP<0A4Q:100o@dH403Xo@@@0
=S/m100b=cT402dc=P@0:Bha0`0Y<3<4030f>P@0>3e1100n@dH40416B@@0@TQ;0`17C50404eBE@@0
D5EH101DFE`405ILG`@0FUmR0`1OHfH406AWJP@0JFa^101_LG84079dM@@0N7Ui101jO7d308:2PP@0
PX>41023QXL408V<S0@0Si6B102GVIT30:2QX@@0ZJVY102e/k<40;fl_0@0_[jo102l_Kd40;Vi^P<0
]KJf102a/[840:f^[`@0ZJZ[102UYZL40:6RX`<0WIjO102HVY/409BFU`@0T9:C102<SXl408N:R`<0
PhF7101oPH<407YmO`@0MWUk5P3oool001@0oooo101]L78406U/KP@0I6QY0`1PHfD405]NH0@0EUYL
101BEEL404eAD`@0B4a>0`14B4X403m3AP@0>Sm1100f>cd4038g>@@0;C<f100Y;S4302T`<`@0<3Hj
100h?D4403i3AP@0@4I91012B4/304M<D0@0CE9E101@EEP405AIG0@0EUaO101JGf8305mSIP@0I6MZ
101YK6h406maLP@0LWAe101hNGT407YlO@<0PX:21022Ph@408>6Q`@0RHb<102?TI8409NIV@<0X:6Q
102YZJT40;Fc/`@0_Kbl102n_[l40;bm_@@0^KVj0`2e][H40;6b/P@0[Jj_102YZZ/40:FVY`@0XJ:S
0`2MWYl409RJV`@0U9JG102@TY<408b>S`@0QhZ;0`23QHL407n1P`@0NWeo101fNG/F0?ooo`00503o
ool406e`LP@0JFa^101TJ6T3061SI@@0FeiP101FFU`4059EE`@0CE5C1018C4h304A8BP@0?d=6100j
?d4403Hk?@@0<SLi100]<cH402T^<@<0:C0c100`=SX403Pm@@@0?T=61010ATT40498B`<0Ada@101=
DUD4051EF0@0E5UL101FG5l405YOHP<0Gf=V101TIfX406U/KP@0Kg5b101bM7D407QiN@@0NWam0`22
PX8408:3Q0@0PhJ71029S8`408nATP@0UiVI0`2PXJ440:VYZ@@0]K>c102m_;`40;jn_`@0_;fm102i
^KX30;Ff]P@0/K:b102][Zl40:VZZ`@0YJJW102QXZ<309fNW`@0V9ZK102DUYL4092BT`@0S8j?1027
RX/308>5Q`@0Oh63101jOGl407IiNaH0oooo000D0?ooo`@0KG1b101YK6h406AXJ@<0H6=U101KGV04
05IJG0@0DUEG101=DE<404Q<CP<0A4Q:100o@dH403Xo@@@0=S/m100b=cT402dc=P@0:Bha0`0Y<3<4
030f>P@0>3e1100n@dH40416B@@0@TQ;0`17C50404eBE@@0D5EH101DFE`405ILG`@0FUmR0`1OHfH4
06AWJP@0JFa^101_LG84079dM@@0N7Ui101jO7d308:2PP@0PX>41023QXL408V<S0@0Si6B102GVIT3
0:2QX@@0ZJVY102e/k<40;fl_0@0_[jo102l_Kd40;Vi^P<0]KJf102a/[840:f^[`@0ZJZ[102UYZL4
0:6RX`<0WIjO102HVY/409BFU`@0T9:C102<SXl408N:R`<0PhF7101oPH<407YmO`@0MWUk5P3oool0
01@0oooo101^LG<406Y^K`@0IVY/0`1SIVP405mRI0@0FeiP101GFed405=GF@@0Ce=E0`1;Ce8404Q<
CP@0A4Q;1010ADL403e1A0@0>Ci1100f>ch3038h>`@0=3Xn100i?d840415B@@0A4Y=1018CU4304aA
E0@0D5EH101DFE`405IKGP@0FEiR101MHFD3065UI`@0I6MZ101YK6h406maL@@0LgAf101gN7P407Yk
N`<0PH611022PX<408F6Q`@0RXb<102?TY8409RIV@<0X:2P102UYZL40;>b/P@0];Be102a/[840:n`
/0@0[Jf^0`2ZZj/40:NXZ0@0XjBU102PXJ8409fNW`@0VI^L0`2FUiP409:DU@@0SY2B102;SHh408N:
R`@0Q8J70`20Ph@407eoP@@0NGam101eN7XF0?ooo`00503oool406iaL`@0JVi_101VJV`306=VJ0@0
Gf9T101KGV0405MKG@@0DeMI101?DeD304]?DP@0B4a>1014B4/40415A`@0?D54100i?T4403Hk?P<0
<SPk100d>Sh403To@P@0@4E91014BTd404Q>D@<0C55D101@EEP405AIG0@0EU]N101IGV8405eQI@<0
HFEW101TIfX406U/KP@0Kg5a101cM7H407MhN0@0NW]k0`21PH4408:2P`@0QHJ7102:S8`408nBTP@0
V9VI0`2PX:040:FVY`@0/k:b102d];D40;6b/P@0[k2`102][Jh30:Z[Z`@0YjRX102SY:D40:2QXP@0
WIjO102IVi`309JGV0@0TYBE102>T98408^=SP@0QhZ;1024QXL30823Q0@0OGn1101iO7d407EhNQH0
oooo000D0?ooo`@0KW5c101ZKVl406IZK0<0HfIX101OHV@405]NH0@0Ee]M101CEeT404mCE@<0BdmB
1018C4h404A8B`@0@4E7100m@D@403Tn@@@0=S/n0`0b>3/403@j?P@0>Cm21010ADT404A:C@@0B4iA
0`1<DE@4051EF0@0E5UL101FFeh405UNHP@0GF5U0`1QIFL406AWJP@0JFa^101_LG4407=dMP@0MgQh
101jNg/30861P@@0PX:31025QXL408Z<S0@0Si:B102HVIT30:2PX0@0YJJW102c/[840;Bd]@@0/K:b
102_/;040:f][P<0ZZ^[102WZ:P40:>TY@@0X:6R102MWYl409VKW0<0UYNH102BU9D408j@TP@0Rhf>
1027RX/408B6Q`<0P8>4101mOh4407UlO@@0MGQj5P3oool001@0oooo101^LG<406Y^K`@0IVY/0`1S
IVP405mRI0@0FeiP101GFed405=GF@@0Ce=E0`1;Ce8404Q<CP@0A4Q;1010ADL403e1A0@0>Ci1100f
>ch3038h>`@0=3Xn100i?d840415B@@0A4Y=1018CU4304aAE0@0D5EH101DFE`405IKGP@0FEiR101M
HFD3065UI`@0I6MZ101YK6h406maL@@0LgAf101gN7P407YkN`<0PH611022PX<408F6Q`@0RXb<102?
TY8409RIV@<0X:2P102UYZL40;>b/P@0];Be102a/[840:n`/0@0[Jf^0`2ZZj/40:NXZ0@0XjBU102P
XJ8409fNW`@0VI^L0`2FUiP409:DU@@0SY2B102;SHh408N:R`@0Q8J70`20Ph@407eoP@@0NGam101e
N7XF0?ooo`00503oool406mbM0@0K6ma101YK6h306IYJ`@0HfIX101PHfD405aPHP@0FEeO101FFU`3
05=GF@@0D5AF101=DE@404Y?D@@0B4a>1015BT`40497BP<0@4I9200oADP40457B`@0BDiB101=DeL3
05=GFP@0EEYM101HGEl405UNH@@0GF5U101PI6L306=VJ0@0I6MZ101YK6l406e`L@@0LWAe101fMgL4
07YkN`<0OWmo1022PX8408F6QP@0RH^;102?TI8409FFUP<0W9fN102RXj@40:RYZP@0YZNX102TYJH4
0:>TY0@0X::R0`2NX:0409bMWP@0VI^L102GV9T409BFU`@0TI>D0`2>T94408b>S`@0RH^<1026R8T4
08>5Q`@0P8>40`1mP84407YmO`@0N7Yl101eN7TF0?ooo`00503oool406mbM0@0K6ma101YK6h306IY
J`@0HfIX101PHfD405aPHP@0FEeO101FFU`305=GF@@0D5AF101=DE@404Y?D@@0B4a>1015BT`40497
BP<0@4I9200oADP40457B`@0BDiB101=DeL305=GFP@0EEYM101HGEl405UNH@@0GF5U101PI6L306=V
J0@0I6MZ101YK6l406e`L@@0LWAe101fMgL407YkN`<0OWmo1022PX8408F6QP@0RH^;102?TI8409FF
UP<0W9fN102RXj@40:RYZP@0YZNX102TYJH40:>TY0@0X::R0`2NX:0409bMWP@0VI^L102GV9T409BF
U`@0TI>D0`2>T94408b>S`@0RH^<1026R8T408>5Q`@0P8>40`1mP84407YmO`@0N7Yl101eN7TF0?oo
o`00503oool406mbM0@0K6ma101YK6h306IYJ`@0HfIX101PHfD405aPHP@0FEeO101FFU`305=GF@@0
D5AF101=DE@404Y?D@@0B4a>1015BT`40497BP<0@4I9200oADP40457B`@0BDiB101=DeL305=GFP@0
EEYM101HGEl405UNH@@0GF5U101PI6L306=VJ0@0I6MZ101YK6l406e`L@@0LWAe101fMgL407YkN`<0
OWmo1022PX8408F6QP@0RH^;102?TI8409FFUP<0W9fN102RXj@40:RYZP@0YZNX102TYJH40:>TY0@0
X::R0`2NX:0409bMWP@0VI^L102GV9T409BFU`@0TI>D0`2>T94408b>S`@0RH^<1026R8T408>5Q`@0
P8>40`1mP84407YmO`@0N7Yl101eN7TF0?ooo`00503oool4071cM0@0KG5b101[KW0306U/KP@0IVY/
101TIfT4069UI`@0Gf=U101MHF<305]NH0@0FEaN101FFU`405AHFP@0DUII101@EEL404mCEP<0CE9E
201<DE@404]@E0@0D5EH101CFE`305MKGP@0G61R201NHVD4061TI`@0HVIX0`1TJ6X406MZK0@0JVi_
101]L744075dM0@0M7Ig101iNW/307amO@@0P8201024QHD408N8RP@0Si2A102ATY<309FGU`P0VI^K
102HVY/409NIVP@0UYRI102EUYL309>EUP@0TI>D102?TI8408f?T0@0Rhf?1029Rhd308N9R`@0QHN9
1023QHL40863Q@@0Oh63101mOh4307YmO`@0N7]m101fNG/407AgNAH0oooo000D0?ooo`@0L7=d101]
LG8406]^L0<0JFa^101VJV`406AWJ@@0HVEW101OHfD405eQH`<0FeiP101IG5h405IJG0@0E5QJ101B
EUT4051EE`@0Ce=F0`1=DUD804aAE0@0Be1D101@EEP405=IG0<0Ee]N101LH68805iRI@@0H6AW101R
IVP306AXJP@0IfY/101ZKVl406e`L@@0LGAd101dMWL407UjN`<0O7em1020P80408B5Q@@0QhR:102?
T944096BT`<0UING202IVi/409RJV`@0UiVJ102FV9T409FFU`<0TiFF102ATi@408nATP@0SHn@102;
SHl408V;S@<0QhV;1025QhT408>5Q`@0PH>5101oPH<407eoP@<0NWeo101hNgd407IiN`@0M7Mi5P3o
ool001@0oooo101`Lg@406eaLP@0Jfi`0`1YK6h406IZK0@0I6MY101RIFL405mSI@@0GF5S0`1KGV04
05ULGP@0EUYL101DF5X4059FF@@0D5EG101?DeH304eBE@P0C55D101;D5@4051EF0@0DeUL0`1GFeh4
05aPHPP0GV9U101PI6L4069VJ0<0I6QZ101WJV`406Y^K`@0KG1a101aM7@407AfM`@0NGYk0`1lOGd4
0820P0@0Q8F51027R8X408n@T@@0TI:C0`2EUiL809VKV`@0V9ZK102GVIX409JHV@@0UIJG0`2CUIH4
096CU0@0Si6B102=Si0408^=S`@0RH^=0`27RH/408F7R@@0PhF71021PhD407n1P`@0OGn10`1jOGl4
07QkO@@0MWUk101dMgTF0?ooo`00503oool4071cM0@0KG5b101[KW0306U/KP@0IVY/101TIfT4069U
I`@0Gf=U101MHF<305]NH0@0FEaN101FFU`405AHFP@0DUII101@EEL404mCEP<0CE9E201<DE@404]@
E0@0D5EH101CFE`305MKGP@0G61R201NHVD4061TI`@0HVIX0`1TJ6X406MZK0@0JVi_101]L744075d
M0@0M7Ig101iNW/307amO@@0P8201024QHD408N8RP@0Si2A102ATY<309FGU`P0VI^K102HVY/409NI
VP@0UYRI102EUYL309>EUP@0TI>D102?TI8408f?T0@0Rhf?1029Rhd308N9R`@0QHN91023QHL40863
Q@@0Oh63101mOh4307YmO`@0N7]m101fNG/407AgNAH0oooo000D0?ooo`@0L7Ae101_LW@406eaLP<0
K6ma101ZKFl406U/KP@0IfY/101VJF/406AWJ@<0HfIX101QIFH4061SI@@0GV9T101MHF<405aPHP@0
FemQ0`1JGV0805UMH0@0FEiQ101KGf8405aQI0<0GF5T101SIVP406EXJ`@0I6MY101UJ6X406AXJ`<0
IVY/101ZKFl406a_L0@0KW5b101aM7D407=fMP@0MWQi0`1iNg/407anO`@0PhB51023Q8H408R:R`@0
RH^<0`29S8d408^=SP@0Rhj?202;SHh408Z<S@@0RH^<0`28RX/408N9RP@0QHR91024QhP408>5Q`@0
PHB50`20Ph@407n1P`@0OH21101lOh0407YmO`@0NGam0`1hNW`407IiN`@0MGQi101cMWPF0?ooo`00
503oool4071dM@@0Kg9d101]LG8306a_L@@0JVe_101YK6h406MZK0@0IVU[101TIfT306=VJ0@0HFEV
101PHfD405iRI0@0GF5S101LH68405]OH@<0FUiP201IGF0405UNH@@0FemR101LHF@305eQI0@0HfIX
101UJ6/406AWJ@@0IFQZ101TJ6/306IZK0@0JVe_101/Kg0406iaLP@0LGAe101cMWH407IhN@<0NG]k
101lOWl408>4Q@@0PhB61028RX/408V;S0<0RHb=102;SHh408^>S`P0Rhf>102:S8d408V;S0<0R8Z;
1027RHX408F8R@@0Q8N81023QHL40864Q@<0P8>4101oPH<407f0P@@0O7n0101jOGl407UlO@<0N7Yl
101fNG/407EhN@@0LgIh5P3oool001@0oooo101`M7D406mbM0@0KG5b0`1/Kg4406Y]K`@0JFa^101W
JV`406IYJ`@0I6MY0`1SIVP4065UIP@0H6=U101NHV@405eQH`@0G61R101KGf4305YNH0P0FEeP101I
GV4405]OHP@0G65T0`1MHF@406=VJ0@0IFQ[101TIfT406EXJP@0I6Q[0`1VJV`406Y]K`@0K6m`101^
LG84075dM@@0LgIf101fN7T307UkN`@0O7io1023Q8D408>4QP@0R8Z;1029Rh`308V<S@@0Rhf>102;
SXl808^=SP@0RXb=1029Rh`308R:R`@0QhV:1025R8T408B7R0@0PhF71021Q8D30823Q0@0Oh63101m
P84407aoP0@0NWeo101iO7d307QjO0@0MWUk101eN7T407=fN1H0oooo000D0?ooo`@0L7Ae101_LW@4
06eaLP<0K6ma101ZKFl406U/KP@0IfY/101VJF/406AWJ@<0HfIX101QIFH4061SI@@0GV9T101MHF<4
05aPHP@0FemQ0`1JGV0805UMH0@0FEiQ101KGf8405aQI0<0GF5T101SIVP406EXJ`@0I6MY101UJ6X4
06AXJ`<0IVY/101ZKFl406a_L0@0KW5b101aM7D407=fMP@0MWQi0`1iNg/407anO`@0PhB51023Q8H4
08R:R`@0RH^<0`29S8d408^=SP@0Rhj?202;SHh408Z<S@@0RH^<0`28RX/408N9RP@0QHR91024QhP4
08>5Q`@0PHB50`20Ph@407n1P`@0OH21101lOh0407YmO`@0NGam0`1hNW`407IiN`@0MGQi101cMWPF
0?ooo`00503oool4075dMP@0L7Ae101`Lg@306mbM0@0KW5c101]L78406e`L@@0K6ma101[KW0306Y]
K`@0JFe_101YK6h406Q[K@@0If]]101WJV`406IZK0/0IVU[201VJV`406M[K@<0J6a^101ZKFl406]^
L0@0JVi`101[Kg0706Y^L0@0KG1b101_LG84071cM0@0LGAf101cMGL407AfN0<0MWQi101hNg`407eo
P@@0O7j0101mOh0407f0P@<0OX22401nPH8407j0PP@0OH210`1mOh4407aoP0@0O7j0101kOWl407Ym
O`@0NWan0`1iO7d407QkO@@0N7Yl101gNW/407IiN`@0MGQj0`1eN7T407AgN@@0LgIh101cMWLF0?oo
o`00503oool4075dMP@0L7Ae101`Lg@306mbM0@0KW5c101]L78406e`L@@0K6ma101[KW0306Y]K`@0
JFe_101YK6h406Q[K@@0If]]101WJV`406IZK0/0IVU[201VJV`406M[K@<0J6a^101ZKFl406]^L0@0
JVi`101[Kg0706Y^L0@0KG1b101_LG84071cM0@0LGAf101cMGL407AfN0<0MWQi101hNg`407eoP@@0
O7j0101mOh0407f0P@<0OX22401nPH8407j0PP@0OH210`1mOh4407aoP0@0O7j0101kOWl407YmO`@0
NWan0`1iO7d407QkO@@0N7Yl101gNW/407IiN`@0MGQj0`1eN7T407AgN@@0LgIh101cMWLF0?ooo`00
503oool4075dMP@0L7Ae101`Lg@306mbM0@0KW5c101]L78406e`L@@0K6ma101[KW0306Y]K`@0JFe_
101YK6h406Q[K@@0If]]101WJV`406IZK0/0IVU[201VJV`406M[K@<0J6a^101ZKFl406]^L0@0JVi`
101[Kg0706Y^L0@0KG1b101_LG84071cM0@0LGAf101cMGL407AfN0<0MWQi101hNg`407eoP@@0O7j0
101mOh0407f0P@<0OX22401nPH8407j0PP@0OH210`1mOh4407aoP0@0O7j0101kOWl407YmO`@0NWan
0`1iO7d407QkO@@0N7Yl101gNW/407IiN`@0MGQj0`1eN7T407AgN@@0LgIh101cMWLF0?ooo`00503o
ool4075dMP@0L7Ae101`Lg@306mbM0@0KW5c101]L78406e`L@@0K6ma101[KW0306Y]K`@0JFe_101Y
K6h406Q[K@@0If]]101WJV`406IZK0/0IVU[201VJV`406M[K@<0J6a^101ZKFl406]^L0@0JVi`101[
Kg0706Y^L0@0KG1b101_LG84071cM0@0LGAf101cMGL407AfN0<0MWQi101hNg`407eoP@@0O7j0101m
Oh0407f0P@<0OX22401nPH8407j0PP@0OH210`1mOh4407aoP0@0O7j0101kOWl407YmO`@0NWan0`1i
O7d407QkO@@0N7Yl101gNW/407IiN`@0MGQj0`1eN7T407AgN@@0LgIh101cMWLF0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00V03oool2@00008H0oooo002J0?ooo`03@000003oool0oooo08<0oooo001l0?ooo`=00000
0P3oool00d000000oooo0?ooo`0:0?ooo`=000000P3oool2@00000<0oooo0d0000050?ooo`03@000
003oool0oooo07d0oooo001m0?ooo`06@000003oool0oooo@000003ooom000002P3oool01T000000
oooo0?oood000000oooo@00000@0oooo00A000000?ooo`3ooom00000Q@3oool007/0oooo14000003
0?ooo`03@000003oool0oooo00P0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A0
00000?ooo`3ooom00000Q@3oool007/0oooo00=000000?oood0000000P3oool2@00000`0oooo0d00
0000103ooom00000@000040000030?ooo`=00000Q@3oool007`0oooo0T0000020?ooo`03@000003o
ool0oooo00d0oooo00=000000?ooo`3oool0S@3oool007d0oooo00=000000?ooo`3oool00d00000<
0?ooo`900000S`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -23 0 ]
[.5 1.0125 23 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(90) show
81.000000 12.812500 moveto
(deg) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
105.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
89818089817F88807F88807F88807E887F7E887F7E877F7D877E7D877E7D877E7C877D7C867D7C\
867D7B867C7B867C7A867C7A867B7A857B79857B79857A78857A78857977857875
867A78857A79857B79857B79857B7A857B79857A79847A79847A79847A79837A79847A7A847B7A\
847C7B847D7C857E7D867F7E867F7F8780808781818783838884858986868A8889
8C8B8C8A87888A8585898484898383898383898383898382898282898281898281898281898281\
898281898181898180
89817F88807F887F7E877F7D877E7D867D7C867D7B867C7B857B7A857B79847A78847A78847977\
83787683787583777482767482767382757282747182747081736F81726E82706C
82726F8273718274728174728175738174738074727F73727F73717F73727E73727E74747F7575\
807777807879827A7B827C7C837E7E847F808581828684858887898A8A8C8C8E91
8D90938B8B8D8A888A898788898586898585888484888484888383888383888282898282898281\
898281898281898181
88807F887F7E877E7D867E7C867D7B857C7A857B79847978837977837775827775827674817572\
8074718073707F726F7F716E7E706D7E6F6B7E6E6A7E6D697E6C677E6A667E6963
7E6B677E6D6A7E6E6B7E6E6C7D6E6D7D6E6C7C6E6C7B6D6D7B6D6D7B6D6D7B6E6E7B70707C7272\
7D74747E75767E77787F797A807C7D817E8083828385858787898C8A8D918D9398
8D92968B8E918A8B8D89888A888788888687888586888485888484888384888383888382888282\
898282898281898281
88807F877F7D867D7C867D7B857B7A847A788379778277758176748175728074717F726F7E716E\
7E6F6C7D6E6B7C6D697B6B687B6A667A69647A67637A66617A65607A645E7A625C
7B65607A67637A68657A68667A6967796967796968796A697A6A69796A6A796B6B796C6D7A6E6F\
7A70717B71737B74767D78797E7B7D807E80828284848689868A8E898F948C959A
8B92968A8F92898C8F888A8C88888A888789878687878686888585888485888484888383888382\
888282898281898281
88807F877E7D867D7B857B7A847A788378768276748175727F73717E726F7D706D7C6E6B7C6C69\
7B6B677A696579676378666177645F76625D76615B765F5A765E58765D56765C55
775F5A77615C77625F766360766461766462756564756564756565756666756767766969776B6C\
776D6E7870717872747A75777C7A7C7D7D8080818483868A858B908891968B969C
8A9297898F93888D90878B8E87898C87888A878788878687878586878585878484888384888383\
888382888282898281
887F7E867D7C857C7A847A788378768176748074727F72707E706D7C6E6B7B6C697A6A67796864\
78666277646075625E74605B735E59725C56725A5471585271575072564F73564F
735953745B57735D59735E5B735F5D725F5E72605E71605F716060716161726363726465726667\
73696A736C6D746F7176747578787A7B7C7F7D818480868A838C9188939989959C
889297878F94878D91868B8F868A8D86888B868789868688878687878586878485878484888383\
888383888282898281
887F7E867D7B847B798378778176748074727F726F7D706D7C6D6A7A6B68796965776662766460\
75625D735F5A725D58715B557058526E564F6D534C6C514A6C4F476D4E46705149
71554F7157527058547059576F5A586E5A596E5A596E5B5A6D5B5B6D5B5B6D5D5D6D5F5F6E6162\
6E65666F686A706C6E727072757577777A7D7A7F827E858A828C9186939A86939A
869197868E94858D91858B8F858A8D85898C85888A868789868688868587878586878484878384\
888383888282898281
877F7D867C7B847A788277758075727F72707D706D7B6D6A7A6A6778686476656175635E73605B\
725D58705B556F58526D554F6C524C6A4F48694C4567494164443C6B4A416F5048
6E514C6E534E6D54506C54526B55536B55536A55546A555569555569555668575768595A685C5D\
6960616B64666C686A6E6D6F71737574787B787E827C84897F8B90849299849198
848F95848E93848C91848B8F848A8E84898C85888B85878A858789868688868586878485878485\
888484888382898281
877E7D857B7A8378778176747F73717D706E7B6D6A796A6778686476656174625D725F5A705C57\
6F59536D56506B534C6A5049684C4566494264463E624139613F37704D446E4E46
6C4F496B4F4A6A4F4C69504D68504E67504F66504F655050654F4F644F50635151635354645759\
655C5D6660626865676B6A6D6E7073717679757C807982877C888E818F96818E95
818D94828D92828C91828B90838A8E83898D84888C84878A858789858688868587868586878485\
878484888383898281
877E7D857B798278768075727E726F7C6E6B7A6B6878686476656174625D715E5A6F5B566D5852\
6B544E6A514B684E47664A4364473F62433B6140375E3B3269453B734F456D4C44
6A4B45684A46664B47654B48644B49634B4A624B4B614A4A60494A5F4A4B5F4C4D5F4F51605456\
61585A625D5F64626468686B6B6E716F7478737A7F7680857A868C7E8B927E8C93
7F8C927F8B92808B91818A90818A8E82898D83888C83888B84878A858689858687868586878485\
878484888383888282
877E7C847A798277757F73717D706E7B6D6978696676656274625E715E5A6F5B566D57526B544E\
68504A664C4564494162453D6041395E3D345B382E643F356F493F6C4940694841
6747416546416346426247446047456047465F46465E45465C43455C45475B484A5B4B4E5C5053\
5D56585E5A5D616063646669686C6F6C727670787D737E8377828979878E7C8B91
7D8B917D8B917E8A907F8A90808A8F81898E82898D83888C83878A848789858688868587868586\
878484888383888282
867D7C847A788176747E72707C6F6C796B6777676374635F725F5B6F5B566D57526A534E685049\
654C4563484061443C5E40375C3C335B382E603B306B443969443A68443B65443D
63433D61423C5F423E5E42405D43415C43425B42425A424359424358464758494A584D4F585152\
5955575A595B5E5F61616568656B6F6A71766E777C717C8175808777858C79888F
7A8A917B8A917C8A917D8A907F8A8F80898E81898D82888C83888B84878A858689858687868586\
878485888383888282
867D7C8379778075737D716E7B6D6A78696575656172605C6F5C586D58536A544E67504A654B45\
6247405F433B5D3F365B3A3158362D553127623B2F663F34654137644138614039
5F3F385C3D385A3D3A5A3F3D593F3F583F3F583F40574242564545554848564E4E565152555152\
56545657595B5B5E615F6567646A6D6871756C767B6F7B80727F8574838A76868E
798A927989917A89917C8A907D8A907F898F80898E81898D82888C83878B848789858688868586\
878485888383888282
867D7B8378778074727C6F6D796B6876676373625E705E5A6D5A556A555068514B654C46624741\
5F433B5C3E36593A3156352C5430265A3327673F33643E34623E34603E365E3D36
5B3B35583934563936563B3B553C3C523C3C564444574847564C4B564E4E564E4F534F50525152\
53575853595B575D5F5C6466626A6D6770756B767B6E7B806F7E8471828973848C
75878F7789917889917A8A917C8A907E8A907F8A8F81898E82898D83888B84878A858688868587\
878485878384888282
867C7B8278767F73707B6E6C786A6675656272605C6E5B576B575268524C654D476248425F433C\
5B3E3758393155342C5330274F2B215E372B643E32623D33603C335E3C355B3A34
5838325436325337355139385441405748475C4E4D584D4C564E4D544D4D524C4C525253535455\
525658515658545C5E5A6366616A6D65707569767B6C7A806D7D836E7F8770828A
72868E7489937589927889927B8A917D8B917F8A90808A8F82898E83898C84888B858789868687\
878586878484888282
857C7B8277757E72707A6D6A77686573635F705E5A6C595469544F664F49634A445F453E5C4038\
583A3254342C502F264F2B22502A20633C2F633D31603C325E3B335B3B34583933
553631513733523A38523E3D5B49475949475748475549485348465147464F47474F4B4D4F4D4E\
515253535657575D605A62655F686C646F7468767B6A797F6B7B826B7D856D8089
6F848D7187917388907689927A8B937D8C927F8B91808B90818A8F83898D84888B85878A868688\
878586878484888382
857C7A8176757D716F796C6975666372615D6E5C576A565267514C634C466047405D413A593C34\
55362E502F2649271D4A261C583125673F32623D325E3B325B3A32593A33563933
533732533B3756423F5949465C4D4B574B495448475247464F43434D43434C43444C47484C494A\
4E505250525554595D585F635E666B64707567767B68797F687980687B836A7F87
6C838C6E8690728993768B957B8E957D8D947F8D93808C91818B90838A8E84898C85888A868688\
878586878484888382
857C7A8076747C706E786A67746561705F5B6C595568544F654E496149435E443D5A3E37573931\
53332A4E2C2348251B532E23643C30643E325F3B325C3A32593A33563A34543833
513833513B385442405546445548465349475248475047464E46454B46454B47474A4A4A4B4E4F\
4C51524F525552585C565E625C666A64717566777B66787E66787F667A83677D86
6A818A6B838E6B848F758C957B90977D8F967F8E95808D93828C91838B8F848A8D85888B868789\
878687878485888383
847B7A8075737B6F6D77696672635F6E5D596A575366514C624C465F46405B4039583B3355362D\
523128502C23542E2261392C663F325F3C315C3A31593A33563A33543A34523934
4F3934503B3852423F5143415144434F45444E45444C44434A4242484342474545474748484B4C\
494E514C5356505B5D5662655C6B6F63737866787D65787E63787F637982657C86
67808A68828D69849079919B7C929A7E9199809097818F95828D93838C90848A8E85898C86878A\
878687878485888383
847B797F74727A6E6B75676571615E6C5B57685550634F496049435C433C583D3655383053332A\
512E24512B20542E225833285A382D5A392F583931563933533934513A344F3934
4E38344E3A374E3E3C4E413F4D42414C42414A414148414146404044404043414243444644484A\
454C4F4A52564E595D53606459686C5E6F7462757A62767E61767F617781637B85
657F8966818D66839079929D7E949E7F939B809199819096828E94838D92848B8F858A8D86888A\
878688878585888383
847A797E7472796D6A7466636F5F5C6A595565524E614C465D4540593F3955393252342C502F26\
4E2B204E291D4F2B20512E2453332A55362E5438315238325038334E38334D3733
4B37334B39364B3C394B3F3E4A403F483F3F473E3E443E3E433E3E403D3E403F4140424441464A\
444B4F4952564D595E52606557676C5B6D735E72795F737C5E747D5F7780617B85
647E8965818D6583907A939D7E959E80949D81939B829198839096838E93848C90858A8E86888B\
878788878586888383
837A797E7371786C697264626D5D5A685652634F4B5E494359423C553C3552362E4F30284C2B21\
4B261B4B261B4A271E4D2C2350322A52342D5036304F37314D37314B36324A3632
483632483834473937473C3B473F3E453E3E433D3D413D3E403C3E3D3B3D3D3D403D414440464A\
424A4F4751564B585E51606655666D596C735B70785B717A5B737D5D7680607A85
637E8966828D66839078919B7F97A081969F82959D82939A839197848F94848D91858B8F86898C\
878789878586888383
837A787D7270776A687163606B5B58655450604D485B4540563E395138314E312A4A2B2348261C\
46211745221946241B4A2D254E322B4E342D4D362F4B3530493530483430463430
453431443533433735443A39443D3D423C3C403B3B3E3A3C3C393B3A393B393A3D3A3F423C4449\
404A4F44515649585E4E5F6653656D556A72566D75576F7859727C5B757F5E7984
637E8967838F6D88937A929C8098A2839AA38397A083949C839299849096848E92858C8F868A8C\
878789888586888383
8279787C716F7569676F615E69595662514E5D4A4557423D523B354D332D492D2545261E421F16\
401B12401D1543251D482F274A322B4A342D49342E48332F46322E44312D43312E
42312F403330403534413939413B3C3F3A3B3D383A3B383A39363936363935383C373D42394247\
3D494E414F5547575E4C5F664F646C51676F526972536B75566E7959737E5D7883
627D8968838F6E899479939F849FAA89A1AA8499A283969E83939A849197848E93858C90868A8D\
87888A888687888384
8279777B706E7468666D5F5D6657545F4F4B594642533E3A4D3731482F294327213F21193C1A12\
3B19113C1F1741292147302949322C47322D46322D44312D42302C412F2C3F2E2C
3E2F2D3D302F3E33323E36373E383A3C383A3A373A39373A36353833353932373C343C41364147\
3B484E3F4F5746575F495D654B61694D636D4D65704F6873536C7856717D5B7682
607C8866838F6C879475919D7E9BA7819BA68299A282969F83949B849198848F94858D91868B8E\
87888A888687888484
8178777A6F6E7266646B5D5B6355525C4C4855433F4F3B3648322D432A243D221B381A1235160E\
3418103820183F2B2345312A46312C45312C43302C412F2B3F2D2A3D2C293B2C2A
3A2C2B3A2E2D3A30313A34353B36383A363938363936353933333830333830363B313B41354148\
39484F3E4F5742555D445962465D67485F6A49626D4B66714F6A76536F7B577581
5D7B8763818E6A8692728F9C7997A37D98A48098A28197A082949C849299849095858E92868B8F\
87898B888687888484
817877796E6D716563695C5961525059494651403C4A3733432E293D2520361C1630130C2B100A\
2B140E331F193E2B2544312B44312C43302C412F2B3E2D293B2B29392A28372929
362A2A362C2C3730303833343835373836393635393334383033372E33382D363B2F3A41324047\
36474E3A4C553D515B3F5660415964435C6745606B4864704C68754F6E7B547380
5A7986607F8C66838F6E8D997593A07C99A57F99A38197A182959D83939A859197858E93868C8F\
87898C888788888484
807776786D6C6F6462665A585E504D5546434D3C3945332F3E292536201B301712280E08220D08\
27151132201C402E2843322C43312D41302C3F2E2B3B2C29382A28352828332828
322829332A2B342E2F3631333734373635393435393234382E32372B31372A343B2C39402F3E46\
32454D354A53384E5839525D3C55613E5965415D6944616E4866734C6B7951717F
5777855C7C8A61818E6A8B9873929F7B9CA97E9AA68098A282969F83949B859298868F94878C90\
878A8C888788898484
807776766D6B6D62616458565A4D4B5143404838363F2E2B372421301B1729120E230B07200E0B\
28171434231F44322C45342E43322E41312D3E2F2C392B293428272F25252D2425
2C25272F282A322E2F35313336343736373B34373B31353A2D323829323728343A29383F2B3D46\
2E424C304751314A55344F5A37535F3957633D5C6841606D456573496A784E6F7D
537583587A885D7E8C6787967293A17B9EAB7E9CA8809AA48298A084959D859399869095878D91\
888A8D888789898484
7F7675756C6A6B615F615654574B494D403E433432392927301F1C291512220D091D0906180A08\
2217143526224836304736314535304233303E302E392D2B342A292F27282B2628
2B26292F2A2C333032353235363639383A3E35393E31373C2C333928323826333A26373F273B45\
2B414B2C45502E4854304C5832505D3554613B5A673F5F6D4263724668774A6D7C
5073825478875A7D8C6789987496A57CA0AF7F9EAA819BA68399A284969E86949A879196878E92\
888B8D888889898585
7F7675746B6A6A605E5F5453544847493C3B3E302F332422281816200F0C1C0805190907180D0B\
271C193A2B274D3A344A3A344737334335323F33313B302F372D2E362D2F312C2E
322D2F3832343B383A3D3B3D3F40433D4246373D4231393F2B343A27313924323A24353F233742\
273F4A26414D2643502847542E4D5B3253613959673C5D6C406271436776486C7C
4D7181507586567B8C6589997498A77DA3B17FA0AC829DA8849AA48598A087959B889297888F93\
898C8E89888A898585
7E7675736A69685E5D5D5351514645453A38392C2B2B1E1D1E100F11020114040215090918100F\
281E1C3D2E2A503E384D3C37493A364537354135343D33333A3232393133373133
3D3738423C3C4440414543444244473D4347373F4431393F2B343A26323924333C243740243A46\
27424E22404E1F404F2847562D4E5D2F51603758673B5D6C406271426777466B7C
496F804B7384527A8C648A9A7599A87EA3B180A1AD839EA9859CA58799A188969D899398899094\
898C8F89898A898585
7E7675726A69675E5D5B52514F45444237363429282519191106060B0000120706120B0B171112\
2A211F41322D55423C50403B4C3D3A4638374237363F36373C35363A35363A3538
3C383A403D3E4341444445474145493C4348373F45303A402A343C26333B23343D243842263C48\
28424E284350274553314E5B3352603656643E5D6B416170436676426879436B7C
456E80457083517A8C658A9A7799A87FA3B282A2AF85A0AB879EA7899BA38A989E8A959A8A9195\
8A8D908A898B8A8586
7D7675726A69665D5C5950504D43433F36353127272117170F0505110808150D0C1A1414201A1A\
34282547373258453F53433E4F413D4A3E3C463D3C41393A3D37383A3538383639
39383B3D3D403F40434043463F454A3B4349363F463039402A353D25343D23343E233743243C48\
27414E2945522E4A583853603B57643E5B6943616F436473416676406779406A7C
406C7F416E82527C8E688C9C799BA981A6B584A4B187A3AD89A0A98B9DA58C9AA08C969B8C9296\
8B8E918B8A8B8A8686
7D7574716968655D5C58504F4B43423E35352F27272017170F0707120B0B1711111F19182A2220\
3B2F2B4B3C375A48425646425144424D4341494140464041433F41403E41424043
43424445454845474A44484C42494D3B444A353E452F394129363E25353F233440213642213A47\
25404E2744522C495732505E3756643B5B6A3E606F3D61723D63763C65783C677B
3B697D3F6D82537E906D90A07A9BAA83A8B687A7B38BA5B08DA3AC8EA0A78E9CA28E989D8E9498\
8D8F928C8B8C8A8686
7D7574716968645C5C58504F4B43423D35352F272720181911090A140E0F1C1616251E1D302625\
3F33304F3F3B5B49435849455448454F46454B444548444546444646464847474A
46484B46494D454A4E43494D3E464B384148323C432D384028373F263640243743233A46233D4B\
23404F2342512947572E4D5D315262345767375B6C385E7039617439647739657A
36667C406F845780936D90A07699A87FA4B38BAAB68FAAB491A7AF92A3AA929FA5919A9F909699\
8E91938D8C8D8B8687
7D7574716968645C5C5850504B43433D36362F2829211A1B120C0D1711131F191A292121352B29\
44363351413D5C4A455A4C48564A485148484D47474A4647474548454649444649
43454941454A3F44493D4348394046343D442F39412B373F28363F253641253844243A48253E4C\
2844522947552B4A592A4C5C2C4F602E546632586A345C6F376175386378356479
33667C437287578295698E9F769AAA84A8B696B4BF96AFB997ABB396A7AE95A2A8949DA192979B\
9092948E8C8E8B8787
7D7574716968645D5C5850504B44443E373730292A221C1D150F101B1516211B1C2C2424382D2C\
45383651423E5A4A455A4D49574C4A524A494E48494A4749474648444548424447
3F43473D42463A4044373E43343C423039402C373F28343E26353F243641233744233A47233D4B\
2541502846552C4C5B305160325465335769365B6D365F72376176336277326479
34677E46768A5984976B92A27DA1AF8DAFBB9EBAC49EB5BE9DB0B89CABB19AA5AA979FA495999D\
9293958F8D8E8C8787
7D7575716969655D5D5851514B45453E3838312B2C241E1F1610121C1617231D1E2E2626392F2E\
4539364F423E5749455A4D4A584D4C534B4B4E494B4A484A4646494244473F4246
3C4044393E43363B41333A402F373E2C353D28333C25323C23333E223440213643213846213B4A\
233F4E25445429495A2D4F5F30536533586A345B6E335D72325F743061762F6379
366A804A798E5F899B7197A785A5B396B3BEA5BDC7A6BBC3A4B6BDA1AFB59EA9AE9BA2A6979C9E\
949597908E8F8D8888
7D7675716A69655E5E5952524C46463F393A322D2E2520211813141E1A1B2520212F282838302F\
4339374C413E554845594D4A594F4D544C4D4E4A4C49484A4545494042463C4044
393D42353A3F32383D2E363C2B333B27323A24303921303B20313D1F323F1E34421E37451E3A49\
1F3E4D224253254758284C5D2A50622C54672C576B2C5A6F2C5D722B5F752D637A
3A6E844F7E92638D9F779CAB8BAAB79FB9C3AEC3CCB1C4CBACBCC2A7B4B9A3ACB19EA5A89A9EA0\
969698918F908D8888
7D7675726A6A665F5F5A53534D4747413B3C342E302722231A1517211C1E282324302A2A393131\
433A394C4240554947594D4B5A504F544D4E4E4A4C48474A4344483E41453A3E43
353B4032373D2E353B2A323A263038232E37202D371E2D391D2F3B1C313E1B33411B35441B3848\
1C3C4D1F415221455723495C254D6126516527546929586E295B712A5E7531667D
43748A5784976B93A480A3B196B2BEABC1CAB9CCD4BCCDD3B4C2C7ADB8BDA7B0B4A2A7AA9D9FA2\
9898999390918E8989
7E7675726B6B6660605B54544F4849423D3E3630322924261C181A221F212A2527312B2C393232\
4139394C4240544847594D4B5A4F4E544E4F4D4A4C46464A4143473B3F44363B41
32383E2E343B293139262F37222C351F2B351C2A361A2B37192D3A192F3D183140183444193748\
193B4C1B3F511D43561F475A204B5F224E6324536825566D255A712A6077376B82
4A7A8F5F8A9D769BAB8CABB8A2BBC6B7CAD2C9D8DEC6D4D9BBC7CCB3BCC0ACB3B6A5AAAC9FA1A3\
99999A9491918E8989
7E7676736C6B6761615C5656504A4B443F403833342B26281E1A1D2521232C2729322D2E383233\
413B3B4B4242514847564D4B564E4E524E4F4B4A4D4445493E4146383D4333393F
2E353C293138252E35212B341D29321B2832182733172936162B39152D3D153040153344163748\
173A4C183D501A42551B465A1D4A5F1F4E6320526822566D265C732F647B3F7288
5382956A93A481A3B198B4BFAEC4CDC2D2D9D2DFE4C9D5D9C0CACEB7BFC2AFB5B8A8ACAEA1A3A4\
9B9A9B9592928F8989
7E7776736C6C6862625D5758524C4D4641423A36372E2A2C211E202824262E2A2B332F31393436\
413B3C4841414E4746524B4B514B4C4E4B4D48494C4244483B3F44353A412F363D
2A3139252E35202A331C2731182530162531142532122735122938122C3C122F40133244133648\
15394C163D5018415519455A1B495F1B4D631D516821566E285E7634698047798E
5D899C759AAB8BABB8A2BBC6BACCD5CFDCE1D9E4E8CDD7DBC3CCCFBAC1C4B2B7B9AAADAFA3A4A5\
9C9B9C9692928F8A89
7F7777746D6D6A63635F595A544F504944453E393B322E302522242B27292F2D2F353133393537\
3F3A3C4641414A45464D484A4C484A4B494C46474B3F4247373D4231383E2B333A
252E37202B331B273117253014232F1122300F22310E25340F28380F2B3C102E40103143113548\
13394C143D5115415617455A18495F194D641D51692258712D637B3E7187538296
6B93A481A3B398B4C0B0C5CFC9D7DEDFE9EDDEE8EBD1D9DCC6CDD0BDC2C5B4B8BAACAEAFA5A4A6\
9D9B9C969393908A89
7F7877756E6E6B6565615B5C5751524C4749413D3F3632342A27292D2B2D322F323633363A3739\
3E3B3D43404247444648464848464947474A4245493B3F45333A412D353D263039
202C361A283316253012222F0E202E0C202E0B21300B24340B27380C2B3C0D2E400E31440F3549\
11394D123D5213415615455B174A611A4F661F546C285E76376B81497A8F608B9E
789CAC8EADBAA5BDC8BECFD7D4E0E5E4EDF1DCE4E7D2D9DCC8CED0BFC3C5B6B8BAAEAEB0A6A5A6\
9E9C9C979393908A89
807878766F6F6D6667635D5E5954554F4B4C4541433B37392F2C2F302E313432353835383A393B\
3E3C3F4240434644474746494646494345493E4348373D442F373F28323B212D37
1A29341525321122300D202E091E2D061E2E0620310723350927390A2B3D0B2E410C32450E354A\
0F3A4E113E5313425815465D184B631D526924597131667D43758A5885986F95A7
86A6B59BB6C2B3C8D1CDDAE0E0E8ECEAF2F4DFE5E7D4D9DBCACED0C0C3C4B7B8BAAEAEAFA6A5A6\
9F9C9C979393908A89
8079787771706E68686560605C5758534E504A4647403D3F37343734323536353839383B3D3C3E\
3F3E4143424546454946464A45464A41444A3C4248333C442C363F24313B1B2B37
1527341023310B202F081E2E041C2D011C2D021F3105233507283A092C3F0A2F420B33470D374B\
0F3B5111405614455B174A611C4F6724576F2E62793F70865380936890A17FA0B0
95B1BEACC2CCC4D4DADBE4E8EDF4F6EEF4F6E0E5E7D5D9DACACDCFC0C2C4B7B8B9AFAEAFA7A5A5\
9F9C9C989392908A89
817A79797271706A6A6862635F5A5B5752544E4A4C4642453E3B3E36353838373A3B3A3E3E3E41\
40404343434747474A47484C46484D41464B3D434A353D462D384122313D172A38
1026340C2231082030041E2F001C2F001E30022234042639062A3D082E410A32460B364A0D394E\
103D5414435A1749601C4F6624566D2E61773C6E834F7C90638B9D799CAB8FADBA
A6BDC8BDCFD6D4DFE4E7EEF0F5F9FBEBF0F1E0E3E5D4D7D8CACCCDC0C1C2B7B7B8AFADAEA7A4A4\
9F9B9B989292908A89
817A797A7373726C6C6A6465635D5E5B5657534F514B484A4441443B393D3B3A3E3F3E41414144\
43434745454949494D494B4F474A4F42474D3E444B3840482F3B442434401A2E3C
1429380F26360B243507233503223504243706273A082B3E092E430B33470D364B0E394F113E54\
1543591A4A601F4F6626576D3060763D6D824D7A8D61899A7698A88CA9B6A2BAC4
B9CBD2D0DBE0E3EAEDF4F7F9F9FBFCEAEDEEDEE1E2D3D5D6C9CACBC0C0C0B7B6B6AEACADA7A3A3\
9F9B9A979292908A89
827B7A7B7474746D6E6D67676660615F5A5B585355514D4F4A47494341443F3D40424144444447\
47474A49494D4D4D514B4D51484B5043484E3E454C38414A313C47283843203341
1A303F172F3E122C3D0E2C3D0C2B3D0C2C3F0D2F410E324510364A123A4E143D521641561A465B\
1E4B612552682B596E356277406D804F798B6086977496A589A5B29EB6C0B5C7CF
CDD8DEE1E7EAF1F4F6FEFFFFF6F8F8E8EAEADCDDDED1D2D3C8C7C8BEBEBEB6B4B4AEABABA6A2A2\
9E9A99979291908989
837B7B7C7575766F6F6F696A696364625E5F5C5859565254504D4F4A484A44434645444748484B\
4B4B4E4C4D504E4F534C4E53494D53444A5041484F3C454E34414C2D3E49283B48
2338462138461C35451A354618354618364719384A1A3C4E1E405221455723495C254C60295165\
2F576B365F723E6779487082547A8B6487977594A389A3B09CB3BDB2C3CBC9D4D9
DFE5E8EFF2F3FEFFFFFDFEFEF0F0F0E4E4E5D9D9D9CFCECFC5C4C5BDBBBBB4B2B2ACA9A9A5A1A1\
9E9998979190908988
837C7B7D7676777171726C6C6C6667666162615C5D5B5759565355514E504B494C48474A4C4C4F\
4F4F524F50545051554F52564E5157484E54454C5340495138454F34444F30424E
2C404D2A3F4D263E4D263F4E253F4F2541512644542948582D4C5D30506133546536596A3C5E70\
4265764A6C7D5174845B7D8C6988967995A28AA2AD9CB0BAB1C0C7C6D0D5DCE1E4
EDEFF1FDFEFEFFFFFFF4F4F4E9E9E9DFDEDED5D4D4CBCACAC3C1C1BAB8B8B2AFAFABA7A7A49F9F\
9D989796908F908988
847C7C7E7877797373746E6E6F696A6A6566656061605C5D5C585A5754565351534E4D4F515153\
53535654545855565A54565B51555A4D5258495057454F573F4C563E4C563A4955
374855354854334855324856324A58344D5B37505E3A53623E5867415C6B4661704A6675506C7B\
5873815E7A8765818E6F8A977D95A18DA1AC9DAFB7B1BEC4C4CDD1D6DBDEE9EAEB
FBFAFAFFFFFEF5F5F4ECEBEBE2E1E1D9D8D8D0CECEC7C5C5BFBDBDB7B4B4B0ADACA9A5A5A29D9D\
9C9696958F8E8F8887
847D7C8079787B7474767070726C6C6D6869696465656162615D5F5E5A5C5A585A58575958575A\
59585B59595D5A5B5E595B5F585B5F55595F51575E4E565E4A545D48545D45525D
43525D41525D41535F415460435662455965485C684B5F6C5064705469755B6F7B5E7380657A86\
6B808B718691798D978497A093A3ABA2AFB6B3BCC2C4CACDD5D7D9E6E6E6F6F4F3
FEFDFCF6F5F4EDECEBE4E3E2DBDAD9D3D1D1CBC8C8C3C0C0BBB8B8B4B1B0ADA9A9A7A2A2A19B9B\
9B9594958E8D8F8887
857D7D817A797D7676797272756F6F716B6C6D68696A6566666264646061615E60605D5F5F5D60\
5F5E60605F626060636161646061655D60655A5F65595F65555D65545D66535D66
515D66515E67525F6952606A53616C55646E5867725C6B7560707A66757F6C7B8471818B798890\
7D8B948391998C9AA199A4AAA6AFB4B4BABFC4C7CAD3D4D5E2E0E0F0EDECFAF8F7
F7F6F6EDEBEBE4E2E2DCDAD9D4D2D1CCCAC9C5C2C2BEBBBAB7B4B3B1ADACABA6A6A5A09F9F9999\
999392948D8C8E8786
857E7D827B7A7E77777B7474777171746E6F716C6C6E696A6B6768696566676465666365666365\
66646666646767656867666A66676B66686C64676C64676C61666D60676E61686F
606870606971606A72616B74636D7566707869737B6D777F717B827680877C868D828B92878F95\
8C9499939BA09EA5A9A8ADB1B3B7BAC1C3C5D0CFD0DDDBDBEAE6E6F6F3F2F5F3F2
EBE9E9E3E1E0DBD9D8D4D1D0CDCAC9C6C2C2BFBCBBB9B5B5B3AFAEADA8A8A7A2A2A29D9C9D9796\
989191938C8B8E8786
867E7E837C7B8079787D76767A7474777171746F6F726D6D706B6C6E6A6B6D696A6C686A6B686A\
6B696A6B696B6C6A6C6D6C6F6E6E716F6F736E6F736E70746C70756D7176707379
70747A70757B70757C70767D72787F757B81787D847C828780858A858A8E898E928E9195929699\
94999C9B9FA3A5A9ABAFB1B4BDBDBECCC9CAD9D5D4E6E0DFEEEAE9F0EDECE7E5E4
E0DDDCD9D6D5D2CFCECBC8C7C5C1C1BFBBBAB9B5B4B3AFAEAEA9A9A9A4A3A49F9E9F9A999B9594\
96908F928B8A8D8685
867F7E847D7C817A7A7F78787C76767A7474787272767071746F6F736E6E726D6E716D6E716D6E\
716D6F716E7072707274727574737677757977777A77787C77787D797A7F7B7C81
7C7D817D7F837E80857E808681828784858A87888C8A8B8E8D8D919292949494979B9A9B9D9C9E\
A1A0A2AAA8A9B2B0B1BDBABAC9C5C4D3CECDE0D9D8E9E4E3E8E5E4E2DFDEDBD8D7
D4D1D0CECAC9C8C4C3C2BEBDBDB9B8B8B3B2B3AEADAEA9A8A9A4A3A59F9FA09B9A9C9696989291\
948E8D918A898D8584
877F7F857D7D837C7B817A797F78787D76767B7575797474787273777272767172767172757172\
7672737673747874767A77797F7C7E7F7D7F7F7D807F7E81808084848386888689
89888B88878B89888C8C8A8E908D90908D90918E919491929794959A96969C9899A29E9DA4A0A0\
A9A5A5B0ACACB9B4B4C3BDBCCDC6C5D3CDCCDFDAD8DFDBDAD8D5D4D3CFCECDC9C8
C8C4C3C3BEBEBEB9B9B9B4B4B4B0AFB0ABAAACA7A6A8A3A2A49E9EA09B9A9D9796999392968F8E\
938C8B8F88878C8584
87807F867E7E847D7C827B7B817A7A7F79787E78777D77767C76767B75757A75757A75757A7575\
7A75767B76777C78797E7A7C817D7F8481838683858885888A878A8D898C8E8B8D
8F8C8E908D8F938F91948F91948F90938F909792929893939A95949C9796A09B9AA49E9EA9A2A1\
AEA8A6B4AFAEBCB7B6C3BDBCCAC5C4D1CDCCD5D0CFCEC9C8C9C4C3C4C0BFC0BBBA
BCB7B6B7B2B2B3AEAEB0AAAAACA7A6A9A3A2A59F9FA29C9B9F99989C969599939296908F938D8C\
918A898E87868C8483
88807F877F7E857E7D847D7C837C7B827B7B817A7A8079797F79797F78787E78787E78787E7878\
7E79797F7A7A807B7B827D7D847F808682838A8586918C8D948E90938D8F948F8F
9691929791929790919690909690919791929A93939B95949F9896A19A98A39C9BA69F9DA9A3A1\
AEA8A7B2ADACBBB6B5C1BCBBC4C0BFC4C0BEC0BBBABDB8B6B9B4B3B6B0AFB2ADAC
AFAAA9ACA6A5A9A3A2A6A09FA39D9DA19B9A9E98979C9595999392979190958E8D938C8B918A89\
8F88878D86858B8382
88818087807F877F7E867E7E857E7D847D7C847D7C837C7C837C7B827B7B827B7B827B7B827B7B\
827C7C837C7C837D7D847E7F8680808882828A85858D8888908A8A938D8C989190
9892919790909891919791919690909790919791909992919B94939D96959F9897A19A98A49E9C\
ADA6A5B0AAA9B4AEACB2ADABB0ABAAB0AAA9AEA8A7ABA5A4A9A3A2A7A1A0A59E9D
A29C9BA09A999E98979D96959B9493999291979090968F8E948D8C938C8B918A899088888E8786\
8D86858C84838A8382
89818088818088807F87807F87807F877F7E867F7E867F7E867F7E867E7E867E7E857E7E857E7E\
867F7E867F7E867F7F8780808881808982818A83838B84848D86858E8786908988
908988908988918A89918A89928C8A968E8D978F8D98918F9992909A93919B94929D95949F9897\
A19A999E97969E97969D97969D96959C95949B94939A939299929198919097908F
968F8E958E8D948D8C938C8B928B8A918A899089888F88878F87868E86858D86858C85848C8483\
8B83828A83828A8281
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool408V1P0@0RH5o1`28
P7l408R0OPP0R7mn1027Ogd708MnO@@0Qgil1027OG`408ImO0@0QWek1026O7/708IlNP@0QW]j2025
NgT808EjN0<0QGUg1025N7D408IjN0@0QGYi2025NgT308EkNP@0QG]i1025NWT<08AjN@@0PgYi0`24
NWX408AkNP@0Q7ak1024OG`408EnO@@0QWmn0`26Ogl408N0P0@0Qh611027Ph<408R4Q@@0RHJ6102:
R8T308b;S0@0RXN8102:QHD408V4Q0/0RH>31029Ph8408V2PQ<0RH:11029PH4408V1P1H0oooo000D
0?ooo`@0RH601029PGl708R0O`@0R81n2028Ogh408MoO@L0Qgim1027OW`408MmO0@0QWel1026OG/4
08IlN`L0QWaj1026NgX808EkN@P0QGYh0`25NGL408EhM@@0QWYh1025NWT808EkN@<0QG]j1025NgT4
08EjN@`0Q7Yi1023NWT308AjNP@0Q7]j1024O7/408AmO0@0QGim1026Ogh308IoO`@0Qh201027PH44
08N3P`@0R8B51029QXH408Z8R@<0S8^<102:QhP408Z5Q@@0RHB42`29Ph<408V3PP@0RH:24`29PX44
08V1P@@0RH605P3oool001@0oooo1029PH0408V1O`L0R81o1028P7h808QoOP@0Qgmm1`27OWd408Mn
O0@0Qgel1026OG`408ImN`@0QWak1`26O7X408IkNPP0QG]i2025NWP308EiM`@0QGQe1026NWP408Ej
N@P0QG]i0`25NgX408EkN@@0QGYi3024NWT408=jN@<0Q7Yj1024NgX408AlN`@0Q7el1025OWd408Io
OP<0QWmo1027P80408N1P@@0Qh>31028Q8D408V6QP@0RXR90`2<Rh`408Z7R0@0RXF51029Q8@;08V3
P`@0RH>21029PX8C08V2P@@0RH611029PH0F0?ooo`00503oool408V1P0@0RH5o1`28P7l408R0OPP0
R7mn1027Ogd708MnO@@0Qgil1027OG`408ImO0@0QWek1026O7/708IlNP@0QW]j2025NgT808EjN0<0
QGUg1025N7D408IjN0@0QGYi2025NgT308EkNP@0QG]i1025NWT<08AjN@@0PgYi0`24NWX408AkNP@0
Q7ak1024OG`408EnO@@0QWmn0`26Ogl408N0P0@0Qh611027Ph<408R4Q@@0RHJ6102:R8T308b;S0@0
RXN8102:QHD408V4Q0/0RH>31029Ph8408V2PQ<0RH:11029PH4408V1P1H0oooo000D0?ooo`@0RH5o
1028P7l408QoOP<0Qgmm1027OWd408ImO0@0QWek1026O7/408EkNP<0QG]i2024NWP408AiM`@0PgQf
1023N7D408=gM0<0PWId1022MW<4089eLP@0PWAa1022M704085cK`<0PG9^1022L6`4089bK`@0PW=a
1022M784085dLP<0PGEc1021M7<4081dLP@0Og=b101oLg4407mcLP@0OW=b0`1nM7@407meM@@0P7Mg
1020N7T4089jN`@0PWal0`23OWh408AoP0@0QH621026Q8D408R7R@@0RXZ<102<SY4308f@T`@0Rh^=
102:R8X408V7R0@0RHF61029QHD708R4Q0P0R8>31028PX8408V2PP/0RH:11029PH4F0?ooo`00503o
ool408V1O`@0R81o1028Ogh308MoO@@0Qgim1026OG`408ImN`@0QWak1025NgX308EkN@P0Q7Yh1024
NGL408=hMP@0PgQe1023Mg@3089fM0@0PWIc1022MG84089dL@@0PWA`1021Lfl3085bKP@0PW1/1022
LVl4089cL@@0PWAb1021M783085eL`@0PGAc1020M78407mcLP@0Og=a101oLg8407icLP<0OWAd101o
MGD4081gM`@0P7Qi1022NW/4089lO0<0Pgin1024Oh0408F1PP@0QXB51028QhT408Z:S0@0S8jA0`2=
T9<408^;S@@0RXR:1029QhP408V5QP@0RHF51`28Q8@808R3P`@0R8:21029PX8;08V2P@@0RH615P3o
ool001@0oooo1029PGl408R0O`@0R7mn0`27Ogd408MnO@@0QWel1026OG/408IlN`@0QG]j0`25NgT8
08AjN0@0Q7Ug1023N7H408=hM@@0PgMd0`22MW@4089fL`@0PWEb1022M744089dL0@0PG=_0`21LVh4
089`K0@0PW9_1022Lg44089dLP@0PGAb0`21MG<4085dL`@0P7Ab101oLg8407mcL@@0Og=b101nLg83
07idM0@0OgEe1020MgL4081hN@@0PWYk1022O7`308=nOP@0Q7n01025PH8408J4Q@@0R8N9102:RX`4
08b>T@<0SI2C102;Rhd408Z8RP@0RHN81029QHH408V5Q@L0R8B42028Ph<408R2PP@0RH:22`29PX44
08V1PAH0oooo000D0?ooo`@0RH5o1028P7l408QoOP<0Qgmm1027OWd408ImO0@0QWek1026O7/408Ek
NP<0QG]i2024NWP408AiM`@0PgQf1023N7D408=gM0<0PWId1022MW<4089eLP@0PWAa1022M704085c
K`<0PG9^1022L6`4089bK`@0PW=a1022M784085dLP<0PGEc1021M7<4081dLP@0Og=b101oLg4407mc
LP@0OW=b0`1nM7@407meM@@0P7Mg1020N7T4089jN`@0PWal0`23OWh408AoP0@0QH621026Q8D408R7
R@@0RXZ<102<SY4308f@T`@0Rh^=102:R8X408V7R0@0RHF61029QHD708R4Q0P0R8>31028PX8408V2
PP/0RH:11029PH4F0?ooo`00503oool408R0O`@0R7mn1027OWd308InO0@0QWek1025O7X408EkN@@0
Q7Uh1023NGL308=gM@@0PWMe1022MW@4085eLP@0P7Aa1020Lg0407mbK`<0Og5^101nL6d407i_J`@0
OViZ101nKFT407i/I`<0OVYV101nJF<407i[I`@0OVeZ101nKV/407i^K0<0OFi]101mKV`407a^K0`0
Nfe]101kKVh307]`L0@0O79b101mM7@407ieMP@0OWMh101oNGX3081lO@@0PGj01023PX<408F5Q`@0
QhV<102:SI4408fCV0<0SI:F102;SY4408Z;S@@0RHR:1028QhP408R6Q`<0R8F61028Q8D408R4Q0@0
R8>41028Ph<408R3PP<0R8:21029PX8808V2PAH0oooo000D0?ooo`@0R81o1028Ogh408MnO@<0QWil
1026OG/408ElNP@0QG]i1024NGP408=iM`<0PgMe1022MgD4089fM0@0PGEb1020M744081cL0@0Og9_
0`1oLFh407i`K@@0OVm[101nKVX407i]J@@0OVaW0`1nJVH407iYH`@0OV]W101nKFX407i^J`@0OVi/
0`1mKVd407e^K0@0O6i/301kKFd407]^KP<0Ng1`101lLW8407edM0@0OWEf101nMgP407miNP<0P7am
1021OX0408>2P`@0QHF71027RH`408Z=T@@0SI>H0`2=TYH408^>T@@0RX^=1029R8X408R7R0@0R8J7
0`28QHH408R4Q@@0R8B41028Ph@408R3P`@0R8>20`28PX8408V2PPP0RH:15P3oool001@0oooo1028
P7l408QoOP@0Qgim0`26OW`408ImN`@0QGaj1025NgT408AiN0@0PgUg0`23MgD4089gM@@0PWId1021
MG84081dL@@0P7=`101oLVl307maKP@0OW1]101nKf/407i^JP@0OVeY101nK6L307iZIP@0OVUS101n
JfL407i]JP@0OVi[101nKV`307e^K@@0OFi/101lKV`<07]]K@@0Nfi^0`1kL70407abLP@0OGAd101n
MGH407igN0@0OgUj0`20O7d4085nP0@0Ph:31025QHL408N9S0@0RXfA102=TiP308fBUP@0RhjA102:
Rhd408V8RP@0R8N81028QXL308R5QP@0R8B51028Q8@408R3Q0@0R8>31028Ph8308R2PP@0RH:22029
PX4F0?ooo`00503oool408R0O`@0R7mn1027OWd308InO0@0QWek1025O7X408EkN@@0Q7Uh1023NGL3
08=gM@@0PWMe1022MW@4085eLP@0P7Aa1020Lg0407mbK`<0Og5^101nL6d407i_J`@0OViZ101nKFT4
07i/I`<0OVYV101nJF<407i[I`@0OVeZ101nKV/407i^K0<0OFi]101mKV`407a^K0`0Nfe]101kKVh3
07]`L0@0O79b101mM7@407ieMP@0OWMh101oNGX3081lO@@0PGj01023PX<408F5Q`@0QhV<102:SI44
08fCV0<0SI:F102;SY4408Z;S@@0RHR:1028QhP408R6Q`<0R8F61028Q8D408R4Q0@0R8>41028Ph<4
08R3PP<0R8:21029PX8808V2PAH0oooo000D0?ooo`@0R81o1027Ogd408ImO0<0QWek1025NgX408Aj
N0@0PgUg1022MgD4085fM0<0PGEb1020M74407mbK`@0OW5^101nKf`407e^J`@0O6eY0`1kJfP407]Z
IP@0NVUT101jIf<407YVH@@0NVEP0`1jI5h407YRG0@0NfEP101jIf<407YXI@@0NVQV0`1jJFL407UY
I`@0NFUX101iJVT407YZJ@@0NFYZ101iJf/307U/K@@0NVi_101jL74407]aL`@0NgAf101mN7T307ik
O@@0P7j01022PX@408B6R@@0QXZ>1029Si@408bEVP<0Ri:F102:Si8408V<S`@0R8Z<1028R8X408R7
R@<0QhJ71027QXH408R5Q@@0R8B51028Q8@408R3P`<0R8>21028PX8808V2PAH0oooo000D0?ooo`@0
R81o1027Ogd408ImO0<0QWek1025NgX408AjN0@0PgUg1022MgD4085fM0<0PGEb1020M74407mbK`@0
OW5^101nKf`407e^J`@0O6eY0`1kJfP407]ZIP@0NVUT101jIf<407YVH@@0NVEP0`1jI5h407YRG0@0
NfEP101jIf<407YXI@@0NVQV0`1jJFL407UYI`@0NFUX101iJVT407YZJ@@0NFYZ101iJf/307U/K@@0
NVi_101jL74407]aL`@0NgAf101mN7T307ikO@@0P7j01022PX@408B6R@@0QXZ>1029Si@408bEVP<0
Ri:F102:Si8408V<S`@0R8Z<1028R8X408R7R@<0QhJ71027QXH408R5Q@@0R8B51028Q8@408R3P`<0
R8>21028PX8808V2PAH0oooo000D0?ooo`@0R81o1027Ogd408ImO0<0QWek1025NgX408AjN0@0PgUg
1022MgD4085fM0<0PGEb1020M74407mbK`@0OW5^101nKf`407e^J`@0O6eY0`1kJfP407]ZIP@0NVUT
101jIf<407YVH@@0NVEP0`1jI5h407YRG0@0NfEP101jIf<407YXI@@0NVQV0`1jJFL407UYI`@0NFUX
101iJVT407YZJ@@0NFYZ101iJf/307U/K@@0NVi_101jL74407]aL`@0NgAf101mN7T307ikO@@0P7j0
1022PX@408B6R@@0QXZ>1029Si@408bEVP<0Ri:F102:Si8408V<S`@0R8Z<1028R8X408R7R@<0QhJ7
1027QXH408R5Q@@0R8B51028Q8@408R3P`<0R8>21028PX8808V2PAH0oooo000D0?ooo`@0R81o1027
OWd408ImN`<0QG]j1024NWP408=hMP@0PWId1021MG8407mcL@<0OW9_101mL6d407a^J`@0O6aY101k
JfL407YYI@@0NFMS0`1hIV4407MTG`@0MV9M101fHE/407IOFP@0MUiH0`1fGEH407ILE@@0MemJ101g
HE`407MRG`@0MV=P0`1fI64407ITHPP0MFET101eIFD407EVIP@0MFMW0`1fJFT407M[K0@0Mfe^101h
L74407QbM0@0NWEg0`1lNW`407emP0@0P8641023QXX408F;T0@0R96F102;UY`308ZBU`@0RHnC1028
SI0408N;SP@0QhV<1027R8X308N7R0@0QhJ71027QHH408N5Q@@0QhB41028Ph@308R3P`@0R8>21028
PX8408V2PAH0oooo000D0?ooo`@0R81o1027OWd408ImN`<0QG]j1024NWP408=hMP@0PWId1021MG84
07mcL@<0OW9_101mL6d407a^J`@0O6aY101kJfL407YYI@@0NFMS0`1hIV4407MTG`@0MV9M101fHE/4
07IOFP@0MUiH0`1fGEH407ILE@@0MemJ101gHE`407MRG`@0MV=P0`1fI64407ITHPP0MFET101eIFD4
07EVIP@0MFMW0`1fJFT407M[K0@0Mfe^101hL74407QbM0@0NWEg0`1lNW`407emP0@0P8641023QXX4
08F;T0@0R96F102;UY`308ZBU`@0RHnC1028SI0408N;SP@0QhV<1027R8X308N7R0@0QhJ71027QHH4
08N5Q@@0QhB41028Ph@308R3P`@0R8>21028PX8408V2PAH0oooo000D0?ooo`@0R81o1027OWd408Im
N`<0QG]j1024NWP408=hMP@0PWId1021MG8407mcL@<0OW9_101mL6d407a^J`@0O6aY101kJfL407YY
I@@0NFMS0`1hIV4407MTG`@0MV9M101fHE/407IOFP@0MUiH0`1fGEH407ILE@@0MemJ101gHE`407MR
G`@0MV=P0`1fI64407ITHPP0MFET101eIFD407EVIP@0MFMW0`1fJFT407M[K0@0Mfe^101hL74407Qb
M0@0NWEg0`1lNW`407emP0@0P8641023QXX408F;T0@0R96F102;UY`308ZBU`@0RHnC1028SI0408N;
SP@0QhV<1027R8X308N7R0@0QhJ71027QHH408N5Q@@0QhB41028Ph@308R3P`@0R8>21028PX8408V2
PAH0oooo000D0?ooo`@0R81o1027OWd408ImN`<0QG]j1024NWP408=hMP@0PWId1021MG8407mcL@<0
OW9_101mL6d407a^J`@0O6aY101kJfL407YYI@@0NFMS0`1hIV4407MTG`@0MV9M101fHE/407IOFP@0
MUiH0`1fGEH407ILE@@0MemJ101gHE`407MRG`@0MV=P0`1fI64407ITHPP0MFET101eIFD407EVIP@0
MFMW0`1fJFT407M[K0@0Mfe^101hL74407QbM0@0NWEg0`1lNW`407emP0@0P8641023QXX408F;T0@0
R96F102;UY`308ZBU`@0RHnC1028SI0408N;SP@0QhV<1027R8X308N7R0@0QhJ71027QHH408N5Q@@0
QhB41028Ph@308R3P`@0R8>21028PX8408V2PAH0oooo000D0?ooo`@0R7mn1026OG`408ElNP<0Q7Yh
1023N7H4085fM0@0P7Ab101oLW0407i`K@<0O6i[101kK6T407YZI`@0NFQT101hIV8407MTH0@0MF9N
0`1dH5/407=NF@@0LUaF101bFU@4075HDP@0LEM@0`1bETl407=FC`@0LeUC101dFeL407=MF@@0LeiK
0`1cGed4079OGP@0LV1N101aH5l4075PH0@0LF5Q101bHf<3079TI@@0LVIW101cJFX407=/K@@0M6ma
101fM7D307QhNP@0Ngao101mPH@40826RP@0PhbA1028TiT408VEW0<0R9:G1027Si@408N=T@@0QX^?
1026RXd408J8R`<0QXN91026QXP408N6Q`@0QhF61027Q8D408N4Q0L0R8>31028PX8408V2PAH0oooo
000D0?ooo`@0R7mn1026OG`408ElNP<0Q7Yh1023N7H4085fM0@0P7Ab101oLW0407i`K@<0O6i[101k
K6T407YZI`@0NFQT101hIV8407MTH0@0MF9N0`1dH5/407=NF@@0LUaF101bFU@4075HDP@0LEM@0`1b
ETl407=FC`@0LeUC101dFeL407=MF@@0LeiK0`1cGed4079OGP@0LV1N101aH5l4075PH0@0LF5Q101b
Hf<3079TI@@0LVIW101cJFX407=/K@@0M6ma101fM7D307QhNP@0Ngao101mPH@40826RP@0PhbA1028
TiT408VEW0<0R9:G1027Si@408N=T@@0QX^?1026RXd408J8R`<0QXN91026QXP408N6Q`@0QhF61027
Q8D408N4Q0L0R8>31028PX8408V2PAH0oooo000D0?ooo`@0R7mn1026OG`408ElNP<0Q7Yh1023N7H4
085fM0@0P7Ab101oLW0407i`K@<0O6i[101kK6T407YZI`@0NFQT101hIV8407MTH0@0MF9N0`1dH5/4
07=NF@@0LUaF101bFU@4075HDP@0LEM@0`1bETl407=FC`@0LeUC101dFeL407=MF@@0LeiK0`1cGed4
079OGP@0LV1N101aH5l4075PH0@0LF5Q101bHf<3079TI@@0LVIW101cJFX407=/K@@0M6ma101fM7D3
07QhNP@0Ngao101mPH@40826RP@0PhbA1028TiT408VEW0<0R9:G1027Si@408N=T@@0QX^?1026RXd4
08J8R`<0QXN91026QXP408N6Q`@0QhF61027Q8D408N4Q0L0R8>31028PX8408V2PAH0oooo000D0?oo
o`@0R7mn1026OG`408ElNP<0Q7Yh1023N7H4085fM0@0P7Ab101oLW0407i`K@<0O6i[101kK6T407YZ
I`@0NFQT101hIV8407MTH0@0MF9N0`1dH5/407=NF@@0LUaF101bFU@4075HDP@0LEM@0`1bETl407=F
C`@0LeUC101dFeL407=MF@@0LeiK0`1cGed4079OGP@0LV1N101aH5l4075PH0@0LF5Q101bHf<3079T
I@@0LVIW101cJFX407=/K@@0M6ma101fM7D307QhNP@0Ngao101mPH@40826RP@0PhbA1028TiT408VE
W0<0R9:G1027Si@408N=T@@0QX^?1026RXd408J8R`<0QXN91026QXP408N6Q`@0QhF61027Q8D408N4
Q0L0R8>31028PX8408V2PAH0oooo000D0?ooo`@0R7mn1026OG/408AkN@<0PgQg1021MW@4081dLP@0
Og9_101mL6d407a]JP<0NV]X101iJFD407MVHP@0MVAP101eHUd407=OFP@0LUeH0`1aFeD4071HDP@0
KUI?101]Dd`406aABP@0K4m70`1]CTH4071AB@@0LEE?101aEe84071HE0@0L5UG0`1_FUP806iJF@@0
KU]J201]Fe/406eMG@<0KEmO101^HF8406iUIP@0KfQZ101`K6h4079`LP<0MGEg101gNWd407YoPP@0
OXF:1022S94808JCVP<0QY6G1026SY@408F=T@@0QH^?1025RXd408F9S0<0QHR:1026QhT408J6R0@0
QXF71027QHH408N4Q0<0Qh>41028Ph<408R2PP@0RH:15P3oool001@0oooo1028Ogh408ImN`@0Q7]i
0`23N7L4085fM0@0P7Ab101oLVl407e`K@@0O6eZ0`1jJfP407UYI@@0MfIR101fI60407ERG@@0LemJ
101bGEP3075KE@@0L5QB101^ETl406eCC0@0K55:101/CdL306e>AP@0L559101aEDl4075GDP@0L5QD
101`FEL306mJF0P0KUYI101^FeX806eKF`@0KEeM0`1]Gel406iQHP@0KVEV101_J6X4071/KP@0LW1b
0`1eMGL407MjO@@0NWn2101nQHX408:<T@P0QY>J0`26TIL408J>U0@0QHfA1025Rhl408F:S@@0QHV<
0`25R8X408J7R@@0QXJ81026QHL408N5QP@0QhB40`27Ph@408R3P`@0R8:21029PX4F0?ooo`00503o
ool408QoOP@0QWek1024NgT308=hM`@0PGId1020M78407mbK`@0OG1]101lKFX307Y[J0@0NFUU101g
IV8407ITH0@0MF9M101cGeX4079MF0<0LE]E101`F58406iFC`@0KE=<101/DDX406a?A`<0KDi6101`
DDT4075EC`@0LEMB101`F5@4071IE`<0KeYH201^FUT406iKFPP0KE]K101]GEd306eOG`@0KV5R101^
IFH406mXJP@0L6a^101bL78307EeM`@0MgYm101jOh8407j5RP@0PXbA2026TiX308JAU`@0QXjD1025
SI4408F;S`@0QHZ=1025RH`308F8RP@0QXN91026QXP408J5Q`@0QhF61027Q8@308N3Q0@0R8>31028
PX8408V2PAH0oooo000D0?ooo`@0R7mn1026OG/408AkN@<0PgQg1021MW@4081dLP@0Og9_101mL6d4
07a]JP<0NV]X101iJFD407MVHP@0MVAP101eHUd407=OFP@0LUeH0`1aFeD4071HDP@0KUI?101]Dd`4
06aABP@0K4m70`1]CTH4071AB@@0LEE?101aEe84071HE0@0L5UG0`1_FUP806iJF@@0KU]J201]Fe/4
06eMG@<0KEmO101^HF8406iUIP@0KfQZ101`K6h4079`LP<0MGEg101gNWd407YoPP@0OXF:1022S948
08JCVP<0QY6G1026SY@408F=T@@0QH^?1025RXd408F9S0<0QHR:1026QhT408J6R0@0QXF71027QHH4
08N4Q0<0Qh>41028Ph<408R2PP@0RH:15P3oool001@0oooo1027Ogd408IlN`@0Q7Yh0`22MgD4081e
LP@0Og9`101mL6d407]]JP@0NVYW0`1hJ6@407IUH@@0MF=N101cH5/4079MF0@0L5]E101_F58306eE
C`@0K59<101ZCdP406U<A@@0IdU1101TA3`306]:@@@0Ke18101^DD`406iCCP@0KEA@101/E58706]E
D`@0JUED101ZEED406UEE@@0JEEF101XEeL306QIFP@0J5aM101YH64406]TIP@0K6QZ101^KFl3075c
M@@0M7Qk101hOX8407b4R@@0Oh^@1024TYT408BAV0<0Q8nE1024SY<408B<T@@0Q8^?1024RXh408B9
S0<0QHR;1025QhX408F7R@@0QXJ81026QHH708N4Q@@0R8B41028Ph8408V2PAH0oooo000D0?ooo`@0
Qgmm1026O7/408AjN0<0PWMe1020MG8407mbL0@0OG1]101kKFX407YZI`<0N6QT101fIF4407ESGP@0
Lf1K101bGEP4071KE@@0KeQB0`1]EDl406aBC0@0JTm8101YC4D406M9@@@0I4@l0`1[BT4406m@B0@0
KU5<101^Ddh406eDD0@0K5AB1`1[EE<406YEE0@0JUEE101YEED406UEEP@0J5MG0`1XFEX406QLG@@0
JF1Q101[I6H406aXJP@0KVe_0`1aLgD407AhN`@0N7j2101lQ8T407n;T0@0Q9:I1024TIP308B?U@@0
Q8jC1024S94408B;S`@0Q8Z>1024RH`308F8R`@0QHN:1025QhT408J6R0@0QXF61`27Q8D408R4Q0@0
R8>21029PX4F0?ooo`00503oool408MoO@@0QWak1024NWP3089gM@@0P7Eb101oLW0407e`K@@0NfeZ
101jJVL307QXI0@0MVEQ101eHeh407=PF`@0LUeH101`FeD406mHDP<0KEE?101/DT`406Y?B0@0JDa5
101WBD4406A4?0<0JdY1101_D4P406iAC0@0KU=>101]E50406aDDPL0JeEC101ZEE@406YEE@@0JEEE
101YEEH406QGE`<0J5UJ101XG5d406UPH@@0JfAV101/J6X406i]K`<0LG=e101dN7/407QnPP@0O8B9
101oRi0408BBV@@0Q96H0`24SiD408B>T`@0Q8bA1024Rhl408B:SP@0Q8V<0`25R8/408F7RP@0QHN9
1026QXP408J5QPL0QhB51028Q8@408R3PP@0RH:15P3oool001@0oooo1027Ogd408IlN`@0Q7Yh0`22
MgD4081eLP@0Og9`101mL6d407]]JP@0NVYW0`1hJ6@407IUH@@0MF=N101cH5/4079MF0@0L5]E101_
F58306eEC`@0K59<101ZCdP406U<A@@0IdU1101TA3`306]:@@@0Ke18101^DD`406iCCP@0KEA@101/
E58706]ED`@0JUED101ZEED406UEE@@0JEEF101XEeL306QIFP@0J5aM101YH64406]TIP@0K6QZ101^
KFl3075cM@@0M7Qk101hOX8407b4R@@0Oh^@1024TYT408BAV0<0Q8nE1024SY<408B<T@@0Q8^?1024
RXh408B9S0<0QHR;1025QhX408F7R@@0QXJ81026QHH708N4Q@@0R8B41028Ph8408V2PAH0oooo000D
0?ooo`@0Qgim1025NgX408=hM`<0PGId101oLg4407e`KP@0NfeZ101iJVL407QXI0<0MVEQ101dHUd4
079OFP@0L5aG101_FE<406eFD0@0Je=<0`1ZD4T406Q<A@@0ITU2101TASh40691>@@0HClg0`1`CD@4
06i>AP@0K4m9101[CdX406Y?C0@0JE1=0`1XD4h406M@C`@0IU1?101UD50406E?C`@0I4m@101SDE43
06=CE0@0I5MI101UG5d406IPHP@0J6EW101[JVd306i`L`@0LGIi101eO80407V2Q`@0O8R>1021SiH4
086>U@<0PHfD1022SI8408:<T@@0PX^@1023RXh408>9S@<0Q8R<1024QhX408F7R@@0QHJ81026QHL4
08J5QP<0QhB51027Q8@408R3P`@0RH:15P3oool001@0oooo1027OWd408EkNP@0PgQg0`21MW@407mc
L@@0OG1^101kKFX407UZI`@0N6QT0`1fIF4407ARG@@0LUmJ101`G5L406mID`@0KEI@101[Dd`306Y@
B@@0J4a5101VBD8406A6?P@0HT4i101Q?cL3071=A0@0KTi6101/CdT406]?BP@0JTm<101YD4d306Q@
CP@0Ie1?101VD4l406E@D0@0IDm?101TCe0406=AD@<0He=D101TEeT406ELG@@0IV1R101XIFL406]Z
K@<0KW1c101aMWT407ElP0@0NH:7101lR8h4086?UP@0PHjE0`21SI@408:=TP@0PXbA1022Ri0408>:
SP@0PhV=0`24R8`408B7RP@0QHN91025QXP408J5Q`@0QXF60`27Q8D408N4Q0@0R8>31029PX4F0?oo
o`00503oool408MnO@@0QG]j1023N7L3085fM0@0Og=a101mL6h407]]JP@0NFYW101hJ6@307IUH@@0
M69M101bGeX4071LE`@0KeUC101]EU0406]CC0<0JU19101XC4D406I9@P@0I4Hn101R@CT4064o=`<0
L4e4101^CTH406a?B@@0Jdm:101ZCd`406U@C@<0J51>101WD4l406I@C`@0IE1@101UCdl406A?D0@0
He5A0`1SDe@406AGF@@0IEaM101VH68406QUI`@0JfY]0`1^L7<4075fN@@0MGb0101iPXL407b8SP@0
PHnF1021SYD3086=U0@0PXfB1022S94408:;T0@0PhZ>1023RHd308B8S0@0Q8N:1025QhT408F6R0@0
QXF71026QHH308N4Q@@0QhB41028Ph<408V2PAH0oooo000D0?ooo`@0Qgim1025NgX408=hM`<0PGId
101oLg4407e`KP@0NfeZ101iJVL407QXI0<0MVEQ101dHUd4079OFP@0L5aG101_FE<406eFD0@0Je=<
0`1ZD4T406Q<A@@0ITU2101TASh40691>@@0HClg0`1`CD@406i>AP@0K4m9101[CdX406Y?C0@0JE1=
0`1XD4h406M@C`@0IU1?101UD50406E?C`@0I4m@101SDE4306=CE0@0I5MI101UG5d406IPHP@0J6EW
101[JVd306i`L`@0LGIi101eO80407V2Q`@0O8R>1021SiH4086>U@<0PHfD1022SI8408:<T@@0PX^@
1023RXh408>9S@<0Q8R<1024QhX408F7R@@0QHJ81026QHL408J5QP<0QhB51027Q8@408R3P`@0RH:1
5P3oool001@0oooo1027OWd408EkN@@0PWQf0`20MG8407ibK`@0O6i[101jJfP407QXI0@0MVEQ0`1d
HUd4075NFP@0Ke]F101]F58406]DCP@0JU5;101XCTL306I:@`@0I4Lo101R@c/40650=`@0GS/b101Y
AC/307=?A@@0KDa4101ZBdD406Q:AP@0IT]7101UBdP306A;B@@0Hd]:101RBd/4065:BP@0H4U:101O
BT/405m<C@<0GdmA101PE5H4065HFP@0HUeO101THV@406QXJ`<0Jfia101_M7P407=jO`@0MX25101j
QX`407j;TP@0OXbC0`1oS98407n;TP@0P8^A1021RY04086:SP@0PXV=0`23R8`408>8R`@0Q8N:1025
QXT408F6Q`@0QXF60`27Q8D408N4Q0@0R8>31028PX8F0?ooo`00503oool408MnO@@0QG]i1022N7H3
081eLP@0OW9_101lKV/407Y[J0@0N6QT101fIF4307ARG@@0LEiJ101_FeH406eHDP@0JeA>101ZDD/4
06Q>A`<0ITY3101TAcl40693>`@0HD0g101N>c8406U5>`<0Ldm5101]C4@406Y;A@@0J4Y6101VBdL4
06E;B0<0I4]9101SBdX4069;B`@0HDY:101PBDX405m:B`@0Gda=0`1OCe44061DEP@0HEQJ101RGEl4
06ARI0@0J6Q[0`1[KW4406mdN0@0LgYo101fP8D407Z6S0@0OX^B101nS9<307n<TP@0Oh^B1020Ri44
086:T0@0PHZ>1022RHd308>8S0@0PhR;1024QhX408F6R@@0QHJ71026QHH308N4Q@@0QhB41028Ph<4
08R2PQH0oooo000D0?ooo`@0Qgim1025NgT4089hMP<0P7Eb101nLVl407a^J`@0NV]X101hJ6@407IU
H@<0M69M101aGUX406mKEP@0KEQB101[E4h406YAB`@0J4i70`1VBT<406A7?`@0HT<k101Q@3L405hk
<P@0JDDk0`1cCdD406e<A0@0JT]5101XBTH406I;A`@0ID]80`1TBdT406=;BP@0HT];101QBTX40619
BP@0GdY;101OC4d305m?D@@0H5AF101QF5X4069MG`@0I69T101XJ6/306]^L@@0KgAh101cNWl407J0
Q@@0NXJ<101nRi8407j<T`<0OhbB101oRi84082;T@@0PHZ@1021RXh408:9S@<0PhR<1023R8/408B7
RP@0QHJ91025QXL408J5QP<0QhB51027Q8@408R3P`@0R8:25P3oool001@0oooo1027OW`408AjN@@0
PWMe0`1oLg4407e`KP@0NfeY101hJFH407IUHP@0M69N0`1aGUX406mKEP@0KEMB101[E4h406Q@BP@0
ITa5101TBD430695?@@0H44i101N?C@405/h;P@0I3le101_BCl306a9@0@0JDQ1101WAd4406E6@@@0
HdI2101RAd@30617A@@0H4M6101OATH405i5AP@0G4=5101LADL405]8BP<0Fd]>101LD5<405eFF0@0
GUYM101QH6<406AVJ@<0J6a_101/LWH4071hO@@0Lgj3101gPXT407V7SP@0O8^A1`1mRi4407j:T0@0
OhZ@1020RXl40869SP<0PXV=1023R8`408>7RP@0Q8N91025QXP408J5Q`<0QXF61027Q8@408R3P`@0
R8:25P3oool001@0oooo1027OW`408AjN@@0PWMe0`1oLg4407e`KP@0NfeY101hJFH407IUHP@0M69N
0`1aGUX406mKEP@0KEMB101[E4h406Q@BP@0ITa5101TBD430695?@@0H44i101N?C@405/h;P@0I3le
101_BCl306a9@0@0JDQ1101WAd4406E6@@@0HdI2101RAd@30617A@@0H4M6101OATH405i5AP@0G4=5
101LADL405]8BP<0Fd]>101LD5<405eFF0@0GUYM101QH6<406AVJ@<0J6a_101/LWH4071hO@@0Lgj3
101gPXT407V7SP@0O8^A1`1mRi4407j:T0@0OhZ@1020RXl40869SP<0PXV=1023R8`408>7RP@0Q8N9
1025QXP408J5Q`<0QXF61027Q8@408R3P`@0R8:25P3oool001@0oooo1027OW`408AjN@@0PWMe0`1o
Lg4407e`KP@0NfeY101hJFH407IUHP@0M69N0`1aGUX406mKEP@0KEMB101[E4h406Q@BP@0ITa5101T
BD430695?@@0H44i101N?C@405/h;P@0I3le101_BCl306a9@0@0JDQ1101WAd4406E6@@@0HdI2101R
Ad@30617A@@0H4M6101OATH405i5AP@0G4=5101LADL405]8BP<0Fd]>101LD5<405eFF0@0GUYM101Q
H6<406AVJ@<0J6a_101/LWH4071hO@@0Lgj3101gPXT407V7SP@0O8^A1`1mRi4407j:T0@0OhZ@1020
RXl40869SP<0PXV=1023R8`408>7RP@0Q8N91025QXP408J5Q`<0QXF61027Q8@408R3P`@0R8:25P3o
ool001@0oooo1027OW`408AjN@@0PWMe0`1oLg4407e`KP@0NfeY101hJFH407IUHP@0M69N0`1aGUX4
06mKEP@0KEMB101[E4h406Q@BP@0ITa5101TBD430695?@@0H44i101N?C@405/h;P@0I3le101_BCl3
06a9@0@0JDQ1101WAd4406E6@@@0HdI2101RAd@30617A@@0H4M6101OATH405i5AP@0G4=5101LADL4
05]8BP<0Fd]>101LD5<405eFF0@0GUYM101QH6<406AVJ@<0J6a_101/LWH4071hO@@0Lgj3101gPXT4
07V7SP@0O8^A1`1mRi4407j:T0@0OhZ@1020RXl40869SP<0PXV=1023R8`408>7RP@0Q8N91025QXP4
08J5Q`<0QXF61027Q8@408R3P`@0R8:25P3oool001@0oooo1026OG`408AjN0@0PGId0`1nLW0407a_
K0@0NF]W101gIf<407ASG`@0LUmK0`1_FeH406eGDP@0JU=>101XD4T406E<A@@0HdQ0101QA3`305i0
=`@0G3`c101K>2h4060k<0@0Jd@i101YA3X306Q4>`@0ID@m101S@cd40652?0@0Gd8n101N@T0305e3
@@@0G4=2101K@T8405Y2@`@0FD93101HATL405Q9BP<0F4e?101HDE8405UEE`@0FUUK101NGf44065U
J0<0IF]_101ZLGH406igO0@0LGb1101eP8L407N5S0@0NHR?0`1jRY4407^:T@@0O8ZA101mRY0407n:
S`@0P8V>0`21RHd408:8S0@0PhR;1024QhX408F6R@@0QHJ70`26QHH408N4Q@@0R8>31028PX8F0?oo
o`00503oool408ImO0@0Q7Yh1021MW@307ibL0@0O6m/101iJfL407MWH`@0M6=O101bGe/306mKEP@0
KEMB101ZDdh406Q@B@@0IDa5101SB4040654?0<0GT0g101L?3<405/h;P@0H3/`101[A3T406U4>P<0
J4@k101UA3d406=3?@@0HD8l101O@Sh405i2@0<0GD=1101L@d8405]2@P@0FT93101I@T<405Q6A`@0
F4U:0`1HCDl405QADP@0FEEG101JFE/405iOH@@0HFEX0`1UJfl406YaMP@0KWMl101aO84407F0Q`@0
MhF<101iR8l307Z:T@@0NhZA101lRY4407f:T0@0OhZ?1020RHh30869S@@0PXR<1023R8/408B7RP@0
QHJ91025QXL308J5QP@0QhB51028Ph<408R2PQH0oooo000D0?ooo`@0QWel1024NWP4085fM0<0OW9`
101lKf`407U[I`@0MfMS101dHel4079OF`<0Ke]F101]Ee8406YCCP@0J519101UC4D406=8@0@0HD@l
0`1N@3L405`l<`@0FcP^101P>c0406]4>@@0JD@j0`1XA3/406E4?@@0Hd<m101Q@S`405m2?P@0GT90
0`1M@d4405a3@P@0Fd92101J@T<405U2@`@0F4I7101HBDX305Q=C`@0F55B101IEEL405YIF`@0GUmQ
101QIFP306E[K`@0JW5f101^Mg`4075lP@@0MH27101gQH`407V8S`<0NXZA101kRY4407b:T@@0OHZ@
101oRXl40829SP<0PHV=1022R8`408>8R`@0Q8N:1025QXT408F6Q`<0QXF61027Q8D408R3P`@0R8:2
5P3oool001@0oooo1026OG`408AjN0@0PGId0`1nLW0407a_K0@0NF]W101gIf<407ASG`@0LUmK0`1_
FeH406eGDP@0JU=>101XD4T406E<A@@0HdQ0101QA3`305i0=`@0G3`c101K>2h4060k<0@0Jd@i101Y
A3X306Q4>`@0ID@m101S@cd40652?0@0Gd8n101N@T0305e3@@@0G4=2101K@T8405Y2@`@0FD93101H
ATL405Q9BP<0F4e?101HDE8405UEE`@0FUUK101NGf44065UJ0<0IF]_101ZLGH406igO0@0LGb1101e
P8L407N5S0@0NHR?0`1jRY4407^:T@@0O8ZA101mRY0407n:S`@0P8V>0`21RHd408:8S0@0PhR;1024
QhX408F6R@@0QHJ70`26QHH408N4Q@@0R8>31028PX8F0?ooo`00503oool408ImO0@0PgUg1020MG<3
07eaKP@0NfeZ101hJFD407EUH@@0LV1L101_G5P306eHD`@0JUA>101WD4X406E;A@@0HTM0101O@c/4
05do=P<0FcXa101H=Rd405Da9`@0HS/_101V?c@406E1=`<0I44h101Q@3T405lo>0@0G3dh101J?CX4
05Xo?@<0FClo101H?cl405Po@0@0Ed92101FADD405E8B0@0ETi>0`1FDE8405EADP@0EUAF101GFE/4
05]NH@@0GfEW0`1TJVd406QaM@@0K7Ik101_Nh04079oQ@@0M8>:101fQXh307V:TP@0NHVA101jRI44
07b:T0@0OHZ@101oRHl30829SP@0PHV=1022R8`408>7R`@0Q8N91025QXP308J5QP@0QhB51028Ph<4
08R2PQH0oooo000D0?ooo`@0QWel1023NGL4081eL`<0OG5^101kKFX407QYI@@0MFEQ101bH5`406mL
F0<0KEQC101ZE4h406M@BP@0ID]5101RAd0405m3>`@0GClf0`1K>S4405Pf;@@0EC4W101R>bl406Ho
=0@0ID4g0`1T@CP40650>@@0Gclh101L?CP405Xm>P@0FSlm0`1I?cl405Po?`@0F3m0101G@T8405I5
A@@0EDQ8101FCTh305IADP@0EE5B101FE5H405MIF`@0FeiQ101OIFL306AZK@@0J75e101/MW/406mk
P0@0LWn5101dPhX407J6SP<0NHZB101iRI4407Z9T@@0O8Z@101mRY0407n9S`<0P8V>1021RHd408:8
S0@0PhN;1024QhT408F6R0<0QXF61027Q8D408R3P`@0R8:25P3oool001@0oooo1026OG`408=iM`@0
P7Ec0`1mLFh407]]JP@0N6UU101eIF44079PG0@0KeaH0`1]F5<406YDCP@0Ie1:101UBdD40697@0@0
Gd<k101M?cH305/j<@@0F3H]101E<BL4068k;`@0ISld101U@CL306A1>0@0HD0i101O?cP405`m>0@0
FSdj101J?cd305To?`@0F3lo101H?d0405M2@P@0ETE5101EB4P405I>CP<0EU5B101EDE8405IDEP@0
EeUK101KGV4405mUI`<0I6Y]101XLGD406afN`@0Kg^0101bOhD407B3RP@0MXJ>0`1iRY8407V9T@@0
NXVA101lRY0407f:T0@0OhV?0`20RHh40869S@@0PXR<1023Qh/408B7R@@0QHJ80`26QHH408N4Q@@0
R8>31028PX8F0?ooo`00503oool408ImO0@0PgUg1020MG<307eaKP@0NfeZ101hJFD407EUH@@0LV1L
101_G5P306eHD`@0JUA>101WD4X406E;A@@0HTM0101O@c/405do=P<0FcXa101H=Rd405Da9`@0HS/_
101V?c@406E1=`<0I44h101Q@3T405lo>0@0G3dh101J?CX405Xo?@<0FClo101H?cl405Po@0@0Ed92
101FADD405E8B0@0ETi>0`1FDE8405EADP@0EUAF101GFE/405]NH@@0GfEW0`1TJVd406QaM@@0K7Ik
101_Nh04079oQ@@0M8>:101fQXh307V:TP@0NHVA101jRI4407b:T0@0OHZ@101oRHl30829SP@0PHV=
1022R8`408>7R`@0Q8N91025QXP308J5QP@0QhB51028Ph<408R2PQH0oooo000D0?ooo`@0QWek1023
N7L4081dLP<0O6m]101iJfP407IWH`@0Lf9N101`GUX406eJE@<0JUE@101XDD/406E<AP@0HTM1101O
@c/405`n=P@0FCXa0`1F=B`405@`9P@0FS<W101W?c<406@n=0@0HShd0`1P?SH405hm=P@0Fc/e101H
>C@405Hi=P@0ES/k0`1E?3`4058l?0@0ETA4101GB4L405I<B`@0ETi>101FCTl305=?D0@0DU5B101C
EeP405=IF`@0EeeO101LI6H3069ZK@@0Ig1e101[MW/406ikP0@0Kgj4101aPXT407>4S0<0MHN?101g
RI4407R9T@@0NXZA101lRY0407j:T0<0OhZ?1021RHh408:9S@@0PhR;1024QhX408F6R0<0QXF71027
Q8D408N3Q0@0R8:25P3oool001@0oooo1026OG/408=hM`@0P7Ab0`1lKfd407U[J0@0MVMS101cHUh4
071NFP@0KEYE0`1ZEE0406QAB`@0IDa6101RAd4405m3>`@0G3hf101I>S4305He;0@0E30V101J<bL4
06Lo<`@0I3hd101R?S@3060n=P@0GSdf101K>cD405Pi=0@0ESTf101F>c/305Dl?0@0DS`l101FA4@4
05M8A`@0ETa;101FCTh405I>C`<0Ddm@101BDE8405=GF0@0DeUK101GGEl405aTIP<0HVY]101WL7D4
06]fN`@0KW^0101_OX@40762R@@0LhB<0`1eQhl407N9T@@0N8VA101jRY4407b:T0@0OXZ@0`1oRXl4
0869SP@0PXV=1023R8/408B7RP@0QHJ80`26QHL408N4Q@@0Qh>41028PX8F0?ooo`00503oool408Im
N`@0PgQg1020M78307a_K@@0NF]X101fIf<407=RGP@0L5iJ101]FUD306YED0@0J55;101UC4H40697
@@@0Gd<k101L?SH405Tj<@<0ESD/101D<2H405Xc9`@0Iclc101T?S@4068n=0<0H3hf101N?CH405/k
=@@0F3Td101F>CH405Hk>`<0EC`l101B?3`405I4A0@0EdQ7101FC4/405I>CP@0ETi?0`1CCe04059A
DP@0DeMH101CFE/405MMG`@0G6AV0`1RJVd406M`M@@0JgIk101^Nh0406mnQ0@0LH:9101cQ8`307F7
S`@0MhVA101hRI4407Z:T@@0O8Z@101nRY0307n:S`@0PHV>1022RHd408>8R`@0Q8N:1025QXP308J5
Q`@0QhB51027Ph@408R2PQH0oooo000D0?ooo`@0QWek1023N7L4081dLP<0O6m]101iJfP407IWH`@0
Lf9N101`GUX406eJE@<0JUE@101XDD/406E<AP@0HTM1101O@c/405`n=P@0FCXa0`1F=B`405@`9P@0
FS<W101W?c<406@n=0@0HShd0`1P?SH405hm=P@0Fc/e101H>C@405Hi=P@0ES/k0`1E?3`4058l?0@0
ETA4101GB4L405I<B`@0ETi>101FCTl305=?D0@0DU5B101CEeP405=IF`@0EeeO101LI6H3069ZK@@0
Ig1e101[MW/406ikP0@0Kgj4101aPXT407>4S0<0MHN?101gRI4407R9T@@0NXZA101lRY0407j:T0<0
OhZ?1021RHh408:9S@@0PhR;1024QhX408F6R0<0QXF71027Q8D408N3Q0@0R8:25P3oool001@0oooo
1026O7/4089hMP@0Og=`0`1kKV`407QZIP@0MFER101bH5`406iKE`@0JeMB0`1XDT`406E=A`@0HTQ2
101O@c`405/n=`@0F3Ta101E=2`305<`9`@0Cb/Q101N=b/406@n<P@0HSdc101P?3<305hl=@@0FcXd
101H>38405@f<P@0DcLe101A>CP305A1@0@0EdQ7101LCTd405Q=C0@0ETi=101DCDd4059<C0<0DU9C
101CE5D4059FF0@0DEIH101DG5h405YSIP<0HFY]101UL7D406UfN`@0K7Z0101]OH<406ioQ`@0L8::
0`1bQXh407B9T`@0MHVB101hRI8407^:T@@0OH^A0`1oRY04082:S`@0PXV>1023RH`408B8R`@0QHN9
0`26QXL408N5QP@0QhB41028PX8F0?ooo`00503oool408IlN`@0PWQf101oLg0307]^K0@0N6YV101e
IF84079PG0@0KU]G101[Ee8306QBC0@0IDe7101RB48405m3?0@0Fchg101H>C4405Dd;0<0Dc0W101?
:b4405hg:`@0I3hb101R?C<4060l<`<0GS`e101K>S@405Ph<P@0E3Hb101C=cD4054i>0<0E450101G
B4L405a>C@@0F4e<101FCTd405A=C@@0DTa<0`1BDU<405=DE@@0DUIH101AEUP405ALGP@0FV=V0`1Q
JVd406E`M@@0JGIk101/NX0406emP`@0KWn7101`PXX307:6SP@0M8VC101eRI8407R9TP@0NhZA101m
Ri4307n:T0@0P8Z?1022RHh408>9S0@0Q8R;1025QhT308J6Q`@0QhF61027Q8@408R2PQH0oooo000D
0?ooo`@0QWak1022N7H407mcL0<0Nfi/101hJVH407EUHP@0LV1L101^FeL406]GDP<0J59<101UCDL4
0698@P@0Gd<l101K?SL405Pi<@@0EC@/0`1C<2L404l[8@@0GSL[101T?S84068m<`@0H3`c0`1N?3D4
05/j=0@0F3Pb101D=S8405<g=@@0DCTh0`1D@D0405M8A`@0G4i=101HCD`405I>C@@0E4e=101BC4`3
059BD`@0DeAE101BEUP4055FF0@0E5aN101JHfH3065ZK@@0IG1e101YMW/406ajP0@0KGf3101^OhL4
0722RP<0LXJ>101dRI<407F9TP@0N8VB101kRY4407f;T@<0OhZ@1020RXl408:9SP@0PhV<1024R8/4
08F7R@<0QXJ71027QHH408N4Q0@0R8:25P3oool001@0oooo1026O7/4089hMP@0Og=`0`1kKV`407QZ
IP@0MFER101bH5`406iKE`@0JeMB0`1XDT`406E=A`@0HTQ2101O@c`405/n=`@0F3Ta101E=2`305<`
9`@0Cb/Q101N=b/406@n<P@0HSdc101P?3<305hl=@@0FcXd101H>38405@f<P@0DcLe101A>CP305A1
@0@0EdQ7101LCTd405Q=C0@0ETi=101DCDd4059<C0<0DU9C101CE5D4059FF0@0DEIH101DG5h405YS
IP<0HFY]101UL7D406UfN`@0K7Z0101]OH<406ioQ`@0L8::0`1bQXh407B9T`@0MHVB101hRI8407^:
T@@0OH^A0`1oRY04082:S`@0PXV>1023RH`408B8R`@0QHN90`26QXL408N5QP@0QhB41028PX8F0?oo
o`00503oool408ElN`@0PWMe101nLW0307Y]JP@0MfQU101cHel4071NFP@0K5UD101YE4l306I?B@@0
HdY4101OACh405a0>0@0F3Xb101D=2`4050_9P<0Cb/R101@:R0406<l;`@0Hcda101P?38405hk<`<0
Fc/d101H>C<405Df<@@0DCLc101B>SP4058n?@<0FdU7101IBDL405M8A`@0EDU8101CB4H40557AP@0
CdM70`1?Bdd404m=CP@0DE9C101CEUL405MMH0@0FV9U0`1OJ6`406A_M0@0J7Ik101ZNGl406]kPP@0
Jgf5101]P8T306n4S@@0LHNA101cR90407J9TP@0NX^C101mS98307n;T@@0P8^@1021RXl408>9S@@0
Q8R;1025QhX308J6R0@0QhF61027Q8@408R3PQH0oooo000D0?ooo`@0QGak1022MgD407ibL0<0NVeZ
101gJ6D407=SG`@0L5iJ101/FE@406UDC`<0ITm9101SBT@405m5?P@0G40h101H>S8405@d;0@0D2lV
0`1?:b84050Z80@0Hc`_101S?C44060l<P@0GS/c0`1K>c@405Pi<`@0ECHa101A=c<4058j>0@0DShm
0`1KBDL405U9A`@0EdQ7101EBDP405=8AP@0DDM6101?AdL304m;C@@0Cde>101ADU<405=FE`@0EeeP
101JHVD305mXK0@0I6md101XMW/406YiO`@0Jg^2101[OHD406f0R@<0KhB=101aQi4407>8T0@0MXVB
101jRi<407f<TP<0Oh^A1020Ri04086:S`@0PhV=1024R8/408F7RP<0QXJ81027QHH408N4Q0@0R8>2
5P3oool001@0oooo1025O7/4089gM@@0OW9`0`1jKFX407MXI@@0Lf=O101`GUX406aIE0@0JEA?0`1V
CdT406=:A0@0GdDn101L@3P405Pj<P@0E3@/101@;bH304l[8P@0D2XP101S?2l406<m<@@0H3`b101N
>c<305/k=0@0F3Tc101E=S44054g<`@0DSXh101B?Sd305]9A`@0FDU7101GB4L405E9B0@0DdQ6101A
AdH404m7A`<0Cd]=101?CDh4055BD`@0DeIG101GGF0405YRI@<0GfQ/101TKg@406QfN`@0JWUo101[
Nh8406]mQ@@0KH290`1_Q8d40767T@@0LhR@101fRI8407Z;T`@0OHbB0`1oRi44082;T0@0PHZ?1023
RHd408B8R`@0QHN:0`26QXP408N5QP@0QhB41028Ph8F0?ooo`00503oool408ElN`@0PWMe101nLW03
07Y]JP@0MfQU101cHel4071NFP@0K5UD101YE4l306I?B@@0HdY4101OACh405a0>0@0F3Xb101D=2`4
050_9P<0Cb/R101@:R0406<l;`@0Hcda101P?38405hk<`<0Fc/d101H>C<405Df<@@0DCLc101B>SP4
058n?@<0FdU7101IBDL405M8A`@0EDU8101CB4H40557AP@0CdM70`1?Bdd404m=CP@0DE9C101CEUL4
05MMH0@0FV9U0`1OJ6`406A_M0@0J7Ik101ZNGl406]kPP@0Jgf5101]P8T306n4S@@0LHNA101cR904
07J9TP@0NX^C101mS98307n;T@@0P8^@1021RXl408>9S@@0Q8R;1025QhX308J6R0@0QhF61027Q8@4
08R3PQH0oooo000D0?ooo`@0QGaj1021MWD407eaK`<0NFaY101eIV<4079QG@@0KUaG101ZEU8406MA
C0<0Hda6101PAd0405e1>P@0FC`d101E=Rh4050_9P@0BBLM0`1:9Q`405Pa9@@0Iclb101R?C8405hk
<P@0FcXb0`1I>S<405Hi<`@0DcLb101C>cL405I2?`@0FDU60`1LCD/405M;B@@0E4Q7101BAdH404m3
@`@0CD=3101<@d@304a7B0@0C4U:101>D584051BE@@0E5UM101HGf<305iVJ`@0I71e101WMW/406Qi
O`@0J7V0101XNh<406YoQ`<0K8><101^QY0407:9T`@0MX^E101kSYD407f=U0<0OhfC1020S944086;
T0@0PhZ>1024RH`408F8RP<0QXJ81027QHH408N4Q0@0R8>25P3oool001@0oooo1025O7X4085fM@@0
OG5_0`1iK6T407EVH`@0LV5M101^G5L406YFDP@0Ie5<0`1SC4H40617@0@0GD4j101I?3@405Df;P@0
D2lV10199ad304XV70@0F34U101W?c84068m<P@0GS/b101K>S8305Tj<`@0ESTc101C=c8405<k=`@0
ET8o101IBDH305a=B`@0Ed]9101DB4L40597AP@0Cd=3101=@d<404a3A0<0C4M8101<BDX404i@DP@0
D59E101DFEd405QOH`<0GVI[101TL7D406MfN`@0J7Uo101XNH0406QkP`@0JWn70`1/Ph`406j6T0@0
LXVC101fRiD407^>U@@0OHfD0`1oSI<4082<T@@0PH^@1023RXh408B9S0@0QHR:0`26QXP408N5QP@0
QhB41028Ph8F0?ooo`00503oool408ElNP@0PGIe101mLFl307U/J@@0MFIS101bHEd406iLE`@0JUIB
101WDD`306=<AP@0H4M0101M@CX405Tl=0@0ECH^101@;bH404TW7@<0BRHL101H<BD406Lo<P@0HSdb
101N>c8405/j<P<0FCXc101F>C<405<g<P@0Dc/g101F@Sl405U9AP<0G4e;101GBdT405A8A`@0DTM6
101?@d<404e3@`@0C4=40`1<AdP404a9BP@0CU1B101@DUD405AIG@@0F5mS0`1NIV/406A`M@@0IgIk
101XNGl406QiP0@0J7^3101ZOhL306b3S0@0KXJ@101bRI<407J;U@@0NhjE101mSI@307n=T`@0P8bA
1021Ri0408>:SP@0Q8V<1025R8X308J6R0@0QhF61027Q8@408R3PQH0oooo000D0?ooo`@0QGaj1020
MW@407a`KP<0N6YW101dIF44071OF`@0K5UE101XE4l406E>B@<0HDU3101NA3d405Xn=`@0EcTa101C
<bX404h/8`@0B2DK0`1C;R<406@l<0@0I3hb101O>c8405`j<P@0FCXc0`1F>S@405@h<`@0DCPc101A
>cP405A2@0@0EDI40`1EB4H405=9A`@0DTQ7101@AdH404i6A@@0BdI5101;AdL304Y:BP@0Bdi?101<
DE8404mBE@@0DUQL101FGV8305aVJP@0I75e101VMg/406IhOP@0IWQo101VNX<406MmQP<0JX6:101[
Phh406^4S`@0MHbE101kT9L407f?UP<0OhjE1020SI<408:<T@@0Ph^?1024RXd408F8R`<0QXN91027
QXL408N4Q@@0R8>35P3oool001@0oooo1025O7X4081fM0@0O71^0`1hJVL407AUH@@0L5mK101/FED4
06QDC`@0IDi90`1QBD<405i4?@@0FShg101G>C4405<c:P@0CR`S10189A/305<^8`@0I3``101T?S84
05lk<P@0G3Xb101I>S<305Hj=0@0E3Pc101A>3<4054k>0@0E490101EAT@305E8AP@0DdU7101BB4L4
0517AP@0CTI5101;ATD404]7A`<0BTY:101;CTl404aADP@0Ce9E101BF5`405INHP<0G6IZ101TLGD4
06IgN`@0IWQn101VN7l406IjP`@0Igf60`1ZPHX406^3SP@0JhB?101eS9D407^@U`@0OHnF0`1oSYD4
082=T`@0PXbA1023Rhl408B:S@@0QHR;0`26QhT408N6Q`@0QhB51028Ph<F0?ooo`00503oool408El
NP@0P7Id101lL6h307QZI`@0M6EQ101`Ge/406aIE@@0J5A?101UCTT30659@`@0GT@m101J?SL405Li
<@@0Dc<Z101>;2<404PU6`<0DbhS101T?30406@n<P@0Gc/b101L>S8405Tj<`<0ESXd101D>3<4054h
<`@0DC/h101D@T0405E6A0<0EDQ6101CBDL40598A`@0D4M6101>ATD404]6A@@0BdM70`1:BTX404]>
C`@0C55B101?DUD4059HG0@0EUiR0`1LIVX406AaM@@0IWMk101VN7h406IhO`@0IWZ3101WOHH306Z1
RP@0Jh>>101[Q8l407F<U@@0Ni2G101mSiH307n>U@@0P8fC1022S94408>;S`@0Q8Z=1025R8/308J7
R@@0QhJ71027Q8D408R3PaH0oooo000D0?ooo`@0QGaj1020MW@407a`KP<0N6YW101dIF44071OF`@0
K5UE101XE4l406E>B@<0HDU3101NA3d405Xn=`@0EcTa101C<bX404h/8`@0B2DK0`1C;R<406@l<0@0
I3hb101O>c8405`j<P@0FCXc0`1F>S@405@h<`@0DCPc101A>cP405A2@0@0EDI40`1EB4H405=9A`@0
DTQ7101@AdH404i6A@@0BdI5101;AdL304Y:BP@0Bdi?101<DE8404mBE@@0DUQL101FGV8305aVJP@0
I75e101VMg/406IhOP@0IWQo101VNX<406MmQP<0JX6:101[Phh406^4S`@0MHbE101kT9L407f?UP<0
OhjE1020SI<408:<T@@0Ph^?1024RXd408F8R`<0QXN91027QXL408N4Q@@0R8>35P3oool001@0oooo
1024NgX4081eL`@0Nfm]0`1gJFH4079SG`@0KUeI101ZEe<406IAC0@0HTa60`1OAT0405]0>@@0F3/c
101E=Rd4058a:0@0D2`S101D;R83064i;0@0ISlb101O?34405`j<@@0FCXc101F>S<305@j=0@0DSTd
101?>C@4050k>0@0DT8o101A@d430554@`@0CdE4101>AD@404a4@`@0BT921018@d8404M5A@<0AdM8
1018Bd`404U>D@@0C5=F101@Fed405IRI@<0G6]_101SLgP406IhO@@0IGQn101SN7l406=iPP@0IGb6
0`1WP8X406R2S@@0JHB@101iTI/407bBVP@0OY6I0`20T9L4086?U@@0PXfC1023S90408B:SP@0QHV<
0`26QhX408N6Q`@0QhB51028Ph<F0?ooo`00503oool408AkNP@0P7Ec101kKfd307MYIP@0LV=O101^
GET406YGD`@0IU5<101RC4H305m6@0@0Fd0i101H>c<405Df;@@0DS4X101@;2<405@^8P<0HCT/101V
?c8405ll<@@0G3Xa101I>S<405Hj<`<0E3Xd101B>C@404li=0@0D3/h101B@Sl40553@@<0DDA3101?
AD@404i5A0@0C4A3101:@T8404Q3@P@0AdE50`17AdP404Q;C0@0BDiA101<DeH4051KG@@0EV9U0`1L
Jfl406=cN0@0IWQm101UN7h406=hO`@0HgV2101UO8H306N0RP@0J8:=101YQ90407VAV`@0O9:J101n
TIT3082@U`@0PHnE1022SI<408><T0@0Q8Z>1025RH`308J7RP@0QhJ71027Q8D408R3PaH0oooo000D
0?ooo`@0Q7]j1020MG<407]_K@<0MfUV101bHel406iMF@@0JUMC101VDD`4069<AP<0GdI0101K@3T4
05Pk<`@0ECH]101B<BP4050/8`@0E2hR0`1Q>B`406Ho<P@0Gc`a101L>S4405Tj<`@0ESXc0`1D>S@4
058i=0@0CcTd101@>cP40592?`@0DD=10`1AA4<404m5A0@0CTE4101<A4<404Y2@P@0B4=21017ADD3
04M7B0@0B4]<1019CU4404aCEP@0D5]M101FHVD305a[K`@0Hg=h101VN7d406EhOP@0HgQo101SNH84
06ElQP<0Ih2:101XPXd406V4T0@0NI6K101lTYX407jAV@<0P92G1021SiD408:=T`@0Phb@1024RXh4
08F9S0<0QXN:1027QXL408N4Q@@0R8>35P3oool001@0oooo1024NgX4081eL`@0Nfm]0`1gJFH4079S
G`@0KUeI101ZEe<406IAC0@0HTa60`1OAT0405]0>@@0F3/c101E=Rd4058a:0@0D2`S101D;R83064i
;0@0ISlb101O?34405`j<@@0FCXc101F>S<305@j=0@0DSTd101?>C@4050k>0@0DT8o101A@d430554
@`@0CdE4101>AD@404a4@`@0BT921018@d8404M5A@<0AdM81018Bd`404U>D@@0C5=F101@Fed405IR
I@<0G6]_101SLgP406IhO@@0IGQn101SN7l406=iPP@0IGb60`1WP8X406R2S@@0JHB@101iTI/407bB
VP@0OY6I0`20T9L4086?U@@0PXfC1023S90408B:SP@0QHV<0`26QhX408N6Q`@0QhB51028Ph<F0?oo
o`00503oool408AkN@@0OgAb101jKV/307EWI@@0LF5N101/FeL406QED0@0Hdm9101PBD<305a3?0@0
F3df101E>30405<c:P@0DBhT101A:b0405@^8P<0F3<X101J>2d405Xi;`@0F3Ta101F>C<405<i=0<0
DCXd101?>C@404hh=0@0CSXg101>?S`404i1?`<0CD91101<@T4404Y1@@@0B4511016@40404A0@0@0
@d520`13A4H404A8BP@0ADa?101:DUH404iIG@@0Df1T0`1IJ6`405i_M0@0HWEj101RMWh4065fO`@0
HGN1101SNhD306EoR@@0IX6=101VPi0407VBW@@0OYBN101oTi/3082AV@@0PI2F1022SY@408>=TP@0
Q8^?1025RXd308J8RP@0QhJ81027QHD408R3PaH0oooo000D0?ooo`@0Q7]i101oM78407Y^J`<0MFMU
101aHEh406aKE`@0J5E@101SCdT40619@`<0G4<l101H?CH405Dh<0@0Dc<Z101A;R@4054[80@0E2hR
0`1H<bP405Xh;@@0FST_101H>C4405Hi<`@0DcTd0`1A>S@404li=0@0CSPd101>>SL404hn?0@0CT4o
0`1=@T4404a2@@@0BT511018@D4404I0@0@0A4101013@D8304=4AP@0A4Q:1015C4l404YBEP@0CUUM
101CH6@305UXK0@0GVmd101RMGX4069fOP@0HGIo101QMh4406=kQ@<0IGn9101VPHd406J3T0@0NI:M
101nU9h407nCV`<0P96I1021T9H408:>U0@0PhfB1024Rhl408F:S@<0QXR:1027QXP408N5Q@@0R8>3
5P3oool001@0oooo1024NgT407mdLP@0NVi[0`1eIfD4075QGP@0K5]G101XEE0406=?B@@0H4U30`1L
@c`405Pm=P@0ECP`101C<bX4054^90@0DB/P101D;R8305Pc:0@0FSP]101J>Bl405Pi<@@0ESTc101C
>C@3054j=0@0CcTd101>>3@404hj=`@0CShl101>@Cl304e2@@@0C491101:@D4404Q1@@@0AT101014
@40404=1@P<0@dA61014B4X404E<C`@0BU9F101>FEd405=PI0<0FFQ/101NKg@4069eNP@0HWIn101Q
MWl4065gP@@0Hg^50`1UOhT406J1S@@0IX>@101iTYd407jDWP@0Oi>K0`20TIT4086@UP@0PXjD1023
SI8408B;S`@0QHZ=0`26R8X408N6R0@0QhF51028Ph<F0?ooo`00503oool408AkN@@0OgAb101jKV/3
07EWI@@0LF5N101/FeL406QED0@0Hdm9101PBD<305a3?0@0F3df101E>30405<c:P@0DBhT101A:b04
05@^8P<0F3<X101J>2d405Xi;`@0F3Ta101F>C<405<i=0<0DCXd101?>C@404hh=0@0CSXg101>?S`4
04i1?`<0CD91101<@T4404Y1@@@0B4511016@40404A0@0@0@d520`13A4H404A8BP@0ADa?101:DUH4
04iIG@@0Df1T0`1IJ6`405i_M0@0HWEj101RMWh4065fO`@0HGN1101SNhD306EoR@@0IX6=101VPi04
07VBW@@0OYBN101oTi/3082AV@@0PI2F1022SY@408>=TP@0Q8^?1025RXd308J8RP@0QhJ81027QHD4
08R3PaH0oooo000D0?ooo`@0Q7Yi101nM78407U]JP<0M6IS101_Ge`406YIE@@0IE9>101QC4H405e5
@0<0FCli101E>C84058d;0@0D2lV101>:b0404hY7@@0Cb/P0`1A;R@405<c:P@0ECH^101D>344058h
<P@0D3Pc0`1>>3<404dg<`@0BcLc101;>CH404/l>@@0Bcln0`1:@3l404Po?`@0Achn1014?Sh404<n
?P@0@3dn1010?d430412A0@0@DI:1014Bdl404UBEP@0CEUN101BH6D305MWK0@0Ffec101NLWT405mc
O0@0GWAm101OMh04065kQ@<0I7j9101UPHd406F3T0@0NY>M101nUIh4082DW@<0PI>K1022TIP408>@
UP@0PhjC1024S90408F:SP<0QXR;1027QhP408N5QP@0R8>35P3oool001@0oooo1024NWT407idLP@0
NFeZ0`1dIV<406mOG0@0JUUE101UDTh4065<AP@0GDE00`1I?cT405Di<P@0DS@/101@;bH404h[80@0
CRTM101?:b03054^90@0Dc<Z101E=Rh405@h<@@0DSPb101@>3<304hh<`@0CCLc101;=c<404/i=P@0
Bc`i101;?ch304Y0?`@0B3lo1017?Sh404@n?P@0@chn1010?Ch4040o@@<0@4941011ATX404A;C`@0
BE9F101=FEh4059PI@<0EfM/101KKG<405ibN@@0Gg=l101NM7d405mgP0@0HG^50`1TOXT406F1S@@0
IH>@101jTid407jEWP@0P9BM0`21Ti/408:AV0@0Pi2F1023SY<408B<T0@0QHZ>0`26R8/408N7R0@0
QhF61028Ph<F0?ooo`00503oool408AjN@@0OWAb101iKFX307AVH`@0KemL101ZFED406EBCP@0HDa6
101MAD0305To>@@0ECTb101B=2`4050_9P@0CR/P101>:Ad404l[80<0DBhT101C<bX405Df;P@0E3Pa
101B>384050h<`<0CSPc101==c<404/g<`@0BcTf101;?3T404/o?P<0BT0o1018?cl404Ln?P@0A3hn
1013?Sh4040m?P@0@3m10`10@T@40456BP@0A4]?1019DUH404eIGP@0DV1U0`1GIf`405]]L`@0GW9i
101OLg`405idO@@0GgN0101QNhD306AnR@@0IH6=101UPi0407ZCW@@0OYFN1020U9d3086CV`@0PY6H
1023T9H408>>T`@0Q8b@1025RXh308J8R`@0QhN81027QHH408R3PaH0oooo000D0?ooo`@0Q7Yi101n
M78407U]JP<0M6IS101_Ge`406YIE@@0IE9>101QC4H405e5@0<0FCli101E>C84058d;0@0D2lV101>
:b0404hY7@@0Cb/P0`1A;R@405<c:P@0ECH^101D>344058h<P@0D3Pc0`1>>3<404dg<`@0BcLc101;
>CH404/l>@@0Bcln0`1:@3l404Po?`@0Achn1014?Sh404<n?P@0@3dn1010?d430412A0@0@DI:1014
Bdl404UBEP@0CEUN101BH6D305MWK0@0Ffec101NLWT405mcO0@0GWAm101OMh04065kQ@<0I7j9101U
PHd406F3T0@0NY>M101nUIh4082DW@<0PI>K1022TIP408>@UP@0PhjC1024S90408F:SP<0QXR;1027
QhP408N5QP@0R8>35P3oool001@0oooo1023NWT407icL@@0N6aY0`1bI68406eMFP@0J5IB101SCd/4
05i9@`@0FD8l0`1E?3D4058f;P@0Cc0X101<:b4804/V6`@0BRLN0`1=;2<4050b:P@0DS@]101@=S04
04lg<@@0CCLa0`1;=S8404Xf<P@0B3Hb1018>3@404Li=`@0Ac`k0`17?ch404Dn?P@0@cdm1011?Ch4
040l?P@0?C/m100m?D0303e1A0@0@4I:1012BTl404MAEP@0BeQN101AH6H305EVK@@0FFac101KL7P4
05]aNP@0Fg=m101MMX04061jQ@<0Hgj9101VPXd406J3T0@0N96K101oUj04086FW`<0PYFM1022TiX4
08>AU`@0Q8nD1024SI4408F;S`<0QXV<1027QhT408N5QP@0R8>35P3oool001@0oooo1023NWT407ic
L@@0N6aY0`1bI68406eMFP@0J5IB101SCd/405i9@`@0FD8l0`1E?3D4058f;P@0Cc0X101<:b4804/V
6`@0BRLN0`1=;2<4050b:P@0DS@]101@=S0404lg<@@0CCLa0`1;=S8404Xf<P@0B3Hb1018>3@404Li
=`@0Ac`k0`17?ch404Dn?P@0@cdm1011?Ch4040l?P@0?C/m100m?D0303e1A0@0@4I:1012BTl404MA
EP@0BeQN101AH6H305EVK@@0FFac101KL7P405]aNP@0Fg=m101MMX04061jQ@<0Hgj9101VPXd406J3
T0@0N96K101oUj04086FW`<0PYFM1022TiX408>AU`@0Q8nD1024SI4408F;S`<0QXV<1027QhT408N5
QP@0R8>35P3oool001@0oooo1023NWT407icL@@0N6aY0`1bI68406eMFP@0J5IB101SCd/405i9@`@0
FD8l0`1E?3D4058f;P@0Cc0X101<:b4804/V6`@0BRLN0`1=;2<4050b:P@0DS@]101@=S0404lg<@@0
CCLa0`1;=S8404Xf<P@0B3Hb1018>3@404Li=`@0Ac`k0`17?ch404Dn?P@0@cdm1011?Ch4040l?P@0
?C/m100m?D0303e1A0@0@4I:1012BTl404MAEP@0BeQN101AH6H305EVK@@0FFac101KL7P405]aNP@0
Fg=m101MMX04061jQ@<0Hgj9101VPXd406J3T0@0N96K101oUj04086FW`<0PYFM1022TiX408>AU`@0
Q8nD1024SI4408F;S`<0QXV<1027QhT408N5QP@0R8>35P3oool001@0oooo1023NWT407icL@@0N6aY
0`1bI68406eMFP@0J5IB101SCd/405i9@`@0FD8l0`1E?3D4058f;P@0Cc0X101<:b4804/V6`@0BRLN
0`1=;2<4050b:P@0DS@]101@=S0404lg<@@0CCLa0`1;=S8404Xf<P@0B3Hb1018>3@404Li=`@0Ac`k
0`17?ch404Dn?P@0@cdm1011?Ch4040l?P@0?C/m100m?D0303e1A0@0@4I:1012BTl404MAEP@0BeQN
101AH6H305EVK@@0FFac101KL7P405]aNP@0Fg=m101MMX04061jQ@<0Hgj9101VPXd406J3T0@0N96K
101oUj04086FW`<0PYFM1022TiX408>AU`@0Q8nD1024SI4408F;S`<0QXV<1027QhT408N5QP@0R8>3
5P3oool001@0oooo1023NWP407ebL0@0MfYX0`1aHf0406]KF0@0IEA@101PCDP405]5@0@0EShi0`1A
>34404ha:P@0BR/S10189Q`404HQ5`@0AB8I101691/304X]9@@0CS8[101>=2d404df;`@0BcD`1019
=C0304Pd<0@0AS@`1015=34404@e<`@0@cLe1014>ST304@m?@@0@S`l1010>c/403hj?0@0?3Tk100j
>C/403Tj?@<0>Sm2100lA4T4041:C`@0A55F1019F5h404iOIP<0DfE]101EJW8405I]M@@0Efmh101I
LW`405]eO`@0GWV40`1SOXT406N3S`@0KHRC101jTY`4082HXP@0PiZS0`23Uj0408>DW0@0Pi:I1024
T9H408B>TP@0QHb?0`26RX`408N7R@@0R8F61028Ph<F0?ooo`00503oool408=jN0@0OG9`101gJVP3
075SH0@0Je]H101UE504061=B0@0FdE0101F?ST3054h<@@0CS4Z101::b<404PV70@0AR4G10158QT4
04HT6`<0BRdU101><R/404hd;@@0CCH_101;=C0404Te<0<0B3@`1016=30404Dd<@@0A3Dc1013=cD4
04@j>@<0A3dm1012?3`4040k>`@0?SXl100l>C/403Xi>`@0>CXm0`0j?d8403a4B@@0@4Y?1014DEH4
04UHGP@0CUmV0`1CIFd405EZLP@0EVee101GKgP405UbO0@0FgEo101NNH@306=nR@@0Ih>?101]R9<4
07ZBW0@0P9RR1023VZ<308>GX0@0PiBL1023TYT408B@UP@0Q8jB1025S8l308J:S0@0QhN91028QHH4
08R3PaH0oooo000D0?ooo`@0PgYh101mLW0407MZJ0<0LF=P101[FeP406EDD0@0H4e8101KAD0405Hn
>@<0DCPa101><BX404X[8`@0B2HL10168AL404DR6@@0AR@K0`1:;BD404hb:`@0CS@]101==Rl404/e
<0@0BCD`0`18=30404Hd<0@0AC@a1014=C<404<g=@@0A3Xi0`14?Cd4048l?0@0@3/k100n>S`403`i
>`@0>STk100i>Sd303Xo@P@0?4A91010BTl404AAEP@0BEQN101>GfH305=UK@@0EFYb101FKGD405M_
N0@0FG9l101KMGl405iiQ0<0Hgj9101WPhl406f8T`@0NY:L1020V:8408>JX`<0PiNP1023U9`408>B
V@@0Q92F1024SY8408F<S`<0QXZ<1027QhT408R5QP@0R8>35P3oool001@0oooo1022NGP407aaK`@0
MFUW0`1_HEh406UIEP@0HU5>101MBTD405M2?@@0DS/e0`1=<bd404T]9@@0ABHN10127aH4040K4P@0
@1dE10139Ad304P_9`@0BS8[101:=2d404Td;P@0B3<_1016<Rh304@a;@@0@c4^1012<Bl4040c<0@0
@3Dd1011>CT3044k?0@0?cXk100m>3X403/h>P@0>CHi100f=ST403Dh?0<0=ce2100i@TL403e9CP@0
@DmE1017Eeh404aOIP<0CfA/101AIfl4059YLP@0Df]e101FKWT405UcOP@0GGR30`1ROHT406R3S`@0
KXVD101iTil408BOZP@0RJ6Z0`24VJ8408>FWP@0Pi>J1024TIL408B>T`@0QHb@0`26RXd408N8RP@0
R8J71028Ph@F0?ooo`00503oool4089iN0@0O75_101eJFL306mQGP@0JEUF101RDDh405e:A@@0Ed8m
101B>cD304dc;@@0BBdU10159Qh4048O5P@0@1/B10107AD404<U7@<0B2lW101:<R/404Xd;@@0BC@^
1018<bl404Hb;P<0A34]1013<Bh4048a;`@0@3<`1010=C@4044i>@<0@C/l100o>S/403dh>P@0>cPj
100i=ST403Hf>@@0=CPl0`0g?D8403U2A`@0?DU>1011CeD404MGGP@0C5mV0`1?I6`4055WK`@0DVUb
101CJgD405I^N@@0FG=n101MN8<3069mR@@0J8>?101^RI@407VCW`@0Q9nZ1029XJX308BIXP@0PiJN
1023TiX408BAU`@0Q8jC1025S90308J:S@@0QhR:1028QXL408R3Q1H0oooo000D0?ooo`@0PWUh101l
LFl407EYI`<0Kf5N101YFEH4069ACP@0GDY5101G@Sd4058k=@<0CC<]1019;BD404DV7P@0@QlF1010
6a84040M5@@0@bDM0`18;bL404Xb:`@0BS@]1019=2h404Pc;`@0AS8^0`14<Bd404<a;P@0@S4_1010
<c04040e=0@0@CTi0`11>c`403lj>`@0?CPj100k>3X403Tf>@@0=SHi100e>3`303Lm@P@0>D97100m
BDh4045?E@@0AeMN101<GfH304mTK0@0DFM_101BJG8405=[M@@0EVii101ILgh405ehP`<0HWf9101X
Phl406j9U0@0NI>O1024WjX408VQZP<0Q9VR1023UYh408>CVP@0Q96G1024SY<408F<T0<0QXZ=1027
R8X408R6Q`@0R8>45P3oool001@0oooo1022NGP407aaK`@0MFUW0`1_HEh406UIEP@0HU5>101MBTD4
05M2?@@0DS/e0`1=<bd404T]9@@0ABHN10127aH4040K4P@0@1dE10139Ad304P_9`@0BS8[101:=2d4
04Td;P@0B3<_1016<Rh304@a;@@0@c4^1012<Bl4040c<0@0@3Dd1011>CT3044k?0@0?cXk100m>3X4
03/h>P@0>CHi100f=ST403Dh?0<0=ce2100i@TL403e9CP@0@DmE1017Eeh404aOIP<0CfA/101AIfl4
059YLP@0Df]e101FKWT405UcOP@0GGR30`1ROHT406R3S`@0KXVD101iTil408BOZP@0RJ6Z0`24VJ84
08>FWP@0Pi>J1024TIL408B>T`@0QHb@0`26RXd408N8RP@0R8J71028Ph@F0?ooo`00503oool4089i
M`@0Ng1^101dJ6H306eOG@@0IUMD101OCd/405U6@P@0Dchj101==c4304P_:@@0@bLQ100o8AT403`J
4P@0>aTA100l7aL4044Y8@<0Ac0Y1019<R`404Lb;@@0AS8]1014<Bd4048`;0<0@Bl/100o;R`403h_
;@@0?C0_100n<c8403hf=`<0?SPj100l>3X403Xg>P@0>CLj100f=CP403<e>@@0<SLl0`0d?44403I1
A`@0>dQ>100oCeL404IGG`@0BEeU0`1;HFT404eSK@@0CFE`101?J7<405=/N0@0EW5m101KMX83061l
R0@0IX>?101/Qi@407FAW@@0OY^W1021VjH308:IXP@0PYJO1023U9/408BAV0@0Q8nD1025SI4308J;
SP@0QhR:1028QXL408R4Q1H0oooo000D0?ooo`@0PWUg101kL6h407AXIP<0KEmM101VEe@405m?B`@0
FDI2101C?SX404dg<@<0B2lY10139b4403lQ6@@0?1XB100k6A4403`O5`@0@BTQ0`17<2T404Tb;0@0
Ac8]1016<Rd404@a;@@0@S0/0`11;b`403l^;0@0?Rl]100m<2l403hc<P@0?SHg0`0n>3X403`h>P@0
>SLj100i=cX403He>0@0<cDi100b=c`303@l@@@0=T57100kB4h403m?E`@0AUMO1019GFD304]QJ@@0
CF=]101=IG0404mXL`@0Dfah101FLGd405]fPP<0H7b8101VPhl406b7U0@0MI6M101nVjL4086KYP<0
PYVR1022UYl408>DV`@0Q96H1024Si@408F=T@<0QX^>1027R8X408R6Q`@0R8B45P3oool001@0oooo
1022NGL407]`KP@0M6QV0`1]Ged406IGE0@0Gdm;101IAT8405<n>P@0CCLa0`18;bT404<W8@@0?b4I
100l6Q8403/I4@@0?1lG1011:B4304L`:@@0BC8/1017<Rd404Hb;@@0A34]1012<2`3044_;0@0?bh/
100n;bd403d`;`@0?S<b100n=SL303hh>P@0?3Pj100j=cX403Tg>P@0=SDh100c=CT4038g?0<0=3a1
100f@DL403]8CP@0?dmG1016Eel404UMI@<0Bf5Y101=Hfd404eUL0@0CfQc101CK7P405IaO@@0FgJ2
0`1PO8P406J3S`@0K8ND101eTId407jKY`@0PI^V0`22VJ8408:FW`@0PiBK1024TIP408B?U0@0QHfA
0`26Rhh408N8RP@0R8J71028Q8@F0?ooo`00503oool4089iM`@0Ng1^101dJ6H306eOG@@0IUMD101O
Cd/405U6@P@0Dchj101==c4304P_:@@0@bLQ100o8AT403`J4P@0>aTA100l7aL4044Y8@<0Ac0Y1019
<R`404Lb;@@0AS8]1014<Bd4048`;0<0@Bl/100o;R`403h_;@@0?C0_100n<c8403hf=`<0?SPj100l
>3X403Xg>P@0>CLj100f=CP403<e>@@0<SLl0`0d?44403I1A`@0>dQ>100oCeL404IGG`@0BEeU0`1;
HFT404eSK@@0CFE`101?J7<405=/N0@0EW5m101KMX83061lR0@0IX>?101/Qi@407FAW@@0OY^W1021
VjH308:IXP@0PYJO1023U9/408BAV0@0Q8nD1025SI4308J;SP@0QhR:1028QXL408R4Q1H0oooo000D
0?ooo`@0PGQg101jKfh4079VI0<0JeeK101SEE8405a<B0@0ED<o101?>cH404Pb;@<0@bXT100m8Q/4
03PJ4P@0=AH>100d610403PP60@0?b/S0`15<BX404Ha;0@0AC4/1013<2`4044_:`@0?bdZ0`0m;2T4
03//:P@0>R`[100j;Rd403X`<@@0>S@e0`0k=SP403Xf>@@0>3Hi100f=CT403<c>0@0<3<h100`=S/3
034k@@@0=D58100iB4l403i?E`@0@UEM1014FF8304IMI`@0B5mZ1019HVd404]VL@@0CfYf101CKg/4
05MeP@<0GG^7101SPHh406Z6TP@0LXnL101iUj<407fHY0<0P9RR1021Uj0408:DW0@0Q9:I1024T9D4
08F>TP<0QX^?1027RH/408R6Q`@0R8B45P3oool001@0oooo1021N7L407Y_KP@0LVIT0`1[GE/406=E
DP@0G4a8101E@cl404lk=P@0B38]0`13:R@403dR6`@0>1XB100e5Ph403@H40@0>20H100o:b<304Da
:P@0AS4/1015<B`404<`;0@0@Bl[100o;BX303d/:@@0>b`Z100j;2/403X^;@@0>S0a100j=3D303/f
>0@0>SHi100h=ST403He>@@0<c<h100`<cP4030f>`<0<C]1100e@DP403U8C`@0?TmG1012EEd404AI
HP<0AUeW1018GfX404URK@@0BfIa101?JWH405=_N`@0EgF10`1MNhL406>1SP@0JXJB101bSi`407VG
X`@0OIRT0`20V:84086GX0@0PYBL1024TYT408B@U@@0QHjB0`26Rhl408N9R`@0R8J71028Q8@F0?oo
o`00503oool4085hM`@0NVm^101bIV@306]MF`@0HeEB101LC4P405E3?`@0Cc/f1018<Rd304<Z90@0
?B8K100h6Q8403DF3P@0=1P@100h81P403l[8`<0AC4Z1016<B`404Da;0@0@c0/1011;b/403l]:P<0
?B`Y100k;2X403X/:`@0>Rh]100j<34403Xd=@<0>cHh100j=ST403Pf>@@0=SDi100c<cP4030c>0@0
<3Hk0`0a>d4403E1B0@0>DQ?100nCeL4049EG@@0A5UR0`16GFL404QOJP@0BF9]101;IW4404mZMP@0
Dfmk101GMH4305ekQ`@0Hh6>101ZQY8407:?W0@0NINS101mV:@3082HXP@0PINP1022U9`408BBV@@0
Q92E1025SY8308J;S`@0QhV;1028QXL408R4Q1H0oooo000D0?ooo`@0PGQg101jKfh4079VI0<0JeeK
101SEE8405a<B0@0ED<o101?>cH404Pb;@<0@bXT100m8Q/403PJ4P@0=AH>100d610403PP60@0?b/S
0`15<BX404Ha;0@0AC4/1013<2`4044_:`@0?bdZ0`0m;2T403//:P@0>R`[100j;Rd403X`<@@0>S@e
0`0k=SP403Xf>@@0>3Hi100f=CT403<c>0@0<3<h100`=S/3034k@@@0=D58100iB4l403i?E`@0@UEM
1014FF8304IMI`@0B5mZ1019HVd404]VL@@0CfYf101CKg/405MeP@<0GG^7101SPHh406Z6TP@0LXnL
101iUj<407fHY0<0P9RR1021Uj0408:DW0@0Q9:I1024T9D408F>TP<0QX^?1027RH/408R6Q`@0R8B4
5P3oool001@0oooo1021N7L407U^K@@0LFES0`1YG5T4065BD0@0FDU6101A@3`404Xg<`@0@bhY0`0m
9B0403HL5P@0<1<<100[40X402/D3P@0<alI100n:bD304@a:`@0A34/1013<2`4044_:`@0?RdY100k
:bT303TZ:0@0=bTY100f:RX403H/;0@0=c0`100h<c@303Pe=`@0>3Hi100f=CT403<d>0@0<3<g100^
<cP402df>`<0;cY1100b@4L403I7CP@0>TaE100mDE/403mFH0<0@EUT1013G6L404EPJ`@0B6A`101<
J7D404m^N`@0E7>00`1JNHH4061oS0@0IX>?101^SIT407FCX0@0O9VU0`1oVJ<4086GX@@0PYFM1023
TiX408FAU`@0QHjC0`26S8l408N9S0@0R8N81028Q8@F0?ooo`00503oool4085hM`@0NFi]101aIF<3
06ULF@@0HE9@101IBDH40550?0@0BSLc1013;RT303dU80@0=Q`F100`4``402/@2P@0:a@>100c7aT4
03h[9@<0A34[1014<B`404<`;0@0@Bl[100n;BT403/[:@<0>BXX100g:BT403HZ:P@0=R`/100g<304
03Pc=0<0>3Dg100h=ST403He>@@0<c@h100`<cL402hc>0@0;CHk0`0_>T440390A`@0=TM>100jC5D4
03eAF`@0?eIP0`11FF@404=LI`@0AF1[1018I70404aXM@@0Cfik101DLh0305YiQP@0H7n<101VPhl4
06j=V@@0MI>P101lVJD307nIX`@0PINQ1022UId408>CVP@0QI6G1025SY<308J<S`@0QhV<1028QhP4
08R4Q1H0oooo000D0?ooo`@0PGQg101iKVd4075UH`<0JEaI101QDU0405U9AP@0DD0l101:=c<404<^
:@<0?BDP100f71H4030C30@0:a0:100[50h403<O6@@0?R/U0`14<B/404@a;0@0@c0/1011;b/403h]
:@@0>b/Y0`0i:RP403LY:@@0=RXZ100f;2`403L`<0@0>3<d0`0h=CL403Pf>@@0=SDi100c=3P4030c
=`@0;S<h100]=S/302lj@@@0<T17100fAdh403Y<E@@0?E5K100oEV03045II0@0@eaW1015H6/404QT
L0@0C6Qe101?KW/405AcP0<0FWV6101POh`406J3S`@0KXfI101eTj0407bIY@<0OiVS1021Uj4408:E
W@@0Pi>J1025TIL408F>T`<0QXb?1027RH`408R7R0@0R8B45P3oool001@0oooo1021N7L407U^K@@0
LFES0`1YG5T4065BD0@0FDU6101A@3`404Xg<`@0@bhY0`0m9B0403HL5P@0<1<<100[40X402/D3P@0
<alI100n:bD304@a:`@0A34/1013<2`4044_:`@0?RdY100k:bT303TZ:0@0=bTY100f:RX403H/;0@0
=c0`100h<c@303Pe=`@0>3Hi100f=CT403<d>0@0<3<g100^<cP402df>`<0;cY1100b@4L403I7CP@0
>TaE100mDE/403mFH0<0@EUT1013G6L404EPJ`@0B6A`101<J7D404m^N`@0E7>00`1JNHH4061oS0@0
IX>?101^SIT407FCX0@0O9VU0`1oVJ<4086GX@@0PYFM1023TiX408FAU`@0QHjC0`26S8l408N9S0@0
R8N81028Q8@F0?ooo`00503oool4081gMP@0N6e/101_I68306IJF0@0GU1=101EAT<404dl>@@0AC<_
100n:BD303HP6`@0<1LB100X3PP4028=20@09aDA100b81`4040^:0<0@c8/1013<Bd4044`;0@0?bh[
100k;2T403PZ:0<0=BPX100c:2P4038X:@@0<bX[100d;Rl403Ha<`<0=c@g100f=CT403@e>@@0<S@h
100^<SL402/a=`@0:S@k0`0/>D0402lnAP@0<TE=100eBU<403Q>F0@0>E9M0`0lEF4403iII@@0@EeY
1014HFh404QVL`@0C6]i101ALGl305MgQ@@0G7b:101QPHh406Z;V0@0Li:O101kW:T307jJYP@0P9RR
1022UYl408>DV`@0QI:H1026Si@308N<T0@0QhZ<1028QhP408V4Q1H0oooo000D0?ooo`@0P7Mf101h
KF`406mTHP<0IUYH101ND4d405E6@`@0CC`i1015<bl403hY9@<0=R0K100`5a8402P>20@08Pd8100W
5A44038P70@0@2hX0`13<R`404<a;@@0@C0/100o;R/403//:@@0>2XX0`0e:2P403<X:0@0<RPY100c
:R/403@^;`@0=S4c0`0g=3L403He>@@0=3Di100b=3P402hb=`@0:c4g100Z=3/302`i@0@0;ci6100b
ADd403E:D`@0>4iH100iDUd303aEH@@0?UUU1011GFT404AQKP@0B6Ic101<JgT4055aO`<0EgN5101L
O8X40661SP@0JX^H101cTYl407^LZ@<0OYZV1020V:8408:FW`@0PiBK1025TYP408J?U0<0Qhb@1027
RX`408R7R0@0RHB45P3oool001@0oooo1020MgH407Q]K0@0KfAR0`1VFUP405i@C@@0EDI3101=?3T4
04Dc;`@0?RTU0`0f81/4030G4P@0:0h8100R3@P402LE4@@0<R0L1010;RP304<b;0@0@c4]1011<2`4
03l^:`@0>b`Y100h:RP303DX:0@0<bPX100b:2T403<Z:`@0=2h_100f<C<303Ld=`@0=SDi100d=CT4
038d>0@0;S8g100[<CL402Xd>`<0;3U0100_?TH40395C@@0=DYC100hCUP403UBG@<0?5EQ100nFFD4
045MJ@@0A65^1018IW<404a[N@@0DG5o0`1GMhD405alRP@0HH6>101ZRiP407>BW`@0NibY0`1nVZH4
082HXP@0PYJO1023U9/408FBV0@0QXnD0`27S90408N:S0@0R8N81029Q8@F0?ooo`00503oool4081g
MP@0N6e/101_I68306IJF0@0GU1=101EAT<404dl>@@0AC<_100n:BD303HP6`@0<1LB100X3PP4028=
20@09aDA100b81`4040^:0<0@c8/1013<Bd4044`;0@0?bh[100k;2T403PZ:0<0=BPX100c:2P4038X
:@@0<bX[100d;Rl403Ha<`<0=c@g100f=CT403@e>@@0<S@h100^<SL402/a=`@0:S@k0`0/>D0402ln
AP@0<TE=100eBU<403Q>F0@0>E9M0`0lEF4403iII@@0@EeY1014HFh404QVL`@0C6]i101ALGl305Mg
Q@@0G7b:101QPHh406Z;V0@0Li:O101kW:T307jJYP@0P9RR1022UYl408>DV`@0QI:H1026Si@308N<
T0@0QhZ<1028QhP408V4Q1H0oooo000D0?ooo`@0P7Mf101fKF/406eRH@<0I5QF101JCD/40553@0@0
B3Pf100o;R/403LT8@<0<1/G100Y4Ph402<;1`@080h;100X5a@403@S7`@0A38/0`15=2h404<b;P@0
@C4]100n;b`403T[:@@0=2PW0`0_9BD402dT9@@0;2DW100_:2X4038^;`@0=C4c0`0f=3L403Hg>`@0
=3Lk100a=CX402db>0@0:C8g100X=3X302Th?`@0:ce6100^@T`40317D@@0<DYE100dCeX303MCG`@0
>EMS100mG6P4045PK@@0AFEc1019JWP404i_O@<0DgF3101HNXP405enS0@0IhNF101bTj4407^NZ`<0
OYbX1020VZ@408:HX0@0Q9FM1025TiT408J@U@<0QhfA1028RXd408R7R@@0RHB45P3oool001@0oooo
1020MgH407I]J`@0KF9Q0`1TF5H405Y=B`@0DD=01018>3H403l^:`@0=b@Q0`0`6aL402TB3P@08`/7
100P3P/402PG50@0=2<O1014<R`304Dd;P@0@c8^1011<Bd403h_;0@0>B/Y100d:2L302lU9@@0;B@U
100/9BL402lX:P@0<Rh_100e<C<303Hd=`@0=SLk100d=c/4034e>P@0;C8h100Y<SL402Pd>P<0:CPo
100[?DH402i2C0@0<4MA100aBUD403A?FP<0=e=O100iEf<403eLJ0@0@F1]1015IG<404UZN0@0CVmm
0`1CMH<405QjR0@0GGj<101WQiH407:CX@@0Nij[0`1nW:P4082JY0@0PYRP1024UId408FCV@@0QY2E
0`27SI4408R:S@@0R8N91029Q8@F0?ooo`00503oool4081gMP@0MVe[101]HV4306AHEP@0FTe;101A
@d0404Ph=P@0?bh[100g9243030K5`@0:A8>100S2`L4020>2`@0:1LD100d8al404@b;0<0AC@^1013
<Rh4044a;@@0?Rl/100i:bT403@X9`<0;bDU100]92D402`U9`@0;bPZ100b;Rl403Da<`<0=S@g100f
=c/403@g>`@0<CDj100]<SP402Tb=`@0:3@j0`0Y>3l402/mAP@0;T9<100`Ae44035:E@@0=4mJ0`0g
Del403UGH`@0?EaX1011H6d404EUL`@0BFYh101>Kgd305=eP`@0F7Z8101MOX`406N7UP@0LY>Q101k
WZ/307jLZ0@0P9ZT1022V:0408BEW@@0QI>I1026T9D308N=T@@0R8Z=1028QhT408V4Q1H0oooo000D
0?ooo`@0OgIe101eK6X406]QG`<0HEID101GBdT404e0?P@0@c@b100i:BL4030O70<0:ADB100R3@T4
01d91P@060X8100R5a@403DV8P@0B3H`0`17=S4404De<0@0@S<`100n<2h403T]:`@0=2XY0`0_9bP4
02/V:0@0:bHY100_:R`403<`<P@0=C8e0`0f=ST403Pj?P@0=CTn100a=c`402`c>@@0:38h100V<cX3
02Hg?`@09c]5100[@D/402a5D0@0;TQD100`C5P3039@G@@0=EAQ100kFVL403mOK@@0@V=b1016J7L4
04Y]O0<0D7>2101DN8L405YmS0@0IhVH101dUZD407bP[`<0OijZ1021VjH408>IXP@0Q9JN1026U9X4
08NAUP<0QhjB1028Rhd408R8R@@0RHF55P3oool001@0oooo101oMWD407E/JP@0Jf5O0`1QEU@405M;
B@@0CD0n1013=38403TY9`@0<1lL0`0Y5A84028=2@@07@T6100H2PP4028G50@0=BHR1018=S0304Lf
<@@0ACD`1012<c0403h`;P@0>Bd[100d:RT302lW:0@0:bHX100[9RT402lZ;0@0<c0b100e<SD303Hf
>@@0>3Xn100e>Ch4034g?0@0;3<i100X<SP402Hc>P<09SLo100W>dD402]1B`@0;4E@100^B5@4031<
F0<0<U1M100eE64403]JI`@0?em]1012Hg8404IXM`@0BVel0`1@Lh8405AhQ`@0FWf<101WRIP407BF
Y@@0O:2_0`1oWZX4086KYP@0PiVR1024UYh408JDVP@0Qi6F0`27SY8408R;S@@0R8R91029QHDF0?oo
o`00503oool407mfM@@0MFaZ101[HEl3065FE0@0Ed]9101=@3h404<d<P@0>BTW100`7a`302TE4P@0
8Pd9100M2@H401P:20@08QLD100e9R8404Pf<0<0AcHa1015=C04048c<0@0?S0^100i;B/403@Z:@<0
;bLX100[9RP402/V:@@0;bX/100c<38403Db=@<0=SHi100h>Sh403Di?P@0<CLl100/<cT402Pb>0@0
9S<j0`0V=cl402LkA@@0:d5;100/AE0402i8E0@0<4aH0`0bD5d403EDH@@0>eYW100oGfd4049SLP@0
AVQg101:KG`3051cPP@0E7R7101JOH`406N9V0@0M9JU101lX:l307nNZP@0PI^V1023VJ8408BFWP@0
QYBJ1027TIH308N>TP@0R8^=1028R8T408V5QAH0oooo000D0?ooo`@0OgIe101eK6X406]QG`<0HEID
101GBdT404e0?P@0@c@b100i:BL4030O70<0:ADB100R3@T401d91P@060X8100R5a@403DV8P@0B3H`
0`17=S4404De<0@0@S<`100n<2h403T]:`@0=2XY0`0_9bP402/V:0@0:bHY100_:R`403<`<P@0=C8e
0`0f=ST403Pj?P@0=CTn100a=c`402`c>@@0:38h100V<cX302Hg?`@09c]5100[@D/402a5D0@0;TQD
100`C5P3039@G@@0=EAQ100kFVL403mOK@@0@V=b1016J7L404Y]O0<0D7>2101DN8L405YmS0@0IhVH
101dUZD407bP[`<0OijZ1021VjH408>IXP@0Q9JN1026U9X408NAUP<0QhjB1028Rhd408R8R@@0RHF5
5P3oool001@0oooo101oMWD407A[JP@0JV1N0`1OE5<405A8A`@0BC`k100n<2l403<T8P@0:1PF0`0P
3``401`81@@06@T7100H3@/402LL6@@0>R/W101=>S@304Xj=0@0AcLc1013=C8403lc<@@0>c0_100g
;Bh303H];`@0<B`^100b;Bl403Pb=0@0>cPj100m>cd303m0@`@0?D96100g?D84034i?`@0:c@j100W
<CT402@b>P<093Do100S=d8402LoBP@09T5=100V@e0402Q7E0<0;TeK100bDf4403UII`@0?5e/1010
HW4404=WMP@0B6al0`1=LH44051eQP@0EW^<101URIT407BHY`@0OJ>a0`1oX:`408:MZ0@0Q9ZT1025
V:0408NEV`@0R9:G0`28Si<408V<SP@0RHR:1029QHDF0?ooo`00503oool407mfM@@0M6]Z101ZH5h3
05mDD`@0E4Q71019?3/403h`;`@0<b@R100X61H3020?30@070P5100I2@L401P=2`@09a`I100j:bL4
04dj=0<0BSXd1017=c<404<e<P@0?c<a100k<2l403L];P<0=Rd_100a;2h4038];`@0>38d100k>3X4
03dk?@<0?d13100m@TH403Lm@P@0<CTo100[=3X402La>@@0938j0`0T=Cl402<g@P@09cm:100V@Dd4
02I3D0@0:4MD0`0^CE/4039CH@@0>EUW100lGF`4041RL@@0@fMf1018K7`304eaP@@0D7F6101FNh`4
06F9V@@0M9RW101mXk4307nP[0@0PYfX1024VZ@408FHX0@0QiFK1028TYL308R?T`@0RHb>1029R8X4
08V5QAH0oooo000D0?ooo`@0OgIe101dJfX406YPGP<0GeAC101DB4L404Tl>`@0?S0_100c928402PH
5P<080l<100L20D401T91`@060d;100W71T403X[9`@0CCXd0`1:>S@404Lg<`@0@cDb100o<c4403/`
;`@0=bd^0`0f;Bl4034/;P@0<Rd_100h<S@403/h>P@0?C/m0`0o@4<403e2AP@0=ce2100a>Cl402/d
>P@09c4i100T<SX302@e?`@08cM2100W?dX402I1C@@09T=@100XAe@302i=F`@0<U=Q100iFFL403aM
K0@0@69a1013IgH404Q/O0<0CG61101@MHH405IkS0@0IHVI101dV:L407fS/@<0Oj2/1022WJP408BJ
Y0@0QIRP1027UI/408RBU`<0R8nC1029S8h408V8RP@0RHF55P3oool001@0oooo101oMWD407A[JP@0
JV1N0`1OE5<405A8A`@0BC`k100n<2l403<T8P@0:1PF0`0P3``401`81@@06@T7100H3@/402LL6@@0
>R/W101=>S@304Xj=0@0AcLc1013=C8403lc<@@0>c0_100g;Bh303H];`@0<B`^100b;Bl403Pb=0@0
>cPj100m>cd303m0@`@0?D96100g?D84034i?`@0:c@j100W<CT402@b>P<093Do100S=d8402LoBP@0
9T5=100V@e0402Q7E0<0;TeK100bDf4403UII`@0?5e/1010HW4404=WMP@0B6al0`1=LH44051eQP@0
EW^<101URIT407BHY`@0OJ>a0`1oX:`408:MZ0@0Q9ZT1025V:0408NEV`@0R9:G0`28Si<408V<SP@0
RHR:1029QHDF0?ooo`00503oool407ifM@@0LfYY101XGUd305eCD@@0DDI51015>SP403T/:`@0:ahM
100N40l301420@@050@2100E2@T401P@3`@0:1hL100m;RX4050n>0<0CC`g1019>SH404Dg=@@0@CDd
100m<c<403Xb<P<0>C4c100g<C<403dg>0@0@S`l1014@44404E3A0<0@TA7100m@dL403LoA0@0<CTo
100[=3X402Hb>@@093<l0`0T=d0402@jAP@09d9>100R@4h401m0C`@0:4MF0`0]CUd402mAH0@0=eQW
100kGF`4041RL@@0@VMg1016Jg`304U_P0@0Bg>4101BNX`406B:VP@0MIVX101nXk43082Q[@@0PijY
1025W:D408NIX@@0R9JM1029TiP308V@U0@0RHb?1029RHX408V5QAH0oooo000D0?ooo`@0OWIe101c
JVT406QNG@<0GE=A101AATD404Dj>0@0>B`[100[7Qd401h@3`<04@81100D108401D92@@0610?100X
7Q`403d^:P@0D3hh0`1=?3L404Tj=P@0ACLe1011=C@403dc<`@0>S8b0`0i<C<403La<`@0?CLh1012
?3`404A0@@@0AD=40`12A4L403e3A`@0=cm4100a>Cl402/d>P@09S8i100T<c`302@g@0@093Y6100W
@Th40290CP@07d1?100XAeH302e>G@@0;e5P100gF6L403]MK0@0@69a1012IgL404I[O0<0BFn0101;
Lh@4059jS0@0I8ZJ101eVJP407jS/@<0P:6]1023WZT408FLY@@0QiVQ1028UYd408VCV0<0RI2D1029
S8l408V9RP@0RHF55P3oool001@0oooo101nMWD407=ZJ@@0J5iM0`1MDe440556A@@0ACXh100i;2/4
02/N7@@07Q0?0`0A0P4401@40P@05@T9100H40l402PN70@0?BhZ101@?SP304dl=`@0BCXf1015=cD4
044e=0@0?C<c100j<S8303Ta<`@0=c4c100m=cP4048l?0@0A4111015@d@30494A`@0?D=7100g?d@4
034i?`@0:c@j100V<ST402@c?0<093M0100T>TH402M2CP@08T1>100O@4l402Q7EP<0;DiM100_DF04
03MHI`@0>ee/1010HW44049WM`@0AV]l0`19Kh0404]cQ0@0DWZ<101TRYX407FIZ0@0OZ>a0`20XJd4
08>NZ@@0QIbU1027VJ4408RFW@@0RI>H0`29T9@408V<S`@0RHV:1029QHDF0?ooo`00503oool407if
M@@0LfYY101XGUd305eCD@@0DDI51015>SP403T/:`@0:ahM100N40l301420@@050@2100E2@T401P@
3`@0:1hL100m;RX4050n>0<0CC`g1019>SH404Dg=@@0@CDd100m<c<403Xb<P<0>C4c100g<C<403dg
>0@0@S`l1014@44404E3A0<0@TA7100m@dL403LoA0@0<CTo100[=3X402Hb>@@093<l0`0T=d0402@j
AP@09d9>100R@4h401m0C`@0:4MF0`0]CUd402mAH0@0=eQW100kGF`4041RL@@0@VMg1016Jg`304U_
P0@0Bg>4101BNX`406B:VP@0MIVX101nXk43082Q[@@0PijY1025W:D408NIX@@0R9JM1029TiP308V@
U0@0RHb?1029RHX408V5QAH0oooo000D0?ooo`@0OWIe101bJVT406MNG@<0Fe9A101?AD@4048g=P@0
=2TX100U6AT401461P<02`00100B1`H4018;2`@05a4B100Z8Al4044b;@@0ED8l0`1@@3/404`m>P@0
ASPg1012=cH403lf=`@0?3Df0`0j=CH403Xe>0@0?3Pj1010?Ch404=1A0@0A4E70`11ADT403a3B0@0
=cm5100`>T0402Xd?0@09S<k100S=3d302@h@P@09Sa8100X@Th402Q3D0@09dEC100aCU/303=BH0@0
=UIT100nGF/4045QL0@0@fIf1012J7T404=[O0<0AFj01015L8<4055jS0@0IHZJ101gVJP407nS/P<0
PZ:_1025X:/408NNY`@0RI^S102:V9h408ZEVP<0RY6E102:SI0408Z9R`@0RXF65P3oool001@0oooo
101nMWD4079ZJ@@0IeiM0`1KDU4404m5A0@0@SLf100d:BP402DI6@@04@H60`0;000401871P@04P/;
100G4A8402XQ7`@0@C8]101E@S`30510>`@0C3dj1016>3L4048g=P@0?cHg100l=CH303Xe=P@0>SDh
100l>3X4040m?P@0@d541014ADL30455B@@0?4=8100g?dD4030j@0@0:S@l100V<c/402<d?@<093Q2
100V?4P402Q2CP@0:4=@100WAE<4035>F`<0<e9P100fEV@403iMJ`@0@F5`1013IWH4049XN@@0@f]l
0`15KX0404E`P`@0DGZ<101URYX407NIZ0@0Oj>b0`22XZl408FPZ`@0QijW1029Vj<408ZHWP@0RYFJ
0`2:TID408Z=T0@0RXV;102:QHHF0?ooo`00503oool407ifM@@0LVYY101WGUd305]BD@@0CdE41012
=cH403@Y:0@09ATI100A1PH300/000@04PL6100B2`/401LA4P@0:R4O1011<Rd405E2?0<0D40k101<
?CX404Hh=`@0@SLf100o=SL403`e=P<0>SDf100j=CP403`h>P@0@3dn1013@D@404A5A`<0@DE9100l
@dP403LoA@@0<3Y0100Z=3`402Hc>`@08c@m0`0T>48402HlB0@0:49>100X@e0402M5D`@0<DiK0`0c
DV0403IFI0@0?Ue[1011HG0404=VMP@0@VQi1013Jg`304E^P0@0AG23101ANX`406F:VP@0MiVX101o
Xk8308:R[`@0QJ2[1027WZL408VKX`@0RYRN102:UIX308ZAU@@0RXf@102:RH/408Z5QQH0oooo000D
0?ooo`@0OWIe101bJVT406MNG@<0Fe9A101?AD@4048g=P@0=2TX100U6AT401461P<02`00100B1`H4
018;2`@05a4B100Z8Al4044b;@@0ED8l0`1@@3/404`m>P@0ASPg1012=cH403lf=`@0?3Df0`0j=CH4
03Xe>0@0?3Pj1010?Ch404=1A0@0A4E70`11ADT403a3B0@0=cm5100`>T0402Xd?0@09S<k100S=3d3
02@h@P@09Sa8100X@Th402Q3D0@09dEC100aCU/303=BH0@0=UIT100nGF/4045QL0@0@fIf1012J7T4
04=[O0<0AFj01015L8<4055jS0@0IHZJ101gVJP407nS/P<0PZ:_1025X:/408NNY`@0RI^S102:V9h4
08ZEVP<0RY6E102:SI0408Z9R`@0RXF65P3oool001@0oooo101mMWD4079ZJ@@0IUeL0`1ID50404e3
@`@0?cHe100a9bL4024G5`@03`D50`0A20P401D=30@06Q@D100P6QX403@X9@@0AcLb101HACl305=3
?P@0Cd4m101:?S`404Hm?0@0@CTj100m=cP303Xe>0@0>3Hi100i>3/403dm@0@0?d131010@dH303m5
BP@0>d=9100f?dH4030i@0@0:SDm100U=3d402<d?P<08cM3100T?4P402M1CP@0:DEB100^BUP403QC
H0<0>eMT100nFfT404=QK`@0@fAc1011IWH4041WN@@0@6Yl0`10K7l4045^PP@0DWb>101XS9`407VK
Z@@0PJJe0`24Y;4408NS[@@0RJ2Y102;WJD408bJX0@0S9JK0`2<TYH408^>T@@0RhZ;102:QXHF0?oo
o`00503oool407efM@@0LVYY101VGE`305U@D0@0CD=3100o=SD4034W9`@08ALG100?1@D3014820@0
5@d<100J51@4020J6P@0=2PU1017=c8405Q5?`<0Dd<n101?@Cd404Xn?0@0ASdl1011>CX403dg>0<0
>SDh100h=ST403Th>`@0?Ce0100o@4<40413AP<0?dE:100k@dT403HoAP@0<3U0100Z=Cd402Dd?@@0
8c@n0`0S=d<402@lB0@09d5>100YAE8402i:F0@0>5=P0`0kEf@403iKJ@@0@f5_1013I7<4045VMP@0
@6Mi1010JW`3041/O`@0@Fj2101BO8h406R<W0@0NI^Y1021Y[D308BT/@@0Qj>]1029X:T408^MY@@0
S9ZP102<UY/308bBUP@0RhjA102;RX/408Z6QQH0oooo000D0?ooo`@0OGIe101bJVT406IMG0<0FE1@
101=@d<403lf=@@0<BLW100Q5aL400l51@<04@P8100E3@`401XD50@081XJ100d:2D404Lg<P@0F4Do
0`1C@ch404m1?@@0BShl1016?C`4044i>P@0?CLh0`0j=CP403Pf>@@0>CPk100m?D0403m0@`@0@4=6
0`0oADX403]3B@@0=Sm6100`>D0402Xe?@@09C@m100S=3h302<g@`@093a8100W@Dh402U5DP@0;TYH
100hDf0303]GI0@0?U]Y1013HFl404=TL`@0@FIf1010IgT4041ZO0<0@6ao1011KX84059lSP@0J8bL
101iVjT4086V]@<0Q:Ba1027Xjd408VPZ@@0RifU102<VZ0408bFV`<0S9:F102;SY4408^:R`@0RXJ6
5P3oool001@0oooo101mMWD4079ZJ@@0IUeL0`1ID50404e3@`@0?cHe100a9bL4024G5`@03`D50`0A
20P401D=30@06Q@D100P6QX403@X9@@0AcLb101HACl305=3?P@0Cd4m101:?S`404Hm?0@0@CTj100m
=cP303Xe>0@0>3Hi100i>3/403dm@0@0?d131010@dH303m5BP@0>d=9100f?dH4030i@0@0:SDm100U
=3d402<d?P<08cM3100T?4P402M1CP@0:DEB100^BUP403QCH0<0>eMT100nFfT404=QK`@0@fAc1011
IWH4041WN@@0@6Yl0`10K7l4045^PP@0DWb>101XS9`407VKZ@@0PJJe0`24Y;4408NS[@@0RJ2Y102;
WJD408bJX0@0S9JK0`2<TYH408^>T@@0RhZ;102:QXHF0?ooo`00503oool407eeM0@0LFUX101UGE`3
05Q@C`@0Bd=2100n=CD402lW9`@081LG100?1`L3018;2`@05a4A100O6AP402XR80@0>bl[101;?3L4
05Y8@P<0ETI2101AA48404e3@@@0BD501016@44404<o@@<0@3i11012@4<404=2A0@0ADE81015AdX4
04A8C0<0@TU=100kA4X403DnA@@0;cU1100Y=Sh402De?`@08cA00`0Q=T84024jA`@09D1>100WA584
02a9E`@0<U1N0`0gEV@403]KJP@0?V1_100mHG8403eSMP@0?6Eh100lIg/303]YO@@0?ff2101COY04
06f@X0@0NY^Z1023Z;H308NW/`@0RjF`102=Xj`408jPY`@0SYbR102>V9d308jDV0@0SHnB102<Rh`4
08Z6QQH0oooo000D0?ooo`@0OGEd101aJFP406EMG0<0F51?101;@d8403he=@@0;bLW100P5aL400l7
1`<04P/;100G4A4401lI60@0:R8P100k;b/404/l=`@0FTQ20`1FAT840554@P@0CD=11019@D0404I0
@@@0@cm10`10?T440490@`@0@d941015ADP404E7BP@0A4Q<0`12BDd403]4BP@0=Ci5100_>D4402Tf
?P@09CDo100S=403024f@P@08CY7100U@4h402M4DP@0;4UG100bD5h303MFI0@0>e]Z100nH6l403eQ
LP@0?F=f100lIGP403aWN`<0>fUm100oKH8405=nT0@0KI2P101jVjX408>X]P<0QjNc102;YK0408fS
[0@0SZ2W102>W:8408jHW@<0SYBH102=Si8408b;S0@0RXJ65P3oool001@0oooo101mMG@4075YJ0@0
IEeL0`1HD4l404]3@P@0?SDe100_9bL4020G5`@03`L70`0B2`/401LA4@@07aTH100Z8R0403/_:`@0
Bc`g101JB48305I6@P@0DDA2101=@d4404U1@0@0AT111013?d43040n@@@0@T131013@T@404E5B0@0
ADM:1014B4`30499C@@0>dA:100e?TD402li@@@0:CHn100U=Cl402<d@0<08CI2100Q>TL402E0CP@0
9dAB100/BEL4039@GP<0=eIT100kFfX403iPK`@0?F5b100mHgH403aUN0@0?6Mk0`0kJGd403m]PP@0
Dgj@101]T:0407ZKZP@0PjRf0`27Yk<408^U/0@0SJ>/102>X:L408jLXP@0SYRM0`2>U9P408f?TP@0
S8^<102:QXHF0?ooo`00503oool407eeM0@0LFUX101UGE`305Q@C`@0Bd=2100n=CD402lW9`@081LG
100?1`L3018;2`@05a4A100O6AP402XR80@0>bl[101;?3L405Y8@P<0ETI2101AA48404e3@@@0BD50
1016@44404<o@@<0@3i11012@4<404=2A0@0ADE81015AdX404A8C0<0@TU=100kA4X403DnA@@0;cU1
100Y=Sh402De?`@08cA00`0Q=T84024jA`@09D1>100WA58402a9E`@0<U1N0`0gEV@403]KJP@0?V1_
100mHG8403eSMP@0?6Eh100lIg/303]YO@@0?ff2101COY0406f@X0@0NY^Z1023Z;H308NW/`@0RjF`
102=Xj`408jPY`@0SYbR102>V9d308jDV0@0SHnB102<Rh`408Z6QQH0oooo000D0?ooo`@0OGEd101a
JFP406ALG0<0F51?101;@d8403de=@@0;bLW100P61T401492P<050h?100L5QH402DN7@@0<2HU100o
<c0404lo>`@0FdU30`1HBDD405A8A@@0CdI5101;A4D404Q4A@@0ATA60`16ATP404M7BP@0ATQ;1016
BDd404E:CP@0@dU=0`0nAT/403Q1B0@0<Sa3100]>40402Pg?`@09SI0100T=d<302<jAP@08ce;100S
@4l402=2D@@0:DMG100^CEd3035BHP@0=5MW100gFf`403QNL0@0>F5d100iI7L403UUNP<0=VIl1010
Kh@405N0T`@0KI2P101fVJP407nT/`<0RjZf102?Z[@4096W[`@0TZ>Z102BWjD4096JW`<0T9JI102>
TI<408f<S@@0RhJ75P3oool001@0oooo101mMG@4075YJ0@0I5aL0`1HD4l404]3@P@0?CDe100_9bL4
020H6@@04@T:0`0D3Pl401`F5P@09AhM100`9RD403lc<0@0Cclk101KBD<305Q9A@@0E4Q5101?ATD4
04]4A@@0B4A51016A4H304I6B0@0AdM:1016B4/404I9C@@0ADY>1013BDd303i6B`@0>458100b?4<4
02dh@0@0:3Lo100V=T0402@g@`<08cY6100S?D/402=0C`@08d9A100YAeL402i=G@<0<E9R100dEfL4
03MKK0@0>5i`100iHG@403UTM`@0>FEj0`0fIW`4041_Q0@0Eh2C101]T:0407JIZ0@0OjBc0`2;Z[H4
08nZ]0@0TJN_102BXjX409:OY@@0TIZO0`2@UYT408jAT`@0SHb=102;QXLF0?ooo`00503oool407ee
M0@0LFUX101TG5`305Q@C`@0Bd=2100m=CD402lW9`@081PI100A2@X301@>3`@071HF100U7Qd4030V
9@@0?c<`101??c/405]9@`<0F4U5101DB4D404m6A@@0BdA51018A4D404I4AP<0ATI81017AdX404I8
B`@0ATU=1015BTh404=9C@<0?TI;100h@DP4038l@`@0;CQ0100X=cl402Hf@0@093M30`0S>TH402<m
B`@08d1?100S@U4402U7E`@0;TeM0`0aDV8403AGI`@0=e]/100hGW0403UQM0@0>FAg100iIGX303IV
O0@0@6n4101GP9<406f@X0@0MYVX101oY;<308^Z]P@0SjZd102AYjl409:SZP@0TYnU102AVYl3092F
V@@0SY6C102=S8d408^6QaH0oooo000D0?ooo`@0OGEd101aJFP406ALG0<0F51@101;@d<403df=P@0
;bPY100Q6Q/4018<3@<05a4C100O6AX402TQ8@@0=B/Y1014=S<40551?@@0G4Y50`1JC4P405I:B0@0
DDQ8101=AdL404Y6A`@0AdE80`15ATT404A6B@@0@dE91011ADX403m4B@@0?D=80`0i@4H403@mA0@0
;cU1100[=cl402Pf?`@09CI1100U>4@302@jB0@09Ci<100XA58402U7E@@0:dYI100ZC5`302a?H0@0
;UAV100bF6X403ALK`@0=f5e100hHgP403ETN@<0<fIl1013LXL405N2U@@0JHjO101fVZX408BX]P<0
U[Bo102F[kT409N[/`@0UZN^102EXZP409BMX@<0TYNK102@TY@408j<SP@0RhN75P3oool001@0oooo
101mMG@4075YJ0@0I5aL0`1HD50404]3@`@0?CHf100_:2T4024J6`@04P`=0`0G4A<401lI6P@0:B4Q
100e:bT404@f<`@0DD4m101LBTD305Y<B0@0ETY8101AB4P404e7A`@0BTI71017ADP304E6B@@0A4I9
1013ADT40455BP@0?dA9100m@dP303U0AP@0=3e4100_>D4402/g?`@0:3Ho100U=T4402DhA0<093Y8
100U?T`402Q4DP@0:DME100[BUT402Y<G0<0;4mP100^E6H4039HJP@0=5a_100gHGD403QSN0@0=FAi
0`0cIW`404=bQ`@0Eh:E101YSYl407JJZP@0Q:Rf0`2F];l409J_^@@0Uj^c102FYjh409FRZ0@0U9fQ
0`2BUi/4092BU0@0SXb>102;QhLF0?ooo`00503oool407eeM0@0LFUX101TG5`305Q@D0@0Bd=3100m
=SH402lX:@@08AXK100B30d301LA4`@07aTJ100Y8B4403D[:@@0A3Hc101A@Cd405a:A@<0FTa8101F
BTP40558B0@0CDM7101:ATL404M5B0<0ADI91014ATT404=5B@@0@DE:100oA4T403e3B0<0>D16100d
?D@402li@@@0:cLo100X=Sl402Df@@@09CQ40`0T>TP402DnC0@0:4AB100YAeD402]:F@@0:TaL0`0/
Cf0402iDIP@0<UQZ100dG6l403MQM@@0>6=h100eI7T303=VO0@0@g:7101GPYD406V>W`@0MYZZ1024
Z;H309Jd_`@0UZni102GZk<409JW[P@0UJ:X102DWJ4309:GV`@0T9:D102>S8h408^7QaH0oooo000D
0?ooo`@0OGEd101aJFP406ALG0<0F51@101;@d<403df=P@0;bPY100Q6Q/4018<3@<05a4C100O6AX4
02TQ8@@0=B/Y1014=S<40551?@@0G4Y50`1JC4P405I:B0@0DDQ8101=AdL404Y6A`@0AdE80`15ATT4
04A6B@@0@dE91011ADX403m4B@@0?D=80`0i@4H403@mA0@0;cU1100[=cl402Pf?`@09CI1100U>4@3
02@jB0@09Ci<100XA58402U7E@@0:dYI100ZC5`302a?H0@0;UAV100bF6X403ALK`@0=f5e100hHgP4
03ETN@<0<fIl1013LXL405N2U@@0JHjO101fVZX408BX]P<0U[Bo102F[kT409N[/`@0UZN^102EXZP4
09BMX@<0TYNK102@TY@408j<SP@0RhN75P3oool001@0oooo101mMG@4075YJ0@0I5eL0`1HD50404]4
A0@0?SLg100`:BX4028L7@@05@l@0`0K5AH4024K70@0;2@T100h;B`404Dh=P@0DD8n101JBTD305Y=
B@@0Eda:101BBTT404i8B@@0BTM91017ATP304A5B0@0@TA7100o@dL403e2AP@0>T14100g?T<303@l
@P@0<3U0100/=cl402Pd?P@09SDo100T=T4402<gA0<08cY7100S?D/402E1D0@0:4IE100/C5/4031A
H0<0<UAU100cEfT403IKK@@0=Umb100gHGH403=RM`@0<VAi0`0dIgh404IfRP@0FHBG101[TZ8407fQ
[`@0SJnk0`2N^/@409je_P@0WK2h102LZk4409ZUZP@0UinT0`2EVId409:CU@@0Shf>102<QhLF0?oo
o`00503oool407eeM0@0LFUX101TGE`305Q@D0@0BdA4100n=cL4030Y:P@08Q`M100E3a0301/E5P@0
8A/L100/92@403P];0@0ACPf101A@Sh405Y:A@<0FTe9101GC4X4059:B@@0CTQ9101:AdT404M6B0<0
A4E81012A4L403m3A`@0?D96100j@4@403Ln@`<0=3a2100`>D0402`g?`@0:3@n100V=Cl402@f@@@0
8cM40`0S>TL402<mB`@09D5@100XAUD402a<F`@0<55P0`0bE6D403=GJ@@0=U]]100fGg8403MQMP@0
<f9g100bI7T303AWOP@0AWJ:101IQ9L406^BXP@0OJ6_102=[k/309jja0@0W[Fn102M/;P409b[/@@0
VZFZ102GWj@309FIW@@0TY>E102?SHh408b7QaH0oooo000D0?ooo`@0OGEd101aJFP406AMG0<0F51@
101;A4@403hg=`@0<2TZ100R71d401D?40<06aDF100Q6a`402`T90@0>2d/1015>3H40552?P@0FTY5
0`1JCDT405M<BP@0DTY9101>B4T404Y7B@@0AdI80`14ADP40494A`@0?d=7100m@TH403Y0A0@0=ci3
0`0d?484030i@0@0;3Lo100X=3h402He?`@093I1100S=d@302<jA`@08ce;100U@E0402Q6E@@0;4aK
100`DF03039DI@@0<eMY100fFfd403IOLP@0=f5f100cHWL4039TN@<0=6Mn1016MXX405V4U`@0Ji:R
101mXJl408f_^`<0W[[4102N]Kh409f`^0@0W:^a102JYJX409NOY0<0UIVM102BTiD408n=SP@0S8N7
5P3oool001@0oooo101mMG@4075YJ0@0I5eL0`1HD50404]4A0@0?SLg100`:BX4028L7@@05@l@0`0K
5AH4024K70@0;2@T100h;B`404Dh=P@0DD8n101JBTD305Y=B@@0Eda:101BBTT404i8B@@0BTM91017
ATP304A5B0@0@TA7100o@dL403e2AP@0>T14100g?T<303@l@P@0<3U0100/=cl402Pd?P@09SDo100T
=T4402<gA0<08cY7100S?D/402E1D0@0:4IE100/C5/4031AH0<0<UAU100cEfT403IKK@@0=Umb100g
HGH403=RM`@0<VAi0`0dIgh404IfRP@0FHBG101[TZ8407fQ[`@0SJnk0`2N^/@409je_P@0WK2h102L
Zk4409ZUZP@0UinT0`2EVId409:CU@@0Shf>102<QhLF0?ooo`00503oool407eeM@@0LFUY101UGEd3
05QAD@@0BdE5100n>3P4034[;0@091hO100F418301`F5`@08adN100^9RH403T_;P@0ACTf101?@Sh4
05M9A@<0FTe:101HCD`405=;B`@0CTU;101:B4X404I6B@<0@TA7100o@TH403a0A0@0>Ci3100f>d44
03<j@0<0;cLn100/=Cd402Pc?0@09C8l100S<ch4028d@0@08CI30`0Q>4H4024kBP@08cm>100UA5@4
02U9FP@0;DmO0`0`DfD403=HJP@0=5]^100cGG84039OM0@0<65f100_HgT303IZP0@0BWV>101ORI/4
076GY`@0QJFc102F/kh30:Fma`@0Y[_3102T][d40:6_]@@0WZV^102KXZH309NLWP@0U9FG102@SXl4
08f8R1H0oooo000D0?ooo`@0OGEe101aJFT406EMG@<0F55A101;ADD403hh>0@0<B//100T7Ql401H@
4P<071HG100S7Ah402hV9P@0>Bl^1015>CH404m2?P@0EdU50`1JCDX405Q=C0@0Dd];101>BD/404Y8
BP@0ATI90`12A4L403m2AP@0?414100i?T<403Hk@@@0<cY00`0_=ch402`e?@@0:3<l100U<S`402<c
?P@08SA0100Q=T<3024hAP@08C]:100S?dh402E4E0@0:DUJ100]Cel3031CI@@0<eQZ100dFfh403=M
LP@0<Umd100`HGH402mSN@<0=VZ0101:NHh405n9V`@0LINW1025YK<409Jc_P<0YKg7102V^l<40:Bf
_@@0XJne102NZJh409^RYP<0UibN102DUIL4092>S`@0SHR85P3oool001@0oooo101mMGD4075YJ@@0
IEeM0`1HDE4404]5A@@0?SPh100a:b`402@N7`@05Q0B0`0L5QL402<M7P@0;RHV100i;bh404Di=P@0
Cd8n101GBDD305Y=BP@0F4e<101CBd/404i9B`@0BTQ:1016ATT30494A`@0?d96100l@4@403Tn@`@0
=S]1100c>T0302lg?P@0;3Dm100X<c`402Db?0@08c<n100R=404024f@`<08CQ6100Q>dX402<oCP@0
9DAD100YBEX402e?G`<0<5=U100cF6X403AKKP@0<eeb100bGg@4031QMP@0;f=i0`0fJX0404YiSP@0
GhVK101aUjL408FU/`@0U[>n0`2U_LL40:Jk``@0Y;Jm102Q[kD409jY[P@0Vj:V0`2GW9h409BEU`@0
T8j?102=R8PF0?ooo`00503oool407eeM@@0LFUY101UGEd305QAD@@0BdE5100n>3P4034[;0@091hO
100F418301`F5`@08adN100^9RH403T_;P@0ACTf101?@Sh405M9A@<0FTe:101HCD`405=;B`@0CTU;
101:B4X404I6B@<0@TA7100o@TH403a0A0@0>Ci3100f>d4403<j@0<0;cLn100/=Cd402Pc?0@09C8l
100S<ch4028d@0@08CI30`0Q>4H4024kBP@08cm>100UA5@402U9FP@0;DmO0`0`DfD403=HJP@0=5]^
100cGG84039OM0@0<65f100_HgT303IZP0@0BWV>101ORI/4076GY`@0QJFc102F/kh30:Fma`@0Y[_3
102T][d40:6_]@@0WZV^102KXZH309NLWP@0U9FG102@SXl408f8R1H0oooo000D0?ooo`@0OGIe101a
JVT406ENGP<0FE9B101<ATH403li>P@0<Rd^100U824401PC50<07QXK100U824402lX:0@0>30_1013
>CL404a1?P@0EDQ50`1ICDX405U?C@@0E4a=101>BT`404U8BP@0ADE90`10@TH403a0A0@0>Ce2100e
>Sl4038h?@@0;SHl0`0[<c/402Lb>P@0930i100Q<3/4020a?@@07c8o100N=48301hgA@@07SY9100O
?Td40292D`@09DMH100XC5d302Y@HP@0;5AW100/Ef/402aJK`@0;5eb100[GgD402eSNP<0>Vj4101?
OY8406>=W`@0Mib[102;Z[L409ni``<0[/?<102aa</40:bl`P@0YkBi102S[;4409jUZ0<0VYjP102F
UYP4096?T0@0SHR85P3oool001@0oooo101mMWD4075ZJ@@0IEiN0`1IDU8404a6AP@0?cTj100b;Bh4
02DP8@@061<D0`0N6Q/402DP8@@0;bPX100h<2l404<i=`@0C44n101EB4D305U=BP@0FDm=101DC4d4
04i:C0@0BDQ:1015ADT30412AP@0?414100i?D8403Dj?`@0<SPm100^=S`302/c>`@09c8j100T<3T4
024`>`@0834m100O<Sl401hd@P<07SM5100N>TT401lnC@@08T9C100UAeP402Q<G@<0:U1R100/E6L4
02aGJ`@0;5Y_100/GG8402]OM@@0;F=j0`0jKX@404mnTP@0HhfO101gW:/408^Z]`@0WkW30`2^`l`4
0;74b`@0[;c2102W];T40:>//@@0WZFX0`2JWZ0409JFV0@0THn@102=R8PF0?ooo`00503oool407ef
M@@0LFYY101UGUh305UBDP@0C4I6100o>CX4038];P@09B0Q100H4a@301hJ6`@09B0Q100_:2P403P`
;`@0@cTg101<@Ch405E8A@<0FDe:101ICdd405A<C@@0CTY<1019B4X404E5B@<0@496100l@4@403Tm
@P@0=CXo100b>3d402hf?0<0:c<k100W<SX402@`>@@08C0k100P<Cd401lb?`@07SA20`0N=dD401hj
B@@07ci=100R@U<402E7F0@0:4aM0`0ZD68402aDI`@0;5M[100/FVl402aMLP@0:eme100]HgX303Y^
Q0@0CgjB101SSIl407NLZ`@0RjZg102O^L<30:k3c0@0/LC;102/_<840:Nd^@@0Xjba102NYJP309ZN
X0@0UYJH102ASi0408f8R1H0oooo000D0?ooo`@0OGIe101aJVT406ENGP<0FE9B101<ATH403li>P@0
<Rd^100U824401PC50<07QXK100U824402lX:0@0>30_1013>CL404a1?P@0EDQ50`1ICDX405U?C@@0
E4a=101>BT`404U8BP@0ADE90`10@TH403a0A0@0>Ce2100e>Sl4038h?@@0;SHl0`0[<c/402Lb>P@0
930i100Q<3/4020a?@@07c8o100N=48301hgA@@07SY9100O?Td40292D`@09DMH100XC5d302Y@HP@0
;5AW100/Ef/402aJK`@0;5eb100[GgD402eSNP<0>Vj4101?OY8406>=W`@0Mib[102;Z[L409ni``<0
[/?<102aa</40:bl`P@0YkBi102S[;4409jUZ0<0VYjP102FUYP4096?T0@0SHR85P3oool001@0oooo
101mMWD4079ZJP@0IUmO0`1JDe<404e7A`@0@C/l100d;S0402LR8`@06QDG0`0Q71h402PS90@0<2XZ
100i<C4404<j>@@0C490101EBDL305U=B`@0FU1?101DCDh404i:C0@0B4M:1013A4P303i1A@@0>Si3
100e>d04038g?@@0;SDk100Z<SX302H`>0@08bhg100P;CL401h]>@@07Blk100L<Ch401/c@@<06cE4
100K>4P401`lC@@07d5B100QAEL402=9G0<09DeQ100VDFD402MDJ@@0:EQ^100YFg4402YNM@@0<FIm
0`13M8X405N4U`@0Ji>T1020Xk4409Jb_P@0Zl7:0`2ic=@40;c=d`@0]<;7102]^;d40:N`]0@0XZNZ
0`2MWj8409RHV@@0Ti2A102>RHTF0?ooo`00503oool407efM@@0LVYZ101VGel305YCD`@0CDM71011
>c`403@^<0@09b8S100J5AL3024L7P@0:2<T100`:RX403Ta<@@0@cXi101<@T0405E9A`<0FDe;101J
D4l405A=CP@0CTY<1018AdX404=4B0<0?T55100j?T<403Dk@0@0<SLm100^=C/402Xb>P<09S0h100S
;SL4020]=`@07Rdi100M;c/401`a?P@06c=10`0K=D@401/hB0@073a=100O@E840255E`@08dUL0`0U
CF4402IAI@@09eAY100YF6h402UKL@@0:Uie100aIWd304=dRP@0EhBG101[Tj@4082S/@@0U[:n102[
`LX30;W<e0@0_<gC102d`/L40:fh_@@0Yk2d102RYjX309fOXP@0V9RI102CT94408j9RAH0oooo000D
0?ooo`@0OGIe101bJVX406IOG`<0FU=C101=AdL4044k?0@0=2h`100W8R<401XE5`<08A`N100X8b@4
030Z:P@0>C4a1013>ST404a2@0@0EDU70`1ICD/405Y@C`@0E4e>101>BT`404Q7BP@0@dA80`0n@DD4
03Xn@`@0=C]0100b=cd402he>`@0:S8j0`0V<3P402<^=`@082dg100N;CT401d_>`@0734n100K<d43
01/eA0@06cQ8100L?4d401m1DP@08DEG100SBE`302E=H@@09U5U100WE6T402UHKP@0:E]a100ZGWD4
035VO@<0@gB:101GQ9L406^CY0@0P:>a102F/[h40:_1bP<0^LcD102lcM<40;C2a`@0[KRm102W/;@4
0::WZP<0WInR102HV9T409>@T@@0SXV95P3oool001@0oooo101mMWD4079ZJP@0IUmO0`1JDe<404e7
A`@0@C/l100d;S0402LR8`@06QDG0`0Q71h402PS90@0<2XZ100i<C4404<j>@@0C490101EBDL305U=
B`@0FU1?101DCDh404i:C0@0B4M:1013A4P303i1A@@0>Si3100e>d04038g?@@0;SDk100Z<SX302H`
>0@08bhg100P;CL401h]>@@07Blk100L<Ch401/c@@<06cE4100K>4P401`lC@@07d5B100QAEL402=9
G0<09DeQ100VDFD402MDJ@@0:EQ^100YFg4402YNM@@0<FIm0`13M8X405N4U`@0Ji>T1020Xk4409Jb
_P@0Zl7:0`2ic=@40;c=d`@0]<;7102]^;d40:N`]0@0XZNZ0`2MWj8409RHV@@0Ti2A102>RHTF0?oo
o`00503oool407ifM@@0LV][101VH60305]DE0@0CdQ91012?Ch403H`<P@0:B@V100L61X3028O8@@0
:RDW100a:b`403Tb<P@0@CTi101<@T0405A8A`<0FDe;101JCdh405A>C`@0CDY<1016ATX40453A`<0
>cm4100f>d44038h?P@0;S@k100Y<CT402H_=`<08R`e100O:cD401`Z=P@06R/g100I;CX401T_?@@0
63500`0H=4@401TgB0@06C]<100K?e4401e3EP@07dMJ0`0PBel4029>H`@095=X100UEVd402EJL@@0
:V1g100gJh8304YjS`@0GhZM101fVj/408b[^0@0X[_6102gb]830<WHgP@0a]CI102kal`40;>l`0@0
[;>f102UZZ`309nQX`@0VIVJ102DTI4408j9RAH0oooo000D0?ooo`@0OWIe101bJf/406IPH0<0FeAD
101?B4T4048m?P@0=S0b100Y92H401`H6P<08QlQ100Z9BL4034[;0@0>C8b1011>CT404a2@0@0E4Q7
0`1ICD/405Y?CP@0E4i?101=BT`404I6BP@0@D=70`0k?d@403Hk@@@0<SPn100^=3/402Ta>@@09Rlg
0`0R;3D401l[=@@072Xf100J:cL401T]>P@06Blm100H<D0301PdA0@06CM8100I>d`401/oD@@07D=F
100OAeX3021;G`@08TiS100TDfP402EFK@@09EYa100ZH7L403M[PP<0BWZ?101ORYd407JKZ`@0S:^h
102R^lH40;O:dP<0bMSN1036e=T40;_7c0@0/kc0102//kH40:FZ[0<0Wj6S102IVIX409BAT@@0SXV9
5P3oool001@0oooo101nMWD4079[J`@0IV1P0`1KE5@404m8B@@0@Sdn100f<38402TT9P@071PJ0`0R
7b4402XU9`@0<B//100i<S84044i>@@0C490101DB4L305U=B`@0FTm>101DCTl404e:C0@0ATI:1011
@dL303/oA0@0=S]1100b>3h402hd>`@0:C4i100V;cL3028/=@@07b/e100L:SH401X[=`@06Bdj100I
;cd401Pa@0<063A4100I=dP401TkC0@06cmA100M@eH401m7FP<084]O100RCV<402ACJ0@09EI]100U
FW4402YPM`@0=f^20`1:NXl405n:W@@0MY^[102<ZkP40::kaP@0]l[B0`39f=h40<KDf@@0^lO<102c
_<040:bc]P@0YJZ/0`2OXJ<409VIVP@0U96A102>RHTF0?ooo`00503oool407ifMP@0Lfa[101WHF43
05aFEP@0D4Y;1014?d0403Pc=0@0:bHX100N6Qd302DQ8`@0;2LY100b;Bh403Pb<`@0@C/k101;@T84
0558A`<0ETe;101FCTh4059>C`@0BdY=1014ADT403i1AP<0>3e3100c>Cl402he?0@0:C4h100U;SD4
024[=0<07BTb100K:38401PW<`@05bTf100F:cT401D]?@@05C100`0E<d@401HgB0@05cY<100H?E04
01Y2E@@06dIJ0`0MBUl401m>H`@0859X100REVd402ILL`@0;fAk100oLXP305>2U@@0JY>T1021Xk44
09Rd_`@0[/C=1032d]T30=;Oi0@0bMGI1030b/h40;No`P@0[kFh102X[:h30:6SY0@0ViZK102ETY84
08n9RAH0oooo000D0?ooo`@0OWIf101cK6/406MQH@<0G5IF101@BT/404@o@0@0>3<d100[9RP401hJ
7@<09B4S100/9bT4038];P@0>38c1011>c/404]2@P@0DDQ70`1FCD/405I>CP@0DTi?101;BTd404A5
B@@0?T560`0h?D<403<i?`@0;SDl100Y<CP402D^=@@08B/d0`0M:C8401/X<P@062Lc100G:CH401H[
>@@05Bdm100E<40301DcA0@05SM8100G>T`401PmD0@06T9E100KAUX301e:G`@07diS100PDVP4029F
K@@09Uac100_I7/403mbR0<0Dh:E101ZTj@4086S/@@0V;Bo102^a<d40<;Bf@<0d]oT1039eMT40<3:
cP@0]ko2102_]KP40:R/[P<0XJ>T102KVY/409FBTP@0ShV95P3oool001@0oooo101nMWH407=/J`@0
If5Q0`1LEUH4051:B`@0A3m0100h<c@402/V:0@07QXM0`0U8B<402`W:@@0<Rd^100h<S<4044k>`@0
Bd92101AB4L305I=B`@0ETi>101BCTl404]:C@@0A4E9100n@DH303Pm@`@0<cTo100^=C`402Ta>0@0
9Bhe100Q:c@301dY<P@06bPb100H9c<401LY=P@05R/i100E;Cd401D`@0<05C=4100F=dP401LjC0@0
63e@100J@UD401]6FP<07DYO100OCV<4021BJ0@08UI]100VG7<402mTN`@0?g:80`1CPYD406ZCY0@0
PJ>a102H];l40:k4c@@0`];I0`3Bgn@40<WEf@@0`<[>102g_l840:ne^0@0Z:b^0`2QXj@409^JV`@0
UI:B102?RHTF0?ooo`00503oool407ifMP@0Lfa[101WHF4305aFEP@0D4Y;1014?d0403Pc=0@0:bHX
100N6Qd302DQ8`@0;2LY100b;Bh403Pb<`@0@C/k101;@T840558A`<0ETe;101FCTh4059>C`@0BdY=
1014ADT403i1AP<0>3e3100c>Cl402he?0@0:C4h100U;SD4024[=0<07BTb100K:38401PW<`@05bTf
100F:cT401D]?@@05C100`0E<d@401HgB0@05cY<100H?E0401Y2E@@06dIJ0`0MBUl401m>H`@0859X
100REVd402ILL`@0;fAk100oLXP305>2U@@0JY>T1021Xk4409Rd_`@0[/C=1032d]T30=;Oi0@0bMGI
1030b/h40;No`P@0[kFh102X[:h30:6SY0@0ViZK102ETY8408n9RAH0oooo000D0?ooo`@0OWMf101c
K6`406QRHP<0GEMH101BC4d404I1@P@0>SHg100^:R`4024N80<0:2@V100^:R/403<_<@@0>C@f1011
>c`404Q1@@@0CTM60`1BBd/4055;C0@0CT]=1018BD`40494B0@0>cm40`0e>T4402lf?@@0:S4i100U
;SD4020Z<`@072La0`0H9C0401HU<@@052Db100B9cD4018Y>0@04R`l100B;d0301<bA0@04cI8100E
>D`401HmD0@0645E100IAEX301]9G`@06deS100MDFP4025FKP@0:5if100dJH0404MiSP<0GHVL101e
VZ/408^[^0@0X[_6102jc=D40<oLh@<0fNCX103=em/40<?<c`@0^/74102b]kT40:Z][`<0XjBU102L
Vi`409JBTP@0ShZ95P3oool001@0oooo101nMgH407=/K0@0J69R0`1MEeP4059<C@@0AT52100j=SL4
02hZ;0@08AhP0`0X92H402hZ:`@0<bla100i=3H4044k?0@0B451101>AdH3059;B`@0DD]<101>Bdd4
04Q9C0@0@TA8100k?d@303Dj@@@0;cHm100Z<CT402D^=@@082Xc100L9c4301PU<0@05RDa100D9C84
018W=@@04RTh100B;3`4018_@0<04c94100C=TP401DiC0@05Se@100H@ED401U5FP<06dUO100KCF<4
01eAJ0@08EI^100XGWH403AYP0@0AgV>0`1MRI`407FJZ`@0Rj^h102R^lH40;[<e@@0cmcQ0`3Ii>P4
0<gGf`@0`lc?102j`L@40;:g^@@0ZZf_0`2SY:D409bKW0@0UY:B102?RXTF0?ooo`00503oool407ig
MP@0Lfa/101XHV8305eGF0@0DTa=1016@D8403Xf=`@0;RX/100Q7R0302PT9P@0;RX[100c;c4403Td
=P@0@C/l1018@D4404i7AP<0DT];101ABd`404i;C@@0B4U<1012A4P403/oA0<0=CY1100_=Sd402Xa
>@@09Bhe100P:S<401`W<@<062D`100F9C4401@U<P@04RLe100B:CP4018/?0@04Rm00`0C<T@401<f
B0@05CU<100F?E0401Q1E@@06DEJ0`0KBEl401]=H`@07E5X100QEVh402QNMP@0=6V01017NHh305f9
W0@0MIZ[102;ZkP40::kaP@0^/cE103?g>430=WTj0@0cMOK1033c<l40;[1a0@0/[Ni102Z[Jl30:>T
Y@@0W9^L102FTY8408n:RAH0oooo000D0?ooo`@0OWMf101cK6`406QRHP<0GEMH101BC4d404I1@P@0
>SHg100^:R`4024N80<0:2@V100^:R/403<_<@@0>C@f1011>c`404Q1@@@0CTM60`1BBd/4055;C0@0
CT]=1018BD`40494B0@0>cm40`0e>T4402lf?@@0:S4i100U;SD4020Z<`@072La0`0H9C0401HU<@@0
52Db100B9cD4018Y>0@04R`l100B;d0301<bA0@04cI8100E>D`401HmD0@0645E100IAEX301]9G`@0
6deS100MDFP4025FKP@0:5if100dJH0404MiSP<0GHVL101eVZ/408^[^0@0X[_6102jc=D40<oLh@<0
fNCX103=em/40<?<c`@0^/74102b]kT40:Z][`<0XjBU102LVi`409JBTP@0ShZ95P3oool001@0oooo
101oMgL407A]K@@0JV=S0`1OFEX405A?D0@0BDA5100n>C/4038^<0@09B8T0`0[9bT402l];`@0=C4c
100i=CL403lj?0@0AT51101:ADH304e8BP@0C4Q:101;BD`404I7B`@0?d97100g?D83034h?P@0:c<j
100U;SL4020[<`@06bLa100G9C0301@S;`@04B8`100?8S4400hU=0@03bPh100?:c`4010^@0<04353
100A=DP401<iC0@053eA100E@EH401M5FP<064UO100ICF@401eAJ@@08UQa100]Hg/403iaQ`@0Dh:F
0`1[Tj@4086S/`@0V;C0102`aLl40<WGgP@0gnW]0`3Nj>/40=7Ig0@0a/g@102m`/D40;Bh^P@0[:j_
0`2UY:H409fKW0@0UY>C102@RXTF0?ooo`00503oool407mgM`@0M6e]101ZHf<305mIFP@0E4m@1019
A4D403hi>`@0<Rh`100U8R@302/W:@@0;bd_100e<C<403Te=`@0?cXl1016@D4404Y5AP<0CDQ:101<
B4X404]9C0@0ATM;100o@TL403Lm@P<0<CPn100[<cX402D^=`@082/c100K9c4401LU<0<052<_100A
8S0400lR<@@03RDd100?:3P400l[?0@042i00`0@<D<4014eB0@04cU<100D?E4401E1EP@05dEJ0`0H
BEl401U=I0@07E5Y100RF74402eSN`@0?W67101CPYH306^CY0@0PJ>c102H]<040;35c`@0bMON103O
jNd30=kXj`@0dMWL1036cM040;g2a@@0];Rj102/[Zl30:FTYP@0WI^L102FTi<4092:RAH0oooo000D
0?ooo`@0OgMg101dKFd406YSH`<0GeUJ101DCe0404U4A@@0?STk100b;S0402DR90<0:bLY100_;Bl4
03Da<`@0>CDg100o>S`404I1@@@0BTE60`1=B4X404a8BP@0BdU<1016Ad/403m2A`@0=ce20`0a>3h4
02/c>P@09Bhg100P:c<401/W<@@05bD`0`0D8bl4014R<0@03b8a100>9C@400lX>0@03b/l100@;T03
010a@`@04CE8100C>D`401@mD@@05D5F100GAEX301Q9G`@06DeT100MDFT4029HL@@0;F=k100nLHL4
05>2UP<0Ji>T1021Xk<409Rd`0@0/<G?1039emh40=oYk@<0g^S[103AfM`40<K=d0@0_L;5102d^;X4
0:b^[`<0YJBV102MVi`409JCT`@0T8Z95P3oool001@0oooo101oMgL407A]K@@0JV=S0`1OFEX405A?
D0@0BDA5100n>C/4038^<0@09B8T0`0[9bT402l];`@0=C4c100i=CL403lj?0@0AT51101:ADH304e8
BP@0C4Q:101;BD`404I7B`@0?d97100g?D83034h?P@0:c<j100U;SL4020[<`@06bLa100G9C0301@S
;`@04B8`100?8S4400hU=0@03bPh100?:c`4010^@0<04353100A=DP401<iC0@053eA100E@EH401M5
FP<064UO100ICF@401eAJ@@08UQa100]Hg/403iaQ`@0Dh:F0`1[Tj@4086S/`@0V;C0102`aLl40<WG
gP@0gnW]0`3Nj>/40=7Ig0@0a/g@102m`/D40;Bh^P@0[:j_0`2UY:H409fKW0@0UY>C102@RXTF0?oo
o`00503oool407mhM`@0MFi^101[IFD3065KG0@0Ee5B101<AdT4044m?`@0=S8d100Z9bT302d[;@@0
<Rlb100f<cH403Xg>@@0?S/m1013@48404M4AP<0B4I81018ATT404M7BP@0@TE9100k?dD403<j@@<0
;CDm100V<3T4020/=P@06RPc100F9C04018R;`<03R0^100<82h400/Q<0@02b@d100;9cP400`[?0@0
3Bi00`0><D@400leB@@04CU=100B?E8401=1EP@05DEK0`0GBV4401Y?IP@07eA/100XGWH403M[P@@0
BGZ?101PRih307RL[0@0SZfj102U_LP40;k?e`@0e>3U103TkO430=cTi`@0d]WL1038c]040;o3a@@0
][Rj102^[[030:JUYP@0WYbL102GTi<4092:RAH0oooo000D0?ooo`@0OgQg101eKVh406]UI@<0HE]L
101GDE8404a7B@@0@Cdo100f<S@402XW:@<0;B/]100b;c8403Hc=P@0>SLi100n>cd404=0@P@0AdA6
0`18ATP404Q6B@@0AdM:1012ADT403/oA@@0<cY10`0]=Cd402H`>@@082`f100J:3<401HU<0@04R8_
0`0>82h400`P;P@02b4`100;93@400/W>0@032/l100=;T0300haA0@03cE9100A>Dd4018mDP@04d5F
100EAE/301M:H@@06TmV100OE6`402QNMP@0=f^11019NXl4062;WP<0N9b/102>[KX40:Fmb0@0_/oG
103Dh>D40>C]l@<0g>CW103BfM`40<S>d0@0_l?5102f^;X40:j^/0<0YZFV102NW9`409NCT`@0T8Z9
5P3oool001@0oooo101oN7L407E^KP@0JfEU0`1QFe`405MADP@0C4M91011?Cl403Hb=0@0:RLY0`0]
:bd4038_<P@0=S<f100j=cT403hk?@@0@d121017A4H304Q6B0@0B4I91017AdX40495B@@0>cm5100c
>T4302de?@@09S0i100P;3H401XX<`@05RD`100B8Rl300hP;P@0320^100;8C0400/T=0@02bLh100<
:c`400d^@0<03S54100?=DT4014iC@@04SeB100C@EH401E5F`<05dYQ100JCfH401mDK0@0:5if100g
Jh4404UjS`@0H8^N0`1hW:`408j]^P@0YKg8102ncmL40=CPi@@0i>ga0`3Li>L40=;Ig0@0b<k@102o
`lD40;Jh^P@0[Zj`0`2VYJH409jLW0@0Ui>C102@RXTF0?ooo`00503oool407mhM`@0MFi^101[IFD3
065KG0@0Ee5B101<AdT4044m?`@0=S8d100Z9bT302d[;@@0<Rlb100f<cH403Xg>@@0?S/m1013@484
04M4AP<0B4I81018ATT404M7BP@0@TE9100k?dD403<j@@<0;CDm100V<3T4020/=P@06RPc100F9C04
018R;`<03R0^100<82h400/Q<0@02b@d100;9cP400`[?0@03Bi00`0><D@400leB@@04CU=100B?E84
01=1EP@05DEK0`0GBV4401Y?IP@07eA/100XGWH403M[P@@0BGZ?101PRih307RL[0@0SZfj102U_LP4
0;k?e`@0e>3U103TkO430=cTi`@0d]WL1038c]040;o3a@@0][Rj102^[[030:JUYP@0WYbL102GTi<4
092:RAH0oooo000D0?ooo`@0P7Qh101fKfl406eVI`<0HeeN101IE5D404m;C0@0AD53100k=cT402l/
;`<0<2ha100d<SD403Pe>0@0>STk100n?3l40490@`@0ATA70`17ATT404I6B@@0@dE9100n@dP403Lm
A0@0;cLo0`0X<S/4024]=`@06RTd100E9C84014R<0@03B0^0`097Rd400HN;P@01R0a10078cD400TW
>@@02R/m100;;T4300`bA@@03SE:100?>Th4014nD`@04d9H100EAUd301Q;H`@07E9Y100TFG44035V
O@@0@gF:101HQIP406nEY`<0QZJe102K]/840;?8d@@0cM[P103Pj>`40>[bm0<0gnGW103DfM/40<[>
d0@0`<?4102g^;X40:j^[`<0YZFV102OW9`409NCT`@0T8Z95P3oool001@0oooo1020N7P407I_K`@0
KFIW0`1SGEh405UDE@@0Cd]<1015@D<403/g>@@0;b`_0`0`;S4403@b=@@0>3Dh100j>C/403hl?`@0
@T131016A4L304M6B@@0ATI91013ADT403i3B0@0=ce4100_=cl302Pb>`@08Bdg100J:C@401DU<P@0
4B8`100=82h300TN;@@01Qh^1006834400LS=@@02BLi100::cd400/^@@<03395100>=DX400ljCP@0
4CiC100C@UP401E6G@<064]S100MDVT402AIL@@0<FIm1013MHX405R5V0@0KiFW0`26Y[D409^f`P@0
/lSA103=f^040>3Xk0@0j_;d0`3OiNL40=CIf`@0b/k@1030`l@40;Nh^P@0[Zj_0`2VYJH409nLW0@0
Ui>C102@RXTF0?ooo`00503oool4081hN0@0MVm_101]IVL306=MGP@0FEAE101?Bd`404E1@`@0>cLi
100_;2l3030^<@@0=38e100h=CP403Xi>`@0?S`o1012@4<404I4A`<0AdI91016ATT404=5B@@0?T=8
100g?D@402lg?`<0:38k100Q;CL401XY=0@05BDb100A8S0400dP;P<02Ah]10067Rh400HP<@@01b<e
10099cT400X[?@@02bi10`0<<TD400heBP@03cY>100A?U<401=2F0@05DIM0`0HBf<401eBJ@@095Ua
100aIWd404=eRP@0F8FH101_UJL308JV]@@0VkK2102cb=440<gJh0@0h>S/103Zl_@30=oUi`@0e=WK
103:c]040<33a0@0]kRj102^[Zl30:JUYP@0WibL102GTi<4092:RAH0oooo000D0?ooo`@0P7Qh101f
Kfl406eVI`<0HeeN101IE5D404m;C0@0AD53100k=cT402l/;`<0<2ha100d<SD403Pe>0@0>STk100n
?3l40490@`@0ATA70`17ATT404I6B@@0@dE9100n@dP403LmA0@0;cLo0`0X<S/4024]=`@06RTd100E
9C84014R<0@03B0^0`097Rd400HN;P@01R0a10078cD400TW>@@02R/m100;;T4300`bA@@03SE:100?
>Th4014nD`@04d9H100EAUd301Q;H`@07E9Y100TFG44035VO@@0@gF:101HQIP406nEY`<0QZJe102K
]/840;?8d@@0cM[P103Pj>`40>[bm0<0gnGW103DfM/40<[>d0@0`<?4102g^;X40:j^[`<0YZFV102O
W9`409NCT`@0T8Z95P3oool001@0oooo1020NGP407MaL0@0KVQX0`1UH60405aGF0@0Ddi@101:ATL4
040m?`@0=c@g0`0d<SD403He>0@0>CPk100m?3h403ln@@@0@d951016ADT304I6BP@0ADI:1011A4X4
03a2B0@0<ca4100/=Sl302@a>`@06b/g100E9c@4010S<@@02b0_10087Rh300@L;@@00A`]10027c44
00DS=@@01bPj1009;3l400X_@P<02c=7100==d/400lkD@@04D1F100DAE/401M:H@<074mW100TEfl4
02iRN@@0?g26101CP9<406R@X@@0Oj2`0`2E/Kh40:c2c0@0a=CJ103Ki>P40>gdmP@0k_Cf0`3PiNL4
0=GIfP@0b/g?1030`/@40;Nh^@@0[jj_0`2WYJD409nLW0@0V9>B102@RXTF0?ooo`00503oool4081i
N0@0Mg5`101^J6P306EPH0@0G5MH101CCU0404Y6A`@0@3do100g=3L303@b=@@0=SDh100i>3/403dl
?P@0?ci11013@TD404I5B@<0ATI:1015ATX40454BP@0?498100c?4@402`f?`<0934k100K:cL401DW
=0@042<a100;82l400PN;P<011`]100172d4008O<@@01B<e1007:3X400T/?`@02Rm20`0;<dL400dg
B`@03c]A100A@5H401A5F`@05dYQ0`0LCfL402AGK`@0;V9i100oL8H405>0T`@0J92Q101oX;0309Fa
_P@0[<;<1034e=X40=_Tj0@0kOCf103^m?H30>3Ui`@0eMWJ103:cLl40<32a0@0]kRi102_[Zl30:NU
Y@@0WibL102HTi84092:RAH0oooo000D0?ooo`@0P7Uh101gLG0406iXJ0<0IF1P101LEeP405=>D0@0
BTI71010?Cl403Ld=`<0=38e100f=CP403Th>`@0?C`n100o?T4404=2A@@0ATE90`16ATX404E6BP@0
@DA:100l@TP403<lA0@0;3Ho0`0T<C/401/[=`@05BLd100@8c4400/P;`@021h^0`0472d4004L;@@0
0Qla10058cD400LX>P@02B`o100:;d8300/cA`@03CM;100?>e440150EP@054EK100GBV4301a?I`@0
95M_100^HWT403m`QP@0Dh2C101XT:4407nP/0<0UK6n102/`/`40<CDfP@0fnCX103]m?H40>kdmP<0
h>GW103EfMX40<[=c`@0`<;4102g^;T40:n^[`<0YjFU102OW9`409RCTP@0T8Z95P3oool001@0oooo
1020NGP407MaL0@0KVQX0`1UH60405aGF0@0Ddi@101:ATL4040m?`@0=c@g0`0d<SD403He>0@0>CPk
100m?3h403ln@@@0@d951016ADT304I6BP@0ADI:1011A4X403a2B0@0<ca4100/=Sl302@a>`@06b/g
100E9c@4010S<@@02b0_10087Rh300@L;@@00A`]10027c4400DS=@@01bPj1009;3l400X_@P<02c=7
100==d/400lkD@@04D1F100DAE/401M:H@<074mW100TEfl402iRN@@0?g26101CP9<406R@X@@0Oj2`
0`2E/Kh40:c2c0@0a=CJ103Ki>P40>gdmP@0k_Cf0`3PiNL40=GIfP@0b/g?1030`/@40;Nh^@@0[jj_
0`2WYJD409nLW0@0V9>B102@RXTF0?ooo`00503oool4085jN@@0NG9a101`JVX306QRH`@0GeYK101G
DU@404i:C0@0AT95100n>ch303He>0@0>3Lj100k>Sh403hn@@@0@4131013@dL404M7BP<0AdQ<1016
B4d40456B`@0?D=:100e?DH402dh@@<08S4m100G:SP4010V=0@0328a1008830400@N;`<001`_1000
7S04008R=0@012Hi1006:Sd400P^@@@02S960`0;=TX400diCP@043eD100D@eX401M9H0@074mV0`0T
EVd402iQM`@0?6j3101?O90406>;W@@0NIb[102?[KX30:Jmb0@0_LoF103Dgn@40>O^l0@0mOWk103[
l?430>3Si@@0e=OH103:c<d40<31`P@0]kNh102_[Jh30:NTY0@0Wi^K102HTY84092:RAH0oooo000D
0?ooo`@0PGYi101iLW44071ZJP<0J69S101OFU/405MBE0@0CTY<1016@TD403hk?P<0=SDh100h=cX4
03/j?P@0?Si11010@4<404=3A`@0AdM:0`17B4`404I8C@@0@DI;100m@dX403DmAP@0;CQ10`0R<Cd4
01LZ>0@042Hd100<8S4400PP<0@011h_0`0072l4000N<0@00R8d10049ST400HZ?@@022i1100:<TH3
00/fBP@03CU>100@?E@401A3FP@05dUP100LCfH302AFK@@0;V5g100lKX<404mlT0@0Hh^M101iW:/4
08n]^P<0Y[g8102mcmH40=COi0@0ink`103enO/40>_`l@<0h>?U103DemP40<[<c@@0`<72102g]kP4
0:n][P<0YjBT102OVi/409RBTP@0T8Z95P3oool001@0oooo1021NWT407UbL@@0L6YZ0`1XHV<405mJ
F`@0Ee9D101>BT`404I2A@@0?S/n0`0f=CP403Pg>P@0>cXn100n?T440410@`@0@d=71017AdX304M8
C0@0ATQ=1011AT/403e3BP@0=Ce6100]>443028a?@@05bXh100@9S@400`R<@@0220`10047Rl3000L
;`@001h`10028S@400@V>@@01RXm1008;T4400XbAP<02cI:100=>Dh4010mE0@054=J100GBF0401a?
IP<095I]100^HGL403a^P`@0Cgb@101SRid407VLZ`@0Sjfj0`2V_LP40;g?eP@0e=oT103Wk_040?Gi
n`@0jo3a0`3PhnD40=CGf0@0b/c=1030`L840;Ng^0@0[jf^0`2WY:@409nKV`@0V9:B102@RXTF0?oo
o`00503oool4085jN@@0NW=c101bK6`306YTI@@0HeeN101KEUL405=?D@@0BdQ:1014@D@303/i?@@0
>cXn100o?T440451A0@0@d=71015ADT404U9C@<0BD]?1017BTl40497C@@0?TA;100h@4P402lkA0<0
93A0100J;S`401@Y>0@03bHf100;93D400LS=@<00b8e100493L400HW>P@022/n1009;T<400/cA`@0
3CI;0`0>>Dl4014nE0@05D=I100JBV0401m?IP@09UM]0`0`H7H403e]PP@0CGZ=101QRIX407JHZ0@0
S:Vf102R^/@30;W;dP@0d=_P103Sj^d40?Cgn@@0nO_l103ZkNh30=kQhP@0dmGF1039b//40<30`0@0
]kJf102^[:d30:NSX`@0Wi^J102GTY84092:RAH0oooo000D0?ooo`@0PGYi101jLg<4079/K0<0JVAU
101SGEh405]FE`@0DdmA101;B4X404A1A0<0>cTm100k>Sh403ln@@@0@D541013@dL404E5B@@0BDU=
0`19Bdl404M:C`@0@TM=100nA4/403Q0B0@0;c]40`0T=40401X^?0@052Th100?9SH400/T=@@01b<e
0`038SD400@T=`@01RLj1008:ch400T^@`@02c=7100==T/300hiC`@04CiD100E@eT401Y:H0@07dmV
100VEfd3031PMP@0?Ff2101=NXd40669VP@0MYRX102<ZKH40::ja0<0^L_B103@fn040>?Zk@@0m?Oi
103ino`40>[]kP<0g^7R103CeMH40<W:b`@0`<30102g][H40:j/[@<0Yj>S102OViX409NBTP@0T8Z9
5P3oool001@0oooo1021NWT407YcL`@0LVa/0`1ZI6D406=MGP@0FeIG101CCe4404]8BP@0A4540`0k
>Cd403/j?P@0?ci11011@D@404=3A`@0ADE91019BDd304U;C`@0AdY?1012Add403i4B`@0>418100_
>d@302@d@0@06Rhl100D:CP400lV=P@02b@e10078cD300<R=@@012@g10069cX400P[?P@02Bi3100;
<dL400dfB`<03SU?100A?U@401E3F@@06TYP100OCfH402IGK@<0<61f100mKH8404ejS@@0HHVJ101f
V:P408bY]P@0X[[40`2ibm840=3Kh0@0hn[]103dmoT40?Wko0@0j^g^0`3NhN840=?EeP@0bL[;1030
`<040;Nf]P@0[Zb]0`2WXj<409nKVP@0Ui:B102@RXTF0?ooo`00503oool4085jN@@0NW=c101bK6`3
06YTI@@0HeeN101KEUL405=?D@@0BdQ:1014@D@303/i?@@0>cXn100o?T440451A0@0@d=71015ADT4
04U9C@<0BD]?1017BTl40497C@@0?TA;100h@4P402lkA0<093A0100J;S`401@Y>0@03bHf100;93D4
00LS=@<00b8e100493L400HW>P@022/n1009;T<400/cA`@03CI;0`0>>Dl4014nE0@05D=I100JBV04
01m?IP@09UM]0`0`H7H403e]PP@0CGZ=101QRIX407JHZ0@0S:Vf102R^/@30;W;dP@0d=_P103Sj^d4
0?Cgn@@0nO_l103ZkNh30=kQhP@0dmGF1039b//40<30`0@0]kJf102^[:d30:NSX`@0Wi^J102GTY84
092:RAH0oooo000D0?ooo`@0PW]j101kM7@407A]KP<0KFMW101VH64405mJF`@0F5=E101ACDl404Y7
B@<0@d54100o?D040491A0@0A4A71017AdX404U9C@@0CDeA0`1;CE4404Q;D0@0@dQ>100nAD`403Q1
BP@0<Ca70`0X>4<4020c@@@06S0o100G;ch4018/?@@03R`m0`0<:cd400`/?`@03Bm1100><TD4010f
BP@04SY>100D?E8301I1EP@06TIK100NBf4402EBJ0@0:eU^100eHWL3041]P0@0CgV;101PQYL407BF
Y@@0RJFb102N]/040;G7c`<0cMSN103QinX40?7dmP@0o_oo103fn?P40>SZjP<0g=gN103Ad]<40<S7
b0@0_[jn102f];@40:j[Z`<0YZ:R102NVYT409NBT@@0T8V95P3oool001@0oooo1022NgX407]dM0@0
M6e^0`1]IfL406IPH@@0GeYK101HDeD4055=C`@0BTM90`13@D@403lm@0@0@T541014A4L404M7BP@0
BDU=101=CE4304]=D@@0B4]@1013B4h403i5C0@0>45:100a?4L302Ph@`@083=1100J<3l401L_?P@0
4R`m100>;3d300`[?@@032`o100=;d4400hbA@@043I:100B>Th401@mDP<05T5F100JAU/401i;H@@0
9E9X100[FFh403ERM`<0@6f0101?NH/40626U`@0M9JU1029YK8409jf`0@0]LO?0`3=f=h40>7WjP@0
lOCf103nool40?Khn0@0j>[Z0`3LgMh40=7Bd`@0b<O8102n_[h40;Jd]0@0[Z^[0`2VXZ8409jJV@@0
Ui:A102@RHTF0?ooo`00503oool4089kNP@0NgAd101dKFh306eWI`@0IV1Q101OFU/405QCE@@0DDe?
101:AdT304=1A0@0?ce01012@D@404A4A`@0AdM:1019BDd404e=D@<0BdeA1018Be0404=8CP@0?TE<
100h@DX4034lA`<0:3Q3100P<d4401X`?`@05bln100B;3d400h/?@<032/m100<;3l400d_@@@03S95
100@=TX4018jCP@053eB0`0F@EH401Y6F`@07T]Q100UDVP402]IKP@0=F9g0`10KH0404miR`@0H8JG
101dUZD408VU/P@0W[K0102eall30<gHgP@0hNOZ103am?H40?koo`@0m_Sh103Xj^X30=cMgP@0dM;C
1038alP40;jn_P@0][Bd102^Zj/30:JRXP@0WYZI102GTY440929RAH0oooo000D0?ooo`@0PW]j101k
M7@407A]KP<0KFMW101VH64405mJF`@0F5=E101ACDl404Y7B@<0@d54100o?D040491A0@0A4A71017
AdX404U9C@@0CDeA0`1;CE4404Q;D0@0@dQ>100nAD`403Q1BP@0<Ca70`0X>4<4020c@@@06S0o100G
;ch4018/?@@03R`m0`0<:cd400`/?`@03Bm1100><TD4010fBP@04SY>100D?E8301I1EP@06TIK100N
Bf4402EBJ0@0:eU^100eHWL3041]P0@0CgV;101PQYL407BFY@@0RJFb102N]/040;G7c`<0cMSN103Q
inX40?7dmP@0o_oo103fn?P40>SZjP<0g=gN103Ad]<40<S7b0@0_[jn102f];@40:j[Z`<0YZ:R102N
VYT409NBT@@0T8V95P3oool001@0oooo1023Ng/407aeM@@0MVm_0`1_JFX406USI0@0HUiO101LF5T4
05IBE0@0D4e?0`1:B4X404A3AP@0ADA71018B4/404];CP@0C4e@101>Ce<304a>D`@0BDeC1014BU04
0458C`@0?4E>100d@D`302dnB@@0:3]8100S>4H4024hAP@073E5100J=DH301PeAP@063I7100I>4X4
01XlCP@07T1B100QAEL402=9G0<09DaP100YDFD402mGJ`@0=Umb100nIgT404Q`PP<0E7Z;101TQiL4
07FDX`@0RJ>`102L/kd40;;3b`@0bMCI0`3OiNP40>obl`@0o_oo103mo_h40?3`l0@0i>CU0`3IfMT4
0<o>c`@0aLC5102m^k/40;Bb/P@0[:VY0`2UXJ4409jIV0@0Ui6@102@RHPF0?ooo`00503oool408=k
N`@0O7Ee101fKfl306mYJP@0JF=T101RGUl405aHF@@0EU9D101@CDl304Y8BP@0A4=61015A4L404Q8
B`@0Bd]>101<CE0404i?D`<0C4iC1019CE<404A:D0@0@DQ?100lADh403A1C0<0;Ci9100X>dP402<h
AP@08CQ6100L=DD401XeAP<063E6100H=TL401ThBP@06Sa>100N@5840255E`@08dUL0`0UC60402UA
I@@0;eM[100fGg8403iWN@@0B7220`1DNX/406B7U`@0MIBS1029Xk0409bc_@@0//?;1039e=T30=oU
j0@0ko;c103nool40?gnoP@0l?3`103Ti>D30=WIf@@0clk?1035a<D40;fk^`@0];:b102/ZJT30:FQ
X@@0WYVH102GTI040929R1H0oooo000D0?ooo`@0Pg]k101lMGD407I_K`<0KfUZ101YHf@4069NG`@0
G5QI101FDU@4051=C`<0BTQ:1014@dH404E4A`@0B4Q;101;Bdh404a=D0@0CTmC0`1<CU<404U=D`@0
A4Y@1011B4l403a5CP@0=45<0`0]?TT402PkB0@08cQ6100Q>4H401`eA@@06SE60`0H=DH401PfA`@0
6CQ:100J?4h401i0DP@08DEG100SBE`302E<H0@0:E5U100_Ef/403IOLP@0?VMi1018L88305AjR`@0
I8NG101eU:<408VS/0@0W;>m102b`l/40<WDf@<0gnGX103_l_<40?koo`@0oOkn103`l?040>CTi@<0
fMWI103?c/l40<G4a@@0_K^k102d/[840:bYZ@<0YJ6Q102NVIP409NAT0@0T8V85P3oool001@0oooo
1023Ng/407aeM@@0MVm_0`1_JFX406USI0@0HUiO101LF5T405IBE0@0D4e?0`1:B4X404A3AP@0ADA7
1018B4/404];CP@0C4e@101>Ce<304a>D`@0BDeC1014BU040458C`@0?4E>100d@D`302dnB@@0:3]8
100S>4H4024hAP@073E5100J=DH301PeAP@063I7100I>4X401XlCP@07T1B100QAEL402=9G0<09DaP
100YDFD402mGJ`@0=Umb100nIgT404Q`PP<0E7Z;101TQiL407FDX`@0RJ>`102L/kd40;;3b`@0bMCI
0`3OiNP40>obl`@0o_oo103mo_h40?3`l0@0i>CU0`3IfMT40<o>c`@0aLC5102m^k/40;Bb/P@0[:VY
0`2UXJ4409jIV0@0Ui6@102@RHPF0?ooo`00503oool408=lN`@0OGIf101gLG43079/K0@0K6IW101V
HF84065LG@@0FeMI101FDeD3055>D0@0BdU<1018AdX404a<C`@0CdmB101?D5@4051AE@<0Ce9F101>
DEL404Q>E0@0ADaC1010BE4403Q5C`<0=4A?100`@Th402a0C@@0:Sm=100V?Td402HoCP<09Cm?100U
@E4402I4E0@0:DQH100]C5d4031@H@@0<eAU0`0fFFX403aNL0@0@VEf101:K7d4055dQ0@0Fgf<0`1Y
R9H407VEXP@0RZ:]102L/;X40;70a`@0a]3E103LhN@30>g_l@@0oOkn103oool40?Cdm0@0jNWY103O
g]h30=GDe0@0bl[:1033`L440;Zh^0@0/Zn_102[YjL30:BOW`@0WIRG102FT8l40929R1H0oooo000D
0?ooo`@0Pgak101mMWH407MaL@<0LVa/101/IVL406IQHP@0HEaM101KEeT405ICE@<0DDi@101;BD`4
04Q7BP@0C4a?101?Ce8404m@E0@0D55E0`1?DUH404iAE`@0B4iD1015C5<40419D@@0>4E?0`0dA4l4
0312CP@0;41=100Z?dd402HnC@@09Sm>0`0U?dl402E1D@@09TAD100YB5P402e<G@@0<51Q100cE6D3
03IIJP@0?5i`1012IGH404Y/O@@0DGB4101KOH`306V8UP@0NIFR102:XZd409b`^P@0/L371036d=D4
0=cQi0<0kNoa103mo_h40?ooo`@0m?Cd103YjNT40=oNgP<0eMCD103;b/X40<?1`@@0^[Rh102b[jl4
0:^WY`<0Y9nO102MV9L409J@S`@0T8V85P3oool001@0oooo1023O7/407efMP@0Mg5a0`1bK6`406aV
I`@0IV5R101QG5d405]GF@@0EU=E0`1ACU0404]9C0@0B4M:101<C4l404m?DP@0Ce1D101@DED304mB
EP@0CU5G1018CU@404E<D`@0@4UA100hADl303A4C`@0<49>100/@4d402XoC@@09Si=100V?dh302Do
C`@09D5A100VA5@402U8F0@0;DaM100`D64403=DI@<0=UUZ100lGW04049UMP@0BVam101AM8@405]m
S0<0JHRF101iUJ8408ZR[@@0W;2j102a`<L40<K@e@@0g>7T0`3]ko440?gnoP@0oooo103dm?@40>WY
j@@0gmkN0`3Ee=@40<_:bP@0`l71102j^;P40;:_[`@0ZjNW0`2TWil409fHU`@0UY2?102@RHPF0?oo
o`00503oool408=lN`@0OGIf101gLG43079/K0@0K6IW101VHF84065LG@@0FeMI101FDeD3055>D0@0
BdU<1018AdX404a<C`@0CdmB101?D5@4051AE@<0Ce9F101>DEL404Q>E0@0ADaC1010BE4403Q5C`<0
=4A?100`@Th402a0C@@0:Sm=100V?Td402HoCP<09Cm?100U@E4402I4E0@0:DQH100]C5d4031@H@@0
<eAU0`0fFFX403aNL0@0@VEf101:K7d4055dQ0@0Fgf<0`1YR9H407VEXP@0RZ:]102L/;X40;70a`@0
a]3E103LhN@30>g_l@@0oOkn103oool40?Cdm0@0jNWY103Og]h30=GDe0@0bl[:1033`L440;Zh^0@0
/Zn_102[YjL30:BOW`@0WIRG102FT8l40929R1H0oooo000D0?ooo`@0Q7al101nN7L407UcL`<0M6i^
101_JFX406YUIP@0IF1Q101PG5d405aHFP<0EeAF101CDE<404i=C`@0DE5C101CDeH405ADF0@0EEIJ
0`1DEU/4055EFP@0CE9H1019D5L404E?E`@0?daF0`0nC5H403Y9E@@0=dQE100eB5@403=8E@@0<TQF
0`0bBUP403A=F`@0=e1N100jDf8403iHI`@0@Ea[1016HG0304YVM@@0D6ak101HLh4405ijQ`@0IH6>
101_RYL307fEX@@0SJ6/102M[kL40;6na0@0a<gA103Ffmh40>WZj`<0no[j103oooh40?Gem0@0k>_[
103RhN440=WHf0<0d<k>1037aLD40;nm_@@0]kBd102`[J`40:VUY@<0XYfM102LUYH409F?SP@0ShR7
5P3oool001@0oooo1024O7`407ihM`@0NG=c0`1dKVh406mYJP@0JVEV101UH644061LG@@0G5QJ0`1G
E5H405=AD`@0CTe?101ADE<405=CEP@0E5AH101EEUX305AFF`@0DEEJ101=DUP404U@E`@0ADmG100o
C5H303i<EP@0>TUE100gB5D403E8E0@0<dQE100bB5H3039:F0@0=4eK100gD5h403YCHP@0?UQW1011
G6/404IQL0<0BVIe101@K7/405QcP@@0GWZ7101UPHh406n:U`<0OIFQ102=XJ`409f_]`@0/Kk41034
cM440=KKgP@0jN[[0`3kn_X40?oooP@0mOGd103/jn/40>;Qh@@0fMSH0`3@c/h40<O5a@@0_kfm102g
];@40;2][0@0ZJFU0`2RWId409bFUP@0UHn>102?R8LF0?ooo`00503oool408AlO0@0OWQg101iLg<3
07A^KP@0KfUZ101ZIFH406EPH@@0H5aM101LF5X305MDEP@0De5C101>CDl4055AD`@0De=F101DE5P4
05EFFP<0E5IK101AEEX404eBF0@0BE1G1015CeL403m<EP<0?TaF100jBED403M8E@@0=DQD100cB5D4
0398EP<0<TYH100dCE/403M@GP@0>U=R100nF6L4045LJ`@0AV5`0`1:IWD4051/N`@0F7>1101NNXL4
06F1SP@0KhZG0`1mUJ4408fQ[0@0WJng102a_/@40<C=d@@0e]_N103Yj^/30?_jnP@0ooon103emO@4
0>c[j`@0h^7Q103If=P30=3>cP@0alG5102o_Kd40;Nd]0@0/:f/102YYJD30::MW@@0W9JF102EShh4
08n8QaH0oooo000D0?ooo`@0Q7al101nN7L407UcL`<0M6i^101_JFX406YUIP@0IF1Q101PG5d405aH
FP<0EeAF101CDE<404i=C`@0DE5C101CDeH405ADF0@0EEIJ0`1DEU/4055EFP@0CE9H1019D5L404E?
E`@0?daF0`0nC5H403Y9E@@0=dQE100eB5@403=8E@@0<TQF0`0bBUP403A=F`@0=e1N100jDf8403iH
I`@0@Ea[1016HG0304YVM@@0D6ak101HLh4405ijQ`@0IH6>101_RYL307fEX@@0SJ6/102M[kL40;6n
a0@0a<gA103Ffmh40>WZj`<0no[j103oooh40?Gem0@0k>_[103RhN440=WHf0<0d<k>1037aLD40;nm
_@@0]kBd102`[J`40:VUY@<0XYfM102LUYH409F?SP@0ShR75P3oool001@0oooo1024OG`4081iN0@0
NgAd0`1fL704079/K0@0KFQY101YI6D406EQHP@0HEeO0`1NFU`405YHFP@0F5MI101HEeX405UHF`@0
FEUM101JFeh305UKG`@0F5]O101EFEl4055GGP@0CUIN101:E5d304QDG@@0AE9M1013DUd4045BG@@0
@E=O1011E60304=FHP@0AEUU1018G6P404]OK0@0D6A`101DJGD405]_N`<0GW>0101UNXH406^0R`@0
LHJA101iSIL408BGX0<0Tj>[102R[kH40;>l`P@0a<[=103EemT40>KViP@0m_Cc0`3noO`40?Kem0@0
kNc[103Thn840=_Jf@@0dm7A0`3;b<P40<?0`0@0^kRh102d/K040:fYZ@@0Yj:R0`2QVi/409^EU0@0
UHj=102?R8LF0?ooo`00503oool408AmO0@0P7Uh101kM7@307I`L0@0LVa/101]J6T406UTI@@0IF5R
101QGEl305iJG0@0FUQJ101HEeT405QGFP@0FEQK101IFEd405YKGP<0FE]O101HFel405EIG`@0DEMN
101>EUh404YDG@<0B5AM1015DUd404=BG@@0@E9M1011Del4045DH0<0@eIR1015FFD404QLJ0@0Bem/
101@I70405AYM@@0Ffmk0`1NLh0406EjQP@0Jh2;101aQY4407V=U`@0Q9NP0`2CXj/40::_]P@0/kc2
1034b/d40=GGf@@0i^KV103fm?<30?kmo0@0m_Gd103]k>/40>CShP@0fm[I103CdM430<_8b0@0`l30
102k^;P40;Ba/0@0[JVY102WXZ830:6KV`@0ViFD102ESXd408n8QaH0oooo000D0?ooo`@0Q7el1020
NGP407]dM0<0MW1`101bK6`406eXJ@@0JFAU101UHF84065MG`<0GUYL101JF5X405QGF@@0F5MJ101I
F5/405UIG@@0FU]N0`1IFel405QKG`@0EEUO101AEeh404iFGP@0BUAM0`18E5d404EBG@@0@e9M1011
DUd4045CG`@0@EAP0`13EV8404EII@@0B5aX101;Gf`4051TL0@0E6Ue101KKg/305icP0@0IGZ6101[
P8/40766T@@0NHfG1024Uj0309>SZ`@0XZnf102c_<840<C:c@@0eMOI103Vi^H40?Kdl`<0o_gl103f
mO@40>g/j`@0i>?R103Kf]T40=?Ad@<0blS81033`<040;^h^0@0];6`102]ZJT40:NRXP<0XI^K102K
UI@409F>S@@0ShR75P3oool001@0oooo1025OGd4085jN@@0OGIf0`1iLW8407E_K`@0LF]/101]J6T4
06YUIP@0IV9T0`1TH644065NH0@0H5eO101OGF0405mNH0@0H5mR101PH6<3065QI0@0H65U101MH6D4
05YOI@@0FEmU101EGFD305AMIP@0DeeV101AGFH4055NI`@0DUmY101BH6X305=QK0@0EFA^101HIg84
05a[M@@0H71j101VMGl406akQ0<0LH6;101iR90407f;U0@0Pi6I102<VZ4409VTZP<0YZnd102d^[l4
0<C7bP@0dmCE103Rh>040?3]k0@0n_Sg0`3gm_H40>g[j`@0i>;R103Lf]T40=CBd@@0c<[90`35`/84
0;jk^P@0]kBc102a[J`40:^VYP@0YJ2O0`2OVIT409VCTP@0U8f<102>QhHF0?ooo`00503oool408Em
O@@0PGYi101mMWH307UbLP@0MFm_101aJf`406eXJ@@0JVEV101VHV@306APH@@0HEiP101PGEl405mM
H0@0GeiP101PGf84061PH`<0HF5T101PHFD405ePI@@0FUmU101IGfD405EMI@<0E5eV101CGFH4055M
IP@0DEiW101BGfT4059PJP<0Df5/101EI6h405QWLP@0G6]e101PL7X406IeO`@0K7^40`1aPH/407V8
T0@0OH^D1023TIT408bJX@@0VJBZ0`2V[k@40;Bj_`@0a<O:103Ce=D40>;Ph0@0l>g/103jn?L30?Of
mP@0kN_[103Th^840=cJf@@0e=;A103<b/T30<G2`P@0_[^j102g];<40;6][0@0ZjJV102UX9l309nI
V@@0VI>B102DSH`408j7QQH0oooo000D0?ooo`@0QGem1021NWT407efMP<0NG9b101eKfl4075[K0@0
KFQY101ZIFH406IRI0<0I61Q101QGV04061MG`@0GeeP101OGV04061OHP@0H61S0`1QHF@4061QI@@0
GF1U101JGfD405UOI@@0EEeU0`1DGFH405=MIP@0DEeV101AGVL4059OJ@@0DV1Z0`1CHF`405ETKP@0
F6Mb101LJgD4061`NP@0IWEo101/Nh@30761R`@0NHR@101mRi@408>AV@@0S9ZQ102IY:X30:J_]0@0
];Zo1034alX40=?De@@0h^3P103`kN`40?[hm`<0moKf103]jn/40>CRhP@0g=[I103Dd]440<c:b@<0
aL;2102n^kX40;Nd/`@0/Jf/102[YZH40:FPW`<0WiVI102ITi8409B=S0@0SXN65P3oool001@0oooo
1025OGd4085jN@@0OGIf0`1iLW8407E_K`@0LF]/101]J6T406YUIP@0IV9T0`1TH644065NH0@0H5eO
101OGF0405mNH0@0H5mR101PH6<3065QI0@0H65U101MH6D405YOI@@0FEmU101EGFD305AMIP@0DeeV
101AGFH4055NI`@0DUmY101BH6X305=QK0@0EFA^101HIg8405a[M@@0H71j101VMGl406akQ0<0LH6;
101iR90407f;U0@0Pi6I102<VZ4409VTZP<0YZnd102d^[l40<C7bP@0dmCE103Rh>040?3]k0@0n_Sg
0`3gm_H40>g[j`@0i>;R103Lf]T40=CBd@@0c<[90`35`/840;jk^P@0]kBc102a[J`40:^VYP@0YJ2O
0`2OVIT409VCTP@0U8f<102>QhHF0?ooo`00503oool408EnO@@0PW]j101nMgL307]dM0@0Mg5a101d
KVl4075/K0@0KVUZ101[IfP306UUIP@0IfAU201VHfD406ITIP@0IVAW101WIFP306MVJP@0IVM[101V
J6`806AWK0@0HFI]0`1PIfh4065XK`@0H6Q`101PJG44061ZLP@0HF]d0`1SKGD406I`N0@0JG=k101]
Mgl4075kPP@0MX27101lQXd308:;TP@0QhnE102<U9T409>KX0@0WZFY102X[K430;>g^P@0`L?5103@
cm040=gKf`@0j^KV103flo840?GclP<0jnWY103ShN040=_If0@0e=7@103=b/T40<K2`P<0_kbk102i
]KD40;>_[P@0[JRX102WXZ840::MW0<0WINF102HTI4409><R`@0SXN65P3oool001@0oooo1025OWd4
089kNP@0OWMg0`1kM7@407MaL@@0M6i_101aK6`406iYJP@0JfMX0`1YIFH406MTI@P0IV=U101VI6H4
06ITI`@0IfEX0`1WIVX406IWJ`@0IVQ/201TIf`4065VK@<0H6M^101QJ6l4061XL0@0H6Ua101PJW84
065[M0<0Hfee101VL7P406UcN`@0KGMo101aNh8407J0Q`@0O8J=0`22Ri8408N?U@@0S9BI102CVj04
09jUZ@@0Z:fa0`2c]kX40<73a@@0d<o@103Mfm/40>[ViP@0m_?b103elo830>_Yj@@0hn7P103KfMP4
0=CAd0@0cL[91036`/830;nl^`@0^KFe102c[jh40:fXZ0@0Yj:R102RWI`309fGUP@0V96A102CS8/4
08j7QQH0oooo000D0?ooo`@0QGim1022NgX407igM`<0NgAd101gLG4407A^K`@0LFa/101^JFX406]W
J0<0JFEV101WI6D806ISI@@0IVAV101VI6L406MUJ0<0IfIZ101VIf/406IXK0P0I6M/101QIVd3061W
KP@0HFQ_101PJ704061YL@@0H6Yb101QJg@306=]M@@0IW1h101YLg/406egO`@0LG^2101fP8L407b6
S@<0PX^B1027SiD408bDV@@0Ti^P102NYJT40:R]/@<0/kNj1031`lD40=3?d0@0gM_K103Zi^H40?Kc
lP@0mO?b0`3[jNT40>?Qh0@0fmWH103DdM040<g:b@@0a/;20`2o_;/40;Ve]@@0/jn^102]Z:P40:NR
XP@0XYfL0`2MUiH409RAT@@0Thb;102>QhHF0?ooo`00503oool408EnO@@0PW]j101nMgL307]dM0@0
Mg5a101dKVl4075/K0@0KVUZ101[IfP306UUIP@0IfAU201VHfD406ITIP@0IVAW101WIFP306MVJP@0
IVM[101VJ6`806AWK0@0HFI]0`1PIfh4065XK`@0H6Q`101PJG44061ZLP@0HF]d0`1SKGD406I`N0@0
JG=k101]Mgl4075kPP@0MX27101lQXd308:;TP@0QhnE102<U9T409>KX0@0WZFY102X[K430;>g^P@0
`L?5103@cm040=gKf`@0j^KV103flo840?GclP<0jnWY103ShN040=_If0@0e=7@103=b/T40<K2`P<0
_kbk102i]KD40;>_[P@0[JRX102WXZ840::MW0<0WINF102HTI4409><R`@0SXN65P3oool001@0oooo
1026OWh408=lN`@0P7Uh0`1mMWH407YdM0@0Mg5a101dKfl4079]K@@0L6]/0`1^JV/406eYJP@0K6QZ
101[J6X406]YJP@0JfU[101/JV`306e/K`@0KVia101_Kg<406i_L`@0KW1d101/L7D306eaMP@0L7=i
101`M7X4071eN`@0L7El101`MWd3079hO`@0MG^1101hOH@407b2Q`@0P8F:1025RXh408V>TP<0SY6E
102BUYT409BIW0@0VinS102UZJ/40:na]0<0_Kfn103<bLX40=WEe0@0i^3O103^j^T40?3]k0@0inGT
0`3PgM`40=WFe@@0d/o>103;b<L40<G1`@@0_k^j0`2i]K@40;>_[P@0[ZVY102YY:<40:BOWP@0WiZI
0`2KUI@409J@S`@0TX^:102=QXDF0?ooo`00503oool408InOP@0Pgak1020NGP307efMP@0NWAd101g
LG4407A_K`@0LVe]101`Jf`306iZJ`@0KFUZ101/J6X406]XJP@0JfUZ101[JF/406aZK0<0KFa_101^
KW4406m_L`@0KVmc101^L7@406a`M@<0KG5f101`LgT4071dNP@0L7Ek101`MG`4071fO@<0LWQo101e
Nh4407QmQ0@0O8:71020QHX408F:SP@0RHjB0`2>TID409:FV@@0U9VL102KWj<40:FYZ`@0[k6d0`2m
_Kh40<c9bP@0fMGD103Vh=l40>kZj@@0l>g/103WiN@30>3Mg0@0fMKE103Bclh40<_8a`@0aL71102o
^kX30;Ve]0@0/jn^102^ZJT40:VTX`@0Y9nN102OVYT309^EU0@0UY2?102BRhX408f6QAH0oooo000D
0?ooo`@0QWin1023O7/4081iN0<0OGIf101jM7@407MaL@@0M6m_101bKFd4071[K0<0KVY[101]JFX4
06aXJP@0JfQZ101[JFX406]YJ`@0K6Y/0`1]K6l406i^L@@0Kfmc101^Kg<406i`M0@0K71e0`1]LGH4
071cN@@0L7Aj101`MG/4071eO0@0L7Im0`1bN7l407EkP@@0N7f4101lPXL40825RP@0QHZ>1029SY83
08jAU@@0TYJI102DVI`409^OX`@0YJV[102_/K@30;fm_P@0c<W:103IeM@40>KPg`@0k^[Y103`kN`4
0>OUi0<0h=gL103Ie]D40=;?cP@0blS71035`L440;nk^P<0^KFd102c[jh40:jYZ@@0ZJBS102TWih4
09nJV@<0ViFD102FT8l409:;RP@0SHJ55P3oool001@0oooo1026OWh408=lN`@0P7Uh0`1mMWH407Yd
M0@0Mg5a101dKfl4079]K@@0L6]/0`1^JV/406eYJP@0K6QZ101[J6X406]YJP@0JfU[101/JV`306e/
K`@0KVia101_Kg<406i_L`@0KW1d101/L7D306eaMP@0L7=i101`M7X4071eN`@0L7El101`MWd3079h
O`@0MG^1101hOH@407b2Q`@0P8F:1025RXh408V>TP<0SY6E102BUYT409BIW0@0VinS102UZJ/40:na
]0<0_Kfn103<bLX40=WEe0@0i^3O103^j^T40?3]k0@0inGT0`3PgM`40=WFe@@0d/o>103;b<L40<G1
`@@0_k^j0`2i]K@40;>_[P@0[ZVY102YY:<40:BOWP@0WiZI0`2KUI@409J@S`@0TX^:102=QXDF0?oo
o`00503oool408IoOP@0Q7el1021NWX307mhN0@0O7If101jM7@407QbLP@0MW1a101dKfl307=^KP@0
LVe^201aKFh4075]K`@0LFi`101bL78307AbM@@0M7=f101gMGT407MgNP@0MgQl101gN7d307UjO`@0
Ngb1101lOH4407eoP`@0OX25101nP8H30862Q`@0Q8F:1027R8`408Z;SP@0SHfA102BTY@409BDU`<0
ViZK102MW9h40:6PXP@0ZZRY102b/;440;fj^P<0bLG4103Cc/d40>3If0@0jNCS103XiN@40>;OgP@0
fmSG0`3DdM040<k:b@@0b<C31032_[d40;fi^0@0^;>b0`2c[Zd40:jYZ0@0ZJBS102UWil40:2KVP@0
W9JF0`2HTY4409B>S@@0THZ9102=QH@F0?ooo`00503oool408IoOP@0Q7el1021NWX307mhN0@0O7If
101jM7@407QbLP@0MW1a101dKfl307=^KP@0LVe^201aKFh4075]K`@0LFi`101bL78307AbM@@0M7=f
101gMGT407MgNP@0MgQl101gN7d307UjO`@0Ngb1101lOH4407eoP`@0OX25101nP8H30862Q`@0Q8F:
1027R8`408Z;SP@0SHfA102BTY@409BDU`<0ViZK102MW9h40:6PXP@0ZZRY102b/;440;fj^P<0bLG4
103Cc/d40>3If0@0jNCS103XiN@40>;OgP@0fmSG0`3DdM040<k:b@@0b<C31032_[d40;fi^0@0^;>b
0`2c[Zd40:jYZ0@0ZJBS102UWil40:2KVP@0W9JF0`2HTY4409B>S@@0THZ9102=QH@F0?ooo`00503o
ool408IoOP@0Q7el1021NWX307mhN0@0O7If101jM7@407QbLP@0MW1a101dKfl307=^KP@0LVe^201a
KFh4075]K`@0LFi`101bL78307AbM@@0M7=f101gMGT407MgNP@0MgQl101gN7d307UjO`@0Ngb1101l
OH4407eoP`@0OX25101nP8H30862Q`@0Q8F:1027R8`408Z;SP@0SHfA102BTY@409BDU`<0ViZK102M
W9h40:6PXP@0ZZRY102b/;440;fj^P<0bLG4103Cc/d40>3If0@0jNCS103XiN@40>;OgP@0fmSG0`3D
dM040<k:b@@0b<C31032_[d40;fi^0@0^;>b0`2c[Zd40:jYZ0@0ZJBS102UWil40:2KVP@0W9JF0`2H
TY4409B>S@@0THZ9102=QH@F0?ooo`00503oool408IoOP@0Q7el1021NWX307mhN0@0O7If101jM7@4
07QbLP@0MW1a101dKfl307=^KP@0LVe^201aKFh4075]K`@0LFi`101bL78307AbM@@0M7=f101gMGT4
07MgNP@0MgQl101gN7d307UjO`@0Ngb1101lOH4407eoP`@0OX25101nP8H30862Q`@0Q8F:1027R8`4
08Z;SP@0SHfA102BTY@409BDU`<0ViZK102MW9h40:6PXP@0ZZRY102b/;440;fj^P<0bLG4103Cc/d4
0>3If0@0jNCS103XiN@40>;OgP@0fmSG0`3DdM040<k:b@@0b<C31032_[d40;fi^0@0^;>b0`2c[Zd4
0:jYZ0@0ZJBS102UWil40:2KVP@0W9JF0`2HTY4409B>S@@0THZ9102=QH@F0?ooo`00503oool408Mo
O`@0QGem1023O7/3085jN@@0OgQh101mMWH407]eM@@0NGAd101hLW<307MbLPP0MW5b101eLG8407Ib
L`@0MW=d101hM7H307YgN@@0Ogan101oOGl407mmP0@0Ogj11020P8@308B3QP@0R8J91029R8/408R7
R`@0RHR<102<RXh7092=T0@0THjA102DTI8409NDU@@0VYJF102LV9T30::NW@@0Y:2P102YYJD40;2/
[0@0^KBd1033_K`30<g6a@@0dlg<103Of]P40=oKfP@0f=GD103Cclh40<g9b0<0b<C31033_[h40;ji
^@@0^KBd102d/:l40;2[ZP<0[:NV102XXj840:BNWP@0X9^J102MUiH409VCTP<0UXn>102CS8/408n8
Q`@0S8F45P3oool001@0oooo1027Ogl408EmO@@0Pgak0`21NWT407mhN0@0OGIf101kMGD407UdM0@0
N79c0`1gLW8807IaLP@0MG5b101fLW<407IcM0@0N7Af0`1jMgT407mlOP@0Ogeo101oOH0407mnP@@0
P8240`24PhH408R6R@@0RHR;1028Qh/408V8S0@0S8Z>1`2@SI04096>T@@0U96B102GU9D409ZFUP@0
W9RI0`2RWYd40:BPX0@0ZJFU102`[:`40;Vd]0@0`kfl0`3=a/D40=?=c0@0gm[H103OfmX40=SEe0@0
dlo>103=bLP30<S4``@0`kjn102n^KT40;Vd]0@0];2_102`ZjX30:bWYP@0Z:>R102TWYh40:2KVP@0
WINF102ITi8309J?SP@0Thb;102?R8L408b5Q1H0oooo000D0?ooo`@0Qgmo1025OGd408=lN`<0PGYi
101oN7P407efMP@0NgEe101iM7@407QbL`<0Mg9b201fLG8407EaLP@0MW9c101fLg@407QdMP<0NWMi
101oO7h407mmO`@0Ogf0101oOX440820Q0<0Q8>61028QXT408V8R`@0R8N;1029R8`408b:SPL0T8f@
102ASY4409BATP@0UiBE102JUYH409bHV@<0XYjM102TX:040:VUY@@0/:b/102i];@40<>m_0<0cLK5
103CcL`40=oJf0@0gm_J103HeM@40=??cP@0cLW80`38a<<40<>n_P@0_[Vi102i];@40;B`[`@0/:^Z
0`2/YjH40:RSXP@0Y9jN102PViX409fGUP@0VI>B0`2FShh409><R`@0ShR7102<QH@F0?ooo`00503o
ool408MoO`@0QGem1023O7/3085jN@@0OgQh101mMWH407]eM@@0NGAd101hLW<307MbLPP0MW5b101e
LG8407IbL`@0MW=d101hM7H307YgN@@0Ogan101oOGl407mmP0@0Ogj11020P8@308B3QP@0R8J91029
R8/408R7R`@0RHR<102<RXh7092=T0@0THjA102DTI8409NDU@@0VYJF102LV9T30::NW@@0Y:2P102Y
YJD40;2/[0@0^KBd1033_K`30<g6a@@0dlg<103Of]P40=oKfP@0f=GD103Cclh40<g9b0<0b<C31033
_[h40;ji^@@0^KBd102d/:l40;2[ZP<0[:NV102XXj840:BNWP@0X9^J102MUiH409VCTP<0UXn>102C
S8/408n8Q`@0S8F45P3oool001@0oooo1027P7l408InOP@0Q7el0`22Ng/4085jNP@0OgUh101nN7L4
07egMP@0O7If0`1kMGD<07YeM@@0NWEf101kMWL407ahN@<0OWYl1021OGl408B1P`@0QX>51028QHP4
08Z7RP<0SHV<102>Rhd408n<SP@0T8f?102CSi4409B?T@<0U8n@102CSi0409NBTP@0V9>C102JUI@4
09bGUP@0X9^J0`2TWYh40:VRX@@0[ZRV102d[jh40;bg]P@0`kfl0`3:aL@40=7=c0@0eM3?103>bLP4
0<W4``@0a<2o1030^kX30;bg]P@0]k:b102c[Zh40;2ZZP@0[:NV102YXj830:FOW`@0XYbK102OVIP4
09bFU@@0VI>B102FT8l309>=S0@0THZ9102>QhH408b4PaH0oooo000D0?ooo`@0Qh1o1026OWh408Am
O0<0PW]k1021NWX407miN0@0OWQg101mMgH407afMP<0NgEe301jMGD407YeMP@0NgIg101lN7T307ij
O0@0PGeo1024PH<408J3Q@@0R8F8102:QhX308f9S0@0SX^=102?S8h4092=S`@0ThnA102DSi4309B?
T0@0Thn@102GTY8409RCT`@0VYFD102LUiH40:2KVP<0Y9jN102YXZ440:jXYP@0]:n^102l]kH40<>m
_0<0b/G4103AcL`40=G@c`@0c/W81039a<<40<C0_`@0`;^j0`2l]kH40;Nb/P@0/jj^102`ZZX40:bW
YP@0ZJ>R0`2UWil40::LV`@0WiVH102LUYD409VCTP@0UY2?0`2CSH`4096:R@@0SXN6102<Q8<F0?oo
o`00503oool408N0O`@0QWin1024OG`3089kN`@0PGYj101oNGP407ihM`@0OGMf101lMWH307]eM@`0
NWEe101jMGH407]fM`@0O7Qi0`1nNW`4085mO`@0Q8631026PhD408R5R0@0RXN:0`2=RH`408j;S@@0
Shb>102@SHl409>?T@@0U8nA0`2DSi0409>?T0@0Ui:B102HTi<409ZEU0@0W9NF102PViX30:BNWP@0
ZJ:Q102^Z:H40;B_[P@0_;Nf1033_K`30<[5a0@0dLg<103Ed<l40<k9b0@0bLC31034`;l40<2k^P<0
_;Nf102g/[840;>^[P@0/:ZZ102/YjH40:VSXP<0YInO102RW9/409nIV0@0W9JE102ITi8409J@S`<0
Thf<102ARXT408j7QP@0S8B35P3oool001@0oooo1028P7l408MoOP@0QGim0`24OG`408=lN`@0PW]k
1021NWX4081iN@@0OgUi0`1oN7P<07ihN0@0OWUi101oNWX4081kN`<0PWem1024Oh0408J2P`@0RXF6
102AS8d409B>T0<0Thf?102DShl409JATP@0Ui6B102GT94409J@T0<0UY2A102GTI8409ZCT`@0ViFD
102OV9H40:6JV0@0XibK0`2VWid40:VSX@@0[ZRW102b[J`40;^f]@@0`Kbk0`34`;l40<C0_P@0`;^j
102m^;H40;Vd/`@0][2_102b[J`30:nZZ@@0[:JU102YXj840:JPW`@0XifM102QViX309jHU`@0W9FE
102ITi8409NAT0@0UHj=102CS8/3096:R@@0ShR7102=QXD408^3PQH0oooo000D0?ooo`@0R81o1027
Ogh408EnO@<0Q7el1023O7/4089kN`@0PGYj1020NGT407miN@<0OgQh301nN7P407iiN@@0OgYj1020
Ng/3089mO@@0Q7n01026PX<408Z5QP@0THb=102DSY0309>=S`@0U8n?102FTI8409NATP@0Ui2A102F
T90309J@T@@0Ui6B102JTi<409^EU0@0WiRF102QVYP40:>LV`<0YYnM102YXj440:jXY`@0/Zf/102k
][D40<6l^`<0a<2o1034`;h40<2k^P@0_KRf102i];<40;J`[`@0/Zf/0`2_ZZT40:bVY@@0ZJ>R102V
X9l40:>MW@@0XI^J0`2NV9L409bEU@@0VI>B102GTI0409F>S@@0Thb;0`2ARXT408n8Q`@0SHJ5102;
Ph8F0?ooo`00503oool408R0O`@0Qgmn1025OWd308AmO0@0Pgak1022Ng/4085jNP@0P7Ui101oNGT3
07mhN0`0OWQh101nNGT407mjNP@0P7]k0`22OGd408AoP0@0QX:3102:QHH4096<S@@0U8j@0`2CSHl4
09B?S`@0UY6B102GTI8409N@T@@0UY2@0`2FT94409NATP@0VY>C102KUI@409nHUP@0XIZH102SW9/3
0:JOW@@0ZJ>Q102^Z:L40;:][0@0^kJe1031_;/30<C0_`@0a<2n1030^kX40;fh]P@0^KBc102f/:l4
0;:][0<0[jZY102/YZD40:VSXP@0YZ2O102SWId40:6KVP<0WYRG102LUID409VCTP@0Ui6@102ESXd4
09><R`<0THZ9102?R8L408f6Q@@0Rh>25P3oool001@0oooo1028P7l408MoOP@0QGim0`24OG`408=l
N`@0PW]k1021NWX4081iN@@0OgUi0`1oN7P<07ihN0@0OWUi101oNWX4081kN`<0PWem1024Oh0408J2
P`@0RXF6102AS8d409B>T0<0Thf?102DShl409JATP@0Ui6B102GT94409J@T0<0UY2A102GTI8409ZC
T`@0ViFD102OV9H40:6JV0@0XibK0`2VWid40:VSX@@0[ZRW102b[J`40;^f]@@0`Kbk0`34`;l40<C0
_P@0`;^j102m^;H40;Vd/`@0][2_102b[J`30:nZZ@@0[:JU102YXj840:JPW`@0XifM102QViX309jH
U`@0W9FE102ITi8409NAT0@0UHj=102CS8/3096:R@@0ShR7102=QXD408^3PQH0oooo000D0?ooo`@0
R8601027P7l408MoOP<0QWin1025OWd808AmO0@0Pgal1023O7/?089kN`@0PWal1023O7`408=mO@<0
Q7io1026P80408R2PP@0RXF5102=R8P4092:RP<0Thf<102HTI0409RBT@@0Ui2@102HTI4409NAT@<0
UY2@102GT94409NAT0@0VI:A102KU9<409fFU@@0WiRG0`2QVYP40:BNW0@0[JJU102`ZZT40;B^[0@0
/Zf[0`2`ZjX40;2ZZ@@0[ZRW102[YJ@40:VSXP@0Yj6P102UWYd30::LV`@0X9ZI102NV9L409fFU@@0
ViBC102ITY4309N@T0@0UXn>102DSH`409><R`@0THZ9102@R8P308j7QP@0SHJ5102<Q8<408Z3PQH0
oooo000D0?ooo`@0R8601027P7l408MoOP<0QWin1025OWd808AmO0@0Pgal1023O7/?089kN`@0PWal
1023O7`408=mO@<0Q7io1026P80408R2PP@0RXF5102=R8P4092:RP<0Thf<102HTI0409RBT@@0Ui2@
102HTI4409NAT@<0UY2@102GT94409NAT0@0VI:A102KU9<409fFU@@0WiRG0`2QVYP40:BNW0@0[JJU
102`ZZT40;B^[0@0/Zf[0`2`ZjX40;2ZZ@@0[ZRW102[YJ@40:VSXP@0Yj6P102UWYd30::LV`@0X9ZI
102NV9L409fFU@@0ViBC102ITY4309N@T0@0UXn>102DSH`409><R`@0THZ9102@R8P308j7QP@0SHJ5
102<Q8<408Z3PQH0oooo000D0?ooo`@0R8601027P7l408MoOP<0QWin1025OWd808AmO0@0Pgal1023
O7/?089kN`@0PWal1023O7`408=mO@<0Q7io1026P80408R2PP@0RXF5102=R8P4092:RP<0Thf<102H
TI0409RBT@@0Ui2@102HTI4409NAT@<0UY2@102GT94409NAT0@0VI:A102KU9<409fFU@@0WiRG0`2Q
VYP40:BNW0@0[JJU102`ZZT40;B^[0@0/Zf[0`2`ZjX40;2ZZ@@0[ZRW102[YJ@40:VSXP@0Yj6P102U
WYd30::LV`@0X9ZI102NV9L409fFU@@0ViBC102ITY4309N@T0@0UXn>102DSH`409><R`@0THZ9102@
R8P308j7QP@0SHJ5102<Q8<408Z3PQH0oooo000D0?ooo`@0R8601027P7l408MoOP<0QWin1025OWd8
08AmO0@0Pgal1023O7/?089kN`@0PWal1023O7`408=mO@<0Q7io1026P80408R2PP@0RXF5102=R8P4
092:RP<0Thf<102HTI0409RBT@@0Ui2@102HTI4409NAT@<0UY2@102GT94409NAT0@0VI:A102KU9<4
09fFU@@0WiRG0`2QVYP40:BNW0@0[JJU102`ZZT40;B^[0@0/Zf[0`2`ZjX40;2ZZ@@0[ZRW102[YJ@4
0:VSXP@0Yj6P102UWYd30::LV`@0X9ZI102NV9L409fFU@@0ViBC102ITY4309N@T0@0UXn>102DSH`4
09><R`@0THZ9102@R8P308j7QP@0SHJ5102<Q8<408Z3PQH0oooo000D0?ooo`@0RH601028PH0408R0
O`L0Qh1o1027Ogh<08IoOPL0QWin2025OWh808IoOP@0QWmo0`27P80408R1P0@0RH:1102:Ph<408^4
Q0@0SHJ50`2>QhH<0929R0P0THZ90`2BS8X409J>S@@0Uhn=102HTHl409VBT0@0VY>A102KU98309fE
U0@0WiRG102QVYT809jGUP@0WINF0`2MUYD409bEU0@0ViBC102JTi8409VBT@@0V96@102GT8l309J?
SP@0UHj=102DSH`409><R`@0TX^:102ARXT30929R0@0ShR7102?QhH408j6Q@@0SHJ5102<QH@308b4
P`@0Rh>2102:Ph8408Z2PAH0oooo000D0?ooo`@0RH601028PH0408R0O`L0Qh1o1027Ogh<08IoOPL0
QWin2025OWh808IoOP@0QWmo0`27P80408R1P0@0RH:1102:Ph<408^4Q0@0SHJ50`2>QhH<0929R0P0
THZ90`2BS8X409J>S@@0Uhn=102HTHl409VBT0@0VY>A102KU98309fEU0@0WiRG102QVYT809jGUP@0
WINF0`2MUYD409bEU0@0ViBC102JTi8409VBT@@0V96@102GT8l309J?SP@0UHj=102DSH`409><R`@0
TX^:102ARXT30929R0@0ShR7102?QhH408j6Q@@0SHJ5102<QH@308b4P`@0Rh>2102:Ph8408Z2PAH0
oooo000D0?ooo`@0RH601028PH0408R0O`L0Qh1o1027Ogh<08IoOPL0QWin2025OWh808IoOP@0QWmo
0`27P80408R1P0@0RH:1102:Ph<408^4Q0@0SHJ50`2>QhH<0929R0P0THZ90`2BS8X409J>S@@0Uhn=
102HTHl409VBT0@0VY>A102KU98309fEU0@0WiRG102QVYT809jGUP@0WINF0`2MUYD409bEU0@0ViBC
102JTi8409VBT@@0V96@102GT8l309J?SP@0UHj=102DSH`409><R`@0TX^:102ARXT30929R0@0ShR7
102?QhH408j6Q@@0SHJ5102<QH@308b4P`@0Rh>2102:Ph8408Z2PAH0oooo000D0?ooo`@0RH601028
PH0408R0O`L0Qh1o1027Ogh<08IoOPL0QWin2025OWh808IoOP@0QWmo0`27P80408R1P0@0RH:1102:
Ph<408^4Q0@0SHJ50`2>QhH<0929R0P0THZ90`2BS8X409J>S@@0Uhn=102HTHl409VBT0@0VY>A102K
U98309fEU0@0WiRG102QVYT809jGUP@0WINF0`2MUYD409bEU0@0ViBC102JTi8409VBT@@0V96@102G
T8l309J?SP@0UHj=102DSH`409><R`@0TX^:102ARXT30929R0@0ShR7102?QhH408j6Q@@0SHJ5102<
QH@308b4P`@0Rh>2102:Ph8408Z2PAH0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002H0?ooo`900000QP3oool009X0
oooo00=000000?ooo`3oool0P`3oool007/0oooo0T0000040?ooo`03@000003oool0oooo00X0oooo
0d0000020?ooo`9000000`3oool3@00000D0oooo00=000000?ooo`3oool0O@3oool007d0oooo00I0
00000?ooo`3ooom000000?oood00000:0?ooo`06@000003oool0oooo@000003ooom00000103oool0
14000000oooo0?oood0000250?ooo`00O03oool2@0000080oooo00=000000?oood0000002P3oool0
1D000000oooo0?oood000000oooo00=000000P3oool014000000oooo0?oood0000250?ooo`00N`3o
ool00d000000oooo@00000020?ooo`03@000003ooom0000000/0oooo0d000000103ooom00000@000
040000030?ooo`=00000Q@3oool007/0oooo00=000000?oood0000000P3oool00d000000oooo@000
000=0?ooo`03@000003oool0oooo08d0oooo001l0?ooo`9000000`3oool00d000000oooo0?ooo`0;
0?ooo`900000S`3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(135) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
BFA390BFA28FBFA28FBFA28EBFA18EBEA18EBEA18DBEA08DBEA08CBDA08CBD9F8CBD9F8BBD9F8B\
BC9E8ABC9E8ABC9E89BC9D89BC9D89BB9D88BB9C88BB9C88BB9C87BB9C87BB9C87
BB9C88BB9C87BB9C87BB9C87BB9C87BB9C87BB9B87BB9B87BA9B87BA9B87BB9B87BB9B87BB9B88\
BB9C89BB9C89BB9D89BB9D8ABC9D8ABC9E8ABC9E8BBC9F8CBC9F8DBDA08EBDA18F
BDA18FBDA18EBDA08DBDA08DBDA08DBDA08DBEA18DBEA18DBEA18DBEA18EBEA18EBFA28EBFA28F\
BFA28FBFA38FBFA390
BFA28FBFA18EBEA18DBEA08DBD9F8CBD9F8BBC9E8ABC9E8ABB9D89BB9C88BB9C87BA9B86BA9A85\
B99A85B99984B89883B89782B79781B79680B79580B7957FB6957FB6947FB7957F
B7957FB6947FB6947EB6947FB6947FB6947FB6937EB5937DB5927DB5927DB5927EB5927FB69480\
B69581B79582B79683B79783B79784B89884B89985B99A87B99B89BA9D8BBB9F8E
BBA08EBB9E8BBB9D8ABB9D89BB9D89BB9E8ABB9E8ABC9E8ABC9E8BBC9F8BBD9F8CBDA08CBEA18D\
BEA18EBFA28FBFA38F
BFA28FBEA18EBEA08CBD9F8BBC9E8ABB9E89BB9C88BA9B86B99A85B99984B89882B79781B79680\
B6957FB5947EB5937DB4927BB3917AB38F78B28F77B28E76B28D76B18D75B18C75
B18C75B28D76B28D76B28D77B28D77B28D77B28D77B18D78B18C78B28C78B28C78B38D79B38F7B\
B4907CB4917DB4907DB3907DB3917DB3927EB49480B59582B69784B79987B99C8B
B99D8BB89A88B89A86B89986B89A86B99A86B99A86BA9B87BA9C88BB9D89BB9D8ABC9E8BBD9F8C\
BEA08DBEA18EBFA28F
BFA28FBEA18DBD9F8CBC9E8ABB9D88BA9B87B99A85B89984B79882B69681B5957FB4937DB4927B\
B39079B28F78B18D76B08C74AF8A72AE8970AE876FAD866DAC856CAC856CAD856C
AD856DAD856EAD866EAD866EAD866FAE8770AE8872B08974B08A75B08A76B08A76B18A76B18A76\
B18A76B18A77B18B77B08B77B08C78B08D79B18F7BB2917DB3927FB49481B59683
B59683B59682B59581B59581B59681B69782B79883B79984B89985B99A86BA9C87BB9D89BC9E8A\
BD9F8CBEA18DBFA28F
BFA28EBDA08CBC9F8BBB9D89BA9B87B99984B79882B69681B5947FB4937CB3917AB28F78B18D76\
AF8B74AE8A71AD886FAC866DAB846BAA8268A98066A87E64A77D63A77D62A77D63
A87E64A87E64A87F65A97F67A98068A9806AAA816BAA836DAB846FAB8570AC8670AD8671AD8671\
AD8671AD8771AE8772AD8672AD8773AD8974AE8975AE8B76AF8D79B0907CB1917D
B1917DB1907CB1917CB2917CB3927DB3937EB4947FB59580B69782B79883B89985BA9B87BB9D89\
BC9E8ABDA08CBEA28E
BEA18EBD9F8CBB9D89BA9C87B99985B79782B69580B4937DB3917BB28F78B08D76AF8B73AE8971\
AC876EAB846BA98269A88066A77D63A57B60A4795DA2765AA17458A17357A27458
A3765BA3775DA4785EA4795FA47961A47A62A57A63A57A64A67C65A77D68A77F69A77F69A87F69\
A87F69A88069A8806AA9816BA9816AA9826CA9846EA9856FAB8772AC8B77AD8C78
AD8B76AD8B76AE8C76AF8C77B08E78B18F79B2917BB3927DB4947EB69681B79783B89985BA9B87\
BB9D89BD9F8BBEA18E
BEA18DBC9F8BBB9C88B99A85B79882B69580B4937DB2917AB18E77AF8C74AE8971AC876EAA846B\
A98268A77F65A67D62A47A5FA2775BA174589F71549D6E509B6A4C9A68499C6A4C
9E6F529F70559F71579F7258A07359A0735AA0735BA0735CA0745CA1745DA1755EA2765FA2765F\
A27760A27861A37962A37A62A47A63A47B63A47C65A57F68A7816AA8836EA8856F
A9856EA9856EAA866FAB8771AC8973AE8B75AF8D77B18F7AB2917CB4937EB59581B79783B99985\
BA9C88BC9F8BBEA18D
BEA18DBC9E8ABA9B87B89883B69680B4937DB2917AB18E77AF8B74AD8970AB866DA9836AA78066\
A67D63A47A5FA2775CA074589E71549C6E509A6A4B976546935F3E94603F996748
9A694C9B6B4F9B6B519B6C519B6C529B6C529B6B529B6B529B6A529B6A529B6A529B6B539B6C55\
9B6D569C6F579C71589D72599E735B9F755CA0765DA17860A27A62A37C64A47D65
A47D65A57F67A68069A8826BA9846DAB8770AC8973AE8C76B08E79B2917BB4947EB69682B89985\
BA9C88BC9E8ABEA18D
BEA08DBB9D89B99A85B79782B5947EB3917BB18E77AF8B74AD8870AB856DA88269A67F65A47C61\
A2795DA075599E72559C6E519A6B4D986748966343935E3D915B3B945F3F976445
97654797654897664996654A96654A96654A96654B96634A956249956048945F47945F47946149\
95644C95674E966950976A52996C53996E549B6F559C70569C71579D72589F745A
A0765CA1785EA27A61A47D64A68068A8836BAA856EAC8872AE8B75B08E79B2917CB4957FB79883\
B99B86BB9D89BDA08D
BDA08CBB9D88B99985B69680B4927CB18F79AF8C75AD8971AA856DA88269A67F65A47B61A1785C\
9F74589D70539B6D4F98694A966545946140925D3C905A3696603D9A6644966242
946042936041925F42925F42915F43915E43915D43915C43905A418F59408F59408F59418F5A41\
8F5C438F5E4590614791634993654B95674D96694F976A4F986A4E98694D996A4D
9B6E529D71569E745AA0775EA27B62A57E66A7826AA9856EAC8972AE8C76B18F7AB3937DB69681\
B89985BB9D89BDA08C
BDA08CBA9C88B89883B5957FB3917BB08D77AD8A72AB866EA8826AA67F65A37B61A1775C9E7357\
9C6F53996B4E976749946344925F3F905B398C5531925B38996442966140935E3E
915C3D8F5B3B8E5A3A8D593B8D583B8C583C8C573C8C563C8B543A8B52398A51398A513A8A523B\
8A543C8A573E8B59408C5C428D5F448F6247916348936448936346936143946243
966648986A4D9A6E529C72579F765CA17A61A47E65A7826AA9866EAC8973AF8D77B2917BB5947F\
B79884BA9C88BDA08C
BD9F8BBA9B87B79883B4947EB19079AE8C74AC8870A9846BA68066A37C61A1775D9E73589B6F53\
986B4D966748936243905E3D8E5A388C5532915A37955F3C935D3A915C3A8F5A39
8D58378B553589533488523488523487523587513687513687533987553A86553A86563C86553C\
85533A85533A85553C87583E895B408B5D428D5F438F6044906043905E40905C3C
915D3D93634596684B986C519B71569E755CA17A61A47E66A7836BAA8770AD8B75B0907AB3947F\
B69783BA9B87BD9F8C
BD9F8BB99B86B69781B3927CB08E77AD8972AA856DA78168A47D63A1785E9E74599B7053986B4E\
9567489262438F5D3D8C58378A5431864E2A88502B8E57338E58358D57358B5635
895433865130844E2E834D2F824D30824D30824E3183503483563A835A3F835E42845F44825B40\
81563B80543981533982543A84573C86593D885B3F8A5D408C5D408C5C3E8C5A3B
8D5A3A8F5C3D91614494674A976C519A71579E765DA17B63A58068A8856EAC8973AF8E78B2927D\
B69782B99B87BC9F8B
BC9F8BB99A85B59580B2917BAF8C75AB8770A8836BA57E65A27A609E755A9B7155986C4F956749\
9262438F5D3D8B5837885331844D2988502B8D55318B55328A5432895433875333
855030824D2C7F4A2A7E482A7D482B7B482C7D5034815A3E835E4485644A856249825D43805F43\
7E5E447C593E7B52377D513680533883563B85583D875B3E885B3D895A3C895839
8855358956368C5B3D8F614493674B976D529B72599F785FA27D65A6826BAA8771AE8C76B1917C\
B59681B99A86BC9F8B
BC9E8AB89985B5947FB18F79AD8B74AA866EA68168A37C629F775D9C7257996D5195684B926345\
8F5E3E8B5838875331844E2B814A26844D29895330885330875230865231845130
824F2F804C2D7D4A2B7947287A4D2F815B3F84604582614682634882614682624682644A83644B\
8161487E5C4179563B7851367C51367F533982563A84583C85593C85583A855537
8554358554358656388A5B3E8F624693694E986F559C755CA07B63A48069A8866FAC8B75B0907A\
B49580B89A85BC9E8B
BC9E8AB89984B4947EB08F78AC8972A8846CA47F66A1795F9D74599A6F53966A4D9365478F6041\
8C5A3A875432834D2A7F4825804825844D2A86512E85512F845231835231815030
7F4F2F7D4F307D50327E53347F55378056387F57397E583A7E583B7D57397D573A7D573B7E573B\
805A3D825E42825D437C563D784F357A4F357D533780553981563A825538825436
8252338251318352328555388A5D4190654A956C529A72599E7960A37E67A7846DAB8973AF8F79\
B3947FB89985BC9E8A
BB9E8AB79883B3937DAF8D77AA8770A68269A27C639E775D9B7156976C5093674A9062438D5C3D\
89573685502E7D4622783F1981492488522F85512F83502F814F2F8050307F5031
7E51327F5538815D408564488463477F5C407D593C7B56387A5235795134795134794F31794F32\
7A53357C55387E563B7F573C7A5238784F347B51367D53377E53377F53367F5234
7F5133805031815132845537875B3E8D6247926A4F9770579C775EA17D65A5836CAA8872AE8E78\
B3937EB79984BB9E8A
BB9D89B69783B2917CAD8C75A9866EA47F67A07A609C745A986E5394694C9164468D5E408A593A\
875534844F2D804A27814B2786522E86543183512F804F307E4F317D50317C5032
7B51347B53367C563A7E5B3F7D5D417C5D407B5C407A5B3E795A3D78593B78583B77593B77593B\
7856387954387B55397D56397E573B7B54397951367A51367B52367C51357C5133
7C4F327C4E2F79492A7D4E2F85593C8A604490684D956E559A755C9F7B63A4816AA98771AD8D77\
B2937EB79884BB9E8A
BB9D89B69782B1907BAC8A74A7846CA37E659E785E9A7157956B509166498E60428A5B3C885636\
86533186512F8D5835935E3A8C583583512F7F4F2F7C50307B4F317A4F32795133
78523578533778533777543777563976573A76563A755639745438735437735437735437735437\
73543773563876593B7A5C407D5F447D5E437A583D785337785136795135795034
7A50327A4E317A4F327C513482573A885F448E664C936D5399735B9E7A62A38069A88670AC8C76\
B1927DB69883BB9D8A
BA9D89B59681B08F7AAB8972A6826AA17C639C755B976F5492684C8E62458A5C3E875737845231\
834F2C834D29854F2A85512F82502F7D4D2D7A4C2D784D2F774E31754F32754F33
755035755135734F33724E31724F337151357151357051356F51356F51346E4F336E4E326D4F33\
6E50346F513572533874563A76583D78593D78573D77543A765137765035774F34
784F33784F32784E317B513581573C865E438C654A926C5297725A9C7961A17F68A7856FAC8B76\
B1917CB69783BB9D8A
BA9C88B49580AF8E78A98770A480699E7961997259946B518F65498A5E4186583A8252337F4D2C\
7D48267C46237B46227A452278462577472975482A73492C724A2E714B2F704C30
704C32704D326F4D316E4B2F6D4A2E6D4B306C4B306B4B2F6B4C306A4C316A4C31694B306A4B31\
6B4D326D4E346E513771543A73563C74563C75553C745339735037745036765036
775035795035795034794F327E5437845C408A6349906A519671599B7860A07E67A6846EAB8B75\
B0917CB59783BA9D89
BA9C88B49480AE8D77A8866FA27E679C775E96705691684E8B6145865A3D8253357E4D2D7A4726\
77421F753F1B733E1C723F1D7341217242237043266E45286D45296C462A6B472B
6B492D6B4A2E6A4A2E69482C68472B68482C68492E67492F67492F67492F664930664A30674A31\
684B32694C346B4F366D51396F533D71553E71553D705239705037725037745037
7651367952377C53377B50337C5135835A3F8962488F6A519470589A77609F7D67A4846EAA8A75\
AF907CB59783BA9D89
B99B87B3947FAD8C76A6846DA07C659A755C936D538D654A885D418256397D4E3078472774401F\
703A196D37156B36146B3A196C3D1F6B3F216A4022694023684125674125664126
65432865442A65452B64452B64452963442963442963452A62452B62452B61442B61452C62462E\
634930654B32674C34684E376B513A6C523C6C513A6C50386D4F376F4F36714F37
7551387A543A825A3E865B3E80553981583E8963498E695193705898765F9E7D66A3836EA98A75\
AF907BB49682BA9D89
B99B87B2937EAB8B75A5836C9E7A6397725A916A508A624784593E7D513477492B7241216D3817\
68310F652D0C643011643618653A1B653C1E643C1E633B1F623B1E613B1F603B20
5F3C215F3D235F3F256041286042285F41275F40265E40265E3F265D3F265D40275D41295D422A\
5E442C5F462F614933644C36654E37664D37674C36684B35694B346B4B346E4D35
724E367752397D573F855E458B664C8B664D89654C8D6951926F5897765F9D7C66A2836DA88974\
AE907BB49682BA9D89
B99B87B1927DAA8A74A3816B9C79619570578D674E865E447F553A784D307244266B3B1C663313\
612D0E5E2D0E5E30116034156036185F371B5F371B5E361A5C361A5B35195A351A
59351A59361C5A381F5A3A225A3C235A3D255B3E265B3E275A3E265A3E26593E27593F27594029\
5A412B5C442F5E4833604934604933604833614832624731644832664832694934
6D4C35714F3876523A7C573E815C43845F4787634B8B6851906E5895755F9B7B66A1826DA78974\
AD8F7BB39682BA9D89
B89A86B1927DA98973A180699A775F926E558A644B835B417B523673482C6C3E206434145D2D0C\
582B0A562B0C572E0F5930135A32155A3317593317583216573015552F13542E13
532E15532F1653311954341B55361E563820563A22563B24563B25563B25563C25563D27563E28\
57402B58422D59432E59432E5A432E5A422D5B422D5C432E5E442F61452F634731
6749326B4B35704E3775523A78533B7C573F825F4888664F8E6D5794745E9A7A65A0816DA68874\
AD8F7BB39682B99C89
B89A86B0917CA88872A07E6898755E8F6B538762497F583E764E336E442865391C5C2E0F532405\
4B20024A22064E280C522C11542E13552F13542E13532E12522D11502B114E2A10
4C29104C2A124D2C154E2F184F321A51341D523720533822533A23523B24523B25523B25523C26\
533D28533D29533D2A533D2A523D29533D29543E2A563F2B59412D5B432E5E442F
6145306547316848316D4B33724E3578533B7E5C4685644E8B6B5692735E987A659F816CA58874\
AC8F7BB29582B99C89
B89A86AF907CA787729E7D6796735D8D6952845F467B553B724A30694024603519572B0E4C2105\
461E03451F0548240A4D290F4F2B11502C12502C124F2C114D2A114A281048270F
46260E46250E46250E4828114A2C154D301A4F341E5037215038224F38234F38234E38244E3924\
4E39254D39254C38254B37244B37244C37244E3825503A27523D29553F2B58402C
5B422E5E432E61452F6546306B4A3473523C7A5A4581634D886A558F725D9679659D806CA48773\
AB8E7BB29582B99C89
B79A86AF907CA686719D7C6694725C8B6850815D447751386D462C643B215B3115532A0F4D260C\
47220844210846240B4A280E4C2A104D2B124D2C134B2A1148270E44230A402007
3E1F073E200941220C43250F462812492E184C331E4E36224E38244E38244D38234C38234A3723\
4936234734224533214532204533204633214835224B37254E3A27503B28533D2A
563F2C58402D5A402D5E412D6547326E513C7659457E614D8669558D715D9578659C806CA38773\
AA8E7BB29582B99C89
B79986AE907BA586719C7C6693715B89664F7E5A43734E366842295E361C552C114D250B442008\
3F1E0741210945250D4828104A2A124C2C144C2D154C2D164A2C15472913422611
3C220D3B220C3E240E412611442712482D184B34204D38244D39264C39264B3825493724473522\
453321443321433120412F1E3F2D1C402E1D43311F4634224936244B38264D3A28
503C2A533E2C56402E5C43326349376B503E7359467B604D8368558B705D9378659B7F6CA28774\
AA8E7BB19582B89C89
B79986AE907BA586719C7B6692715B87654F7C5942704B33633D245730164E260D48230946240C\
45240E44240E462710482A14492C154A2D174B2E194C301C4E331F5035214F3420
4B321D48311C47311E4934214D38254E3A274D39264D3A284C3B294C3A284A3927483625453222\
42301F3F2F1E3B2B1A3828183829193B2C1B3E2E1D41301F4533224836254A3827
4C39294D3A2A4F3C2C5542325E4A3A67514070584678604E816855896F5D9277659A7F6CA18674\
A98E7BB19582B89C89
B79985AE907BA586719B7C6791715B87654F7B59426D4A325D38204B2309411A00411F0742230C\
432510442712452914472B16492D184A2E1A4A2F1B4C321E4E3624513927553D2B
5A43305A443157422E54412E51402E4F3D2C4E3C2A4D3B2A4C3B2A4C3B2B4C3B2B4B3B2B4A3C2C\
473A2B403326392C1F372A1C392B1D372A1B392A1C3E2E1E423121463526483828
483829483829493A2B4E3E2F584637634F3E6C5645765E4D7F6755886F5D907765997F6DA18674\
A98E7BB09582B89C89
B79A86AE917DA587739C7D6992725D8767517B5A446D4B3459351C4B270E401F08391A043A1E09\
40240F452914482C17492D19492F1C4A2F1D4A2F1D4B32214D3726503B2B533F30
5542325644345645365444345242334F40314E3E2E4D3D2D4C3C2D4C3D2E4C3E2F4C3F304D4030\
4D3F304D3E2F4B3C2E47392B44362844352744352746372947382B47382A46382A
45382A44362845372A4C3D2F5542335E4A3A695444735D4D7D6655866F5E8F7766987F6DA08775\
A88E7CB09583B89C89
B79B88AE927EA688749C7F6A937460886A557D5E4871513B63432C5738214D311B452A16422814\
452B16492D1A492E1B4A301D4A321F4C36244D38284B36254A35254B38284C3B2D
4E3F314F41335042344F41344F41344F42344E40314D3D2F4C3D2E4C3E304C3E324B3E324B3E31\
4B3F314E413354463858493A5445375242344F41334C3E31483B2F463A2E45392D
43372B42372B45392D4C3E315443355C4A3B665344715C4D7B6656856F5E8F7767987F6EA08775\
A88E7CB09583B89C8A
B79B88AF927FA68A769E806C9477638B6D5981634E7658436B4E3960432E553B274F36224C331F\
4B331F4A33204A321F49311F4B34234C38274F3C2D51413352433653443856493D
5A4E425A5045594F44574E43544A3F5045394D41344C3E314B3D314B3F334C40354A3E34483C32\
483C314A3E324D41345043375145395045394D4237493E34463B3245393043382E
41362C40362C443A304E423654463A59493B6351426F5C4D7A66578570608F786898806FA08876\
A88F7DB09684B89D8A
B89B88B09380A88B779F836F977A678E715E8568557C604C7358446A4F3C6147345A412E543C29\
5139264E37254B34224933224A35244C38284D3C2E50413453483C574E435A5247
5B554C5B564E5A564E575249524B404E44394B4034493E31493E324B40344D443850473D4F463D\
493F38453B32453B32483E344940354A4035483E35463C33443A31433A31423830
3F362E41372F473D344A40364E42375243365D4C3E6E5C4E7A67598571628F7A6A988271A18978\
A9907EB19684B89D8A
B89C89B19581A98D7AA18673997E6B917663896E5B816654795F4D7159476A5240634B395D4534\
58402F523B2A4E37264B35254A35264A37284C3A2C4D3E314F433751473D534B41
534C43534D45524C445049414D453C4A4136483D32473C30473C30493E334B41374F453C524A42\
554C445349414C433B453D35433B33433B33433B33433B33443C34443C35423A33
403A32433C34473F374740384B433A564B406355487060527C6A5C877365917C6D998473A28A7A\
AA9180B19785B89D8B
B99D89B29683AA8F7CA388759C816F947A688D7361866C5A7F665579614F725A496A5342644D3C\
5D46365640304E39294935254834254936274A382A4A3B2E4B3D314C40354D4238
4D443B4C443B4B433A494138473E35453C3244392F43382E44392E453A30473C334A40374D443B\
50483F534B42554C44544C445048404D453D4C443D4B443D47413A433E37413D36
423E3746413A4A453D4D4940514D455B5349675B4F7364577F6E60897769937F709B8676A38C7C\
AB9281B29886B99E8B
B99D8AB39784AC917FA58B799F8573987E6C9178678A7261846C5A7D6654776150715B4B695343\
614B3B5843334F3A2C49352647332547342647362947372B47392E473A2F473B30
473C32463C32453B3143393041372D40352B3F332A3F33293F342A40362C42382F443A31473E35\
4A41394D443D4F4840514A43524B44504A444D48424A443F46423C43403A423E38
44413B4A4741504C4656514A5B564E625A506B5E5376675B8373668D7C6E9683749E897AA58F7F\
AC9483B39988B99E8C
BA9E8BB49886AE9381A88E7CA188779B8271957D6C8F7767887262826D5E7D68597661536D5A4B\
6351435A4739513E3149362946332546332645342744342844342943352A42352A
41342A40342A3E33293D32283B30273A2F25392E24392E253A2F263B30273C322A3E352D413831\
433C34463F3849423C4A443E4A453F4A454048443F45433E43423C41413C41413D
4545414E4D4855534E5C5953635E576B645C73695F7E7166897A6E9282759A887AA18D7EA79282\
AE9686B49B89BA9F8D
BA9F8CB59A88AF9583AA907FA48B7A9F8776998272937D6D8E7869887365826E607C695B746154\
6B584B604F4257463A4D3C31473529443226433125413024402F233E2F243D2F25
3B2F253A2D24382C23372B22352A2134292033281F332820342921352B23362D263830293A332C\
3D3630403934423C37443F3A44403C44413D44413D43413D43413D42423E454542
4E4D495554505D5B5666635E6F6B6578726B807970897F7591847998897C9E8D80A49183AA9585\
B09988B59C8BBAA08D
BB9F8DB69B89B19786AC9382A78F7FA28B7B9D8677978273927E708C7A6C877568816F6279675B\
6F5E526554495B4A3F5341364A392D4432274030243E2E223C2C203A2A1F38291E
36281E34271D32261D30241B2F231A2E221A2E221A2D231B2D241C2F251F302821332A24352E28\
37312D3A35303C37333D3A363F3C383F3E3A403F3C41403D40413E4344424A4B48
5354505C5D59676661716F697B7871858079918B84978F87998E849E9084A39286A89587AD9889\
B29B8BB69E8CBBA08E
BBA08DB79D8BB39988AE9685AA9383A68F80A18B7D9C8779968375917E728B7A6D8574687D6D62\
75655B6B5C525E514754463C4A3C3343342A3E2F253B2C2138291E35261C332419
3022172E20162C1E152A1D14281C13271B13271B14271C16281F1829211B2B241E2D27222F2A25\
322E2934302D3633303837343A39373C3C3A3D3E3C3E403F414442474A48505251
5B5D5A66676471716D7C7A7586837E908C8599928B9E958DA1968CA4968BA8988BAC998CB09B8C\
B49D8DB89F8EBCA18F
BCA18EB89E8CB59B8AB19989AD9687A99485A59183A28F829D8B7E9886799180758A7B7084756B\
7A6C626F615863564D564B424A3E3641342B3B2D2437291F34251B3122172D1E13
2A1B1028190E25170D23150C21150C20150D20150F201610211813221B16251F1A27231F2A2623\
2D2A26302E2B32312F353432373736383A39393D3C3C4140414646494E4E555959
6165636E6F6E7A7A77858380908E8A9D9893A39E97A59D95A79D94AA9D92AC9D91AF9D90B39E90\
B69F90B9A190BCA290
BDA18FB99F8EB69E8DB39C8CB09A8BAD988AAA978AA79589A493879E8F8497897E908278887A71\
7E716873675E675C54594F484B413A40352E392D2534271E3022182C1D1328190F
25160B2113091F11081D10091B0F09190E08180E0919100C1A13101C17141F1A18221E1B25221F\
2826242B2A292E2F2E313332333636363A3A393D3E3D4244444B4C5056575D6263
6B6F6E797A7985858392908D9F9C98ACAAA6B0ACA7ADA69FAEA49BAFA298B1A296B3A194B5A193\
B8A292BAA291BDA391
BDA290BBA18FB8A08FB69F8FB39E8FB19D8FAF9C90AD9C90AA9B91A6988F9E9188968A818E8279\
847971786E676B625C5D544F4F4741423934372D2630251D2B1F17271A1122150D
1E110A1A0E07170C05150A04130904110904110A06120C09130F0C1512101916141C1A191F1F1E\
2323232628282A2D2D2D3232313637353B3D3A414341494B4B5355585F61666C6D
75797982858490918F9D9C99A8A6A2B0ADA8B3AEA8B3ACA5B3A9A0B4A79DB5A69AB6A598B8A496\
BAA494BCA393BEA391
BEA390BCA291BAA291B8A192B6A193B5A194B3A296B2A298B1A399ADA098A69A939D928B948A83\
8A817B7F7670736A65665E5958504B47403B39312D2F2520281C172216101D110B
180C071409051107030E05010B04010A04020905030B07060D0B0A100E0E1313121718181B1D1D\
1F2222232728272C2E2B323430373A363E403E474A485155555E61646C6E72787A
7F84858D90909B9D9CAAAAA7B5B3B0B9B6B2BAB5AFB9B2AAB9AEA6B9ACA2B9AA9EB9A89BBAA798\
BCA596BDA594BEA492
BEA391BDA392BBA493BAA495B9A596B8A699B8A79BB8A99FB9ADA5B7ABA5AEA49DA59C959D948E\
948B8589807A7C74706F6864615B58514C4A403B39312B29261E1B1F1613180F0C
1209070D05030A02010701000500000200000201010404040708090A0D0E0E1112121617171C1D\
1C222321272A262E312C3538333C403B4449464F54545D61626B6E71787B7F8688
8E93939C9F9FAAACABB6B7B5C2C3C2C6C5C2C1BCB7BFB7B0BDB3AABDB0A6BCADA1BCAB9EBDA99A\
BDA798BEA695BFA492
BFA492BEA493BDA595BCA697BCA89ABCA99DBCACA0BDAFA5BFB3ABBDB4ADB6ADA7ADA59FA59D97\
9A948F908A86857F7A79736F6D67655F5A584F4A493E3A39302C2B231E1D181312
0F0B0A09040406010103000100000100010300030601050803080B060D0F0B12150F181B131C20\
192226202A2E2732372F3A3F394349444F55525D62606B6F70797C7F878A8E9496
9DA2A3ACAFAFBABCBAC4C5C3CACAC7C9C8C4C6C2BCC4BCB5C2B7AEC0B3A9BFB0A4BFADA0BFAB9C\
BFA899BFA796BFA593
BFA492BFA594BEA797BEA899BEAA9CBFACA0BFAFA4C0B3A9C2B7AFC3BAB5C0B8B3B8B0ABAFA8A3\
A69F9B9B9591908B8785807D7873716B66645D59574E4A493F3C3B302E2E242222
1A18181210120C0B0E08080C06080D050A0F050C11050D13050F150812190B171D101C22162329\
1C2A302331372D3A4037444A435056515E63606C71707A7E81898C90979AA0A5A7
AFB3B4BEC1C0CACBCBD3D4D3D5D5D2CFCDC9CBC6C0C8C0B8C5BAB2C3B6ACC2B2A6C1AFA2C0AC9E\
C0AA9AC0A797C0A593
C0A593C0A695C0A898C0AA9BC0AC9FC1AFA2C2B2A7C4B6ACC6BBB3C9C1BAC8C1BCC1BAB5B8B1AD\
B0A9A5A8A29E9D9895908C89837F7D7571706763625955554C4849403D3D343334
2A2B2D2224271B1E22161A1E14191E12191E10191F0F1A210F1C24111E2614212A19272F1E2D35\
26343C2E3D4438464D445259526065606D72707B80818A8E92999CA2A8AAB2B6B7
C2C5C6CFD1D2DADCDBE0E2E1DCDDDBD4D1CDCFC9C3CBC3BBC8BDB4C6B8AEC4B4A8C3B0A3C2AD9F\
C1AB9BC0A897C0A694
C0A593C0A796C1A999C1AB9CC2AEA0C3B1A4C5B5A9C7B9AFC9BEB6CDC4BDCFC9C4CBC6C2C2BDB9\
BAB5B1B1ACA9A7A2A09A96948E8A88817E7C7471706866655B5A5B4F4F51464648
3E3F4137393C3033372A2E33262B30252A30232B31232D33232F3626323A28363E2C3A42314048\
3948504351584D5B6158666B667277758084858E92949C9FA4AAACB4B9BAC4C8C8
D3D6D5DFE1E1E9ECECE8EAE9DEDDDAD8D4CFD2CBC5CEC4BCCBBFB5C8BAAFC6B5A9C4B2A4C3AEA0\
C2AB9BC1A897C0A694
C0A593C1A796C1AA9AC2AC9DC3AFA1C5B3A6C7B6ABC9BBB1CCC0B8CFC6BFD3CCC7D3CDC9CDC7C4\
C4C0BDBBB7B4B0ACAAA6A3A09C9997908D8C8381807674736A696960606158585A
505153484A4E4346493F42463B4045393F453840463942483A444B3C474E3F4B524350574A565E\
515E655A666C636F756E797F7B858A8A929699A0A3A8AEB0B8BCBDC8CBCBD7D9D8
E3E5E4EEF2F2EFF3F2E7E7E5DFDDD9D9D4CED4CCC5D0C5BDCCC0B6CABBAFC7B6AAC5B2A5C4AFA0\
C3AC9CC2A998C1A694
C0A593C1A897C2AA9AC3AD9EC4B0A2C6B4A7C8B8ACCBBCB2CEC2B9D1C8C0D6D0CAD9D5D1D6D3D0\
CFCBC8C6C3C0BEBAB8B3B0AEA8A5A49D9A9992908F8685857C7B7B7373736B6B6C
6464665E5E60585A5D54575B51555950555950555B51575D535960555D635961685E676D656E74\
6C767B737D827C858A868E9291999C9EA5A7ADB2B4BDC0C1CBCECED8D9D9E3E5E4
F0F3F3F3F6F6ECEDEBE6E4E1DFDBD6DAD3CDD5CCC4D1C5BCCDC0B5CBBBAFC8B6A9C6B2A4C4AFA0\
C3AC9CC2A998C1A694
C1A693C1A897C3AB9AC4AD9EC5B0A2C7B4A7C9B8ACCCBDB2CFC2B9D3C9C1D8D1CADFDBD7E2E0DD\
DBD9D6D2CFCDC9C7C5C0BDBCB7B4B3AEABABA5A2A19B9898919090878687807F7F
7A79797474756F70716C6E6F6B6D6F696C6E696C6F6A6D716C70746F737774797D7A7F837F8589\
868C908D9396959A9D9FA4A6ABAEB0B7BABBC5C6C7D1D2D2DDDEDDEAEAE9F4F4F3
F6F7F6F0F1F0EAE9E6E4E1DCDFD9D3DAD1CAD5CAC2D1C4BBCEBFB4CBBAAEC9B6A9C7B2A4C5AFA0\
C3AC9BC2A997C1A694
C1A693C2A897C3AB9AC4AD9EC6B0A2C7B4A6CAB8ABCCBDB1D0C2B8D3C8C0D8D0C9DED8D3E5E2DF\
E7E6E4E0DEDCD6D4D2CECAC9C6C2C1BEBBBAB6B4B3AEACACA6A4A49E9C9C979595
918F908C8C8C89898886858683838482828381828382838584858787898B8B8E909395989B9DA0\
A0A2A4A6A7A9AEAFB0B9B9B9C2C3C2CCCCCBD7D7D6E3E2E1ECECEBF4F5F4FAFDFD
F7F9F9EFEEEBE8E5E1E3DDD7DDD5CFD9CFC7D5C9BFD1C3B8CEBEB2CBB9ADC9B5A8C7B2A3C5AF9F\
C4AB9BC2A997C1A694
C1A593C2A896C3AA9AC4AD9DC6B0A1C8B3A5CAB7AACCBCB0CFC1B6D3C6BDD8CDC5DDD5CEE2DDD9\
EAE7E5EBE9E8E4E1DFDBD7D6D2CFCDCBC9C7C7C4C2C1BEBCBAB7B5B4B1AFADABAA
A8A5A5A4A1A0A09D9D9D9A9A9B98989A98989A97989A98989B9A9A9D9C9CA2A0A0A7A5A4ADAAA9\
B5B2B0BCBAB8C4C2C0CCCAC8D3D1CFDCDAD8E5E4E1EFEEECF8F7F6FDFFFFFBFDFD
F2F2F0ECE8E5E6E0DBE0D9D2DCD2CAD7CCC2D4C6BCD0C1B5CDBCB0CBB8ABC9B4A6C7B1A2C5AE9E\
C3AB9AC2A897C1A693
C1A593C2A896C3AA99C4AC9CC6AFA0C7B2A4C9B6A8CCBAADCFBFB3D2C4B9D6CAC1DBD0C9E0D8D2\
E5E0DBECE9E6EDEBE9E7E4E2E0DCDBD9D5D3D4D0CFD0CDCCCBC8C7C7C3C2C4BFBE
C1BCBABDB8B6B8B3B2B5B0AFB2AEACB1ACABB0ABAAB0ACABB2ADACB3AEACB4AFACB7B1ADBBB6B2\
BFBAB6C5C0BCCCC8C4D5D1CEDFDBD8E9E5E2F1EEEBF9F7F5FFFFFEFCFEFDF5F4F1
EEEBE7E8E2DDE3DAD4DED4CCD9CDC4D6C8BED2C3B8CFBEB2CCBAADCAB6A8C8B3A4C6B0A0C5AD9D\
C3AA99C2A896C1A693
C1A593C2A795C3A998C4AC9BC5AE9EC7B1A2C9B4A6CBB8AACDBCAFD0C0B5D4C6BBD8CBC2DCD2CA\
E1D9D3E7E1DCEEEBE8EFEDEBE9E6E4E3DFDDDFDBD9DCD8D6D9D6D4D7D2D1D3CDCC
D0CAC8CFC8C7CDC7C5CAC3C1C7C0BEC6BFBDC6BEBCC5BEBAC5BEBAC7BFBBC8BFBBC9C1BCCCC4BF\
D1C9C4D9D0CBDFD8D3E7E0DCEFEAE5F5F1EDFBF8F5FFFFFEFDFEFDF6F5F1EFEBE6
E9E2DCE3DBD4DFD4CCDACEC5D7C9BED3C4B8D0BFB3CEBBAECBB8AAC9B4A6C7B1A2C6AF9FC4AC9B\
C3AA98C2A796C1A593
C1A592C1A795C2A897C3AB9AC5AD9CC6AFA0C8B2A3CAB5A7CCB8ABCEBCB0D1C1B5D5C6BBD8CBC2\
DDD1C9E2D8D2E7E0DBEFEAE7F4F1EFF0ECEAE8E3E1E2DDDBE1DCDAE2DDDCE3DDDB
E2DCD9DED7D5DBD3D1DCD3D1DDD4D0DAD0CBD6CBC6D4C9C4D4C9C4D3C9C3D4C9C2D5CAC3D7CCC5\
DCD1CAE2D8D1E9DFD9EFE7E2F6EEE9FAF4F0FDFAF8FAF9F7F4F0ECEEE8E2E8E0D9
E3D9D1DED3CADACDC3D7C8BDD3C3B7D1BFB2CEBBAECCB8AACAB5A6C8B2A3C6AF9FC5AD9CC4AB9A\
C3A997C2A795C1A592
C0A492C1A694C2A896C3A998C4AB9AC5AD9DC6AFA0C8B2A3CAB5A6CCB8AACEBCAFD1C0B3D4C4B9\
D8C9BFDCCFC6E0D5CDE6DDD6ECE4DFF1ECE8F1ECE9EDE6E3E9E3DFE8E1DEE8E0DD
E7DEDBE7DDD9E7DCD8E5D9D3E1D5CEDFD3CBDFD2C9DDCFC6DACCC3D9CCC2DBCEC5DCD0C7DED2C9\
E3D7CFE8DED6EFE5DFF3EAE5F5EFEBFAF6F3F8F4F0F0E9E4EAE2DBE5DBD3E1D5CC
DDCFC5D9CABFD6C5BAD3C1B5D0BDB0CEBAACCCB7A8CAB4A5C8B2A2C7AF9FC5AD9DC4AB9AC3A998\
C2A896C1A694C0A592
C0A491C1A593C2A794C2A896C3A998C4AB9AC5AD9CC6AF9EC8B1A1C9B3A4CBB6A7CDB9ABCFBCAF\
D2C0B4D5C5B9D9C9BFDDCFC5E1D4CCE6DAD2ECE3DCF2E9E3F2E9E3EDE3DDE9DED9
EADFDAEADED9E8DBD4E5D7D0E2D4CDE2D4CCE2D3CAE2D3C8E2D3C8E1D2C8E1D2C7E2D4C9E3D6CD\
E4DBD2E8DFD7EDE5DFF3EDE8F5EFEAF0E9E2EAE0D8E5D9D0E0D3C9DCCEC3D9C9BD
D6C5B8D3C1B4D0BDB0CEBAACCCB7A8CAB5A5C9B2A3C7B0A0C6AE9EC5AC9CC4AB9AC3A998C2A896\
C2A795C1A693C0A492
C0A492C1A592C1A693C1A694C2A795C3A897C3AA98C4AB9AC5AC9CC6AE9EC7B0A0C9B2A2CAB4A5\
CCB7A8CEBAACD1BDAFD3C0B4D6C4B8D9C8BDDDCDC2E0D1C6E2D4C9E6D8CDE7DACF
E6D8CEE5D6CDE5D7CEE4D5CDE1D1C9DECEC5DCCCC2DCCCC0DDCCC0DDCCC0DDCCC1DCCCC0DECFC3\
E4D7CDEADED6E9DED5E5D9CFE2D5CBE0D1C6DCCCC1D9C8BBD6C3B7D3C0B2D1BDAF
CFBAABCDB7A8CBB5A5C9B3A3C8B1A1C7AF9EC6AD9DC5AC9BC4AB99C3A998C3A897C2A795C1A694\
C1A693C1A592C0A491
C0A491C0A491C0A492C1A592C1A593C1A693C2A694C2A795C2A896C3A997C4AA98C4AB99C5AC9B\
C6AD9CC7AF9EC8B0A0CAB2A2CBB4A4CDB6A6CEB8A9D0BAABD1BCACD2BDAED3BEAF
D3BEAFD3BEAFD3BFB0D4C0B1D7C3B4D8C5B5D9C5B7D9C5B8D9C6B8D9C6B8DAC7B9DAC8BBDBC9BC\
D8C5B8D5C1B4D4C0B2D3BEB0D1BCADD0BAABCEB8A8CCB5A6CBB3A3C9B2A1C8B09F
C7AF9EC6AD9CC5AC9BC5AB99C4AA98C3A997C3A896C2A895C2A795C2A694C1A693C1A593C1A592\
C0A492C0A491C0A491
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool40;nST0P0_j:?0`2o
XXh40;nQSP@0_Z6>102nXHd40;jPS@@0_Z2<0`2mX8`40;fOS0P0_In;202lWXX40;bNR@L0_9f9102k
WHP80;^LR0/0^ib7102kW8PC0;^LQ`P0^i^7202jVhL70;^KQ`@0^i^8202kW8T40;^MR@@0^if:0`2l
WHX40;bNRP@0_9j;102lWh`40;bOS@@0_J2>1`2mXHl40;fQSQ00_J2=2`2nXHd80;jQSP@0_j:>1`2o
XXl40;nSS`@0_j>@5P3oool001@0oooo102oXi080;nRS`<0_j:>102oXHh40;jQSP@0_Z6=102nX8d4
0;jPS0<0_J2<102mWh`80;fOR`P0_9j:102lWXT70;bMR@@0^if8202kW8P;0;^LQ`@0^ib84`2kW8L8
0;^KQ`P0^Y^71`2kVhL40;^KR0P0^ib9102kWHT40;^MRP<0_9f:102lWXX40;bNR`@0_9n<102lWhd4
0;fPSPL0_J6?102mXHh@0;fPS@/0_Z6=202nXHh40;nRSPL0_j:?102oXhl40;nST1H0oooo000D0?oo
o`@0_j>@202oXXl30;nRSP@0_j6>102nXHh40;jQS@@0_Z2=102nX8`30;fPS0@0_In<202mWh/80;bN
RP@0_9j91`2lWHT40;^MR0P0^ib82`2kW8L40;^LR1<0^ib7202kVhL80;ZKQ`L0^i^7102kVhP80;^L
R@@0^if9102kWHX30;bMRP@0_9j:102lWX/40;bOS0@0_9n=102mX8h70;fQS`@0_J6>402mX8d;0;jQ
S@P0_Z6>102oXXh70;nRS`@0_j>?102oXi0F0?ooo`00503oool40;nST0P0_j:?0`2oXXh40;nQSP@0
_Z6>102nXHd40;jPS@@0_Z2<0`2mX8`40;fOS0P0_In;202lWXX40;bNR@L0_9f9102kWHP80;^LR0/0
^ib7102kW8PC0;^LQ`P0^i^7202jVhL70;^KQ`@0^i^8202kW8T40;^MR@@0^if:0`2lWHX40;bNRP@0
_9j;102lWh`40;bOS@@0_J2>1`2mXHl40;fQSQ00_J2=2`2nXHd80;jQSP@0_j:>1`2oXXl40;nSS`@0
_j>@5P3oool001@0oooo102oXXl40;nQSP@0_Z6=0`2nX8d40;fOS0@0_In;202lWXX40;^MR@<0^ib8
102kW8L40;ZKQP@0^YZ5102iVXD40;VIQ0@0^9R30`2hUh840;NGP@@0]iJ0102gUH040;NEO`@0]YEo
0`2fU7l80;NEO`@0]YAo102fU7h;0;JDO`@0]Y=n102eTgd80;FBO@@0]I9n0`2eTWl40;JDP0@0]YF1
102gUH840;NFP`@0]iN30`2gUh@40;RHQ0@0^9V5102iVXL40;VKR@@0^Yf;102kWhh30;^PSP@0^ij;
102kWHX80;^MR@L0^ij:102lWXX40;bNR`@0_9n;102mWh`40;fPS0<0_Z6=102nXHh40;nRS`@0_j>?
5P3oool001@0oooo102oXXl40;nQSP@0_Z6=0`2nX8d40;fOS0@0_In;202lWXX40;^MR@<0^ib8102k
W8L40;ZKQP@0^YZ5102iVXD40;VIQ0@0^9R30`2hUh840;NGP@@0]iJ0102gUH040;NEO`@0]YEo0`2f
U7l80;NEO`@0]YAo102fU7h;0;JDO`@0]Y=n102eTgd80;FBO@@0]I9n0`2eTWl40;JDP0@0]YF1102g
UH840;NFP`@0]iN30`2gUh@40;RHQ0@0^9V5102iVXL40;VKR@@0^Yf;102kWhh30;^PSP@0^ij;102k
WHX80;^MR@L0^ij:102lWXX40;bNR`@0_9n;102mWh`40;fPS0<0_Z6=102nXHh40;nRS`@0_j>?5P3o
ool001@0oooo102oXXl40;nQSP@0_Z6=0`2nX8d40;fOS0@0_In;202lWXX40;^MR@<0^ib8102kW8L4
0;ZKQP@0^YZ5102iVXD40;VIQ0@0^9R30`2hUh840;NGP@@0]iJ0102gUH040;NEO`@0]YEo0`2fU7l8
0;NEO`@0]YAo102fU7h;0;JDO`@0]Y=n102eTgd80;FBO@@0]I9n0`2eTWl40;JDP0@0]YF1102gUH84
0;NFP`@0]iN30`2gUh@40;RHQ0@0^9V5102iVXL40;VKR@@0^Yf;102kWhh30;^PSP@0^ij;102kWHX8
0;^MR@L0^ij:102lWXX40;bNR`@0_9n;102mWh`40;fPS0<0_Z6=102nXHh40;nRS`@0_j>?5P3oool0
01@0oooo102oXXl40;nQSP@0_Z6=0`2nX8d40;fOS0@0_In;202lWXX40;^MR@<0^ib8102kW8L40;ZK
QP@0^YZ5102iVXD40;VIQ0@0^9R30`2hUh840;NGP@@0]iJ0102gUH040;NEO`@0]YEo0`2fU7l80;NE
O`@0]YAo102fU7h;0;JDO`@0]Y=n102eTgd80;FBO@@0]I9n0`2eTWl40;JDP0@0]YF1102gUH840;NF
P`@0]iN30`2gUh@40;RHQ0@0^9V5102iVXL40;VKR@@0^Yf;102kWhh30;^PSP@0^ij;102kWHX80;^M
R@L0^ij:102lWXX40;bNR`@0_9n;102mWh`40;fPS0<0_Z6=102nXHh40;nRS`@0_j>?5P3oool001@0
oooo102oXXl40;jQSP@0_Z2<0`2mWh/40;bNRP@0^ij9102kW8P40;ZKQP@0^IZ50`2iVH@40;RHPP@0
]iN1102gUX040;JEO`@0]IAn102eTgd30;BBN`@0/i5j102cSgP40;:?M`@0/Xif102bSGH30;6=M@P0
/Hae202bSGH?0;:=M`@0/Heh102aS7P80;:<N0<0/hei102cSg/40;B@O0@0]95m102dT7d40;>@O@<0
/i5m102cTWh40;BDP0@0]IF2102fUh@40;NIQ`@0^Ib;0`2iWH/40;RJR0@0^9Z6102hVHH40;RJQPL0
^IZ6102jVhL40;ZLR0@0^if9102kWHX40;bNR`<0_In<102nX8d40;jQSP@0_j:?5P3oool001@0oooo
102oXXl40;jQSP@0_Z2<0`2mWh/40;bNRP@0^ij9102kW8P40;ZKQP@0^IZ50`2iVH@40;RHPP@0]iN1
102gUX040;JEO`@0]IAn102eTgd30;BBN`@0/i5j102cSgP40;:?M`@0/Xif102bSGH30;6=M@P0/Hae
202bSGH?0;:=M`@0/Heh102aS7P80;:<N0<0/hei102cSg/40;B@O0@0]95m102dT7d40;>@O@<0/i5m
102cTWh40;BDP0@0]IF2102fUh@40;NIQ`@0^Ib;0`2iWH/40;RJR0@0^9Z6102hVHH40;RJQPL0^IZ6
102jVhL40;ZLR0@0^if9102kWHX40;bNR`<0_In<102nX8d40;jQSP@0_j:?5P3oool001@0oooo102o
XXl40;jQSP@0_Z2<0`2mWh/40;bNRP@0^ij9102kW8P40;ZKQP@0^IZ50`2iVH@40;RHPP@0]iN1102g
UX040;JEO`@0]IAn102eTgd30;BBN`@0/i5j102cSgP40;:?M`@0/Xif102bSGH30;6=M@P0/Hae202b
SGH?0;:=M`@0/Heh102aS7P80;:<N0<0/hei102cSg/40;B@O0@0]95m102dT7d40;>@O@<0/i5m102c
TWh40;BDP0@0]IF2102fUh@40;NIQ`@0^Ib;0`2iWH/40;RJR0@0^9Z6102hVHH40;RJQPL0^IZ6102j
VhL40;ZLR0@0^if9102kWHX40;bNR`<0_In<102nX8d40;jQSP@0_j:?5P3oool001@0oooo102oXXl4
0;jQSP@0_Z2<0`2mWh/40;bNRP@0^ij9102kW8P40;ZKQP@0^IZ50`2iVH@40;RHPP@0]iN1102gUX04
0;JEO`@0]IAn102eTgd30;BBN`@0/i5j102cSgP40;:?M`@0/Xif102bSGH30;6=M@P0/Hae202bSGH?
0;:=M`@0/Heh102aS7P80;:<N0<0/hei102cSg/40;B@O0@0]95m102dT7d40;>@O@<0/i5m102cTWh4
0;BDP0@0]IF2102fUh@40;NIQ`@0^Ib;0`2iWH/40;RJR0@0^9Z6102hVHH40;RJQPL0^IZ6102jVhL4
0;ZLR0@0^if9102kWHX40;bNR`<0_In<102nX8d40;jQSP@0_j:?5P3oool001@0oooo102oXXl40;jQ
S@@0_In<0`2lWXX40;^MR0@0^Y^7102iVXD40;RIQ0@0]iR20`2fUX440;FEO`@0]9=m102dTW/40;>@
N@@0/Xmh102aSGH30;2<M0@0[hYb102^RG040:j7K`@0[HI]1`2/QF`40:f5K0@0[HE]102]QFh80:f6
KP<0[HI_102^Qg040:j8LP@0/8Ud102`RWD80;2:MP/0/HYf102aRWL40;6;M`@0/8]g0`2`S7P40;2=
N@@0/Hmk102bTGd40;>BO`@0]9B11`2eUX<40;FFPPP0]IF1102eUX440;JGPP<0]iR3102gVH@40;RI
Q@@0^IZ6102jW8L40;^MR@<0_9j:102mWh`40;jQS@@0_j:?5P3oool001@0oooo102oXXl40;jQS@@0
_In<0`2lWXX40;^MR0@0^Y^7102iVXD40;RIQ0@0]iR20`2fUX440;FEO`@0]9=m102dTW/40;>@N@@0
/Xmh102aSGH30;2<M0@0[hYb102^RG040:j7K`@0[HI]1`2/QF`40:f5K0@0[HE]102]QFh80:f6KP<0
[HI_102^Qg040:j8LP@0/8Ud102`RWD80;2:MP/0/HYf102aRWL40;6;M`@0/8]g0`2`S7P40;2=N@@0
/Hmk102bTGd40;>BO`@0]9B11`2eUX<40;FFPPP0]IF1102eUX440;JGPP<0]iR3102gVH@40;RIQ@@0
^IZ6102jW8L40;^MR@<0_9j:102mWh`40;jQS@@0_j:?5P3oool001@0oooo102oXXl40;jQS@@0_In<
0`2lWXX40;^MR0@0^Y^7102iVXD40;RIQ0@0]iR20`2fUX440;FEO`@0]9=m102dTW/40;>@N@@0/Xmh
102aSGH30;2<M0@0[hYb102^RG040:j7K`@0[HI]1`2/QF`40:f5K0@0[HE]102]QFh80:f6KP<0[HI_
102^Qg040:j8LP@0/8Ud102`RWD80;2:MP/0/HYf102aRWL40;6;M`@0/8]g0`2`S7P40;2=N@@0/Hmk
102bTGd40;>BO`@0]9B11`2eUX<40;FFPPP0]IF1102eUX440;JGPP<0]iR3102gVH@40;RIQ@@0^IZ6
102jW8L40;^MR@<0_9j:102mWh`40;jQS@@0_j:?5P3oool001@0oooo102oXXh40;fPS0@0_9n;0`2k
WHT40;ZKQ`@0^IV4102gV8840;JFP@@0]IAo0`2dTg`40;>ANP@0/Xmh102aSGH40:n;M0@0[XYa102]
R6l30:b6K@@0ZhA[102ZPVP40:V0IP@0Z7iT102WOF<30:MmHP@0YgeS202XOV@40:QoI@@0ZGmW0`2Y
P6P40:V0JP@0ZX5[102ZPfd40:^4K`@0ZhE`102/QW0;0:f6L@@0[HMa102^Qg840:f6LP<0[HMc102]
RG@40:j9M@@0[X]f102_SGT40;2@O0L0/I5m102aT7`40;6AO0@0/Y5l102cTWd40;>COP<0]9Ao102e
UH040;JGPP@0]iR3102hVHD40;ZKQ`<0^if9102lWXX40;fPS0@0_Z:>5P3oool001@0oooo102oXXh4
0;fPS0@0_9n;0`2kWHT40;ZKQ`@0^IV4102gV8840;JFP@@0]IAo0`2dTg`40;>ANP@0/Xmh102aSGH4
0:n;M0@0[XYa102]R6l30:b6K@@0ZhA[102ZPVP40:V0IP@0Z7iT102WOF<30:MmHP@0YgeS202XOV@4
0:QoI@@0ZGmW0`2YP6P40:V0JP@0ZX5[102ZPfd40:^4K`@0ZhE`102/QW0;0:f6L@@0[HMa102^Qg84
0:f6LP<0[HMc102]RG@40:j9M@@0[X]f102_SGT40;2@O0L0/I5m102aT7`40;6AO0@0/Y5l102cTWd4
0;>COP<0]9Ao102eUH040;JGPP@0]iR3102hVHD40;ZKQ`<0^if9102lWXX40;fPS0@0_Z:>5P3oool0
01@0oooo102oXXh40;fPS0@0_9n;0`2kWHT40;ZKQ`@0^IV4102gV8840;JFP@@0]IAo0`2dTg`40;>A
NP@0/Xmh102aSGH40:n;M0@0[XYa102]R6l30:b6K@@0ZhA[102ZPVP40:V0IP@0Z7iT102WOF<30:Mm
HP@0YgeS202XOV@40:QoI@@0ZGmW0`2YP6P40:V0JP@0ZX5[102ZPfd40:^4K`@0ZhE`102/QW0;0:f6
L@@0[HMa102^Qg840:f6LP<0[HMc102]RG@40:j9M@@0[X]f102_SGT40;2@O0L0/I5m102aT7`40;6A
O0@0/Y5l102cTWd40;>COP<0]9Ao102eUH040;JGPP@0]iR3102hVHD40;ZKQ`<0^if9102lWXX40;fP
S0@0_Z:>5P3oool001@0oooo102oXXh40;fPS0@0_9n;0`2kWHT40;ZKQ`@0^IV4102gV8840;JFP@@0
]IAo0`2dTg`40;>ANP@0/Xmh102aSGH40:n;M0@0[XYa102]R6l30:b6K@@0ZhA[102ZPVP40:V0IP@0
Z7iT102WOF<30:MmHP@0YgeS202XOV@40:QoI@@0ZGmW0`2YP6P40:V0JP@0ZX5[102ZPfd40:^4K`@0
ZhE`102/QW0;0:f6L@@0[HMa102^Qg840:f6LP<0[HMc102]RG@40:j9M@@0[X]f102_SGT40;2@O0L0
/I5m102aT7`40;6AO0@0/Y5l102cTWd40;>COP<0]9Ao102eUH040;JGPP@0]iR3102hVHD40;ZKQ`<0
^if9102lWXX40;fPS0@0_Z:>5P3oool001@0oooo102nXHh40;fOS0@0^if90`2jW8L40;VIQ@@0]iN2
102fUH040;BCO@@0/i5k0`2bSgP40;2=MP@0[h]c102^RG440:b7KP@0ZhA[102YPVT30:R0IP@0YgeS
102UNf040:AiG@@0XWIJ102QM5P30:5cE`@0XWAH102SMU/40:=gG@@0Y7QN102TNEl30:AiH@@0Y7YR
102UNV<40:EjI0@0YWaU102WOFP70:MoJ@P0Z7mY102XP6T40:R0JP@0ZH5[0`2YPFX40:V2K0@0ZHA^
102YQFl40:^7LP@0[8]g102]S7P70:f;MP@0[Xaf102_S7L40;2>N0@0/Hmi0`2bTG/40;>BO@@0]9An
102fUX440;NGP`@0^9V50`2jVhL40;^MR@@0_In;102nXHhF0?ooo`00503oool40;jQSP@0_In<102k
WHT30;ZLQ`@0^IV5102gUh840;JEP0@0]9=m102cTG/30;:?N0@0/8ef102_Rg<40:j9L@@0[8M^102[
Q6/40:V2J@<0Z81V102WOF<40:EkH0@0Y7UM102RMUX40:5dF0<0XG=G102RM5P40:=fF`@0XgMM102T
N5h40:AiG`<0Y7UQ102TNV840:EjH`@0YGYT102VO6D40:MmJ0L0YgmY202XOfT40:R0J@@0Z81Z102Y
PF/30:V1JP@0ZH9/102YQ6h40:V5K`@0ZhMb102/RgL40:f<N0L0[H]f102^S7H40:n<M`@0/8ih102a
SgT30;:AN`@0/i9m102dU7h40;JFP@@0]iN3102hVHD30;ZKQ`@0^if9102mWh/40;jQSQH0oooo000D
0?ooo`@0_Z6>102mWh`40;^MR@<0^Yb7102iVHD40;NGPP@0]YF0102dTgd40;>AN`<0/Xmh102`SGH4
0:n;L`@0[XUa102/Qfh40:^4J`@0ZH9Y0`2XP6H40:MmH`@0YG]P102TNEd40:9fFP@0XGAH0`2QLeL4
0:9dF0@0XgIK102SMed40:AhGP@0Y7UO0`2TNF440:AjHP@0YGYS102UNV@40:IlI@@0YgeX1`2WOfT8
0:QoJ@@0Z81Y102XP6X40:V1J`<0ZH5Z102YPV`40:V4KP@0ZHE_102[Qg840:b;M`@0[Hah1`2]RgH4
0:j<MP@0[hag102`SWP40;6?N@<0/Y5k102cTWd40;BDOP@0]YJ1102gUh<40;RIQ@<0^Y^7102kWHT4
0;fOR`@0_Z6>5P3oool001@0oooo102nXHh40;fOS0@0^if90`2jW8L40;VIQ@@0]iN2102fUH040;BC
O@@0/i5k0`2bSgP40;2=MP@0[h]c102^RG440:b7KP@0ZhA[102YPVT30:R0IP@0YgeS102UNf040:Ai
G@@0XWIJ102QM5P30:5cE`@0XWAH102SMU/40:=gG@@0Y7QN102TNEl30:AiH@@0Y7YR102UNV<40:Ej
I0@0YWaU102WOFP70:MoJ@P0Z7mY102XP6T40:R0JP@0ZH5[0`2YPFX40:V2K0@0ZHA^102YQFl40:^7
LP@0[8]g102]S7P70:f;MP@0[Xaf102_S7L40;2>N0@0/Hmi0`2bTG/40;>BO@@0]9An102fUX440;NG
P`@0^9V50`2jVhL40;^MR@@0_In;102nXHhF0?ooo`00503oool40;jQS@@0_9n;102kW8P30;VJQ@@0
]iR2102fUH040;BCO@@0/Y5j102aSWL30:n<M0@0[XUa102/Qfh40:Z4J`@0ZH9X102WOfD40:ImHP<0
Y7YO102RMe/40:5dF0@0Wg5D102MKU0409]ZC0<0VVQ9102LJT`409i_DP@0Wg1E102OLEL409mbF0<0
X7=I102PLeX40:1cF`@0X7=L102PM5`40:5dG@@0XGEN1`2RMUl40:9gH0@0XWQQ102SNF840:=jHP<0
Y7YS102TNf<40:AlI@@0YGmX102WPFX40:R3KP@0Z8E_1`2YQFh40:Z6K`@0ZhMa102/RG<40:j;M@<0
[heg102aSgX40;:AO0@0]9=n102eUH440;NGP`<0^IV5102jW8P40;bOR`@0_Z6=5P3oool001@0oooo
102nXHd40;bOR`@0^ib80`2iVXD40;NHPP@0]YF0102dTgd40;:ANP@0/Hig0`2_S7@40:j9L@@0[8M^
102ZQ6/40:V2J0@0YgmU102VOF830:AjG`@0XWMK102QM5P409maE0@0WFi@102KJT`309YXB@@0W6Y<
102NKe8409m`E@@0Wg5G102OLUP30:1cF@@0X7=J102PLe/40:1cG0@0X7AL102QM5d40:5eGPL0XWIO
102RMf040:9hH@@0XgUR102SNV830:AjH`@0Y7]S102TO6D40:EoJ0@0Yh5Z102XPfh40:R5K`L0ZHE^
102ZQVl40:^7L@@0[8Uc102^RgD30:n=M`@0/Hmj102bTG`40;BCOP@0]IF1102gUh<30;VIQ@@0^Yb8
102lWh/40;jQSAH0oooo000D0?ooo`@0_Z6=102lWh/40;^LR0<0^IZ5102gV8840;JEP0@0]9=m102b
TGX40;6>M`<0[had102^RG440:b7KP@0ZXA[102YPVP40:MoI@@0YWeR0`2TNUl40:9gF`@0XGAH102O
LE@409e^D0@0VfY<0`2JJ4T409aZC0@0WVmB102OL5D409maE`@0Wg9H0`2PLeT40:1cFP@0X7=K102P
Le`40:1dG0@0XGAM102QMEh70:9fG`@0XWMP102RN6440:=iHP@0XgYR0`2TNV<40:AkH`@0Y7aU102U
OfP40:N1JP@0Z8=^102XQFl70:V5KP@0ZXI_102[Qg440:b9L`@0[X]e0`2_SGL40;6?NP@0/Y5l102d
Tgh40;FEP@@0]iN30`2iVHD40;ZLR0@0_9n;102nXHdF0?ooo`00503oool40;jQS@@0_9n;102kW8P3
0;VJQ@@0]iR2102fUH040;BCO@@0/Y5j102aSWL30:n<M0@0[XUa102/Qfh40:Z4J`@0ZH9X102WOfD4
0:ImHP<0Y7YO102RMe/40:5dF0@0Wg5D102MKU0409]ZC0<0VVQ9102LJT`409i_DP@0Wg1E102OLEL4
09mbF0<0X7=I102PLeX40:1cF`@0X7=L102PM5`40:5dG@@0XGEN1`2RMUl40:9gH0@0XWQQ102SNF84
0:=jHP<0Y7YS102TNf<40:AlI@@0YGmX102WPFX40:R3KP@0Z8E_1`2YQFh40:Z6K`@0ZhMa102/RG<4
0:j;M@<0[heg102aSgX40;:AO0@0]9=n102eUH440;NGP`<0^IV5102jW8P40;bOR`@0_Z6=5P3oool0
01@0oooo102nXHd40;bNRP@0^Y^70`2hV8<40;JFP0@0]9=m102bTGX40;6>M`@0[h]d0`2]RG040:^6
K@@0ZH=Z102WP6H40:ImH`@0Y7YO102RMe`30:1dF0@0WW5D102LKU0409YZB`@0UfE6102CGch309AP
?`@0VFM8102JJD`409][C`@0Vf]A102KK54709]/DPP0Vf]B302KJU8309][D`@0VfaE102KKEH409a_
E`@0W75H102MLUT309icF`@0WgEL102PMUd40:5hH0@0XWYR102SO6@70:AmI@@0YGmW102VP6T40:R2
J`@0ZHA]102[Qg030:b9L`@0[Xaf102`SWT40;:AN`@0]9An102fUX830;RIQ@@0^Yb8102lWXX40;jQ
SAH0oooo000D0?ooo`@0_Z6=102lWXX40;ZKQ`<0^9R3102fUX040;BCO@@0/Y5j102aSWL40:n;M0<0
[HU`102[QVd40:V3JP@0Yh1V102VOF<40:AjG`@0XWML0`2PM5P409iaE0@0W6i@102JJT/409MUAP@0
Teln0`2DH3l409UWB0@0VVU<102KJdl409][D@@0VfaA1`2KK58809][DP`0VfYB0`2KJe<409]/E@@0
VfeF102LKeL409aaF0@0WG9I0`2NLe/409meG0@0X7IM102QN6040:9jHP@0XgaT1`2TOFD40:EoI`@0
YX1Y102XPV/40:V4K@@0ZhM`0`2/RG<40:j<MP@0/8ii102bTG/40;BDOP@0]YJ20`2hVHD40;ZLR0@0
_9j:102nXHdF0?ooo`00503oool40;jQS@@0_9j:102jVhL30;RHP`@0]YJ0102dTgd40;:ANP@0/Hig
102_Rg@30:f9L0@0ZhI]102YPfX40:N0IP@0YWeS102TNUl40:9gG0<0X7AH102NLE@409a^D0@0VVY;
102GIDH409=O?P<0U60o102IIdP409YYC0@0Vf]?102KJe4409]/D@L0VfaB202KJe8<09]ZDP<0Vf]C
102KK5D409]]EP@0W6mG102LLEP409ebF@<0WW=K102OME`40:1fG@@0XGQP102RNV840:=lI0L0Y7eU
102UOfL40:J0J@@0Z89[102YQ6d40:^7L0<0[8Uc102^S7H40;2>N@@0/Y5k102dU7h40;JFPP<0^9V5
102jW8P40;bNRP@0_Z6=5P3oool001@0oooo102nXHd40;bNRP@0^Y^70`2hV8<40;JFP0@0]9=m102b
TGX40;6>M`@0[h]d0`2]RG040:^6K@@0ZH=Z102WP6H40:ImH`@0Y7YO102RMe`30:1dF0@0WW5D102L
KU0409YZB`@0UfE6102CGch309AP?`@0VFM8102JJD`409][C`@0Vf]A102KK54709]/DPP0Vf]B302K
JU8309][D`@0VfaE102KKEH409a_E`@0W75H102MLUT309icF`@0WgEL102PMUd40:5hH0@0XWYR102S
O6@70:AmI@@0YGmW102VP6T40:R2J`@0ZHA]102[Qg030:b9L`@0[Xaf102`SWT40;:AN`@0]9An102f
UX830;RIQ@@0^Yb8102lWXX40;jQSAH0oooo000D0?ooo`@0_Z2=102kWHT40;VJQ@<0]iN2102eU7h4
0;>AN`@0/Hig102_Rg@40:f8L0<0ZhE]102XPVT40:IoI@@0Y7aQ102RNEd40:1eF@@0WW9E0`2LKU44
09Y[C@@0V6M8102FHd<409=N?@@0TE/k0`2DGcl409MTA@@0UfE7102GIDP409MVB@/0UVE:102FID/4
09ISBP@0UF99102EH4P709AOA`@0U659102EI4`409EWCP@0UVU@102GJU8309U/D`@0VFiD102KKeD4
09a`EP@0W75G102MLUP409mdFP<0X7IL102QN5h40:9jH@@0Y7eT102VP6P40:R3J`<0ZXE^102/R784
0:j;M@@0/8ii102bTG`40;BEO`<0]iR3102iVhH40;^MR@@0_J2=5P3oool001@0oooo102nX8d40;^M
R@@0^IZ50`2gUh840;FDOP@0/i5k102aSWL40:n;M0@0[HQ`0`2[QFd40:R2J@@0YWmU102TO6440:9i
G@@0X7EI102NLUD309a^D@@0VV]=102HIdP409IS@`@0Tehm102AFc/309AO?`@0UfA5102GIDL409MU
B0@0UfI92`2FIDX409IUB`@0UV=:102EHTT409EPB0L0U5m7102DHDT409ETC0@0UFM>102FJE0409MZ
DP<0VFaC102IKU@409]_E@@0W71F102LLEL409ebF0@0WgAJ0`2PMU`40:5hGP@0XWYQ102TOF@40:J0
J0@0Z8=[0`2ZQFh40:b8LP@0[X]e102`SWT40;:AO0@0]9Eo0`2gV8<40;VKQP@0^if9102mX8dF0?oo
o`00503oool40;jPS@@0^if9102iVXD30;NGPP@0]IAn102cTG/40;6>M`@0[h]d102]R7030:^5K@@0
Z89Y102VOfD40:AlH@@0XWUM102PMET409ibE@<0W6iA102JJdd409QWB0@0UV=3102CGSd4095K>`<0
U5lo102GI4D409MUA`@0UfE8102GITT;09IUBP@0UVE;102FHdX409ERB@@0UF181`2DGdL409AQB@@0
UFA<102EIdh409IYD0@0UfYB0`2IK5<409U^E0@0VfmE102LL5H409aaE`@0WG9H102OM5X30:1fG0@0
XGQN102RNV440:AmI0@0YX1X102XPf/30:Z5KP@0[8Qb102^RgD40;2>N@@0/Y5l102dUGl30;NHP`@0
^I^6102kWHT40;fPSAH0oooo000D0?ooo`@0_Z2=102kWHT40;VJQ@<0]iN2102eU7h40;>AN`@0/Hig
102_Rg@40:f8L0<0ZhE]102XPVT40:IoI@@0Y7aQ102RNEd40:1eF@@0WW9E0`2LKU4409Y[C@@0V6M8
102FHd<409=N?@@0TE/k0`2DGcl409MTA@@0UfE7102GIDP409MVB@/0UVE:102FID/409ISBP@0UF99
102EH4P709AOA`@0U659102EI4`409EWCP@0UVU@102GJU8309U/D`@0VFiD102KKeD409a`EP@0W75G
102MLUP409mdFP<0X7IL102QN5h40:9jH@@0Y7eT102VP6P40:R3J`<0ZXE^102/R7840:j;M@@0/8ii
102bTG`40;BEO`<0]iR3102iVhH40;^MR@@0_J2=5P3oool001@0oooo102mX8`40;^MR0@0^IV50`2f
UX040;BBO0@0/Hmi102_S7D40:f9L@@0ZXE]0`2XPVT40:IoI@@0Y7]Q102QN5`409mdF0@0WG1C102K
KDl309QYBP@0UVE5102DHD04099M?0@0T5Xf102FH3d309YVA0@0UV92102DH48409=P@@P0TUm20`2A
Gd<4095N@`@0TEe3102AG4<4091J@@P0SeU00`2?FD4408mJ@@@0Sea3102?GTD4091QA`@0TF=90`2C
ID/409EWC@@0UVU?102GJTl409QZCP@0V6U=102IJTd309]^DP@0WG5F102NM5X40:1gGP@0XW]R102U
OVH30:N2JP@0ZHE^102/RG840:j<MP@0/Hmj102cTgd30;JFP@@0^9V5102kWHT40;fPS1H0oooo000D
0?ooo`@0_J2<102kWHP40;VIQ@<0]YJ0102dTW`40;6?N@@0[hae102]RG440:Z5K@<0Z89Y102VOfD4
0:AkH@@0XGQL102OM5P409e`D`@0Vfe?0`2HJDX409IUA@@0U650102BGC`4091J=P@0UV0m0`2JIT@4
09IR@P@0U612102CH448099O@P<0TEm3102AGT<4095M@`@0TEa3102@FT4808mI@0<0SeU1102?FT44
08mL@`@0Sei5102@HDL4095SB@<0TfE;102EIdd409IYC`@0UfY?102HJTh409QYC@@0VFY=0`2KKU84
09eaEP@0WWAJ102PMeh40:9kHP@0YGiV0`2WPVX40:V5KP@0[8Ub102^S7H40;6?NP@0/i=m0`2fUX44
0;RIQ@@0^if9102mX8`F0?ooo`00503oool40;fPS0@0^if8102iVHD30;JFP0@0]99l102aSgT40:n<
M@@0[HUa102ZQFd30:R2J@@0YWmU102TNf440:5hG0@0WgAH102ML5<409]]C`<0V6U:102FIDD409AQ
@0@0TUdl102@FSH409IP?@<0VVI4102FHT8409AP@P@0Tf11202BGd83095O@`@0TEi3102AGD<4095L
@`@0T5Y1202?FD0308mI@@@0SeY1102?G4<408mNA@@0T657102AHdT309=UB`@0UFM=102FJDl409MZ
C`@0V6Y>102HJDd409UZC@<0VfiB102MLEH409idFP@0X7MN102RNf840:EnIP<0Yh9Z102YQFh40:b9
LP@0[Xaf102aSgX40;>CO@<0]YJ1102hVHD40;^MR@@0_J2<5P3oool001@0oooo102mX8`40;ZLR0@0
^9R30`2eUGl40;>AN`@0/8eg102]RW840:^6KP@0Z89Z0`2VOfD40:=kH@@0XGML102NLeL409a_D`@0
VF]>102GIdT309ASA0@0TUlo102@FcT408aE<@@0TU/h102II48309IQ@0@0Tehn102AG3d408mK>`@0
SUXj102=FC/308eH>`@0S5Pl102<Ec`408aF?0@0Re@j102;DST408YA>@<0RU4j102:DS/408YD?0@0
RULn102;FD0408aL@P<0SEm4102?HTL4095SB0@0TfA8102CHdH409=Q@`@0U6930`2FITP409QZC@@0
VViB102LLUL409mfG0@0XGYQ0`2TOVD40:N2JP@0ZHI^102/RG<40:n=M`@0/Y5k0`2eU7l40;NHQ0@0
^Yb8102mX8`F0?ooo`00503oool40;fPS0@0^Yb8102hV8<30;FEO`@0/i5k102`SGL40:f:LP@0ZhI^
102XPVX30:IoI@@0Xg]Q102QMe`409icE`@0W6mC102IJdh409MWB@<0U6=4102BGcl4091K>@@0S5Da
102BFcP409UT@P<0UV50102CGSh4095L?@@0Se/k102>FSX408eI>`<0SEPk102<F3`408aG?0@0S5Hl
102;E3X408]B>@@0RU4i0`2:DCX408YB>`@0RU@l102:Ech408]I@0@0S5a20`2=Gd@408mRA`@0TF=8
102CI4P409=SAP@0Tf53102DHT<309IVB0@0V6Y=102JKU8409abE`@0WgIL102QNV430:AnI@@0Yh9Z
102YQVh40:b9L`@0[heg102bTG/30;FDO`@0]iR4102jW8P40;fPS1H0oooo000D0?ooo`@0_J2<102j
W8P40;RHP`<0]IEo102cTG/40;2=M`@0[HYb102[QVh40:R2JP<0YWmU102SNf440:5gG0@0WW=G102L
Ke<409U[CP@0UfM90`2DHd@4099O?`@0T5/i102<EC44099K>0@0VFA20`2FHD0409=N?P@0TE`m102?
Fc/408iJ>P@0SETk0`2=F3/408aH?0@0S5Ll102<ES`408]D>P@0Re8i102:DCT308YA>P@0RU8k102:
E3`408YG?P@0ReU0102<G48308eOA0@0Sf97102AHdP409=TB0@0Tf=6102CHD<409AR@`<0UVI8102H
JTd409Y^DP@0W79G102OMU`40:5jH@<0Y7iU102WPVX40:V6KP@0[8Uc102_SGL40;:AN`<0]IAo102g
V8@40;ZLR0@0_J2<5P3oool001@0oooo102mX8`40;ZLR0@0^9R30`2eUGl40;>AN`@0/8eg102]RW84
0:^6KP@0Z89Z0`2VOfD40:=kH@@0XGML102NLeL409a_D`@0VF]>102GIdT309ASA0@0TUlo102@FcT4
08aE<@@0TU/h102II48309IQ@0@0Tehn102AG3d408mK>`@0SUXj102=FC/308eH>`@0S5Pl102<Ec`4
08aF?0@0Re@j102;DST408YA>@<0RU4j102:DS/408YD?0@0RULn102;FD0408aL@P<0SEm4102?HTL4
095SB0@0TfA8102CHdH409=Q@`@0U6930`2FITP409QZC@@0VViB102LLUL409mfG0@0XGYQ0`2TOVD4
0:N2JP@0ZHI^102/RG<40:n=M`@0/Y5k0`2eU7l40;NHQ0@0^Yb8102mX8`F0?ooo`00503oool40;fO
R`@0^Y^7102gV8<30;BDOP@0/I1i102^S7@40:b8L0@0ZHA[102VP6H30:=lH@@0XGMM102NLeP409]_
D`@0V6]=102FIdP409=R@`<0T5hm102>FSP408aE<P@0TEXg102EGc`409=M>P<0TE`j102?FST408eH
=`@0ReDe1029Dc@708QB=0@0Qe8e2027DCH408MC>@@0QeDj1026ECX308IF?0@0QUDl2025DcX408EE
?0@0QePn0`29Fd0408]M@P@0SEm3102?H4@4091P@`@0T5i0102@G3`3095M?@@0Tf=5102FJ4/409Q/
D@@0Vg5F102NME`30:5jH@@0Y7iV102WPf/40:Z7L0@0[H]e102`T7X30;>DO`@0]YN3102jVhL40;fO
S1H0oooo000D0?ooo`@0_In;102jVhL40;NHP`<0]9An102aT7T40:j<M0@0[8Q`102YQ6/40:J0IP<0
XgaQ102QMed409icF0@0VfmC102HJdd409IWB0@0Tf930`2@GSd408iJ>0@0S5Db102AFSL409EO?0@0
Tedj0`2AG3X408mJ>@@0SEPg102;ECD408UC=0L0R58d1027DSD808MA=P@0Qe<i1027ECX408IE>P<0
QUHl1026EC`808EC>P@0QEDl1027F3h308UK@0@0Ree2102=Gd<408mPA0@0T613102@GT04091L?0<0
TEdm102CHdD409IXB`@0V6aA102KLEH409ieG0<0XGYQ102TOVH40:N3J`@0ZXM`102]RgD40;2@NP<0
/iAo102fUh<40;ZKQ`@0_In<5P3oool001@0oooo102mWh/40;ZKQ`@0]iR30`2dU7h40;6@N@@0[Xad
102/R7040:V4J`@0YX1V0`2SO6440:5gG@@0WW=H102KKe<409Q[C@@0UVM8102CHT<3091N?@@0SUXh
102<EC84095J=`@0UEll102CGCX3095L>P@0SeXi102=F3L408]E=@@0RE<d1`28DS@408MB=@P0Qe4f
1027DcT408ME>P@0QUDj0`26ES`408IE?0P0QE<j1025EC`408MH?P<0RE]0102;GD8408eO@`@0Sf14
102@H4<4091N@0@0T5`l0`2AGCd409=SA@@0UVQ;102HK54409]aEP@0WWEL0`2QNV440:AnIP@0Yh=[
102ZQg040:f;M@@0/91j0`2cU7l40;JGP`@0^Y^7102mWh`F0?ooo`00503oool40;fOR`@0^Y^7102g
V8<30;BDOP@0/I1i102^S7@40:b8L0@0ZHA[102VP6H30:=lH@@0XGMM102NLeP409]_D`@0V6]=102F
IdP409=R@`<0T5hm102>FSP408aE<P@0TEXg102EGc`409=M>P<0TE`j102?FST408eH=`@0ReDe1029
Dc@708QB=0@0Qe8e2027DCH408MC>@@0QeDj1026ECX308IF?0@0QUDl2025DcX408EE?0@0QePn0`29
Fd0408]M@P@0SEm3102?H4@4091P@`@0T5i0102@G3`3095M?@@0Tf=5102FJ4/409Q/D@@0Vg5F102N
ME`30:5jH@@0Y7iV102WPf/40:Z7L0@0[H]e102`T7X30;>DO`@0]YN3102jVhL40;fOS1H0oooo000D
0?ooo`@0_In;102iVhH40;JGP@<0/i9l102`SWL40:f9LP@0ZXE]102WPFP40:AmH`<0XGQN102NM5T4
09]`D`@0V6]>102EIdP4099R@`@0Sedm0`2<F3L408YD<@@0QThZ1028D2/408iG<`@0SUPe0`2=EcD4
08]F=@@0RE@c1026DC0408A>;P@0Pdd_1`22CC04089><@@0Pe0d1023ESX408=J?`@0Pei20`24Gd@4
089K@0@0PEHk1020E3T4085C>@@0PU@j0`24Ec`408II?@@0R5/o102:GD0408aM@0@0S5`n102<FS/3
08eJ>P@0Se`m102AHD@409AWBP@0UfaA102JLEL309ifG@@0XG]S102UP6P40:R5KP@0[8Uc102_SWP3
0;:BO@@0]YN2102iVhL40;bORaH0oooo000D0?ooo`@0_In;102iVhH40;JGP@<0/i9l102`SWL40:f9
LP@0ZXE]102WPFP40:AmH`<0XGQN102NM5T409]`D`@0V6]>102EIdP4099R@`@0Sedm0`2<F3L408YD
<@@0QThZ1028D2/408iG<`@0SUPe0`2=EcD408]F=@@0RE@c1026DC0408A>;P@0Pdd_1`22CC04089>
<@@0Pe0d1023ESX408=J?`@0Pei20`24Gd@4089K@0@0PEHk1020E3T4085C>@@0PU@j0`24Ec`408II
?@@0R5/o102:GD0408aM@0@0S5`n102<FS/308eJ>P@0Se`m102AHD@409AWBP@0UfaA102JLEL309if
G@@0XG]S102UP6P40:R5KP@0[8Uc102_SWP30;:BO@@0]YN2102iVhL40;bORaH0oooo000D0?ooo`@0
_In;102iVhH40;JGP@<0/i9l102`SWL40:f9LP@0ZXE]102WPFP40:AmH`<0XGQN102NM5T409]`D`@0
V6]>102EIdP4099R@`@0Sedm0`2<F3L408YD<@@0QThZ1028D2/408iG<`@0SUPe0`2=EcD408]F=@@0
RE@c1026DC0408A>;P@0Pdd_1`22CC04089><@@0Pe0d1023ESX408=J?`@0Pei20`24Gd@4089K@0@0
PEHk1020E3T4085C>@@0PU@j0`24Ec`408II?@@0R5/o102:GD0408aM@0@0S5`n102<FS/308eJ>P@0
Se`m102AHD@409AWBP@0UfaA102JLEL309ifG@@0XG]S102UP6P40:R5KP@0[8Uc102_SWP30;:BO@@0
]YN2102iVhL40;bORaH0oooo000D0?ooo`@0_In;102iVhH40;JGP@<0/i9l102`SWL40:f9LP@0ZXE]
102WPFP40:AmH`<0XGQN102NM5T409]`D`@0V6]>102EIdP4099R@`@0Sedm0`2<F3L408YD<@@0QThZ
1028D2/408iG<`@0SUPe0`2=EcD408]F=@@0RE@c1026DC0408A>;P@0Pdd_1`22CC04089><@@0Pe0d
1023ESX408=J?`@0Pei20`24Gd@4089K@0@0PEHk1020E3T4085C>@@0PU@j0`24Ec`408II?@@0R5/o
102:GD0408aM@0@0S5`n102<FS/308eJ>P@0Se`m102AHD@409AWBP@0UfaA102JLEL309ifG@@0XG]S
102UP6P40:R5KP@0[8Uc102_SWP30;:BO@@0]YN2102iVhL40;bORaH0oooo000D0?ooo`@0_9n;102i
VXD40;FEP0<0/Y5k102_S7D40:^7L0@0Z8=[102UOVD40:9jH0<0WWEJ102KLED409Q/C`@0UFM9102B
HT<408mM?@@0RePg0`28Dc4408A=:@@0R50[102=EC4408]E<P@0RU@b0`29E3<408MC<`@0QE0`1022
CB`407m::P@0OTPZ0`1mB2/407]8;0@0OE0d1021FSh408=NA0@0QFA:1025HTT3089M@`@0P5m3101n
GT@407aI?P@0Ne8g101mDCH3081C>0@0PeHk1025F3d408MK?P@0R5/m1029FS`408UH>@<0R5De1029
ESH408aK?@@0Sf54102CId/409M]DP<0Vg9I102ON5l40:9mI@@0YX9[102ZQg440:j<MP<0/I5l102e
UX440;VJQP@0_9n;5P3oool001@0oooo102lWh/40;VJQ@@0]IF00`2bTG/40:n<M@@0ZhM`102XPf/4
0:EnI@@0XWYP0`2NMEX409]aE@@0V6a?102EIdT4099R@`@0Sedm102;F3L308QC<@@0Q4dY1028D2/4
08eE<@@0ReDb102:E38308UD<`@0Qe<c1025D304089=;0@0OdXZ101nB2X307e8:`@0NdP/101mD3@4
085J?P@0Pei41025I4X408ERB@<0PUe31020Gd<407iNA0@0O5Tn101kDSL407eA=P<0P5<h1023ES/4
08EH?@@0Qe/n1028Fcd408UJ?0@0REPi0`28ECD408UF=P@0S5/m102?HD@409=WB`@0UfeB0`2KLUT4
09mhG`@0XWeU102VPV/40:Z7L@@0[Xaf0`2aTG`40;FFP@@0^IZ6102lWh/F0?ooo`00503oool40;bO
R`@0^IZ5102eUH030;:AN`@0[hae102[Qg040:R3J`@0YGiU102RNV0309ieFP@0Vg5E102HK4l409EW
B@@0TV93102?GCd408]H=`<0R5<a1024CBT408Q@:`@0SEDa102;EC8408YD<P<0RE@c1027Dc<408E@
<0@0PTd/101oBRX407i8:P<0ODP[101kB2`407e@=0@0PEXn1023GT@408ETBP@0QF990`22GD<4081O
@`@0OUi4101lFCh407]B=`@0OE4f0`20DcP408=F>`@0QEPm1027Fch408QK?@@0REXl1029F3T308QE
=@@0REHf102<Fcd408mQA0@0TfM;102GKE8309]bF@@0WgQO102ROFD40:J2J`@0ZXMa102^S7H30;6A
O0@0]IJ1102iVXH40;bORaH0oooo000D0?ooo`@0_9n;102iVXD40;FEP0<0/Y5k102_S7D40:^7L0@0
Z8=[102UOVD40:9jH0<0WWEJ102KLED409Q/C`@0UFM9102BHT<408mM?@@0RePg0`28Dc4408A=:@@0
R50[102=EC4408]E<P@0RU@b0`29E3<408MC<`@0QE0`1022CB`407m::P@0OTPZ0`1mB2/407]8;0@0
OE0d1021FSh408=NA0@0QFA:1025HTT3089M@`@0P5m3101nGT@407aI?P@0Ne8g101mDCH3081C>0@0
PeHk1025F3d408MK?P@0R5/m1029FS`408UH>@<0R5De1029ESH408aK?@@0Sf54102CId/409M]DP<0
Vg9I102ON5l40:9mI@@0YX9[102ZQg440:j<MP<0/I5l102eUX440;VJQP@0_9n;5P3oool001@0oooo
102lWXX40;RIQ@@0]IAo0`2aSgT40:f;M0@0ZXI^102VPFP40:=lHP@0WgMM0`2LLUL409U]D@@0UFQ;
102BHdD408mN?P@0RePh1027Dc4308A>:`@0PDXV1024CBT408UC<0@0R5<`1027DS0308IB<@@0Q54`
1022Cbl4081<;@@0ODX[101iAbP307Y=;`@0PE/o1024H4D4089QAP@0PV=81022HDH4089RAP<0PVA:
1023I4/4085QB0@0OUa1101iES/407QA=P<0O54f101oDcT4089F>P@0Q5Pl1025FC`408EH>P@0QEDg
1`25E3D408IF>0@0RU/n102?HTH409=YCP<0V6mE102LME`40:1kH`@0Y81Y102XQVl40:b;M@<0/91j
102dUH040;RJQ@@0_9j;5P3oool001@0oooo102lWXX40;RIQ@@0]IAo0`2aSgT40:f;M0@0ZXI^102V
PFP40:=lHP@0WgMM0`2LLUL409U]D@@0UFQ;102BHdD408mN?P@0RePh1027Dc4308A>:`@0PDXV1024
CBT408UC<0@0R5<`1027DS0308IB<@@0Q54`1022Cbl4081<;@@0ODX[101iAbP307Y=;`@0PE/o1024
H4D4089QAP@0PV=81022HDH4089RAP<0PVA:1023I4/4085QB0@0OUa1101iES/407QA=P<0O54f101o
DcT4089F>P@0Q5Pl1025FC`408EH>P@0QEDg1`25E3D408IF>0@0RU/n102?HTH409=YCP<0V6mE102L
ME`40:1kH`@0Y81Y102XQVl40:b;M@<0/91j102dUH040;RJQ@@0_9j;5P3oool001@0oooo102lWXX4
0;RIQ@@0]IAo0`2aSgT40:f;M0@0ZXI^102VPFP40:=lHP@0WgMM0`2LLUL409U]D@@0UFQ;102BHdD4
08mN?P@0RePh1027Dc4308A>:`@0PDXV1024CBT408UC<0@0R5<`1027DS0308IB<@@0Q54`1022Cbl4
081<;@@0ODX[101iAbP307Y=;`@0PE/o1024H4D4089QAP@0PV=81022HDH4089RAP<0PVA:1023I4/4
085QB0@0OUa1101iES/407QA=P<0O54f101oDcT4089F>P@0Q5Pl1025FC`408EH>P@0QEDg1`25E3D4
08IF>0@0RU/n102?HTH409=YCP<0V6mE102LME`40:1kH`@0Y81Y102XQVl40:b;M@<0/91j102dUH04
0;RJQ@@0_9j;5P3oool001@0oooo102lWXX40;RIQ@@0]IAo0`2aSgT40:f;M0@0ZXI^102VPFP40:=l
HP@0WgMM0`2LLUL409U]D@@0UFQ;102BHdD408mN?P@0RePh1027Dc4308A>:`@0PDXV1024CBT408UC
<0@0R5<`1027DS0308IB<@@0Q54`1022Cbl4081<;@@0ODX[101iAbP307Y=;`@0PE/o1024H4D4089Q
AP@0PV=81022HDH4089RAP<0PVA:1023I4/4085QB0@0OUa1101iES/407QA=P<0O54f101oDcT4089F
>P@0Q5Pl1025FC`408EH>P@0QEDg1`25E3D408IF>0@0RU/n102?HTH409=YCP<0V6mE102LME`40:1k
H`@0Y81Y102XQVl40:b;M@<0/91j102dUH040;RJQ@@0_9j;5P3oool001@0oooo102lWXX40;RIQ0@0
]9An0`2`SgP40:b9LP@0Z8A/102TOfH40:5iG`@0WGAI0`2JKe<409IZC@@0TfE7102?H44408aJ>P@0
Qe@b1023CBX307m89@@0P4PU1024CBX408IA;P@0QE4_1024DS4308=B<@@0PE0`101oCbl407e?<0@0
OE0b101nDc@307mE=`@0P5Hh101oEcT407iH>P@0OUPk101mEcT407eG>P<0OELk101nEc/4081J?@@0
PUi21022GD<407aF?@<0N4le101jCcD407eC=`@0P5Di1021ESX4089E>0@0PU@f0`22DS<4089A<@@0
Pe8b1025ECP408YM@@@0T6E:0`2EK58409YbF@@0WWUP102SOVL40:N4K@@0ZhUc0`2_SgT40;>DO`@0
^9V5102lWXXF0?ooo`00503oool40;bNRP@0^9V4102dU7h30;2?N0@0[8Ub102XQ6`40:AoIP@0XGUO
102MM5T309Y_D`@0UVY=102CIDL408mP@@@0S5Xj1027E38408==:P<0OdPU1020B2D408A=:P@0QU4^
1025DBl408AB<@<0Pe8a1021D30407m?;`@0ODl`101mD38407iC=0<0OeDg1020ESP407mG>@@0OUPj
101nF3/407eG>@@0OELj0`1mEc/407iG>`@0P5Xm1022GT84089M@`@0O5Hm0`1hCcD407Y?=@@0OE<g
1020ECT4085F>P@0PUDh1022E3H3089B<`@0PU4a1023DS8408EE>0@0RUe1102@IDX309E/DP@0VW9I
102NNF040:=nI`@0YhA]102[RG<30:n?N@@0/iAo102hVHD40;bNRQH0oooo000D0?ooo`@0_9j:102h
VH@40;BDOP<0/8mh102/RG840:R4K0@0Y7mV102QNEl409edF@<0VVmC102FJTd409=UA`@0Sf11102<
FSX408MD<P@0PddZ0`1oB2D408189@@0Q4dZ1026DBh408EA;`@0Q58a0`23DS44085@<0@0Odl_101m
Cc0407e@<P@0OU<d0`1oECL4081F>0@0OeLi101nF3X407iH>`@0OELi101mEcX307eG>`@0OULk1020
FSd4089N@P@0PUe3101lESd307Q?=@@0NTle101mDcL4081E>@@0PEHj1022ECP4089D=P<0PU8c1022
DC4408=B<P@0QEDh102:GD44091UBP<0UFaB102JLUT409iiH0@0XgiW102WQ6d40:^9L`<0[hmi102c
U7l40;RIQ@@0_9j:5P3oool001@0oooo102lWXX40;RIQ0@0]9An0`2`SgP40:b9LP@0Z8A/102TOfH4
0:5iG`@0WGAI0`2JKe<409IZC@@0TfE7102?H44408aJ>P@0Qe@b1023CBX307m89@@0P4PU1024CBX4
08IA;P@0QE4_1024DS4308=B<@@0PE0`101oCbl407e?<0@0OE0b101nDc@307mE=`@0P5Hh101oEcT4
07iH>P@0OUPk101mEcT407eG>P<0OELk101nEc/4081J?@@0PUi21022GD<407aF?@<0N4le101jCcD4
07eC=`@0P5Di1021ESX4089E>0@0PU@f0`22DS<4089A<@@0Pe8b1025ECP408YM@@@0T6E:0`2EK584
09YbF@@0WWUP102SOVL40:N4K@@0ZhUc0`2_SgT40;>DO`@0^9V5102lWXXF0?ooo`00503oool40;^N
RP@0]iR3102cTgd30:n=M`@0ZXM`102VPVT40:9lH`@0WWMM102KLEH309M/D0@0TfM:102@HT<408eL
?@@0RELf1025D2h407e68P<0N3lI1021BB@408QB;`@0QE4_1023D2l4085?;`<0P50`101oD34407iA
<P@0OeDh1021GD0408ETB0<0Q6=7101oG40407eI?0@0NeHh101jDSD807UA=0<0NDla101iCc8407YC
=@@0O5Dh101nES/407mG?0<0NU8h101hCc@407]A=P@0OE<g101nDcL407mC=P@0Oe8d0`1oDC<4081@
<@@0PE4b1024ECL408MK?P@0SF970`2BJTl409M`E`@0W7MN102QOFD40:F3K0@0ZXQb0`2^SWP40;>C
OP@0]iV4102kWXXF0?ooo`00503oool40;^NRP@0]iR3102cTgd30:n=M`@0ZXM`102VPVT40:9lH`@0
WWMM102KLEH309M/D0@0TfM:102@HT<408eL?@@0RELf1025D2h407e68P<0N3lI1021BB@408QB;`@0
QE4_1023D2l4085?;`<0P50`101oD34407iA<P@0OeDh1021GD0408ETB0<0Q6=7101oG40407eI?0@0
NeHh101jDSD807UA=0<0NDla101iCc8407YC=@@0O5Dh101nES/407mG?0<0NU8h101hCc@407]A=P@0
OE<g101nDcL407mC=P@0Oe8d0`1oDC<4081@<@@0PE4b1024ECL408MK?P@0SF970`2BJTl409M`E`@0
W7MN102QOFD40:F3K0@0ZXQb0`2^SWP40;>COP@0]iV4102kWXXF0?ooo`00503oool40;^NRP@0]iR3
102cTgd30:n=M`@0ZXM`102VPVT40:9lH`@0WWMM102KLEH309M/D0@0TfM:102@HT<408eL?@@0RELf
1025D2h407e68P<0N3lI1021BB@408QB;`@0QE4_1023D2l4085?;`<0P50`101oD34407iA<P@0OeDh
1021GD0408ETB0<0Q6=7101oG40407eI?0@0NeHh101jDSD807UA=0<0NDla101iCc8407YC=@@0O5Dh
101nES/407mG?0<0NU8h101hCc@407]A=P@0OE<g101nDcL407mC=P@0Oe8d0`1oDC<4081@<@@0PE4b
1024ECL408MK?P@0SF970`2BJTl409M`E`@0W7MN102QOFD40:F3K0@0ZXQb0`2^SWP40;>COP@0]iV4
102kWXXF0?ooo`00503oool40;^MR@@0]YN3102bTG`30:f<M@@0ZHI^102TOfL40:1jH0@0W7AJ102H
KU<309AYC0@0TFA6102=GT0408YI>P@0QeDd1024Cbd4081:9`<0PD/W1026DRh408ID<@@0Pe4_1020
Cc0407i?<@<0OE0a101lD38407]A=0@0Ne<f101lESX407iK?`<0OEe1101lGD0407]L@0@0NU/n101i
FSd407QI>`@0N5Pk1`1gFC/407QF>0@0NE@h101kECT407eF>@<0OULk101kE3T407UA=P@0NU4f101k
DSH407aA=@@0O54c0`1lCc8407a>;`@0NDTZ101mCRl408EI?0@0RV140`2@J4d409E^E@@0VWEL102O
Nf<40:B1JP@0ZHMa0`2]SGL40;:COP@0]iR4102kWXXF0?ooo`00503oool40;^MR@@0]YN3102bTG`3
0:f<M@@0ZHI^102TOfL40:1jH0@0W7AJ102HKU<309AYC0@0TFA6102=GT0408YI>P@0QeDd1024Cbd4
081:9`<0PD/W1026DRh408ID<@@0Pe4_1020Cc0407i?<@<0OE0a101lD38407]A=0@0Ne<f101lESX4
07iK?`<0OEe1101lGD0407]L@0@0NU/n101iFSd407QI>`@0N5Pk1`1gFC/407QF>0@0NE@h101kECT4
07eF>@<0OULk101kE3T407UA=P@0NU4f101kDSH407aA=@@0O54c0`1lCc8407a>;`@0NDTZ101mCRl4
08EI?0@0RV140`2@J4d409E^E@@0VWEL102ONf<40:B1JP@0ZHMa0`2]SGL40;:COP@0]iR4102kWXXF
0?ooo`00503oool40;^MR@@0]YN3102bTG`30:f<M@@0ZHI^102TOfL40:1jH0@0W7AJ102HKU<309AY
C0@0TFA6102=GT0408YI>P@0QeDd1024Cbd4081:9`<0PD/W1026DRh408ID<@@0Pe4_1020Cc0407i?
<@<0OE0a101lD38407]A=0@0Ne<f101lESX407iK?`<0OEe1101lGD0407]L@0@0NU/n101iFSd407QI
>`@0N5Pk1`1gFC/407QF>0@0NE@h101kECT407eF>@<0OULk101kE3T407UA=P@0NU4f101kDSH407aA
=@@0O54c0`1lCc8407a>;`@0NDTZ101mCRl408EI?0@0RV140`2@J4d409E^E@@0VWEL102ONf<40:B1
JP@0ZHMa0`2]SGL40;:COP@0]iR4102kWXXF0?ooo`00503oool40;^MR@@0]YN3102bTG`30:f<M@@0
ZHI^102TOfL40:1jH0@0W7AJ102HKU<309AYC0@0TFA6102=GT0408YI>P@0QeDd1024Cbd4081:9`<0
PD/W1026DRh408ID<@@0Pe4_1020Cc0407i?<@<0OE0a101lD38407]A=0@0Ne<f101lESX407iK?`<0
OEe1101lGD0407]L@0@0NU/n101iFSd407QI>`@0N5Pk1`1gFC/407QF>0@0NE@h101kECT407eF>@<0
OULk101kE3T407UA=P@0NU4f101kDSH407aA=@@0O54c0`1lCc8407a>;`@0NDTZ101mCRl408EI?0@0
RV140`2@J4d409E^E@@0VWEL102ONf<40:B1JP@0ZHMa0`2]SGL40;:COP@0]iR4102kWXXF0?ooo`00
503oool40;^MR@@0]YN2102aT7/30:b:M0@0YhA/102SOVD409ihGP@0VW5G102EJe03095VB@@0SV12
102:Fc`408QF=P@0QU<a1026DBl408eH=@<0Tehj102<F3D408=A;`@0Odl_101lD30407]?<@<0NTlb
101iDC<407QB=@P0N5<g101gE3L307MF>@@0MULj101fESX407EF>@@0M5@h4`1cE3L407=F>0@0MUTk
101jG40307eOA0@0OEi3101jF3d407QC=`@0N54f101iDCD407U@=0<0NU0b101jCS4407Y?<P@0O54d
1022EcX408QOA0<0SVI<102CKE<409UcF`@0WWYR102SP6T40:R6L0<0[8af102aTWd40;JHP`@0^if:
5P3oool001@0oooo102kWHT40;JGPP@0/I1k0`2/RW@40:N4K0@0XgiU102NN5h409YaE`@0UF]@0`2A
ITT408iP@P@0RU/l1028ESH408IC<@@0QU4_102=F3D309=N>P@0S5Pe1023DBl407m?;`@0O50`101k
Cc4307Y?<P@0NE4c101hDSD807QC=`@0Me@g0`1gEST407IG>P@0MUHj101eEST407AD>1<0Le@g101c
ESP407II>`@0NUa00`1mGd@407eN@`@0NUPm101hDcL407QA=P@0NE4e101iD3@307Y@<P@0NTha101j
Cc8407aA=0@0PULj1028Gd@308iVC0@0TfeC102ILe/409ijHP@0Xh1Y102XQW030:b<MP@0/I9m102f
V8<40;^MRQH0oooo000D0?ooo`@0^if9102fUh840;6@N`<0[8Yd102WQ6`40:=nI@@0WWQN102JLEL4
09E[D0<0TFI9102>H48408YK?0@0R5Hf1026Dc4408IA;`@0SEPe0`2CGSX408aH=@@0Pe4_101oCbl4
07a@<0@0Ndla0`1jCc8407UA<`@0N58e201hDcL407MD=`<0MeHi101fEcX407IF>P@0MEHi101dE3PC
07=D=`@0LeHh101fFC/407YL@0<0OEm4101mGT<407YH?@@0N5<g101hDCH407UA=@@0NE0d0`1jD384
07Y><@@0NTlb101lDC@4089G>P@0R5m40`2>IT`409=]D`@0VG=K102NNV840:>0J@@0Z8I`0`2/S7H4
0;6BO@@0]YR3102kWHXF0?ooo`00503oool40;^MR@@0]YN2102aT7/30:b:M0@0YhA/102SOVD409ih
GP@0VW5G102EJe03095VB@@0SV12102:Fc`408QF=P@0QU<a1026DBl408eH=@<0Tehj102<F3D408=A
;`@0Odl_101lD30407]?<@<0NTlb101iDC<407QB=@P0N5<g101gE3L307MF>@@0MULj101fESX407EF
>@@0M5@h4`1cE3L407=F>0@0MUTk101jG40307eOA0@0OEi3101jF3d407QC=`@0N54f101iDCD407U@
=0<0NU0b101jCS4407Y?<P@0O54d1022EcX408QOA0<0SVI<102CKE<409UcF`@0WWYR102SP6T40:R6
L0<0[8af102aTWd40;JHP`@0^if:5P3oool001@0oooo102jWHT40;FFP@@0/8mj0`2[RG840:J2JP@0
XGaS102LME/409M_E0@0TVQ<0`2>HTD408YL?P@0QeLg1024DS4408=?;0@0PddY1025CbX308EA;`@0
PU0_101mCBd407Y<;@@0N4d_101gCS4307E?<P@0MDlc101eD3D407EA=@@0Ldlc101bCS43079?<`P0
LE4e101`DCD406mA=@@0Ke4d101^Cc<306i><P@0KDlc101^D3@406mA=@@0LU<h101dESX307IH?@@0
N5Tm101hEcd407MD>P@0MU4g101fD3D407M?=0<0N4lc101hCc8407Q><@@0Ne4e1021Ec`408IN@`<0
S6E:102BK58409MbFP@0W7UQ102QOfP40:N5K`<0[8]f102aTG`40;JGP`@0^if:5P3oool001@0oooo
102jWHT40;FFP@@0/8mj0`2[RG840:J2JP@0XGaS102LME/409M_E0@0TVQ<0`2>HTD408YL?P@0QeLg
1024DS4408=?;0@0PddY1025CbX308EA;`@0PU0_101mCBd407Y<;@@0N4d_101gCS4307E?<P@0MDlc
101eD3D407EA=@@0Ldlc101bCS43079?<`P0LE4e101`DCD406mA=@@0Ke4d101^Cc<306i><P@0KDlc
101^D3@406mA=@@0LU<h101dESX307IH?@@0N5Tm101hEcd407MD>P@0MU4g101fD3D407M?=0<0N4lc
101hCc8407Q><@@0Ne4e1021Ec`408IN@`<0S6E:102BK58409MbFP@0W7UQ102QOfP40:N5K`<0[8]f
102aTG`40;JGP`@0^if:5P3oool001@0oooo102jWHT40;FFP@@0/8mj0`2[RG840:J2JP@0XGaS102L
ME/409M_E0@0TVQ<0`2>HTD408YL?P@0QeLg1024DS4408=?;0@0PddY1025CbX308EA;`@0PU0_101m
CBd407Y<;@@0N4d_101gCS4307E?<P@0MDlc101eD3D407EA=@@0Ldlc101bCS43079?<`P0LE4e101`
DCD406mA=@@0Ke4d101^Cc<306i><P@0KDlc101^D3@406mA=@@0LU<h101dESX307IH?@@0N5Tm101h
Ecd407MD>P@0MU4g101fD3D407M?=0<0N4lc101hCc8407Q><@@0Ne4e1021Ec`408IN@`<0S6E:102B
K58409MbFP@0W7UQ102QOfP40:N5K`<0[8]f102aTG`40;JGP`@0^if:5P3oool001@0oooo102jWHT4
0;FFP@@0/8mj0`2[RG840:J2JP@0XGaS102LME/409M_E0@0TVQ<0`2>HTD408YL?P@0QeLg1024DS44
08=?;0@0PddY1025CbX308EA;`@0PU0_101mCBd407Y<;@@0N4d_101gCS4307E?<P@0MDlc101eD3D4
07EA=@@0Ldlc101bCS43079?<`P0LE4e101`DCD406mA=@@0Ke4d101^Cc<306i><P@0KDlc101^D3@4
06mA=@@0LU<h101dESX307IH?@@0N5Tm101hEcd407MD>P@0MU4g101fD3D407M?=0<0N4lc101hCc84
07Q><@@0Ne4e1021Ec`408IN@`<0S6E:102BK58409MbFP@0W7UQ102QOfP40:N5K`<0[8]f102aTG`4
0;JGP`@0^if:5P3oool001@0oooo102jW8P40;BEP0@0[hih0`2YQg040:B0J@@0WWUQ102ILUT409A[
D@@0SfE90`2:GT4408IH>P@0PU8c101oCB`407e89P@0O4HS101kAR8307Y58P@0N4HU101gAbT407E8
:P@0LdT/101bBRh3075;;`@0L4``101`C384071=<P@0Kdda101^Bbl306e:;P@0KD/`101/Bc0406];
;`@0Jd``201ZC34306U;<0@0JT/a101[CC8406e>=0@0KU4g101aE3X307=F?0@0M5Hl101eEC`407AC
>@@0Le0g101dD3H407I@=P<0Me0e101iD3D407U@=0@0NDlb101nE3L408AL@0<0RV=9102@JU4409Ia
F@@0VgQP102POVL40:J4KP<0Zh]e102`TG`40;FGP`@0^Yf95P3oool001@0oooo102jW8P40;BEP0@0
[hih0`2YQg040:B0J@@0WWUQ102ILUT409A[D@@0SfE90`2:GT4408IH>P@0PU8c101oCB`407e89P@0
O4HS101kAR8307Y58P@0N4HU101gAbT407E8:P@0LdT/101bBRh3075;;`@0L4``101`C384071=<P@0
Kdda101^Bbl306e:;P@0KD/`101/Bc0406];;`@0Jd``201ZC34306U;<0@0JT/a101[CC8406e>=0@0
KU4g101aE3X307=F?0@0M5Hl101eEC`407AC>@@0Le0g101dD3H407I@=P<0Me0e101iD3D407U@=0@0
NDlb101nE3L408AL@0<0RV=9102@JU4409IaF@@0VgQP102POVL40:J4KP<0Zh]e102`TG`40;FGP`@0
^Yf95P3oool001@0oooo102jW8P40;BEP0@0[hih0`2YQg040:B0J@@0WWUQ102ILUT409A[D@@0SfE9
0`2:GT4408IH>P@0PU8c101oCB`407e89P@0O4HS101kAR8307Y58P@0N4HU101gAbT407E8:P@0LdT/
101bBRh3075;;`@0L4``101`C384071=<P@0Kdda101^Bbl306e:;P@0KD/`101/Bc0406];;`@0Jd``
201ZC34306U;<0@0JT/a101[CC8406e>=0@0KU4g101aE3X307=F?0@0M5Hl101eEC`407AC>@@0Le0g
101dD3H407I@=P<0Me0e101iD3D407U@=0@0NDlb101nE3L408AL@0<0RV=9102@JU4409IaF@@0VgQP
102POVL40:J4KP<0Zh]e102`TG`40;FGP`@0^Yf95P3oool001@0oooo102jW8P40;BEP0@0[hih0`2Y
Qg040:B0J@@0WWUQ102ILUT409A[D@@0SfE90`2:GT4408IH>P@0PU8c101oCB`407e89P@0O4HS101k
AR8307Y58P@0N4HU101gAbT407E8:P@0LdT/101bBRh3075;;`@0L4``101`C384071=<P@0Kdda101^
Bbl306e:;P@0KD/`101/Bc0406];;`@0Jd``201ZC34306U;<0@0JT/a101[CC8406e>=0@0KU4g101a
E3X307=F?0@0M5Hl101eEC`407AC>@@0Le0g101dD3H407I@=P<0Me0e101iD3D407U@=0@0NDlb101n
E3L408AL@0<0RV=9102@JU4409IaF@@0VgQP102POVL40:J4KP<0Zh]e102`TG`40;FGP`@0^Yf95P3o
ool001@0oooo102jW8P40;BDP0@0[Xeg0`2XQVl40:9nI`@0W7MN102FL5H4095XCP@0Rf550`26FSd4
089C=@@0OTd]101jAbH407M27`@0MClK101c?Q`3078o7@@0Ld4Q101b@R<407139P@0KTDX101]ABT3
06a6:P@0JdL[101[BBd406]:;P@0JTX^101YB2`306Q7:`@0J4P/101XBBh<06M9;`@0ITT`0`1VBS04
06M:<@@0J4/b101YC3@406]?=P@0KE4i0`1_Dcd4075E?P@0LEDm101`DST4071@=`@0LU0g101dD3L3
07IA=P@0NE8g101lDcL407]@<`@0O54e1023FSl308URB0@0SfYA102DL5P409YgH0@0WgeW102TQ6h3
0:Z:M@@0[i1l102eUh<40;ZMRAH0oooo000D0?ooo`@0^Yb8102dU8040:j=M`<0Z8I_102ROVL409ag
GP@0UW1F102AJ4h408]QA@<0QUXm1022DcD407i=;@@0NTLV101g@Ql407Do6`@0LchL0`1b?ad407=1
8@@0LT8S101`@bH406i5:0@0KDDY0`1/ARX406]7:`@0JdT]101[BRh406Y:;P@0JDP/0`1XAb/406Q8
;0@0J4T^301WBBl406I9<0<0ITX`101WBS4406Q;<P@0JD`d101[CcH406eA>@<0Ke<m101aECh4075E
?@@0L58i101`D3L4079@=`@0M50g0`1fDCH407UB=`@0O5<g101kD3<407aA=@@0PeXo0`29HTP408mZ
D@@0U71H102JMf0409mmI`@0Y8A^0`2ZRWD40:n@O0@0]IN3102jWHTF0?ooo`00503oool40;ZLR0@0
]9B0102^SGL30:R6K`@0XWiW102LMeh409I`EP@0TFQ>102;HDD308IJ?@@0PU<e101nCBd407Y79P@0
Md8O101e?a/407<n70<0LSlM101c@B4407928`@0L4<V101^ABP406e5:@<0K4HZ101[Ab/406]9;@@0
JdX^101ZBRh406U8;0<0J4L[101XB2`406Q9;P`0IdT_101VBC0306I:<0@0IdXa101XBc8406U<=0@0
Jdlf101]DCT306mC?@@0LEDn101aECd4071B>@@0L50g101bD3L407A@=`<0MU4f101iDSL407aC=`@0
Ne0c101lDCD408=J?`<0RF98102?JU4409A`F0@0VWMP102OOFL40:B4KP<0ZXYe102_T7`40;FGP`@0
^Yf95P3oool001@0oooo102jW8P40;BDP0@0[Xeg0`2XQVl40:9nI`@0W7MN102FL5H4095XCP@0Rf55
0`26FSd4089C=@@0OTd]101jAbH407M27`@0MClK101c?Q`3078o7@@0Ld4Q101b@R<407139P@0KTDX
101]ABT306a6:P@0JdL[101[BBd406]:;P@0JTX^101YB2`306Q7:`@0J4P/101XBBh<06M9;`@0ITT`
0`1VBS0406M:<@@0J4/b101YC3@406]?=P@0KE4i0`1_Dcd4075E?P@0LEDm101`DST4071@=`@0LU0g
101dD3L307IA=P@0NE8g101lDcL407]@<`@0O54e1023FSl308URB0@0SfYA102DL5P409YgH0@0WgeW
102TQ6h30:Z:M@@0[i1l102eUh<40;ZMRAH0oooo000D0?ooo`@0^I^7102cU7l40:f<MP<0YXA]102P
O6D409YeG0@0TfeC102=IDX408QM@@<0PUHi101mCS0407Q79`@0M40O101`>QT406dg5@@0JcHD0`1[
>QT406`m7`@0JclQ101Z@28406U08`@0J44U0`1W@BD406I19P@0ID<X101UA2X406E5:`@0I4D[0`1T
ABT806=4:@@0HdDZ201RAB/40654:`<0HDD/101RARh406=9<0@0ID/b101WC3@406Q>=`<0Je4j101/
DS`406aA>P@0K50h101]CcL406m?=P@0LDlg0`1eDCP407YD>P@0PUXn1026Fch4081E>@@0PEPn0`29
HdT408iYD@@0Tg1H102HMUl409imIP@0Xh=^0`2YRWD40:n@N`@0]9J2102jWHTF0?ooo`00503oool4
0;VKQ`@0/iAo102]S7H30:J4K@@0X7aU102JME`409=]D`@0SFE:1028GD43089F>@@0ODh`101hAbL4
07A07`@0L3XI101]=aD406/f50<0JcXI101/?Al406/o8@@0JT0R101Y@2<406Q19@<0Id4U101V@BH4
06E3:0@0ID@Z101UAB/406A5:`<0I4DY201SA2T406=5:PP0HTD[101QA2/30655;0@0HTH^101SBC04
06E;<P@0Id`d101XCSL306]A>P@0K58l101/DCX406a@>0@0KDlg101_CcH4075?=`<0ME4h101jE3X4
089J?P@0QU/n1020ECT4085H?P<0RF=9102>JE4409=`F0@0V7IO102NOFH40:>3KP<0ZHYe102_T7/4
0;BFPP@0^Yf95P3oool001@0oooo102iVhL40;>DO`@0[Haf0`2VQ6d40:1lI@@0VWEL102CKE<408eU
BP@0R5e10`22EST407e><0@0N4LW101d@1l4070j6@@0KCLE101[=Q@306/j6@@0K3dO101[?b4406Y0
8P@0JD0S101X@BD306M19@@0IT4V101U@bP406E4:P@0IDD[101TAB/306A5:@P0Hd@Y101SABX80695
:`@0HD@[0`1QAB`40696;P@0HdT`101UBc8406M<=0@0J4hg0`1[DCX406aB?0@0K54j101/D3P406e?
=`@0Kdlf101aCcL307EA>0@0NU@j1022FSh408IK?P@0P5Di1021F3h308USB@@0SVUA102CL5P409Qf
G`@0WWeV102SPfh30:V:M@@0[i1k102dUX840;ZMRAH0oooo000D0?ooo`@0^I^7102bTgh40:^;M@<0
YH=/102NNV<409MbFP@0TFY@102:HTL408AI?P<0OE4d101gBB/407918@@0KCPG101X<@l406D]30@0
I30A0`1T=QP406Dj6`@0IC`N101T?1h406<k7`@0HS/N0`1Q>al4060k80@0Gc`Q101O?B<405lo9@@0
H44X0`1P@RP405m19`@0Gd0V101N@2H405ho9P@0GClV101M@2L305e1:@@0GD8Z101NA2`405m6;`@0
HDTc101TC3H306E>=`@0ITdg101WC3H406Q;=@@0JD/d101[Bc@406i==@<0LThf101gDST407eG?`@0
QEi5102;IT`408]VC@<0RFE<102=JE44099_F0@0UgIO102MO6H40::3K@<0Z8Ud102^T7/40;BFPP@0
^Yf95P3oool001@0oooo102iVhL40;:COP@0Zh]e0`2UPf`409ijH`@0Ug9J102AJU0408YRA`@0Q5Tn
0`1mDC@407M9:`@0LT4Q101]>1L406Pa3`@0IBd<101T<14306@f60@0ICXK101U?1h406@l7P@0Hc/O
101R>ah3064k7`@0H3/P101O?24405lm8`@0GclU101P@BP30612:0@0Gd4W101O@2H405i09P@0GSlV
101M?bH405e09`<0GD4Y101M@RX405i4;0@0GdH_101QBC<406A<=P<0IDhg101VCCL406M<=P@0J4/e
101YBc@406];=0@0KTde0`1bCSH407MB>@@0OELo1025GTD408]VC0@0RfI=0`29ID`408eYD@@0TVmH
102GMUl409elIP@0XX=]0`2XRG@40:j@N`@0]9J2102jWHTF0?ooo`00503oool40;VKQ`@0/Y=n102[
RgD30:F3K0@0WWYS102GLUX4095ZD0@0RV971024FCh307eA=0@0MdT[101b@B4406dh5`@0J34?101U
;@`406@`4@<0I3HH101U>Q/406Dl7P@0I3`N101S>al4068k7P<0HC/O101P>b0405ll8@@0GcdS101O
?bD40611:0<0H48X101O@BL405m09P@0GT0V101N?bH405do9P@0GD0W0`1M@BT405e2:P@0GT@/101O
ARl40659<`@0I4`f0`1UCSL406I==`@0Id`f101XBcD406U;=0@0Jd/d101^CCD3079>=P@0Me8i101m
Ecl408ENA@@0RfI<102;ITd308UUC0@0SFUA102BKeP409MfG`@0WGaV102RPfd30:R9M0@0[Y1k102d
UX840;ZMRAH0oooo000D0?ooo`@0^I^7102bTgh40:^;M@<0YH=/102NNV<409MbFP@0TFY@102:HTL4
08AI?P<0OE4d101gBB/407918@@0KCPG101X<@l406D]30@0I30A0`1T=QP406Dj6`@0IC`N101T?1h4
06<k7`@0HS/N0`1Q>al4060k80@0Gc`Q101O?B<405lo9@@0H44X0`1P@RP405m19`@0Gd0V101N@2H4
05ho9P@0GClV101M@2L305e1:@@0GD8Z101NA2`405m6;`@0HDTc101TC3H306E>=`@0ITdg101WC3H4
06Q;=@@0JD/d101[Bc@406i==@<0LThf101gDST407eG?`@0QEi5102;IT`408]VC@<0RFE<102=JE44
099_F0@0UgIO102MO6H40::3K@<0Z8Ud102^T7/40;BFPP@0^Yf95P3oool001@0oooo102iVhL40;6B
O@@0ZXYd0`2SPF/409aiH@@0UG1G102=Idh408INA0@0OeDj0`1hCC0407949P@0Jc/L101V<a<4064]
3P@0GRd>101N<143060d5@@0H3HH201O=a/405hf6P@0G3HJ0`1K=AT405Xe6P@0FCDJ101I=Q`405Xh
7`@0FSXR0`1J?2<405Xm9@@0FchV101K?RL805Xn9P@0FChW0`1I?bL405U0:@@0FT4[101LA2l405i8
<`@0H4Td0`1PBC<40618<`@0HDPb101RAc4406A8<P@0ITPb101YBC@306e<=@@0LDlh101fDSX407aG
?P@0PEa31024GdL308MSB`@0RfQA102@KUP409EeG`@0Vg]V102QPVd30:N9M0@0[Hmk102cUX840;ZM
RAH0oooo000D0?ooo`@0^I^7102aTWd40:Z:M0<0Xh5[102LNF4409E`E`@0SFM>1026GT@407mE>P<0
N4d`101bA2H406/k70@0IS<C101Q;@h405h]3P@0GS0A0`1P=1D4060f60P0GcLK101N=QX405`f6P<0
FcDI101J=AX405Te6P@0FCHL101J>1l405Xj8P<0FS`S101J?BD405/n9P@0FchW201J?RH405Tn9`<0
FClW101I@2T405Y1:`@0G4@_101NB3<40619=0<0H4Tc101PB3<40658<P@0HTLa101TB38406I8<P@0
JDTd0`1]C3D4075?>0@0MU8j101lEch4085L@`@0Q5m70`27Hd/408]XD@@0T6iH102EMEl409]kIP@0
XH9]0`2WRG@40:f?N`@0/iJ2102jWHTF0?ooo`00503oool40;VKQ`@0/I9m102ZRW@30:>1J`@0W7UQ
102EL5L408eWCP@0QUi4101oECX307Q=<0@0LT@V101[>a`406Hc4`@0HBd>101N;@h405h`4@<0H3@E
101P=QP805lg6`@0GSHJ101L=QX305/e6@@0FSDJ101I=AX405Tf70@0FSPO101J>R8305Xl8`@0FSdU
101K?RH405/n9`P0FShV101I?RL305To9`@0FD0Y101J@B/405a4;`@0GTPc101PBC@30619<`@0H4Pc
101QB3840697<@@0I4Pb101VB38406U9=0<0KD`e101aCcP407IB>P@0O5Ln1021G4<408AOA`<0Qf=;
102;J544091^F0@0UGEO102KNfH40:62K@<0YhUd102]Sg/40;>FPP@0^Yf95P3oool001@0oooo102i
VhL40;6BO@@0ZXYd0`2SPF/409aiH@@0UG1G102=Idh408INA0@0OeDj0`1hCC0407949P@0Jc/L101V
<a<4064]3P@0GRd>101N<143060d5@@0H3HH201O=a/405hf6P@0G3HJ0`1K=AT405Xe6P@0FCDJ101I
=Q`405Xh7`@0FSXR0`1J?2<405Xm9@@0FchV101K?RL805Xn9P@0FChW0`1I?bL405U0:@@0FT4[101L
A2l405i8<`@0H4Td0`1PBC<40618<`@0HDPb101RAc4406A8<P@0ITPb101YBC@306e<=@@0LDlh101f
DSX407aG?P@0PEa31024GdL308MSB`@0RfQA102@KUP409EeG`@0Vg]V102QPVd30:N9M0@0[Hmk102c
UX840;ZMRAH0oooo000D0?ooo`@0^9Z6102aTWd40:V9L`<0XH1Y102JMel4099^E@@0RVA;1023Fd44
07]B=P<0LdP/101/?R0406@d50@0GBd<101H:`X405H[30@0Ebh?0`1I<1<405Xb5@@0FS<G101I<aL4
05Pb5P@0Ec0E0`1E;a<405@^4`@0DbhE101C;aH405<a6@@0E3@K0`1E=Qh405Hh80@0ESXR101F>b@8
05Hk9@@0ES`U0`1F?BL405Hn:0@0Ed0[101H@Rd805U3;P<0FT<^101J@Rd405]2;@@0G4<^101NA2l4
0655;`@0HdLa0`1WBC8406];=@@0L4hg101eDSX407QC>`@0O5Lo0`22GdP408QVC`@0SVeG102DM5h4
09YjI@@0X85]0`2VR7@40:f?N`@0/iJ2102iW8TF0?ooo`00503oool40;RJQP@0/I9m102YRG<30:60
J@@0VWMO102BKUD408YTB`@0Pe]1101kDSH307=8;0@0K3hP101T=1@405d]30@0F2/:101F:``405L^
3`<0FC0C101J<QD405Xc5`@0FC<G101H<QH405L`5@<0EBlC101D;Q<405<^5@@0DblF101C<AT405@d
6`<0ECHN101F>20405Hj8P@0ES/T201F>bD405Hl9@<0ESdW101F?RP405M0:`@0F48]201I@bh305Y3
;P@0FT8]101K@Rd405a3;P@0GT@_101QABl406=7<@<0IdTb101[BcD4071>=`@0ME8j101hDc/407aG
?`<0PUm81028ITl408i]E`@0U7AN102JNVD40:21K@<0YXQd102]Sg/40;>FPP@0^Ib95P3oool001@0
oooo102hVXH40;6BO@@0ZHUc0`2QP6T409YgG`@0TViE102:I4/408=K@@@0Ne8f0`1cB2`406`n80@0
I3@D101M;@`405P[2P@0ER/<101G;Pl305T`4`@0FS8E101J<aL405Tc5`@0F38F101G<1D305D_4`@0
E2hC101C;QD405<_5P@0Dc4I101D=1/305Df7P@0ESPP101F>R8405Hk90P0ES/U101F?2D305Hm9`@0
EShX101G@2/405Q2;@P0FD<^0`1J@bh405Y2;@@0Fd8]101L@bh405i4;`@0HDD_101SAc4306M9<P@0
Jd/e101`CSL407EB>P@0N5<k101lEcl3089OB0@0R6I?102>KEL409AdGP@0VWYU102PPFd30:J8M0@0
[Hmk102cUX840;VLRAH0oooo000D0?ooo`@0^9Z6102aTWd40:V9L`<0XH1Y102JMel4099^E@@0RVA;
1023Fd4407]B=P<0LdP/101/?R0406@d50@0GBd<101H:`X405H[30@0Ebh?0`1I<1<405Xb5@@0FS<G
101I<aL405Pb5P@0Ec0E0`1E;a<405@^4`@0DbhE101C;aH405<a6@@0E3@K0`1E=Qh405Hh80@0ESXR
101F>b@805Hk9@@0ES`U0`1F?BL405Hn:0@0Ed0[101H@Rd805U3;P<0FT<^101J@Rd405]2;@@0G4<^
101NA2l40655;`@0HdLa0`1WBC8406];=@@0L4hg101eDSX407QC>`@0O5Lo0`22GdP408QVC`@0SVeG
102DM5h409YjI@@0X85]0`2VR7@40:f?N`@0/iJ2102iW8TF0?ooo`00503oool40;RJQP@0/95l102X
R7830:1nJ0@0V7EN102?Je<408MRB@@0OePn101fCS<306i4:0@0ICTL101L;Pl405<T1@@0Bb02101:
8PH404hX30<0DR`A101D;Q<405D_4`@0E2hC101C;Q84058]4@<0D2/A101>:Q0404`Y40@0C2XB101=
;1D404h_60<0Cc8J101A=1d4058g80@0DcPR101C>R<4058k90L0DS/U101B?2H405<m:0@0DcdY201C
?BX3058m:@@0DcdY101D?RX405Ho:`@0FD4]101K@bh405i4;`<0HDD`101UAc4406Q8<@@0KD/c101b
CSD407QC>`<0OUa61025I4h408][EP@0TW=N102HNVD409n1K0<0YHQd102/Sg/40;:EPP@0^Ib95P3o
ool001@0oooo102hVXH40;2AO0@0Z8Qb0`2POVP409QeGP@0Sf]C1027HTT407mH?P@0MThc0`1^A2P4
06Di70@0G2h?101C90D404/P0P@0BR86101>:0`3058/4@@0E2hC101E;a<405@^4`@0DbhB101B;A43
050[4@@0CRX@101<:A0404`Z4P@0CB`E101>;aP304lb6P@0DC@M101B=b0405<h8P@0DcXS101B>b@7
058k9@@0DS`V101C?BP405<m:@P0DcdZ0`1B?BT405<m:@@0E3hZ101F?b/405U1;@@0Fd<^101NA2l3
0655<0@0IDLa101XB34406e;<`@0LThe101hDc/307iLAP@0QFA>102;JeH4099cGP@0V7YU102OPF`3
0:F8M0@0[8mk102bUH840;VLRAH0oooo000D0?ooo`@0^9Z6102`TG`40:R8LP<0X7iX102HMEh408m[
D`@0Qf99101oF3h407I><`<0KT@X101U>A`405`^3`@0Db@5101;808404XR1P@0CRP<0`1B;14405@^
4`@0EBlC101D;Q<405<^4P@0DRdA0`1@:a4404hZ40@0C2T@101<:Q8404d/5@@0CRlH0`1?<QX4054d
7@@0DSLP101C>28405<j8`@0DS/T1`1B>bD4058l9P@0DcdX101C?BT805<m:P<0DSdY101C?BT405@n
:P@0ESl[101I@Bd405]3;P@0GT@_0`1QAC0406E7<@@0J4Pa101]Bc<4079>=@@0N5<k0`1nG4H408ET
CP@0Rf]F102BLeh409QjI@@0Wh5/0`2UR7@40:b?N`@0/YF2102iW8TF0?ooo`00503oool40;RJQP@0
/95l102XR7830:1nJ0@0V7EN102?Je<408MRB@@0OePn101fCS<306i4:0@0ICTL101L;Pl405<T1@@0
Bb02101:8PH404hX30<0DR`A101D;Q<405D_4`@0E2hC101C;Q84058]4@<0D2/A101>:Q0404`Y40@0
C2XB101=;1D404h_60<0Cc8J101A=1d4058g80@0DcPR101C>R<4058k90L0DS/U101B?2H405<m:0@0
DcdY201C?BX3058m:@@0DcdY101D?RX405Ho:`@0FD4]101K@bh405i4;`<0HDD`101UAc4406Q8<@@0
KD/c101bCSD407QC>`<0OUa61025I4h408][EP@0TW=N102HNVD409n1K0<0YHQd102/Sg/40;:EPP@0
^Ib95P3oool001@0oooo102hVXH40:n@O0@0YhMb0`2NOFL409IcG@@0SFUB1024GdH407]E>`@0LTX`
0`1Y@2@4060e6@@0Eb/>101<8@D404HN0`@0AAl5101890X304dY3`@0Cb/A201@;18404l/4@@0CBXA
0`1::10404PW3`@0ARH>20169@h404PX4@<0BR`E101=<1X404ld7P@0D3LQ101@>28804lh8`<0CSPT
101>>B@404hi9@@0CCTU101<>2D704/g90@0C3LT101>>2D4050j9`@0DSdY101E?b/405Q0;0<0Fd8^
101N@bh40655;`@0IDH`101[BS@407=B?0<0NUY51021Hdd408QZE@@0Sg9M102FNFD409f0K0<0Y8Mc
102[SW/40;:EPP@0^Ib95P3oool001@0oooo102hVXH40:n@O0@0YhMb0`2NOFL409IcG@@0SFUB1024
GdH407]E>`@0LTX`0`1Y@2@4060e6@@0Eb/>101<8@D404HN0`@0AAl5101890X304dY3`@0Cb/A201@
;18404l/4@@0CBXA0`1::10404PW3`@0ARH>20169@h404PX4@<0BR`E101=<1X404ld7P@0D3LQ101@
>28804lh8`<0CSPT101>>B@404hi9@@0CCTU101<>2D704/g90@0C3LT101>>2D4050j9`@0DSdY101E
?b/405Q0;0<0Fd8^101N@bh40655;`@0IDH`101[BS@407=B?0<0NUY51021Hdd408QZE@@0Sg9M102F
NFD409f0K0<0Y8Mc102[SW/40;:EPP@0^Ib95P3oool001@0oooo102hVXH40:n@O0@0YhMb0`2NOFL4
09IcG@@0SFUB1024GdH407]E>`@0LTX`0`1Y@2@4060e6@@0Eb/>101<8@D404HN0`@0AAl5101890X3
04dY3`@0Cb/A201@;18404l/4@@0CBXA0`1::10404PW3`@0ARH>20169@h404PX4@<0BR`E101=<1X4
04ld7P@0D3LQ101@>28804lh8`<0CSPT101>>B@404hi9@@0CCTU101<>2D704/g90@0C3LT101>>2D4
050j9`@0DSdY101E?b/405Q0;0<0Fd8^101N@bh40655;`@0IDH`101[BS@407=B?0<0NUY51021Hdd4
08QZE@@0Sg9M102FNFD409f0K0<0Y8Mc102[SW/40;:EPP@0^Ib95P3oool001@0oooo102hVXH40:n@
O0@0YhMb0`2NOFL409IcG@@0SFUB1024GdH407]E>`@0LTX`0`1Y@2@4060e6@@0Eb/>101<8@D404HN
0`@0AAl5101890X304dY3`@0Cb/A201@;18404l/4@@0CBXA0`1::10404PW3`@0ARH>20169@h404PX
4@<0BR`E101=<1X404ld7P@0D3LQ101@>28804lh8`<0CSPT101>>B@404hi9@@0CCTU101<>2D704/g
90@0C3LT101>>2D4050j9`@0DSdY101E?b/405Q0;0<0Fd8^101N@bh40655;`@0IDH`101[BS@407=B
?0<0NUY51021Hdd408QZE@@0Sg9M102FNFD409f0K0<0Y8Mc102[SW/40;:EPP@0^Ib95P3oool001@0
oooo102gVXH40:n@O0@0YXIa0`2MO6H409AbG0@0RfQ@1021GD@407MA>0@0KDH/0`1T>b4405/a5@@0
DbX?101=9P`404LR20@0A248101690/304XX3P@0C2X@101=:a8404d/4`@0BbXA10189`h304@S2P@0
@207100n7`L403hP2@@0@B8<10139@l304HX4P@0BBhH101<<ah404hf8PP0CSPT101=>2<304`h8`@0
BSLS1019=R<404Ld8P@0AC<Q1015<R0304Dc80@0AS<Q1018=B8404/g9@@0CSXW101@>bP405<m:P<0
ESl/101H@2d405Y0;@@0GT4]101UAc8406iA?0<0MUU5101nHDd408IYE@@0SG5M102EN6D409b0K0<0
XhMc102ZSW/40;:EPP@0^Ib95P3oool001@0oooo102gVXH40:n@O0@0YXIa0`2MO6H409AbG0@0RfQ@
1021GD@407MA>0@0KDH/0`1T>b4405/a5@@0DbX?101=9P`404LR20@0A248101690/304XX3P@0C2X@
101=:a8404d/4`@0BbXA10189`h304@S2P@0@207100n7`L403hP2@@0@B8<10139@l304HX4P@0BBhH
101<<ah404hf8PP0CSPT101=>2<304`h8`@0BSLS1019=R<404Ld8P@0AC<Q1015<R0304Dc80@0AS<Q
1018=B8404/g9@@0CSXW101@>bP405<m:P<0ESl/101H@2d405Y0;@@0GT4]101UAc8406iA?0<0MUU5
101nHDd408IYE@@0SG5M102EN6D409b0K0<0XhMc102ZSW/40;:EPP@0^Ib95P3oool001@0oooo102g
VXH40:n@O0@0YXIa0`2MO6H409AbG0@0RfQ@1021GD@407MA>0@0KDH/0`1T>b4405/a5@@0DbX?101=
9P`404LR20@0A248101690/304XX3P@0C2X@101=:a8404d/4`@0BbXA10189`h304@S2P@0@207100n
7`L403hP2@@0@B8<10139@l304HX4P@0BBhH101<<ah404hf8PP0CSPT101=>2<304`h8`@0BSLS1019
=R<404Ld8P@0AC<Q1015<R0304Dc80@0AS<Q1018=B8404/g9@@0CSXW101@>bP405<m:P<0ESl/101H
@2d405Y0;@@0GT4]101UAc8406iA?0<0MUU5101nHDd408IYE@@0SG5M102EN6D409b0K0<0XhMc102Z
SW/40;:EPP@0^Ib95P3oool001@0oooo102gVHH40:j@N`@0YHIa0`2LO6H409=aF`@0RFI?101nFT<4
07=>=P@0J48Y0`1N=Q`405D/4@@0CBD;101480P403lN1`@0@B4910159@d304PX40@0BRXB101<;1@4
04`]5@@0C2dF101:;1D304LY4`@0@RHA100l8Pd403/R30@0?R@>10119Q4304@W4P@0B2dH101;=204
04dh90@0CCTV101<>BH404/h9@<0BCLT1017=B8404Dc8@@0A3<Q1013<B04044_7P<0?bdL1010;Qd4
04<a7`@0AS@R1019=R@404/h9P@0CCXX0`1@?2X405<n;0@0ET0^101L@c8406=9=`@0Je0n0`1cFDH4
07]PC@@0PfQE102;L5d409=hI@@0Vgm/0`2RQg@40:Z>N`@0/IF2102hW8TF0?ooo`00503oool40;NI
QP@0[Y1k102UQW4309alIP@0Tg5K1029ITl407iJ@`@0Ldhf101X@RT305hf70@0EB`A101=9@/404@P
20@0?ah710118@T404DU3@<0B2P@101::Q8404`/50@0C2dE101<;AH404X/5@<0AbTC10129Q4403`R
3@@0>b8<100n90h4044V4@<0A2LB1018;AP404/d80@0CCPT101=>BH404`i9P@0BcPU0`19=b@404Le
8P@0AC<Q1014<b4404<a80@0@BlN0`0o;A`4040^7@@0@c4O1016=28404Tf90@0BcPV101=>RP3050l
:P@0Dch/101F@2h405a3<P@0HdTg101[D3h307=IAP@0Nf1=1023J5D408]`G@@0TgQU102KOf`30::7
M0@0ZXik102aUH840;RLRAH0oooo000D0?ooo`@0]iV6102^T7/40:F6L@<0W7aV102CLE/408UVC`@0
OUY3101cCSH406Q2:@<0GSHL101E;14404dU2`@0A208100o7PL4044Q2@@0ABD=0`18:10404XZ4P@0
C2`D101<;AD404`]5P@0BR`E0`17:A<4048V4@@0?28=100k8P`403hT3P@0@BHA0`149a8404P]60@0
Bc@P101=>2@404di9P@0C3TV101;>2D304Tg90@0AcDR1015<b4404@c8@@0@c4P1011;ah303l]70@0
@2hM1013<Al404Hd8P@0BCHT101;>2H404dj:0<0D3`Z101C?R`405I0;P@0G4<b101SBCL406]@?P<0
LeU6101kH4d408=XE@@0Rg1M102CN6D409]oK0<0XXMd102ZSW/40;6EPP@0^9b95P3oool001@0oooo
102gVHH40:j@N`@0YHIa0`2LO6H409=aF`@0RFI?101nFT<407=>=P@0J48Y0`1N=Q`405D/4@@0CBD;
101480P403lN1`@0@B4910159@d304PX40@0BRXB101<;1@404`]5@@0C2dF101:;1D304LY4`@0@RHA
100l8Pd403/R30@0?R@>10119Q4304@W4P@0B2dH101;=20404dh90@0CCTV101<>BH404/h9@<0BCLT
1017=B8404Dc8@@0A3<Q1013<B04044_7P<0?bdL1010;Qd404<a7`@0AS@R1019=R@404/h9P@0CCXX
0`1@?2X405<n;0@0ET0^101L@c8406=9=`@0Je0n0`1cFDH407]PC@@0PfQE102;L5d409=hI@@0Vgm/
0`2RQg@40:Z>N`@0/IF2102hW8TF0?ooo`00503oool40;NIQP@0[Y1k102UQW4309akIP@0TW5K1027
IDl407aI@P@0L4/c101S?B@305L`5P@0CRH=10188`T404HT30@0AB@>101490h404HW40<0B2XD1019
;1D404X]5`@0BbhI101<<1`404hc7`<0D3DQ101?=20404/b7@@0B34L1017<Ah404Td8@<0CCPU101>
>RL404di9P@0CCXX101<>bT404`j:0@0BSTW0`18=RD404Db8P@0@S0O100o;ah403/[6P@0>2PH0`0h
:AT403//6`@0?RhM1011<1l404Dc8P@0B3HU101:>2L304`i:@@0CCXZ101??2`405E2<P@0GTXj101W
DD03071HAP@0N61>1021J5D408U_G@@0TWMU102JOf`30:66M0@0ZHik102aUH840;RLRAH0oooo000D
0?ooo`@0]iV6102^T7/40:F6L@<0W7]V102BLE/408MUC`@0O5U2101`Bc<406<m90<0Ec0F101>9Pd4
04PS2@@0AR@<101590h404@T3P@0ARL@0`18:Q@404T/5@@0BRdG101;;QT404``70@0CS<O0`1@=B44
04ld80@0Bc8M1018<A`404La7P@0BC@Q0`1=>2D404hj9`@0CCTV101=>RP404`k:@@0C3XX101:>BL3
04Pf9@@0AC8R1012<1l403l_7P@0>b/J100h:1P303PY6@@0>b`K100n;Qd4044`7`@0AC<R1018=RD4
04Xh9`<0C3TY101=>RX404ll;0@0ED8b101NBSX406MA@0<0L5Q6101hH4h4085XE@@0RFmM102BMfD4
09YoK0<0XHId102YSW/40;6EPP@0^9b95P3oool001@0oooo102gVHH40:j@N`@0YHIa0`2LNfH4099a
F`@0QfE?101lFD84071;<`@0HcdT0`1G<1H404hV3@@0B2<9101690`404DT3P@0A2@>10169a0304PZ
50@0BB`E101:;AL404/^6@@0C30L101><al3050e8@@0Cc@P101;<Qd404Pa70@0Ac4N1019=24304dh
9@@0CSXW101=>BH404dj:0@0C3/Y101<>RP404Xi9`<0B3HU1015<R84048`7`@0?blN100k:aX403PX
60<0>2TI100k;1/403h^7@@0@C0O1015<b8404Pf9@@0BSPW0`1<>BT404dj:P@0Cc`/101E@S8405i:
>P@0Ie500`1`F4H407QPCP@0PFQE1029Ked4099gI@@0VWm/0`2QQW@40:V>N`@0/IF2102hW8TF0?oo
o`00503oool40;NIQP@0[Y1k102UQW4309akIP@0TW5K1027IDl407aI@P@0L4/c101S?B@305L`5P@0
CRH=10188`T404HT30@0AB@>101490h404HW40<0B2XD1019;1D404X]5`@0BbhI101<<1`404hc7`<0
D3DQ101?=20404/b7@@0B34L1017<Ah404Td8@<0CCPU101>>RL404di9P@0CCXX101<>bT404`j:0@0
BSTW0`18=RD404Db8P@0@S0O100o;ah403/[6P@0>2PH0`0h:AT403//6`@0?RhM1011<1l404Dc8P@0
B3HU101:>2L304`i:@@0CCXZ101??2`405E2<P@0GTXj101WDD03071HAP@0N61>1021J5D408U_G@@0
TWMU102JOf`30:66M0@0ZHik102aUH840;RLRAH0oooo000D0?ooo`@0]iV5102^T7/40:F6L@<0VgaW
102ALE/408MUC`@0NeU2101]BS8405dh80<0Bb<910116P04044O1`@0@R<<10139A0404@W4P@0ABTD
0`17:aH404T]60@0BRhJ101:;a/404`b7P@0CSHT0`1A>BL405Dm:`@0FT<`101JA34405M2;P@0E44^
0`1A@2h404lm;0@0CS`Z101=>bX404`k:PP0C3/[0`1;>b/404Xl;0@0AcX[1010<bH403T/7`@0=bXL
0`0i:ad403LZ6`@0>BXL100n;Qh4048a8@@0ASDV1018>2P704Ph:@@0BCX[101>?Rl405Q6=`@0Hdln
0`1/ETD407INC@@0OfME1028Ked4091gI@@0VGm]0`2QQW@40:V>N`@0/9F2102hW8TF0?ooo`00503o
ool40;NIQ@@0[Y1k102UQW4309]lI`@0TG5K1027IDl407]I@P@0KDXb101M>20304/S2@@0@AX01011
7`L4048S30@0@bD@10149a8404DY50<0Ab/F1019;AP404X^6P@0BRlK101<<Qh404hf90<0DCTW101E
?B/405Y3<0@0FT@a101G@Rh405A1;P<0DD0^101??B`404hl:P@0CC/Z101<>bX804`k:`<0Bc/[101:
?2`404Lj:`@0@3<V100i;1l403LZ70<0>B/M100g:Q/403TZ70@0?RhN1012<B4404He9P@0B3PX1`18
>2T404Tj:`@0CSh_101HASL406=??P<0K5I5101fGTd407mWE@@0R6mM102@MfD409UoK@<0XHId102Y
SW/40;2EPP@0^9b95P3oool001@0oooo102gVHD40:j@N`@0YHIa0`2KO6L4095aF`@0QfE?101kFD84
06e:<P@0GCPP0`1;8`T4044J00@0@Al710128``404<U40@0A2LB1015:A@304L[5P@0BBdH101:;QX4
04X_6`@0C38N101>=R@3054i9`@0ECd[101J@c0405Y4<@@0Ed8^101D@Bh30550;P@0Ccd/101>?2X4
04dk:P@0C3/Z201<>b/304/k:`@0BS`/1017>R/4040c9P@0>B`O100g:Q`303T[7@@0=bXK100i:Q`4
03h^7P@0@S4Q1016=BH404Ph:0L0B3PY1019>R/404hn;`@0F4Hg101SCch306aFA@@0MUi=101oIeD4
08Q_G@@0T7MU102IOfd30:66M0@0ZHik102`UH840;RLRAH0oooo000D0?ooo`@0]iV5102^T7/40:F6
L@<0VgaW102ALE/408MUC`@0NeU2101]BS8405dh80<0Bb<910116P04044O1`@0@R<<10139A0404@W
4P@0ABTD0`17:aH404T]60@0BRhJ101:;a/404`b7P@0CSHT0`1A>BL405Dm:`@0FT<`101JA34405M2
;P@0E44^0`1A@2h404lm;0@0CS`Z101=>bX404`k:PP0C3/[0`1;>b/404Xl;0@0AcX[1010<bH403T/
7`@0=bXL0`0i:ad403LZ6`@0>BXL100n;Qh4048a8@@0ASDV1018>2P704Ph:@@0BCX[101>?Rl405Q6
=`@0Hdln0`1/ETD407INC@@0OfME1028Ked4091gI@@0VGm]0`2QQW@40:V>N`@0/9F2102hW8TF0?oo
o`00503oool40;NJQP@0[Y5m102UQg<309amJ@@0TW9M1027Ie4407]JA0@0KD/d101I=A`304/W3P@0
@1l8100i6P@403XN2@@0@2@?1015:A@404P/5`<0BBdI1019;a`804X_7@@0Bc8Q101==bH3050k:`@0
Dcl`101E@S8405I4=0@0ETDf101DA3@30592<`@0Cd0a101>?Rh404dm;@@0C3`]101<?Bh404`n;`<0
C3l`101=@30404do<0@0CCh_101;?2h404Li:`<0A3HX2014=BL404Hg:@@0AcP[1017>2X404Hh:P<0
ACPZ1014=RP404Dg:P@0C3d_101E@S<405i:>P<0JEA4101cGDd407eVE@@0QVmN102?MfH409QoK@<0
X8Me102XSW`40;2EP`@0^9b95P3oool001@0oooo102gVXH40:jAO@@0YHMc0`2LOFT4099bG@@0QfMA
101kFT@406e;=0@0FCDL0`1;9`h4040O20@0>AX4100j7PT4040T3`@0ABTD1018;1L304T]6@@0BBlL
201:;ad404/b8@@0CCLV0`1@>b/405<o<0@0ED8b101FA3@405I5=P@0E4@d0`1B@S<404m0<@@0CSh^
101=?Bd404`l;@@0C3d^101<?Rl304`o<0@0CD0`101=?c0404dn;`@0Bc`^1017>B/304@f:0P0A3DW
1016=bT404Lh:`@0AcPZ1016>2X304Dh:P@0A3HX1015=bX404`m;`@0ED8c101NBSX306UDA0@0Lee=
101mIUD408I_GP@0SgMV102HOfd30:27M@@0Z8il102`UH<40;RLRAH0oooo000D0?ooo`@0]iZ6102^
TGd40:F7L`<0W7eY102BLUd408MWD@@0NeY4101]Bc@405Te70<0BbL>10107`P403TJ10@0>Qh91010
90l404DY50@0B2`G0`19;AT404T_70P0BRlM101;<R4404dg9P<0D3/[101C?c0405E2<P@0ET@d101F
ACH405A4=0<0DT8c101?@34404hn;P@0CCd]101<?2d404`m;P@0C3h_0`1<?c0404e0<0@0CCl`101=
?Rl404/l;P@0AcT[0`14=RP804@e9`@0ASLY1017>2/404Lh:P@0ASPZ0`15>2X404@f:0@0ACLZ101<
?Bl405E2<`@0GTXj0`1YE4@407=MC@@0OFIE1026Keh408mgIP@0V7m]0`2PQgD40:R>O0@0/9F3102h
W8TF0?ooo`00503oool40;NJQP@0[Y5m102UQg<309amJ@@0TW9M1027Ie4407]JA0@0KD/d101I=A`3
04/W3P@0@1l8100i6P@403XN2@@0@2@?1015:A@404P/5`<0BBdI1019;a`804X_7@@0Bc8Q101==bH3
050k:`@0Dcl`101E@S8405I4=0@0ETDf101DA3@30592<`@0Cd0a101>?Rh404dm;@@0C3`]101<?Bh4
04`n;`<0C3l`101=@30404do<0@0CCh_101;?2h404Li:`<0A3HX2014=BL404Hg:@@0AcP[1017>2X4
04Hh:P<0ACPZ1014=RP404Dg:P@0C3d_101E@S<405i:>P<0JEA4101cGDd407eVE@@0QVmN102?MfH4
09QoK@<0X8Me102XSW`40;2EP`@0^9b95P3oool001@0oooo102gVhP40:jBOP@0YXQd0`2LOfX409=d
H0@0R6YE101mGTP4075A>`@0Hd</0`1G>24404da6`@0ABXF1012:1@404D[5P@0BBdJ1019;Q/304X`
7@@0BS8O101<=R@404dh:0@0BcHU101:=BD304/h:0@0C3/]101>?c4404m1<`@0D48d1`1?@C@404m2
=0@0CT0a101=?Bl404`m;P@0C3h`101<?S8304/n<P@0Bcha101;?c4404i1<`@0E4Hh101HBCX305A5
=`@0DT8d101?@C<404`n<@@0B3/_1016>Rh404Di;@<0@cL[1012=b/404Di;@@0C3ha101D@cD405a:
>`<0IU=4101aG4d407]VEP@0QFmN102?MfL409QoKP<0X8Me102XSW`40;2EP`@0^9b:5P3oool001@0
oooo102gVhP40:jBOP@0YXQd0`2LOfX409=dH0@0R6YE101mGTP4075A>`@0Hd</0`1G>24404da6`@0
ABXF1012:1@404D[5P@0BBdJ1019;Q/304X`7@@0BS8O101<=R@404dh:0@0BcHU101:=BD304/h:0@0
C3/]101>?c4404m1<`@0D48d1`1?@C@404m2=0@0CT0a101=?Bl404`m;P@0C3h`101<?S8304/n<P@0
Bcha101;?c4404i1<`@0E4Hh101HBCX305A5=`@0DT8d101?@C<404`n<@@0B3/_1016>Rh404Di;@<0
@cL[1012=b/404Di;@@0C3ha101D@cD405a:>`<0IU=4101aG4d407]VEP@0QFmN102?MfL409QoKP<0
X8Me102XSW`40;2EP`@0^9b:5P3oool001@0oooo102gVhP40:jBOP@0YXQd0`2LOfX409=dH0@0R6YE
101mGTP4075A>`@0Hd</0`1G>24404da6`@0ABXF1012:1@404D[5P@0BBdJ1019;Q/304X`7@@0BS8O
101<=R@404dh:0@0BcHU101:=BD304/h:0@0C3/]101>?c4404m1<`@0D48d1`1?@C@404m2=0@0CT0a
101=?Bl404`m;P@0C3h`101<?S8304/n<P@0Bcha101;?c4404i1<`@0E4Hh101HBCX305A5=`@0DT8d
101?@C<404`n<@@0B3/_1016>Rh404Di;@<0@cL[1012=b/404Di;@@0C3ha101D@cD405a:>`<0IU=4
101aG4d407]VEP@0QFmN102?MfL409QoKP<0X8Me102XSW`40;2EP`@0^9b:5P3oool001@0oooo102g
VhP40:jBOP@0YXQd0`2LOfX409=dH0@0R6YE101mGTP4075A>`@0Hd</0`1G>24404da6`@0ABXF1012
:1@404D[5P@0BBdJ1019;Q/304X`7@@0BS8O101<=R@404dh:0@0BcHU101:=BD304/h:0@0C3/]101>
?c4404m1<`@0D48d1`1?@C@404m2=0@0CT0a101=?Bl404`m;P@0C3h`101<?S8304/n<P@0Bcha101;
?c4404i1<`@0E4Hh101HBCX305A5=`@0DT8d101?@C<404`n<@@0B3/_1016>Rh404Di;@<0@cL[1012
=b/404Di;@@0C3ha101D@cD405a:>`<0IU=4101aG4d407]VEP@0QFmN102?MfL409QoKP<0X8Me102X
SW`40;2EP`@0^9b:5P3oool001@0oooo102gVhP40:nBO`@0YXYf0`2NP6`409AgH`@0RfeI1021Hdh4
07IH@`@0Jdhi0`1P@bh405Dk9`@0CcHR101<<al404/c7`@0BS<P101:<Ql304Ta7`@0Bc@S101<>2L4
04ll;@@0DD4c101B@cH305=4>0@0ETTm101JCT8405Y@A@@0FDm4101GCT<305A:?`@0D4Di101=@C@4
04`n<@@0Bcda101;?c<404a0=@<0BShd1018?38404Pl<@@0BShb101=@C@40513=`<0DDDi101@ACT4
04e2=`@0BChd1016>c8404Di<0@0@cP^0`11=R`4040f;0@0A3X`101>@SH405A6>P@0FDTk0`1SDD84
06mLC@@0NVIG1025L60408mhJ0@0V81_0`2PR7H40:R?O@@0/9J4102hWHXF0?ooo`00503oool40;NK
R0@0[i9o102VRWH309j0K0@0U7MS102;KET4085SCP@0MUQ3101[CST30613;P@0EC/W101?=R8404`c
7`@0Bc<O101:<b0404Xb7`<0BC4O101;=2<404`h9`@0Cc`]101A@C<40593=P<0Dd@h101FBCd405Y>
@P@0FU15101ICd@405M>@`<0E4Xo101@ACT404e1=0@0C3ha101;?C4404/o<`@0C40e0`1:?S@404Pl
<P@0B3`a101:?S8404e1=0@0D4<g0`1AACT40515>@@0CD8g1019?S@404Hk<P@0ACT`1013>2h3044f
;0@0@3H/1014>S0404i2=P@0E4Hj101IBC/306=A@P@0Kea=101jIUL408E`H0@0SgQX102HP6l30:28
MP@0Z8mm102`UX@40;RMRQH0oooo000D0?ooo`@0]i^8102_TWl40:J:MP<0WX1/102DMf<408]]F@@0
PF=>101fF4<406]>>@<0H4<^101E>bL404lf8P@0C3<O101;<al404Xc80@0BS8O0`19<Al404/d8`@0
C3PW101??2d40551<`@0DT<f0`1CA3P405I9?@@0FTi2101JD4D405U?A0@0Edi30`1DBSl40515>@@0
CD4d101<?S4404/m<@@0Bclc101<@3D304Xn=0@0B3`b1018?34404Xn<P@0CD4d101@@cL30555>@@0
D4Di101=@SL404Tn=0@0AS/b1015>C0404<h;P<0@CH/1010=R`404@j<0@0CT8f101DASX405U9>`<0
He52101_G4d407YVE`@0QG1P102?N6P409R0K`<0X8Qf102XSgd40;2FQ0@0^9f:5P3oool001@0oooo
102gVhP40:nBO`@0YXYf0`2NP6`409AgH`@0RfeI1021Hdh407IH@`@0Jdhi0`1P@bh405Dk9`@0CcHR
101<<al404/c7`@0BS<P101:<Ql304Ta7`@0Bc@S101<>2L404ll;@@0DD4c101B@cH305=4>0@0ETTm
101JCT8405Y@A@@0FDm4101GCT<305A:?`@0D4Di101=@C@404`n<@@0Bcda101;?c<404a0=@<0BShd
1018?38404Pl<@@0BShb101=@C@40513=`<0DDDi101@ACT404e2=`@0BChd1016>c8404Di<0@0@cP^
0`11=R`4040f;0@0A3X`101>@SH405A6>P@0FDTk0`1SDD8406mLC@@0NVIG1025L60408mhJ0@0V81_
0`2PR7H40:R?O@@0/9J4102hWHXF0?ooo`00503oool40;RKR0@0/9>0102XRgL309n3K`@0UgYW102>
LEh408EXE@@0O61<101cF4@306Y??0@0HDLd101J@Bh405@l:@@0DCTV101>=bD404/d8P<0BC<R101:
=B@404`h:0@0CC`^101@@C@405=8?0<0Edi3101JDTL405]EC0@0FeI>101JETh405MBB@<0DT]0101>
A3T404]0=0@0BCha1019?S8404]0=0@0CD@h0`1@Acd404m6?@@0BClh2015>c8404Pn=0<0BD0e101:
@3D404Pn=@@0AS`c1014>S4404<j<@@0@SP`0`0o=Rh4044g;`@0Acdd101:@3H404i2=`@0DT<f0`1M
C3h406iLCP@0NVMI1025LF8408mjJP@0V89a0`2QRGP40:V@OP@0/IJ4102hWHXF0?ooo`00503oool4
0;RKR0@0/9>0102XRgL309n3K`@0UgYW102>LEh408EXE@@0O61<101cF4@306Y??0@0HDLd101J@Bh4
05@l:@@0DCTV101>=bD404/d8P<0BC<R101:=B@404`h:0@0CC`^101@@C@405=8?0<0Edi3101JDTL4
05]EC0@0FeI>101JETh405MBB@<0DT]0101>A3T404]0=0@0BCha1019?S8404]0=0@0CD@h0`1@Acd4
04m6?@@0BClh2015>c8404Pn=0<0BD0e101:@3D404Pn=@@0AS`c1014>S4404<j<@@0@SP`0`0o=Rh4
044g;`@0Acdd101:@3H404i2=`@0DT<f0`1MC3h406iLCP@0NVMI1025LF8408mjJP@0V89a0`2QRGP4
0:V@OP@0/IJ4102hWHXF0?ooo`00503oool40;RKR0@0/9>0102XRgL309n3K`@0UgYW102>LEh408EX
E@@0O61<101cF4@306Y??0@0HDLd101J@Bh405@l:@@0DCTV101>=bD404/d8P<0BC<R101:=B@404`h
:0@0CC`^101@@C@405=8?0<0Edi3101JDTL405]EC0@0FeI>101JETh405MBB@<0DT]0101>A3T404]0
=0@0BCha1019?S8404]0=0@0CD@h0`1@Acd404m6?@@0BClh2015>c8404Pn=0<0BD0e101:@3D404Pn
=@@0AS`c1014>S4404<j<@@0@SP`0`0o=Rh4044g;`@0Acdd101:@3H404i2=`@0DT<f0`1MC3h406iL
CP@0NVMI1025LF8408mjJP@0V89a0`2QRGP40:V@OP@0/IJ4102hWHXF0?ooo`00503oool40;RLR@@0
/IF1102YSGX30:66L`@0VGi[102AMV<408U^F`@0PFID101iGdd3075IA`@0JU90101SBcT405e5=0@0
F40_101B>bX404hg9P<0BcDU101:=BH404Xg:0@0C3X/101=?S4404m3=`<0DDLm101CBd4405=<@`@0
Dde5101BC4@40519@@<0CDDl101:@CH404Pm<PP0Ac``1019?S<404]1=`<0CdDl101BBT8405E<A0@0
DdU1101<@c/404Dm=@l0@c/c1014?3@404@l=@@0@SXc0`10>S8404<l=0@0Aclg1017@3P404]3>P@0
ET]00`1SEDP4071PDP@0O6YL1027LfD4095lK@@0VHAc0`2RRWX40:ZAP0@0/IN5102hWH/F0?ooo`00
503oool40;RLR@@0/IF1102YSGX30:66L`@0VGi[102AMV<408U^F`@0PFID101iGdd3075IA`@0JU90
101SBcT405e5=0@0F40_101B>bX404hg9P<0BcDU101:=BH404Xg:0@0C3X/101=?S4404m3=`<0DDLm
101CBd4405=<@`@0Dde5101BC4@40519@@<0CDDl101:@CH404Pm<PP0Ac``1019?S<404]1=`<0CdDl
101BBT8405E<A0@0DdU1101<@c/404Dm=@l0@c/c1014?3@404@l=@@0@SXc0`10>S8404<l=0@0Aclg
1017@3P404]3>P@0ET]00`1SEDP4071PDP@0O6YL1027LfD4095lK@@0VHAc0`2RRWX40:ZAP0@0/IN5
102hWH/F0?ooo`00503oool40;RLR@@0/IF1102YSGX30:66L`@0VGi[102AMV<408U^F`@0PFID101i
Gdd3075IA`@0JU90101SBcT405e5=0@0F40_101B>bX404hg9P<0BcDU101:=BH404Xg:0@0C3X/101=
?S4404m3=`<0DDLm101CBd4405=<@`@0Dde5101BC4@40519@@<0CDDl101:@CH404Pm<PP0Ac``1019
?S<404]1=`<0CdDl101BBT8405E<A0@0DdU1101<@c/404Dm=@l0@c/c1014?3@404@l=@@0@SXc0`10
>S8404<l=0@0Aclg1017@3P404]3>P@0ET]00`1SEDP4071PDP@0O6YL1027LfD4095lK@@0VHAc0`2R
RWX40:ZAP0@0/IN5102hWH/F0?ooo`00503oool40;RLR@@0/IF1102YSGX30:66L`@0VGi[102AMV<4
08U^F`@0PFID101iGdd3075IA`@0JU90101SBcT405e5=0@0F40_101B>bX404hg9P<0BcDU101:=BH4
04Xg:0@0C3X/101=?S4404m3=`<0DDLm101CBd4405=<@`@0Dde5101BC4@40519@@<0CDDl101:@CH4
04Pm<PP0Ac``1019?S<404]1=`<0CdDl101BBT8405E<A0@0DdU1101<@c/404Dm=@l0@c/c1014?3@4
04@l=@@0@SXc0`10>S8404<l=0@0Aclg1017@3P404]3>P@0ET]00`1SEDP4071PDP@0O6YL1027LfD4
095lK@@0VHAc0`2RRWX40:ZAP0@0/IN5102hWH/F0?ooo`00503oool40;VMR@@0/YJ3102ZSg`30:>8
M@@0W85_102DNVP408ecH@@0QVaJ101oIUD307UQC`@0LUY9101ZDd8406A=?0@0GDHf101F@30404hi
:@<0BCDU1018=2D404Tf9`@0BSPZ101:>bh404/m<@<0C40e101=@SP404e4>`@0C4@k101;@cX404U1
>0<0Ache1015?38404@i;`@0@cP^1014>Bh404Dj<0@0Ac`c0`1:@3L404e4>`@0D4Po101CBd8405E<
A0@0E4a40`1@B40404e5?@@0C4@m101;A3d404M1>P@0@chg1011?CH3048n=`@0AT4j101:ACd404e9
@0@0DDe5101KDdT306MKC`@0LfAG101oKV0408UgJ@@0Tgm`102KQWH30:><O0@0Zi:1102bV8H40;VN
RaH0oooo000D0?ooo`@0^If9102bUX<40:Z?O0<0XhQe102LPFl409AjJ0@0SG=Q1026K5X407mVE@<0
NF5?101bFTT406YC@P@0I4dl101MASH405I0<0@0CSTY0`19=BD404Pd9@@0BCHW101:>2X404Xk;P@0
Bcda0`1<@3D404e2>0@0CD@k101<A3/404]3>P@0BD4h0`17?SD404Dl<P@0A3T_1013>2h404@i;P@0
ACX`1017?3<304Y0=`@0CD@k101@B3l405=;@P@0EDa4101DC4@30518@0@0CDDm101<A3d404]4?@@0
Ad4j1013?SL4044m=P<0@Shg1016@CX404Y5?@@0CDU0101ACDD405]CB@<0Ie]?101cI5L407m^H0@0
RGMY102COg0409^6MP<0Xhal102[TX440;:HQP@0^Ij;5P3oool001@0oooo102iWHT40;:FP`@0ZXml
0`2SR7D409b1K`@0U7YX102=Lf4408I/FP@0OfIE0`1iHDl4079JB@@0JU=2101TCC`405e6=P@0ET0`
101>>BT304Te9@@0B3@U1019=RL404Xh:P@0BS/^101;?C4304a0=@@0CD8h101=A3/404a4>`@0Bd<j
1019@CP304Ln=@@0AC`b1014>Bl404<h;P@0A3T^1015>S0404Ll<`<0BT0g101=A3/40518?`@0Dd]2
101EC4@405A<A0<0D4Q0101=ACd404a4?@@0Bd@m1017@CX404<n=`@0@Cdf0`12?SL404I1>P@0BTDm
101=BD04055=A@@0Fe=90`1WFdl407=TE`@0OfiP1029MfT409=oL0@0VhIf0`2SS7`40:^BP@@0/YR6
102iWX/F0?ooo`00503oool40;VMR@@0/YJ3102ZSg`30:>8M@@0W85_102DNVP408ecH@@0QVaJ101o
IUD307UQC`@0LUY9101ZDd8406A=?0@0GDHf101F@30404hi:@<0BCDU1018=2D404Tf9`@0BSPZ101:
>bh404/m<@<0C40e101=@SP404e4>`@0C4@k101;@cX404U1>0<0Ache1015?38404@i;`@0@cP^1014
>Bh404Dj<0@0Ac`c0`1:@3L404e4>`@0D4Po101CBd8405E<A0@0E4a40`1@B40404e5?@@0C4@m101;
A3d404M1>P@0@chg1011?CH3048n=`@0AT4j101:ACd404e9@0@0DDe5101KDdT306MKC`@0LfAG101o
KV0408UgJ@@0Tgm`102KQWH30:><O0@0Zi:1102bV8H40;VNRaH0oooo000D0?ooo`@0^If:102cUh@4
0:bAO`<0YH]i102OQG<409QnK0@0TGQW102:LV4408A/FP<0OFID101gHE04075KB`@0JE=3101QBc/4
05Q3<`@0CcX/0`19=BH404Lc9@@0Ac@V1017=RT404Lg:`@0AcT^0`17>Rl404Lk<0@0Ac`b1016?384
04Dk<@@0@cT`0`11=bd4040e:`@0?c<Z100o<bT403ld:P@0@3H/1012>2l304@j<@@0Ache101:@CT4
04e4?@@0CdQ0101ABT<3059;A0@0D4Y4101=B48404Y4?`@0AT8l1013@3X4048n>0<0A44k101:Ad44
051<AP@0EU5:101KETh4069JD0<0JeiC101fIe/408=cIP@0SGa^102FPg@409j9NP<0YHmo102/U8<4
0;>IR0@0^Ij<5P3oool001@0oooo102iWHX40;>GQ0@0[95o0`2URgT409n5L`@0V7i/102AN6L408Yb
H@@0Q6aJ0`1mIU@407MQD0@0LE];101YDd<4065;>`@0F4<c101?>R`304Te9P@0Ac<U1017=2H404Lf
:@@0AcL[1017>Bh304Lj;`@0Ac/`1017?38404Hl<P@0AC/a1013>C03044g;@@0@3D[100o<bX403lc
:@@0?c@Z1010=R`4048h;`<0A3Xa1017?SD404Y1>@@0CD@m101?B404055:@`<0DT]4101@BT@404e8
@P@0BT@o1016@S`404=0>P@0@Shh0`14@C/404Y7@@@0D4a6101FDDX405]FCP@0HUY@0`1[GU<407IW
F`@0Pg=V102=O6h409J3M0@0WXUj0`2USgl40:bDP`@0/iV8102iWX`F0?ooo`00503oool40;VMRP@0
/iN4102/TGl30:F;N@@0WhEc102HOV`4095hI`@0RW9Q1024K5X307eVE0@0Mf5@101aFd/406UC@`@0
HD/k101H@c<404lj;0<0BCDV1017<bD404Ld9P@0AcHY1017=b/404Li;P<0AcX_1017>c0404Ll<P@0
AS`b1015>c4404<i<0<0@CL]1010=B/403lc:P@0?c<Y100o=2X4040f;0@0@SP_0`14>S4404Ln=@@0
BT4i101=A3d404m8@0@0DDY30`1BBd@4051:A0@0CDQ2101:A3l404I2?0@0@d0j1012?SP304A1>`@0
BTM1101@C4H405IABP@0FeI>101RFU0306]ND`@0MVMK1023LfH408elKP@0UX=d102NRGX30:F?O`@0
[9B3102cVHP40;VNS1H0oooo000D0?ooo`@0^If:102cUh@40:bAO`<0YH]i102OQG<409QnK0@0TGQW
102:LV4408A/FP<0OFID101gHE04075KB`@0JE=3101QBc/405Q3<`@0CcX/0`19=BH404Lc9@@0Ac@V
1017=RT404Lg:`@0AcT^0`17>Rl404Lk<0@0Ac`b1016?38404Dk<@@0@cT`0`11=bd4040e:`@0?c<Z
100o<bT403ld:P@0@3H/1012>2l304@j<@@0Ache101:@CT404e4?@@0CdQ0101ABT<3059;A0@0D4Y4
101=B48404Y4?`@0AT8l1013@3X4048n>0<0A44k101:Ad44051<AP@0EU5:101KETh4069JD0<0JeiC
101fIe/408=cIP@0SGa^102FPg@409j9NP<0YHmo102/U8<40;>IR0@0^Ij<5P3oool001@0oooo102j
WX/40;BHQP@0[Y>10`2XSW`40:68M`@0Vh9a102EOF`408mgI`@0R79R0`22KEh407eXF@@0MV5C101]
FT/406=A@`@0FTLi101A?S4304Tf:@@0AS<U1016<bH404Dd9`@0A3@X1014=2T304<e:P@0@SDZ1011
=2X4040d:P@0?S<Y100m<RP303/`9`@0>RlU100i;R@403T^9@@0>RlV100k<2L403`b:P<0?SD]1011
>34404<l=0@0ASlh1019@S`404Y4?P<0BTDo101:AD0404Q4?`@0AD<n1013@S`40451?0@0@D4m0`15
AD4404i=B0@0EE=>101LFE<406=NE`@0JfAL0`1cJEl407iaIP@0RGY^102BPWD409Z8NP@0XHen0`2W
TX840:jFQP@0]9^9102jWhdF0?ooo`00503oool40;ZNR`@0]9R6102^Th430:R>O0@0XHQg102KPW44
09EmK0@0SgMW1028LV83089]GP@0OFQI101fHE<406eJB`@0He53101JAcT4054n<@<0BCHY1016<bD4
04Hc9P@0AC@W1014=2P404@d:@<0@cDZ1012=BX4044d:P@0@3@Z100n<bT403db:0<0>c0W100j;bD4
03T^90@0>BhU100j;bH403/`9`@0?38Z0`0n=Bd4044h<@@0@c`d1016?cP404U2?0@0BT@n0`1:ACl4
04Y5@0@0B4@o1015@ch404=2?0@0@D4l1011@Cd304E5@@@0CTe8101EDdh405aID`@0HeiG101[I5`3
07=YG`@0OW5V1029NVh409:2M@@0VXQj102QSGh30:NBPP@0[YJ6102dVhT40;ZOSAH0oooo000D0?oo
o`@0^Yj;102dV8H40:jCP@<0Z8il102QR7L409^2L@@0UGe/102?MfL408QbHP<0PVeN101mJ5T407IQ
D`@0KEY;101SDD<405Y7>@@0DCha0`19=RT404Hc9@@0AS<V1015=2L404@d:0@0A3@Y0`13=BX4048e
:P@0@C@Z1010=2X403hc:@@0?C8X0`0k<2L403X_9@@0>BhT100i;RD403X_9P@0>c0W100l<RX303he
;@@0@CPa1013?3@404Ho>0@0BD8l101:A3h304Y5?`@0BTE01018A3l404E3?P@0@d8l1011@C`40451
?@<0ADE1101>CDP405ECCP@0G5UC101SGUL406]TG0<0LfUO101nLFH408UjKP@0TX9e102JR7X40:6=
OP<0Yi:2102^UXH40;BKR@@0^Yn=5P3oool001@0oooo102jWX/40;BHQP@0[Y>10`2XSW`40:68M`@0
Vh9a102EOF`408mgI`@0R79R0`22KEh407eXF@@0MV5C101]FT/406=A@`@0FTLi101A?S4304Tf:@@0
AS<U1016<bH404Dd9`@0A3@X1014=2T304<e:P@0@SDZ1011=2X4040d:P@0?S<Y100m<RP303/`9`@0
>RlU100i;R@403T^9@@0>RlV100k<2L403`b:P<0?SD]1011>34404<l=0@0ASlh1019@S`404Y4?P<0
BTDo101:AD0404Q4?`@0AD<n1013@S`40451?0@0@D4m0`15AD4404i=B0@0EE=>101LFE<406=NE`@0
JfAL0`1cJEl407iaIP@0RGY^102BPWD409Z8NP@0XHen0`2WTX840:jFQP@0]9^9102jWhdF0?ooo`00
503oool40;ZOS0@0]IZ8102_UH<30:Z@O`@0Y8]j102OQgH409V2LP@0Tge]102>N6T308QcI@@0PViP
101lJE/407AQE0@0JeQ;101PCd8405M6>P<0CC`a1017=BT404@b9P@0@c4U1011<2@4040_8`<0?RlT
100m;bD403/_9@@0>RdT100h;2<403L[8P<0=BXQ100d:B0403<X7`@0<bPP100d:B4403D[8`@0=RdV
0`0h<2T403Xc;0@0?CH`1010>C@4048l=`@0A3lj0`14@3`804A1?@P0@d4m1012@Sh404E5@P<0CTe9
101EE50405eKEP@0IV=N101_JfD407QbJ`<0P7U`1029OgD40964N@@0V8Ul102NSH040:BAP`<0ZYF5
102`VHP40;FLR`@0^Z2=5P3oool001@0oooo102jWh`40;FJR0@0[iF30`2ZT7l40:B;NP@0WhMf102I
PW8409=mK@@0SWQY0`28LfD4089^H0@0O6UK101dHE@406]HB`@0H4m2101GASX304dl<@@0AcDY1014
<RH404<a9@@0@C0T1010;b<303h_90@0?BlU100k;bD403X]90@0>2`S100g:b8303DZ8@@0=2TP100c
:1l403<X80@0=2TQ100e:b<403H]9P<0>30Y100j<b`403df<0@0@3Td1012?3L404@o>P<0A40l2014
@Cd804=1?@@0@T8n1015AD8304i=B@@0EEA@101MFeH406ISGP@0Kf]U101hLV/3081iL0@0RGme102A
Q7T409R9O0@0WXf0102TTH<30:ZEQ@@0/9V8102eW8/40;ZPSAH0oooo000D0?ooo`@0^Yn<102eVXP4
0:nEP`<0ZY1o102TRgX409n7MP@0VH9b102COFd408ihJ@<0R7=U1022KV0407aYF`@0M65D101[F4/4
061?@P@0EdHj0`1=?34404Le:@@0A38V1013<BD4044`90@0@2lS0`0n;b@403d_9@@0>blU100j;B@4
03P/8`@0=b/R0`0e:R4403@Y80@0<bPO100c:20403@Y8@@0=B/S100f;BH303P`:@@0>S</100m=S04
040i=0@0@S`g1014?cX304A0?0P0A44m2013@Cd40492?P@0ADE20`1>CDT405EDD0@0GE]F101VHeh4
06m[I@@0N79[0`20NG0408UoM@@0THAi102HRG`409j=P0@0Y9630`2ZUHD40;2IR0@0]Ib;102jX8dF
0?ooo`00503oool40;ZOS0@0]IZ8102_UH<30:Z@O`@0Y8]j102OQgH409V2LP@0Tge]102>N6T308Qc
I@@0PViP101lJE/407AQE0@0JeQ;101PCd8405M6>P<0CC`a1017=BT404@b9P@0@c4U1011<2@4040_
8`<0?RlT100m;bD403/_9@@0>RdT100h;2<403L[8P<0=BXQ100d:B0403<X7`@0<bPP100d:B4403D[
8`@0=RdV0`0h<2T403Xc;0@0?CH`1010>C@4048l=`@0A3lj0`14@3`804A1?@P0@d4m1012@Sh404E5
@P<0CTe9101EE50405eKEP@0IV=N101_JfD407QbJ`<0P7U`1029OgD40964N@@0V8Ul102NSH040:BA
P`<0ZYF5102`VHP40;FLR`@0^Z2=5P3oool001@0oooo102kWhd40;JKR@@0/IN60`2/Th840:N?O`@0
XX]k102MQWL409N2L`@0TWi`0`2<NV`408MeJ0@0PFmR101iIe/406mNDP@0IEA9101KBSl305=1=P@0
BST]1014<RL4040`90@0?RhR100l;20303XZ7`@0>2TN100f:1h403@W7@@0<RHM100`91/302lS6PP0
;R8J100]8a/402dT70@0;bDO100`:24303<Z90@0=BhX100g<Bd403Xe<0@0?3Lc100m>SH303ll>0@0
?chj1010?c`40450?@@0@44n1013A48404Y;B0<0DeA@101LGET406MVH@@0LFmY101kN74408F0N@<0
TH^4102GShL409V>Q0@0WY24102STXH40:REQ`<0[IR9102bVh/40;JNS0@0^j2>5P3oool001@0oooo
102kWhd40;JKR@@0/IN60`2/Th840:N?O`@0XX]k102MQWL409N2L`@0TWi`0`2<NV`408MeJ0@0PFmR
101iIe/406mNDP@0IEA9101KBSl305=1=P@0BST]1014<RL4040`90@0?RhR100l;20303XZ7`@0>2TN
100f:1h403@W7@@0<RHM100`91/302lS6PP0;R8J100]8a/402dT70@0;bDO100`:24303<Z90@0=BhX
100g<Bd403Xe<0@0?3Lc100m>SH303ll>0@0?chj1010?c`40450?@@0@44n1013A48404Y;B0<0DeA@
101LGET406MVH@@0LFmY101kN74408F0N@<0TH^4102GShL409V>Q0@0WY24102STXH40:REQ`<0[IR9
102bVh/40;JNS0@0^j2>5P3oool001@0oooo102kWhd40;JKR@@0/IN60`2/Th840:N?O`@0XX]k102M
QWL409N2L`@0TWi`0`2<NV`408MeJ0@0PFmR101iIe/406mNDP@0IEA9101KBSl305=1=P@0BST]1014
<RL4040`90@0?RhR100l;20303XZ7`@0>2TN100f:1h403@W7@@0<RHM100`91/302lS6PP0;R8J100]
8a/402dT70@0;bDO100`:24303<Z90@0=BhX100g<Bd403Xe<0@0?3Lc100m>SH303ll>0@0?chj1010
?c`40450?@@0@44n1013A48404Y;B0<0DeA@101LGET406MVH@@0LFmY101kN74408F0N@<0TH^4102G
ShL409V>Q0@0WY24102STXH40:REQ`<0[IR9102bVh/40;JNS0@0^j2>5P3oool001@0oooo102kX8d4
0;NMR`@0/iV80`2^UXD40:ZCP`@0YXn0102QRgd409b7N@@0UX=e0`2AOW8408]jK@@0QGAX101mKF84
07EUF`@0JeaB101NDDL305A6?0@0BS`c1013=2X403h_9@@0>b`Q100h:Ah303DV70@0<b@I100`8QL4
02hP5P@0;1hE100Z7A@302PL4`@09a/C100W6a@402LL5P@0:1lH100Y8A/402/T7P<0;BLR100_:RD4
038^:@@0=30]100f<c0403Pg=0<0>STg100l?3X403dn?0@0?T0o1011A48404M:B0@0D59A0`1KGEX4
06IWI0@0LG5]101lNWD408J3OP@0T8b50`2ITX/409jES@@0XIJ<102TUX/40:RHR`@0[9V<0`2`Vh`4
0;BMS@@0^9n>102lXHlF0?ooo`00503oool40;^PS@@0]if;102cVHP30:jFQ@@0ZY>3102VSh040:6;
O@@0W8Mi102FPgD3095nLP@0RgY]1025M6P407e]HP@0MFEK101[G58405iAA`<0E4Hl101:?3<404<d
:P@0?RlU100k;24403PY7P<0=BHL100c91T4030R5`@0;R0F100/7QD402XM50<0:1`C100W6a<402LK
50@09a`F100X7aP402TQ6`@0:b@N0`0]9b8402lZ9@@0<RhY100d<2d403Hc<0@0>3Ld0`0j>CL403`l
>P@0?Chl100n@3l40454@P@0AdY8101@DU4305]MFP@0IVMT101aLFd407ajM@@0QX=n102@S8D309VB
R`@0WYF=102QUX`40:BFR`@0Z9R;102/VH`30;2KS0@0]9f=102hWhh40;bQSaH0oooo000D0?ooo`@0
^j2=102gWH/40;>IR0<0[YJ5102ZTh<40:J?P0@0XH]m102LQgT409J3M@<0TGib102;NVd408EdJ0@0
OFeR101eIE/406]LDP@0GU570`1DAS`404Xl<`@0@c@Z100n;bD403//8@@0>2TN0`0e9Q`403<T6@@0
<28G100^81H402`N5@@0:QdD0`0X71<402LK4`@09a/D100W71H402PO60@0:B4K100[91h302dW8P@0
;bXU100b;RT403@`;@@0=S<`100h=c@303Xi=`@0?3`j100m?S`403i0?`@0@DA21017BTP4051BD@<0
FeeJ101VIf@4075aK@@0O7Ye1026Pgh4092<Q@<0VI:;102NUHd40:6FS0@0Y9J;102XV8/40:bIS0<0
/9^<102dWHd40;ROSP@0_:6?5P3oool001@0oooo102kX8d40;NMR`@0/iV80`2^UXD40:ZCP`@0YXn0
102QRgd409b7N@@0UX=e0`2AOW8408]jK@@0QGAX101mKF8407EUF`@0JeaB101NDDL305A6?0@0BS`c
1013=2X403h_9@@0>b`Q100h:Ah303DV70@0<b@I100`8QL402hP5P@0;1hE100Z7A@302PL4`@09a/C
100W6a@402LL5P@0:1lH100Y8A/402/T7P<0;BLR100_:RD4038^:@@0=30]100f<c0403Pg=0<0>STg
100l?3X403dn?0@0?T0o1011A48404M:B0@0D59A0`1KGEX406IWI0@0LG5]101lNWD408J3OP@0T8b5
0`2ITX/409jES@@0XIJ<102TUX/40:RHR`@0[9V<0`2`Vh`40;BMS@@0^9n>102lXHlF0?ooo`00503o
ool40;bQSP@0^9j<102eVhX30;6IR@@0[IJ7102YU8D40:FAP`@0XXn2102MRgh309R6N@@0TH1e102:
Ng0408AeJ`@0NVaR101_HEP406=FC@<0ET]2101:?SH4044d:`@0>bdT100g:Al403@U6`<0<B8G100]
7Q<402XK40@0:1T>100U5`d402<E30<08AD<100P5@d4020E3`@081H@100Q61<4028K5P@09AlJ0`0W
8al402XV8`@0;BXV100`;R/4038a;`@0=C@b0`0g=cH403Pj>@@0>Cdl100l@D040456AP@0BDi>101E
FET3065UH`@0KVm^101jNWL408F3P0@0T8j:102MV9<30:>NU`@0YIfE102WWI@40:ZMTP@0[9fA102_
WI030;>NT0@0]Yn@102iXI040;bRT1H0oooo000D0?ooo`@0_:6>102hWX`40;FKRP<0/IV9102]UXL4
0:VDQ@@0YI63102RSh8409f;OP<0V8Ii102AP7D408YkL0@0Q7E[101jK68406mQF0@0HeI=0`1FBd84
04Xn=P@0@C@[100k;B@403LY7`@0=2DK0`0a8QL402dN4`@0:Q/@100X6@h402DG3@@08aD<0`0Q5@`4
020E3@@081D?100P5Q04024H4`@08Q/F100U7aX302LS7`@0:RHS100]:RH4030^:`@0<S4_100e=383
03Lg=P@0>3Xi100i?C`403a1@0@0@DI61019CTh405EIF@<0HFES101^Kfh407YjM`@0QH>0102@SXX4
09fHT`<0XijG102UWID40:NMU0@0ZYfB102/WI440:nMT0<0/ij@102fWi040;VQT0@0_::@5P3oool0
01@0oooo102lXHh40;RNS0@0]I^:0`2aVHT40:fFQ`@0ZIB5102UTH<40::?PP@0WH]n0`2HQWT40960
M@@0RW]`1024MF/407Y/HP@0Kf5H101SETd305I;@P@0BShf1011=2/403/]90@0=bTO100d9A/3034R
5`@0;AhC100Z6a0402PI3P@09AL=100S5@`3024E30@081D=100P5@l4020F40@08APC100R6aH402DO
6P<09b<O100Z9R<402dZ9P@0<2h[100b<Bl403Dd<P<0=cLf100h>ST403Tm?0@0?4501011ATH404U>
CP@0EEUI0`1QIF<406i_KP@0NWYg1025Ph04092>RP@0WIRC0`2SWYL40:FMU@@0YifD102ZWI840:bM
T@@0[if@0`2cWY040;JOT0@0^J6@102lXY0F0?ooo`00503oool40;bQSP@0^9j<102eVhX30;6IR@@0
[IJ7102YU8D40:FAP`@0XXn2102MRgh309R6N@@0TH1e102:Ng0408AeJ`@0NVaR101_HEP406=FC@<0
ET]2101:?SH4044d:`@0>bdT100g:Al403@U6`<0<B8G100]7Q<402XK40@0:1T>100U5`d402<E30<0
8AD<100P5@d4020E3`@081H@100Q61<4028K5P@09AlJ0`0W8al402XV8`@0;BXV100`;R/4038a;`@0
=C@b0`0g=cH403Pj>@@0>Cdl100l@D040456AP@0BDi>101EFET3065UH`@0KVm^101jNWL408F3P0@0
T8j:102MV9<30:>NU`@0YIfE102WWI@40:ZMTP@0[9fA102_WI030;>NT0@0]Yn@102iXI040;bRT1H0
oooo000D0?ooo`@0_J6?102iWhh40;JNS@<0/ib<102`VX/40:fHRP@0ZYN:102WUHT40:BCQ`<0WXn4
102GRGh40922N0@0R7Ya101nLFP407=WGP@0IeaD0`1ICdP404]1>P@0@3D^100i;BD403@W7P@0<28H
0`0/7A<402PI3`@09AH;100Q4`T401lA20@07A090`0K3`T401T>20@060h9100I40`401XC40@071LD
100O6QP3028N6`@09B8O100X9R@402/Z:@@0;Rl^100a<c8303<f=P@0=SXj100i?Ch403e2A0@0A4]<
101@EUL405eRH`<0Jfm^101iNWT408F5P`@0TY2=102OW9P40:bZYP<0/:bW102]YYl40:jTV`@0[j:H
102aXYH40;>QU0<0]J6C102hXY840;ZRT@@0_J>A5P3oool001@0oooo102mXHl40;VOSP@0]Yj=0`2c
W8`40;2JR`@0[IR:102ZUhX40:NER@@0Y9>70`2NSh@409N9OP@0T89h1028NW4407iaJ0@0LfMN101W
G5@305U?B0@0Bd4j1010=Bh403T]9@@0=2LN100`8QP302`M4`@0:1T?100U5P/4024C2@@07a48100M
40T301/?2@@06@h8100H3PT401T@30@06Q<@100L5a@401lJ60<08QhK100U8Ql402PV90@0:bXY100^
;bh4034c<P<0<cHf100f>SX403Tm?P@0?D941014Bd`4051FE`@0GF9S0`1[Kfh407UjN@@0QHF3102B
T8d409nLV0@0[:ZV0`2`[:L40:fVW`@0[ZBK102_XYP40;6RUP@0/j6D0`2eXI<40;RRTP@0^Z:A102m
Xi4F0?ooo`00503oool40;fQS`@0^In>102fWXd30;>LS0@0/9Z;102]V8X40:ZGRP@0YiF9102TThL3
09j?Q0@0UhUn102@PWP408QjL@@0OW5X101cIeh406MLE0<0FDm8101;@CX4040e;P@0>BdU100d9ah4
030R60<0;1dC100X6@l402DF2`@08A<9100O4@P401d@2@<06`l9100I3PP401P>2@@06A0<100J4a04
01`G50@07aXH0`0R7Q/402DR7`@0:2HT100[:RT402h_;P@0<C<b0`0c=SH403Hj>P@0>Cdn100m@T@4
04A;C0@0D5IG101MHV<306]_KP@0NGYi1025QH<409:@S@@0WibH102/ZZH30;2/Y`@0[JJO102^Y9/4
0:nRV0@0/J:F102cXI@30;FQT`@0^::B102jXY440;fSTAH0oooo000D0?ooo`@0_J6?102iWhh40;JN
S@<0/ib<102`VX/40:fHRP@0ZYN:102WUHT40:BCQ`<0WXn4102GRGh40922N0@0R7Ya101nLFP407=W
GP@0IeaD0`1ICdP404]1>P@0@3D^100i;BD403@W7P@0<28H0`0/7A<402PI3`@09AH;100Q4`T401lA
20@07A090`0K3`T401T>20@060h9100I40`401XC40@071LD100O6QP3028N6`@09B8O100X9R@402/Z
:@@0;Rl^100a<c8303<f=P@0=SXj100i?Ch403e2A0@0A4]<101@EUL405eRH`<0Jfm^101iNWT408F5
P`@0TY2=102OW9P40:bZYP<0/:bW102]YYl40:jTV`@0[j:H102aXYH40;>QU0<0]J6C102hXY840;ZR
T@@0_J>A5P3oool001@0oooo102mXY040;^QS`@0^:2?0`2fWhl40;>NS`@0/If?102_W9040:fLT0@0
ZY^A0`2VV8l409jAR0@0UXZ1102>PWT408AiL@@0N6iW101[HU`305eDC`@0CdM11012>C@403L]9P@0
<2DM100[7aL302LJ4@@08QD=100N4@X401X>1`@05``5100E2P@301<910@04@T4100A2PH4018<2@@0
4`l<100E4Q0401TF50<071XI100O7ah402<S8`@09RPX100Z;Bd402db<P<0<CHg100e>cd403Y1@`@0
@DU;101;DeD405QOH@@0IVa]0`1eNGT408:5Q0@0T96?102MW9T40:RVXP@0/:fX0`2c[ZP40;>/Y@@0
/jVP102dYid40;FVVP@0]ZFH0`2hY9H40;ZTU0@0_:>C102nXi4F0?ooo`00503oool40;fRT0@0^j6?
102hX8l30;JOS`@0/ij?102aWHl40:nLT0@0[Ib@102ZVi430:JHS`@0WY68102FRX4408j2N@@0Q7Ua
101hKVL406]RG0<0GEA?101?Ad44048i=0@0=bdV100`9Ad402/O5`<09aXA100R5@d401hA2P@06Ph7
100G30D401D:10<04`T4100A2@@4014:1P@04P`9100C3``401DB40@06AHD0`0L6QT401lO7P@08b<S
100V:2P402X];@@0;C8b0`0a=SL403Dk?@@0>T531011BD/404]CE@@0F5mQ101VK6d307EiN@@0PXF4
102@THl409fLV@@0Z:JR102`[JP30;>^Z0@0/jbU102cZJ040;BWW@@0]JJJ102fYIP30;RTUP@0^ZBD
102lXi<40;jSTAH0oooo000D0?ooo`@0_J:@102kXHl40;RPS`<0]Yn?102cWXl40;6MS`@0[ib@102]
W9040:ZKT@<0YYR?102NTHP409J:P@@0SX9i1024NG4407Q^I`@0Jf9L0`1ME4l404m7@@@0@STd100g
;BH4030U7@@0:alG0`0W6Q44028E3@@07Q4:100J3PL401L<1@@05@X40`0C2@@4014910@04@X6100B
30T401<?30@05A8@100I5Q@301`J6@@07alN100S8b<402HX:0@0:Rd]100]<S83034f=`@0=C/m100j
@D<40459B`@0Be=E101HGf4406I/K@<0MGUi1022QH@4092AS`@0WIbI102XYZ840;2]Z0<0/jjX102c
[:D40;>YX0@0]:NM102eYYX40;JUV0<0^:BF102jY9@40;bST`@0_Z>A5P3oool001@0oooo102mXY04
0;^QS`@0^:2?0`2fWhl40;>NS`@0/If?102_W9040:fLT0@0ZY^A0`2VV8l409jAR0@0UXZ1102>PWT4
08AiL@@0N6iW101[HU`305eDC`@0CdM11012>C@403L]9P@0<2DM100[7aL302LJ4@@08QD=100N4@X4
01X>1`@05``5100E2P@301<910@04@T4100A2PH4018<2@@04`l<100E4Q0401TF50<071XI100O7ah4
02<S8`@09RPX100Z;Bd402db<P<0<CHg100e>cd403Y1@`@0@DU;101;DeD405QOH@@0IVa]0`1eNGT4
08:5Q0@0T96?102MW9T40:RVXP@0/:fX0`2c[ZP40;>/Y@@0/jVP102dYid40;FVVP@0]ZFH0`2hY9H4
0;ZTU0@0_:>C102nXi4F0?ooo`00503oool40;jST0@0_::A102jXY430;RQTP@0]Z6C102eXI@40;>R
UP@0/Z:H102aXiT30:fPV0@0YYZC102MTX/409B:P`@0RX5k101oMW0407=ZI@<0IUiI101HD4/404M0
>`@0>C4]100_9B0402PL5`<08QH@100M4@/401P<1`@050T5100A1`<400h50@<02`@1100:108400T5
0`@02`L6100=2`X4010>3P@04a<B0`0G61P401/M7@@07b8R100S9bP402L/;P@0:c8d0`0`=cX403Hn
@0@0?TM:1018DED405ENH@@0I6a^101bN7X307n4Q@@0SI2@102KWI`40:ZZY`@0]K>`102i][830;Ze
[`@0^K:Z102i[ZH40;V/XP@0^JZN102iZ9/30;ZWV0@0_:FF102mYI@40;jTTQH0oooo000D0?ooo`@0
_Z>@102lXY440;ZRT@<0^:6B102fXI<40;FQU0@0/j:F102bXYP40;6SV@<0[J2H102VVY<409fBR`@0
U8Z3102:PG/407mfL0@0LfYU0`1VGUT405Q@B`@0Ad0k100i<Bd402lU80@0:1`G0`0R5Q0401dA2`@0
60`7100D2@D401470`@03PD10`0;104400X40P@02@D3100;1`H400d;2P@040h>100C4a8301LH60@0
6adM100O8R8402<W:0@09b`^100[<S@3030g>P@0=Si0100nAdX404QAE@@0EEiQ101TK6h4079hNP<0
OhB5102=T90409^MW0@0ZZZW102e/k040;Vf/P<0^[F_102i/ZX40;V^YP@0^JbR102iZYh40;VXV`<0
^ZNH102lYIH40;fUU0@0_ZBB5P3oool001@0oooo102nXi040;bRT@@0^Z:A0`2hXI840;JQT`@0]J6D
102cXYH40;:RV0@0/J>I0`2]X9P40:JJT`@0WI:;102DRX<408Z1N`@0OgI`101cJVD306INF@@0F51;
1017@3/403Ta;@@0;bDP100X71L3028F40@07A4;100H30L401@91@@04@L3100>1@4300/40@@02P@2
10091@<400/71P@03@/:100@3Ph401<C4P<05aPH100K7Ad401lR8P@08bLX100W;2h402/b=0<0<3Lj
100f?T0403i7BP@0B55E101EGV4406A/KP@0LWQj0`1oQ8D408f@T0@0VifL102ZZZL40;Fc/0@0^KJb
0`2j]Jl40;VbZP@0^JjV102i[:840;VZWP@0^JRK0`2jYiP40;bUUP@0_JFD102nY98F0?ooo`00503o
ool40;jST0@0_::A102jXY430;RQTP@0]Z6C102eXI@40;>RUP@0/Z:H102aXiT30:fPV0@0YYZC102M
TX/409B:P`@0RX5k101oMW0407=ZI@<0IUiI101HD4/404M0>`@0>C4]100_9B0402PL5`<08QH@100M
4@/401P<1`@050T5100A1`<400h50@<02`@1100:108400T50`@02`L6100=2`X4010>3P@04a<B0`0G
61P401/M7@@07b8R100S9bP402L/;P@0:c8d0`0`=cX403Hn@0@0?TM:1018DED405ENH@@0I6a^101b
N7X307n4Q@@0SI2@102KWI`40:ZZY`@0]K>`102i][830;Ze[`@0^K:Z102i[ZH40;V/XP@0^JZN102i
Z9/30;ZWV0@0_:FF102mYI@40;jTTQH0oooo000D0?ooo`@0_Z>A102mXi840;^TT`<0^ZBE102iYIH4
0;RVV@@0^:NK102hZIl40;V]Y@<0]j^U102^Y9d40:FLU@@0WIB>102DRhD408V0NP@0O7A`0`1_J6@4
065KF0@0DDa:1010>cT4034[:@@09QhK0`0O5Q<401P?30@04PT7100=1@<400X20@@01`400`050004
008000@00P41100410@400L82@@02Pd>100>4A83018F5`@05a`M100L8R<4024W:P@09Rha100/=CP3
03<l@0@0>dA91016Ce@405AMH@@0HV]^101aN7/407n6R0<0SY>C102LWil40:Z/Z`@0][Ne1032`l84
0<K5`P<0`Kbg102o]k040;fcZP@0_K2V102l[J440;b[WP<0_JVJ102mYiP40;jVU@@0_jBB5P3oool0
01@0oooo102nXi440;fSTP@0^jBC0`2jY9D40;VUUP@0^:JI102hYi/40;RYW`@0^JfU0`2gZjD40:jT
W@@0YIbE102MU8h409B;Q@@0RH1j101lM70306mXI0@0HE]H101AC4X4040k>@@0<B/Y100V7Q/301lF
4`@060l<100B2@L400d50`@02P8110070@0300D000@00P0010020@4400@410@01`P9100:3@h400hA
4P<04QHG100G71d401`R8`@08BLZ100V;S4402`e>0<0<ca0100kA4T404I?E0@0E5eQ101RJfh4075h
N`@0OhJ80`2>Ti<409bOW`@0ZZb[102f]kD40<;3`P@0a/G20`31_;L40;ng/0@0_K>Z102m/:H40;b]
X@@0_:^N0`2mZIX40;fWV0@0_ZJE102oY98F0?ooo`00503oool40;jST@@0_J>B102kY9<30;ZTU@@0
^JFF102hYYT40;RWV`@0^:VO102i[JD30;N[Y@@0[ZBM102UW9D409fDSP@0U8^51029P7X407adL0<0
KfQT101QFeP4055<BP@0@3/i100a:bT402HN6`<07aHC100H3``401891`@03@D3100:0P4400L100<0
1@001002000400810@@010@4100720T400X=3P@03Q4B0`0B5QL401LL7@@0728S100Q9bX402H^<@@0
;3Dh0`0c?40403]4B@@0ATmD101DGF44069[KP@0LGQk101oQXP308jCT`@0W9nO102Z[:/40;Jg]@@0
`/?21036aL830<6l]`@0_kN`102m/jX40;f`YP@0_:fQ102lZih30;fYVP@0_JNH102nYYD40;nTTQH0
oooo000D0?ooo`@0_Z>A102mXi840;^TT`<0^ZBE102iYIH40;RVV@@0^:NK102hZIl40;V]Y@<0]j^U
102^Y9d40:FLU@@0WIB>102DRhD408V0NP@0O7A`0`1_J6@4065KF0@0DDa:1010>cT4034[:@@09QhK
0`0O5Q<401P?30@04PT7100=1@<400X20@@01`400`050004008000@00P41100410@400L82@@02Pd>
100>4A83018F5`@05a`M100L8R<4024W:P@09Rha100/=CP303<l@0@0>dA91016Ce@405AMH@@0HV]^
101aN7/407n6R0<0SY>C102LWil40:Z/Z`@0][Ne1032`l840<K5`P<0`Kbg102o]k040;fcZP@0_K2V
102l[J440;b[WP<0_JVJ102mYiP40;jVU@@0_jBB5P3oool001@0oooo102oY9840;jTT`@0_JFE0`2l
YYL40;bXVP@0_:VM102l[:040;f_Y@@0_k>[0`2m]:d40;J]Y`@0[JFO102UWIL409ZDS`@0T8Z61025
OgX307UcK`@0KFMU101OFUP404m:B@@0?SXi100`;2/302<N7@@061<B100?2`X400T410@01P411003
004300000@@0004310000`H4004520@00`P;10063@l400/B5@<03aPK100C720401TR9P@082X^100W
<SL402lj?`<0>D=91014CeD4059MHP@0H6]_101`NG`407n7RP@0SYBF0`2MXZ<40:b_[`@0^[bj1034
aL<40<[:a`@0bLS40`36`[`40<Bl]@@0`[N^1030/jT40;n`Y0@0_jfP0`2oZi`40;nXV@@0_jNF102o
YI<F0?ooo`00503oool40;nTTP@0_ZBC102mYID30;bVU`@0_:RJ102lZId40;b/X0@0_JnU102o/j/3
0;fd[@@0]ZfW102]YIl40:FMU`@0VYB?102@RXH408EoNP<0NG=_101]IfD405mJF0@0CdY9100n>ST4
030/:`<08ahM100H4a8400l;2P@02@@410060@4400<00@<0000110000@<400031P@00@D8100320/4
00H=3`@02a8E0`0?61/401<L80@06B8V100P:Rh402Lb=`@0;cXo0`0i@dT404A?E@@0DUeR101PJfl4
071iO0@0OhN:102>U9H309fRX`@0[:n_102j_;X40<C5``@0b/[71039b<@30<K2_0@0a;be1032]jh4
0<2cZ@@0_k2T102o[J030;n[W0@0_jRI102oYiH40;nUTaH0oooo000D0?ooo`@0_jBB102nY9<40;fU
U@<0_:JG102lZ9X40;bYW@@0_:bP102m[jD40;ncZ`<0_KB]102f[JL40:fUW`@0YIfG102JU8l4092:
QP@0QGmj0`1iLfl406eWI@@0GeYH101?BTT403hj>@@0<2`[0`0S7Qd401PC4P@03`/:100910@400H1
0@@00`010`00004400010`@000<610011@P400<82`@01Pd?100;4QD300lH6`@04a`P100I8RH4020Z
;P@09c8g100_>Sl303U3B@@0A4mE101BGF84061[K`@0L7Ul101oQhX408jDUP<0WJ:S102/[jl40;Zl
^P@0a<G3103:b/L40<W8a0<0a/:l1034_;D40<:g[P@0`;>Y102o/:@40;n]X0<0_j^L102oZ9T40;nW
UP@0_jFC5P3oool001@0oooo102oY9840;nUU0@0_ZNG0`2nZ9T40;jZW0@0_jbP102o[j@40<2cZ@@0
`[N_0`33^[D40<2h/`@0^;2[102_Z:<40:JOV`@0ViFA102@RhL308F0O@@0N7=a101[IV@405eIE`@0
CTY9100o?3/3030^;P@0928R100J61P4018@4P@030/>100820`300H83@@01@X?1005314400D=4`@0
1@lE10084QT400/G7@<041`R100F8bT401`Z<0@08c4g100]>T0403M4BP<0@e1F101AGV<4061/L@@0
L7Yn1021RH`4092GVP@0X:FW0`2_/k@40;k1`0@0b/_;103Ce=<40=GEdP@0clg90`3;a/040<S0^0@0
aKZb1033]Z`40<:bYP@0`JnR0`30[9h40<2ZVP@0`:NG1030YI<F0?ooo`00503oool40;nTTP@0_jFD
102nYiL30;jXV@@0_ZZL102o[:040;n_Y0@0`;>Y1032]jl30<>j]@@0`;Rc102h/:/40:nXX`@0YYnK
102KUI44092;Q`<0QH1m101hLg4406]VI0@0GEUG101>BTT403ll>`<0<2h^100T8R8401XH60@04Q0B
100<2`h400P830<01PP=10052Pl400D<4@@01@dC10053aD400PB6@@02aLM0`0@728401HS:@@072X`
100S<CL402dj@0@0=dA:0`13D5H4055NH`@0H6aa101`NWh40869S0@0T9NJ102PYJL30:nc]0@0_/70
103:bl/40=?Dd`@0eMGB103?cLT30<_6`0@0b<2h1035^[840<>f[0@0`[:V1031[j830<2/WP@0`:ZJ
1030YiL40<2UTaH0oooo000D0?ooo`@0_jBB102oYI@40;jWU`<0_ZRI102nZY`40;n/X0@0_jnT1030
/jT40<:g[`<0`kZe1030^;<40;R`Z`@0[jRS102VWi/409^ET@@0T8^70`25P7d407QcL@@0JfIT101M
FEL404i:B@@0?c`k0`0`;Rh402@R8P@06QPH100B418400`;3P@020P<0`0620d400D:3`@01@`A1005
3A<400D?5@@0218I100;5ad3010L8P@05R<Y100L:S0402<a=`@0;CY0100gA4X304=@EP@0DEiS101P
K744071jOP@0PHV<102@UiX40:2UY`<0[k>d102n`L040<[;b`@0dmCC103EeM840<o=b@<0blK01038
`;P40<Fj/P@0`kJ/1032/ZH40<6_XP<0`:bN1030ZYX40<2WU`@0`:FC5P3oool001@0oooo102oY984
0;nUU0@0_ZNG0`2nZ9T40;jZW0@0_jbP102o[j@40<2cZ@@0`[N_0`33^[D40<2h/`@0^;2[102_Z:<4
0:JOV`@0ViFA102@RhL308F0O@@0N7=a101[IV@405eIE`@0CTY9100o?3/3030^;P@0928R100J61P4
018@4P@030/>100820`300H83@@01@X?1005314400D=4`@01@lE10084QT400/G7@<041`R100F8bT4
01`Z<0@08c4g100]>T0403M4BP<0@e1F101AGV<4061/L@@0L7Yn1021RH`4092GVP@0X:FW0`2_/k@4
0;k1`0@0b/_;103Ce=<40=GEdP@0clg90`3;a/040<S0^0@0aKZb1033]Z`40<:bYP@0`JnR0`30[9h4
0<2ZVP@0`:NG1030YI<F0?ooo`00503oool40<2UT`@0`:JE1030Z9P30<2ZV`@0`:bO1031[j840<:b
Y`@0a;J/1036^k<30<W1^P@0b<6l1031^[D40;Ra[@@0/:VU102XXYh409fHU@<0T8b91023Ogd407Ea
L0@0If=R101IEED404a8B@<0@3dm100d<c@402X[;@@08R@W100K7R8401HJ7P<051TN100B6Ah4010I
7`@03aXQ100?72@4014N9P@0524Z0`0I9bl401h]=@@09S@l100^?D@403Q6C@@0A59I0`1BH6D4061]
LP@0L7^01021RXh409:IW0@0XZRZ102b][L30<;5aP@0cm7B103Jg=/40>3Rh@@0g=gK103DdLd30<o9
``@0bl>k1038_K@40<Jh[P@0a;BX1033/:<30<:]W`@0`J^K1030Z9L40<2VU1H0oooo000D0?ooo`@0
`:FC1030YYD40<2XV0<0`:ZK1030[9l40<6_XP@0`[:W1034]Z`40<Jk/`<0bL6j1038`K`40<6j]@@0
^;6]102`ZJD40:RRWP@0WIRE0`2@S8T408=oO@@0MG5`101WHf8405UEE@@0C4Q90`10?Cd403@c=0@0
:R/]100R92L401/N8P@05QXN0`0D6Ah4018I7P@041TO100?6R4400lL90@04AhV100D8BX301TW;`@0
7Rde100V=3`402hmA0@0>4I=1014DUT3059PI@@0H6eb101`Nh04086:SP@0TYVL102RZ:X40;:f]`<0
`/G6103?dM840=[Lf`@0h>;Q103LgM/40=CAc@<0clW3103;`k/40<Rm]0@0a[R^1034]:P40<>`X`<0
`ZfO1031Zi/40<2XU`@0`:JD5P3oool001@0oooo1030YI<40<2VU@@0`:RH0`30ZY/40<2/W`@0`JnR
1032/ZL40<Bf[0@0a[^c0`39`KX40<S1_0@0`KZe102h/Jd40;2YY@@0Z::N102MV9D3092<R@@0Pgmm
101eLG0406MSHP@0FEEE101<B4T3040m?@@0=3<d100Z:bd4028T9`@06ahR100F6Qh301@I7P@04QTN
100@6Al400lJ8@@03a`T100A7RH401@Q:P<06BL_100N;CD402Hd?0@0;Se4100hATd404ABF@<0DV1U
101PKG84071kP0@0PHZ>102BVI`40::XZP@0/[Jg0`32aLH40<oAdP@0f]cK103Ph^440=cMf`@0e=7=
0`3?bL<40<_3^`@0b;fd1036^:h40<BdZ0@0`k2S0`32[Il40<6[V`@0`:RG1030YY@F0?ooo`00503o
ool40<2UT`@0`:JE1030Z9P30<2ZV`@0`:bO1031[j840<:bY`@0a;J/1036^k<30<W1^P@0b<6l1031
^[D40;Ra[@@0/:VU102XXYh409fHU@<0T8b91023Ogd407EaL0@0If=R101IEED404a8B@<0@3dm100d
<c@402X[;@@08R@W100K7R8401HJ7P<051TN100B6Ah4010I7`@03aXQ100?72@4014N9P@0524Z0`0I
9bl401h]=@@09S@l100^?D@403Q6C@@0A59I0`1BH6D4061]LP@0L7^01021RXh409:IW0@0XZRZ102b
][L30<;5aP@0cm7B103Jg=/40>3Rh@@0g=gK103DdLd30<o9``@0bl>k1038_K@40<Jh[P@0a;BX1033
/:<30<:]W`@0`J^K1030Z9L40<2VU1H0oooo000D0?ooo`@0`:FC1030YiH40<6YV@<0`J^L1032[Z04
0<>aY0@0aKFY1037^Jl40<Vn]P<0cLBm103?bL@40<_6`P@0`[fi102j]K440;6/Z@@0Yj:P0`2JUY@4
08j:R0@0PGil101dLG0406QVI@@0FeYK0`1?Ce4404I6B0@0?Sm1100g>C`4030c=`@0:Rhc0`0V:c04
02DZ<0@08b/a100S;C<402<_=P@09S8j100X=Sh302`j@P@0<D18100iB50404=AF0@0CE]Q101HIV/3
06IbM`@0MH241025SY8409BLW`@0Y:Z/102d^KX40<C8b0<0dmKE103OhN440>W/k0@0j>[Y103NgMX4
0=SDc`<0d/_5103>a;`40<^o]@@0b;Z_1036]JT40<BbY0<0`jjP1032Zi/40<6XU`@0`:JD5P3oool0
01@0oooo1030YI<40<2WUP@0`JVI0`31Zi`40<:^X0@0`k6T1035]JT40<Ni[`@0bKjf0`3=a;d40<o9
a0@0blK21032_KT40;Ze/@@0/JbY102WXZ0309ZFU0@0SXZ81021OW`407AaL0@0J6IU101KFU/304m?
D@@0ATI8100n?d4403Li?0@0<3<g100Z;S<302H[<0@09BX`100S:c4402<]<`@08blf100V<SX402Pf
?P<0;3Y2100a@4P403U8D0@0@e5H101=Ff4405QVJ`<0IW9g101eP8@408F>TP@0U9bO102TZZ`40;Bi
^P@0a<S80`3Ce]D40=oQh@@0jNc/103Xj^T40=kMfP@0f=C?0`3BblD40<k4_0@0bkne1038^Zl40<Je
Z@@0a;:T0`33[Z040<:[V`@0`JRG1030YY@F0?ooo`00503oool40<2UT`@0`:NF1031ZIT30<6[W0@0
`ZjP1033/J@40<FeZ@@0akV_1039_[H30<g4_@@0clW4103;a/840<:m^@@0^[Fa102a[:T40:NRX0<0
VYJD102>RXP4085nO0@0M75`101XIVD405]JF`<0CdmA1016ATP403ho@@@0=cTl100`<cL402X^<`<0
9R/`100U:S0402<[<@@08bdc100S;cH402Hb>P@0:3Hn0`0/>T840350B0@0>DQ@1013DEP404eKH@@0
F6I[0`1VLWL407F0Q0@0QHjB102DW9l40:BZ[0@0];Vj1034b<P30=?Fe@@0gn7Q103Yk>`40>SZj@@0
g]gJ103He<l30=;;a@@0c/Bl103;_kD40<Rj[`@0a[FY1034/Z@30<>^X0@0`Z^K1031Z9L40<2VU1H0
oooo000D0?ooo`@0`:FC1030YiH40<6YV@<0`J^L1032[Z040<>aY0@0aKFY1037^Jl40<Vn]P<0cLBm
103?bL@40<_6`P@0`[fi102j]K440;6/Z@@0Yj:P0`2JUY@408j:R0@0PGil101dLG0406QVI@@0FeYK
0`1?Ce4404I6B0@0?Sm1100g>C`4030c=`@0:Rhc0`0V:c0402DZ<0@08b/a100S;C<402<_=P@09S8j
100X=Sh302`j@P@0<D18100iB50404=AF0@0CE]Q101HIV/306IbM`@0MH241025SY8409BLW`@0Y:Z/
102d^KX40<C8b0<0dmKE103OhN440>W/k0@0j>[Y103NgMX40=SDc`<0d/_5103>a;`40<^o]@@0b;Z_
1036]JT40<BbY0<0`jjP1032Zi/40<6XU`@0`:JD5P3oool001@0oooo1030YI<40<6WUP@0`JZJ0`32
[9d40<>_X@@0aK>V1037]Z/40<Vk/@@0c<2h0`3?a[l40=?<a`@0dlg9103=al@40<C0_@@0^kNd102`
[:X30:JSX0@0W9VG102@SH`408>1P0@0MWAc101ZJFT3061PH@@0F5QJ101@DE<404Q:CP@0@dI9100o
@TH303]0A@@0>Cm5100h@4H403U2B0@0>TA;100lAdh403m;DP<0@e1G101:EUh4055NI@@0FVI/101S
KgD406iiO`<0NhF:102:TYH409VPX`@0Z:j`102h_;d40<S;b`@0emWH0`3SiN@40>kblP@0ko?b103W
inD40=oMf@@0fMC>0`3Dc<D40=35_@@0c<2f103:^jl40<NfZP@0aK:U0`34[j040<>/W0@0`ZVH1031
YY@F0?ooo`00503oool40<2UT`@0`JNF1031ZYX30<:/W@@0`jnQ1035/jH40<NfZ`@0bK^a103<`;P3
0<o6_`@0dlc7103CcLT40<g7a0@0a<2m102k]k@40;2/ZP<0YZ>P102LVIL4092=S0@0Ph60101fM7<4
06YYJ@<0H61Q101HF5X4051AD`@0B4Y>1013ATT403m2AP<0>d15100i?dD403Q0AP@0>D98100jA4/4
03a7CP@0?d]B0`13D5L404YFGP@0DEiU101JIV`406=_M@@0KWUo0`1kQHX408ZBUP@0VJ2S102X[[04
0;Rl_@@0b<_;103GfMP30>?Ui0@0k_;b103_lo840>OWi@@0gmgI103Ie<h30=C<a@@0d<Fm103<`;H4
0<Zk[`@0akJZ1035/ZD30<B_X0@0`jbL1032ZIP40<6VU1H0oooo000D0?ooo`@0`:FC1031YiH40<6Z
VP<0`ZbM1033[j440<FcYP@0akJ[1039^k440<c0^0<0clJo103Cc<L40=?=b@@0cLO41034`;d40;^g
]0@0/:bZ0`2VXj0409bIU`@0T8f<1023PH0407IdL`@0JVUY0`1PH64405QHFP@0D55C1018BTh404=6
B@@0?d960`0k@4D403ToA@@0>416100i@TP403Y4B`@0?4M>100oBe8304=@E`@0BUIN101AGVD405YV
K0@0Hfme101^NGl307^5RP@0RY:F102IX:<40:R^/0@0^;bm1038bl/40=OIf0<0hnGT103^l_840>oc
lP@0inOU103OgMT40=WDcP<0e<c5103@aKd40<c0]P@0b[^_1037]ZX40<FbY@<0a:nP1033[9`40<:Y
V0@0`JJD5P3oool001@0oooo1030YI<40<6WUP@0`JZJ0`32[9d40<>_X@@0aK>V1037]Z/40<Vk/@@0
c<2h0`3?a[l40=?<a`@0dlg9103=al@40<C0_@@0^kNd102`[:X30:JSX0@0W9VG102@SH`408>1P0@0
MWAc101ZJFT3061PH@@0F5QJ101@DE<404Q:CP@0@dI9100o@TH303]0A@@0>Cm5100h@4H403U2B0@0
>TA;100lAdh403m;DP<0@e1G101:EUh4055NI@@0FVI/101SKgD406iiO`<0NhF:102:TYH409VPX`@0
Z:j`102h_;d40<S;b`@0emWH0`3SiN@40>kblP@0ko?b103WinD40=oMf@@0fMC>0`3Dc<D40=35_@@0
c<2f103:^jl40<NfZP@0aK:U0`34[j040<>/W0@0`ZVH1031YY@F0?ooo`00503oool40<2UT`@0`JRG
1032ZYX30<>]WP@0a;2R1036]:L40<Rh[0@0bkbb103>`[T30=78`0@0e]3:103IeM440=KCd0@0cl_8
1036`l040;jj^0<0/k2^102XYJ@409fJV@@0TY2?1026QHD407akN`<0Lg=c101[Jf`406ATIP@0GUiP
101HFUd405AGF`<0DEEI101@EET4051EF`@0DEMM101CFF0405EMH`@0FF5X0`1NIfd406E^M0@0K7Ik
101cOH8407b5RP@0QXjB0`2AVI`409jUY`@0[K:d102m`<440<_>cP@0f=WI103SiN@30?3cl`@0loKf
103/kN/40>KTh@@0gm_F103Jdld30=G<a0@0dLFl103=`;D40<^k[`@0b;JY1036/Z@30<B_X0@0`jbL
1032ZIP40<6VU1H0oooo000D0?ooo`@0`:FC1031Z9L40<:ZVP<0`jfN1034/:840<JdY`@0b;R/103;
_;840<k2^@<0dLS0103Fd<X40=WEd@@0e]?@103?blP40<K3`0@0_[Zh0`2c/:h40:RUY0@0WIZI102B
T8l408J5Q@@0O7]k0`1cLg<406][K0@0I6AV101NGV0405QJG@@0E5MK0`1AEET4051EF@@0D5EK101A
Eed405=IH0@0EEeS101IHFP305iWK@@0IFid101/MW/407=mPP@0O8F:1026SY83096IW0@0WZFW102]
/[@40;g0`@@0blk>103HfMT40>?Ui0<0l??c103cm_H40>c]j`@0i^CQ103OfmH40=[Cc@<0eLc4103A
aK`40<g0]@@0bk^_1038]ZT40<JbY0<0a:nP1033[9`40<:YV0@0`JJD5P3oool001@0oooo1030YI<4
0<6XU`@0`ZZJ0`33[Ih40<B`XP@0a[BW1038^:`40<^l/P@0c/:i0`3Ab<040=K@bP@0fMGA103Fdm04
0<o;b0@0a/?0102n^[P30;>`[P@0Z:FT102MVYT409:@S`@0QXF5101lNg/307=cL`@0Jf]/101TI6H4
05iNH0@0F5YM101DEe/3055EF@@0D5EI101@EE/4055GG@@0DeUP101EGF<405UQJ0<0GVM]101UKW@4
06afN`@0Lgf2101lQHX408J>TP<0TIVL102NYJL40:fb]0@0_L31103;c/h40=SIf@@0hnGT0`3`lo<4
0??fmP@0k>g[103Vi>440=oKeP@0f]?=0`3Ec<@40=75_0@0cL2e103;^jl40<RfZ@@0a[:T0`34[j04
0<>/W0@0`ZVH1031YY@F0?ooo`00503oool40<2UT`@0`JRG1032ZYX30<>]WP@0a;2R1036]:L40<Rh
[0@0bkbb103>`[T30=78`0@0e]3:103IeM440=KCd0@0cl_81036`l040;jj^0<0/k2^102XYJ@409fJ
V@@0TY2?1026QHD407akN`<0Lg=c101[Jf`406ATIP@0GUiP101HFUd405AGF`<0DEEI101@EET4051E
F`@0DEMM101CFF0405EMH`@0FF5X0`1NIfd406E^M0@0K7Ik101cOH8407b5RP@0QXjB0`2AVI`409jU
Y`@0[K:d102m`<440<_>cP@0f=WI103SiN@30?3cl`@0loKf103/kN/40>KTh@@0gm_F103Jdld30=G<
a0@0dLFl103=`;D40<^k[`@0b;JY1036/Z@30<B_X0@0`jbL1032ZIP40<6VU1H0oooo000D0?ooo`@0
`JJC1031Z9L40<>[VP<0a:fN1035/:840<NdY`@0bKR/103<_K840<o2^@<0dlW1103HdLX40=oKe`@0
h^3M103KfMH40=;?c@@0bLO50`30_K`40;Nd/`@0[Z^[102UXZ4409^HV0@0TI2@0`27QXL4081oO`@0
NWUi101dM7D406m`L@@0K6i_0`1[KFl406U/KP@0JFa_101ZKG4406a`M0@0Kg=g101dNGd307YoP`@0
OhF91026S90408fCUP@0UIZM102OY:H30:^^/0@0]kZk1035a/L40=7BdP@0gMkM103Zj^T40?Cdl`<0
m_Of103`lO040>[YiP@0i>7L103OfM<40=[AbP<0eL[2103Aa;/40<jo]0@0bkZ^1039]ZT40<NbY0<0
aJnP1033[9/40<:YU`@0`JJD5P3oool001@0oooo1031YY<40<6XU`@0`j^J0`34[Ih40<F`XP@0akBW
1039^:`40<bm/P@0cl:i0`3CbL440=SAbP@0gm_G103Rh=d40=_IeP@0d/o=1039alD30<2m_0@0]kBc
102^Zj/40:FRX@@0ViRH102AT90308N6Q`@0P7mo101jNGT407AdM@@0Kg1a101/KVl306]]K`@0JFa^
101YK6l406Y]L@@0K71d101_LgL407AiO@<0NWn3101oQHT408J<T0@0SI>F102EVYd409nTYP<0Zjj`
102g^[/40<G6a`@0dM;B103Mg]d40>[Zj@@0m?Cc0`3fmoH40?3al0@0j^WV103ThM`40=oId`@0f]7:
0`3Eb/840=74^`@0c[nd103;^Zh40<VfZ@@0ak:T0`35[j040<>/V`@0`ZVG1031YY@F0?ooo`00503o
ool40<6VT`@0`JRG1033ZiX30<B]WP@0aK2R1037]:L40<Vh[0@0c;fb103?`[T30=?9`@@0f=7:103O
fmL40>;Pg@@0fmWF103Bcld40<W7a@<0`;fl102g];<40:j[Z`@0YJ:Q102KV9P4096@T0<0QhJ71020
Ogl407YiN@@0M7Ae101_L74406a^K`<0Jfe_101YK6h406U/K`@0JVea101/L7@406mcM`@0M7Um0`1j
Oh<407n5R@@0QXb@102=TiH409FJW@@0WjBV0`2[[[040;Nj^`@0aLK7103Ad]840=gNg@@0j^[Y103d
m?<30?KgmP@0l?7`103ZjNH40>CQg0@0gmWC103JdLX30=G:`P@0dLBk103>_k@40<^j[P@0bKJY1037
/Z@30<F_X0@0`jbK1032ZIL40<6VU1H0oooo000D0?ooo`@0`JJC1032Z9L40<>[VP<0a:fN1036/:84
0<NdYP@0b[R[103<_K440=32^0<0dlS0103Hd<T40=kHd`@0iN;O103Wi^@40>3Ng0@0e]CB0`3>b/T4
0<K2`@@0_[^j102f];<40:j/[0@0YZBT0`2NW9`409NEU@@0THn@102<S8`408V9R0@0QXF60`23Ph@4
08:2P`@0PH:31022PhD408B5Q`@0QhV;102;SY0309>EV0@0VifP102PXZ@40:JWZ@@0[Zn`102i^KT3
0<;3`P@0c<c;103GemH40>?Rh@@0k>c[103dmO@40?[mo@<0moWi103_k^/40>SUh@@0hmgG103MeLl4
0=W?a`<0eLVo103A`kP40<jn/P@0bkV]1039]JP40<NbX`<0aJnO1034Zi/40<:YU`@0`JJD5P3oool0
01@0oooo1031YY<40<:XU`@0`j^J0`34[Ih40<J`XP@0akBV103:^:/40<bm/@@0d<:h0`3Cb<040=S@
b@@0g]SC103Uh]l40>OVi0@0h=kL103Fe=830<k:b@@0a/;1102n^kX40;Jd/`@0[Zb/102VY:@309jL
W0@0UiFE102ASi0408b<S0@0RHV81026QHH308>3Q0@0PX:31021PX<408:3Q@@0Q8F71027RH/408^>
T0<0TiFH102KWJ040:2RY0@0YZNY102^[k040;Vi^@<0`/?2103<c</40=OGeP@0hn;Q103/k>/40?Ce
m0@0n_gm0`3gnOT40>o^j`@0j>GQ103SgML40=gEc`@0fLo70`3EbKl40=73^0@0c[jb103;^Jd40<Ve
Z0@0ak:S0`35[il40<B[V`@0`ZVG1031YY@F0?ooo`00503oool40<6VT`@0`ZRG1033ZiX30<B]WP@0
a[2R1037]:H40<ZhZ`@0c;fa103@`[P30=?8`0@0f=39103Nf=<40>GRg`@0inKT103Pg]`40=KDdP<0
c/[91036`/440;jk^P@0][Bc102^[:`40:JTY0<0WYbL102GUID4096?T0@0S8b<1029RHP408J5QP<0
Ph>41022PX<40862P`@0PX>51024QHL408N9R`@0Rhj@0`2CUIP409^MX0@0X::T102VYjT40:j_/0@0
^KVi0`32`l840<c<b`@0emOF103Sh^440>c/j`@0m?Gd103joOd30?Oin@@0knk[103XiN440>?Me`@0
gMG?103IclL30=G9_`@0dL>h103>_[840<^i[@@0bKFX1037/Z<30<F_W`@0a:^K1032ZIL40<6VU1H0
oooo000D0?ooo`@0`JJC1032Z9L40<>[VP<0a:fN1036/:840<NdYP@0b[R[103<_K440=32^0<0dlS0
103Hd<T40=kHd`@0iN;O103Wi^@40>3Ng0@0e]CB0`3>b/T40<K2`@@0_[^j102f];<40:j/[0@0YZBT
0`2NW9`409NEU@@0THn@102<S8`408V9R0@0QXF60`23Ph@408:2P`@0PH:31022PhD408B5Q`@0QhV;
102;SY0309>EV0@0VifP102PXZ@40:JWZ@@0[Zn`102i^KT30<;3`P@0c<c;103GemH40>?Rh@@0k>c[
103dmO@40?[mo@<0moWi103_k^/40>SUh@@0hmgG103MeLl40=W?a`<0eLVo103A`kP40<jn/P@0bkV]
1039]JP40<NbX`<0aJnO1034Zi/40<:YU`@0`JJD5P3oool001@0oooo1031YI<40<:XUP@0`jZJ0`34
[Id40<J`X@@0b;>U103:]jX40<bl/0@0cl6f0`3Ca[d40=S=a@@0gMG>103RgMT40>[Wi@@0jnWX103T
hMl30=_GeP@0d/o=103;bLL40<O4`P@0`Kjl102j]kD30;Ba[`@0[J^Z102XYJD40:BQX0@0X9fM102M
VYX309^HV0@0VYRH102JUiP409ZHV0@0ViZJ102MW9`40::PX0<0YjFT102]ZZT40;Fb/0@0_;Zh1034
`/040<c:b0<0dm7?103Lf]P40>GTh@@0knk/103hmoH40?goo`@0nogm0`3bl_040>cXi@@0i^3K103P
fM840=cBbP@0elc20`3Da[`40=31]@@0cKb`103;^:/40<VdYP@0ak6R0`35[Yh40<>[VP@0`ZRG1031
YY<F0?ooo`00503oool40<6UT`@0`ZRF1033ZYX30<B]W@@0a[2Q1038/jD40<ZgZP@0c;b`103?`KH3
0=?6_@@0f<g5103MeLh40>;Mf@@0j^OU103[jNP40>CQg`<0fmOF103Bcld40<_9a`@0alC21031_[`4
0;Zg]@<0];6_102]ZjX40:RUY@@0Y:6P102PWId409fJVP<0ViRH102JV9P409ZGV0@0VYRH102KVYX4
09fLW0@0XZ2P0`2WYJ@40:fZZ@@0]K:`102l^[P40<C2`0@0c<[80`3CdLl40=cJf0@0iNCQ103_k^`4
0?SgmP@0oOoo103koOd30?;bl0@0k>SU103Vh=/40>3IdP@0g=;:103Gc<830=C6_0@0d<6e103=_;04
0<^hZ`@0bKBV1037/J830<F^WP@0`j^J1032Z9L40<6VTaH0oooo000D0?ooo`@0`JFC1032Z9H40<>Z
VP<0a:fM1036/:440<RcY@@0b[NZ103<_;040<o1]P<0dlJm103HcLD40=gEcP@0h]gI103ZinD40>_Y
j0@0i>7O0`3KemH40=;?c@@0blW71037a<840<6n_0@0^[Ne0`2d/Jl40:f[ZP@0Z:FU102TXJ040:2M
W@@0WIZJ0`2KV9P409ZHV0@0VYNH102JV9P409^JVP@0WIbL102RX:030:NUY0@0[JZY102e/[040;bj
^0@0a<;0103<b/P30=?Ac`@0g=[H103Ui>440>o^k0@0n?Of103mool40?_mo@<0l_;`103/j>D40>KP
f`@0h=WB103Ld/X40=O<`P<0e<Jl103@`KD40<fl/0@0bkR[1039]:H40<NaXP<0aJjN1033ZiX40<:X
U`@0`JJC5P3oool001@0oooo1031YI<40<:XUP@0`jZJ0`34[Id40<J`X@@0b;>U103:]jX40<bl/0@0
cl6f0`3Ca[d40=S=a@@0gMG>103RgMT40>[Wi@@0jnWX103ThMl30=_GeP@0d/o=103;bLL40<O4`P@0
`Kjl102j]kD30;Ba[`@0[J^Z102XYJD40:BQX0@0X9fM102MVYX309^HV0@0VYRH102JUiP409ZHV0@0
ViZJ102MW9`40::PX0<0YjFT102]ZZT40;Fb/0@0_;Zh1034`/040<c:b0<0dm7?103Lf]P40>GTh@@0
knk/103hmoH40?goo`@0nogm0`3bl_040>cXi@@0i^3K103PfM840=cBbP@0elc20`3Da[`40=31]@@0
cKb`103;^:/40<VdYP@0ak6R0`35[Yh40<>[VP@0`ZRG1031YY<F0?ooo`00503oool40<6UT`@0`ZRF
1033ZYT30<B/W0@0aZnP1037/Z@40<VfZ0@0c;Z]103?_k<30=;4^@@0e/[1103Kd<T40>3HdP@0iN3K
103/jNH40>g[j@<0inCR103Pg=/40=WEd`@0e=3?103@cL`40<_8a`<0al?21034_kh40<6l^P@0_KRf
102h/k840;F`[`<0/Zj/102a[:/40;2[ZP@0/:b[102b[J`40;>^[0@0]:n/0`2g/Jd40;^f/P@0_kZf
1035`;`40<c8a0@0eM7>0`3OfmP40>WUhP@0lNk[103imoD40?oooP@0o?km103em?430>k[i`@0j>;M
103Sf]@40=kDc0@0fLg4103Fb;h30=;3^0@0ckjb103<^Zd40<ZfZ0@0b;>T1036/:030<F]W@@0`jZI
1032Z9H40<6VTaH0oooo000D0?ooo`@0`JFC1032Z9H40<>ZV@<0a:bL1036[j040<NbY0@0bKJX103<
^Zd40<no/`<0d/Bi103Fb/440=_@b@@0h=SB103Uh=/40>cYiP@0kN_Y0`3Wi>840>3Lf`@0fMGC103D
d<l40=3=c0@0blS70`37`l840<Bo_P@0`Kbj102m^;H40;Rc/P@0]K2_0`2b[Z`40;6/Z`@0/:^Z102`
[:/40;:][0@0/jj/102d[j`30;Na[@@0^kJb102o^[H40<G0_0@0c<S4103EdLh30=oKf0@0jNGR103a
k^/40?Wgm@@0ooon103lo_d40?Gdl@<0k^_W103Xh]d40>?Je0@0g]C<103IcL@40=K8_P<0d/>h103?
_[840<bj[@@0b[JX1038/j@40<J`X0<0aJfM1033ZYT40<:XUP@0`JJC5P3oool001@0oooo1031YI<4
0<:XUP@0`jZI0`34[9`40<J_X0@0ak:T1039]ZP40<bj[@@0cknc0`3Ba;T40=K:`@@0fm39103Pf=84
0>GPf`@0k>WV103]jnT30>OThP@0h=cK103IeM<40=C@c`@0d<g<103;b<L30<O3`P@0a;nn1031_;X4
0;fh]P@0^;>b102e/:l30;:^[0@0/Jb[102`ZjX40;2/Z`@0/Zf/102c[Z`40;B_[0<0]k6]102k][84
0;nj]P@0aL2l103<b<@40=GAcP<0gm_H103YiN840?7^j`@0nOOe103oooh40?cno@@0mOCa0`3^jnL4
0>SRg@@0hm[D103Ne<`40=W=a0@0e/Rn0`3B`kP40<nn/P@0c;Z]103:]ZP40<RcY0@0a[2P0`35[Id4
0<>ZV@@0`ZRF1031YY<F0?ooo`00503oool40<6UT`@0`ZRF1033ZYT30<B/W0@0aZnP1037/Z@40<Vf
Z0@0c;Z]103?_k<30=;4^@@0e/[1103Kd<T40>3HdP@0iN3K103/jNH40>g[j@<0inCR103Pg=/40=WE
d`@0e=3?103@cL`40<_8a`<0al?21034_kh40<6l^P@0_KRf102h/k840;F`[`<0/Zj/102a[:/40;2[
ZP@0/:b[102b[J`40;>^[0@0]:n/0`2g/Jd40;^f/P@0_kZf1035`;`40<c8a0@0eM7>0`3OfmP40>WU
hP@0lNk[103imoD40?oooP@0o?km103em?430>k[i`@0j>;M103Sf]@40=kDc0@0fLg4103Fb;h30=;3
^0@0ckjb103<^Zd40<ZfZ0@0b;>T1036/:030<F]W@@0`jZI1032Z9H40<6VTaH0oooo000D0?ooo`@0
`JFC1032YiD40<>YV0<0a:bK1035[Yh40<NaXP@0bKBV103;^:X40<fl[`<0d<2e103Da[/40=S;`P@0
g=;:103QfM<40>OQg0@0k^_X0`3_kN/40>WVi0@0hmoM103OfmT40=cHeP@0fMKD0`3Gd]440=?=c0@0
d<[8103?b<L40<g7a@@0b/?10`37`;h40<Jo_@@0a[jl2035_[X40<No^`@0b;nk0`39`K`40<c4_`@0
dLW4103Id</40=oHd`@0in3L0`3_j^D40?Gak@@0noSe103oooh40?gno@@0m_Ga103_jnH30>WRg0@0
hm_D103Oe<`40=[>a@@0elVn103Ca;P30=2o/`@0c[^^103;^:X40<VdYP@0ak6R1036[il30<B/V`@0
`jZH1032YiH40<6UTaH0oooo000D0?ooo`@0`JFC1032YiD40<>YV0<0a:bK1035[Yh40<NaXP@0bKBV
103;^:X40<fl[`<0d<2e103Da[/40=S;`P@0g=;:103QfM<40>OQg0@0k^_X0`3_kN/40>WVi0@0hmoM
103OfmT40=cHeP@0fMKD0`3Gd]440=?=c0@0d<[8103?b<L40<g7a@@0b/?10`37`;h40<Jo_@@0a[jl
2035_[X40<No^`@0b;nk0`39`K`40<c4_`@0dLW4103Id</40=oHd`@0in3L0`3_j^D40?Gak@@0noSe
103oooh40?gno@@0m_Ga103_jnH30>WRg0@0hm_D103Oe<`40=[>a@@0elVn103Ca;P30=2o/`@0c[^^
103;^:X40<VdYP@0ak6R1036[il30<B/V`@0`jZH1032YiH40<6UTaH0oooo000D0?ooo`@0`JFC1032
YiD40<>YV0<0a:bK1035[Yh40<NaXP@0bKBV103;^:X40<fl[`<0d<2e103Da[/40=S;`P@0g=;:103Q
fM<40>OQg0@0k^_X0`3_kN/40>WVi0@0hmoM103OfmT40=cHeP@0fMKD0`3Gd]440=?=c0@0d<[8103?
b<L40<g7a@@0b/?10`37`;h40<Jo_@@0a[jl2035_[X40<No^`@0b;nk0`39`K`40<c4_`@0dLW4103I
d</40=oHd`@0in3L0`3_j^D40?Gak@@0noSe103oooh40?gno@@0m_Ga103_jnH30>WRg0@0hm_D103O
e<`40=[>a@@0elVn103Ca;P30=2o/`@0c[^^103;^:X40<VdYP@0ak6R1036[il30<B/V`@0`jZH1032
YiH40<6UTaH0oooo000D0?ooo`@0`JFC1032YiD40<>YV0<0a:bK1035[Yh40<NaXP@0bKBV103;^:X4
0<fl[`<0d<2e103Da[/40=S;`P@0g=;:103QfM<40>OQg0@0k^_X0`3_kN/40>WVi0@0hmoM103OfmT4
0=cHeP@0fMKD0`3Gd]440=?=c0@0d<[8103?b<L40<g7a@@0b/?10`37`;h40<Jo_@@0a[jl2035_[X4
0<No^`@0b;nk0`39`K`40<c4_`@0dLW4103Id</40=oHd`@0in3L0`3_j^D40?Gak@@0noSe103oooh4
0?gno@@0m_Ga103_jnH30>WRg0@0hm_D103Oe<`40=[>a@@0elVn103Ca;P30=2o/`@0c[^^103;^:X4
0<VdYP@0ak6R1036[il30<B/V`@0`jZH1032YiH40<6UTaH0oooo000D0?ooo`@0`JFB1031YiD40<:X
U`<0`j^J1035[I`40<J_X0@0b;:S103:]JL40<bhZ`<0c[b`103A`KD40=G6^`@0f<_2103MdLT40>;H
dP@0in3K0`3_j^L40?Cak`@0l>cZ103Xhn440>;Mf`@0hMcJ0`3RgM`40>?Mf`@0h]cI103NemD40=_C
d@@0g=?A0`3Me=040=[@b`@0e/_6203DbL@40=?9``@0e<W20`3Eb/<40=O<a@@0g=7:103Rf=440>WO
f@@0knOR0`3fk^T40?[dl0@0oO[h103jnOL40?C`k0@0k^SR103Xh=T30>?Id@@0g]?:103JcL<40=O8
_@@0dl>g103A_k830<jk[P@0c;RZ103:]JH40<RbX`@0aZnO1035[I`30<B[VP@0`jVG1032YiD40<6U
TQH0oooo000D0?ooo`@0`JFB1031YiD40<:XU`<0`j^J1035[I`40<J_X0@0b;:S103:]JL40<bhZ`<0
c[b`103A`KD40=G6^`@0f<_2103MdLT40>;HdP@0in3K0`3_j^L40?Cak`@0l>cZ103Xhn440>;Mf`@0
hMcJ0`3RgM`40>?Mf`@0h]cI103NemD40=_Cd@@0g=?A0`3Me=040=[@b`@0e/_6203DbL@40=?9``@0
e<W20`3Eb/<40=O<a@@0g=7:103Rf=440>WOf@@0knOR0`3fk^T40?[dl0@0oO[h103jnOL40?C`k0@0
k^SR103Xh=T30>?Id@@0g]?:103JcL<40=O8_@@0dl>g103A_k830<jk[P@0c;RZ103:]JH40<RbX`@0
aZnO1035[I`30<B[VP@0`jVG1032YiD40<6UTQH0oooo000D0?ooo`@0`JFB1031YiD40<:XU`<0`j^J
1035[I`40<J_X0@0b;:S103:]JL40<bhZ`<0c[b`103A`KD40=G6^`@0f<_2103MdLT40>;HdP@0in3K
0`3_j^L40?Cak`@0l>cZ103Xhn440>;Mf`@0hMcJ0`3RgM`40>?Mf`@0h]cI103NemD40=_Cd@@0g=?A
0`3Me=040=[@b`@0e/_6203DbL@40=?9``@0e<W20`3Eb/<40=O<a@@0g=7:103Rf=440>WOf@@0knOR
0`3fk^T40?[dl0@0oO[h103jnOL40?C`k0@0k^SR103Xh=T30>?Id@@0g]?:103JcL<40=O8_@@0dl>g
103A_k830<jk[P@0c;RZ103:]JH40<RbX`@0aZnO1035[I`30<B[VP@0`jVG1032YiD40<6UTQH0oooo
000D0?ooo`@0`JFB1031YiD40<:XU`<0`j^J1035[I`40<J_X0@0b;:S103:]JL40<bhZ`<0c[b`103A
`KD40=G6^`@0f<_2103MdLT40>;HdP@0in3K0`3_j^L40?Cak`@0l>cZ103Xhn440>;Mf`@0hMcJ0`3R
gM`40>?Mf`@0h]cI103NemD40=_Cd@@0g=?A0`3Me=040=[@b`@0e/_6203DbL@40=?9``@0e<W20`3E
b/<40=O<a@@0g=7:103Rf=440>WOf@@0knOR0`3fk^T40?[dl0@0oO[h103jnOL40?C`k0@0k^SR103X
h=T30>?Id@@0g]?:103JcL<40=O8_@@0dl>g103A_k830<jk[P@0c;RZ103:]JH40<RbX`@0aZnO1035
[I`30<B[VP@0`jVG1032YiD40<6UTQH0oooo000D0?ooo`@0`:BB1031YY@40<:XUP<0`jVH1034ZiX4
0<F]W@@0aZnP1038/Z<40<ZeYP<0c;RZ103>_:l40=70/`@0e<Bi103HbKl40=c?aP@0h=G=0`3VgMH4
0>cTg`@0lNcX103ak>T40>gVh`@0jN?O0`3XhMh40>SPg@@0imkK103WgMT40>OLf0@0iMWC0`3QeLh4
0=oCb`@0gm;9103MclH40=[<``@0fLc2103Kc/D30=c@a`@0g];9103Sell40>SNeP@0knGO103cj^D3
0?G_j`@0n_Kc103hm?040?3Yi0@0j^;K103Ufm<40>7Ec0<0gLo5103Ib[l40=K5^P@0dl6e103@_K04
0<jj[0<0c;NX103:]:D40<RbXP@0ajnO1035[Id40<B[VP<0`jVH1032Z9H40<6VU0@0`:FB5P3oool0
01@0oooo1030Y9840<6VU0@0`ZRF0`33ZIP40<B[VP@0aJfM1036[j040<RbX`@0b[FV0`3<^:X40<jl
[`@0dL2c103Da;T40=S9_`@0g<o6103PeLd30>KMeP@0k>CO103ak>P40?7/j@@0kNKS103Yhml30>SQ
gP@0j>3M103Wg]/40>OMf@@0imcH103UfM<30>7EcP@0gm?;103Od/T40=g?aP@0f/c3103Ic<840=_>
a@<0g=37103Nd/T40>?Gc`@0j=kF103_iMl40??Zi@<0mNo[103jm_<40?Sdl0@0l>WT103Zh]/40>GK
d`@0hMG<0`3MclD40=W:_`@0e/Fj103C`KD40=2m/0@0c[Z/0`3<]jP40<ZdY@@0b;:R1037[il40<F]
W@@0a:^J0`33ZIP40<:XUP@0`JJD1030YI8F0?ooo`00503oool40<2TTP@0`JJD1032Z9H30<>YV0@0
a:^J1035[Id40<J_X0@0b;:S103:]JH30<bhZP@0c[b_103A`;<40=C4^@@0f<Vo103LclH40>3Ec@<0
i]gF103/i=l40?7/j0@0lNcY103]i^<40>WSg`<0j>7N103Xh=d40>ONf`@0imgI103Wg=P40>GId`<0
hMG>103Odl/40=oBb@@0gLo6103Jc<<40=W<`P@0flk50`3Ld<L40=kBb@@0hmO?103Xg]H40>oUg`@0
ln[U0`3ekn/40?[fl`@0n?C`103`jN@40>[Rf`@0iM_C103QeL`30=g?a@@0fLZo103FaKX40=?1]@@0
d;f`103>^Z`30<bgZ0@0b[BU1038/Z840<N_W`@0aJfM1034ZiX30<>YV0@0`ZRF1031YY@40<2UTQH0
oooo000D0?ooo`@0`:BA1031YI<40<:WU0<0`ZRF1033ZIP40<B[VP@0aJfL1036[ih40<RaX@<0bK>T
103;]ZL40<fiZ`@0ckb_103B`;@40=G5^@@0fLVo0`3MclD40>7Dc0@0i][B103/hm`80?;Yh`<0kN?M
103Yg]T40>[OfP@0j]kI103Xfm@40>GGd0<0h]C=103Re<`40>;CbPP0h]?8103Qd/P40>7Ba`<0h]C9
103Se/d40>CKdP@0j=oG103]iMl40??]j0<0mNoZ103`jN840>[Pf0@0iMW@103PdlT40=c>``@0fLVm
0`3FaKP40=?1]0@0d;f`103>^Z`40<bgZ0@0b[FU0`39/Z<40<N`X0@0aZjN1035[9`40<B[VP@0`jVH
0`32Z9H40<:WU@@0`JJC1030Y98F0?ooo`00503oool40<2TT@@0`JFC1032Yi@30<:XUP@0`jVH1034
ZiX40<F]W0@0aZnN1038/J430<VcY0@0bkJW103=^J/40<nl[`@0d/2d103EaKT40=W9_`<0gLo5103Q
e<`40>KJdP@0k>?L203bjN<30>gSg@@0jMkI103ZgmX40>[Nf@@0j=_D103Uem030>;Dc@@0h]C<103R
dlX80>;Cb0@0hM;8103Qd/L30>;Db@@0hmK=103Tfm840>SOe`@0kNGO103ckNP30?G_jP@0l>WR103Z
h=P40>GId0@0h=?9103Lc/<40=W9_@<0e/Fh103C`K@40=2m/0@0c[Z/103<]jP40<ZeY@<0bK:S1037
/:040<J^WP@0aJbL1034ZiX40<>YV0<0`ZRF1032YiD40<6VT`@0`:BB5P3oool001@0oooo1030Y944
0<6UT`@0`ZND0`32Z9H40<>YV0@0a:^J1035[I`40<J_WP@0b;6Q0`39/j@40<^fY`@0cKV[103?_:l4
0=;0]0@0eLFi103IbKl30=g?a@@0hMC<103Vf]840>cSg0P0l^WS0`3]hmd40>WNf@@0j]oJ103Zg]T4
0>SKe0@0iMO@0`3Re<d40>;Dc0@0h]?:203RdlP40>7Bb0@0hM;70`3Re<T40>?Fc@@0i=_B103XgmL4
0>gUg`@0lngX0`3eknX40?3YhP@0j^3H103UfM040>3Cb@@0g<k3103IbKd30=K5^0@0dl6d103@_K04
0<jj[0@0c;NX103:]JD30<VbX`@0ak2P1036[Yh40<F/W0@0a:^J1033ZIP30<:XUP@0`ZNE1031YY<4
0<2TTQH0oooo000D0?ooo`@0`:BA1031YI<40<:WU0<0`ZRF1033ZIP40<B[VP@0aJfL1036[ih40<Ra
X@<0bK>T103;]ZL40<fiZ`@0ckb_103B`;@40=G5^@@0fLVo0`3MclD40>7Dc0@0i][B103/hm`80?;Y
h`<0kN?M103Yg]T40>[OfP@0j]kI103Xfm@40>GGd0<0h]C=103Re<`40>;CbPP0h]?8103Qd/P40>7B
a`<0h]C9103Se/d40>CKdP@0j=oG103]iMl40??]j0<0mNoZ103`jN840>[Pf0@0iMW@103PdlT40=c>
``@0fLVm0`3FaKP40=?1]0@0d;f`103>^Z`40<bgZ0@0b[FU0`39/Z<40<N`X0@0aZjN1035[9`40<B[
VP@0`jVH0`32Z9H40<:WU@@0`JJC1030Y98F0?ooo`00503oool40<2TTP@0`JFB1031YY<30<6VU0@0
`ZNE1033Z9L40<>ZV0@0a:^J1035[9`30<J^WP@0ak2P1039/Z840<ZdY@@0c;NX103>^Z`40=6m[`<0
dl2d103Fa;P40=W8_@@0gLg2103PdLH40>;Db@<0i]S=103Wf/l40>KHcP@0iMK=103Uelh40>CEc@<0
hM79103Nc/D40=c<`P@0g<c0203Mc<040=g<`@<0g<c0103Ncl<40>CGc@@0j]kF103Yg]D40>GIc`<0
h]G;103PdLH40=c<`@@0fLRk103F`kL40=?0/P@0dKf_0`3?^Z/40<fgZ0@0bkFU1039/j<40<RaX@@0
ajnN0`36[Id40<F/V`@0a:^I1033ZIP40<>XU`@0`ZNE0`31YY@40<6VT`@0`JFB1030Y94F0?ooo`00
503oool40<2TTP@0`JFB1031YY<30<6VU0@0`ZNE1033Z9L40<>ZV0@0a:^J1035[9`30<J^WP@0ak2P
1039/Z840<ZdY@@0c;NX103>^Z`40=6m[`<0dl2d103Fa;P40=W8_@@0gLg2103PdLH40>;Db@<0i]S=
103Wf/l40>KHcP@0iMK=103Uelh40>CEc@<0hM79103Nc/D40=c<`P@0g<c0203Mc<040=g<`@<0g<c0
103Ncl<40>CGc@@0j]kF103Yg]D40>GIc`<0h]G;103PdLH40=c<`@@0fLRk103F`kL40=?0/P@0dKf_
0`3?^Z/40<fgZ0@0bkFU1039/j<40<RaX@@0ajnN0`36[Id40<F/V`@0a:^I1033ZIP40<>XU`@0`ZNE
0`31YY@40<6VT`@0`JFB1030Y94F0?ooo`00503oool40<2TTP@0`JFB1031YY<30<6VU0@0`ZNE1033
Z9L40<>ZV0@0a:^J1035[9`30<J^WP@0ak2P1039/Z840<ZdY@@0c;NX103>^Z`40=6m[`<0dl2d103F
a;P40=W8_@@0gLg2103PdLH40>;Db@<0i]S=103Wf/l40>KHcP@0iMK=103Uelh40>CEc@<0hM79103N
c/D40=c<`P@0g<c0203Mc<040=g<`@<0g<c0103Ncl<40>CGc@@0j]kF103Yg]D40>GIc`<0h]G;103P
dLH40=c<`@@0fLRk103F`kL40=?0/P@0dKf_0`3?^Z/40<fgZ0@0bkFU1039/j<40<RaX@@0ajnN0`36
[Id40<F/V`@0a:^I1033ZIP40<>XU`@0`ZNE0`31YY@40<6VT`@0`JFB1030Y94F0?ooo`00503oool4
0<2TTP@0`JFB1031YY<30<6VU0@0`ZNE1033Z9L40<>ZV0@0a:^J1035[9`30<J^WP@0ak2P1039/Z84
0<ZdY@@0c;NX103>^Z`40=6m[`<0dl2d103Fa;P40=W8_@@0gLg2103PdLH40>;Db@<0i]S=103Wf/l4
0>KHcP@0iMK=103Uelh40>CEc@<0hM79103Nc/D40=c<`P@0g<c0203Mc<040=g<`@<0g<c0103Ncl<4
0>CGc@@0j]kF103Yg]D40>GIc`<0h]G;103PdLH40=c<`@@0fLRk103F`kL40=?0/P@0dKf_0`3?^Z/4
0<fgZ0@0bkFU1039/j<40<RaX@@0ajnN0`36[Id40<F/V`@0a:^I1033ZIP40<>XU`@0`ZNE0`31YY@4
0<6VT`@0`JFB1030Y94F0?ooo`00503oool80<2TT@@0`:BB0`31YI840<6UT`@0`JJC1032YY@40<:W
U@@0`ZRF0`33ZIL40<BZV0@0a:^I1035[9/40<J]W0@0ajnN1038/:030<ZbXP@0bkBT103=]ZH40<jh
Z@@0d;Z[103A_:`30=:m[P`0dkj_103C_k040=C0/@<0el>d103HaKD40=W5]`@0fLFh203Ia[P40=[7
^@<0f/Rk103KbK`40=S5^0@0eL6d103D`;840=>n/0<0dKb]103@^Z/40<jhZ0@0c;FV103;/j<40<Vb
X@@0b;2O0`37[ih40<J]W0@0aJbK1035ZiT40<BZV0@0`jVG0`33Z9H40<:XU@@0`ZNE1032YY@40<6V
T`@0`JFC0`31YI840<2TTPP0`:BA5P3oool001@0oooo2030Y9440<2TTP<0`JFB1031YI<40<6VT`@0
`ZJD1032YiD40<:XUP<0`jVG1034ZYP40<B[V@@0aJbK1036[I`40<N_WP@0b;2P0`3:/Z840<^dY0@0
cKJV103>^:T40=2jZ`@0dKb/0`3B_Jh<0=>n[`@0dkn`103D`;430=O3]0@0f<Fe103IaKL40=W5^0P0
fLJh103JakT30=[8^`@0flVl103HaKP40=G1]0@0e<2b103C_[030=6l[@@0d;Z[103>^:P40<beYP@0
bk>S1039/Z440<R`W`<0ajnN1036[I`40<F/V`@0aJ^I1034ZYP40<>YU`<0`jRF1032Z9D40<:WU@@0
`ZJD1031YY<40<6UT`<0`JFB1030Y9880<2TTAH0oooo000D0?ooo`P0`:BA1030Y9830<6UTP@0`JFC
1031YY<40<:VU0@0`ZNE1032Z9H30<>YU`@0a:ZH1034ZiT40<F/V`@0aZfL1037[ih40<R`X0<0b[:R
103;]:@40<ffYP@0c[RY103@^Z/40=6l[0<0d[f^303C_Zl40=>o/0@0e<2a0`3G`k@40=S5]@@0fLFg
103IaKP80=W6^0@0f/Ni0`3Jb;/40=_9_0@0f<Fh103E`K@40=C0/P@0dkj`0`3A_:d40=2jZ`@0c[RX
103<]JH40<^cX`@0bK:Q1038/9l30<N_WP@0aZfL1035[9/40<F[V@@0a:ZH1033ZIL30<>XUP@0`ZRE
1032YiD40<:VU0@0`JJC1031YI<30<6UTP@0`:BB2030Y94F0?ooo`00503oool80<2TT@@0`:BB0`31
YI840<6UT`@0`JJC1032YY@40<:WU@@0`ZRF0`33ZIL40<BZV0@0a:^I1035[9/40<J]W0@0ajnN1038
/:030<ZbXP@0bkBT103=]ZH40<jhZ@@0d;Z[103A_:`30=:m[P`0dkj_103C_k040=C0/@<0el>d103H
aKD40=W5]`@0fLFh203Ia[P40=[7^@<0f/Rk103KbK`40=S5^0@0eL6d103D`;840=>n/0<0dKb]103@
^Z/40<jhZ0@0c;FV103;/j<40<VbX@@0b;2O0`37[ih40<J]W0@0aJbK1035ZiT40<BZV0@0`jVG0`33
Z9H40<:XU@@0`ZNE1032YY@40<6VT`@0`JFC0`31YI840<2TTPP0`:BA5P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
09/0oooo0T0000230?ooo`00W@3oool00d000000oooo0?ooo`200?ooo`00M`3oool5@00000030?oo
od000010000000@0oooo00=000000?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=00000
1@3oool00d000000oooo0?ooo`1j0?ooo`00N@3oool00d000000oooo0?ooo`030?ooo`06@000003o
ool0oooo@000003ooom000002`3oool01T000000oooo0?oood000000oooo@00000@0oooo00A00000
0?ooo`3ooom00000PP3oool007T0oooo00=000000?ooo`3oool00P3oool00d000000oooo0?ooo`03
0?ooo`03@000003oool0oooo00T0oooo00E000000?ooo`3ooom000000?ooo`03@0000080oooo00A0
00000?ooo`3ooom00000PP3oool007T0oooo00=000000?ooo`3oool00`3oool00d000000oooo0?oo
o`02@00000d0oooo0d000000103ooom00000@000040000030?ooo`=00000PP3oool007T0oooo00M0
00000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?ooo`3oool03P3oool00d000000
oooo0?ooo`2:0?ooo`00N03oool2@00000@0oooo00A000000?ooo`3oool0oooo0d00000=0?ooo`90
0000S03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(180) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
988F8C988F8C988F8C988F8C988F8C988F8C988F8C988F8C978F8C978F8C978F8C978F8C978F8C\
978F8C978F8C978F8C968E8C968F8C968F8D968F8D968F8D968F8E96908F969191
958F8E968E8C968E8C968E8C968D8B968E8B968E8B968E8B968E8C978E8C978E8C978E8C978E8B\
978D8A978D8A968C89968B88968A87958A87958986958885958884948783938581
91827E938682948784958885958986958A87968A87968B87968B88968C89978C89978D8A978D8A\
978D8B988E8B988E8C
988F8C988F8C988E8C988F8C978F8C978E8C978F8C978F8C978E8C968E8C968E8C968E8C968E8D\
958E8D958E8D958E8D958E8C948E8D948E8D948E8D938F8E938F8F939090949293
938F8F938E8D938D8B948D8B948C8B948D8B958D8B958D8B948D8B958C8B958C8A958C8A958C8A\
958B88958A8794888694878493868392858192838092827E91807C907E7A8E7D77
8D7B768F7E7990807C91827E92847F928581938682938783948784948885958986958A87968B88\
978C89978D8A988E8B
988F8C988F8D978F8C978E8C978F8D978F8C968F8C968F8D968E8C958E8D958E8C958E8D948E8D\
948E8D948E8D938E8D938E8D928E8D928E8D918E8E918E8E918F8F909091909193
908E8F908D8D918C8B918C8B928B8A928B8A938C8B938C8B928C8B938C8B958B8A958B89958A88\
94898794888693858392838090817E8F7F7C8E7E7A8E7B778D79748B77718A746D
8A756F8B78728C7A758D7C778E7E798F807B90817D91827E928480928581938783948885958986\
968B88978C89978D8B
988F8C988F8D978F8D978E8C968F8C968F8D968F8D958F8D958E8D948F8D948E8D938E8D938E8D\
928E8D928E8D918E8D918E8D908E8D908D8E8F8D8E8E8E8E8E8E8F8D8F918E9093
8D8D8F8D8C8C8E8B8B8E8A8A8F8A8A908B8A928B8B938C8C938D8D938E8C958C8C948A89948987\
94878593858392828090807D8F7D7A8D7B778B78748A757089726D876F68856B63
866E6787716B89746E8A76718B79738C7B768D7D788E7F7A8F807C90827E918480938682948884\
958986968B88978D8A
988F8C978F8D978F8D968F8D968F8D958F8D958F8D948F8D948E8D938E8D938E8D928E8D928E8D\
918E8D908E8D908E8E8F8D8E8E8D8E8E8D8E8D8D8E8C8D8E8B8D8F8A8D908A8F92
8A8C8E8A8B8B8B8A898C89898D89898E89898F8A89908B8A918C8B918C8B928C8B928A89928886\
92868392838191817E8F7C798D79758B767288736E866F69856B6583686181645C
826860846B64856E6786716A88736D8976708A78738C7B768D7D788E7F7B90817D918480938682\
948885958A87978D8A
988F8C978F8C978F8D968F8D958F8D958E8D948E8D948E8D938E8D928E8D928E8D918E8E908E8E\
908E8E8F8E8E8E8D8E8D8D8E8C8D8E8B8C8E8A8C8E898B8D888B8D868B8E868B8F
868A8C87898A8888898988878A87878B87878C88878D88888E88888F89898F89889088878F8583\
8F83818E807D8E7D7A8C79768A747088716C856D6882696381655E7E61597E5F57
7F625A80655D826861836B64846E6886716B87746E8977718B79748C7C778E7F7A90817D918480\
938783958986978C89
988F8C978F8C968F8D968F8D958E8D948E8D938E8D938E8D928E8D918E8E918E8E908E8E8F8E8E\
8E8E8E8D8D8E8D8D8E8C8D8E8B8C8E898C8E888B8E868A8D84898C82878A818689
8387898487888586878686868786868885868985858A86858A85858B85858B84848C83838C8180\
8C7F7D8B7C798A797589747187706C846B668167617F635C7D5E567959507A5A50
7B5C547C5F577E635B7F665E816962836C6685706986736D8876708A79748C7C778E7F7B90827E\
928581948885968C89
988F8C978F8C968F8D958E8D948E8D948E8D938E8D928E8E918E8E908E8E8F8E8E8F8E8E8E8E8E\
8D8D8E8C8D8E8B8D8E8A8D8E898C8E888C8E868B8E858A8D81888B7A82867D8487
808587818587838586838485848384858484868383868282878282878181888080887E7E877C7B\
87797886767486747184706C826B668067617E625B7A5D5578584F75524776544A
77564D7959507A5D547C60587E645C806860826B65846F6986726D8876718A7A758D7D798F817D\
918480948884968B88
978F8C978F8D968F8D958E8D948E8D938E8D928E8D918E8E908E8E8F8E8E8E8E8E8E8E8E8D8D8F\
8C8D8F8B8D8F8A8D8F888C8F878C8F868C8E858B8E848B8E828A8E767F847B8286
7E83857F8485808384818384828282828182838182848081847F80847E7E847B7C847879837676\
83747382716F816E6C806B677E66617C625C7A5C5576564E735147704A3F724D42
73504575534976574E785B527A5F577D635B7F6760816B64846F6986736D8977728B7B768E7F7B\
90837F938783968B88
978F8C968F8D958F8D948E8D938E8D928E8D918E8E908E8E8F8E8E8E8E8E8D8E8F8C8E8F8B8D8F\
8A8D8F898D8F888D8F878C8F868C8F858C8F848B8F848C8F80898C7B84877B8386
7C82857D82847E81827E81827F80817F7F80807F80817F7F817E7E817C7C817879817576807172\
7F6E6E7E6C6A7D69677B656279615C785C5776585173524A704C426D44396D4539
6F493E714D4272514775554C775951795E567C625B7E6760816B6584706A87746F8A79748C7D79\
8F827E928682958A87
978F8C968F8D958F8D948E8D938E8D928E8E918E8E908E8E8F8E8E8D8E8F8C8E8F8B8E8F8A8D8F\
898D8F888D8F878D8F858C8F848C8F838C8F828B8F808A8E7E888C7C85897B8386
7B82847B81837B80817C7F7F7C7E7F7D7E7E7D7D7E7E7D7E7F7D7E7F797A7F75777E71737D6D6F\
7C696A7B676779646277605E755C5873585272534C704E466D483E6A4035683D31
6A42366C463B6E4B40714F4673544B765951795E567B635C7E6861826D6785726C8877728B7B77\
8E807C928581958A87
978F8C968F8D958F8D948F8D928E8E918E8E908E8E8F8E8E8E8E8F8D8E8F8B8E8F8A8E8F898D90\
888D90868D90858D90848C90828C90818B90838D927D888C7C868A7B85887A8386
7A8284798182797E80797D7D797C7C7A7C7C7A7C7C7B7B7C7D7E7E7D7B7C7D78787C74747B7070\
79696978646475605F735C5A7158556F544F6D50496C4B436A463C68403465392D
65392C683F336A44396D4A3F6F4F4572544B755A51785F577C645D7F6A63836F698675708A7A75\
8D7F7B918481958A86
978F8C968F8D948F8D938F8E928E8E918E8E8F8E8E8E8E8F8D8E8F8C8E8F8A8E90898E90888D90\
878D90858D90848D90828C90818C907F8B90758388788589798589798487788386
788285788183777E7F767B7C767A7B767A7B777B7B787B7B7A7D7D7B7F7E7B7C7B7B7A797A7674\
776D6B756564725E5E6F59576D55526B514B694D4669494168453B663F34643A2D
62352864392C663E326844396B493F6E4F4672554D755B5379615A7D6760816D6785726D897873\
8C7E79908380948986
978F8D968F8D948F8D938E8E918E8E908E8E8F8E8F8D8E8F8C8E8F8B8E90898E90888E90878E91\
868D91848D91828D91818C917F8B917E8B90758389768489768488768387778487
778386778183757E7F73797A73787A73787A717879777F7F7A7F7F7D82827D81807C7B7A7A7977\
777371736B696D5F5E6B5655685250674E49664A4466473F65443A643F3462392D
5F33265F322561382B643E3267443A6A4A416E504872574F765D567A645D7F6A6483706B877672\
8B7D7890837F948985
978F8D958F8D948F8D928E8E918F8E8F8E8F8E8E8F8C8E8F8B8E908A8E90888E91878E91868E91\
858E92838D92818D917F8C917E8D9372838A738389748389758489758286768487
778588778386758081727B7B6E7778768080757F7F7781817981817A80807C82817D7F7D7E7C7B\
7C777578716F6D6462665755644F4D634B4762474163453E63433A623E3460392D
5E34275C30225C32265E372C623E3466453B6A4C436F534B735A5378615A7D6861816E69867570\
8A7B778F827E948885
978F8D958F8D938F8E928F8E908E8E8F8E8F8D8E8F8C8E908A8E90898E91878E91868E92858E92\
848E93828E93808D927D8B917D8C936C7F87708188728388738489748488758588
76868A7786897684857782826F787872797A747B7B757B7A767D7C787D7B797C7B7977767A7674\
7B74707C7370776B686B5E5C604F4D5E47445E443F60433C614239613E345F392E
5D33275B2F20592F215931255C372D61403666483F6C4F4771574F765E577B655F806C6785736E\
897A768E817D938885
978F8D958F8D938F8E918F8E908E8F8E8E8F8C8E8F8B8E90898E90888E91868E92858E92848F93\
848F94838F94808E9377878D75868D6F80886F8288718288728288728388748589
76888C77878B78898A7A8989748383737E7F737D7D737B7B747B7B767A7A767A79767573777270\
766E6B776E6B76686472625E6555515B46425B423E5D413A5F41385F3E345D392E
5B34285A2F21582E1F572F225732285D3B3163433A684C436E534C735B5479635C7E6A6583726D\
8879758E807C938884
968F8D958F8D938F8E918F8E8F8E8F8D8E8F8B8E8F8A8E90888E91868E91858E92848E93838F94\
83909584929786949B7B8C926F838A70828A6F82896F838970828970838972858A
74878C748588728183738284728282728181738080738080748180767F7E767E7C767B79767773\
74706D746D6973686371615D6B5A555E4A4659413D5B403A5D40385E3E345D392E
5A3428592F22552A1C4E271A532E2359362C5F40366548406B504971595276615A7C686382706B\
8778738D807C938784
968F8D948F8D928F8E908F8F8E8E8F8C8F908A8E90898E91878E91858E92838E92828E93828F94\
8290968594998B999F85949975878E70838A6E82896D83896E82896E828970858A
72878C7285896E7E816E7D7F6F7E7F6F7E7F707E7F717E7F727F7F737E7E737C7B737977727572\
71716E6F6D686E69646D645F6B5E5864544E5C47425A423B5C40395D3E355C3A30
5A352A593125592F224A24184E2A1F5533295C3C3362453C684E466E564F745E587B6761806F6A\
8677728C7F7B928784
968F8D948F8D928F8E908F8F8E8E8F8C8E908A8E90878E91858D91838D92828D92808D937F8E94\
7F8F958091977F8F967B8C9373868E6E82896B80886B81886B82886C82896D848A
6F858B6F84886C7E816A797C6B7A7B6C7B7D6D7C7D6E7C7D6F7E7E717D7D717A7A7076756F7371\
6E6F6C6B6A67696561685F5B655A5461524C5D4A455B453E5B423A5C3F365B3A31
59362B5933265830224722174B271D5130265839305F4239664B436C544D735C5679655F7F6D68\
8576718C7E7A928783
968F8D948F8E928F8E908F8F8D8E908B8E90898E91868E91848D92828D927F8C927D8C937C8C93\
7A8C93788C9476899072848C6E8088697E87687D85687E85687F86688087698188
6B83896B81876A7E8268787B68777969787A6A7A7B6C797B6D7B7C6E7C7C6E797A6E75756D7070\
6C6D6B69686566635F645D5A6258535F524C5C4A455B46405A433C5B40375A3B32
5A372D5A35285B32244520144623184E2C2255362C5C3F376349416A524A715B5477635E7E6C67\
8575708B7E7A928683
968F8D948F8E928F8F8F8F8F8D8F908A8E91888E91858D91828D92808C927D8C927A8B92788A92\
76899273879070848D6C8088697C84667B83657A82647A82647C83657D84657E85
668086677F85677D8265787C64747766767867797B69797B6B797B6C7A7C6C78796C75756A706F\
696C6B66666463605E605B585F57535D524E5B4C475A484259443D594038593C33
59382E5A362A5E3527492317421E134A281E5233295A3D3461463E6850496F595276625C7D6B66\
84746F8A7D79918683
968F8D948F8E918F8F8F8F908C8F908A8E91878E92848D92818D927E8C927A8B92778A92748891\
7187916D828C6A7F8865798363788161788061777F60777F617880617A82617A82
627C83637C83637B8162777C61737762747764767866767968777A6A787A6A7678697273676E6E\
656A69626463605F5C5C59565B54515A504D594C4858494357453E574039573C34
57392F59372B5F382B562E20472115452218503027583B325F443C664E476D575174615B7B6A65\
83736F8A7C78918682
968F8D948F8E918F8F8F8F908C8F91898F92868E92838E937F8D937C8C93788B92748992708791\
6C838E677D886378835E747E5B747E5C747D5C747D5C747D5C757D5D767E5D767F
5D777F5E777F5F777D5F757B5E7377607376617477637477657578677578677476666F71646B6C\
6166675E62615B5C5B595654575350564E4B564B4756474255433D543F38543B33
54372E55342A573429563024522B1E4C291F5030275639315D423B644C456B564F725F5A7A6964\
82726E897C78918582
968F8D948F8E918F908E8F918C8F92898F92858F93828E937E8D937A8C93768A937189926C8792\
67828E627C875C737F59707A57707A57717B58717B58717B58727B58727B59727B
59737B5A727B5A72795A70775A6F755C70765F7377617377637578657578657375636E7061696B\
5D64655B5F60585A5A55555454514F524D4A534A4652464251423D503E38503933
4F352E4F31294F30264D2A1F4A24184B281E4E2F2554372F5B4139624A4369544E715E58796863\
80716D887B77908582
968F8D94908F9190908F90918C9092899093858F94818E947D8D94798C94748B946E8892688590\
61808B5A7884546F7B516B77516C77526D78536E79546F79546F78546F78546F78
546E77546D76546D75556B73566B71586D735B70745E7276617478637478647174626D705F686A\
5B6364575D5E545757515252504E4D4F4B494E48454E45414D413C4C3D374B3832
4A342D492F27492D2547261C4320154523194B2B2251352D583E375F484267524C6F5C57776662\
7F706C887B77908581
968F8E94908F9190918F91928C9193899194859095818F967D8E96788D96738B956C899564828D\
5979864F707D4968764967744B68744D6A754F6B76506C77516D77516D77506C76
4F6B754E69734F68714F677051686E546A70586D725B70755E73776174786271745F6C6F5C6668\
596062545A5C5055564E50504C4C4B4B49474A46444A434049403C483C37463731
45322C432D26422A224022193F1E14401D1346281F4D322A543C355C464065504B6D5B56756561\
7E706C877A76908481
96908E9490909291928F92938C92958992968691978190977D8F97788E97728D986D8C9864838F\
557684486B7A3D61704162704565724867744B69754D6B764E6C774E6C764C6B75
4B697449667048636D49626B4C636B4F666D546A70596E745D72775F73776070745D6B6E5A6567\
555E6051585A4D53544A4E4E474A4A46464545434145403E443D3A433A35423631
40312B3E2B253D2922391F17381C133A191041241C492F2851393359443E624F496B5955746460\
7D6F6B8679768F8481
97908E9591909392929093948D93968A93978693988292997D9199778F99728E996E8D9A688694\
577785456978375D6E3B5E6E4062704465724868754B6A764B6A754B6A75486772
45657043626E425F6B445E68465E674B616951676E576D735C72775F73785F70745C6B6E596567\
535D604E57594A5253464C4D434848424444414040413E3C413B393F38343E3430
3C302A3A2B26382722321D1730171033150D3C211A442C254D373156423D5F4D4868585372635F\
7B6E6A8579758F8481
97908F9592919493949194968F95988C959A88959B83949B7D929B77909A718E9A6C8B97658492\
5274833F667630596B365C6C3B606F4063714568754B6C784E6E7A4E6E794C6C77
4567733F626E3D5E6A405E68425C65465D654F666D556C735B72785F74795F71765C6C6F586567\
525D5F4F585A4A5254454C4D4046473E42433C3E3E3C3C3B3D3A373C36333A332F
382F2A372B263527222F1F192B15102D120B361E183F292449352F52403B5C4B4766565270625E\
7A6D698478758E8481
97918F96929295949593969891979A8E989C8B989E86979E7F949D76909B6E8D9A6A8995688592\
5476853E65762C5669325A6C385F6F3D6271436775496C7950717E54747F587580
51707B48697542646F42646E46636C49626A4F676E556D745B737A5F757B6072785D6C71596669\
505B5E4E575A485153414A4C3B43453A4041373C3D3839393937363A353338322E
352E2A332A26302521271C1824140F27100B311C163A272244322D4F3E395949456355516E615D\
796C698378758E8380
98918F979393969696959899949A9D929B9F8F9CA28A9BA28298A176919C64849263839162818E\
5274833B64762854682F586B355D6E3B6171406574466A774D717E5274805A7883
5B788356747F4F6D774969734966704B656E506870556D755B737A60767C62757A617075606D70\
586265535D604C5658404B4F3C454838404233393C34373836353539353337322F
342E2B322A262B24202018151A0F0C200D092B1814352420402F2C4B3B385647446153506C5F5C\
776B688277748D8380
989290989494989898989A9C979DA0969FA394A1A791A2A98AA0A87C97A26687955A7D8B577A89\
4A6F803862742653672D576A335C6D3961723E6373436775496D7B4F7380547683
54768253737F4F6F7B4B6A764A68724C6871506A72566F765C747B60767D63767C637377616F71\
60686A6066675E62624D5457474C4E4347493A3F41393C3D3939393A3735383331
35302D322B2827211F1B1614130A081808042414112F201D3B2D2A4739365246435E524F6A5E5B\
766B688177748D8380
9993919A96959A9A9A9B9D9F9BA0A39BA4A89BA7AC9AABB19BB0B888A1AA75949F638592587B8A\
476E7F3761742552672B5669315B6D3862723E6676426877456A78496E7C4C717F
4D72804C707D4A6D7A486A764867734C6A74516C755670785C747C61767D63777D637278616E72\
5E696B6067686467675D60605557574E4F504547484041423D3C3C3B39383A3533
37312F342E2B25211F1815140F0A091204021D100E291D1B362A284337344F44415C514E685D5B\
746A678076748C8380
9A93919B97979C9C9C9DA0A19FA4A7A0A9ACA1ADB2A3B3B9A7BAC193AAB37E9AA56C8C995C7F8D\
4870813561742453682754682F596C355F703D6676456C7C49707E4D72804F7583
5378865377845174824E717D4D6D794E6D77526E7856717A5B747C60767E64787E64747B606D73\
5C676C5B65675B6163585E5F56595A505353474B4C4345453F3F3F3D3B3B3A3736
393331342E2C2321201414150F0D0C0C0201160C0B2319183127253F35334C4240594F4D665C5A\
7369678076738C8280
9A94929C99989E9E9EA0A2A4A3A8AAA5ADB1A8B3B8ABB9BFB0C1C89FB3BB8AA2AC75939F618391\
4B72833662752554692553672B5769325C6D396272406979476F7E4D74824F7785
5279885379875378865075824F707D4F6F7A52707A55727A5A747C5F767D64797E697A7F67757A\
606B71596468545D62525A5D5156594D5153484B4D4446474141413E3D3D3E3939
3C3635342E2C2221210F13140B0B0C0600000903031C15142C24233B333249413F574E4D655C5A\
7269677F76738C8280
9B94939E9A99A1A0A0A3A5A6A6ABADAAB1B4ADB8BCB1BFC4B6C7CDA7BAC293AAB47E99A5698997\
50768739647727566B2452662854672E596A355E6E3B6373416878456D7C497080
4B73824C73824D73824D72804D717E4E6F7B51707A54717B58727B5C737B61757C66777D6B787C\
6B7479676E725C6468535B5E4D54584A5053474B4D444748424343424040413D3C
413A39332F2E2221220F1417060B0D06040505010317121328222238313147403F564E4D645B5A\
7168677E75738B8280
9C95939F9B9AA3A1A1A6A8A9AAAEB0AEB5B8B2BCC0B7C3C8BDCCD1AEBFC69CB1BA859FAA6F8E9B\
567B8B3E687B29586D2251662551652B556731596A365E6E3B62723F6675436A79
456D7C476E7D486F7E496E7D4A6E7C4C6E7B4F6E7A526F7A5570795870785C7178617278657378\
677276687073666C6E616668595E605457594F51534C4D4E474748454343434040
433D3C353131242525151A1C080E11030608010104131112252122363131453F3F544E4D635B5A\
7168677E75738B8280
9C9594A09C9BA5A3A3A9AAABADB1B3B2B8BBB7C0C3BCC7CCC2CFD5B2C2C9A2B5BE8CA5B07593A0\
5C7F8F446C7F2D5B70225166224F632752642D566732596A365D6D3A61713D6473
406776426978446A7A456B7A476B79496B794B6C784E6C78516C76546D76586D755B6E745F6E73\
616D72636C7062696C6065685D6164595C5D5356574F50504B4B4B494746474342
433E3C3633332828291B1E200D121503080B0002040F0E10232022343131454040544E4D625C5A\
7069677E76748B8280
9D9694A29D9CA6A4A4ABACADB0B3B5B6BBBEBBC3C7C1CBD0C6D4D9B7C7CDA7BAC293AAB57C99A6\
6285954A72843360742352681F4D61244F622A53642E5666325969365D6D396070
3B62723E64744066764167774368774569764869764A69754D69744F6972536972566971596A70\
5B696F5C676C5D65695B6366595F62575B5D5356584F51524C4D4D4B4949494645
413E3E353434292A2C1D2023111619060C1002070A0E0F11232223353233454141544F4F635C5B\
7169687E76748B8280
9E9695A39E9DA8A6A6AEAEAEB3B6B7B9BEC0BFC6CAC5CFD3CCD8DDBCCAD1ACBEC699B0BA84A0AC\
6C8D9B53798B3B677B2A586E1F4E63224D612750622B53642F5565325868355C6C
375E6E3961713B62723D64733F65744165744366744666724865714B65704D656F50656E53656D\
56656C576369576166576064565D6055595C5356585152534F4F4F4E4B4B4B4746
43403F3737372C2D2E212427161B1E0C1317080D11111316252527373536464343555150635E5D\
716A697E77758B8380
9E9795A49F9EAAA7A7B0AFB0B6B8B9BCC0C3C3C9CCC9D2D6CFDBE0C0CFD5B0C2CA9FB5BF8BA6B1\
7493A15A7F90446D80315E73245267224D61254E612951622C53642F5565315768
335A6B355D6E375F703960703B61713D62713F637141636F43626E45616C49616C4B616B4E6169\
516169526067535E64535D61535B5F53585C525558515354504F504F4D4D4B4847
4240403938392E303125282A1B1F2212181C0F14181B1D202A2B2D3A383A494646575353655F5F\
726B6A7F77768C8381
9F9795A5A09EABA8A8B2B1B1B8BABBBFC3C5C6CCCFCDD5D9D4DEE2C5D2D8B5C6CDA5B9C392ABB7\
7C9AA86487974B758736647829576C234F63234E61264F612951622C53632E5465
30576731596A335B6C355C6D365D6D385E6D3B5F6D3D5E6C3E5E6B405E6A435E69465E68495E67\
4C5E664D5D644F5C62505B6051595E51585C515558505455515152504E4E4A4848
4342423A3A3B313334272A2D1E2225151B1F1015192123262F30323E3D3E4C494A595555676161\
736D6C8078778C8481
9F9895A6A09FACA9A9B3B2B2BBBCBCC2C5C7CACFD2D2D9DCDAE3E6CAD6DCBBCAD1ABBEC79AB1BC\
85A1AE6D8E9E557C8E3E6A7E2D5D72235166224D61244E61274F612950622B5162
2C53642E55662F576831586932596A335A6A355B6A375A683859673B5A663E5A65415A65445A64\
475A634A5B624C5A614D595F4E585D4F575B5055584F53564F50524D4D4F484849
414243393B3C313436282C2F1F2528191F23171B1F27292C3535374241434F4D4D5C5858696363\
756E6D8179788D8482
9F9896A6A19FAEAAA9B5B3B3BDBDBEC5C7C8CDD1D3D6DCDFDFE7EBD1DCE1C2D0D6B2C3CCA1B6C1\
8DA7B37695A45F849547728535637826556A224E63234E61254E61264F60284F61
2951622A52632B54652D55672E57682E56673056663155653355643555633856633C56623F5761\
42576145576048575F4A585E4C575C4E565A4F55594F53564D50534B4D4F47484A
4143443B3D3E3336392B2F3223282C1E232724272B2E30333B3B3D4746475351515F5B5B6B6665\
76706F827A798D8582
A09896A7A1A0AFABAAB6B4B4BEBEBFC7C8C9D0D3D5D9DFE1E3EBEED9E3E7C9D6DCB9CAD1A9BDC7\
96AEBA7F9DAB698B9C537B8D3F6C802D5C72245166224E62234E61244E60254E61
264F612650622750622752642953652953642A52632B52622C51602F516032525F3653603A535F\
3D545F41545E44555E47565D4A565C4D565B4F565A4F54574D51534A4D4F45484B
4043463B3E4034383B2C313423292D1C21252A2D303537394141434C4B4C575555635F5E6D6868\
787271837C7A8E8583
A09896A8A1A0AFABAAB7B5B4C0BFBFC9C9CAD2D5D6DCE0E2E7EDEFE0E8ECD2DDE2C2D1D8B1C4CD\
A0B6C08AA5B27595A46185964D768939667B29586E235166224E63224D61224D61
224D60234D61234E61234E62245063245063244E61254E5F274D5E294D5D2C4E5D304F5D35515D\
38525D3D525D41535D44555D48555C4B555B4F565B4F54584D52554B4E51464A4C
4044483B4043353A3D2E3437292E3223272B3133363C3D3F4746485150515C5959666262706B6A\
7A7473847D7B8E8684
A09896A8A2A0B0ABAAB8B5B4C1BFBFCACACAD3D5D6DEE1E3EBEFF2EAF0F3DBE4E9CBD8DEBBCBD3\
ABBFC897AFBA829EAC6F909F5C82934A73873763792B596F245268224E63224E62
204C601F4B601F4B601F4C60204D611F4D611D4B5E1E495C20495B234A5B274B5B2B4C5B304E5B\
344F5B39515C3E525C43545D48565E4B565C4F565C50565A4F53574C5053484C4F
43484B3F4346383D4130373B2D3337313437393C3E4344464D4C4E565555605D5D696565736E6D\
7C7675867E7C8F8784
A09896A8A1A0B0ABAAB8B5B4C1BFBFCACACAD4D5D5DEE1E2EAEEEFF0F6F8E4ECEFD4DFE4C4D2D9\
B4C6CFA2B8C38EA8B47D9AA86C8D9D5D81924B73863C677B315E7329566B265267
214E631E4C611D4B601D4B601E4C611D4C611B4B5F1A485C1B475A1E4759224A5A274B5A2B4C5B\
2F4D5B364F5B3C525D41545E47575F4C585E4F585E50575C5055594E53564B4F52
464B4E42474A3C4145363C3F2F3437393C3F4243464A4B4C5352535C595A6461616D696876706F\
7E7876877F7E908785
A09896A8A19FB0ABA9B8B4B3C1BEBECAC9C9D4D4D4DEDFE0E9EBECF4F7F9EFF4F7DFE7ECD0DBE1\
C0CFD6AFC2CB9BB2BD8BA5B17B99A66D8D9C5E8192507688446C7F3A6478335E71
2D586C275469235066224F64235065204F651E4E631D4B601B4A5D1C485C204A5C254B5C2A4D5D\
2F4F5D34505D3B535E4256604959614D5A61525B61535A5E53595C5256594F5356
4B4F52484B4E43474A3D41453B3D404344474A4B4D525152595858615E5F696565716C6B797372\
807A7888817F908885
A09895A8A19FB0AAA8B8B3B2C0BDBCC9C7C7D3D2D2DDDDDDE7E9EAF4F6F7F7FAFDE9EFF2DAE2E7\
CBD7DDBCCBD3AABDC699AFBA8AA3AF7C98A56D8C9B5F81925578894D7182456B7C
3D6578366073315C702C586C2C586C2A566A275468245166224F63214D61244D60284F602C5060\
3252613753603E56624559634C5C64505D64545E63565D62565C60565A5D53575A
5053564E50534B4D4F44484B484A4C4D4D4F5252545957595F5D5E6663636D6969746F6E7B7574\
837C7A8A8280918886
A09795A7A09EAFA9A7B7B2B1BFBCBBC8C5C5D1D0CFDBDBDAE5E6E6F1F2F2FAFDFEF4F8FAE4EAEE\
D5DEE3C7D3D9B6C5CDA7BAC397ADB78BA3AF7D98A5708F9D6686955D7E8E567887
4F7283476C7D43697B3D64763A6174375F71355D70325A6D2F596B2F5769315668345767375867\
3B5A67415B67475E684C5F685361685662685A62675B61655B60635A5E60585B5D
55575A5456585152555152545253555656575A595A605E5E6562636B6767716D6C7872717E7877\
857D7C8B8381928987
A09795A79F9DAEA8A6B6B1AFBEBAB8C6C3C2CFCDCCD8D7D7E2E2E2EDEEEEF8FAFAFBFDFEEEF1F4\
E0E6EAD2DBDFC1CED4B4C3CAA7B9C19CB0B98DA4AF809AA678929E6E8A97668391
5F7E8C5677875374834E6F7F4A6C7D46697A4467784165753F63733E61713F617042617045626F\
48626F4C646E52656F56666E5A676E5D676D60676C61666A6164676062655E5F61
5B5C5E5A5A5C59595B5A595B5B5B5C5E5D5E6260606663646B6767706C6B7570707B7574817A79\
867F7D8C8482928A87
9F9794A69F9CADA7A5B5AFADBCB7B6C4C0BFCCCAC9D5D3D3DFDEDDE9E9E8F4F5F5FEFFFFF7F9FA\
EAEEF0DDE3E6CFD8DCC1CCD2B4C2C9AABAC19EB0B991A6B0899EA87E95A0778F9B
708995698390637F8C5E7B895A7785567482547180526F7E4F6C7B4F6B7A4F6B78526C78556C78\
586D785B6E775F6E77626E75636D73656D72676D70686C6F686A6C656668616264
5F5F615F5F60605F606160616361626563646865666C6869706C6C74706F7974737E7877837C7B\
88817F8E8683938A88
9F9694A59E9BACA5A3B3ADABBAB5B3C1BDBCC9C6C4D2CFCEDAD8D8E4E3E2EFEEEDFBFBFBFFFFFF\
F5F7F8E8EBEDDBE0E3CED6DAC2CCD1BAC5CBAFBCC3A4B3BA9BABB390A2AA889BA4
81959E7B909A748B957087916C838F687F8B647C88627A866077835F7682607580647781647680\
6777806B787F6D787E6F777C6F767A7075787174767072746E6F716E6C6E6A6869
6461626664656765666866666A67676C69696E6B6B716D6D7570707973737D7776817B79867F7D\
8A83818F8784948B88
9E9693A49C9AABA3A1B1AAA9B8B2B0BEB9B8C6C1C0CDCAC8D5D3D1DEDCDBE8E6E5F2F0F0FDFBFB\
FFFEFEF4F4F5E7E9EADADEE0CFD5D8C7CED1BFC7CCB5BFC4ADB8BDA3AFB69AA7AE
93A1A98D9CA488989F82939B7D8F97798B9475879072848E70818B6E80896E7E87728088758189\
7882897A82887C81867D80847C7F817A7C7E797A7B7978797575767270726E6C6E
6D6B6B6D6A6B6E6B6B6E6B6C706C6C726E6E74706F7672717974737D7776807A79847D7C88817F\
8C8482908885948B89
9E9592A39B99A9A19FAFA8A6B5AFADBBB5B4C2BDBBC9C4C3D0CCCBD8D4D3E0DDDCE9E6E5F1EFEF\
FBFAF9FDFBFBF3F1F1E5E6E7D9DBDDD0D4D6CBCFD2C4C9CCBDC2C5B5BBBEABB3B8
A4ADB29EA7AC98A2A8939EA48E9AA089959C869299828E96808C937C88907B868D7D868C7F868D\
858A8E888B8E88898C88888B868587838283807F807E7D7D7D7B7B787676767273
7471717470707470707571707671717772727974737B76757E7877807A79837D7B87807E8A8281\
8E8583918986958C89
9D9492A29A97A79F9DACA5A3B2ABA9B7B1AFBDB8B6C3BEBDCAC5C4D1CCCBD8D4D3DFDCDBE7E4E3\
EFECEBF8F6F5F9F6F5EFECECE4E3E3D9D9DAD3D4D5CED0D1C9CBCCC2C4C6BBBDC0
B6B8BBAFB3B6A9ADB0A4A9AC9EA4A899A0A4959CA091989D8F959B8B9297878E92868C90878C90\
8B8D918B8D8F8C8C8E8C8B8D8C8A8B898787878484848181827F7F7D7A7A7C7878
7B77767A76757A75757A75757B76757C77767E78777F7A79827B7A847D7C867F7E8982808C8482\
8F8785928987958C8A
9D9491A19896A59D9BAAA2A0AFA7A5B3ADABB8B2B0BEB8B6C3BEBCC9C4C3CFCBC9D6D1D0DCD8D7\
E3E0DEEBE7E6F4F0EFF4F0EFEBE7E6DFDDDDD8D7D7D4D2D3D1D0D0CBCACBC4C3C4
BFBEC0BBBABCB8B7B8B3B3B4ADAEB0A8A9ABA4A5A89FA1A49C9EA1989A9E97989B929497949597\
979597989596989494979293959191938E8D8D89898A868588848384807F827D7D
807B7B7F7A7A7F7A797F7A79807A79817B7A827C7B847D7C857F7D87807F8982808C84828E8684\
918886938A88968D8A
9C9390A09794A39B98A79F9DABA4A1AFA8A6B3ADABB8B1AFBDB6B5C1BCBAC7C1BFCCC7C5D2CDCB\
D8D3D1DED9D7E4E0DEEDE8E6EFE9E8E9E3E2DDD9D8D6D2D1D2CECED0CDCDCDC9C9
C9C5C5C5C1C1C0BCBCBDB9B9BBB7B7B6B2B2AFACACA9A7A9A6A4A5A2A1A3A19E9F9B9A9B9C9A9B\
9E9A9A9E99999E98979C96969A9493999291908B8B8E89888B8685898383878180
85807F847F7E847E7D847E7D857E7D857F7D867F7E87807F8982808A83818C84828E8684908885\
928987948B89968D8A
9B928F9E9593A19996A49C9AA8A09DABA3A1AEA7A5B2ABA9B6AFADBAB3B1BEB7B5C2BCBAC6C0BF\
CBC5C3D0CAC9D6D0CEDBD5D3E0DAD8E5DEDCE3DCDAD9D3D2D3CDCBCEC9C8CCC6C6
C9C3C3C8C2C0C5BEBDC1BAB8BDB6B5BAB4B2B5AFADB1ABAAABA6A5A7A3A3A5A1A1A39F9FA19E9D\
A29D9CA39D9CA39B9AA19A999D97969C9595958F8E918C8B8F89888D86858B8583
8A83828982818982818982808982808982818A83818B84828C84838D85838F8784908886928987\
938B88958C89978D8B
9B918E9D93919F9694A19996A49B99A69E9CA9A19FACA4A2AEA7A5B1AAA8B4ADABB8B1AFBBB4B2\
BFB8B6C2BCB9C6C0BDCAC3C1CEC7C4D2CBC8D7D0CDD7CFCCD5CCC9CFC7C5C8C1BF
C7BFBEC6BEBDC4BBB9C0B8B6BCB5B3BAB2B0B7AFAEB5ADABB1AAA8AFA7A6AAA4A3A8A3A1A6A1A0\
A4A09EA49F9EA29C9BA59F9EA39C9B9C959497918F948D8C928B899089878F8886
8E87858D86848D85848D85848D85838D86848E86848F87848F8785908886918986928A87938B88\
958C89968D8A978E8B
9A918E9B928F9D94919E9593A09795A29997A39B98A59D9AA79F9DA9A19FABA3A1ADA5A3B0A8A5\
B2AAA8B4ADAAB7AFADBAB2AFBCB4B2BFB7B4C1B9B6C2B9B6C2BAB6C5BCB8C1B9B6
BEB6B3BEB6B3BDB5B3BDB5B2BAB1B0B4ADABB2AAA9B0A8A6ADA6A4ACA5A3AAA3A1A7A19FA69F9D\
A49E9CA9A2A0A49E9BA19A989E97959B949298918F968E8C948D8B938B89928A88
918A88918987918987918986918986918987918987928987928A87938A88948B88948B89958C89\
968D8A978D8B988E8B
99908D9A908E9B918F9B928F9C93909D94919E95929F9693A09794A19895A29996A39A98A49B99\
A59D9AA69E9BA89F9CA9A09EAAA29FABA3A0ACA4A1ADA4A1ADA5A1AEA5A1ADA4A1
ACA3A0ACA4A0ACA3A0ADA5A1AFA6A2AEA5A1ADA4A2ACA3A1ABA29FAAA19FA9A19FA9A19EA79F9C\
A19997A098959E96949D94929B93919A918F98908E978F8C968E8B968D8B958D8A
958C8A958C8A958C89958C89958C89958C89958C89958C8A958C8A968D8A968D8A968D8A978D8B\
978E8B988E8B988E8C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503ooolO09R?S1l0Uhn<0`2F
SX`409J?S0`0UXn=102FShh309J@S`@0UY6A102EShh<09J>S0<0UXf;302FSX/409J>S0/0Uhj<102G
SX/809N=RP@0UXb9102FRhP309J:Q`@0UHZ7102ERHH409F8Q@@0UHR4102DQh<409>5P@<0TH9n102C
QX8409B7Q0@0UHR5102ERHH409F:Q`<0UXZ7102FRhL409J;R0@0UXb9102GS8T709N=RP@0Uhf;102H
SX/409R>S1H0oooo000D0?oooal0V8n<7`2GSh`309J>S0@0UXn<302FShd409J?SP<0UY2?102FTI44
09F?SP`0UXj<0`2FSH/<09J>R`@0UXj<2`2GSX`409N>R`P0Uhf:102FS8T409J;R0<0UXZ7102ERXL4
09F9QP@0UHR5102ER8@409B7P`@0ThF10`2APWh409>6PP@0U8N4102ER8D409F9QP@0UHZ70`2FRXL4
09J;Q`@0UX^8102FS8T409N<R@L0Uhf:102GSH/409R>R`@0V8j<5P3oool001@0oooo7`2HSh`O09N?
S0<0UXj<102FSh`<09J?S@@0UXn>0`2FT8l409JAT@@0UHn>302FSX`309J=R``0UXj;102FSX`;09N>
S0@0Uhj;202GSHX409J<R@@0UX^80`2FRXL409F:Q`@0UHV6102ER8D409F8Q0@0U8N3102CQH430962
OP@0ThJ2102DQh@409F8Q@@0UHV6102ERXL309J:Q`@0UX^7102FRhP409J<R@@0Uhb91`2GSHX409N=
R`@0V8j;102HSX`F0?ooo`00503ooolO09R?S1l0Uhn<0`2FSX`409J?S0`0UXn=102FShh309J@S`@0
UY6A102EShh<09J>S0<0UXf;302FSX/409J>S0/0Uhj<102GSX/809N=RP@0UXb9102FRhP309J:Q`@0
UHZ7102ERHH409F8Q@@0UHR4102DQh<409>5P@<0TH9n102CQX8409B7Q0@0UHR5102ERHH409F:Q`<0
UXZ7102FRhL409J;R0@0UXb9102GS8T709N=RP@0Uhf;102HSX/409R>S1H0oooo000D0?ooo`P0V8n<
102HSX`309R?S0@0Uhn<102GSX`809N?S0@0Uhj<2`2FSX`409J>S@`0UHj=0`2ESX`<09B>S@@0Thn>
102CShl309>@T0@0U9:C102CShl409>>S@@0Thf;102DSH/309B<R`@0U8f;202ESH/409B=R`@0UHb;
2`2ES8X409F;R0@0UHZ7102DR8H409B7Q0<0ThJ3102BQH4409:3P0@0TX9n102AP7`4091nNP@0SWeg
0`2=NgH408mnN@@0T81l102APWh409:4O`@0TXF10`2CQX8409>7P`@0U8N4102DR8D409F9QP@0UHZ7
0`2FRhP409N<R@@0Uhf:102HSX/F0?ooo`00503oool809R?S0@0V8j<0`2HSh`409N?S0@0Uhj<202G
Sh`409N>S0/0UXj<102FSXd<09F>S@<0UHj<302DSXd409>?SP@0Thn?0`2CT90409BBT`@0Thn?102C
SXd409>=R`@0U8f;0`2DS8/409B=R`P0UHf;102DSH/409F<R`/0UHb:102ERhP409F:Q`@0U8R6102D
Qh@309>6P`@0TXF1102BPh0409:2OP@0TH1l102@OWX408imM`<0SG]f102?OWT40920O0@0TH9n102B
Q7l409:5P@<0ThJ2102CQh<409B7Q0@0U8R5102ERHH409F:Q`<0UX^8102GS8T409N=RP@0V8j;5P3o
ool001@0oooo202HSh`409R>S0<0V8n<102GSh`409N>S0P0Uhn<102GSX`;09J>S0@0UXj=302ESXd3
09F>S0`0U8j=102CShh409>?S`<0Ti2@102DTY<409>?S`@0Thj=102CSH/409B=R`<0U8b;102DSH/8
09F=R`@0U8f;102ES8/;09F<RP@0UH^8102ERXL409B8QP@0U8N40`2CQX<409:5P@@0TX>0102BPWh4
0960O0@0T7ij102>OGL308ekMP@0Sgii102@P7`40962OP@0TXAo102BQH4309>6PP@0ThN3102DQh@4
09B8Q@@0UHV6102ERXL309J;R0@0Uhb9102GSHX409R>RaH0oooo000D0?ooo`P0V8n<102HSX`309R?
S0@0Uhn<102GSX`809N?S0@0Uhj<2`2FSX`409J>S@`0UHj=0`2ESX`<09B>S@@0Thn>102CShl309>@
T0@0U9:C102CShl409>>S@@0Thf;102DSH/309B<R`@0U8f;202ESH/409B=R`@0UHb;2`2ES8X409F;
R0@0UHZ7102DR8H409B7Q0<0ThJ3102BQH4409:3P0@0TX9n102AP7`4091nNP@0SWeg0`2=NgH408mn
N@@0T81l102APWh409:4O`@0TXF10`2CQX8409>7P`@0U8N4102DR8D409F9QP@0UHZ70`2FRhP409N<
R@@0Uhf:102HSX/F0?ooo`00503oool409R?S0@0V8n=102GSh`309N>S0@0Uhn=102GSh`409J?S0@0
UXn=102FSX`309F>S@@0UHj<102ESXd<09B>S@L0Thj=202BSXd8096>SP@0THn?0`2@T944092AT`@0
T8j?102@SHd8096<R`L0TX^:202CS8/409:<R`@0Thb;102ERhX309F;R@@0UHZ8102DRHL409B8QP@0
ThF3102BPh030921OP@0Sgml102>OWX408ikM`@0SGUd102;Mg4408YdK@<0RWE_102;N78408ajM@@0
SGag102>OWT408n0N`<0T85m102APWh409:4P0@0TXF1102CQh<409B8Q@<0UHV6102FRhP409N<R@@0
Uhf;5P3oool001@0oooo102HSh`409R?S@@0Uhn<0`2GSX`409N?S@@0Uhn<102FSh`409J?S@@0UXj<
0`2ESXd409F>S0@0UHj=302DSXd709>>S@P0TXj=202ASXh4096?S`<0T92A102@TI<4092>S`@0T8f=
202AS8/709:;RPP0Thb;102BS8/409><R`@0UH^:0`2ERhT409F:R0@0U8V7102DR8H409>5P`@0TX>0
0`2@PGh408moO0@0SWij102>NgL408eiM0@0RgMa102:M6d308YeK`@0RgQb102<NWD408elM`@0SWii
102?P7/30921O@@0TH9n102BQ80409:5P@@0ThN3102DR8D309F9QP@0UX^8102GS8T409N=RaH0oooo
000D0?ooo`@0V8n<102HShd409N?S0<0Uhj<102GShd409N?S0@0UXn<102FShd409J>S0<0UHj=102E
SX`409F>S@`0U8j=1`2CSXd809:>S@P0THj>102AShl3092@T@@0T96C102@SXl4092=S@P0THb;1`2B
RhX809><R`@0TXb;102CS8/409F;RP<0UH^9102ERXP409B9Q`@0U8R6102CQH<409:3P0<0T85n102?
Og`408inNP@0SW]g102=NG@408]gL@@0RWA]0`2:MFl408]hLP@0S7Ye102=O7L408inN@@0Sh1k0`2@
PGd40962OP@0TXB0102BQH4409>7P`@0U8R50`2ERHH409J;R0@0Uhb9102GSH/F0?ooo`00503oool4
09R?S0@0V8n=102GSh`309N>S0@0Uhn=102GSh`409J?S0@0UXn=102FSX`309F>S@@0UHj<102ESXd<
09B>S@L0Thj=202BSXd8096>SP@0THn?0`2@T944092AT`@0T8j?102@SHd8096<R`L0TX^:202CS8/4
09:<R`@0Thb;102ERhX309F;R@@0UHZ8102DRHL409B8QP@0ThF3102BPh030921OP@0Sgml102>OWX4
08ikM`@0SGUd102;Mg4408YdK@<0RWE_102;N78408ajM@@0SGag102>OWT408n0N`<0T85m102APWh4
09:4P0@0TXF1102CQh<409B8Q@<0UHV6102FRhP409N<R@@0Uhf;5P3oool001@0oooo102HSh`409R?
S@@0Uhn=0`2GSX`409J?S0P0UXn=102EShd409F>S@<0U8n=102DSXd809>>S@P0TXj=1`2ASXd4092>
S@@0T8f>102?SHh408j>SP@0SXj?0`2=Si4408j@T`@0SHf?102=S8`408j;R`@0SXZ:0`2?RXX4092;
RP@0TX^;102CS8`409>=S@@0Thj<102ES8`309B:R@@0U8V7102DQhD409>5P`@0TX:0102@P7d308mm
NP@0SG]g102;N7@408YeL0@0RG9]1027KfP408E[H`<0QViW1027LF/408UdKP@0RWIa102;NG<408ak
MP<0SGeh102>OgX408n0O0@0T89n102AQ80409>6PP<0U8R4102ERHH409J;R0@0Uhf:5P3oool001@0
oooo102HSh`409R?S@@0Uhn=0`2GSX`409J?S0P0UXn=102EShd409F>S@<0U8n=102DSXd809>>S@P0
TXj=1`2ASXd4092>S@@0T8f>102?SHh408j>SP@0SXj?0`2=Si4408j@T`@0SHf?102=S8`408j;R`@0
SXZ:0`2?RXX4092;RP@0TX^;102CS8`409>=S@@0Thj<102ES8`309B:R@@0U8V7102DQhD409>5P`@0
TX:0102@P7d308mmNP@0SG]g102;N7@408YeL0@0RG9]1027KfP408E[H`<0QViW1027LF/408UdKP@0
RWIa102;NG<408akMP<0SGeh102>OgX408n0O0@0T89n102AQ80409>6PP<0U8R4102ERHH409J;R0@0
Uhf:5P3oool001@0oooo102HSh`409R?S@@0Uhn=0`2GSX`409J?S0P0UXn=102EShd409F>S@<0U8n=
102DSXd809>>S@P0TXj=1`2ASXd4092>S@@0T8f>102?SHh408j>SP@0SXj?0`2=Si4408j@T`@0SHf?
102=S8`408j;R`@0SXZ:0`2?RXX4092;RP@0TX^;102CS8`409>=S@@0Thj<102ES8`309B:R@@0U8V7
102DQhD409>5P`@0TX:0102@P7d308mmNP@0SG]g102;N7@408YeL0@0RG9]1027KfP408E[H`<0QViW
1027LF/408UdKP@0RWIa102;NG<408akMP<0SGeh102>OgX408n0O0@0T89n102AQ80409>6PP<0U8R4
102ERHH409J;R0@0Uhf:5P3oool001@0oooo102HSh`809N?S@L0UXn=202EShd409B?S@@0U8j=1`2C
SXd809:>S@@0THj=102@SXd4092>SP<0Shf>202>SHh408f=SP@0S8f>102;SHl308Z=T0@0RXnB102:
S8h408Z;R`@0RhZ9102<RHT308f9R@@0SXV9102?RXT4092;RPP0THb;102BS8/309::R@@0TXR6102B
QX<409:3P@@0TH5n102?O7T308eiM@@0RgIb1028Lfh408I_J@@0QF]U1023J644085TG0<0PVQP1024
Jf@408E^I`@0QW5Z1028Lfd408UfL0<0RWQc102<NgH408emN0@0SWmk102@PGd40964P0<0ThJ2102D
R8D409F:Q`@0Uhf:5P3oool001@0oooo102HSh`809N?S@L0UXn=202EShd409B?S@@0U8j=1`2CSXd8
09:>S@@0THj=102@SXd4092>SP<0Shf>202>SHh408f=SP@0S8f>102;SHl308Z=T0@0RXnB102:S8h4
08Z;R`@0RhZ9102<RHT308f9R@@0SXV9102?RXT4092;RPP0THb;102BS8/309::R@@0TXR6102BQX<4
09:3P@@0TH5n102?O7T308eiM@@0RgIb1028Lfh408I_J@@0QF]U1023J644085TG0<0PVQP1024Jf@4
08E^I`@0QW5Z1028Lfd408UfL0<0RWQc102<NgH408emN0@0SWmk102@PGd40964P0<0ThJ2102DR8D4
09F:Q`@0Uhf:5P3oool001@0oooo102HSh`809N?S@L0UXn=202EShd409B?S@@0U8j=1`2CSXd809:>
S@@0THj=102@SXd4092>SP<0Shf>202>SHh408f=SP@0S8f>102;SHl308Z=T0@0RXnB102:S8h408Z;
R`@0RhZ9102<RHT308f9R@@0SXV9102?RXT4092;RPP0THb;102BS8/309::R@@0TXR6102BQX<409:3
P@@0TH5n102?O7T308eiM@@0RgIb1028Lfh408I_J@@0QF]U1023J644085TG0<0PVQP1024Jf@408E^
I`@0QW5Z1028Lfd408UfL0<0RWQc102<NgH408emN0@0SWmk102@PGd40964P0<0ThJ2102DR8D409F:
Q`@0Uhf:5P3oool001@0oooo102HSh`809N?S@L0UXn=202EShd409B?S@@0U8j=1`2CSXd809:>S@@0
THj=102@SXd4092>SP<0Shf>202>SHh408f=SP@0S8f>102;SHl308Z=T0@0RXnB102:S8h408Z;R`@0
RhZ9102<RHT308f9R@@0SXV9102?RXT4092;RPP0THb;102BS8/309::R@@0TXR6102BQX<409:3P@@0
TH5n102?O7T308eiM@@0RgIb1028Lfh408I_J@@0QF]U1023J644085TG0<0PVQP1024Jf@408E^I`@0
QW5Z1028Lfd408UfL0<0RWQc102<NgH408emN0@0SWmk102@PGd40964P0<0ThJ2102DR8D409F:Q`@0
Uhf:5P3oool001@0oooo102HSh`409N?S0@0Uhn=0`2FShd409F?S@@0UHj=202DSXd409>>S@L0TXj=
102ASXh8092>SP@0Shj>102>SHh308f=SP@0S8f>102;S8h408Z<SP@0RH^=1028Rhd308J;SP@0QX^?
1026RX`408N9RP@0R8R91029R8L308Z7Q`@0RhN7102<R8L408f8R0@0SXR8102?RHT408n9R0<0T8R7
102?QH<408n3P@@0SX1m102>OGX408aiMP<0RWA`1028LF`408E]J0@0PVUS1021IEh407iQF@@0OUmG
0`1oHUX4081UG@@0PVQQ1023Jf@408A^J0@0QW5[0`27M6h408UgL@@0RgUd102<O7L408ioNP@0T85m
0`2AQ80409>7P`@0UHV6102GS8TF0?ooo`00503oool409R?S0@0Uhn<102GShd309J?S@@0UHn=102E
SXd809B>S@@0Thj=1`2BSXd4096>SPP0T8j>102?SXh408j=SP<0SHf>102<SHh408^<SP@0RXb>1029
Rhd408R;S@<0QX^>1026Rhl408J:S0@0QhV:1028R8T408V8Q`<0RXN7102;QhL408b8Q`@0SHR8102>
R8P408n9R@@0ShV80`2@R8L408n5P`@0Sh>1102>P7d408imNP@0S7Uf0`2:M70408QaK0@0QFeX1022
JF<4085UGP@0OV5I101nGeL307mRFP@0P6EM1022J64408=[I0@0Q6iX1026LF/308MdKP@0RGMa102;
NG@408alM`@0SWmj102@PGd30964P0@0ThN3102ERHH409N<RAH0oooo000D0?ooo`@0V8n<102GSh`4
09N?S@<0UXn=102EShd409F>S@P0U8j=102CSXd709:>S@@0THj>202@SXh408n>SP@0SXf>0`2=SHh4
08b=SP@0Rhb>102:S8h408V;S@@0R8^=0`26Rhh408J;S`@0QXZ<1027RHX408R8R@@0RHR70`2:QhL4
08^7Q`@0S8R7102=R8P408j8R0@0ShV9102?RHP30928Q`@0ShF3102?Ph4408j0O@@0SWej102<NGH3
08YdL0@0R75/1025KFP4089YH`@0PFEN101nHET407iOE`<0Of9J1020IEd4089XH@@0Pf]T1024KVP4
08IaJ`<0QgA^1029Mg4408]iM0@0S7ag102>OgX40921O@<0THB0102CQh<409F9QP@0Uhb95P3oool0
01@0oooo102HSh`409N?S0@0Uhn=0`2FShd409F?S@@0UHj=202DSXd409>>S@L0TXj=102ASXh8092>
SP@0Shj>102>SHh308f=SP@0S8f>102;S8h408Z<SP@0RH^=1028Rhd308J;SP@0QX^?1026RX`408N9
RP@0R8R91029R8L308Z7Q`@0RhN7102<R8L408f8R0@0SXR8102?RHT408n9R0<0T8R7102?QH<408n3
P@@0SX1m102>OGX408aiMP<0RWA`1028LF`408E]J0@0PVUS1021IEh407iQF@@0OUmG0`1oHUX4081U
G@@0PVQQ1023Jf@408A^J0@0QW5[0`27M6h408UgL@@0RgUd102<O7L408ioNP@0T85m0`2AQ80409>7
P`@0UHV6102GS8TF0?ooo`00503oool409R?S0@0Uhn<1`2FShd409F>S@@0U8j=202CSXd409:>S@L0
THj>102@SXh408n>SP@0SXj>202=SHh308b=SP@0Rhb>1029S8h408R;SP@0QXZ=1024RH`308:7RP@0
PHJ91023QhT408B7R0@0QHJ71026QXH308N6QP@0R8F61029QHD408Z6Q@@0RXF5102;QHD408^4Q0<0
S8>3102<PH0408aoO@@0Rgai102:NGD408UdL@<0Qg1/1024JfH4085WH@@0Of=L101mGUH407UID0@0
NUY@0`1kG5@407aOE`@0OV=K101oIUh4085YHP@0PfaV0`25L6T408IcK@@0R7I`102:NG@408alM`@0
SWmk0`2@PWh409:5P@@0U8R5102FS8TF0?ooo`00503oool409R?S0@0Uhn<1`2FShd409F>S@@0U8j=
202CSXd409:>S@L0THj>102@SXh408n>SP@0SXj>202=SHh308b=SP@0Rhb>1029S8h408R;SP@0QXZ=
1024RH`308:7RP@0PHJ91023QhT408B7R0@0QHJ71026QXH308N6QP@0R8F61029QHD408Z6Q@@0RXF5
102;QHD408^4Q0<0S8>3102<PH0408aoO@@0Rgai102:NGD408UdL@<0Qg1/1024JfH4085WH@@0Of=L
101mGUH407UID0@0NUY@0`1kG5@407aOE`@0OV=K101oIUh4085YHP@0PfaV0`25L6T408IcK@@0R7I`
102:NG@408alM`@0SWmk0`2@PWh409:5P@@0U8R5102FS8TF0?ooo`00503oool409R?S0@0Uhn<1`2F
Shd409F>S@@0U8j=202CSXd409:>S@L0THj>102@SXh408n>SP@0SXj>202=SHh308b=SP@0Rhb>1029
S8h408R;SP@0QXZ=1024RH`308:7RP@0PHJ91023QhT408B7R0@0QHJ71026QXH308N6QP@0R8F61029
QHD408Z6Q@@0RXF5102;QHD408^4Q0<0S8>3102<PH0408aoO@@0Rgai102:NGD408UdL@<0Qg1/1024
JfH4085WH@@0Of=L101mGUH407UID0@0NUY@0`1kG5@407aOE`@0OV=K101oIUh4085YHP@0PfaV0`25
L6T408IcK@@0R7I`102:NG@408alM`@0SWmk0`2@PWh409:5P@@0U8R5102FS8TF0?ooo`00503oool4
09R?S0@0Uhn<1`2FShd409F>S@@0U8j=202CSXd409:>S@L0THj>102@SXh408n>SP@0SXj>202=SHh3
08b=SP@0Rhb>1029S8h408R;SP@0QXZ=1024RH`308:7RP@0PHJ91023QhT408B7R0@0QHJ71026QXH3
08N6QP@0R8F61029QHD408Z6Q@@0RXF5102;QHD408^4Q0<0S8>3102<PH0408aoO@@0Rgai102:NGD4
08UdL@<0Qg1/1024JfH4085WH@@0Of=L101mGUH407UID0@0NUY@0`1kG5@407aOE`@0OV=K101oIUh4
085YHP@0PfaV0`25L6T408IcK@@0R7I`102:NG@408alM`@0SWmk0`2@PWh409:5P@@0U8R5102FS8TF
0?ooo`00503oool409R?S0@0Uhn<102FShd309F>S@P0U8j=102CSXd409:>SP@0THj>0`2@SXh808n>
SP@0SXj>102=SHh408b=SP@0Rhf>0`2:SHh408V<SP@0R8b>1026Rhh408F:S@@0PHR;0`1jPXH407f4
Q`@0P8F71021QHL408>5QP@0PhB50`24Ph@408F4Q0@0QX>31026PX8408N2PP@0Qh611028P80308Qn
OP@0Qgak1027NGP408IfM0@0QWAa1024L6`3089[IP@0P6MQ101nHU/407YME@@0N5Q?101eDTL407ID
BP<0MeI=101iFE0407YME0@0O61H101nI5`4081XH0<0PV]U1024KfT408IbK@@0R7Ia102:NWD408em
N@<0Sh5m102AQ80409B8Q0@0UX^85P3oool001@0oooo102HSh`409N?S0@0UXn=0`2ESXd809B>S@@0
Thj=102BSXh4096>SP<0T8j>202?SXh408j>SP@0SHf>102<SHh408^=SP<0RXf>1029S8h408R<SP@0
QX^>1025RXd40868R`<0NX:6101mQ8L40825Q`@0PHF71023QHH408>4Q@<0Q8>41025Q8@408J3P`@0
QX:21027PX8408N1P@@0R8200`28OWh408MlN`@0QgUh1026MW@408IdL@@0Q71/0`22JfH4081WH@@0
OV9K101jGED407QHC`@0ME97101fE4X307MFC@@0NEU@101jGE@407aPF0@0OVAL1020J603089[I@@0
Q6mY1026LVd408QfL@@0RWYe102=OGT308n1O@@0THB0102DR8@409J;R1H0oooo000D0?ooo`@0V8n<
102GSh`409J?S@<0UHj=202DSXd409>>S@@0TXj>102ASXh3092>SPP0Shj>102>SXh408f=SP@0S8f>
102;SHh308Z=SP@0RHb>1028S8h408J;SP@0QHZ=1021R8/307Z2QP@0OHB71020QHL40865Q`@0PhF6
1023Q8D308B3Q0@0QHB41026Ph<408J2PP@0Qh:21027PH4408R0P0<0R7in1027O7/408MiN0@0QWId
1026M74408A`K0<0PV]V1020If4407iRF`@0NUeE101hF4l407EBA`@0MUA:0`1gETd407UID0@0NUeD
101lH5P407iTG0@0P6QP0`22JfD408A_J@@0QW9]1028MW4408YjM@@0SGei0`2?PGd40964P0@0U8R4
102FRhPF0?ooo`00503oool409R?S0@0Uhn<102FShd309F>S@P0U8j=102CSXd409:>SP@0THj>0`2@
SXh808n>SP@0SXj>102=SHh408b=SP@0Rhf>0`2:SHh408V<SP@0R8b>1026Rhh408F:S@@0PHR;0`1j
PXH407f4Q`@0P8F71021QHL408>5QP@0PhB50`24Ph@408F4Q0@0QX>31026PX8408N2PP@0Qh611028
P80308QnOP@0Qgak1027NGP408IfM0@0QWAa1024L6`3089[IP@0P6MQ101nHU/407YME@@0N5Q?101e
DTL407IDBP<0MeI=101iFE0407YME0@0O61H101nI5`4081XH0<0PV]U1024KfT408IbK@@0R7Ia102:
NWD408emN@<0Sh5m102AQ80409B8Q0@0UX^85P3oool001@0oooo102GSh`409N?S@@0UXn=0`2ESXd4
09B>S@@0Thj=102BSXd4096>SP@0T8j>0`2?SXh808j>SP@0SHf?102<SHl408^=S`@0RXf?0`28S8l4
08N<S`@0QXb>1025Rhh408B;SP@0PXZ>0`1fOh@407^2QP@0OX>5101oQ8D40823Q0@0PH>40`22PX84
08:1PP@0Ph621024P84408AoP0@0Q7in1024Ng`308AhN@@0PgIf1023M7<4089aK`@0PFi/1020JfL3
07iVH@@0O69L101jG5D407IFCP@0Le57101`BSl4079=@P<0Le15101eDdT407IGCP@0N5]B101jGeL4
07eSF`<0OfMP1021Jf@408A_J@@0QW=]1029Mg8408]kMP<0SWmk102@Pgl409>7P`@0UX^85P3oool0
01@0oooo102GSh`409N?S@@0UXn=0`2ESXd409B>S@@0Thj=102BSXd4096>SP@0T8j>0`2?SXh808j>
SP@0SHf?102<SHl408^=S`@0RXf?0`28S8l408N<S`@0QXb>1025Rhh408B;SP@0PXZ>0`1fOh@407^2
QP@0OX>5101oQ8D40823Q0@0PH>40`22PX8408:1PP@0Ph621024P84408AoP0@0Q7in1024Ng`308Ah
N@@0PgIf1023M7<4089aK`@0PFi/1020JfL307iVH@@0O69L101jG5D407IFCP@0Le57101`BSl4079=
@P<0Le15101eDdT407IGCP@0N5]B101jGeL407eSF`<0OfMP1021Jf@408A_J@@0QW=]1029Mg8408]k
MP<0SWmk102@Pgl409>7P`@0UX^85P3oool001@0oooo102GSh`409N?S@@0UXn=0`2ESXd409B>S@@0
Thj=102BSXd4096>SP@0T8j>0`2?SXh808j>SP@0SHf?102<SHl408^=S`@0RXf?0`28S8l408N<S`@0
QXb>1025Rhh408B;SP@0PXZ>0`1fOh@407^2QP@0OX>5101oQ8D40823Q0@0PH>40`22PX8408:1PP@0
Ph621024P84408AoP0@0Q7in1024Ng`308AhN@@0PgIf1023M7<4089aK`@0PFi/1020JfL307iVH@@0
O69L101jG5D407IFCP@0Le57101`BSl4079=@P<0Le15101eDdT407IGCP@0N5]B101jGeL407eSF`<0
OfMP1021Jf@408A_J@@0QW=]1029Mg8408]kMP<0SWmk102@Pgl409>7P`@0UX^85P3oool001@0oooo
102GSh`409N?S@@0UXn=0`2ESXd409B>S@@0Thj=102BSXd4096>SP@0T8j>0`2?SXh808j>SP@0SHf?
102<SHl408^=S`@0RXf?0`28S8l408N<S`@0QXb>1025Rhh408B;SP@0PXZ>0`1fOh@407^2QP@0OX>5
101oQ8D40823Q0@0PH>40`22PX8408:1PP@0Ph621024P84408AoP0@0Q7in1024Ng`308AhN@@0PgIf
1023M7<4089aK`@0PFi/1020JfL307iVH@@0O69L101jG5D407IFCP@0Le57101`BSl4079=@P<0Le15
101eDdT407IGCP@0N5]B101jGeL407eSF`<0OfMP1021Jf@408A_J@@0QW=]1029Mg8408]kMP<0SWmk
102@Pgl409>7P`@0UX^85P3oool001@0oooo102GSh`409J?S@@0UHn=0`2DSXd409>>S@@0TXj=102A
SXh4092>SP@0Shj>0`2>SXh408f>S`@0S8j?102;SHl408Z=S`@0RHf?1028SHl308N<S`@0QXb?1025
S8l408B;S`@0Q8b?1020RH`307^4Q`@0Nh>6101lPXD407f2Q0P0OX620`1oP84407moP0@0P7n01021
Ogl4085nOP@0PGal1021N7T3085eMP@0P75b101oKVh407i/JP@0OFUW101kIF8307UQG0@0N5aG101f
F54407=BBP@0L4a2101]A3T406e5>@<0KdTn101aCD84079AA`@0MEE<101gFE4407UNEP<0O69K101n
If04085[I@@0Q71Z1027M6l408YiM0<0S7ei102?PWh409:6PP@0UHZ75P3oool001@0oooo102GSh`4
09J?S@@0UHn=0`2DSXd409>>S@@0TXj=102ASXh4092>SP@0Shj>0`2>SXh408f>S`@0S8j?102;SHl4
08Z=S`@0RHf?1028SHl308N<S`@0QXb?1025S8l408B;S`@0Q8b?1020RH`307^4Q`@0Nh>6101lPXD4
07f2Q0P0OX620`1oP84407moP0@0P7n01021Ogl4085nOP@0PGal1021N7T3085eMP@0P75b101oKVh4
07i/JP@0OFUW101kIF8307UQG0@0N5aG101fF54407=BBP@0L4a2101]A3T406e5>@<0KdTn101aCD84
079AA`@0MEE<101gFE4407UNEP<0O69K101nIf04085[I@@0Q71Z1027M6l408YiM0<0S7ei102?PWh4
09:6PP@0UHZ75P3oool001@0oooo102GSh`409J?S@@0UHn=0`2DSXd409>>S@@0TXj=102ASXh4092>
SP@0Shj>0`2>SXh408f>S`@0S8j?102;SHl408Z=S`@0RHf?1028SHl308N<S`@0QXb?1025S8l408B;
S`@0Q8b?1020RH`307^4Q`@0Nh>6101lPXD407f2Q0P0OX620`1oP84407moP0@0P7n01021Ogl4085n
OP@0PGal1021N7T3085eMP@0P75b101oKVh407i/JP@0OFUW101kIF8307UQG0@0N5aG101fF54407=B
BP@0L4a2101]A3T406e5>@<0KdTn101aCD84079AA`@0MEE<101gFE4407UNEP<0O69K101nIf04085[
I@@0Q71Z1027M6l408YiM0<0S7ei102?PWh409:6PP@0UHZ75P3oool001@0oooo102GSh`409J?S@@0
UHn=0`2DSXd409>>S@@0TXj>102ASXh4092>SP@0Shj>0`2=SXl408b>S`@0Rhj?102:SHl408V=S`@0
R8f?1027SHl308F<S`@0Q8b?1023S8l408:;S`@0P8Z>101nR8`307b5R@@0Nh>6101kPX@407^1P`@0
Nh21101lOgl307anO`@0OGin101mOGh407imOP@0Ogen101oNGX407meM`<0OW5c101mKFl407aYJP@0
NfMW101iI68407MPGP<0MEaH101cF584079CC0@0L4i6101]B3h406Y0=@@0J3da0`1Z@SH406a6>`@0
KT]0101aCdH407=DB`@0MUUA0`1iGUH407]SG0@0OVQQ1022KFL408EbK0@0R7Mb0`2;NgL408j0O0@0
TXF1102ERXLF0?ooo`00503oool409N?S0@0UXn=102EShd309B>S@@0Thj=102BSXh4096>SP@0T8j>
102?SXh308f>S`@0S8j?102;SXl408Z=S`@0RHf?1028SHl408N=S`<0QHb?1024S8l408><S`@0PX^?
1020RXh407j8S0<0O8F9101kPhH407^2Q0@0Nh63101kP84407aoO`<0O7io101mOWh407emOP@0OWen
101oOGh407miNP@0OgEg0`1nLG<407e]K`@0O6UZ101kIfL407UTHP@0Mf1N0`1eG5P407=HDP@0LU=<
101`CTH406e8?P@0JT0e101X?C4306Y2=P@0K4Hk101^Bd04075?AP@0LeA;101fFE4307UNEP@0Nf=L
101nJ644089]I`@0QG9/1028Mg8308]kM`@0SX1l102BQH4409F:QaH0oooo000D0?ooo`@0Uhn<102F
Shd409F?S@<0U8j=102CSXd409:>SP@0THj>102@SXh408n>SP<0SHj?102<SXl408^>S`@0RXf?1029
SHl408R=S`@0Qhf?0`25S8l408B<S`@0Phb?1022Rhl4082:SP@0OXR<0`1lQHT407^3QP@0Nh:4101k
PH<407^0P@@0O7mo0`1lOWl407enOP@0OGen101nOGh407mmOP@0OgUj101oMGL307iaL`@0OFe_101l
JFX407]WI`@0NFAR101gH5h307ELF0@0LeQB101bDd`4071>AP@0KDPn101Z@3D406Pm<@<0JT8f101/
AS/406i;@0@0LDm6101cE4/407IID@<0NEiF101kHe`407iXH@@0PVeW1025LV`408QgLP<0Rg]g102>
P7`409:5P@@0UHZ75P3oool001@0oooo102GSh`409J?S@@0UHn=0`2DSXd409>>S@@0TXj>102ASXh4
092>SP@0Shj>0`2=SXl408b>S`@0Rhj?102:SHl408V=S`@0R8f?1027SHl308F<S`@0Q8b?1023S8l4
08:;S`@0P8Z>101nR8`307b5R@@0Nh>6101kPX@407^1P`@0Nh21101lOgl307anO`@0OGin101mOGh4
07imOP@0Ogen101oNGX407meM`<0OW5c101mKFl407aYJP@0NfMW101iI68407MPGP<0MEaH101cF584
079CC0@0L4i6101]B3h406Y0=@@0J3da0`1Z@SH406a6>`@0KT]0101aCdH407=DB`@0MUUA0`1iGUH4
07]SG0@0OVQQ1022KFL408EbK0@0R7Mb0`2;NgL408j0O0@0TXF1102ERXLF0?ooo`00503oool409N?
S0@0UXn=102EShd309B?S@@0TXj>102ASXh4092>SP@0Shj>102>SXl308f>S`@0Rhj?102:SXl408V=
T0@0R8f@1026SI0408F=T0<0Q8b@1022S904086;T0@0PhfB101mR8`407b6RP<0NhF8101jPhH407Z2
Q0@0NH62101iOX0407UmO@<0NGal201jO7`407]kO0@0OGin101mNg`407ehN0<0O7Ad101kL70407UY
J@@0N6AT101eH5l407=LFP<0LEQE101_E4l406e@B@@0K4]3101ZAS`406Q0=0@0ICT]0`1U>B`406Po
<`@0JT@i101]BSl406m?A@@0LUA;0`1eFU4407QOE`@0O6AM101oJV<408=_J@@0QWE`0`2:NWD408eo
N`@0THB1102ERXHF0?ooo`00503oool409N?S0@0UXn=102EShd309B?S@@0TXj>102ASXh4092>SP@0
Shj>102>SXl308f>S`@0Rhj?102:SXl408V=T0@0R8f@1026SI0408F=T0<0Q8b@1022S904086;T0@0
PhfB101mR8`407b6RP<0NhF8101jPhH407Z2Q0@0NH62101iOX0407UmO@<0NGal201jO7`407]kO0@0
OGin101mNg`407ehN0<0O7Ad101kL70407UYJ@@0N6AT101eH5l407=LFP<0LEQE101_E4l406e@B@@0
K4]3101ZAS`406Q0=0@0ICT]0`1U>B`406Po<`@0JT@i101]BSl406m?A@@0LUA;0`1eFU4407QOE`@0
O6AM101oJV<408=_J@@0QWE`0`2:NWD408eoN`@0THB1102ERXHF0?ooo`00503oool409N?S0@0UXn=
102EShd309B?S@@0TXj>102ASXh4092>SP@0Shj>102>SXl308f>S`@0Rhj?102:SXl408V=T0@0R8f@
1026SI0408F=T0<0Q8b@1022S904086;T0@0PhfB101mR8`407b6RP<0NhF8101jPhH407Z2Q0@0NH62
101iOX0407UmO@<0NGal201jO7`407]kO0@0OGin101mNg`407ehN0<0O7Ad101kL70407UYJ@@0N6AT
101eH5l407=LFP<0LEQE101_E4l406e@B@@0K4]3101ZAS`406Q0=0@0ICT]0`1U>B`406Po<`@0JT@i
101]BSl406m?A@@0LUA;0`1eFU4407QOE`@0O6AM101oJV<408=_J@@0QWE`0`2:NWD408eoN`@0THB1
102ERXHF0?ooo`00503oool409N?S0@0UXn=102EShd309B?S@@0TXj>102ASXh4092>SP@0Shj>102>
SXl308f>S`@0Rhj?102:SXl408V=T0@0R8f@1026SI0408F=T0<0Q8b@1022S904086;T0@0PhfB101m
R8`407b6RP<0NhF8101jPhH407Z2Q0@0NH62101iOX0407UmO@<0NGal201jO7`407]kO0@0OGin101m
Ng`407ehN0<0O7Ad101kL70407UYJ@@0N6AT101eH5l407=LFP<0LEQE101_E4l406e@B@@0K4]3101Z
AS`406Q0=0@0ICT]0`1U>B`406Po<`@0JT@i101]BSl406m?A@@0LUA;0`1eFU4407QOE`@0O6AM101o
JV<408=_J@@0QWE`0`2:NWD408eoN`@0THB1102ERXHF0?ooo`00503oool409N?S0@0UXn=102DShd3
09>?SP@0TXj>102ASXh408n>SP@0SXj?102=SXl308b>S`@0RXj@1029SY0408R=T0@0Qhf@1025SI04
08B=T0<0PXb@1021S90407n;T0@0MH>8101hQHT407V5R@<0NHB7101hPhH407R2Q@@0N863101gOWl4
07IkO0L0MWYk101gNg/407QkN`@0NWem101kOgh407]lN`<0NgYi101jMW@407M]J`@0MFET101bGUh4
06mIE`<0KEEB101[DD/406U=AP@0JDU1101XAC/406Ho=0@0I3X]0`1R=BP406@i;0@0IShb101XA3T4
06]9?`@0KTm60`1bEDd407EKD`@0NF5J101mIf04085]I`@0QG9]0`29N7<408anN@@0T8>0102DRHHF
0?ooo`00503oool409N?S0@0UXn=102DShd309>?SP@0TXj>102ASXh408n>SP@0SXj?102=SXl308b>
S`@0RXj@1029SY0408R=T0@0Qhf@1025SI0408B=T0<0PXb@1021S90407n;T0@0MH>8101hQHT407V5
R@<0NHB7101hPhH407R2Q@@0N863101gOWl407IkO0L0MWYk101gNg/407QkN`@0NWem101kOgh407]l
N`<0NgYi101jMW@407M]J`@0MFET101bGUh406mIE`<0KEEB101[DD/406U=AP@0JDU1101XAC/406Ho
=0@0I3X]0`1R=BP406@i;0@0IShb101XA3T406]9?`@0KTm60`1bEDd407EKD`@0NF5J101mIf04085]
I`@0QG9]0`29N7<408anN@@0T8>0102DRHHF0?ooo`00503oool409N?S0@0UXn=102DShd309>?SP@0
TXj>102ASXh408n>SP@0SXj?102=SXl308b>S`@0RXj@1029SY0408R=T0@0Qhf@1025SI0408B=T0<0
PXb@1021S90407n;T0@0MH>8101hQHT407V5R@<0NHB7101hPhH407R2Q@@0N863101gOWl407IkO0L0
MWYk101gNg/407QkN`@0NWem101kOgh407]lN`<0NgYi101jMW@407M]J`@0MFET101bGUh406mIE`<0
KEEB101[DD/406U=AP@0JDU1101XAC/406Ho=0@0I3X]0`1R=BP406@i;0@0IShb101XA3T406]9?`@0
KTm60`1bEDd407EKD`@0NF5J101mIf04085]I`@0QG9]0`29N7<408anN@@0T8>0102DRHHF0?ooo`00
503oool409N?S0@0UXn=102DShd309>?SP@0TXj>102ASXh408n>SP@0SXj?102=SXl308b>S`@0RXj@
1029SY0408R=T0@0Qhf@1025SI0408B=T0<0PXb@1021S90407n;T0@0MH>8101hQHT407V5R@<0NHB7
101hPhH407R2Q@@0N863101gOWl407IkO0L0MWYk101gNg/407QkN`@0NWem101kOgh407]lN`<0NgYi
101jMW@407M]J`@0MFET101bGUh406mIE`<0KEEB101[DD/406U=AP@0JDU1101XAC/406Ho=0@0I3X]
0`1R=BP406@i;0@0IShb101XA3T406]9?`@0KTm60`1bEDd407EKD`@0NF5J101mIf04085]I`@0QG9]
0`29N7<408anN@@0T8>0102DRHHF0?ooo`00503oool409N?S@@0UXn=102DShd309>>SP@0THj>102@
SXh408n>S`@0SHj?102<SXl308^>T0@0RHj@1028SY0408N>T@@0QXfA1024SI4408:=T@<0PHbA101o
Ri4407j;T0@0MH>9101fQ8T407J4R0<0MX>7101gQ8L407N3QP@0Mh63101eOWl407=iNPL0LgQj101a
N7T407MoO`@0NWmo101mPX8407f1P0<0O7]j101jNGL407McL@@0Lf]Y101]Geh406]FE@<0J59@101W
CTT406I:A0@0ITLo101UA3X406@o=0@0HST]0`1O<bH405lb9@@0HCP[101T?S8406M4>P@0JTY10`1^
D4P4079GC`@0MUeF101jI5d407mZI0@0Pg1[0`27MW8408]mN0@0T8=o102DRHDF0?ooo`00503oool4
09N?S@@0UXn=102DShd309>>SP@0THj>102@SXh408n>S`@0SHj?102<SXl308^>T0@0RHj@1028SY04
08N>T@@0QXfA1024SI4408:=T@<0PHbA101oRi4407j;T0@0MH>9101fQ8T407J4R0<0MX>7101gQ8L4
07N3QP@0Mh63101eOWl407=iNPL0LgQj101aN7T407MoO`@0NWmo101mPX8407f1P0<0O7]j101jNGL4
07McL@@0Lf]Y101]Geh406]FE@<0J59@101WCTT406I:A0@0ITLo101UA3X406@o=0@0HST]0`1O<bH4
05lb9@@0HCP[101T?S8406M4>P@0JTY10`1^D4P4079GC`@0MUeF101jI5d407mZI0@0Pg1[0`27MW84
08]mN0@0T8=o102DRHDF0?ooo`00503oool409N?S@@0UXn=102DShd309>>SP@0THj>102@SXh408n>
S`@0SHj?102<SXl308^>T0@0RHj@1028SY0408N>T@@0QXfA1024SI4408:=T@<0PHbA101oRi4407j;
T0@0MH>9101fQ8T407J4R0<0MX>7101gQ8L407N3QP@0Mh63101eOWl407=iNPL0LgQj101aN7T407Mo
O`@0NWmo101mPX8407f1P0<0O7]j101jNGL407McL@@0Lf]Y101]Geh406]FE@<0J59@101WCTT406I:
A0@0ITLo101UA3X406@o=0@0HST]0`1O<bH405lb9@@0HCP[101T?S8406M4>P@0JTY10`1^D4P4079G
C`@0MUeF101jI5d407mZI0@0Pg1[0`27MW8408]mN0@0T8=o102DRHDF0?ooo`00503oool409N?S@@0
UXn=102DShd309>>SP@0THj>102@SXh408n>S`@0SHj?102<SXl308^>T0@0RHj@1028SY0408N>T@@0
QXfA1024SI4408:=T@<0PHbA101oRi4407j;T0@0MH>9101fQ8T407J4R0<0MX>7101gQ8L407N3QP@0
Mh63101eOWl407=iNPL0LgQj101aN7T407MoO`@0NWmo101mPX8407f1P0<0O7]j101jNGL407McL@@0
Lf]Y101]Geh406]FE@<0J59@101WCTT406I:A0@0ITLo101UA3X406@o=0@0HST]0`1O<bH405lb9@@0
HCP[101T?S8406M4>P@0JTY10`1^D4P4079GC`@0MUeF101jI5d407mZI0@0Pg1[0`27MW8408]mN0@0
T8=o102DRHDF0?ooo`00503oool409N?S@@0UHn=102DShd309:>SP@0THn>102?SXl408j>S`@0S8j?
102;SY0308Z>T0@0R8jA1027SY4408J>T@@0QHjB1023SI84086=T@<0OhbA101nSI<407:3RP@0Lh>9
101dPhT407F4R@<0MH:6101fQ8L407N5R0@0Mh>6101eP844079kN`<0KWMh101fP80407EoO`@0Mh61
101iPH4407Z0P0@0O8:10`1mOgd407ilN`@0O7Me101hLFl406eTHP@0IUME0`1TCdd406=;A`@0HTM1
101SACh406=3>P@0HShd101P>Bd305hd9`@0G30R101L<RH405hg;0@0HShd101VAC/306Y<@`@0Ke=;
101cFU<407QQFP@0OFQQ1021KVT308IeL0@0RW]g102?PWh409B8QAH0oooo000D0?ooo`@0Uhn=102E
Shd409B?S@<0TXj>102AShh408n>S`@0SXj?102<SXl408^>T0<0RXj@1028SY4408N>T@@0QXjA1025
SY8408>=TP@0PHfA0`1oS94407j=T`@0LX>:101cPhT407B3R@@0MHB90`1ePXH407J4Q`@0MhF8101g
PhH407F0P@@0LW]k0`1^MgP407J0P0@0MGmo101gPH4407V1P@@0NX20101lPX4307eoO@@0OWak101l
MgD407QaK`@0KFAR101VEeD306A?C@@0Hd]7101RAd4406=5?P@0Hd<j101R?S@4060i;@<0GS@W101L
<28405`b9P@0GSL/101R?S@406I5>`<0JTa3101_Dd/407=JD`@0N65J101mJ644085^J@<0QWE`102:
NgL408n2OP@0U8R55P3oool001@0oooo102GShd409F?S@@0U8n=0`2BSXh4096?SP@0Shj?102>SXl4
08b>S`@0Rhj@0`2:SY0408R>T@@0QhjA1026SY4408F>TP@0PhfB1021SI4307n<T@@0OXfC101bPhX4
07>3R@@0M8>9101eQ8T307F2QP@0MXB7101gQHP407N3QP@0MH21101bNg/306igN0@0MX20101eOgl4
07N1P@@0NH61101jP80407b2P@<0OGmm101nO7/407agM@@0N75_101]I68406IGE@<0I4m=101SBdL4
0697@@@0HdDn101S@cX4068n=0@0H3T]0`1N=2L405``8P@0G38V101N=b`4068n=0@0ITDk0`1ZC4<4
06mCB`@0LeYC101hHEX407eXH@@0PFiY0`26MG0408YkM`@0Sh9n102DR8DF0?ooo`00503oool409N?
S@@0UHn=102DShd309:>SP@0THn>102?SXl408j>S`@0S8j?102;SY0308Z>T0@0R8jA1027SY4408J>
T@@0QHjB1023SI84086=T@<0OhbA101nSI<407:3RP@0Lh>9101dPhT407F4R@<0MH:6101fQ8L407N5
R0@0Mh>6101eP844079kN`<0KWMh101fP80407EoO`@0Mh61101iPH4407Z0P0@0O8:10`1mOgd407il
N`@0O7Me101hLFl406eTHP@0IUME0`1TCdd406=;A`@0HTM1101SACh406=3>P@0HShd101P>Bd305hd
9`@0G30R101L<RH405hg;0@0HShd101VAC/306Y<@`@0Ke=;101cFU<407QQFP@0OFQQ1021KVT308Ie
L0@0RW]g102?PWh409B8QAH0oooo000D0?ooo`@0Uhn=102EShd409>?SP<0TXn>102@SXh408n>S`@0
SHj?102<SY0408Z>T0<0RHjA1027SY4408J>TP@0QHjB1024SY<408:>T`@0P8fB0`1mRi4407f<T`@0
K7n7101`PHP407:3R0@0LhB90`1dQ8P407F5R0@0MXJ:101gQXT407J4Q@@0Mh:20`1_N7P4079iNP@0
M7]k101eNgX407ImO0@0N7ek101iO7/307UgMP@0NWId101kM70407acL0@0Mf]X101[GU`3061?C@@0
GTM4101NA3l40613?0@0HD8i101Q?S@405li;P<0GC<W101K;b0405T_8@@0FC4U101L=bd40650=P<0
ITPo101/CdL4075GC`@0MUiG101kIEl4081/I`<0QG=^1029NWH408j1O@@0ThR55P3oool001@0oooo
102GShd409F?S@@0Thn>0`2BShh4092>SP@0Shj?102=SXl408b>T0@0RXj@0`29SY4408N>T@@0QXjB
1025SY8408B>T`@0PXjC1020SI8307f;T@@0OHbC101/OhL40721R0@0LX>8101cQ8T307B4R0@0MHF8
101fQXX407N6R@@0MXB5101gPX8306mhN0@0LWUj101dNg/407EkNP@0MWel101hOG/407UlN`<0NGMf
101jMW@407]dL0@0O7=`101gJfP406]NG0<0H4m=101NAd@405i4?`@0H4<l101Q@ST4064n=0@0GcT^
0`1M<bL405/_80@0FBlQ101I<BD405`g;@@0HD0f0`1VB3l406a?A`@0LEM?101fGUL407]UG`@0P6aW
0`25Lfh408UjMP@0SX5m102CR8DF0?ooo`00503oool409N?S@@0UHn=102CShh309:?SP@0T8j>102?
SXl408f>S`@0S8j@102:SY0308V>T@@0QhjA1026SY8408F>TP@0Q8jC1022SY<4082=TP<0OH^A101m
S9<406aoQ`@0L868101bPhP407>4R@<0M8B8101eQHP407J6RP@0MhJ9101fQ8D407N2PP<0KgQh101b
NGX407AkN`@0MG]j101fOG`407QmN`@0NGak0`1iMgH407YfM0@0NgA`101lLg0407M[J0@0JeiL0`1P
Cdd405i7A0@0GT@o101P@c`40652>@@0HChd101O>Bh305dc9`@0FblP101I;b4405Ta9@@0G3L]101Q
@3H306I8?`@0K4m7101aEdl407INE`@0NfEO1020K6L308EcKP@0RGYf102>PGd409>8QAH0oooo000D
0?ooo`@0Uhn=102EShd409>?SP<0TXn>102@SXh408n>S`@0SHj?102<SY0408Z>T0<0RHjA1027SY44
08J>TP@0QHjB1024SY<408:>T`@0P8fB0`1mRi4407f<T`@0K7n7101`PHP407:3R0@0LhB90`1dQ8P4
07F5R0@0MXJ:101gQXT407J4Q@@0Mh:20`1_N7P4079iNP@0M7]k101eNgX407ImO0@0N7ek101iO7/3
07UgMP@0NWId101kM70407acL0@0Mf]X101[GU`3061?C@@0GTM4101NA3l40613?0@0HD8i101Q?S@4
05li;P<0GC<W101K;b0405T_8@@0FC4U101L=bd40650=P<0ITPo101/CdL4075GC`@0MUiG101kIEl4
081/I`<0QG=^1029NWH408j1O@@0ThR55P3oool001@0oooo102GShd409F?S@@0Thn>0`2AShh4092>
S`@0SXj?102<SXl408^>T0@0RHj@0`28SY4408J>TP@0QHjB1024Si<408B?U0@0PhnD1020SY<307N7
S@@0MHJ=101_P8P406n2R0@0LH:8101bPXP307:3R0@0M8F9101fR8`407N7R`@0N8V:101jRHT307B3
P`@0Lgio101cOGd407=kN`@0M7]k101fNWX407IjN@<0MWEc101gLW0407I^J`@0Mfi[101fJ6@4079R
GP<0IEEA101KAT8405]2?P@0GD4j101O@CP405ln=0@0GCT^0`1K=2P405X_8@@0F2hO101G;b8405Lb
:0@0GC/a0`1S@cX406Q<@`@0KU=<101cFe@407USG0@0OVYU0`23LVd408QiM@@0SX1l102CR8@F0?oo
o`00503oool409N?S@@0UHn=102CShh3096?SP@0T8j?102>SXl408b>S`@0Rhj@1029SY0308R>T@@0
QXjB1025SY8408B?T`@0Q8nD1023Si@4082>T`<0MhN=101eQXd406n0R0@0Kh:8101aPXP407:2R0<0
LX>8101dQHT407J8S0@0MhN;101hRHX407Z9R@<0M8>3101cOWl407=mO@@0Lg]k101dNg/407IjNP@0
MWYi0`1fMG<407MbL0@0MVi[101gKV/407IXI0@0LV9N0`1UEE4405]6@P@0Fd8n101M@CX405m1>0@0
Gchd101M>Bh305/d:0@0FRlQ101H;Ql405L_8P@0Ec8X101M>c4306=3>P@0J4a3101^Dd`407=KE0@0
NF=L101nJVD308=bK@@0R7Ue102>P7`409>8Q1H0oooo000D0?ooo`@0Uhn=102EShd409>?SP<0THn>
102@SXl408j>S`@0S8j?102;SY0408V>T0<0R8jA1026SY8408F>TP@0Q8nC1024Si@408>?U0@0P8jC
0`1gQhd407F6S@@0Kh28101_PXP40762R0@0LX:80`1bPhP407B5R@@0MXR<101gQh/407R9RP@0NXV9
0`1dPh<407=nO`@0Lgem101cNg/407AkN`@0MWYj101fNWT307IeL`@0Mg9`101fKV/407M^J`@0MVQT
101bHUh306EED@@0FdI2101K@Sh405e1>P@0Gd4h101O?S@405di;P<0Fc@X101J;b4405P^7`@0EblR
101G<RP405dk<@<0Hd<j101XC4<406iCC0@0Le]D101iHe`407iZI@<0Pg9]1028NGD408j0O0@0ThR4
5P3oool001@0oooo102FShd409F?S@@0Thn>0`2AShh408n>S`@0SHj?102;SXl408Z>T0@0R8jA0`26
SY4408F>TP@0Q8jC1023Si@408>@U@@0Q9:G1026U9/307^<TP@0Kh>:101`PXX406n2R@@0Kh>9101`
PXT30723R@@0LXF:101dQh`407B5R0@0LX63101cPX@307:2PP@0LX61201cP80407B1P0@0MWmn101f
OW`307IkN@@0MWMc101dL6d407A]J@@0LfQS101aHEd306]JE@@0GTY6101I@Cd405]0>P@0GD0h101N
?S@405di;P<0FS@X101I;b8405DZ70@0CRLJ101C;R<405Tf;0<0Gd0f101UB40406]@B@@0LEUB101f
HEX407aXH`<0PW1[1027N7<408f0O0@0ThN45P3oool001@0oooo102FShd409F?S@@0Thn>0`2AShh4
08n>S`@0SHj?102;SXl408Z>T0@0R8jA0`26SY4408F>TP@0Q8jC1023Si@408>@U@@0Q9:G1026U9/3
07^<TP@0Kh>:101`PXX406n2R@@0Kh>9101`PXT30723R@@0LXF:101dQh`407B5R0@0LX63101cPX@3
07:2PP@0LX61201cP80407B1P0@0MWmn101fOW`307IkN@@0MWMc101dL6d407A]J@@0LfQS101aHEd3
06]JE@@0GTY6101I@Cd405]0>P@0GD0h101N?S@405di;P<0FS@X101I;b8405DZ70@0CRLJ101C;R<4
05Tf;0<0Gd0f101UB40406]@B@@0LEUB101fHEX407aXH`<0PW1[1027N7<408f0O0@0ThN45P3oool0
01@0oooo102FShd409F?S@@0Thn>0`2AShh408n>S`@0SHj?102;SXl408Z>T0@0R8jA0`26SY4408F>
TP@0Q8jC1023Si@408>@U@@0Q9:G1026U9/307^<TP@0Kh>:101`PXX406n2R@@0Kh>9101`PXT30723
R@@0LXF:101dQh`407B5R0@0LX63101cPX@307:2PP@0LX61201cP80407B1P0@0MWmn101fOW`307Ik
N@@0MWMc101dL6d407A]J@@0LfQS101aHEd306]JE@@0GTY6101I@Cd405]0>P@0GD0h101N?S@405di
;P<0FS@X101I;b8405DZ70@0CRLJ101C;R<405Tf;0<0Gd0f101UB40406]@B@@0LEUB101fHEX407aX
H`<0PW1[1027N7<408f0O0@0ThN45P3oool001@0oooo102FShd409F?S@@0Thn>0`2AShh408n>S`@0
SHj?102;SXl408Z>T0@0R8jA0`26SY4408F>TP@0Q8jC1023Si@408>@U@@0Q9:G1026U9/307^<TP@0
Kh>:101`PXX406n2R@@0Kh>9101`PXT30723R@@0LXF:101dQh`407B5R0@0LX63101cPX@307:2PP@0
LX61201cP80407B1P0@0MWmn101fOW`307IkN@@0MWMc101dL6d407A]J@@0LfQS101aHEd306]JE@@0
GTY6101I@Cd405]0>P@0GD0h101N?S@405di;P<0FS@X101I;b8405DZ70@0CRLJ101C;R<405Tf;0<0
Gd0f101UB40406]@B@@0LEUB101fHEX407aXH`<0PW1[1027N7<408f0O0@0ThN45P3oool001@0oooo
102FShd409B?S@@0TXn>0`2@Shl408j>S`@0S8n@102:SY0408V>T@@0QhjA0`25SY8408>>TP@0PXjC
1022Si@408:@UP@0QIBI102;VIl308FDV@@0MHN>101`PhX406j2R@@0KH>91`1^PXT40725RP@0LXN<
101bQHT406inP@@0KWeo1`1_OWl4071nO`@0LGio101bOgl407=nOP@0Lgak0`1cNGL4079eLP@0LG5^
101_KFP406iYI0@0KFAO0`1[GUP406ADCP@0G4M2101J@S/405a0>@@0GChe101L>S0305Xe:P@0FC4U
101I;b8404XT60@0CRXO101E<bT305`l<`@0HTDl101XCTH406iFC`@0M5iH101kIf43081_JP@0QWMb
102<Og/409:7Q1H0oooo000D0?ooo`@0UXn=102DShd409:?SP<0T8n?102>SXl408b?T0@0RXj@1029
SY4408N>T@<0QHjB1023SY8408:>T`@0PXnD1022T9H408FDV@@0RiVO0`25U9T407F7SP@0L8>:101^
PXT406f3R@L0KX:9101`QHX407:7S0@0LXF9101^OX4406imO`L0Kgio101`OWl4075nO`@0LWmo101c
OWh407=lN`<0LgUg101bMG84075aKP@0KfeX101^JF@406eTG`<0JeiH101TE4h405a7@P@0FT8k101L
@3T405dn=@@0G3X`0`1J=BX405Ta9@@0FBlR101:91P404hZ7`@0EC<Y0`1L?3<40695?0@0J4i6101^
ETl407ANF0@0NfMQ0`20KfX408IgLP@0S7mk102BQh@F0?ooo`00503oool409J?S@@0U8n=102BShh3
092?S`@0SXj?102<Si0408Z>T0@0RHjA1027SY4308F>TP@0PhjB1022SY<408:?U0@0PY2F1025U9T4
08^IW`<0QIBI101eQhh40723RP@0KX:9101]PhT706j2R@@0L8F:101bQh`407:5R@@0KWj1101^OGl7
06mnO`@0L7io101aOWl4079oO`@0Lgin101cO7/307=iM`@0LWEb101aLFh406m]J0@0KVUT101]I5l3
06]NF0@0I5A>101LAd8405Y2>`@0G40i101M?SD405`j<0<0FSDZ101I<BD405T_8P@0BR@H101>:Ql4
05Dc:@<0G3`c101RAC`406Q>AP@0KUI?101dGUP407]WH@<0P6mZ1026Mg8408aoN`@0TXN45P3oool0
01@0oooo102FShd409B?S@@0TXn>0`2@Shl408j>S`@0S8n@102:SY0408V>T@@0QhjA0`25SY8408>>
TP@0PXjC1022Si@408:@UP@0QIBI102;VIl308FDV@@0MHN>101`PhX406j2R@@0KH>91`1^PXT40725
RP@0LXN<101bQHT406inP@@0KWeo1`1_OWl4071nO`@0LGio101bOgl407=nOP@0Lgak0`1cNGL4079e
LP@0LG5^101_KFP406iYI0@0KFAO0`1[GUP406ADCP@0G4M2101J@S/405a0>@@0GChe101L>S0305Xe
:P@0FC4U101I;b8404XT60@0CRXO101E<bT305`l<`@0HTDl101XCTH406iFC`@0M5iH101kIf43081_
JP@0QWMb102<Og/409:7Q1H0oooo000D0?ooo`@0UXn=102DShd409:?SP<0T8n?102>SXl408b>T0@0
RXj@1027SY4408F=T@<0PhfB1022SI84082=T`@0OhjD101oSiD4082AU`@0OhnF0`1kS9<407>6SP@0
KX:9101[P8P406^1R0@0Jh:80`1/PXT406f4RP@0KhF;101_Q8P406anP@@0JWUl0`1[NW/406akO@@0
KGam101^O7d406mnOP@0LGem101aNWX3071fM@@0Kg=a101^Kf`406]ZI`@0JFEQ101XGe/306EJE0@0
HE9<101MBTD405]5?P@0Fd8j101L?cH405/j<@<0FCH[101I<bH405P`8P@0Ab8G101;9ad4054`9P<0
F3T`101O@ST406I;@`@0K5A=101cG5H407UUG`<0OfeX1025MW4408anNP@0TXN35P3oool001@0oooo
102FShd409B?S@@0TXn>0`2@Shl408j>S`@0S8j@102:SY0408N>T@@0QHfA0`23SI8408:=TP@0P8fC
101oSY@407n?U@@0P96G101oSiH307^<T`@0LhJ>101^PXT406^0R0@0Jh68101[PXP306b2R@@0KHB:
101_QH/406n4R0@0K7j1101ZNG`306]jN`@0K7]m101]O7d406ilO@@0Kgin101aOGd4075jNP<0L7Ie
101_Lg4406i_K0@0JfYW101YIF4406QOF`<0IEYD101QDT`405e:A@@0FdDn101K@SX405`o=P@0FcXa
0`1I=R/405Tc9P@0F30R10178QL404/W7@@0DC0V0`1H>C0405m2>@@0IT]3101/E4d407=LEP@0NFEO
0`1oKFP408EfL@@0S7ij102BQh<F0?ooo`00503oool409J?S@@0U8n=102BShh3092?S`@0SXj?102<
SY0408Z>T0@0QhjA1025SI4308>=TP@0PXfB1020SI<407n>U0@0OhnE1020TIL407n?UP<0NhbC101c
QXh406j2R@@0Jh28101[PHP406^2R0<0K8:9101]Q8X406n5R`@0KhB8101/OX4406YiO0<0JgYk101/
Ngd406elO@@0KWam101_OWh4075mO@@0LGYj0`1`MWD406mcL@@0KVm/101[JVL406UUH@@0J5mK0`1U
FU@4065BC0@0GDY5101KACh405]2>P@0G3lf101K>S4305Tf:`@0FC<V101H<28404LR5`@0BbLM101A
<2H305Pi<0@0Gd8i101VBd<406aDC@@0LeaF101iIEl307m]J0@0QGIa102<OWX409:7PaH0oooo000D
0?ooo`@0UXn=102DShd409:?SP<0T8n?102>SXl408b>T0@0RXj@1027SY4408F=T@<0PhfB1022SI84
082=T`@0OhjD101oSiD4082AU`@0OhnF0`1kS9<407>6SP@0KX:9101[P8P406^1R0@0Jh:80`1/PXT4
06f4RP@0KhF;101_Q8P406anP@@0JWUl0`1[NW/406akO@@0KGam101^O7d406mnOP@0LGem101aNWX3
071fM@@0Kg=a101^Kf`406]ZI`@0JFEQ101XGe/306EJE0@0HE9<101MBTD405]5?P@0Fd8j101L?cH4
05/j<@<0FCH[101I<bH405P`8P@0Ab8G101;9ad4054`9P<0F3T`101O@ST406I;@`@0K5A=101cG5H4
07UUG`<0OfeX1025MW4408anNP@0TXN35P3oool001@0oooo102FShd409B?SP@0TXn>0`2@Shl408f>
T0@0Rhj@1029SY4408J>T@@0Q8fB0`22SI8407n<TP@0OHbC101lS9<407Z<T`@0N8bD101fRI0307:4
S0@0KX28101YOXL406QmQ@@0J7j5101XOhH306R0Q`@0JH68101[PhT406^1Q`@0JWj2101XN7/306Qg
N@@0JGQj101ZNW/406aiN`@0KG]l101^O7`406iiNP<0KWEe101]L70406a]J`@0JFQU101VHel406AM
FP<0HUQC101ODT`405a:A@@0FdI0101J@c`405]0=`@0FS/b0`1J=bd405Xe:0@0Fc8T101581@404HS
60@0CR`R0`1E=R`405`o=`@0HdU1101ZDTX4075KE0@0Mf=N0`1nK6L408EeL0@0Rgij102BQX<F0?oo
o`00503oool409J?S@@0U8n>102BShh3092?S`@0SHj@102;SY0408V>T@@0QXjA1024SI8308:=TP@0
OhbB101mS9<407b<T`@0NXbC101hS9@407J9T0<0LXB<101^P8P406UnQ`@0J7f5101XOXD406QoQP<0
J827101YPHP406^3R@@0Jh67101ZOX8406QhN`<0J7Mi101YN7X406YjN`@0K7Uk101]Ng`406ilO0@0
KWUj0`1^MGD406e`L0@0K6e[101YJ6D406ISG`@0I5eJ0`1RF5<405mBC0@0G4Y5101KAT0405Y3?0@0
Fd0g101J>c8305Xg;@@0FSDX101K<R@404DP50@0AR<H101>;28305Df;0@0G3lg101SBD4406YBBP@0
LE]D101gHeh307i/I`@0QGE`102;OWX409:6PaH0oooo000D0?ooo`@0UXn=102DShh409:?SP<0T8n?
102=SY0408^>T0@0RHjA1026SY4408B=TP<0PXfB101oS98407f<T`@0O8bC101jS9<407R<U0@0MXV@
0`1bQ8`406j0R0@0JGj7101XOHD406QnQ@@0J7n60`1XP8L406V1R0@0Jh>9101[PHL406YnPP@0J7Qk
0`1XMgT406UhNP@0JWYk101/NG/406ekO0@0KWal101^NGX306ieM@@0KG1`101/KF/406UXI@@0IV=O
101TGEX3069HD`@0Ge9<101LBTD405]6@0@0FT<l101K@3L405Xk<P<0FSL]101J=BP405/b90@0AB0D
10168aP404h/8P<0ECH/101L?cL406=9@@@0JU9:101aFe@407MSGP<0OVaW1025MG0408]nNP@0TXJ3
5P3oool001@0oooo102FShd409B?SP@0TXn>0`2@Shl408f>T0@0Rhj@1029SY4408J>T@@0Q8fB0`22
SI8407n<TP@0OHbC101lS9<407Z<T`@0N8bD101fRI0307:4S0@0KX28101YOXL406QmQ@@0J7j5101X
OhH306R0Q`@0JH68101[PhT406^1Q`@0JWj2101XN7/306QgN@@0JGQj101ZNW/406aiN`@0KG]l101^
O7`406iiNP<0KWEe101]L70406a]J`@0JFQU101VHel406AMFP<0HUQC101ODT`405a:A@@0FdI0101J
@c`405]0=`@0FS/b0`1J=bd405Xe:0@0Fc8T101581@404HS60@0CR`R0`1E=R`405`o=`@0HdU1101Z
DTX4075KE0@0Mf=N0`1nK6L408EeL0@0Rgij102BQX<F0?ooo`00503oool409J?S@@0U8n>102BShl3
08n?S`@0SHn@102:SY4408R>T@@0QHfA1022SI83082<TP@0OHbB101jRi8407R:TP@0MXVB101cQi04
0724S@<0K828101YO8@406IkP`@0IGZ2101TNX8406AlP`<0IGf4101UOXD406J0QP@0Ign5101WOH84
06EhO0<0I7Ag101VMWP406MiN`@0JGUk101[NG/406ajO0@0K7Qi0`1/MGD406Y`K`@0JFa[101VIV@4
06=PGP@0H5]H0`1OEe<405eBCP@0Fda7101JB48405U4?@@0FD0h101I?3<305Th;P@0FSHZ101N=BL4
04TS5`@0@QhC101::1h3058c:@@0FSdd101QASh406Q@B@@0KeUB101fHU`307e[IP@0Q7A_102:OGT4
0966PaH0oooo000D0?ooo`@0UXn=102DShh409:?S`<0Shn?102=Si0408Z>T@@0R8jA1025SI4408:=
TP<0P8bB101mS98407Z;TP@0N8ZB101fRI8407>7T0@0L8B=0`1/P8P406UlQ0@0IW^3101UNX8406Aj
PP@0I7b30`1UOH@406EnQ@@0IX26101WOhD406MmPP@0IGQl0`1TM7L406IfN0@0IgUk101YNG/406]i
N`@0K7Yl101/N7T306aeM@@0JW1_101YK6/406IVI0@0Hf1N101PFeP305mGD`@0GE9>101KC4L405Y8
@P@0FD@m101I@3P405Tl<`<0FCP^101J=RX405he9`@0BB<G10127Q<404XX7P<0DS<Y101J?C@40656
?P@0J519101_FE8407IRG0<0OF]V1024M6l408YmN@@0THJ35P3oool001@0oooo102FShd409B?SP@0
TXn?0`2?Shl408f?T0@0RXjA1028SY4408F=T@@0PXfB0`20S98407f<TP@0NX^B101hRY8407J9TP@0
LhN@101`Q8d306b0R0@0JGb4101VNh<406EjPP@0I7Z2101TO8<306EmQ0@0IGj5101VP8H406MoQ@@0
Igf2101UN7`306AdM`@0IWIh101WNG/406UiN`@0JgUk101/NW`406ahN@<0K7Ee101ZL6l406U/J`@0
IVIT101SH5h4061KF0<0GeMC101MDTh405]<A`@0FTQ2101IA3d405U0>0@0FC`c0`1I>2h405Xf:P@0
GSDW10198aL4048N4`@0BRPN0`1B<bT405Xm=0@0HDHn101XD4T406mIDP@0MV9L0`1mJfH408AdK`@0
RWei102AQX<F0?ooo`00503oool409J?S@@0U8n>102BShl308n?S`@0SHn@102:SY4408R>T@@0QHfA
1022SI83082<TP@0OHbB101jRi8407R:TP@0MXVB101cQi040724S@<0K828101YO8@406IkP`@0IGZ2
101TNX8406AlP`<0IGf4101UOXD406J0QP@0Ign5101WOH8406EhO0<0I7Ag101VMWP406MiN`@0JGUk
101[NG/406ajO0@0K7Qi0`1/MGD406Y`K`@0JFa[101VIV@406=PGP@0H5]H0`1OEe<405eBCP@0Fda7
101JB48405U4?@@0FD0h101I?3<305Th;P@0FSHZ101N=BL404TS5`@0@QhC101::1h3058c:@@0FSdd
101QASh406Q@B@@0KeUB101fHU`307e[IP@0Q7A_102:OGT40966PaH0oooo000D0?ooo`@0UXn=102D
Shh4096?S`<0Shn@102<Si0408Z>T@@0QhjB1024SI84086=TP<0OXbB101jRi8407N:TP@0M8RA101a
Qi4406f2S0@0JWn80`1UNH<406=hP@@0HGR0101QMgl4061gO`@0HGR01`1QNX84069lP`@0Hgb3101S
Nh44069gO0<0HG=g101RM7L406AfN0@0IWIi101XMgX406YhNP@0JWIh0`1YLW<406M^KP@0IFYY101R
I6<4061OG0@0G5UF0`1KE54405Y@C@@0FDa8101HBD<405M5?P@0Ed0i101G?3@305Li;`@0FCL[101O
>2/405H^80@0Ab4E10158QP3050`9`@0F3/b101OA3`406I>A`@0KEMA101dHE/307]ZI@@0Pg=_102:
O7P40966PQH0oooo000D0?ooo`@0UXn=102DShh4096?S`<0Shn@102<Si0408Z>T@@0QhjB1024SI84
086=TP<0OXbB101jRi8407N:TP@0M8RA101aQi4406f2S0@0JWn80`1UNH<406=hP@@0HGR0101QMgl4
061gO`@0HGR01`1QNX84069lP`@0Hgb3101SNh44069gO0<0HG=g101RM7L406AfN0@0IWIi101XMgX4
06YhNP@0JWIh0`1YLW<406M^KP@0IFYY101RI6<4061OG0@0G5UF0`1KE54405Y@C@@0FDa8101HBD<4
05M5?P@0Ed0i101G?3@305Li;`@0FCL[101O>2/405H^80@0Ab4E10158QP3050`9`@0F3/b101OA3`4
06I>A`@0KEMA101dHE/307]ZI@@0Pg=_102:O7P40966PQH0oooo000D0?ooo`@0UXn=102DShh4096?
S`<0Shn@102<Si0408Z>T@@0QhjB1024SI84086=TP<0OXbB101jRi8407N:TP@0M8RA101aQi4406f2
S0@0JWn80`1UNH<406=hP@@0HGR0101QMgl4061gO`@0HGR01`1QNX84069lP`@0Hgb3101SNh44069g
O0<0HG=g101RM7L406AfN0@0IWIi101XMgX406YhNP@0JWIh0`1YLW<406M^KP@0IFYY101RI6<4061O
G0@0G5UF0`1KE54405Y@C@@0FDa8101HBD<405M5?P@0Ed0i101G?3@305Li;`@0FCL[101O>2/405H^
80@0Ab4E10158QP3050`9`@0F3/b101OA3`406I>A`@0KEMA101dHE/307]ZI@@0Pg=_102:O7P40966
PQH0oooo000D0?ooo`@0UXn=102DShh4096?S`<0Shn@102<Si4408V?TP@0QXjB1023SY<407n=T`<0
O8bC101hRi8407B9TP@0L8NA101/Phh406MmR0@0HgR30`1NM7h405]dOP`0G7Am101LMGd305efOP@0
GGIo101MMgl405igO`@0GgMm101OMG/305icM`@0H7=f101QM7L406=dM`@0IGEh101WMGP406MdMP<0
IVma101TJf`4065VI`@0GV9Q101KG5/405UFE0<0Ee=@101FCT/405I;A`@0ETM2101E@cd405@o>0@0
E3/c0`1D=bh405Dd:P@0Ec@Y101F<2@4058[7P@0C2TO0`1@<2L405Hi<@@0GD8k101TC4D406]FC`@0
LUmJ0`1jJF@4089bKP@0RGah102AQH8F0?ooo`00503oool409J?S@@0U8n>102AShl308n?T0@0S8nA
1029Si8408J>TP@0PhjC101oSI<307b<T`@0N8^B101dRI840727T@@0K8>>101WOHP406=hP`<0GWAn
101KM7h<05adO@@0G7Em0`1MMWh405efO`@0GGMo101NMgl405mgO@@0GgEk0`1NLgL4061cMP@0HGAg
101SM7L406EeN0@0IgEh101WM7H306I_L@@0I6]/101QIVL405iRH@@0FeaK101IEU@305MCD0@0ETi;
101FBdL405I7@P@0ED<m101D?cP405@k<`<0E3L^101E=2X405Ld:@@0ES0T101B:ah404`Y7`<0D30W
101F>C4405e2>`@0I4a5101[ETl4079OFP<0NVUT1022LVh408UlN0@0THF25P3oool001@0oooo102F
Shd409B?SP@0THn?0`2?Si0408b?T@@0RHnB1026SY8408>>T`@0OhfC0`1lS9<407R;TP@0M8VB101`
Qi4406b3SP@0Igf8101SN8<305idOP@0FgAn301LM7d405aeO@<0GGIn101MMWl405egO`@0GWMo101O
Mgd405meN`<0GW=g101PLgH4065dM`@0HgAg101UMGP406MeN0@0IgAf0`1VKg4406A[K0@0HFIW101N
HV4405]LF`@0FEID0`1GDe0405I>B`@0ET]7101FAd8405E3?@@0E3lh101D>c<305@g;P@0EC@Z101G
=2T405H`90@0DR/N101<:Al3050`9`@0ESTa101M@S/406A<A@@0JeI?101bGeX307YYI0@0PW9^1029
O7P40965PQH0oooo000D0?ooo`@0UXn=102DShh4096?S`<0Shn@102<Si4408V?TP@0QXjB1023SY<4
07n=T`<0O8bC101hRi8407B9TP@0L8NA101/Phh406MmR0@0HgR30`1NM7h405]dOP`0G7Am101LMGd3
05efOP@0GGIo101MMgl405igO`@0GgMm101OMG/305icM`@0H7=f101QM7L406=dM`@0IGEh101WMGP4
06MdMP<0IVma101TJf`4065VI`@0GV9Q101KG5/405UFE0<0Ee=@101FCT/405I;A`@0ETM2101E@cd4
05@o>0@0E3/c0`1D=bh405Dd:P@0Ec@Y101F<2@4058[7P@0C2TO0`1@<2L405Hi<@@0GD8k101TC4D4
06]FC`@0LUmJ0`1jJF@4089bKP@0RGah102AQH8F0?ooo`00503oool409J?S@@0U8n>102ASi0308j?
T@@0S8nB1029Si8408F?T`@0PXjC101nSI<307Z<T`@0MXZC101aRI8406b7TP@0Ih:>101RO8L405ac
O`<0FG1j101GL7X405MaN`P0F75k1`1HLW/405UbN`@0FG=k101JLW/405YbN@@0FW1g0`1JKgD405a`
MP@0Gg=g101QLgL406=eN0@0IGEh101ULgD306=^L0@0HFU[101MI6D405]OH0@0F5YJ101EEE@305AA
C`@0DTe:101CBTH40596@P@0DD8m101@?SP4050i<`<0CcD^101?<BT404l`9P@0CBXO101:91P404/X
7P<0CRlU101D=bl405]1>@@0HTY3101YE4h4075NF0<0NFQS1020LFd408QkM`@0T8F25P3oool001@0
oooo102FShd409B?SP@0THn@0`2>Si4408b?TP@0RHnB1025Si<408:>T`@0OXfC0`1jS9<407J:T`@0
LHVB101/Qi8406N2SP@0HWb7101LLgl305U`NP@0Eg1j101GLG/805QaN`L0F79k101ILW/405UcN`@0
FW9k101JLWT405Y`M`<0FVme101LL7H405mcM`@0HG=g101SMGP406EeN0@0IG=e0`1SKW04065YJ`@0
GFAU101KGf0405QJFP@0EEED0`1DDDl4059=BP@0DdY6101BAT840552?@@0D3hh101@>C<304le;P@0
Cc4Y101?<2H404dZ7`@0BR@H101;:1h304h_9@@0E3L_101K@CT4069:@`@0JEA>101aGUP307UXH`@0
P75]1028NgL40925PQH0oooo000D0?ooo`@0UXn=102DShh4096?T0<0SXnA102<Si8408V?TP@0QHnC
1022SY<407j=T`<0NXbC101fRY<40769TP@0K8NB101WPXh4069lQ`@0G7=o0`1IL7X405M`NP@0Eg5k
201HLG/705QbN`@0FG9k101ILg/405YbN`@0FW9i101JL7L305Y_M@@0G71f101OLgL4065cM`@0HgEh
101UMGP406EcM@<0Hfi`101QJF/405eTI@@0FemP101HFUX405EEE0<0E55?101BCDX405=:AP@0DTI2
101A@Sd4050n>0@0D3Tc0`1?=Bh404la:@@0Cc0V101=:Ql404XT60@0BbPN0`1>;bD405@g;`@0Fd4i
101RBT<406UDCP@0LEiH0`1iJ6<4081aK@@0R7]g102@QH8F0?ooo`00503oool409J?S@@0U8n>102A
Si0308j?T@@0S8nB1029Si8408F?T`@0PXjC101nSI<307Z<T`@0MXZC101aRI8406b7TP@0Ih:>101R
O8L405acO`<0FG1j101GL7X405MaN`P0F75k1`1HLW/405UbN`@0FG=k101JLW/405YbN@@0FW1g0`1J
KgD405a`MP@0Gg=g101QLgL406=eN0@0IGEh101ULgD306=^L0@0HFU[101MI6D405]OH0@0F5YJ101E
EE@305AAC`@0DTe:101CBTH40596@P@0DD8m101@?SP4050i<`<0CcD^101?<BT404l`9P@0CBXO101:
91P404/X7P<0CRlU101D=bl405]1>@@0HTY3101YE4h4075NF0<0NFQS1020LFd408QkM`@0T8F25P3o
ool001@0oooo102FShd409B@S`@0TI2@0`2?T94408b@TP@0RI2C1025Si@4086>U0@0OHfD0`1iS9@4
07B;U0@0KXRB101XQI040660R`@0FWR4101DKg/3055[M`@0DFag101BKGP405=^N@@0E6mi2`1DKgP4
05A^M`@0E6ef101DKGD405E[L`<0EV]a101HKG<405]`M0@0GW9f101QM7P406=dN0@0I75d0`1RKG04
05mXJP@0Ff=T101GGEh405AGE`@0DE9B0`1@CTd404m;B@@0CTQ5101>AD4404e1?0@0C3dg101;>383
04Xd;@@0BBlW1019;BD404LV70@0@b0E10158aT304/[8P@0DCD]101H?SL405m8@P@0Ie9<101_G5L3
07MVHP@0Og1/1028NgL40925PAH0oooo000D0?ooo`@0UXn=102DT8l4096@T0<0Si2A102<T98408V@
T`@0QHnD1021SY@407f=U0<0NHbD101dRi@406j8TP@0J8F@101QP8/405YhQ0@0E6mk0`1AJgL4055/
M`@0DVeh101CKWT405A_N@/0E6mh101DKWL405A]MP@0E6ee101EJg<305I[L@@0F6ec101KL7@405ib
MP@0HGAh101SM7P406AaM0<0HVe`101OJ6X405]SI0@0EeeN101DEeL4055BDP<0D4i=101?BdT404i8
A@@0CTE1101=@C`404`m=`@0BcPb0`1:=2d404T_9`@0BBdU10179Q`404<P5@@0AB<I0`1;:b84054e
;@@0F3hg101OB48406MBC0@0KeaG0`1gIV8407m`K0@0R7]g102@QH4F0?ooo`00503oool409J?S@@0
U92?102AT90308n@T@@0S92B1029T9<408F?U0@0PHjD101mSI@307V<U0@0M8^D101^R98406R5T0@0
HH2;101JN8@405A_N`<0DF]g101AK7L4059]N0@0Dfii101DKgT;05A_N0@0E6ig101DKGH405A]M@@0
EF]c0`1FJg4405Q]L`@0Fg1d101NLWH4065dN0@0HgAh101TLG@3069]L0@0GfQZ101KHf@405MMGP@0
E5MG101ADU83051>C@@0Cd]9101>B4D404i5@@@0CD4l101<?CL404/h<P<0BS@]1019;bL404T]9@@0
AbHL101381D404DS6@<0Bb/R101A=Bd405Pn=`@0GdQ2101WDT`406mLE`<0MfIR101oL6`408QkM`@0
T8F15P3oool001@0oooo102FShd409B@S`@0TI2@0`2?T94408b@TP@0RI2C1025Si@4086>U0@0OHfD
0`1iS9@407B;U0@0KXRB101XQI040660R`@0FWR4101DKg/3055[M`@0DFag101BKGP405=^N@@0E6mi
2`1DKgP405A^M`@0E6ef101DKGD405E[L`<0EV]a101HKG<405]`M0@0GW9f101QM7P406=dN0@0I75d
0`1RKG0405mXJP@0Ff=T101GGEh405AGE`@0DE9B0`1@CTd404m;B@@0CTQ5101>AD4404e1?0@0C3dg
101;>38304Xd;@@0BBlW1019;BD404LV70@0@b0E10158aT304/[8P@0DCD]101H?SL405m8@P@0Ie9<
101_G5L307MVHP@0Og1/1028NgL40925PAH0oooo000D0?ooo`@0UXn>102DT8l4096@T@<0Si6B102<
TI<408VAU0@0QI2E1021SiH407f>UP<0N8fF101cRiD406b9U@@0I8:=101INHH404m`O@@0BFQf0`19
Ig@404]XM0@0CFYe101?JgH4051/M`L0DFeg101@K7H404m[M@@0CVUc101?J74404mWL0<0DFQ^101D
JW0405Q]LP@0Fg1e101NLgL4065dN0@0HW5d0`1OK6l405aVJ0@0FF1R101DFU`4051EEP@0CU1@0`1<
C4/404]9A`@0BTI4101:@d0404U0?0@0B3`g1016=c4304Db;0@0@bdV1012:R84040R6@@0?ahD1010
7A<304HX7`@0CC8Z101D?3D405a6@0@0IE1;101]FeH307EUH@@0OW1/1027NWH40924PAH0oooo000D
0?ooo`@0UXn>102DT8l4096@T@<0Si6B102<TI<408VAU0@0QI2E1021SiH407f>UP<0N8fF101cRiD4
06b9U@@0I8:=101INHH404m`O@@0BFQf0`19Ig@404]XM0@0CFYe101?JgH4051/M`L0DFeg101@K7H4
04m[M@@0CVUc101?J74404mWL0<0DFQ^101DJW0405Q]LP@0Fg1e101NLgL4065dN0@0HW5d0`1OK6l4
05aVJ0@0FF1R101DFU`4051EEP@0CU1@0`1<C4/404]9A`@0BTI4101:@d0404U0?0@0B3`g1016=c43
04Db;0@0@bdV1012:R84040R6@@0?ahD10107A<304HX7`@0CC8Z101D?3D405a6@0@0IE1;101]FeH3
07EUH@@0OW1/1027NWH40924PAH0oooo000D0?ooo`@0UXn>102DT8l4096@T@<0Si6B102<TI<408VA
U0@0QI2E1021SiH407f>UP<0N8fF101cRiD406b9U@@0I8:=101INHH404m`O@@0BFQf0`19Ig@404]X
M0@0CFYe101?JgH4051/M`L0DFeg101@K7H404m[M@@0CVUc101?J74404mWL0<0DFQ^101DJW0405Q]
LP@0Fg1e101NLgL4065dN0@0HW5d0`1OK6l405aVJ0@0FF1R101DFU`4051EEP@0CU1@0`1<C4/404]9
A`@0BTI4101:@d0404U0?0@0B3`g1016=c4304Db;0@0@bdV1012:R84040R6@@0?ahD10107A<304HX
7`@0CC8Z101D?3D405a6@0@0IE1;101]FeH307EUH@@0OW1/1027NWH40924PAH0oooo000D0?ooo`@0
UXn>102DT8l4096@T@<0Si6B102<TI<408VAU0@0QI2E1021SiH407f>UP<0N8fF101cRiD406b9U@@0
I8:=101INHH404m`O@@0BFQf0`19Ig@404]XM0@0CFYe101?JgH4051/M`L0DFeg101@K7H404m[M@@0
CVUc101?J74404mWL0<0DFQ^101DJW0405Q]LP@0Fg1e101NLgL4065dN0@0HW5d0`1OK6l405aVJ0@0
FF1R101DFU`4051EEP@0CU1@0`1<C4/404]9A`@0BTI4101:@d0404U0?0@0B3`g1016=c4304Db;0@0
@bdV1012:R84040R6@@0?ahD10107A<304HX7`@0CC8Z101D?3D405a6@0@0IE1;101]FeH307EUH@@0
OW1/1027NWH40924PAH0oooo000D0?ooo`@0UY2>102DT90409:ATP<0Si:C102<TYD408VBUP@0QY6G
1021T9L407f?U`<0N8jG101bSIP406f<V0@0I8>?101EMX@404Q[NP@0?F5`0`11HW0404EULP@0B6Md
101;JGD404e[MP@0CVag0`1>K7H404a[M@@0BfUd1019IW0404QSK@@0BF9[0`1<Hf/404mVK@@0E6Y`
101IKW@405ebM`@0Gg=g101PL7@305e[KP@0FVEW101EGV04055HFP@0CE=D101:CTh304M:BP@0ATI5
1015@d4404E0?P@0A3dj1013>SD4048f<@<0@34[100n:bD403dY8P@0>AlG100h71<403XI40<0@B@L
1019;bP4054i<`@0FD@n101RCdT406]IE@<0M6AP101mKf/408IiMP@0ShB15P3oool001@0oooo102F
T8h409B@T0@0TY6B0`2?TY<408bBU@@0RI:F1026TIL4086@U`@0OHnG0`1hSYL407:=V0@0KHbH101T
Phl405EfQ0@0B6]j100mHG03045RL0@0AFEb1018Ig@404]YM@@0CF]f101>K7L304i/MP@0C6]e101;
JG@404UVL0@0B6=]1019HV/304aSJ`@0CfI]101DJW0405U^M0@0GG9g101OLgL4061`M0<0GF]^101J
IFL405ENH0@0DEQJ101=De@404Y>CP<0AdY:1016ATD404E3@@@0AD0n1014?CX404<j=@@0@SHa0`10
<B/403h[9@@0?BTR100i7aL403PL4`@0>QT@0`1191`404T_:0@0DCTc101IA3h4069?B@@0JeUE0`1d
I60407e_J`@0QWUf102?Q84F0?ooo`00503oool409J@SP@0U92@102BTI8308nBT`@0S9:E1029TYH4
08JAU`@0PI2G101mSiL307R>U`@0LXfH101]S9P406B3S`@0EGJ41018JgX403eQL0<0@F9`1015IG84
04QWM0@0BfUe101=JgH404i/M`<0CVaf101<JgD404]YM0@0BFI`1018Hfd404URJ`<0C6=[101?IVd4
05AZL0@0FFid101MLWL405mcM`@0H71d0`1MJfh405YUI`@0EEiP101AF5X404eCE0@0BTi>0`17BTX4
04I6A@@0AD=11015@3h404@m>P@0@cXe1012=S43040a:`@0?R/U100m:B8403TO5`@0>1`C100j6A03
044T70@0BBlX101A>C<405U4?P@0HTm9101[FED307ATH0@0OFm[1026NGH408n4PAH0oooo000D0?oo
o`@0UY2>102DT90409:ATP<0Si:C102<TYD408VBUP@0QY6G1021T9L407f?U`<0N8jG101bSIP406f<
V0@0I8>?101EMX@404Q[NP@0?F5`0`11HW0404EULP@0B6Md101;JGD404e[MP@0CVag0`1>K7H404a[
M@@0BfUd1019IW0404QSK@@0BF9[0`1<Hf/404mVK@@0E6Y`101IKW@405ebM`@0Gg=g101PL7@305e[
KP@0FVEW101EGV04055HFP@0CE=D101:CTh304M:BP@0ATI51015@d4404E0?P@0A3dj1013>SD4048f
<@<0@34[100n:bD403dY8P@0>AlG100h71<403XI40<0@B@L1019;bP4054i<`@0FD@n101RCdT406]I
E@<0M6AP101mKf/408IiMP@0ShB15P3oool001@0oooo102GT8h409FAT0@0Ti:B0`2@Ti@408fCUP@0
RY>G1026TiP408:BV@@0OI6I0`1gSiT407:>V@@0KXfJ101XQY@405MgQ@@0AFUh100gGFh303]NKP@0
@69`1014IG8404QXM@@0BfYf1`1;JWD404QWLP@0AFE`1013HVh4049OJ`@0A5iX0`16GVL404]QJ@@0
DFM^101GKG<405abM`@0Gg=h101OL7@305a[KP@0FFEW101CGF0404iGF@@0BU9C1016C4d304=8B0@0
@TA41011@404044n?0@0@C/i100o>3@403hd<0<0?30Z100j:bH403PW8P@0<QdG100`5a0403<E3@<0
?24J1014;2D404dg<@@0ET8m101OCDP406QHD`<0LV=O101kKVX408EiM@@0ShB15P3oool001@0oooo
102GT8h409FAT0@0Ti:B0`2@Ti@408fCUP@0RY>G1026TiP408:BV@@0OI6I0`1gSiT407:>V@@0KXfJ
101XQY@405MgQ@@0AFUh100gGFh303]NKP@0@69`1014IG8404QXM@@0BfYf1`1;JWD404QWLP@0AFE`
1013HVh4049OJ`@0A5iX0`16GVL404]QJ@@0DFM^101GKG<405abM`@0Gg=h101OL7@305a[KP@0FFEW
101CGF0404iGF@@0BU9C1016C4d304=8B0@0@TA41011@404044n?0@0@C/i100o>3@403hd<0<0?30Z
100j:bH403PW8P@0<QdG100`5a0403<E3@<0?24J1014;2D404dg<@@0ET8m101OCDP406QHD`<0LV=O
101kKVX408EiM@@0ShB15P3oool001@0oooo102GT8h409FAT0@0Ti:B0`2@Ti@408fCUP@0RY>G1026
TiP408:BV@@0OI6I0`1gSiT407:>V@@0KXfJ101XQY@405MgQ@@0AFUh100gGFh303]NKP@0@69`1014
IG8404QXM@@0BfYf1`1;JWD404QWLP@0AFE`1013HVh4049OJ`@0A5iX0`16GVL404]QJ@@0DFM^101G
KG<405abM`@0Gg=h101OL7@305a[KP@0FFEW101CGF0404iGF@@0BU9C1016C4d304=8B0@0@TA41011
@404044n?0@0@C/i100o>3@403hd<0<0?30Z100j:bH403PW8P@0<QdG100`5a0403<E3@<0?24J1014
;2D404dg<@@0ET8m101OCDP406QHD`<0LV=O101kKVX408EiM@@0ShB15P3oool001@0oooo102GT8l4
09FBT@@0U9>D0`2AU9H408nEV0@0S9FJ1028UI/408>DV`@0OI:K0`1gT9X4076>VP@0K8^G101UQ984
059dP`@0?fIf100`FF/303ILK0@0>f1_1010Hg4404EXM@@0Bfah101>KWX304i^N@@0C6ag1015Ig<4
03mRKP@0?EiZ1010GVP3049LI@@0AUeU101?IVd405E/L`@0Fg9h101OM7T405maMP<0G6a_101HIFL4
059MG`@0CeQJ101:DU@404E<C@<0@4I7100n@T<403`n?P@0?3`k100m>SL403`f<`@0>S<_0`0h;bX4
03L[9P@0=BLR100_7aT402/E40@0;A8;0`0f7QP403lY90@0BCD_101B@3/405a;A`@0IUIB0`1`HUh4
07Y]J@@0Q7Qe102>Q84F0?ooo`00503oool409N@S`@0UI:A102DTi@3096DUP@0SiFH102<UIX408RE
V`@0PiBK101mTY/307N@VP@0LHjJ101/RiL406F4TP@0DWB3100oIWH4031IJ`<0=Ua/100kH6l4041S
L@@0AFQe101;K7P404i^NP<0CVii101<K7L404EWL`@0?f9^100mGVX4041NJ0<0@UaU1016GFD404mV
K@@0EFac101KLWP405mdN@@0Gg5f0`1LK6l405QUI`@0DUeO101?F5X404YBE0@0ADa=0`10ATL403i2
@`@0?3hn100l?3/403dj=`@0?3Hc100j<bl303P_:P@0=b/V100e9b8402lO6@@0:aD@100]4P/303HN
60@0?bTT1019=Bl40590>`@0G4]7101VEU83071RGP@0NVeY1024N7D408j4PAH0oooo000D0?ooo`@0
Ui2?102ETY4409BCU0<0TIBF102?UIP408bEVP@0R9FK1023U9/407fBV`<0Mi2J101aSYX406b;U`@0
IHBB101BM8<403mVMP@0<5U[0`0fG6`403]PK`@0@6=a1015J7D404]/N0@0CVij0`1>KWT404a/M`@0
AFMc100oHVh403eNJP@0@5iX0`12G6D404IMI@@0CfI]101EK7<405]bN0@0GgAi101OLGH305a/K`@0
F6EW101BGEl404mHFP@0BU9D1015C4d30416A`@0?T93100l?Sh403`l>`@0?CXg100l=S<403Xc;`<0
>2lZ100g:bH403DW8P@0;alI100[5A0402dB2`<0=QhH100o:B@404Te;`@0DT0k101LBdL406IFDP<0
L69N101jKFT408AhM@@0SXB15P3oool001@0oooo102GT8l409FBT@@0U9>D0`2AU9H408nEV0@0S9FJ
1028UI/408>DV`@0OI:K0`1gT9X4076>VP@0K8^G101UQ984059dP`@0?fIf100`FF/303ILK0@0>f1_
1010Hg4404EXM@@0Bfah101>KWX304i^N@@0C6ag1015Ig<403mRKP@0?EiZ1010GVP3049LI@@0AUeU
101?IVd405E/L`@0Fg9h101OM7T405maMP<0G6a_101HIFL4059MG`@0CeQJ101:DU@404E<C@<0@4I7
100n@T<403`n?P@0?3`k100m>SL403`f<`@0>S<_0`0h;bX403L[9P@0=BLR100_7aT402/E40@0;A8;
0`0f7QP403lY90@0BCD_101B@3/405a;A`@0IUIB0`1`HUh407Y]J@@0Q7Qe102>Q84F0?ooo`00503o
ool409NAS`@0UY:B102EU9D309>FV0@0TINJ102>V9`408^HWP@0QYNN101oU9d307J@V`@0KXfJ101Z
RID406R5TP@0E7J5100nIGH402aFJ@<0<UY/100hGfl403eRL@@0@fMe1019K7T4051aOP<0E7Ao101H
MH04055`N`@0B6Ue1012I6l4049TKP<0AV=/1019HVX404mWKP@0EFed101KLgX405meN`@0H79h0`1M
K74405UVJ@@0D5]N101>EeX404QAD`@0@DY<0`0k@dD403Y0@@@0=c`m100h>CT403Tg=P@0>SDc100h
<Rh303D^:P@0<bXV100`9B4402LL60@091@?100W40/3034L5P@0>RLR1014<Rd404ln>@@0FDU5101S
EE4306iQG@@0NFaY1023N7D408j3P1H0oooo000D0?ooo`@0Ui6?102FTY8409FDU@<0TiJH102AUiX4
08jHW0@0RiRN1026Uih407nDW@<0MY2K101^SIX406Z9U@@0J8FB101DMXD403iUMP@0;5IY0`0bFV`4
03QOK`@0?F9a1013IgD404U/N@@0D75n0`1DM7l405QeP0@0DG1k1018JGD4049TK`@0@VA^0`16Hf`4
04URJP@0CfM^101EKG@405]cNP@0GgEk101PLWP305e/L@@0FFIY101@Feh404iGFP@0B55C1011BT`3
03]3A@@0>T11100g?3d403Pi>@@0>CLf100j=C<403Pb;P<0=BhZ100c:RH4030U8@@09a`H100T50l4
02L@2`<0<A`F100j9b8404@b;@@0Cchi101IBDD406=ED@<0KV5M101iK6T408=hM@@0SX>05P3oool0
01@0oooo102GTHl409JBTP@0UIBE0`2CUYP4096GVP@0SYRL102;V9h408JGWP@0OiBM0`1fT9/406j=
VP@0JXVE101XQI8405AfQ@@0?VEf100/EVT3039JK0@0>5m_100mHW4404=WM@@0BFai101@LGh305Ad
O`@0F7F0101AL7/404QYM@@0@VA_1012I6h304ISK0@0BF9Z101?Ifh405E]M0@0Fg=j101OMG/4061b
N0<0GFaa101IIVT4051KGP@0CUMJ1018DE<4045:C0<0>d=5100j@44403Ll?@@0>3Ti100i=cH403Xe
<`@0>38^0`0e;RX403<Z9P@0<2DQ100W71P402@D3`@09a0;0`0a71H403XW8P@0A38]101??ST405U9
A@@0HeEA0`1^HEd407U/J@@0PgQe102>Ph0F0?ooo`00503oool409NAS`@0UY:B102EU9D309>FV0@0
TINJ102>V9`408^HWP@0QYNN101oU9d307J@V`@0KXfJ101ZRID406R5TP@0E7J5100nIGH402aFJ@<0
<UY/100hGfl403eRL@@0@fMe1019K7T4051aOP<0E7Ao101HMH04055`N`@0B6Ue1012I6l4049TKP<0
AV=/1019HVX404mWKP@0EFed101KLgX405meN`@0H79h0`1MK74405UVJ@@0D5]N101>EeX404QAD`@0
@DY<0`0k@dD403Y0@@@0=c`m100h>CT403Tg=P@0>SDc100h<Rh303D^:P@0<bXV100`9B4402LL60@0
91@?100W40/3034L5P@0>RLR1014<Rd404ln>@@0FDU5101SEE4306iQG@@0NFaY1023N7D408j3P1H0
oooo000D0?ooo`@0V96?102GTi<409JFUP<0UIRI102DVYd409:KW`@0SibR102:Vj8408:HX@<0MY6L
101TQ98406>3T@@0HX6>101BM8<403]TMP@0:5AX0`0_F6/403EMKP@0>f5a1010IG@404IZM`@0CG5n
0`1BM80405YhP`@0FgR3101FM7l404m]M`@0BFUc0`19IW0404]UKP@0D6Q`101EKGD405]cNP@0H7Il
101RMGX3065`M@@0H6e`101HHVD405=MH0@0C5IH1010Bdl303a5B0@0>412100c>C`403@g>0@0=SDe
100i=C<403Lb;`<0=2h[100b:RH402/T80@081PE100J3``4020=2@<0:aPD100e9204040_;0@0Bc/h
101FAd@4065CD0<0K5mL101gJfP4089gM0@0SH>05P3oool001@0oooo102HTHl409NCT`@0UYJF0`2E
V9T409BJW@@0TY^O102?W:8408ZKXP@0PYRQ0`1fTI`406B4TP@0Hh>A101RPHh4059dP`@0>fAf100X
E6P302mHJ`@0=Ee^100kHG44041UM0@0AVYg101=LGh3059dP0@0FWR3101KN8<405IdO`@0Cfeg1019
JG<304UVL0@0BfE^101@J70405E]M@@0Fg=j101PMW`4069eNP<0HG1e101PKG0405QRI@@0DeeP101<
EUP4041;C`<0?4E8100h@48403<i?0@0=3Lh100f=CD403Te<`@0=c8_0`0d;R/4038Z9P@0:b@P100P
61D401X?30@080d90`0[61@403DT80@0@2l/101;>cP405I7A0@0HE=@0`1/Ge`407M[J0@0PWMd102=
Ph0F0?ooo`00503oool409RAS`@0Ui>C102FUYH309FHV@@0U9ZM102BVil408nLXP@0RY^R1022V:43
07JAW0@0I8BB101SPi4406:1SP@0DWB3100kI7H402QDJ0<0;eQ[100eGFh403]QL@@0@6Ed1016JWL4
04eaOP<0DWB0101JN8<405]hP`@0EWAo101?KGL404UYL`<0BFI`101;IFh4051XL0@0EFee101KLgX4
061fO0@0HWEj0`1QL7D4061]L0@0F69U101CGF0404aFF0@0@4]?0`0lADP403Q0@P@0<cTl100d=cP4
03He=@@0>CDc100g<Rl303@^:`@0<RXV100[9204020H5@@06Pl<100P3@T302/H50@0=B@P1010;b`4
04/k>0@0ETM4101QDe0306aOG0@0Mf]X1022Mg@408f3P1H0oooo000D0?ooo`@0V96?102GTi<409JF
UP<0UIRI102DVYd409:KW`@0SibR102:Vj8408:HX@<0MY6L101TQ98406>3T@@0HX6>101BM8<403]T
MP@0:5AX0`0_F6/403EMKP@0>f5a1010IG@404IZM`@0CG5n0`1BM80405YhP`@0FgR3101FM7l404m]
M`@0BFUc0`19IW0404]UKP@0D6Q`101EKGD405]cNP@0H7Il101RMGX3065`M@@0H6e`101HHVD405=M
H0@0C5IH1010Bdl303a5B0@0>412100c>C`403@g>0@0=SDe100i=C<403Lb;`<0=2h[100b:RH402/T
80@081PE100J3``4020=2@<0:aPD100e9204040_;0@0Bc/h101FAd@4065CD0<0K5mL101gJfP4089g
M0@0SH>05P3oool001@0oooo102HTY0409RDU0@0V9RH0`2HVY`409NMX0@0UYnS102DXJL4096RZ@@0
RZ2X0`1lUj8406J7U@@0FWf;101GNXT404Y_P0@0>69d100VDfL302eGJP@0<ea]100iHG8403iSL`@0
@fMe1019KG/304mcP0@0E7J3101DMX8405=cO`@0Cfmk101;JWH304YXLP@0C6Qa101@JW8405I_MP@0
G7Ak101PMWd406=fO0<0Hg=g101QKg44061XJP@0H6IW101NHV8404eDE`<0Ada>1013AdT403Xo@@@0
>C`m100i>CT403Xg=@@0>3<a0`0e<2d4038[:0@09b4O100K5Q@401<:20@060P40`0T514402lP7@@0
>bdZ1017>CH40596@`@0GU9?0`1ZGU/407I[J0@0PGMd102=Ph0F0?ooo`00503oool409RBT0@0V9BD
102HV9P309RJW0@0UifP102FWj<409BQY`@0TJ:Y102:X:P307bGXP@0IXNE101JOH/405MjR@@0BVn0
100hHW@402ICI`<0;EMZ100cG6d403UQLP@0?V=c1013IgD404U]N`<0Cg>0101DMX<405AfPP@0Dg=o
101?Kg/404]ZMP<0BVQb101<J744051ZLP@0EVmf101LM7/4061fO@@0HgIl0`1SLgL4065_L@@0H6QZ
101PIVL405iRHP@0CEAG0`17C4h404=7B@@0>Sm1100i?3d403Ti>@@0>SLe100h<c4303D`;@@0<R/X
100W8Al401/F50@04`X8100H20@302@D4@@0;b0M100k;BX404Li=P@0DTI3101NDTl306YNF`@0MV]X
1021Mg@408f3P1H0oooo000D0?ooo`@0V9:@102HU9@409RHV0<0V9ZL102GWJ0409JOX`@0U:6W102A
XZT408ZPZ0<0O9NR101VQiD405YmR`@0EgZ9101:Kh0403QRM0@09U=W0`0]EfX403=LK@@0>F5b100n
Hg<404=WM@@0BFek0`1?Lh0405AfP`@0E7J2101CLgl404m_N`@0BfYf0`1:J78404aXL@@0D6Yb101F
KgH405adN`@0H7Im101SMW`306=cM`@0HFma101PJ6X4061VI`@0GV9R101=E5L304M<CP@0@dM9100j
?d4403Tl?@@0>CTi100j=cD403Pc<@<0=C0]100b:bP402LQ7`@06aHD100C2PP401P810<091@A100_
81d403/]:P@0AcTf101BAT<405iBC`<0JUiK101fJfP4085gM0@0SH>05P3oool001@0oooo102HTY04
09RDU0@0V9RH0`2HVY`409NMX0@0UYnS102DXJL4096RZ@@0RZ2X0`1lUj8406J7U@@0FWf;101GNXT4
04Y_P0@0>69d100VDfL302eGJP@0<ea]100iHG8403iSL`@0@fMe1019KG/304mcP0@0E7J3101DMX84
05=cO`@0Cfmk101;JWH304YXLP@0C6Qa101@JW8405I_MP@0G7Ak101PMWd406=fO0<0Hg=g101QKg44
061XJP@0H6IW101NHV8404eDE`<0Ada>1013AdT403Xo@@@0>C`m100i>CT403Xg=@@0>3<a0`0e<2d4
038[:0@09b4O100K5Q@401<:20@060P40`0T514402lP7@@0>bdZ1017>CH40596@`@0GU9?0`1ZGU/4
07I[J0@0PGMd102=Ph0F0?ooo`00503oool409VCT@@0VYJE102JVYX309^MW`@0Vj2S102KY:P409^W
[0@0VZ^a102K/;P308RQZP@0MIBO101SQI8405QkRP@0Afio100gHG@402EBI`<0:eIY100aFfd403QR
LP@0?VIf1012J7L404EZN0<0BFil101<LGl404ebP0@0C71m101:KGX404QZMP<0B6Mc101<JW@4055/
M@@0EW1h101LM7`4065fO@@0HgMm0`1SLWP4065^LP@0GVU[101PIfP406AWI`@0GF1P0`1EEeL404i?
D0@0ADM81010@D8403dl?0@0>cTh100j=C<303La;`@0=2h[100U8Al401PE50@03`X9100B108301d@
3P@0:AdK100f:RP404<g=0@0CdA1101LDDh306QMF`@0M6YW1020MW@408b3P1H0oooo000D0?ooo`@0
VI>A102JUYD409ZJVP<0VifO102KX:<409^TZ0@0VjN/102JZk4409^`^0<0R:6Z101eU9l406>5TP@0
F7^:1017KWl403MQM0@09E9W0`0[EVT4035KK@@0>69b100nIWH4049XM`@0AFYh0`19KW`404aaO`@0
CG:0101<L7d404Y]NP@0B6Yf0`18Ig<404aZM0@0DFae101FL7P405adO0@0HGIm101SMgd306=bN0@0
HFib101NJF/4061WJ0@0I6MW101MH60305EGE`@0CTm@1015AdP40411@P@0?C`l100k>CP403Xe<`<0
=c4_100d;R/402DQ7`@061DD100?2PT401840P<07A0>100Y7A/403HZ:0@0@cLd101?A44405aACP<0
J5eK101dJVL4081fM0@0S8>05P3oool001@0oooo102ITi4409ZFU@@0VYZJ0`2KWIl409^PX`@0VjBX
102KYj`409Z[/@@0Vk2h0`28XJX407FDW`@0HhFB101HNhX404M^O`@0=f5d100UDVL302]FJ@@0<E]]
100hHW8403iVMP@0@VQg1015JWP304U^O0@0C75o101=LX0404a`O@@0BVej1018JWH304QWL`@0C6Yd
101AK7D405I`N0@0G7Al101QMWd406=gO@<0Hg9h101QKW8405iYJ`@0H6MX101TIfL405ePH0<0EEMG
101>Ce0404E7B0@0@452100m?3`403/i>0@0>SDc0`0g<Bl403@^:`@09B4O100H5A@400l:2@@04P@2
0`0M40h402TM6`@0=RXX1013=c@404m4@@@0G55>0`1XGE/407AZI`@0P7Id102<Ph0F0?ooo`00503o
ool409VCT@@0VYJE102JVYX309^MW`@0Vj2S102KY:P409^W[0@0VZ^a102K/;P308RQZP@0MIBO101S
QI8405QkRP@0Afio100gHG@402EBI`<0:eIY100aFfd403QRLP@0?VIf1012J7L404EZN0<0BFil101<
LGl404ebP0@0C71m101:KGX404QZMP<0B6Mc101<JW@4055/M@@0EW1h101LM7`4065fO@@0HgMm0`1S
LWP4065^LP@0GVU[101PIfP406AWI`@0GF1P0`1EEeL404i?D0@0ADM81010@D8403dl?0@0>cTh100j
=C<303La;`@0=2h[100U8Al401PE50@03`X9100B108301d@3P@0:AdK100f:RP404<g=0@0CdA1101L
DDh306QMF`@0M6YW1020MW@408b3P1H0oooo000D0?ooo`@0VY>A102KUiL409bLW0<0WJ2Q102OY:L4
0:2Y[0@0XJfb102S/kT40:Nj`@<0TjZc101nVZD406b<V@@0G7n=1018L84403EQM0@095=X0`0WE6P4
02mIK0@0=Em`100mIWH404E/O0@0BG1n0`1=LX0404meP`@0DgR6101CMh@4055dPP@0CW5m0`1=KGT4
04i]M`@0DVih101FLGX405]dO0@0H7In101TN7h306AdN`@0H6ec101LIf`405]UI`@0Ff5S101HGUl3
05IIFP@0D5=C1017Bd`404=5A@@0?clo100m>c/403Xg=P<0>C<a100d;R`402<Q80@051@E100?3@`4
00`20@<05P`;100S6AP4034W9@@0?cDc101<@T0405U?C@<0IUaJ101cJFL4081fL`@0S8:05P3oool0
01@0oooo102JTi4409^GU`@0W9bL0`2MX:4409nTY`@0X:V/102Q[K840:>c^@@0Yk[10`2CZ[<407jJ
Y@@0K8bI101LOhd404Q`P@@0=F5d100TDfP302MDJ0@0;eU/100eGg0403eVMP@0AFal1019L7h304eb
P0@0CgF3101CN8H405=gQ0@0DGB2101>LGd304e]N@@0CVeg101BKWP405IaNP@0FgAl101PMWh406Ah
OP<0I7Ak101PKG<405aWK0@0FfEW101KHF<405QNG`<0EUUJ101@De<404M;C0@0@dE5100o?cl403dk
>`@0>SLf0`0i<c4403@^;0@08b4P100D51D400l=30@030810`0F30/402<I60@0<BLU100o=C<404a2
@0@0FDm=0`1VG5X407=YI`@0P7Ic102<PX0F0?ooo`00503oool409ZCT@@0ViNG102LW9`309fPX@@0
WjBW102PZJ`40:6]/P@0Xk>i102W^/4309>Z/`@0OYZU101/S9T405aoS@@0B721100eHG@402ACJ0<0
9eAX100_FF`403EOL0@0?FIf1015K7`404U`OP<0CG:0101?MH<405=hQP@0DgN4101AM88404iaO@<0
CFei101>KGL4059^N0@0EW5j101KM7`4061fOP@0I7Qn0`1TM7/4061]L`@0G6M/101KIFL405]QH`@0
F5iO0`1FFEX4051CD`@0Ad]<1013ADD403lo?`@0?C/k100j=cH303Tc<@@0=2h/100S8B0401@D5@@0
3`d<100<0P4301H<2`@08aTH100a9bD403le<`@0C490101ICdd306ILFP@0LfUW1020MW<408b2P1H0
oooo000D0?ooo`@0VY>A102KUiL409bLW0<0WJ2Q102OY:L40:2Y[0@0XJfb102S/kT40:Nj`@<0TjZc
101nVZD406b<V@@0G7n=1018L84403EQM0@095=X0`0WE6P402mIK0@0=Em`100mIWH404E/O0@0BG1n
0`1=LX0404meP`@0DgR6101CMh@4055dPP@0CW5m0`1=KGT404i]M`@0DVih101FLGX405]dO0@0H7In
101TN7h306AdN`@0H6ec101LIf`405]UI`@0Ff5S101HGUl305IIFP@0D5=C1017Bd`404=5A@@0?clo
100m>c/403Xg=P<0>C<a100d;R`402<Q80@051@E100?3@`400`20@<05P`;100S6AP4034W9@@0?cDc
101<@T0405U?C@<0IUaJ101cJFL4081fL`@0S8:05P3oool001@0oooo102JU98409bIV0@0WYjN0`2P
XZ@40:>XZP@0YJfa102X/kP40:^i_`@0/<780`2O/k/408ZR[0@0MI>O101QPi4404]bP`@0=V9e100U
E6T302ECI`@0:eMY100bG6d403URLP@0@6Ui1017Kgh304edPP@0CgN5101BNHP405=iQ`@0DgR6101@
MH8304m`O@@0Cfmj101BL7X405EbNP@0FWAl101OMWd406AiOP<0JGYo101WMGX4061[L@@0FFAX101D
GF84059JG@<0DEII101=DE<404Q;C@@0A4I71011@D4403hm?@@0?STi0`0l=SD403@^;0@08R4Q100?
4a@400/;30@01P000`090`<401`E50@0;2@S100k<c8404U1?`@0Edi=0`1UG5X4079YI`@0OgIc102<
PX0F0?ooo`00503oool409ZDTP@0W9VH102NWYh30:2RY0@0XjRZ102U[K440:Rc^0@0ZkVo102``LP3
09nc^`@0RZ:/101eTil40663T@@0Bg:3100fHWD402EDJ@<09E=W100[EfT4039LK@@0>F9b1010JGT4
04M_OP<0CGB2101?MhD4059iR0@0DgV7101CN8H4051ePP<0Cg1m101?KgX4059`NP@0EG9j101JM7`4
05mfO@@0I7Un0`1YNWl406MeNP@0H6]a101II6P405AMHP@0DUYM0`1AEUT404eAD`@0B4]=1014ATL4
0451@@@0?Sdm100n>CT303`f=@@0=2h/100R8B4400lC50@02`/<1006000300T30`@071DD100/92<4
03/c<P@0BD4o101GCTd306ELFP@0LVUW101oMW<408b2P1H0oooo000D0?ooo`@0VYBB102LVIP409jN
WP<0X::T102SZ:X40:F]/@@0Z;>h102[^Kl40;31b0<0Wk>k102:XZ`407FCW`@0HH>A101;LX<403IR
M@@09EAY0`0UDfL402]GJ@@0<Ua]100iHW84041YN@@0Afmn0`1=M88404mgQ@@0DWV8101CNHL405=h
QP@0D7F20`1?L7d404m_NP@0DW1j101ELWX405YdO0@0GgIm101TNGh306UjO`@0IgEj101PJg4405UT
J0@0E5eR101BFUd3055FF@@0CE5C1018Bdd404A6A`@0@D51100n?Cd403hi>@<0?3He100d;R`4028Q
8@@03a<D100;2``400H000<02@<3100L5A@402`T8`@0>c<b1019@Cl405M>C@<0IEaJ101bJFL407mf
L`@0S8:05P3oool001@0oooo102KU9<409jJV@@0XJ2P0`2SYJH40:J[[@@0Z[6d102]^;`40;6oa0@0
]/O=0`2W^/8409>Z]0@0OYVU101YRIL4051fQ`@0>FAg100WEV/302ABIP@0:5AW100^FFX403ENKP@0
>f=c1011J7P304E]O0@0BG20101;Lh8404acPP@0CG>2101=LX0304eaOP@0CVmk101AL7X405AaN`@0
F79k101LLg/4065eO0<0IWMm101[N7`406]dN@@0Ifib101LI6P405=KGP<0CEAH101:D5<404M;C@@0
A4M81012@d<40490@0@0@Cdl0`11>ST403<_;P@08R4R100?51L400H;3@@01P@50`050@<401LB4`@0
:28R100h<C4404M0?`@0ETi=0`1TFeX4075XI`@0OWEc102;PX0F0?ooo`00503oool409^DT`@0WYZI
102QX:030:>UYP@0YZ^]102Z/K@40:fh_0@0/Ko4102fald30:Nj`P@0TjZd101nVJD406V9U`@0D7J7
100iI7L402MFJ`<0959V100XE6L402iIJP@0=Ei^100kHg<4045XN0<0AFel1019L80404]cPP@0C7>2
101=Lh8404ebP0<0CG5n101>Kg/4055`NP@0E75k101HLW/405acN`@0HGEl0`1VMgd406]hO0@0JgAi
101WKW8405aTJ0@0De]N0`1=E5P404Y@D`@0Ad]=1014AdP40493@`@0@T101011?C`3044j>@@0<bl^
100R8B8400lD5`@01P/=100610D300D10`@05a8C100X8R8403Pa<@@0Ad0o101FCTd306AKFP@0LFQW
101nMG<408^2P1H0oooo000D0?ooo`@0ViBC102NVYT40:6PX0<0XjFV102VZjd40:Za]0@0[KRl102a
_l@40;K7c@<0Yk[2102CZ[@407jIY@@0JHVG101@MXL403UTM`@09eI[0`0TDVH402QDI`@0;UUZ100e
GVh403]SL`@0@FQh0`15KG`404U`P0@0Bg>2101<Lh8404ecPP@0CG:00`1=LGh404i_N`@0DG1j101D
LG/405QbN`@0G7=k101QMG`306IgO@@0JgQl101[M7T406M^LP@0G6AX101CFeh304eDF0@0BU1C1017
Bdd404A7B0@0@T=31012@404044m?0<0@CXi100c;bh4028Q8P@03a@G10062`d400H41@<01@43100G
4Q<402PR8P@0>34a1017@3l405I>C@<0I5]J101aJ6L407ieL`@0Rh:05P3oool001@0oooo102KU9<4
09jJV@@0XJ2P0`2SYJH40:J[[@@0Z[6d102]^;`40;6oa0@0]/O=0`2W^/8409>Z]0@0OYVU101YRIL4
051fQ`@0>FAg100WEV/302ABIP@0:5AW100^FFX403ENKP@0>f=c1011J7P304E]O0@0BG20101;Lh84
04acPP@0CG>2101=LX0304eaOP@0CVmk101AL7X405AaN`@0F79k101LLg/4065eO0<0IWMm101[N7`4
06]dN@@0Ifib101LI6P405=KGP<0CEAH101:D5<404M;C@@0A4M81012@d<40490@0@0@Cdl0`11>ST4
03<_;P@08R4R100?51L400H;3@@01P@50`050@<401LB4`@0:28R100h<C4404M0?`@0ETi=0`1TFeX4
075XI`@0OWEc102;PX0F0?ooo`00503oool409bET`@0Wi^J102SXJ430:JXZ@@0ZZj`102^]KP40;:l
`0@0]l?8102mc=430:joaP@0W;6j1025WjX406n>V`@0EW^;100nJ7/402UHK@<08U5V100UDFD402]E
I`@0<EUZ100fGVh403]RLP<0?fIe1013JWT404E]O0@0Afim1018Kgh404U^O@<0BVil101<KW/404m^
NP@0DVmj101EL7T405Q`N0@0G75h0`1QLWP406EcN0@0Ig9f101XL7<406I/KP@0HFIX0`1IGV0405AG
F@@0Ce5C101<CDh404M7B0@0AD=31013@40304<m?0@0=C4a100T9BD401DJ70@020hA10031PP30041
10@04a4B100U8B8403Ha<@@0AClo101DCTd306=KFP@0LFQW101nMG<408^2P1H0oooo000D0?ooo`@0
W9FC102OViX40:>QX@<0YZRY102Z[[040:je^0@0/[c0102g`lP40;g<d@<0[[o6102L/KX408FOZP@0
KhjK101FNh/403iXN`@0:EQ]0`0RDFH402EAI@@0:eEW100aFFX403INKP@0>f9b0`0oIWD404=ZN@@0
AFel1017KWd404Q_OP@0BFim0`1:KW`404a^N`@0Cfij101BKgX405E`N@@0F71h101LLGP3065bN0@0
IG=h101WLWH406Q`L`@0IVa^101QIVP305UNH0@0E5MI101?DE<404a=CP@0AdM81015@d<404=0@0<0
@cdl100e<C4402@U9@@05AXL10083Q4400<620<00@44100C4A8402DQ8P@0=S4a1015?cl405A>C@<0
He]J101aJ6L407ieL`@0Rh:05P3oool001@0oooo102LUI<409nKVP@0Xj6Q0`2VZ:T40:Z^/0@0[[Fh
102b_<040;O3b0@0_LcA0`2^_lH409ba^P@0QInZ101_SY/405IkR`@0?VQk100YF6d3029AIP@09E5U
100[EFL4035IJP@0=Ui^100kHW8303mVM@@0@fYi1015KG`404M^O@@0B6mn1019KWd304Y^O0@0C6ik
101?KWX4059_NP@0EG1i101HL7P405aaN0<0HG9h101ULgP406MbMP@0J71c101VK6h4065VJ0<0FEiP
101DEeT404mAD`@0C4e>1017AdP404E3@`@0@d100`13?C`403Da<@@092DU100E6Q`400P>4@@00`H8
0`010@@401<A4P@09B4R100f<C4404Do?`@0E4i=0`1SFeX4075XI`@0OWEc102;PX0F0?ooo`00503o
ool409bET`@0Wi^J102SXJ430:JXZ@@0ZZj`102^]KP40;:l`0@0]l?8102mc=430:joaP@0W;6j1025
WjX406n>V`@0EW^;100nJ7/402UHK@<08U5V100UDFD402]EI`@0<EUZ100fGVh403]RLP<0?fIe1013
JWT404E]O0@0Afim1018Kgh404U^O@<0BVil101<KW/404m^NP@0DVmj101EL7T405Q`N0@0G75h0`1Q
LWP406EcN0@0Ig9f101XL7<406I/KP@0HFIX0`1IGV0405AGF@@0Ce5C101<CDh404M7B0@0AD=31013
@40304<m?0@0=C4a100T9BD401DJ70@020hA10031PP3004110@04a4B100U8B8403Ha<@@0AClo101D
CTd306=KFP@0LFQW101nMG<408^2P1H0oooo000D0?ooo`@0W9FD102PW9/40:FSX`<0ZJZ[102]/K<4
0;:h^`@0]l33102lal`40<;?e@<0//;9102R]Kh408bU/0@0MI>P101LOhl404A/O`@0;E]`0`0RDFH4
029?H`@09e9T100]EVL4039IJP@0=Ue]0`0jHG4403eTL`@0@6Mf1012JGP404AZNP@0AF]j0`17JgT4
04U[N@@0Bfah101>K7P4055/MP@0E6ef101HKGD305]^M0@0Gfic101QKG8406=/L0@0HVU/101PIFP3
05eQI0@0FEaM101CEUL404m@D0@0Bd];1019AdH404M3@P<0@chl100f<c<402PX:@@06ahP100=4QD4
00<82`<00084100?3Q0402<P8P@0=34a1015@40405A>C@<0HUaJ101`JFL407ifM0@0Rh:05P3oool0
01@0oooo102LUI@40:2LV`@0YJ>S0`2YZZ/40:fa/`@0/[Rk102g`<<40;c7c0@0`/oE0`2b`/T40::e
_P@0S:F`101eTj0405aoS`@0A6ao100]Fg03029AIP@08TmS100WDV@402eFI`@0<UUZ100fGFd303YQ
L@@0?FAc1010IgH4049YN0@0A6Yj1015JgX304M[N@@0BF]i101;K7P404i/N0@0DFaf101DKGH405Q]
M@<0Ffid101OKW<4065]LP@0Hfa`101RJF`4061UJ0<0GF5T101IG5d405=FE`@0Ce1@101;Bd/404U7
AP@0Ad=20`13?S`403Hc<`@0:2PY100K7R0400dB5@@00`P;0`000P@400l>40@08b0R100d<C4404E0
@0@0E4i=0`1RG5X4071YI`@0OWId102;PX0F0?ooo`00503oool409bEU0@0X9bK102UXj<30:VZZ`@0
[K6c102b^;/40;O0``@0_<O<1032cmD30;;2b@@0X[Fn102<YK0407FCX0@0G7n?1014K7l402eKL0<0
8U5V100RCf<402MBI0@0;EIW100bFFX403IMK@<0>V5a100mI7<4041WMP@0@VUh1014JWX404E[NP<0
Af]i1019JgT404]/N0@0CVah101AK7H405A]MP@0F6ee0`1KKW@405m^L`@0HFeb101SK704069YK0@0
H6EX0`1MHF@405ULG@@0DeIG101?D50404];B`@0BDM61017@d8304<n?0@0=S<c100X:2T401/N80@0
3A8E100320/3000210@03`h@100S828403@a<@@0AD10101DCTd3069LFP@0L6UW101nMW@408^2P1H0
oooo000D0?ooo`@0W9FD102PW9/40:FSX`<0ZJZ[102]/K<40;:h^`@0]l33102lal`40<;?e@<0//;9
102R]Kh408bU/0@0MI>P101LOhl404A/O`@0;E]`0`0RDFH4029?H`@09e9T100]EVL4039IJP@0=Ue]
0`0jHG4403eTL`@0@6Mf1012JGP404AZNP@0AF]j0`17JgT404U[N@@0Bfah101>K7P4055/MP@0E6ef
101HKGD305]^M0@0Gfic101QKG8406=/L0@0HVU/101PIFP305eQI0@0FEaM101CEUL404m@D0@0Bd];
1019AdH404M3@P<0@chl100f<c<402PX:@@06ahP100=4QD400<82`<00084100?3Q0402<P8P@0=34a
1015@40405A>C@<0HUaJ101`JFL407ifM0@0Rh:05P3oool001@0oooo102MUY@40::MW0@0YZBT0`2[
[:d40;2c]@@0][^n102k`lL40<7;d0@0a]CI0`2gald40:Nj`P@0TjZe101lVJH406:5U@@0BW:4100c
H7@302=BJ0@07deQ100TCf8402YCI0@0;UIV100bFFT303IMK@@0>F1`100kHW8403iTM0@0@6If1011
IgL304=XM`@0AFUf1018JGH404YYM@@0CFUd101?JG8405=YLP<0EVUa101IJW0405]YK`@0G6M/101M
IFT405]SIP<0FEmR101GFed405=FF0@0Ce5B101<CDd404]9B@@0BDI50`11?Sh403Dd=0@0:BX/100M
82<4014F6@@01P`@0`021`X400h?4@@08b8S100e<S<404E1@@@0E4m?0`1SG5/4075YJ0@0OWId102;
PX0F0?ooo`00503oool409fFU0@0XYfL102VY:@30:^/[@@0/;>e102f^kh40;_3a`@0`L_@1036e=T3
0;O7c@@0Yk[2102CZ[D407bIYP@0HXFE101:LX@403=PM0<08e9X100OCF4402A?HP@0:U=T100^EVH4
039IJ@<0=Ue]100iH70403]RLP@0?VAd1010IWH4045WM`<0@fQg1015JGH404QYMP@0BVUe101=JG@4
04mYLP@0DfUb0`1FJG4405UZL0@0FfU_101LIf`405eUJ@@0Ff=V0`1IGf8405MKG@@0DeIH101?DE84
04a=C@@0BdU91019ATD3044n?P@0=C@d100Y:R`401dP8`@04AHI1006310300872P@03PlA100S8R<4
03Db<`@0AD51101DCdl306=LF`@0LFUX101nMW@408^2P1H0oooo000D0?ooo`@0WIJD102RWI`40:JT
Y0<0Zjb]102`/kD40;Jk_P@0^l?71031bm040<KDf@<0]lO=102W^/8409>Z]@@0O9VV101RQID404Yb
Q0@0<f1d0`0SDVP401m=H@@094mR100ZDf@402iFIP@0<UUY0`0fGFd403UPL0@0>f9b100nI7@4041V
MP@0@FMg0`13J7L404EYMP@0B6Uf101:JGD404eYM0@0CfUb101CJG8305IYL@@0FFY`101KJFl405aW
K0@0GFEY101KHfH305UOHP@0Ee]M101CEUP404mADP@0C4e=101;BDT404U6A@<0@Chn100e=3@402TZ
;0@07B0S100A5QT400H<40<00PL:100>3a4402<R8`@0=C8c1015@D4405A?C`<0HeaK101aJFP407if
M0@0Rh:05P3oool001@0oooo102MUY@40::MW0@0YZBT0`2[[:d40;2c]@@0][^n102k`lL40<7;d0@0
a]CI0`2gald40:Nj`P@0TjZe101lVJH406:5U@@0BW:4100cH7@302=BJ0@07deQ100TCf8402YCI0@0
;UIV100bFFT303IMK@@0>F1`100kHW8403iTM0@0@6If1011IgL304=XM`@0AFUf1018JGH404YYM@@0
CFUd101?JG8405=YLP<0EVUa101IJW0405]YK`@0G6M/101MIFT405]SIP<0FEmR101GFed405=FF0@0
Ce5B101<CDd404]9B@@0BDI50`11?Sh403Dd=0@0:BX/100M82<4014F6@@01P`@0`021`X400h?4@@0
8b8S100e<S<404E1@@@0E4m?0`1SG5/4075YJ0@0OWId102;PX0F0?ooo`00503oool409jFU@@0XijM
102XYZH30:j^[P@0/kJg102i_/040;o6bP@0aLoC103<f=d30;c:d@@0[;k6102I/;X408BP[0@0K8fK
101CNH/403]WN`<0:UQ^100OCV<4029=H@@09e1R100[Df@402mEI@<0<UQX100eG6`403MNKP@0>F5a
100kHW8403eTL`<0?fEd1011IG@404=VM0@0AVIb1018IG4404]UL0@0CFE_0`1@IFh405=UK@@0EVE/
101GHfT405MQIP@0Ef1T0`1FGF0405EIG0@0DeIH101ADU<404m?C`@0CT];101;AdH304=0?`@0=cLg
100/;Bh4024T9`@05Q/N100<4aL300P=4@@04A<F100U9BL403Le=P@0AT=3101EDE0306=NG@@0LFYY
101nMgD408^3P1H0oooo000D0?ooo`@0WYJE102SWYd40:RVYP<0[Zj^102c][L40;Vn`0@0_lK:1035
cm<40<cHg@<0_<[A102/_/H409V`^P@0Q:2/101/SI/405=iR`@0>fMk0`0ZF6h401m>H`@08TeQ100W
D68402]CI0@0;eEU0`0bF6P403ELK0@0=ei^100iHG4403]RLP@0?FAc0`0oIG@4045UM0@0@fId1016
IW8404QUL@@0BfE`101=IFl3051UKP@0DfE]101FIF`405MSJ@@0Ef5V101GH6@305IMH0@0EEUL101C
EUP4055BD`@0Cdm?101>Bd/404]7AP<0@d0o100g=cL402`];P@08B@W100F6ah400`C5`<020dA100A
4aH402DU9`@0=cDf1016@d<405EAD0<0HeiM101aJVT407igM@@0Rh>05P3oool001@0oooo102NUYD4
0:>NW@@0Z:JV0`2^[Zh40;>f]`@0^Kk0102oa/X40<G?d`@0c=SM0`2lb]440:bnaP@0VK2j1024X:`4
06b=V`@0DgV;100kIg/302YHKP@07diS100RCF4402M@HP@0:e=T100_EFD3039HJ0@0=Ea/100gGVh4
03UQL@@0>f9b100mI7<303mUM0@0@FEd1013IW@404IVLP@0B6Ea101;IG0404eUK`<0D6E^101CIFd4
05IUK0@0Ef=Y101GHFH405MPI0<0EUeP101EFE`405=FF0@0DE9C101?Cdl404i;B`@0BdM60`13@3l4
03Lg=`@0;2d^100Q92L401HK7P@031<G0`083A44014C5P@09BDW100g=CH404I3@`@0EE5@0`1SGUd4
075ZJ@@0OWMe102;Ph0F0?ooo`00503oool409jFU@@0XijM102XYZH30:j^[P@0/kJg102i_/040;o6
bP@0aLoC103<f=d30;c:d@@0[;k6102I/;X408BP[0@0K8fK101CNH/403]WN`<0:UQ^100OCV<4029=
H@@09e1R100[Df@402mEI@<0<UQX100eG6`403MNKP@0>F5a100kHW8403eTL`<0?fEd1011IG@404=V
M0@0AVIb1018IG4404]UL0@0CFE_0`1@IFh405=UK@@0EVE/101GHfT405MQIP@0Ef1T0`1FGF0405EI
G0@0DeIH101ADU<404m?C`@0CT];101;AdH304=0?`@0=cLg100/;Bh4024T9`@05Q/N100<4aL300P=
4@@04A<F100U9BL403Le=P@0AT=3101EDE0306=NG@@0LFYY101nMgD408^3P1H0oooo000D0?ooo`@0
WYNE102TWih40:ZWY`<0/:n`102f^;T40;c0``@0`lW<1039d]H40<oKh0<0`<oE102``/X409ne_`@0
RjJa101dTj4405YoT0@0A6f00`0aGW<402ABI`@08TeQ100UCV4402UAHP@0;5=T0`0_EFD4035GJ0@0
<eY[100eGFh403MOL0@0>F1`0`0kHG4403eRL@@0?f=a1011Hfl404=RKP@0AF5/1019HF`304]QJ`@0
CV5Y101AHFT4059PI`@0DeiT101CGF4305=KG`@0DeQL101BEEP4055CE0@0D4m@101?CDd404]8A`<0
@T10100i>3T402h`<@@09BPZ100K7b84018H70<03a@H100K7B0402X[;@@0>SPj1019ATH405MCD`<0
IEmO101bJfX407mgMP@0S8>15P3oool001@0oooo102NUiD40:BOWP@0ZZNW0`2`[k040;Jh^@@0_<33
1033bL`40<WBeP@0cm_P0`30cmD40;32bP@0WkFo102;Y[4407BCX@@0FWn@1014KH03035NL`@0959W
100RCF4402E>H@@0:E5R100/Df@302mEI@@0<EMX100cFV/403EMKP@0=em`100iH70303]QL@@0?F9a
100oHg44045SK`@0@f9^1015HF`404UQK0<0Bf5[101>HFT4055QJ@@0DV1W101CGV@405=MH@<0De]O
101CF5`4059EF0@0DE=D101@Ce0404m=C@@0BdQ70`12@40403Th>@@0;S0a100U:2X401/O8P@04QPL
0`0?51P401/M80@0:R/]100j>3X404U6AP@0Ee=C0`1UGel4079[JP@0OgMf102<Ph4F0?ooo`00503o
ool409jGU@@0Y9nN102ZYjL30;2_/0@0][Ri102l`<<40<?9c0@0bM;F103?fn030<3?e@@0/<;:102O
]Kl408^V/@@0M9>Q101JOi0404A]P0<0<Eic100TDVL4029=H@@09DiQ100YDF8402aCI0<0;eEU100a
EfP403=JJ`@0=Ee^100gGg0403UPL0<0>f5a100mHW4403mSL@@0@F=_1013HVh404EQK0@0BF5/0`1;
HF/404iQJ@@0DF5Y101BH6L405=NI0@0DeeQ0`1CFel405=HG0@0DUEH101ADe@4051?D0@0Cde=101;
B4L30490@0@0>CPi100^<34402DX:P@06alR100B61`300lD60@06adP100Z:bd403Xh>P@0BDI6101G
De<306EOG`@0LV]Z101oMgH408b3PAH0oooo000D0?ooo`@0WiNE102UX9h40:^XZ0<0/[6a102h^[/4
0;o3a@@0a/c?103=eMT40=CNhP<0aM;H102ea/d40:Fi``@0TZ^g101lVZP406B7U`@0BgF70`0fI7P4
02UGK0@08dmS100SCV4402I?H@@0:E5R0`0/Df<402iDI@@0<5MW100aFFX403=KK0@0=Ea]0`0fGFd4
03QNK@@0>em]100mGV`403iNJ`@0@5iZ1013GVT304INJ0@0BEiW101<GVH404eMI0@0CeaR101@Ff03
055IGP@0DEQL101AEEP4051DE@@0DE5B101@CTh404Y8B0<0@d92100j>S/4034c=0@09bX]100N8RD4
01DK7`<041DI100Q8bH402l`<P@0?Sdn101<BDX405UEE@<0If5Q101cKF`4081hM`@0S8B15P3oool0
01@0oooo102OUiD40:FPWP@0ZjRX0`2b/K440;Rj^`@0_l?51036c<l40<gEf@@0e=kR0`35d]P40;G6
c@@0YKW3102BZkL407bJZ0@0I8NG101;MHL303ITN0@0:EM/100SCf<402=>H@@09TmQ100YDF8302aC
H`@0;UAU100`EfL4035IJP@0<e]/100eG6d303IMK@@0>5i]100kGfd403eNK0@0?Ui[1010GVX404=N
J@<0AUiX1019GVL404aNIP@0CEeT101?G684051KH0<0DEUN101AF5`4055EF0@0D5AE101ADE84051>
CP@0BTQ80`13@T8403Xj>`@0<C<d100W:Rd401hR9@@05A/O0`0@5AT4024S9P@0;c0b100n?Ch404a9
BP@0FEEE0`1WHF4407=]K0@0P7Qg102<Q84F0?ooo`00503oool409nGU@@0YJ2N102[Z:P30;:a/@@0
^;Zk102o`lD40<K<c`@0cMGI103Dg^830<GBf0@0]LK=102U^L<409:[]`@0O9ZX101TQiL404]eQ`<0
=VAh100YEf`402=?H`@08diQ100VCf4402UAHP<0;5=S100^E6D4031GI`@0<EUZ100cFf`403ELK@<0
=Ue]100hGVd403]OK@@0?Ei/100nGV/4041NJP@0@eiY0`16GVP404UNI`@0C5iV101=GF@404mLHP@0
D5]P0`1AFEh4055HG0@0DEEH101@E5D4055ADP@0D4i>101:B4P304=2@P@0>SXk100a<c@402LZ;@@0
7R8U100E6al3010E6@@08B<V100_<38403hm?P@0C4U:101IEED306MQH@@0Lfe/1020N7L408b4PAH0
oooo000D0?ooo`@0WiNE102UX9h40:^XZ0<0/[6a102h^[/40;o3a@@0a/c?103=eMT40=CNhP<0aM;H
102ea/d40:Fi``@0TZ^g101lVZP406B7U`@0BgF70`0fI7P402UGK0@08dmS100SCV4402I?H@@0:E5R
0`0/Df<402iDI@@0<5MW100aFFX403=KK0@0=Ea]0`0fGFd403QNK@@0>em]100mGV`403iNJ`@0@5iZ
1013GVT304INJ0@0BEiW101<GVH404eMI0@0CeaR101@Ff03055IGP@0DEQL101AEEP4051DE@@0DE5B
101@CTh404Y8B0<0@d92100j>S/4034c=0@09bX]100N8RD401DK7`<041DI100Q8bH402l`<P@0?Sdn
101<BDX405UEE@<0If5Q101cKF`4081hM`@0S8B15P3oool001@0oooo102OV9D40:JPW`@0[:VY0`2c
/[840;^l_0@0`/G7103:cm840=;Ig0@0f^?V0`3:e]`40;_:d@@0Zkk7102J/K`408FQ[P@0KHjN101E
O8h303iZOP@0;Eeb100SDFH4029=H@@094iQ100WCf4302U@HP@0:e5R100/Df@402iEIP@0;eMX100a
F6T3039IJP@0<eYZ100eFfX403MJJ0@0>5UW100kFVH403iJI@<0@EYU1014FV@404MJH`@0BU]R101<
FV4404eIG`<0CUQM101?Ee/4051EF0@0Ce=F101?D58404e=C`@0B4Q90`11@T<403Tk?0@0<C@f100X
;2l401lU:0@06AlS0`0G6al402LY;0@0=CDg1012@D<404m=C@@0G5QH0`1YHf<407E^K@@0PGUh102=
Q88F0?ooo`00503oool409nHU@@0YZ2O102/ZJT30;>b/P@0^kbl1032aLL40<[?dP@0d]WL103JhnH3
0<[Fg0@0^l[A102[_/L409Za_0@0QJ6^101]SYh405ElSP<0?VYn100]GG8402=AIP@08TeQ100TCV44
02M?H@<0:E1R100[DF8402aCI0@0;UEV100_EfP4035HJ@<0<UUZ100cFVX403EKJP@0=eYX100hFFL4
03]JIP@0?UYU0`11FVD404AJI0@0AeYS101:Ff8404aJH@@0CEUO0`1>F5d404mGF`@0D5EH101?DeH4
04m@DP@0CDe?1018B4T30452@`@0>C/l100a=3H402P/;`@07bDX100I7b<301LK7`@09bT/100e=CL4
0491@`@0Cde=101LF5P306USH`@0MFi]1021NGP408f4PQH0oooo000D0?ooo`@0WiRE102VX9l40:bY
Z@<0/k:b102k_;`40<;5a`@0b/oB103BfM`40=[SiP<0b]KL102kb]440:^na`@0V[6l1025XJh406f>
WP@0EGb>0`0nJWh402eMLP@08e5V100RCF4402A>H@@09dmQ0`0YD68402]AHP@0;5=T100^EFH402mG
J0@0<EQY0`0bFFX403=JJP@0=E]Z100gFVP403QII`@0>eYV100nFVD3045JI@@0A5YT1017FV<404YK
HP@0C5YQ101=FEl304iHG@@0CeMK101@EEP404mCEP@0Ce1B101=CDl404Q8B@<0@D93100i>c`4034d
=P@0:2`_100O9BP401TO8`<05a/O100W:B`403De=`@0@T53101?CDd405aHF0<0JF=S101eKVd4085i
N0@0SHB25P3oool001@0oooo102OV9D40:JPW`@0[:VY0`2c/[840;^l_0@0`/G7103:cm840=;Ig0@0
f^?V0`3:e]`40;_:d@@0Zkk7102J/K`408FQ[P@0KHjN101EO8h303iZOP@0;Eeb100SDFH4029=H@@0
94iQ100WCf4302U@HP@0:e5R100/Df@402iEIP@0;eMX100aF6T3039IJP@0<eYZ100eFfX403MJJ0@0
>5UW100kFVH403iJI@<0@EYU1014FV@404MJH`@0BU]R101<FV4404eIG`<0CUQM101?Ee/4051EF0@0
Ce=F101?D58404e=C`@0B4Q90`11@T<403Tk?0@0<C@f100X;2l401lU:0@06AlS0`0G6al402LY;0@0
=CDg1012@D<404m=C@@0G5QH0`1YHf<407E^K@@0PGUh102=Q88F0?ooo`00503oool409nHUP@0YZ6O
102^ZZT30;Fc/`@0_Kfn1035alP40<gAd`@0e]cO103Oin/30=7Lh@@0`]3F102b`l`40:6f`@@0SJNc
101fUJ@405n4U@<0Ag:5100eHgP402IEJP@08TiS100SCV4402E>H@<09TmP100XCf4402UAHP@0:U9S
100[E6D402eEI`<0;UMX100^EVL4031FIP@0<EEU100cEF@403EEH`@0>5IS0`0lEV8403mGH@@0@UMQ
1015Ef0404QGG`@0BUQN0`1<Ee`404iFFP@0CeEI101?DeH404e@D`@0Bde?1017B4X30453A0@0>cdn
100c=ST402/_<P@08bP/100N8bL302@W:`@0;S0c100k>cd404M6A`@0De5A101OFe/306]VI@@0MW1_
1022NWT408f5PQH0oooo000D0?ooo`@0WiRF102VXIl40:jZZ@<0]K>c102m_Kh40<G7b0@0cM7C103F
g=l40=oWj`<0dMcQ1032d=H40;;3c0@0XKK1102=Yk<407JEY0@0GhBE0`17LXD403ESN0@09UEZ100R
CV<402=>H@@09DiQ0`0VCf0402Q?H@@0:E5R100ZDV<402]DI@@0;EEW0`0^EfP402iFI`@0<5IV100a
EFD403=EI0@0=EES100hEV<303aFHP@0?eMQ1012Ef4404EGH0@0B5MO101:F5h304aGG0@0CUIJ101?
EET404mCEP@0CE1C101;CDl404M8BP<0@D=4100k?Ch403<f>@@0:blb100S:2`401hS9`<092L[100^
<3<403/k?@@0AdI7101CDE4405mKF`<0JfIU101fL6l4089jN@@0SHF25P3oool001@0oooo102OV9H4
0:JQW`@0[ZZY0`2e/k<40;fm_P@0aLO8103=dM<40=KLg`@0gnO[0`3Ag>440<;@eP@0//?<102Q]/44
08fW/`@0MYFT101OQ9D304MbQ@@0=F=h100VEFX4029>H`@08diQ100UCV4302I?H0@0:4mQ100YDF84
02YBH`@0:eAU100]EFL302iGJ0@0;UIW100`EVH4035EI@@0<eET100eEF<403QFH`<0?5IR100oEf44
049GH@@0AEMP1018Eel404YHGP<0C5ML101>EUX404mEF@@0Ce=F101=D5<404]=C`@0AdQ:0`11@d@4
03/m?P@0<cHi100[;c8402<X;0@07R<W0`0T9b/402h`<`@0>c/m1017ATL405=AD@@0Ge]K0`1[IVD4
07I`K`@0PWYi102=QH8F0?ooo`00503oool409nHUP@0YZ6O102^ZZT30;Fc/`@0_Kfn1035alP40<gA
d`@0e]cO103Oin/30=7Lh@@0`]3F102b`l`40:6f`@@0SJNc101fUJ@405n4U@<0Ag:5100eHgP402IE
JP@08TiS100SCV4402E>H@<09TmP100XCf4402UAHP@0:U9S100[E6D402eEI`<0;UMX100^EVL4031F
IP@0<EEU100cEF@403EEH`@0>5IS0`0lEV8403mGH@@0@UMQ1015Ef0404QGG`@0BUQN0`1<Ee`404iF
FP@0CeEI101?DeH404e@D`@0Bde?1017B4X30453A0@0>cdn100c=ST402/_<P@08bP/100N8bL302@W
:`@0;S0c100k>cd404M6A`@0De5A101OFe/306]VI@@0MW1_1022NWT408f5PQH0oooo000D0?ooo`@0
X9RF102WXJ040:n[ZP<0][Bd102n_[l40<O8b@@0d=?E103Ign440>?[kP<0fN?W1039e]`40;W:d@@0
ZKg7102F[[X407nMZ`@0JH^L0`1CNhd403m/P0@0;Eab100TDFH4029>HP@08diQ0`0TCV0402E>H@@0
9TmQ100VD68402M@HP@09e9T0`0YDfD402UCI0@0:U9S100[DV8402aAH0@0;e5P100bDUl303ICH0@0
>U=O100mE5l4045DGP@0A5EN1017EUd304YFG0@0CEIK101?EUX404mDE`@0CE5C101:CDl404E8B`<0
@4=6100k?T0403@h>`@0;34d100S:Bd401`Q9@<0:Rd`100e=cT40451@`@0C4]<101GEED406=OGP<0
KFQX101hLW4408=lNP@0SXF35P3oool001@0oooo102PV9H40:NQX0@0[j^Z0`2f];@40;jn_`@0alS9
103@dmD40=WOh@@0hn_^0`3IhnL40<WFg0@0^L[A102Y_LL409J^^P@0Oif[101YRi`305=kS@@0?fb0
100]G78402AAIP@08TiR100SCV4302A>H0@09DiQ100VCf4402I@HP@09e1R100WDV@302UCI@@0:E=T
100ZDV<402]BHP@0;55P100_DF04039BG`<0=U=P100jDel403eDG`@0@EAN1014EEh404MFG@<0BUIL
101=EU/404mFFP@0CeAG101=DE<404Y=C`@0ADQ;0`10@dH403/n@0@0=3Pk100/<C@402<Y;@@0724U
0`0Z;C0403Dg>@@0@D53101<Bd`405MEE@@0HemN0`1]J6P407QbL@@0Pgaj102>QH<F0?ooo`00503o
ool40:2HUP@0Yj6P102_ZjX30;Jd]0@0_[jo1037b<T40=3Ce@@0fMoQ103Sjnh30=WSi`@0bMKL102i
b]440:Vma`@0UZjj101oWJ/406V;W0<0Dg^=100oK80402eLLP@0955V100RCV8402=>H@<094iP100U
CV4402I?H@@09U1R100WD68402MBI0<0:E=U100YDf@402YBH`@0:e9R100/DF0402mAH0@0<U9O0`0f
Df0403YCG`@0?EAO1011E5h404AEGP@0AeIM0`1:EU`404eFF`@0CeIJ101?E5L404eAD`@0BTe?1015
B4/30413AP@0>ci0100d>3/402`a=0@08bT]100L8BD302X]<0@0=CLi1011@D<404a;C0@0EeEE101S
Geh306eXJ0@0N79a1023O7X408j5PaH0oooo000D0?ooo`@0X9RF102WXJ040:n[ZP<0][Bd102n_[l4
0<O8b@@0d=?E103Ign440>?[kP<0fN?W1039e]`40;W:d@@0ZKg7102F[[X407nMZ`@0JH^L0`1CNhd4
03m/P0@0;Eab100TDFH4029>HP@08diQ0`0TCV0402E>H@@09TmQ100VD68402M@HP@09e9T0`0YDfD4
02UCI0@0:U9S100[DV8402aAH0@0;e5P100bDUl303ICH0@0>U=O100mE5l4045DGP@0A5EN1017EUd3
04YFG0@0CEIK101?EUX404mDE`@0CE5C101:CDl404E8B`<0@4=6100k?T0403@h>`@0;34d100S:Bd4
01`Q9@<0:Rd`100e=cT40451@`@0C4]<101GEED406=OGP<0KFQX101hLW4408=lNP@0SXF35P3oool0
01@0oooo102PV9H40:RQX0@0[j^Z0`2g]K@40<2o_`@0bLW:103BeMH40=cPhP@0ing_0`3Pj>`40=;M
hP@0`]7H102aa<d40:2f`0@0RZFb101eUJ@30665UP@0CGJ9100iIW/402UHKP@08e5V100RCV<7029=
H@@08TeP100SCF4402=>H@@08diR1`0TD6<402A>H@@09DiO100WCEh402U=G@@0;4iM0`0`Ced403EA
G@@0>59M100mDUd4045CG@@0A5EM0`18EE`404]EF`@0CeIK101?E5P404eBE@@0BdiA1016BT`30414
B0@0>d13100e>Sd402hd=`@0:Bhb100S9b/3034c=P@0?3do1017ATP4055@D@@0G5UI101VHV83071[
JP@0NWAc1024OG/408j6Q1H0oooo000D0?ooo`@0X9RF102XXJ040:n[ZP<0]kFd1030_kl40<W9bP@0
d]GF103Lh>840>O]k`<0h>S/103BgN840<;Af0@0/LC=102P]/0408ZU/P@0MIFT0`1QQIH404efR@@0
>FIk100YF6h402=AIP@08TiS1`0RCF44029=H0@08deQ100SCV4402=>HPL0951S100TCV4402E>G`@0
9deN100YCEd402a>G@<0<4mM100eDEd403QBG@@0?E9M1011Ded404AEG@<0B5EL101;EE/404mFF`@0
CeAH101=DUD404]>D@@0ATY<0`10A4P403]0@`@0=CXm100^=3L402T^<P@08bL[0`0a<cH403`m?`@0
AdI8101AD54405aIF@@0IV9R0`1`JfX407YdL`@0Q7ek102>QX@F0?ooo`00503oool40:2HUP@0Z:6P
102_ZjX30;Ne]0@0`;no1039bLX40=;EeP@0g>3R103WkNl30>3Xk0@0d]gR1032dMP40;74c@@0X;K0
102:YK8407FEY0<0HHFF101=MXT403UVN`@0:EQ^100SDFH4029>H`L08TeQ100RCF0402==H@@08diQ
100SCV8702A@H`@094iQ100UCUl402M=GP@0:DeM100/CUd3031?G@@0=E5M100hDUd403eBG@@0@E=M
1014EEd304QEG0@0BeEK101?EU/404mDF0@0CE9E101;CU4404I:C0<0@4A8100k@4<403Dj?@@0;S@g
100Y;S8402<W:`<0<C<f100l?Cl404M6B0@0DE1A101LFET406IRHP<0L6]Z101jM7<408AmN`@0SXJ4
5P3oool001@0oooo102PV9H40:RQX0@0[j^Z0`2g]K@40<2o_`@0bLW:103BeMH40=cPhP@0ing_0`3P
j>`40=;MhP@0`]7H102aa<d40:2f`0@0RZFb101eUJ@30665UP@0CGJ9100iIW/402UHKP@08e5V100R
CV<7029=H@@08TeP100SCF4402=>H@@08diR1`0TD6<402A>H@@09DiO100WCEh402U=G@@0;4iM0`0`
Ced403EAG@@0>59M100mDUd4045CG@@0A5EM0`18EE`404]EF`@0CeIK101?E5P404eBE@@0BdiA1016
BT`30414B0@0>d13100e>Sd402hd=`@0:Bhb100S9b/3034c=P@0?3do1017ATP4055@D@@0G5UI101V
HV83071[JP@0NWAc1024OG/408j6Q1H0oooo000D0?ooo`@0X9RF102XXZ040;2[ZP<0^;Fd1031_kl4
0<[:bP@0dmGF103NhN<40>__lP<0j_3c103Ki>T40<_HgP@0^l_C102[_lP409N_^P@0PYj/0`1_T9l4
05b2T`@0BW>7100gHgT402]IK`@0959X0`0RCV<4029>HP@084aP200OBf0401m<H0<084eQ100OCF44
01e;GP@07TUL100PBE/402=:F`@09d]K0`0[C5/4031>F`@0=4mK100iDE`403iBG0@0@eAM0`18EUh4
04]FG0@0CeIL101@EUX404mCE`@0C51C1018C4l304=8B`@0?d=6100h?D44030g>`@0;C<g100a=3L3
03Tl?P@0@dA6101=C4h405IEE@@0H5eM101YIFD307=^K@@0O7Ie1026OW`408n7Q1H0oooo000D0?oo
o`@0X9RF102XXZ040;2[ZP<0^;Fd1031_kl40<[:bP@0dmGF103NhN<40>__lP<0j_3c103Ki>T40<_H
gP@0^l_C102[_lP409N_^P@0PYj/0`1_T9l405b2T`@0BW>7100gHgT402]IK`@0959X0`0RCV<4029>
HP@084aP200OBf0401m<H0<084eQ100OCF4401e;GP@07TUL100PBE/402=:F`@09d]K0`0[C5/4031>
F`@0=4mK100iDE`403iBG0@0@eAM0`18EUh404]FG0@0CeIL101@EUX404mCE`@0C51C1018C4l304=8
B`@0?d=6100h?D44030g>`@0;C<g100a=3L303Tl?P@0@dA6101=C4h405IEE@@0H5eM101YIFD307=^
K@@0O7Ie1026OW`408n7Q1H0oooo000D0?ooo`@0X9RF102XXZ040;2[ZP<0^;Fd1031_kl40<[:bP@0
dmGF103NhN<40>__lP<0j_3c103Ki>T40<_HgP@0^l_C102[_lP409N_^P@0PYj/0`1_T9l405b2T`@0
BW>7100gHgT402]IK`@0959X0`0RCV<4029>HP@084aP200OBf0401m<H0<084eQ100OCF4401e;GP@0
7TUL100PBE/402=:F`@09d]K0`0[C5/4031>F`@0=4mK100iDE`403iBG0@0@eAM0`18EUh404]FG0@0
CeIL101@EUX404mCE`@0C51C1018C4l304=8B`@0?d=6100h?D44030g>`@0;C<g100a=3L303Tl?P@0
@dA6101=C4h405IEE@@0H5eM101YIFD307=^K@@0O7Ie1026OW`408n7Q1H0oooo000D0?ooo`@0X9RF
102XXZ040;2[ZP<0^;Fd1031_kl40<[:bP@0dmGF103NhN<40>__lP<0j_3c103Ki>T40<_HgP@0^l_C
102[_lP409N_^P@0PYj/0`1_T9l405b2T`@0BW>7100gHgT402]IK`@0959X0`0RCV<4029>HP@084aP
200OBf0401m<H0<084eQ100OCF4401e;GP@07TUL100PBE/402=:F`@09d]K0`0[C5/4031>F`@0=4mK
100iDE`403iBG0@0@eAM0`18EUh404]FG0@0CeIL101@EUX404mCE`@0C51C1018C4l304=8B`@0?d=6
100h?D44030g>`@0;C<g100a=3L303Tl?P@0@dA6101=C4h405IEE@@0H5eM101YIFD307=^K@@0O7Ie
1026OW`408n7Q1H0oooo000D0?ooo`@0X9RF102XXJ040;2[ZP<0^;Fd1031_kl40<[:bP@0e=GE103N
hN840>[^k`<0l?Kh103Tk>l40=COi0@0a=;I102da/l40::h``@0SZRd0`1mVZP406b=W@@0GH6B101;
LhH403aWN`@0<Eic0`0YEV/402IBI`@08DiS100NC64801e;H0<07TaQ100MC64401];G`@06TQL100K
AeX401i7F@@08TYJ0`0WBeX402]<F`@0;deK100fCe/403aBG@@0@EAN0`17Eel404aHGP@0CeQN101@
Ee`4051EF@@0CU=F101;Ce8304I;CP@0@TM:100l@DD403Hl?`@0;c@g100i?3l30493AP@0BT]<101C
DU<405aIFP@0I65Q101]JFP307I`K`@0OWQf1027Ogh40927QAH0oooo000D0?ooo`@0X9RF102XXJ04
0;2[ZP<0^;Fd1031_kl40<[:bP@0e=GE103NhN840>[^k`<0l?Kh103Tk>l40=COi0@0a=;I102da/l4
0::h``@0SZRd0`1mVZP406b=W@@0GH6B101;LhH403aWN`@0<Eic0`0YEV/402IBI`@08DiS100NC648
01e;H0<07TaQ100MC64401];G`@06TQL100KAeX401i7F@@08TYJ0`0WBeX402]<F`@0;deK100fCe/4
03aBG@@0@EAN0`17Eel404aHGP@0CeQN101@Ee`4051EF@@0CU=F101;Ce8304I;CP@0@TM:100l@DD4
03Hl?`@0;c@g100i?3l30493AP@0BT]<101CDU<405aIFP@0I65Q101]JFP307I`K`@0OWQf1027Ogh4
0927QAH0oooo000D0?ooo`@0X9RF102XXJ040;2[ZP<0^;Fd1031_kl40<[:bP@0e=GE103NhN840>[^
k`<0l?Kh103Tk>l40=COi0@0a=;I102da/l40::h``@0SZRd0`1mVZP406b=W@@0GH6B101;LhH403aW
N`@0<Eic0`0YEV/402IBI`@08DiS100NC64801e;H0<07TaQ100MC64401];G`@06TQL100KAeX401i7
F@@08TYJ0`0WBeX402]<F`@0;deK100fCe/403aBG@@0@EAN0`17Eel404aHGP@0CeQN101@Ee`4051E
F@@0CU=F101;Ce8304I;CP@0@TM:100l@DD403Hl?`@0;c@g100i?3l30493AP@0BT]<101CDU<405aI
FP@0I65Q101]JFP307I`K`@0OWQf1027Ogh40927QAH0oooo000D0?ooo`@0X9RF102XXIl40;2[Z@<0
^;Bc1031_[h40<[9b@@0e=CD103Ngn040>W[k0<0m?Oi103_m?L40=oWk0@0d=_Q1030cmH40:o2b`@0
Vk:m0`2;YK4407^IYP@0KHfL101NPI84051fR0@0A6ao0`0jI7P403=NL@@0;EQ/100WE6T402=@IP@0
8TmT0`0SD6D4021?I@@07TiS100MBf0401]:G@@074QL100PBU`302E;G0@0:TeM100_Ced403A@G@@0
>e=N1012EV0304UIH@@0CEYQ101BFf4405=JGP@0DeUL101BEUT404mCEP<0BdmB1018Bdh404=7BP@0
?D55100k?D0404=4A`<0BT]=101BDE8405UHF0@0HEiO101YIFD4075/J`<0NG=b1020NWP408R1O`@0
T8R55P3oool001@0oooo102PV9H40:RQW`@0/:^Y0`2h];<40<6n_P@0b/W9103De=@40=kOh0@0jN_/
0`3dmoT40>odm`@0gnO/103@fn440<3?eP@0[l;;102K/[d308^U/@@0NiVV101]SI`405j1TP@0D7J8
1014K7l303YTN0@0<eia100]F6`402MDJ@@08e1V100RCf@302=@I@@084mU100NCV<401e;H0@06dYM
100LB5`4021:G0<09D]L100ZCEd402m?G@@0=51M100kDeh4049FH0<0BEUQ101=FV44059KH@@0DeYN
101CFE`4059FF@@0Ce=F0`1;Ce8404Q;CP@0@dM:100m@DD403/m@0@0@dA70`1:Bdd4059ADP@0FEQH
101QGUl406UUI@@0LFa[0`1iLg84081jN0@0R85o102@R8DF0?ooo`00503oool40:2HUP@0Z:6O102`
ZjT30;Rd/`@0`Kjn103:bLT40=CDe0@0g]oP103Yjn`30?Cgn@@0koCg103Oin`40=3Kh@@0`<oF102_
`//409^b_@<0RjFa101kVJH406f=W0@0GX6B101@MXP404A/O`<0>VAh100cGW4402eHK0@09eAY100S
D6H4029?I0<08e1U100PCfD401i>H`@07D]P100KBUd401a8G0@084YL0`0UBe`402Y=G@@0;dmM100d
D5d403]CGP@0@UIP0`19FF4404eJH@@0DU]Q101CFUh405=IG0@0DUII101?DeH304]?DP@0B4]>1013
AdX403e1A@@0>ce01013A4L304Y;C@@0DU5B101IF5P4065NG`@0JFEU101aK6/307UcLP@0P7Yh1028
PGl40928QAH0oooo000D0?ooo`@0X9RF102XXIl40;2[Z@<0^;Bc1031_[h40<[9b@@0e=CD103Ngn04
0>W[k0<0m?Oi103_m?L40=oWk0@0d=_Q1030cmH40:o2b`@0Vk:m0`2;YK4407^IYP@0KHfL101NPI84
051fR0@0A6ao0`0jI7P403=NL@@0;EQ/100WE6T402=@IP@08TmT0`0SD6D4021?I@@07TiS100MBf04
01]:G@@074QL100PBU`302E;G0@0:TeM100_Ced403A@G@@0>e=N1012EV0304UIH@@0CEYQ101BFf44
05=JGP@0DeUL101BEUT404mCEP<0BdmB1018Bdh404=7BP@0?D55100k?D0404=4A`<0BT]=101BDE84
05UHF0@0HEiO101YIFD4075/J`<0NG=b1020NWP408R1O`@0T8R55P3oool001@0oooo102PV9D40:RQ
W`@0/:ZX0`2h/k840<2m_0@0bLO7103Cd]840=gMg@@0inWZ0`3dm_L40?Ojo@@0jNob103Jh^L40<_G
g@@0_<_C102Z_LH309V_^P@0RZ>_101lV:D406f<V`@0Gh6B101EN8T304eaPP@0AF]l100mIGP403IP
L`@0<Ea`1`0/F6`402YFJP@09eAX100TDFH4029?H`@08DeQ100TCF0302Q?H0@0;51P100bDV4403MC
H0@0?UIR1015FF<304aLI0@0D5eT101DGV<405IMHP@0EUaP101FFUd405=GFP<0D5=F101>D5<404]=
C`@0A4Q;1018BT`404e=C`<0DU9D101IEeT405mMGP@0IV=S101]JFT407A_KP<0NgEd1023O7X408Z2
P0@0THR65P3oool001@0oooo102PV9D40:RQW`@0/:ZX0`2h/k840<2m_0@0bLO7103Cd]840=gMg@@0
inWZ0`3dm_L40?Ojo@@0jNob103Jh^L40<_Gg@@0_<_C102Z_LH309V_^P@0RZ>_101lV:D406f<V`@0
Gh6B101EN8T304eaPP@0AF]l100mIGP403IPL`@0<Ea`1`0/F6`402YFJP@09eAX100TDFH4029?H`@0
8DeQ100TCF0302Q?H0@0;51P100bDV4403MCH0@0?UIR1015FF<304aLI0@0D5eT101DGV<405IMHP@0
EUaP101FFUd405=GFP<0D5=F101>D5<404]=C`@0A4Q;1018BT`404e=C`<0DU9D101IEeT405mMGP@0
IV=S101]JFT407A_KP<0NgEd1023O7X408Z2P0@0THR65P3oool001@0oooo102PV9D40:RQW`@0/:ZX
0`2h/k840<2m_0@0bLO7103Cd]840=gMg@@0inWZ0`3dm_L40?Ojo@@0jNob103Jh^L40<_Gg@@0_<_C
102Z_LH309V_^P@0RZ>_101lV:D406f<V`@0Gh6B101EN8T304eaPP@0AF]l100mIGP403IPL`@0<Ea`
1`0/F6`402YFJP@09eAX100TDFH4029?H`@08DeQ100TCF0302Q?H0@0;51P100bDV4403MCH0@0?UIR
1015FF<304aLI0@0D5eT101DGV<405IMHP@0EUaP101FFUd405=GFP<0D5=F101>D5<404]=C`@0A4Q;
1018BT`404e=C`<0DU9D101IEeT405mMGP@0IV=S101]JFT407A_KP<0NgEd1023O7X408Z2P0@0THR6
5P3oool001@0oooo102PV9D40:RQW`@0/:ZX0`2h/k840<2m_0@0bLO7103Cd]840=gMg@@0inWZ0`3d
m_L40?Ojo@@0jNob103Jh^L40<_Gg@@0_<_C102Z_LH309V_^P@0RZ>_101lV:D406f<V`@0Gh6B101E
N8T304eaPP@0AF]l100mIGP403IPL`@0<Ea`1`0/F6`402YFJP@09eAX100TDFH4029?H`@08DeQ100T
CF0302Q?H0@0;51P100bDV4403MCH0@0?UIR1015FF<304aLI0@0D5eT101DGV<405IMHP@0EUaP101F
FUd405=GFP<0D5=F101>D5<404]=C`@0A4Q;1018BT`404e=C`<0DU9D101IEeT405mMGP@0IV=S101]
JFT407A_KP<0NgEd1023O7X408Z2P0@0THR65P3oool001@0oooo102PUiD40:NPWP@0[jVW0`2g/[44
0;nl^`@0b<G5103Ad<l40=_KfP@0iNKV0`3al_840?[moP@0m?Sj103Tj^h40=GNh`@0am?I102faLd3
0:Nj``@0Ujfg102;Xjl407fHY@@0L8nM101VQYD305enSP@0EWR7101?LX<404M/O@@0@fUk100mI7H3
03YQM0@0=ema100eGG04039JK@@0;eU[100_EfT4035FJ0<0=5MW100gF6L403]JI`@0@E]W1017GVP4
04aOJ0<0Df5X101FHVP405YRI`@0Ff5U101KH6<405YNH0@0F5]M0`1EEeX405AFF0@0DE9E101ADU@4
059CE@@0EUIG0`1JFEX4061NGP@0IF9S101[IfL4075]K0@0N79a0`1nN7L408EmO0@0Rh>1102BRHLF
0?ooo`00503oool40:2GU@@0Yj2N102_ZJL30;Nb/@@0_kbk1038aLD40=7@c`@0fm_J103Ui^H30?7b
lP@0n_gn103dn?X40>CZkP@0eMkS1037dmT40;K5c@<0Yk[3102G[KL408^S[`@0OIRU101`Sid406J6
U@<0GGj>101FN8L404mbP`@0Afam1013JG/403eTMP<0>V5d100gGg4403EML0@0<UY]100_FF/402mG
J@@0<EIX0`0dEfL403MHI`@0>eYW1011FfL404MNJ0@0C5mX0`1CHFP405IRJ0@0FV9W101KHFD405]P
H`@0FUiP101HFed305EGFP@0E5IH101ADUD4055BE0@0DU=E101FEUL305YIFP@0H5iN101UHV<406]W
I`@0LFe/101hLW4307ihM`@0QGel102;Ph4409:9QaH0oooo000D0?ooo`@0X9NE102WX9h40:nYY`<0
]k:a102o_;/40<S5a@@0dM3?103KfmX40>GViP<0lO;b103joOh40?ChnP@0i>[^103Eg^<40<OCf@@0
]/G=0`2W^/<409N]]`@0Rj>_101mV:D4072?W@@0IXJE0`1MOXh405IhQ`@0Cg:31017K7d404=YN`@0
?FAf0`0jHG@403MOL@@0=Ee`100bFVd402mIJ`@0;eMY100aEVP303AGI`@0=eQW100kFVL4045KI`@0
AeiX101<GfP305=QJ0@0EV9X101JHVL405]QI@@0Ff1S101JGV0405QKG@<0EEMJ101DEUP4055BE@@0
DE9D101BDeD405IFE`<0FUUJ101PGUh406ERH`@0JfMW101aKF`407QbL@<0OWQg1025OG`408^3P@@0
TXV75P3oool001@0oooo102PUiD40:NPWP@0[jVW0`2g/[440;nl^`@0b<G5103Ad<l40=_KfP@0iNKV
0`3al_840?[moP@0m?Sj103Tj^h40=GNh`@0am?I102faLd30:Nj``@0Ujfg102;Xjl407fHY@@0L8nM
101VQYD305enSP@0EWR7101?LX<404M/O@@0@fUk100mI7H303YQM0@0=ema100eGG04039JK@@0;eU[
100_EfT4035FJ0<0=5MW100gF6L403]JI`@0@E]W1017GVP404aOJ0<0Df5X101FHVP405YRI`@0Ff5U
101KH6<405YNH0@0F5]M0`1EEeX405AFF0@0DE9E101ADU@4059CE@@0EUIG0`1JFEX4061NGP@0IF9S
101[IfL4075]K0@0N79a0`1nN7L408EmO0@0Rh>1102BRHLF0?ooo`00503oool40:2GU@@0YinM102^
Z:H30;Ja[`@0_[Zh1036`l840<o=c0@0f=OG103Rh^830>g^kP@0n?[j103koOh40>kam0@0h>KZ103B
fml40<7>e0<0]<?:102W^L4409b`^@@0SJB_1020VZH407RBWP<0KXZG101VPi4405mnS0@0EWN7101C
M8<404i_O`<0BVam1016JGX404AWN0@0@FEe100oHg<403iQL@@0?f5`0`12HG0404ERK`@0B69_101<
I6h4059UK`@0EVI^0`1JIfh405eWK@@0H6M/101QIVX4065TI`@0H69U101NGf4305]LGP@0FUYL101I
FE/405YIF`@0Fe]L101NGEh3069PH0@0IV=T101[IfL4071/J`@0MG1`101kMG@3085jN@@0QWmm102<
Q88409::QaH0oooo000D0?ooo`@0X9NE102WWid40:jXYP<0][6_102n^[P40<K3`P@0clg<103HemL4
0>;RhP<0kNk^103hn_X40?_moP@0k_7d103Pi^X40=;Kg`@0`LkD0`2d`lX40:Ni`@@0W;2i102=Y:l4
082JYP@0N9:N0`1^RYL406J3T@@0Ggj<101FMhL405=dP`@0CVmo0`1:K7d404IYNP@0A6Mh1011IGD4
03mSL`@0?V5a100oHG03049QL0@0AF9_1018HVl404aTKP@0DVE_101FIVh305YWKP@0GFM]101PIf`4
065VJP@0HFAW101PHVD405iOH@<0FeaN101JFU`405UIF`@0FUUK101KFe`405iMGP<0HV1P101VHf@4
06]WI`@0L6a[101eL70407]eM0<0PGYi1026Ogd408b4PP@0TXZ75P3oool001@0oooo102PUiD40:NO
W@@0[ZRV0`2f/Jl40;jj^0@0a/?2103?cL`40=SGe`@0h^;R0`3]k^h40?SjnP@0nogn103^lO@40>3V
jP@0d]_O1031c]@30;C3bP@0YkW1102L/;T408fT[`@0P9ZV101hTYh306j:U`@0IX>A101OOX`405Ig
Q`@0DgB3101>Kgl304Y/O@@0AVUj1014IgP4045UM@@0?f=c100nHG4403mQL0<0@V5`1015HVl404QR
K`@0C6A^101BIFl405IVKP<0FVM^101MIfd4061WK0@0HFIZ101QI6L4061RI@@0GUmQ0`1KG5h405YJ
G0@0FEUK101JFE/405]KG0@0GUeN0`1RH60406ISI0@0JfMW101`K6/407E`L0@0NgEd0`21NWT408Io
O@@0S8B2102BRXLF0?ooo`00503oool40:2GU@@0YinM102^Z:H30;Ja[`@0_[Zh1036`l840<o=c0@0
f=OG103Rh^830>g^kP@0n?[j103koOh40>kam0@0h>KZ103Bfml40<7>e0<0]<?:102W^L4409b`^@@0
SJB_1020VZH407RBWP<0KXZG101VPi4405mnS0@0EWN7101CM8<404i_O`<0BVam1016JGX404AWN0@0
@FEe100oHg<403iQL@@0?f5`0`12HG0404ERK`@0B69_101<I6h4059UK`@0EVI^0`1JIfh405eWK@@0
H6M/101QIVX4065TI`@0H69U101NGf4305]LGP@0FUYL101IFE/405YIF`@0Fe]L101NGEh3069PH0@0
IV=T101[IfL4071/J`@0MG1`101kMG@3085jN@@0QWmm102<Q88409::QaH0oooo000D0?ooo`@0WiND
102VWi`40:fWY@<0]Jn]102l]kH40<C0_`@0c<[9103Edm<40=oNg@<0jNWX103dmOD40?koo`@0moWj
103Zk_040=gSiP@0cmSL0`31c=840;C2b@@0Z[[1102N/;T4096V/0@0RIjX0`1nUJ0407N?V`@0L8VE
101YPi0406=oS0@0GW^90`1JMhD405IdPP@0E760101BKgh404m/N`@0Cf]j101?JgP3059/N0@0EFah
101HKGP405]^M`@0Gfig101RKWD306=]L`@0IFeb101WKG0406Q/K`@0J6Y/101UIVP4065RI0<0GemQ
101OGf04061OH0@0HF1Q101SHF8406ESI0<0J6EV101/J6T4071/K0@0M71_101iM7<407ihM`<0Pgak
1028PGl408j6P`@0ThZ85P3oool001@0oooo102OUi@40:JOW0@0[JNU0`2e[jd40;bg]P@0a<2o103<
b/T40=GCd`@0gmkM0`3YjNP40?Cem@@0o_oo103gnOX40>[^l0@0gN?V103?f=`30<7<dP@0]<;9102Z
^/4409j`^@@0TJJ`1029WZP307jEX0@0MhnK101`RID406V3T0@0Hgn<101NNhT305YgQ@@0EWB2101D
LH04059_OP@0Cfak101?JgX404m[N0<0DVah101EK7P405Q]N0@0Ffig101OKWL4069^M@<0Hfec101U
KG8406M]L0@0J6a_101XJV`406EVJ0@0HF9T0`1OGf4405mOH0@0H5mP101QH64406=QHP@0IF=T0`1X
IFH406aXJ@@0L6a/101dL6l407UdL`@0OWQg0`23O7/408R1O`@0SXJ3102CRXPF0?ooo`00503oool4
09nGU0@0YYnL102]YjD30;F_[@@0_;Nf1034`;l40<c:b@@0eM?C103Og]d30>WYj0@0m?Ge103nool4
0?OinP@0j^k`103MhnH40<oHg0<0`LcB102d`/T40:Zj`@@0W[2i102AY[0408VNZ0<0OYFP101gSi/4
0729U@@0JH>@101SOh`405ikR@<0FWN5101FM88405AaP0@0DVmn101?K7/404m[NP@0Cf]h0`1BK7P4
05E/N0@0F6eh101KKWL405m^M`@0HVie0`1SKG<406E]LP@0Ife`101XK6l406QZK0@0IFIX101QHV@3
05mOH@@0GemP101PGf04065PH@@0Hf5R101UHf@306QUIP@0K6QY101`K6`407A`K`@0NGAc101nN7L3
08=lN`@0R85o102>QX<409>:R1H0oooo000D0?ooo`@0WiND102VWi`40:fWY@<0]Jn]102l]kH40<C0
_`@0c<[9103Edm<40=oNg@<0jNWX103dmOD40?koo`@0moWj103Zk_040=gSiP@0cmSL0`31c=840;C2
b@@0Z[[1102N/;T4096V/0@0RIjX0`1nUJ0407N?V`@0L8VE101YPi0406=oS0@0GW^90`1JMhD405Id
PP@0E760101BKgh404m/N`@0Cf]j101?JgP3059/N0@0EFah101HKGP405]^M`@0Gfig101RKWD306=]
L`@0IFeb101WKG0406Q/K`@0J6Y/101UIVP4065RI0<0GemQ101OGf04061OH0@0HF1Q101SHF8406ES
I0<0J6EV101/J6T4071/K0@0M71_101iM7<407ihM`<0Pgak1028PGl408j6P`@0ThZ85P3oool001@0
oooo102OUY@40:FNV`@0[:FS0`2c[J/40;Ze/`@0`Kfl1039a/@40=;?cP@0f]SH0`3Thn840>o^k@@0
no_k103oool40?Ggn0@0j>_]103Kh><30<kFfP@0`/cA102jaL/40:nl``@0Y;>j102KZk<3092RZP@0
R9^T1021UIh407^@VP@0M8^E101`Qi4306b3S`@0J7n;101TO8P4069jQP@0H7N3101OMX84061eP0<0
I7N1101TMX0406MgP0@0JgQo101]N7h406mgO0<0KgIj101`MGP4075dMP@0L79d101^Kg4406i/KP@0
JVQY0`1THF8406ITI@@0IfEV101XIVH406YWI`@0K6UY0`1^Jf/4075]K@@0MG1`101iLg<407egMP@0
PG]i0`26Ogd408Z3P@@0ShN4102DRhPF0?ooo`00503oool409nFU0@0YIjK102/YJ<30;>]Z`@0^[Fc
1031_K`40<W6a0@0d/o>103Jf=P30>CShP@0knk]103kno/40?ooo`@0mOOh103Xjnd40=_Ph`<0c]KJ
1032c=440;[5b`@0[kc3102T/kX409^[/`<0T::Z1028Vj@4086EWP@0Ni2J101dRiD40727T@<0K8>?
101XOh/406AlR0@0HWZ6101PMh<405mfPP@0H7F00`1TMh4406AfP0@0IgN0101[N7l406ehOP@0KgMl
0`1_MWX4071eN0@0LGAf101`LW@406i_L@@0KVa^101ZJ6T306AQHP@0IVAU101WIFH406QVIP@0JVMW
101/JFT306i[J`@0LFe]101eL70407UcL`@0OGMf1021NgT308IoO@@0RX>1102?Qh@409B;R1H0oooo
000D0?ooo`@0WiJD102UWY/40:bUX`<0/jf[102j]K<40<6m_0@0bLK4103Bclh40=[Hf0<0i>?R103_
k^d40?_kn`@0oooo103emoP40>S[k@@0fn3S0`3>e]X40<;<d@@0^/G;102__<<40:Bc^P@0Vj^c0`2@
XZX408RKY0@0PIFN101kT9X407B;U@@0L8NA0`1/Phl406QoR`@0I7b8101RNXH4061gP`@0GgJ2101P
MH0306AgP@@0I7J0101WMh0406]hO`@0KGQn101_Mg`306mfNP@0L7Eh101aM7H4071bM0@0KVma101^
K6h406YXJ@<0I65R101VI6D406MUIP@0J6IV101ZIfL406aYJ@<0KV][101aKFd407E`L0@0NG=c101m
MgH4085kN@<0QWmm102:Ph4408n7Q0@0U8^85P3oool001@0oooo102NUY<40:BLVP@0Zj>Q0`2aZZT4
0;Rb/0@0_[Vh1036`L040<g:b0@0eM?A0`3Ng=/40>SVi@@0l_3`103mno/40?onoP@0m?Ce103WjNX3
0=[Nh0@0cmGH1037c]440;o7c0@0]Ko4102]^;d30:>_]P@0VZN^102CXJT408fLY0@0R9RO1022Ti/3
07f?U`@0NH^D101eQi0407:4SP@0L86;101^P8T406inQ`<0LX28101ePHT407R2R@@0NX:8101lPHH4
07f0Q0<0O7n1101jO7h407UjN`@0NGQi101eMGH4079`LP@0KVa^0`1]Jf/406eZJ`@0KV][101^Jf`4
071/K0@0LVi^0`1dL6l407IbL@@0NGAc101mMgH4081jN@@0Q7el0`28PGl408b4PP@0T8R5102DRhTF
0?ooo`00503oool409jFT`@0Y9bJ102[Xj430;6ZZ@@0^;:`102n^KP40<K1`0@0cL[8103Edm430=kL
f`@0j>KU103bl?040?gkn`@0ookn103dm?D40>OYjP<0f]kP103?eMP40<O>d@@0_lO<102e_l@40:fh
_@<0Xjnf102JYjh409>QZ@@0SIbT1028V9l408:CV`<0OHnG101iRi@407F7T0@0LXB>101`PH/406j0
R@@0KWj70`1bP8P407F1R@@0N8:9101jPXP407b1QP@0OH240`1lOh4407YlOP@0NGYk101iN7T407Ee
MP@0LW1b101^K6h306e[J`@0KFY[101^Jf/406i[K0@0L6a/101bKVh307A`K`@0MW9a101iM7<407eg
MP@0P7Yi1024OG`308R1O`@0S8B2102@R8D409B;RAH0oooo000D0?ooo`@0WYJC102TW9X40:^SX@<0
/JZY102h/[040;ji^0@0a/70103=b/P40=GCd@<0g]cK103Xi^D40?;`l0@0oO_k103oo_h40?Cdm@@0
inWZ0`3Jg^040<oEf0@0alkA102oal`40;Foa0@0[KRm0`2S[kH409ZW[P@0Tj6Y102=W:@408RHW`@0
PY>K0`1mSiL407V;U0@0MHN@101bQ8h40721R`@0KX29101^OXL307:0R0@0MH69101hPXT407Z2R0@0
O866101mP8@307aoP@@0NWan101iNW/407UhN@@0MGEf101bL78406i/KP<0KF][101]JV/406i[J`@0
KV]/101`K6`4079^KP<0M71_101fLW4407UdL`@0OGMf1020NWT408AmO0<0R85o102<Q8840928Q@@0
U8^95P3oool001@0oooo102NUY<40:BLVP@0Zj>Q0`2aZZT40;Rb/0@0_[Vh1036`L040<g:b0@0eM?A
0`3Ng=/40>SVi@@0l_3`103mno/40?onoP@0m?Ce103WjNX30=[Nh0@0cmGH1037c]440;o7c0@0]Ko4
102]^;d30:>_]P@0VZN^102CXJT408fLY0@0R9RO1022Ti/307f?U`@0NH^D101eQi0407:4SP@0L86;
101^P8T406inQ`<0LX28101ePHT407R2R@@0NX:8101lPHH407f0Q0<0O7n1101jO7h407UjN`@0NGQi
101eMGH4079`LP@0KVa^0`1]Jf/406eZJ`@0KV][101^Jf`4071/K0@0LVi^0`1dL6l407IbL@@0NGAc
101mMgH4081jN@@0Q7el0`28PGl408b4PP@0T8R5102DRhTF0?ooo`00503oool409jETP@0Xi^I102Y
XIl30:nXYP@0]Jn]102k]K@40<:m^`@0bLC3103@c</30=SDd`@0h=gL103Yi^D40?7_k`@0no[i103m
no/40??al@<0iNKW103Ifmd40=3DeP@0bloB1034bL`40;g2a@<0]K^n102[/kP40:B]/P@0WZN/102H
XZP409>NY0<0SYZP1029UI`408JBV@@0PXjF1020S9<407b8T0@0NhJ=0`1mQX`407n6S@@0QHZ>1028
Rhh408R9S0@0R8R;0`26QHL408>2P`@0P7n0101nOGd407ekN`@0N7If101fLW<307AaL@P0M71`101e
LG0407IaL@@0Mg9b0`1iM7<407]fM@@0OWQg1020NWT408=mN`@0Qh1n0`2:PX4408j5P`@0THV6102E
S8TF0?ooo`00503oool409jETP@0Xi^I102YXIl30:nXYP@0]Jn]102k]K@40<:m^`@0bLC3103@c</3
0=SDd`@0h=gL103Yi^D40?7_k`@0no[i103mno/40??al@<0iNKW103Ifmd40=3DeP@0bloB1034bL`4
0;g2a@<0]K^n102[/kP40:B]/P@0WZN/102HXZP409>NY0<0SYZP1029UI`408JBV@@0PXjF1020S9<4
07b8T0@0NhJ=0`1mQX`407n6S@@0QHZ>1028Rhh408R9S0@0R8R;0`26QHL408>2P`@0P7n0101nOGd4
07ekN`@0N7If101fLW<307AaL@P0M71`101eLG0407IaL@@0Mg9b0`1iM7<407]fM@@0OWQg1020NWT4
08=mN`@0Qh1n0`2:PX4408j5P`@0THV6102ES8TF0?ooo`00503oool409jETP@0Xi^I102YXIl30:nX
YP@0]Jn]102k]K@40<:m^`@0bLC3103@c</30=SDd`@0h=gL103Yi^D40?7_k`@0no[i103mno/40??a
l@<0iNKW103Ifmd40=3DeP@0bloB1034bL`40;g2a@<0]K^n102[/kP40:B]/P@0WZN/102HXZP409>N
Y0<0SYZP1029UI`408JBV@@0PXjF1020S9<407b8T0@0NhJ=0`1mQX`407n6S@@0QHZ>1028Rhh408R9
S0@0R8R;0`26QHL408>2P`@0P7n0101nOGd407ekN`@0N7If101fLW<307AaL@P0M71`101eLG0407Ia
L@@0Mg9b0`1iM7<407]fM@@0OWQg1020NWT408=mN`@0Qh1n0`2:PX4408j5P`@0THV6102ES8TF0?oo
o`00503oool409jETP@0Xi^I102YXIl30:nXYP@0]Jn]102k]K@40<:m^`@0bLC3103@c</30=SDd`@0
h=gL103Yi^D40?7_k`@0no[i103mno/40??al@<0iNKW103Ifmd40=3DeP@0bloB1034bL`40;g2a@<0
]K^n102[/kP40:B]/P@0WZN/102HXZP409>NY0<0SYZP1029UI`408JBV@@0PXjF1020S9<407b8T0@0
NhJ=0`1mQX`407n6S@@0QHZ>1028Rhh408R9S0@0R8R;0`26QHL408>2P`@0P7n0101nOGd407ekN`@0
N7If101fLW<307AaL@P0M71`101eLG0407IaL@@0Mg9b0`1iM7<407]fM@@0OWQg1020NWT408=mN`@0
Qh1n0`2:PX4408j5P`@0THV6102ES8TF0?ooo`00503oool409fDTP@0XYZG102WWid30:bUX`@0/Z^Y
102g/Jl40;fh]P@0`kjm103:aL@30=7<b`@0f=CC103Og=/40>OTh`@0knc[103hm_D40?Wfm@<0knc/
103Thn<40=WIfP@0dmCE103>d=440<W;c0<0`/C6102k_L040;Jh^`@0[k>f102Y[K040:BY[0<0WZBX
102IX:@409FLX0@0TIRM102?UI/408^BU`@0QhjB0`26S90408N<T0@0RhfA102;SHl408b<SP@0S8^=
0`2<RX/408V7Q`@0QhB41024PH44089oO`@0OGYj101lN7P307]gMP@0NWIe201jMGD407]fM@@0O7Mf
0`1nN7L407mjN@@0PW]j1024OG`408IoOP@0RH:00`2<Q88408n7Q@@0TXV7102ES8XF0?ooo`00503o
ool409fDTP@0XYZG102WWid30:bUX`@0/Z^Y102g/Jl40;fh]P@0`kjm103:aL@30=7<b`@0f=CC103O
g=/40>OTh`@0knc[103hm_D40?Wfm@<0knc/103Thn<40=WIfP@0dmCE103>d=440<W;c0<0`/C6102k
_L040;Jh^`@0[k>f102Y[K040:BY[0<0WZBX102IX:@409FLX0@0TIRM102?UI/408^BU`@0QhjB0`26
S90408N<T0@0RhfA102;SHl408b<SP@0S8^=0`2<RX/408V7Q`@0QhB41024PH44089oO`@0OGYj101l
N7P307]gMP@0NWIe201jMGD407]fM@@0O7Mf0`1nN7L407mjN@@0PW]j1024OG`408IoOP@0RH:00`2<
Q88408n7Q@@0TXV7102ES8XF0?ooo`00503oool409fDTP@0XYZG102WWid30:bUX`@0/Z^Y102g/Jl4
0;fh]P@0`kjm103:aL@30=7<b`@0f=CC103Og=/40>OTh`@0knc[103hm_D40?Wfm@<0knc/103Thn<4
0=WIfP@0dmCE103>d=440<W;c0<0`/C6102k_L040;Jh^`@0[k>f102Y[K040:BY[0<0WZBX102IX:@4
09FLX0@0TIRM102?UI/408^BU`@0QhjB0`26S90408N<T0@0RhfA102;SHl408b<SP@0S8^=0`2<RX/4
08V7Q`@0QhB41024PH44089oO`@0OGYj101lN7P307]gMP@0NWIe201jMGD407]fM@@0O7Mf0`1nN7L4
07mjN@@0PW]j1024OG`408IoOP@0RH:00`2<Q88408n7Q@@0TXV7102ES8XF0?ooo`00503oool409fD
TP@0XYZG102WWid30:bUX`@0/Z^Y102g/Jl40;fh]P@0`kjm103:aL@30=7<b`@0f=CC103Og=/40>OT
h`@0knc[103hm_D40?Wfm@<0knc/103Thn<40=WIfP@0dmCE103>d=440<W;c0<0`/C6102k_L040;Jh
^`@0[k>f102Y[K040:BY[0<0WZBX102IX:@409FLX0@0TIRM102?UI/408^BU`@0QhjB0`26S90408N<
T0@0RhfA102;SHl408b<SP@0S8^=0`2<RX/408V7Q`@0QhB41024PH44089oO`@0OGYj101lN7P307]g
MP@0NWIe201jMGD407]fM@@0O7Mf0`1nN7L407mjN@@0PW]j1024OG`408IoOP@0RH:00`2<Q88408n7
Q@@0TXV7102ES8XF0?ooo`00503oool409fDT@@0XIRF102UWI/30:ZRX0@0[jNU102c[J/40;Rb/0@0
_[Rf1033_[`30<W4``@0cl_9103FdM040=cHe`@0hn3N103[inH70?C`k`@0jnOV103OgMd40=SGe`@0
e=;C103Ad=030<_:b`@0a<?4102o_/040;^j_0@0^;Nh102c/k@30:f^/0@0Z:V[102TYJP409nQY0@0
W9jQ102HVYh409NHV`<0TYBG102DUIL409NEU`@0V9FF102HU9@409NBT`<0UI6A102CSXd408f9R@@0
RXJ51028Q8<408B0O`@0PWem0`20Ng/407mjNPP0OgYi1020NWT4085kNP<0PWak1024OG`408EoO@@0
Qh1o1029PX0408b4PP<0SXJ4102AR8H409>:R0@0UXf:5P3oool001@0oooo102MU9440:6HUP@0YIfK
0`2ZXZ040:nWY@@0/jf[102h/[040;jh]P@0`kjl0`39a<<40<o;b@@0e]7@103Lf=L40>?PgP@0jnOV
1`3dl>l40>_WiP@0gmgM103HemL40=CBd`@0dM3@0`3;b//40<C3a0@0_kk0102k^[`40;Rg^0@0/k>d
0`2][[040:RYZ`@0Y:FX102OXJ@409bNX@@0V9ZN102GV9/309:DU`@0U9FG102GUIL409REUP@0V9BD
102GTY<309FAT@@0Thj=102=RHT408Z6Q@@0R8B31024P7l4089mO@<0P7]k101oNWX807mjN@@0P7Yi
1021NgX3089lN`@0Q7el1025Ogd408N0O`@0RH:0102<Q88308j6Q0@0THR6102CRXP409J=RQH0oooo
000D0?ooo`@0WIBA102QV9H40:FMV`<0ZZ:P102_YjD40;>]Z`@0^;:`102n^;H40<>n_0<0bLC3103?
blT40=KAd0@0g=SG103Sh=h40>_WiPL0m?3_103[inH40=oMg@@0f=OG103Dd]<40=7@d0<0bl[;1034
`l@40;nn`0@0^kZl102h]kP40;>c]0<0[Jj`102XZJ/40:BUZ0@0Wj6T102LWZ4409RJWP@0UiRK0`2B
U9L409BEU`@0UiFG102HUIH409RDU0@0Ui:C0`2ETI4409>>S@@0SHV9102:QXD408R4P`@0Q81o1022
OGd3081kN`@0OgYj201oNWT4081jN@@0PG]j0`22O7/408AmO0@0QGmm1027P7l408V2P0@0S8B20`2>
QX@40968QP@0ThZ8102FSHXF0?ooo`00503oool409fDT@@0XIRF102UWI/30:ZRX0@0[jNU102c[J/4
0;Rb/0@0_[Rf1033_[`30<W4``@0cl_9103FdM040=cHe`@0hn3N103[inH70?C`k`@0jnOV103OgMd4
0=SGe`@0e=;C103Ad=030<_:b`@0a<?4102o_/040;^j_0@0^;Nh102c/k@30:f^/0@0Z:V[102TYJP4
09nQY0@0W9jQ102HVYh409NHV`<0TYBG102DUIL409NEU`@0V9FF102HU9@409NBT`<0UI6A102CSXd4
08f9R@@0RXJ51028Q8<408B0O`@0PWem0`20Ng/407mjNPP0OgYi1020NWT4085kNP<0PWak1024OG`4
08EoO@@0Qh1o1029PX0408b4PP<0SXJ4102AR8H409>:R0@0UXf:5P3oool001@0oooo102LTi040:2G
U0@0Xi^H0`2WWid40:^TX@@0[jRV102c[J/40;Ra[`@0_KJe0`31_;X40<O1_`@0c<O5103BcL/40=SC
d@@0g]WG103Th=h30>gXiP@0knWX103Yhn840=gIf0@0e];A103Bc/h30=3=c@@0cLW91039aLD40<G1
`@@0`;bl102m^KT30;^g]`@0][:b102_[:`40:VWZ@@0YZBU102RXJ<40:6NW`<0ViZK102LVY/409jJ
VP@0WYVI102NV9L409bFUP<0VYBC102ITY44092;R`@0SXV8102;QXD408V3P`@0Qh600`25P7l408Ao
OPP0Q7im1025OWd408EoO@<0QWmn1027P7l408V2P0@0RX>1102<Q88408j6Q0<0T8R5102BRHL409B;
R@@0UXf:5P3oool001@0oooo102LTi040:2GU0@0Xi^H0`2WWid40:^TX@@0[jRV102c[J/40;Ra[`@0
_KJe0`31_;X40<O1_`@0c<O5103BcL/40=SCd@@0g]WG103Th=h30>gXiP@0knWX103Yhn840=gIf0@0
e];A103Bc/h30=3=c@@0cLW91039aLD40<G1`@@0`;bl102m^KT30;^g]`@0][:b102_[:`40:VWZ@@0
YZBU102RXJ<40:6NW`<0ViZK102LVY/409jJVP@0WYVI102NV9L409bFUP<0VYBC102ITY44092;R`@0
SXV8102;QXD408V3P`@0Qh600`25P7l408AoOPP0Q7im1025OWd408EoO@<0QWmn1027P7l408V2P0@0
RX>1102<Q88408j6Q0<0T8R5102BRHL409B;R@@0UXf:5P3oool001@0oooo102LTi040:2GU0@0Xi^H
0`2WWid40:^TX@@0[jRV102c[J/40;Ra[`@0_KJe0`31_;X40<O1_`@0c<O5103BcL/40=SCd@@0g]WG
103Th=h30>gXiP@0knWX103Yhn840=gIf0@0e];A103Bc/h30=3=c@@0cLW91039aLD40<G1`@@0`;bl
102m^KT30;^g]`@0][:b102_[:`40:VWZ@@0YZBU102RXJ<40:6NW`<0ViZK102LVY/409jJVP@0WYVI
102NV9L409bFUP<0VYBC102ITY44092;R`@0SXV8102;QXD408V3P`@0Qh600`25P7l408AoOPP0Q7im
1025OWd408EoO@<0QWmn1027P7l408V2P0@0RX>1102<Q88408j6Q0<0T8R5102BRHL409B;R@@0UXf:
5P3oool001@0oooo102LTi040:2GU0@0Xi^H0`2WWid40:^TX@@0[jRV102c[J/40;Ra[`@0_KJe0`31
_;X40<O1_`@0c<O5103BcL/40=SCd@@0g]WG103Th=h30>gXiP@0knWX103Yhn840=gIf0@0e];A103B
c/h30=3=c@@0cLW91039aLD40<G1`@@0`;bl102m^KT30;^g]`@0][:b102_[:`40:VWZ@@0YZBU102R
XJ<40:6NW`<0ViZK102LVY/409jJVP@0WYVI102NV9L409bFUP<0VYBC102ITY44092;R`@0SXV8102;
QXD408V3P`@0Qh600`25P7l408AoOPP0Q7im1025OWd408EoO@<0QWmn1027P7l408V2P0@0RX>1102<
Q88408j6Q0<0T8R5102BRHL409B;R@@0UXf:5P3oool001@0oooo102KTXl409jET`@0XIVF0`2TW9X4
0:RPW@@0Zj>Q102^YjD40;:[Z@@0]Zn]0`2j/k440;jg]@@0`[bj1036`;l40<_5``@0d<[9103Fd<h3
0=_Ed`@0h=[H103Ug]`40>?LfP@0fM?B103CcL/30<k9b0@0c<K61039`l<40<S2`0@0aKjm1031^[P3
0;ff]@@0^[Bb102e[jd40;6[ZP@0ZjJU102WXj<40:FQX@<0XinO102QWYd40::MW0@0XifL102SViX4
0:6JV@<0WINF102LUID409F?SP@0THb;102?RHP408f6Q@@0RhF30`2:Ph8808V2P@P0RH:01029PX43
08Z3P@@0RhB2102<Q8<408f5P`@0ShN4102@R8H309:9Q`@0Th^8102ES8T409N=RaH0oooo000D0?oo
o`@0Vi:?102NUI<40:6IUP<0Y9bJ102XX9d40:^SX@@0[ZNU102bZjT40;J_[@<0^[>a102n]kD40<:l
^P@0a/2o103;aL<40=3:b@@0e]3>0`3KeM<40>3Jf0@0iMkL103Sg=X40=WCdP@0dlg;0`3>bLP40<c6
aP@0bL?31038`/040<Fn_@@0`KZh0`2m][D40;Zd/P@0]Jn]102aZjX40:^VY@@0Yj>S102UXJ430:>O
W`@0XIjM102RWI`40:>MW0@0Xi^J102QVYT309fGUP@0W9FE102EShh4096<R`@0ShV8102=QXD408^5
P`<0RX>22029PX4808V2P0@0RH:10`2:Ph4408^4PP@0S8B3102=QH<408n7Q0@0T8R60`2BRHL409>;
R0@0UHb9102GSH/F0?ooo`00503oool409^BS`@0WYFC102QVIH30:BLVP@0Z:2M102[Xj440:jWY@@0
/Z^Y102f[jd30;Zc/@@0_[Ne1032_;X40<K0_`@0blG3103@b/T40=K@cP<0fmGC103Pf]P40>GNg0@0
hmcJ103Idm840=?=b`<0c/W8103<a/H40<W3``@0b<;01035_[d40<6j^0<0_KJe102j];840;F_[@@0
/J^Z102[YZD40:NSX`@0YJ6Q0`2SWil40:6NW@@0XYfL102SWI`40:>KVP@0XIZI0`2MUiH409bEU@@0
UHn>102AS8/408n9R0@0SHJ5102;QH<308Z3PPP0RH:12029PX0408V2P@<0RX>1102;Q88408b4P`@0
SHF3102?Qh@40928QP<0TXV7102CRhP409F<R@@0Uhf;5P3oool001@0oooo102KTHh409fCT@@0WiJD
0`2QVIH40:BKV@@0YYjL102YXIl40:bTXP@0[ZNU0`2aZZP40;B]Z`@0^;6_102k];840;nh]P@0`[bi
1036`;d30<[3`@@0c/O4103BblP40=O@c@@0elo<103Ec<T30<o7a@@0b<6o1037_kh40<Jn_@@0a;^i
1030^;H30;be/`@0^[:`102g[jh40;F]Z`@0/JZX102_YjH40:ZTX`<0Z:>Q102VXJ040:BPWP@0Y9nN
102RW9/40:FOWP<0XibK102LUI@409NAS`@0U8f<102BRhT40929Q`@0ShR60`2>QhD408f6Q0P0SHF4
102=QH<408f6Q0<0SXJ4102?Qh@408n7Q@@0T8R6102ARHH409::Q`<0Th^8102ES8T409J=RP@0Uhj;
5P3oool001@0oooo102KTHh409fCT@@0WiJD0`2QVIH40:BKV@@0YYjL102YXIl40:bTXP@0[ZNU0`2a
ZZP40;B]Z`@0^;6_102k];840;nh]P@0`[bi1036`;d30<[3`@@0c/O4103BblP40=O@c@@0elo<103E
c<T30<o7a@@0b<6o1037_kh40<Jn_@@0a;^i1030^;H30;be/`@0^[:`102g[jh40;F]Z`@0/JZX102_
YjH40:ZTX`<0Z:>Q102VXJ040:BPWP@0Y9nN102RW9/40:FOWP<0XibK102LUI@409NAS`@0U8f<102B
RhT40929Q`@0ShR60`2>QhD408f6Q0P0SHF4102=QH<408f6Q0<0SXJ4102?Qh@408n7Q@@0T8R6102A
RHH409::Q`<0Th^8102ES8T409J=RP@0Uhj;5P3oool001@0oooo102KTHh409fCT@@0WiJD0`2QVIH4
0:BKV@@0YYjL102YXIl40:bTXP@0[ZNU0`2aZZP40;B]Z`@0^;6_102k];840;nh]P@0`[bi1036`;d3
0<[3`@@0c/O4103BblP40=O@c@@0elo<103Ec<T30<o7a@@0b<6o1037_kh40<Jn_@@0a;^i1030^;H3
0;be/`@0^[:`102g[jh40;F]Z`@0/JZX102_YjH40:ZTX`<0Z:>Q102VXJ040:BPWP@0Y9nN102RW9/4
0:FOWP<0XibK102LUI@409NAS`@0U8f<102BRhT40929Q`@0ShR60`2>QhD408f6Q0P0SHF4102=QH<4
08f6Q0<0SXJ4102?Qh@408n7Q@@0T8R6102ARHH409::Q`<0Th^8102ES8T409J=RP@0Uhj;5P3oool0
01@0oooo102KTHh409fCT@@0WiJD0`2QVIH40:BKV@@0YYjL102YXIl40:bTXP@0[ZNU0`2aZZP40;B]
Z`@0^;6_102k];840;nh]P@0`[bi1036`;d30<[3`@@0c/O4103BblP40=O@c@@0elo<103Ec<T30<o7
a@@0b<6o1037_kh40<Jn_@@0a;^i1030^;H30;be/`@0^[:`102g[jh40;F]Z`@0/JZX102_YjH40:ZT
X`<0Z:>Q102VXJ040:BPWP@0Y9nN102RW9/40:FOWP<0XibK102LUI@409NAS`@0U8f<102BRhT40929
Q`@0ShR60`2>QhD408f6Q0P0SHF4102=QH<408f6Q0<0SXJ4102?Qh@408n7Q@@0T8R6102ARHH409::
Q`<0Th^8102ES8T409J=RP@0Uhj;5P3oool001@0oooo102JTHh409^BS`@0WIBA0`2NUI<40:2GU@@0
XYVG102SViP40:FMVP@0YinM0`2YXIl40:^SX@@0[JFS102`Z:D40;:ZZ0@0]:fZ102g[jd30;Zb[`@0
_;Bb102o]k@40<6i]P@0`[Vf1032^[H30<Fl^0@0`KVf202n][<40;fe/`@0_KFb0`2j/K040;B]Z`@0
/ZZY102`Z:H40:fVY0@0[:FS102ZXj430:NQW`@0YYnM102TWY`40:VRX0@0Y9jK102QVYP309jGU@@0
ViBB102HTHl409J>S0@0U8f;102CRhT409::R0<0THZ8202ARHL80969QPL0THV7102BRHL409::Q`@0
ThZ8102DRhP409B;R@<0UHb9102FSHX409N=R`@0V8j;5P3oool001@0oooo102JTHh409^BS`@0WIBA
0`2NUI<40:2GU@@0XYVG102SViP40:FMVP@0YinM0`2YXIl40:^SX@@0[JFS102`Z:D40;:ZZ0@0]:fZ
102g[jd30;Zb[`@0_;Bb102o]k@40<6i]P@0`[Vf1032^[H30<Fl^0@0`KVf202n][<40;fe/`@0_KFb
0`2j/K040;B]Z`@0/ZZY102`Z:H40:fVY0@0[:FS102ZXj430:NQW`@0YYnM102TWY`40:VRX0@0Y9jK
102QVYP309jGU@@0ViBB102HTHl409J>S0@0U8f;102CRhT409::R0<0THZ8202ARHL80969QPL0THV7
102BRHL409::Q`@0ThZ8102DRhP409B;R@<0UHb9102FSHX409N=R`@0V8j;5P3oool001@0oooo102J
THh409^BS`@0WIBA0`2NUI<40:2GU@@0XYVG102SViP40:FMVP@0YinM0`2YXIl40:^SX@@0[JFS102`
Z:D40;:ZZ0@0]:fZ102g[jd30;Zb[`@0_;Bb102o]k@40<6i]P@0`[Vf1032^[H30<Fl^0@0`KVf202n
][<40;fe/`@0_KFb0`2j/K040;B]Z`@0/ZZY102`Z:H40:fVY0@0[:FS102ZXj430:NQW`@0YYnM102T
WY`40:VRX0@0Y9jK102QVYP309jGU@@0ViBB102HTHl409J>S0@0U8f;102CRhT409::R0<0THZ8202A
RHL80969QPL0THV7102BRHL409::Q`@0ThZ8102DRhP409B;R@<0UHb9102FSHX409N=R`@0V8j;5P3o
ool001@0oooo102JTHh409^BS`@0WIBA0`2NUI<40:2GU@@0XYVG102SViP40:FMVP@0YinM0`2YXIl4
0:^SX@@0[JFS102`Z:D40;:ZZ0@0]:fZ102g[jd30;Zb[`@0_;Bb102o]k@40<6i]P@0`[Vf1032^[H3
0<Fl^0@0`KVf202n][<40;fe/`@0_KFb0`2j/K040;B]Z`@0/ZZY102`Z:H40:fVY0@0[:FS102ZXj43
0:NQW`@0YYnM102TWY`40:VRX0@0Y9jK102QVYP309jGU@@0ViBB102HTHl409J>S0@0U8f;102CRhT4
09::R0<0THZ8202ARHL80969QPL0THV7102BRHL409::Q`@0ThZ8102DRhP409B;R@<0UHb9102FSHX4
09N=R`@0V8j;5P3oool001@0oooo102IT8d409Z@SP@0Vi6?0`2KTXl409bCT0@0WIBA102NUI8409nF
T`@0X9ND0`2QV9D40::IUP@0XiZH102TViT40:FMVP@0YYjK102XWi`30:VPWP@0ZZ:O102[Xj040:bT
X@@0[JBQ102]YJ430:jUX@@0[JBQ102/Xj040:bTX0@0[:>P102]YJ430:nVXP@0[ZFQ102]Y:840:bS
X@@0Zj:O102ZXIl40:VQW`<0ZJ6N102WWi`40:6IU`@0X9RE102NUY@409fDTP<0Vi>A102JTHl409R@
SP@0Uhn<102FSX/409J=R`@0UHf:1`2ES8XC09F<R@P0UHb:302FSHX309N=R`@0Uhj;102HSX/409R>
S1H0oooo000D0?ooo`@0VI2=102JT8h409^AS`<0Vi:?102LTi0409fDT@@0WYFB102OUY<40:2GU0<0
XIRE102RVIH40:>JV0@0Y9^I102UWIX40:JNV`@0Z9nL0`2YX9h40:ZRW`@0Zj>P102/Y:440:fTX@@0
[JFQ0`2^YJ440:fTX@@0[:>P102/Y:040:bSX0@0[JFQ0`2_YZ840:jUX@@0[JBR102/Xj440:^RW`@0
ZZ6O102YXIl30:VQWP@0YinL102QVIL40:2HU@@0WYJD102MU98309^CT@@0VY6?102HT8h409N?S0@0
UXj;102FSH/409F=RPL0UHb:4`2ES8T809F<RP`0UXf:0`2GSH/409N>R`@0V8j;102HSX`F0?ooo`00
503oool409V@S@@0VY2>102KTHl309^BS`@0W9>@102MU94409jETP@0WiJC102PUi@30:6HU@@0XYVF
102SVYP40:BKV@@0YIfJ102VWY/40:ROW0<0ZJ2N102ZXYl40:^SX0@0[:BQ102]Y:440:fUX@<0[ZFQ
102]Y:440:bSX0@0[:BP102/Xj040:fUX@<0[jJR102^YJ440:fTXP@0[:>Q102[XYl40:ZQW`@0ZJ6O
0`2YXIh40:NOW0@0XIVG102PV9D409jFU0@0WIBB0`2KTi4409ZAS`@0V92>102GSh`409J>R`@0UXf;
102ESHX709F<RQ<0UHb9202ES8X<09J=RP<0Uhf;102GSX/409R>R`@0V8j<5P3oool001@0oooo102I
T8d409Z@SP@0Vi6?0`2KTXl409bCT0@0WIBA102NUI8409nFT`@0X9ND0`2QV9D40::IUP@0XiZH102T
ViT40:FMVP@0YYjK102XWi`30:VPWP@0ZZ:O102[Xj040:bTX@@0[JBQ102]YJ430:jUX@@0[JBQ102/
Xj040:bTX0@0[:>P102]YJ430:nVXP@0[ZFQ102]Y:840:bSX@@0Zj:O102ZXIl40:VQW`<0ZJ6N102W
Wi`40:6IU`@0X9RE102NUY@409fDTP<0Vi>A102JTHl409R@SP@0Uhn<102FSX/409J=R`@0UHf:1`2E
S8XC09F<R@P0UHb:302FSHX309N=R`@0Uhj;102HSX/409R>S1H0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002K0?oo
o`900000P`3oool009d0oooo00=000000?ooo`3oool0P03oool007L0oooo1D0000020?ooo`03@000
003oool0oooo0080oooo00=000000?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=00000
1@3oool00d000000oooo0?ooo`1j0?ooo`00N@3oool01d000000oooo0?ooo`3ooom000000?oood00
00000P3oool00d000000oooo@000000;0?ooo`06@000003oool0oooo@000003ooom00000103oool0
14000000oooo0?oood0000220?ooo`00N@3oool01d000000oooo0?ooo`3ooom000000?oood000000
0P3oool00d000000oooo@000000;0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04
@000003oool0oooo@0000880oooo001i0?ooo`03@000003oool0oooo0080oooo00M000000?ooo`3o
ool0oooo@000003ooom0000000`0oooo0d000000103ooom00000@000040000030?ooo`=00000PP3o
ool007T0oooo00M000000?ooo`3oool0oooo@000003ooom000000080oooo00=000000?oood000000
3P3oool00d000000oooo0?ooo`2:0?ooo`00N03oool2@00000@0oooo00=000000?ooo`3oool00P3o
ool00d000000oooo0?ooo`0<0?ooo`900000S03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(225) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
8D8A898D8B898D8B898D8B898E8B8A8E8B8A8E8B8A8E8C8A8E8C8B8E8C8B8E8C8B8E8D8B8E8D8C\
8E8D8C8E8D8C8E8D8D8E8E8D8E8E8D8E8E8D8E8E8E8E8F8E8E8F8F8E90908F9293
8E8F8F8E8E8E8E8E8D8E8E8D8F8D8C8F8E8D8F8E8D8F8E8D8F8F8D908E8D908F8D908E8D908E8C\
908D8B908C8A8F8B898E8A878E89868D88858D87858D85838B84818A827F89807C
877C7889817D8A83808B84828B85838B86848C86848C87858C87858C88868C88868C88868D8987\
8D89878D89888D8A88
8D8B898D8B8A8E8B8A8E8C8A8E8C8B8E8C8B8E8D8C8E8D8C8F8E8D8F8E8D8F8F8E8F8F8E8F8F8F\
8F90908F90908F91918F91918F92928F92928F93938F93948F94958F95978F979A
8F94968F93938F92918F929190919090919191929192929192929192929193929193919092908F\
928E8C918D8B908B888F89868E87848D85828C83808B817D897E79877A76857771
83746E867975877D78887F7B89817D8A827F8A83808A84818B84828B85838B86848C87848C8785\
8C88868D89878D8988
8D8B898E8C8A8E8C8B8E8C8B8E8D8C8F8E8D8F8E8E8F8F8F8F8F8F909090909190909191909292\
90939390939491949591949591959691969791979890979A90999B909A9D909CA0
8F999B909798909596909595919595929595939595949695939695949695959594949392949290\
93908E938E8C918B889088858E85828D837F8B7F7C8A7C7787787385736D816E66
81706983746E857772867A75877C78887E7A897F7C89807D8A827E8A83808B84818B85838B8684\
8C87858C88868D8987
8D8B8A8E8C8B8E8D8C8F8D8C8F8E8D8F8F8E90908F909191909191909293919393919494919595\
91969792979892979992989A92999B929A9C929B9D929C9F919DA0919EA291A0A5
909C9F909A9C91999A919899929898939898949898959898959998959998969797969594959391\
94918F948F8C938B889187848F84808D807C8A7C7788777285736C826D667E675E
806B64826F6883736D857670867873867A76877C78887D79887F7B89817D8A827F8A83818B8582\
8B86848C87858D8987
8E8B8A8E8C8B8E8D8C8F8E8D8F8F8F909090909191919292919394919495929596929697929899\
93999A939A9B939B9D939C9E939D9F939EA1939FA293A0A492A0A592A1A791A3A9
919FA3919DA0929C9D929B9C939A9B949A9B959A9A969A9A969B9B969B9A979A99979796969592\
969290958F8C948C889287838F827E8D7E7989797486736D846E678068607D6359
7F675F806B64826F6883726B84746E857771867974877B76877D78887E7B89807D8A827F8A8481\
8B85838C87858C8887
8E8B8A8E8D8C8F8E8D8F8F8E90909090919191939391949492959692969793989993999A939A9C\
949B9E949D9F949EA1959FA295A0A495A2A695A3A794A4A893A4AA92A5AA91A5AB
91A2A691A0A3929EA0939D9F949D9E959C9D959C9C969C9C979C9C989C9C989B9A989998979694\
979391968F8C958C8893868290807C8D7C76897671867069826A617E63597C6056
7E645B7F685F806B63826E6783716A84736D857670857873867A75877C78887E7B89807D8A827F\
8B84818B86848C8886
8E8C8A8E8D8C8F8E8E90908F90919191939391949592969693979893999A949A9C949B9D959D9F\
959EA195A0A396A1A596A3A796A4A896A6AA96A7AC96A8AE95A8AF92A8AF90A5AC
91A3A892A2A593A1A393A0A1949FA0959F9F969E9F979E9E989E9D989E9D999C9B999A99989795\
989491978F8C958B8793858290807B8D797489746D856D6581665D7C5E537C5E54
7D61587E655C7F685F806B63816E6682706A83736D847670857873867A76877D78887F7B89817E\
8A83808B85838C8886
8E8C8A8F8D8D8F8F8E90919091929291949492969693979893999A949B9C959C9E959EA096A0A3\
96A1A597A3A797A5A998A6AB98A8AD98AAAF99ABB199ADB399AEB58FA7AF8EA4AB
90A4A992A3A793A2A594A2A395A1A296A1A297A0A198A0A099A0A0999F9F9A9D9D9A9B9A999896\
989491978F8C968A87938581907E798D787288716A836A628063597B5A4F7B5C51
7C5F547D62587E655C7F685F806A63816D6682706A83736D847570857873867B76877E7A89807C\
8A827F8B85828C8785
8E8C8B8F8E8D90908F90919191939392959693979893999A949B9D959D9F969FA196A0A397A2A6\
98A4A898A6AA99A8AD99AAAF9AACB19AAEB49BB0B69CB2B99BB3BB89A3AC8EA5AC
90A5AA92A5A994A4A795A4A696A3A497A3A498A3A399A3A29AA2A29AA1A09B9E9E9B9B9A9A9896\
999391988E8B96898693847F907D788C7770886F6883685F7F60567A584C7A594E
7B5C517C5F547D61587E645B7F675F806A63816D6682706A83736D847671857974877C78887F7B\
89817E8B84828C8785
8E8C8B8F8E8E90919091929292949593969793989A949B9C959D9F969FA197A1A497A3A698A5A9\
99A7AC9AA9AE9AABB19BADB39BB0B69CB2B99CB4BB9FB7BF94AFB78BA5AD8FA7AD
91A7AC93A7AB94A6A996A6A897A5A698A5A599A5A59AA5A59BA5A59CA4A29CA09F9C9C9B9A9795\
999290988D8B96888592827E8F7B768B756F876E6683665D7E5F547A564A7A564A
7A594D7B5B517C5E547D61587D645B7E675F806B63816E6782716B83746E857772867A76877D7A\
89817D8A84818C8785
8E8C8B8F8F8E909191919393929596939899949A9B959C9E969FA197A1A498A3A799A5A999A8AC\
9AAAAF9BACB29CAFB59CB1B79DB3BA9EB6BD9FB9C198B3BC8FABB48FAAB291AAAF
93A9AE94A9AD96A9AC97A8A998A7A899A7A79AA7A79BA8A79CA8A79DA5A49DA1A09D9C9B9B9795\
9A918F988C8A96878392817C8E7A758A736C866C6583665D7E5F547B574B785346
7955497A584C7A5B507B5E547C61587D645C7E68607F6B64816F6882726C847570857974877C78\
88807C8A83808C8784
8E8D8C8F8F8F90929292949493969794999A959B9D969EA097A0A398A3A699A5A99AA8AC9BABAF\
9CADB29DB0B69DB2B99EB4BC9EB7BF9FB9C29CB9C291AFB891AEB792ADB493ACB2
94ACB196ACB097ABAE98A9AB99A9A999A8A89AA9A99CA9A89DAAA99EA6A59EA2A19D9D9B9D9897\
9B918F998C89958582917F7B8D787388716B856B6382655C7E5F547C584C785245
77514478544879574C7A5B507B5E547C61587D655C7E6861806C6581706A83746E847873867B77\
887F7B8A83808B8684
8E8D8C90908F919292929595939899949A9C959D9F97A0A298A2A599A5A99AA8AC9BABAF9CADB3\
9DB0B69EB3B99FB5BDA0B8C0A0BAC3A1BDC792B2BC91B0BA92AFB893AFB695AFB4
96AFB498AFB399ADB099ABAC99AAAA9AAAAA9AAAA99CA9A89EA8A79FA6A69EA1A09E9E9C9F9B99\
9C93919A8C8A958482907D7A8C7772877069846A6281645B7F5F547C584D795347
764E4077514478544878574C795B507A5E557B62597D665E7E6A63806E6782726C837671857A75\
877E7A89827F8B8684
8E8D8C90909091939392969694999A959B9D969EA197A1A499A4A89AA7AB9BAAAF9CADB29EB0B6\
9FB3B9A0B6BDA1B9C0A2BCC4A2BFC89DBCC78EAFBA91B0B993B1B994B0B796B1B7
98B2B79BB2B69BB0B299ACAC9AABAB9CABAB97A6A59BA7A79DA5A49FA5A4A0A4A2A1A09EA19D9B\
9E96939C908D958683907C798A7571866E6883686081635B7F5F557D594E7A5448
774F41764D3F76504377544877574C785B51795F567B635B7D67607F6C6581706A83746F857974\
877D7989817E8B8683
8F8D8C909190919494939697949A9B969D9F97A0A298A3A69AA6AA9BA9AE9CACB19EB0B59FB3B9\
A1B6BDA2B9C1A3BCC4A3BFC8A5C3CC93B4C08FB0BB91B1BA94B2BA95B1B798B3B9
9AB5BA9DB5B99DB2B49CAEAE98A7A79AA7A897A3A39BA5A59DA5A49FA4A4A1A6A5A2A09EA29D9B\
A19996A09592978A868E7D7988736F846D6781665F80625A7F5F557E5B4F7B5649
795042764C3D754D4074504375534876574D775C527960587B655D7D69627F6E6882736D847773\
867C7888817E8B8583
8F8E8D909191929495939798959B9C969EA098A1A499A5A89AA8AC9CABB09DAFB49FB2B8A1B6BC\
A2B9C1A4BDC5A5C0C9A5C2CBA4C3CD8CAFBC8FB0BB91B1BB94B2BA96B2B899B4BA
9CB7BC9FB7BA9EB4B59EB0AF94A2A397A3A499A4A49BA4A39EA6A6A0A6A5A2A6A5A2A09EA29E9C\
A29996A197939B8D8891827E877470826B6580645E7F6159805F567F5C507C574A
7A5143784C3D754C3E724C3F714F4373534975584F775D5479625A7C67607E6C6681716C837671\
867B7788807D8B8583
8F8E8D919191929595949899959C9E979FA298A3A69AA6AA9BAAAE9DADB29EB1B7A0B4BBA2B8C0\
A4BCC4A7C1CAABC6CFA4C3CC99BAC68BAEBA8FB0BB92B2BB95B2BA97B3B99AB5BB
9DB8BD9EB5B89DB1B39CADAE96A6A698A5A69BA6A69CA5A59FA8A7A1A7A6A3A7A5A2A29FA29E9B\
A19794A096929C8E889786818B79748069647E635D7F6158806056805D517E584B
7B5244794D3E754A3B714A3B6E4A3E704F4573554B755A517860577A655E7D6A6480706A827570\
857A7688807C8A8582
8F8E8D91929293969694999B969D9F98A1A399A4A79BA8AC9CABB09EAFB59FB3B9A1B7BEA3BBC2\
A5BFC7AAC5CEAFCBD5A1C0CB8DB1BD8DAFBB90B1BB93B3BB95B2BA97B3BA9AB5BB
9DB7BC9DB3B79AACAE9AAAAC99A9A99BA8A89CA7A89EA8A8A0A9A9A2A9A8A3A7A5A3A3A1A39E9B\
A198959E95909C8E88978680907C76826B667E625C7F6158816157815E527F594C
7C54467A4F40784C3C6C44366B463A6D4B4070524773574E765D5579635B7C69627E6E6881746F\
847975877F7C8A8582
8F8E8D919292939697959A9C979EA098A2A59AA6A99CAAAE9DADB39FB1B7A0B5BCA1B8C0A3BCC5\
A5C1CAA9C6CFAAC8D39DBEC990B2BE91B2BD92B2BC94B2BA96B2BA98B2BA9AB5BB
9DB6BB9DB3B799ABAD99A9AB9AA9AA9BA9A99DA8A99FA9A9A1AAAAA3AAA9A4A7A6A4A4A2A39F9C\
A19A969D958F9A8D8896857F8F7C7587706980655F806259816157825F53805A4E
7D55477C51427C4E3E673F316842366A483C6E4E4471554B745B527761597A67607D6D6781736E\
847974877E7B8A8482
8F8E8E919393949798969B9D979FA299A3A79BA7AB9DABB09EAFB59FB3B9A1B7BEA2BAC2A3BEC7\
A4C1CBA5C5CFA2C2CE9DBDC896B6C193B3BD93B2BB95B2BA96B2BA98B2B99AB4BA
9CB5BB9CB3B79AADB099A8AA9AA8A99CA9A99EA9AAA0AAAAA2ABABA4ABAAA5A8A7A5A4A2A4A09C\
A29A969D938F998C8694847D8E7B7489726B83696282655B826359836054815B4F
7F56487E52437D4F3E653D2F643F326845396B4B416F524872584F765F5779655E7C6B6580716C\
837873867E7A8A8481
8F8F8E929393949899969C9E98A1A39AA5A89CA9AD9EADB29FB1B7A0B5BCA1B9C0A2BCC5A3BFC9\
A3C2CDA2C3D0A0C0CC9CBBC698B6C094B3BD94B1BA95B1B996B1B998B2B99AB3BA
9BB5BA9CB3B79CAFB29AA9AB9AA7A89CA8A99FAAABA1AAAAA3ABABA5ACABA6A9A8A6A5A3A49F9C\
A19A969C928E978B8592827D8E7B7489736B856B6284685E84655A846155825C4F
8057497F5444805140633C2D613C2F65423669483D6C4F4570564D745D5578635C7B6A647F706B\
827772867D7A8A8481
908F8E929494959999979D9F99A2A49BA7AA9DABAF9FAFB4A0B3B9A2B7BEA2BBC3A3BEC7A3C1CC\
A3C4D0A1C3CE9FC0CB9BBAC497B4BD94B2BB94AFB895AFB897B1B898B2B899B3B9
9BB4B99CB2B79CB0B39BABAD9BA7A89DA8A99FABABA1AAABA3ABABA6ADACA7AAA8A6A6A3A49F9C\
A19A969C918D97898491817B8D7B738A736C876D64866A6085665C846256825D50
80584A7F5445815342673F305D382A623E3266453A6A4D426F544B735B5376625A7A69627E6F6A\
827672867D79898381
908F8E939494959A9A989FA09BA3A69DA8AC9FADB1A1B1B7A2B6BCA3BAC1A4BDC6A4C1CAA4C4CE\
A3C6D2A1C2CE9FBFCA99B6C095B2BB94B0B994AEB795AFB796B0B798B1B899B2B8
9AB2B89BB1B79DB0B49BACAE9BA7A99DA8A99FAAABA2ABABA4ACACA7ADACA8ABA9A6A5A3A49F9C\
A099959B918C96898390807A8C7A728A746C897067886C6286685D846357825E51
7F584B7D54457D51426E443560382A5D382C644237694A406D52487159517560597967617D6E69\
817571857C79898381
90908F939595969B9B99A0A29CA5A89EAAAEA1AFB4A2B4B9A4B8BFA5BCC4A6C0C9A6C4CEA5C7D2\
A4C7D3A1C2CE9DBAC696B1BB93AFB993AEB794AEB695AEB696AFB698B0B799B1B7
9AB1B79BB0B69CAFB39BABAE9BA8AA9DA9AAA0ABABA2ABABA5ADACA8ADACA9ABA9A7A5A2A49F9B\
9F98949B908B958882907F798C7A728B756D8A7269896E6386695E846458815E51
7D584B7A5244774E406F4536643A2B5D382B63413568493E6C504670574F745F5778665F7C6D68\
807470857C78898380
91908F949696979C9C9BA1A39EA7AAA0ACB0A3B1B6A5B6BCA6BBC2A7BFC7A8C4CDA8C7D1A7CAD6\
A5C8D4A1C1CC9AB5C093AEB891ADB792ADB693ADB695AEB696AFB697B0B799B0B7
9AB0B69BAFB59AADB19BAAAD9BA8AA9DA9AAA0ABABA2ABABA5AEADA9ADACA9ABA9A7A5A2A49E9B\
9F96939A8F8A948780907F798D7A738B766E8B736A896F65866A5F836458805E52
7C584B775143734D3E6C4334633829623B2D64403467473C6B4E456F564D735D5677655E7B6C67\
80746F847B78898380
919090959797999D9E9CA3A59FA9ABA2AEB2A5B4B9A7B9BFA9BEC5AAC3CBABC7D1ABCBD6A9CCD7\
A6C8D39FBEC996B1BC90ABB68FABB491ABB492ADB594AEB696AFB698B0B798B0B6
99B0B59AAEB399ABB09AA8AC9AA7A99CA8A99FAAAAA2ABABA6AEADAAAEADAAABA8A8A5A2A49E9A\
9F9691998E899486809080798E7B748D786F8B746B8A7065866B608365597F5E52
7B574B755042714C3E6A423363392961392C633F3266453A694D436D544B715C5476635D7A6B66\
7F736E847B77888280
9191909697979A9E9F9EA4A6A1ABADA5B1B5A8B7BBAABCC2ACC2C9AEC7CFAFCBD5B0D0DBADCED8\
A7C6D19BB9C58FACB88CA8B38DA9B28FAAB391ACB594AEB696AFB698B0B799B0B6
99AFB499ACB198A9AE98A7AA98A5A89BA6A89EA8A9A2ABABA7AEADAAAEADABABA8A8A5A2A49D99\
9F9590998E8895878192817A8F7D758E78708B756B897066866B608365597F5F52
7A584B745143704C3F694132633A2B5E3527613C2F644338674B416B524A705A5274625B796A64\
7E726D837A7688827F
9291909798989B9FA0A0A6A8A4ADB0A8B4B7ABBABEAEC0C5B0C5CCB2CBD3B3D0D9B5D5E1B4D1DB\
A7C4CE97B5C187A6B387A4B08AA6B18DA8B290ABB494ADB597AFB699B0B799B0B6
99AFB498ACB196A7AC95A4A896A3A699A4A59DA7A7A2AAAAA7AEADABAEADACABA8A9A5A2A59E99\
9F95909B8E8896898293827B907E758E79708B746B897066866B608265597E5F53
79584B7451456F4D40674132603A2B5B31235E392C61413565483F6950486E585173615A786963\
7D716D82797688827F
9292919899999DA1A2A2A8AAA7B0B2ABB7BAAFBDC2B2C4C9B5C9D0B6CFD7B8D4DDB9D8E2B8D2DC\
A8C3CD95B2BE80A1AF82A1AD86A4AF8AA6B18FAAB394AEB698B0B79BB2B89BB1B6
99AFB496ABB094A5AB93A2A694A0A396A1A29BA4A5A1A9A9A7ADACACAFADADACA9AAA5A2A79E99\
A196919D8F89998A8394847C917E768F7A718B746B887065856B608265597E6053
79594C745346704E406542345C3628572E1F5B36295E3E3363463C674E466C574F715F59766862\
7C706C82797587817F
939291999A9A9FA2A3A4AAACAAB2B5AFBABDB4C1C5B7C8CDBACED4BBD3DBBCD7E1BCD8E1BCD4DC\
A8C1CB90AEBA799CAB7D9DAB82A1AD87A4AE8DA9B294AEB599B1B89DB3B89EB2B7
9BAFB494A9AF8FA3A890A1A5919EA1929B9D99A1A2A1A7A7A8ADACADAFADAEACAAACA7A3A9A09A\
A39791A0918B9C8C8497867E927F778F7A7189736A876F65856B6082665A7E6053
795A4C745447704F41634134573326532A1C5733275B3B3060443A644C446A554E6F5E57756661\
7B6F6B81787587817F
9493929A9B9BA1A4A5A7ACAEADB5B7B3BEC1B9C6CABECDD2C1D4DAC1D8DFBFDAE3BED7DFBED2DA\
A6BFC98BABB77397A7799AA87F9FAA84A2AD8BA7B092ACB399B1B79CB2B7A2B4B8
9DB0B493A8AE8EA1A68C9FA48D9B9E90999B989FA0A0A6A6A8ADACAEB0AEB0AEABAFA8A4ADA49D\
A49791A3948DA08F869A8880927F778E797188736A866E64846A5F83665A7E6053
795A4D7655476F4E405F3F325231244E271A53302557392E5C4138614A4267534C6D5C56736560\
7A6E6A80787487817E
9493929C9C9CA3A6A6AAAFB0B1B8BAB8C2C4BFCBCEC5D4D8CADBE1CBE1E7BED8E0BCD3DBB9CED6\
A5BDC688A8B56E93A37597A57B9CA882A0AB88A4AD8EA8B095ADB499AFB59FB2B7
9BAEB395A8AE8FA1A68B9DA28C9A9E919A9D989FA0A1A6A6A8ADACAFB0AEB2AFACB1AAA5B0A59F\
A99A93A99890A7938A9A8880937F778F7A72877269846E6482695E8265597F6154
7B5C4E7857496F4E405B3D304C2D214925194F2E2253362C583F365E484064514A6B5A5471645F\
786D697F777486807E
9594939D9D9DA5A7A8ADB1B2B5BBBDBDC6C8C6D0D3CEDBDFD8E7EBD3E6ECC1D7DFB9CED7B4C8D0\
9EB7C283A4B26A90A07195A37899A5809FAA86A1AB8BA4AC91A9B096ADB399AEB3
98ACB194A7AD90A2A78D9DA18E9B9E939C9E99A0A0A1A7A6A9ADACAFB0AEB2AFACB2AAA5B0A59E\
AD9D95AD9B92AD988E9B8981968179917C7386726A846D6482695E836659816254
7E5E507C5A4A6D4D3F583B2F462A1F442216492A204E3329543C335A453E614F486858536F625E\
776C687E767386807E
9694939E9E9EA7A9A9B0B3B4B9BEC0C2C9CBCCD5D8D7E2E5E4F1F5D6E6EBC8DBE1B9CDD5AEC3CC\
96B2BE7EA0AE678E9E6D92A07596A27D9CA6849FA989A3AB8EA5AD93A9AF95ABB0
95A9AF92A5AB8FA1A78E9DA28E9B9E949D9F9AA1A2A2A7A7A9ADACB0AFADB3AFACB3ABA6B0A59E\
AD9E96AD9B92AC978DA08D8499857C937D7489746B876F65866B5F85685B856456
826052805C4D6B4B3E54392E42291F3E1D1243261C492F264F383156423B5D4C466556516D615C\
756B677D757285807D
9695949F9F9FA9AAAAB2B5B6BCC1C2C6CDCED1D9DBDDE7EAEBF6F9DDE9EECCDCE2BBCED6A9C1C9\
91AFBA7A9DAB658C9D6A8E9D72939F7997A2819DA687A1A98CA4AB91A6AC91A6AD
93A7AD91A3A990A1A68E9EA28F9B9F959FA19CA4A4A3A9A8AAACABB0AEACB3B0ABB5ACA8B2A59F\
AD9E97AB9A91A7948BA18E849D877E967F758F776D8C73688A6E61896A5D886658
886354825D4D694A3D4D362C422A20391B113D2219422B2349352E513F395A4A446254506B5F5B\
736A667C7572847F7D
979594A1A0A0AAACACB5B7B7BFC3C4CACFD1D5DCDEE2EAECEFF9FBE2EDF1D0DEE3BDCFD6A8C0C9\
90ADB9789BA9658C9C678B9A6E8F9B75939E7C98A1839CA589A0A78DA2A88DA2A9
90A3AA90A2A891A2A790A0A4939FA397A2A39EA6A7A3AAA9A9ACAAAFADAAB2AEA9B6ADA8B5A8A2\
B0A099AC9B92A5938BA18D849E877E998177947B7091766A8E71648C6C5F8C695B
8D6757815C4D66483C4A352B422B21381C12321A123B251E43312A4C3C365647425F524E685E5A\
7169657B7471847F7D
979694A2A1A0ACADADB7B8B9C1C5C5CDD1D2D9DFE0E5ECEEF3FAFDE6EFF2D4E0E5BFD0D7AAC0C9\
90ADB9799BA9668D9C6589986B8B9872909A79939D7F98A0849BA2889EA48BA0A6
8EA1A78FA1A791A2A893A2A796A3A79AA4A69FA8A8A4AAA9A9ABA9ADACA8B0ACA7B4ABA5B6A9A2\
B4A39CB19E95A9968DA48E859E887F9B8278977D7293786B9072658F6F61916C5D
9269597F5A4B65483B4D372D3F2920351C1327130C32201A3D2C274739335245405C504C665C59\
7068657A7371837F7D
989695A2A2A1ADAEADB8BABAC4C6C7CFD3D4DBE0E1E8EEEFF5FCFDE7F0F3D8E3E7C1D2D9ACC1CA\
93AFBA7B9DAA688E9D6488966889956F8D977590997B949C81979E859AA1899DA3
8C9FA58FA1A692A3A894A4A898A5A99BA7A9A0A8A9A4ABAAA8ABA9ABAAA7AFAAA5B1A9A3B4A7A0\
B3A39CB29F97AE9990A89288A28B819E8479997E7397796C937566957163956E5F
936A5A7D594B66483C4F382E3B281F2D19121F0F092B1C163728234235314E423E594F4B635B57\
6E6764797370837E7C
989695A3A2A1AEAEAEBABBBBC5C7C7D1D4D5DDE1E2EAEFF0F7FDFEE9F1F3DAE4E8C5D5DAAEC4CC\
97B1BB80A0AD6D919F6388966586936C8A94738D967991987E949B83989E889BA1
8B9EA48FA0A692A3A895A4A999A6AA9CA8AAA0A9AAA4ABAAA7AAA8AAA9A6ADA8A4B0A7A1B2A59E\
B2A29AB19E95AE998FAA9389A68D83A1877B9D81749B7C6E99786A997466987161
9169597B584A64473B4F372E39271F2717121A0D082316123024203D322F4A403C564D4A615A57\
6D6663787270827E7C
989695A4A2A2AFAFAEBBBBBBC7C8C8D3D5D5DFE2E3ECF0F1F9FEFFEBF1F3DCE5E9C8D7DCB3C7CE\
9CB5BE86A4B07294A2658997638491698792718B94778E967D929982969D879AA0
8B9DA28EA0A692A3A896A5A999A7AB9DA8AAA1AAABA4AAA9A7A9A7A9A8A5ACA7A2AEA5A0B0A39D\
B0A099AF9C94AD988EAB9389A88E83A5897DA28477A07F719E7B6C9E77689B7262
8E675777564862463A4D362D37261F221611150C081A100D2B211E39302D473E3B544C49605956\
6B6563777270827E7C
999695A4A3A2B0AFAEBCBCBBC8C9C8D4D6D6E1E3E3EDF1F1FBFEFFECF2F3DDE6E9CBD9DEB8CAD1\
A2B9C28CA8B37798A5698C9A6284916885906F8992768D957C909781949B86999E
8A9CA18EA0A592A3A796A5A99AA7AB9EA9ABA1AAAAA4AAA9A6A9A6A8A7A4ABA6A1ADA49EAEA29B\
AF9F97AE9B93AD978EAB9389A98F83A88A7EA68679A38173A27D6EA179699A7161
8863547353465E433848332B32231D1E1411110A07150D0A271F1C362F2C453D3B524B485E5856\
6A656376716F827E7C
999695A4A3A2B0AFAEBCBCBBC8C9C8D5D6D6E2E3E4EFF1F1FCFFFFEEF3F4DEE7EACFDBDFBDCDD3\
A9BDC591ABB67D9CA86E909D6587946885906F8891758C947B909781939986979D
8A9CA18FA0A593A3A797A5A99AA7AA9EA9ABA1AAAAA3A9A8A5A8A5A7A6A2AAA4A0ABA39DADA099\
AE9E96AD9A92AD978DAC9388AB8F84A98B7FA88779A68374A57E6FA17969966E5E
835F516F50435840364230282D201A19120E0A0604140E0C251F1D352F2C433D3B514B495D5856\
6A656376716F817E7C
999695A5A3A2B0AFAEBCBCBBC9C9C8D6D6D6E3E4E4F0F1F1FDFFFFEFF3F4E0E8EAD2DCE0C2D0D6\
AEC0C898B0B984A1AC7393A06A8B976A86916F8891758C947C909681939986979C
8B9BA08F9FA493A3A797A5A99BA8AA9EA8AAA1A9A9A3A8A7A5A6A4A7A5A1A9A39EAAA19BAC9E98\
AD9C95AD9991AC968CAC9288AB8F83AB8C7FA98779A88375A57E6E9E7767906A5B
7D5B4E674B40523C333C2C25271C18130E0C05020016111025201F342F2D433E3C504B495D5856\
696563757270817E7C
999695A5A3A1B0AFAEBDBCBBC9C9C8D6D6D5E3E4E3F1F1F1FFFFFFF0F4F5E3E9EBD4DEE1C6D2D7\
B3C4CA9FB5BD8CA6B07A98A471909B6D8994708892768C947C909782949A87979D
8C9BA0909FA394A3A798A5A99BA7AA9EA8A9A1A9A8A2A7A6A4A5A2A5A3A0A7A19CA99F9AAB9D96\
AB9B93AC9890AC958BAC9287AC8E83AC8B7EAB877AA88374A37C6D997364886557
75564A60473C4B372F3528221F18140D0A0904020117131226222135312F433F3D504C4A5D5957\
696564757270817E7C
999695A4A2A1B0AFADBCBBBAC9C8C7D6D5D4E3E3E2F1F1F0FFFFFFF2F5F6E6EAEBD8DFE2CAD5D9\
B9C8CEA6B9C195ACB5849EA97996A1718D97728A93778D957D919883959A88989E
8D9CA0919FA395A3A699A5A89CA7A99EA7A8A0A7A7A2A5A4A3A3A0A4A19EA59F9AA79E98A99B95\
AA9991AA978EAB948AAB9186AC8E82AC8B7EAA8779A682739E796A916D5F7F5F52
6B504658423843332C2D231E17121005040309070719161628252436333144403F514D4C5D5A58\
6A6665767271817E7D
999694A4A2A0B0AEADBCBAB9C8C7C6D5D4D3E2E1E0F0EFEEFFFEFDF6F7F7E9ECEDDBE2E4CFD8DC\
BFCCD0AEBEC59DB1B98FA6AF829CA677929D758D97798F977F939984969B8A999E
8E9DA193A0A396A2A599A5A79DA7A89FA7A8A0A6A5A1A4A2A1A19EA29F9BA39D99A59C96A79993\
A89790A9948CAA9289AB9085AB8D81AB8A7DA98678A37E7097746688675A75594D
614A414F3C343B2E28241D1A0F0E0C0000000E0D0C1C1A1A2A2827383534454241524F4D5E5B5A\
6A6766767371827F7D
989694A4A1A0AFADACBBB9B8C7C5C4D3D2D1E1DFDEEEEDECFDFCFBF8F8F7ECEEEFE0E5E6D4DBDE\
C6D0D3B6C3C8A6B7BD99ACB48DA3AC829AA37C939C7D929A81959B86979D8C9B9F
909DA194A0A397A2A59AA4A69DA7A89FA7A79FA4A49FA2A09F9F9CA09C99A19B96A39994A59791\
A6958DA7938AA89087AA8E83A98B80A8877AA583759C796B8E6E617E61556C5349
58453C4637303128231B18160A0B0A0000011110101F1E1E2D2B2B3A383747454353514F5F5D5B\
6B6867777472827F7D
989594A3A19FAEACABBAB8B6C6C4C2D2D0CEDEDCDBECEAE8FAF8F7FBFAF9F1F1F1E5E8E8D8DDDF\
CCD4D7BDC8CCAEBBC1A2B2B997AAB18EA2AA859AA28499A085989F89999E8F9DA1
939EA196A1A398A2A59BA4A59FA6A7A0A6A69EA3A29C9F9E9C9C9A9D9A979E9894A09691A2958F\
A3938BA59088A68E85A78C81A6897EA384779E7D7093736684675C745B50624D44
4F3F383D312C27221F131312040606060607151515232222302F2F3D3B3B494746555352615E5D\
6C6968777473827F7E
989593A2A09EADABA9B8B6B4C4C1C0CFCDCBDBD9D7E8E6E4F5F2F0FEFBFAF5F4F3E9EAEADDE0E1\
D2D8DAC4CDD0B5C0C5ABB8BCA0AFB59AAAB092A3A98EA0A68C9EA38F9DA294A0A3
96A1A397A2A499A2A49CA3A4A0A6A5A0A5A49DA1A09A9D9C999A979A97949B96929E948F9F928D\
A09088A18D85A28B82A2897EA1857A9C7F7395766B896C617A61566A544B58463F
463934332B271F1C1B0E0F0F0003040D0E0F1B1B1B282727343333413F3E4C4A4958555463605F\
6D6B6978757483807E
979493A29F9DACA9A8B7B4B2C1BFBDCCCAC8D8D5D4E4E1DFF0EDEBFDF9F7FAF7F5EDECECE2E3E4\
D7DADCCBD1D3BBC5C8B1BCC0A9B5B9A3B0B49DABB098A7AB97A5A998A4A79BA4A6
9BA4A69BA3A59BA2A49DA3A3A0A4A49FA2A29C9F9F9A9B9A98989697949298938F9B918D9B8F8A\
9C8D869C89829D877F9C847B99807693786E8A70667D655C6F5A515F4E464E403A
3B332F292523191818090C0D0407081415162121212D2D2D3938384443424F4E4D5A5857656261\
6F6C6B79767583807F
979492A19E9CABA8A6B5B2B0BFBCBAC9C7C5D4D1CFDFDCDAEBE8E5F7F4F1FCF8F7F1EFEEE6E6E6\
DBDDDDD0D4D5C2C9CBB8C1C3B2BBBEACB6B9A6B1B4A2ADB1A0AAADA1A9ABA2A8A9
A1A7A89FA5A69FA4A59FA2A2A0A3A29FA1A09C9E9D9A9A9997969495929096908D978E8A978C87\
978A8496867F96837B947E769079708871697F6961725E5764534C554741433A36
312C2A212020141515070B0C0F11121B1D1D2728283333323E3D3D4847475351505D5B5A676563\
716E6D7A777684817F
969392A09D9BA9A6A4B2AFAEBCB9B7C6C3C1D0CDCBDAD7D5E5E2DFF0EDEAFBF6F4F6F2F0EAE8E7\
DFDFDFD4D6D7C9CDCEC1C6C8B9BFC1B5BCBEAEB6B8AAB2B4A9B0B1A8AEAEA7ABAB
A6AAA9A2A7A6A4A7A6A1A3A2A0A2A19FA09F9D9D9C9A999796959393918F938E8B948C88938984\
9286818F827C8F7E778B797286736C7E6B6473625B675852594D484A403D383331
2726251C1C1D0F11120F12131A1C1C2425262F2F2F3939394342424D4C4B565554605E5D696766\
72706F7B7977848180
9693919E9B9AA7A4A2B0ADABB9B6B4C2BFBDCCC8C6D5D2D0DFDCD9EAE6E3F4F0EDF8F4F2EDE9E8\
E3E1E0D9D9D8CFD0D0C7CACABFC3C4BCC0C1B6BBBCB1B6B7B1B4B4AEB0B0ACAEAD
AAACAAA6A8A7A6A7A6A3A4A3A2A2A09F9E9D9D9B9A999796959391928F8D918C8A918A868F8682\
8C827E897E79887A7583746E7C6D6873655F695D575D524D4F47433F3A382F2E2C
2122221517181315161B1D1E2425262D2E2E3636363F3F3F4848475150505A59586361606C6A68\
7472707C7A78858280
9592909D9A98A5A2A0ADAAA8B6B3B1BEBBB9C7C4C1D0CCCAD9D5D3E3DFDCEDE8E6F6F1EEF0EAE8\
E6E2E1DDDBDAD4D3D2CBCCCCC5C7C7C2C4C3BDBFBFB8BABAB6B7B6B1B2B1B0B0AE
ADADABAAAAA8A8A7A5A5A4A3A3A19F9F9D9C9B9A9898969493918F918E8C8E8A878D87848A8380\
877F7C857B778277727D716C7468646A605C605753534C4945413F373634282929
1A1C1D17191A1F20212627272D2E2E3536363E3E3D4645454E4D4D5655545E5D5C6664636E6C6B\
7674727E7B7A858381
9491909C9997A3A09EABA8A6B2AFADBAB7B5C2BFBCCAC7C4D2CFCCDBD7D4E4DFDDEDE8E5F0EAE8\
E9E4E2E0DCDBD8D5D3D0CECDC9C9C8C7C6C5C2C2C1BEBDBBBBB9B7B5B4B2B3B1AF
AFADABADABA8A9A7A4A6A3A1A2A09E9E9C9A9A9896979493928F8E8E8C8A8A87858A858286807E\
837D7A8279767E7471766D6A6D6561625B585752504B48463E3D3D313232242627
1A1C1C222323292A2A2F30303637373E3E3E4545444C4C4B5453525B5A596261606A6867716F6E\
7876747F7C7B868382
94918F9B9796A19E9CA8A5A3AFACAAB6B3B0BDB9B7C4C1BECCC8C5D3CFCCDBD6D4E2DDDAE9E4E1\
EBE5E2E4DEDBDBD7D5D2CFCDCCCAC8C9C6C4C6C3C1C1BEBCBEBBB8B9B6B3B4B1AF
B1AEABADAAA7A9A6A4A6A3A0A29F9D9E9B99999795959391908E8C8B898887848385817F827E7C\
817C7A7F787579716F716A686762605C5856504E4D464545393B3B2D3030242626
2526262C2D2D3333333939393F3F3F4646454C4C4B5352515A5858605F5E6765646D6B6A747170\
7A7876807E7C878482
93908E9996949F9C9AA5A2A0ABA8A6B2AEACB8B4B2BEBAB8C5C1BECBC7C5D2CDCBD8D3D0DED9D6\
E4DEDBE5DFDCDED8D5D5D1CECECAC8C9C5C3C6C2C0C3BFBCC0BBB7BBB6B3B5B1AE
B2ADAAADA9A6A9A6A2A6A29FA19E9C9C9A9798969493918F8F8D8B898786848280817F7D7E7C7B\
7F7B797C7675746F6E6E696765615F5856554C4C4C424343383A3B2D2F302C2D2D
3232333838383D3D3D4343424848484E4D4D5453525958585F5E5D6563636B6968716F6D767473\
7C7A78827F7E878583
928F8E9894939D9A98A29F9DA8A4A2ADAAA8B3AFADB8B4B2BEBAB8C3BFBDC9C4C2CEC9C7D3CECC\
D8D3D0DED8D5DED8D5D7D1CDCFCAC7C8C3C1C5C0BDC2BDBAC0BAB6BBB5B1B5B0AC
B1ACA9ADA8A5A9A5A1A6A19EA19D9A9C9996979492918F8E8E8C8B8886868281807E7E7D7C7B7A\
7D7A78797574726E6D6B6867615F5F5555554B4C4C404242393B3A3535363A3A3A
3E3E3E4342424747474C4C4B5150505655545B5A59605F5E6563636A68676F6D6C747271797776\
7E7C7A83807F888584
928F8D9693919B97969F9C9AA4A19FA9A5A3ADAAA8B2AEACB7B3B1BBB7B5C0BCB9C5C0BEC9C4C2\
CDC8C6D2CCC9D6D1CED6CFCCCFC9C5C7C2BEC1BCB9BFB9B6BDB7B4B8B3AFB2ADAA
AFAAA7ABA6A3A9A3A0A5A09DA09C999B9895969391908E8D8D8B8A8786868583827D7D7D7D7C7B\
7C7978767373706E6D6866665F5E5E5656564A4C4C424343414140434242464645
4A49494E4D4D5251505655545A59585E5D5C6261606765646B69686F6D6C7371707875747C7A78\
807E7C858280898684
918E8C9591909995939C9997A09D9BA4A19FA8A4A2ACA8A6B0ACAAB4B0ADB7B3B1BBB7B4BFBAB8\
C2BEBBC6C1BEC9C4C1CDC7C4CBC5C1C6C0BDBFBAB6BBB5B2B7B1AEB3AEABAFAAA7
ABA6A3A9A4A1A6A19DA29E9A9E9A989B9895969391908E8E8C8B898887878584847E7E7E7D7D7C\
7A7978757373706D6D6766665F5F5F5A59584C4D4D4B4B4A4E4D4D504F4F525251
5554545857575C5B5A5F5E5D6261606664636968676D6B6A716F6D7472717875747B79787F7C7B\
82807E8683828A8785
908D8B93908E9693919996949C99979F9C9AA39F9DA6A2A0A9A5A3ACA8A6AFABA9B2AEABB5B0AE\
B7B3B1BAB5B3BDB8B5BFB9B6C0BAB7C0BAB7BEB8B4B6B1ADB2ACA8ACA8A5AAA5A2
A7A2A0A6A19EA29E9A9F9B989C99979B9895969390928F8E8D8B8A8988888584848180807D7D7D\
7A7979767474706E6D6A69696362615D5C5B5756555958575B5A595C5B5B5F5D5D
615F5F6362616664636867666B69686E6C6B716F6E7371707674737977767C7A787F7C7B827F7E\
8582808785838A8786
8F8C8B928E8D94918F9693919995939B98969D9A98A09C9AA29E9CA4A19FA6A3A1A9A5A3ABA7A5\
ADA9A6AFAAA8B0ACA9B2ADAAB3AEABB3AEABB4AFABAFAAA7ACA6A3A8A4A1A39F9D
A19D9AA19D9A9F9B989D99979B9795989593959190928F8E8E8B8B8B89888685848382827F7F7F\
7B7A7A787775706F6E6E6D6C6A68686664646664646765646866656967666A6968
6C6A696E6C6B706E6D72706F7472707674727876747A78767C7A787E7C7A807E7C82807E858280\
8784828986848B8886
8F8B8A908D8B928E8D93908E9592909693919895939996949B98969C99979E9A999F9C9AA19D9B\
A29E9CA39F9DA4A09EA5A19FA6A29FA6A29FA6A19EA4A09DA39E9BA29E9B9C9997
9A97949B98969A97959B979499959395929093908F918E8D8E8B8A8C8989898786868484838180\
7C7B7A7C7B79777574767473767372747271747170747271747271757372767473
7775747876757A77767B78777C7A787E7B7A7F7C7B807E7C827F7E83807F858280868382878583\
8986848A87868C8987
8E8B898F8B8A8F8C8B908D8B918E8C928F8D928F8E93908E94918F959290969290969391979492\
989492989593999593999694999694999694999593999593989492979391959290
94918F95918F94908F95918F95918F928F8D908E8D8F8C8B8E8B898C8A888B8987898786878483\
82807E83817F82807F827F7E817F7D817E7D817E7D817E7D817E7D817F7D827F7E
82807E83807F83817F8481808582808583818683828784828785838885848986848A87858A8786\
8B88868C89878C8988
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool408f:R@/0SH^9302>
RhX408j<RP/0SXb;102>SH/<08j=S0@0SXf=2`2>SXd408j>SP@0SXn>102>Shl308j@T0@0Si:C102>
Shl408j>SPP0SXj=0`2?SH`<08n>S@@0Shn=102@SXd4092?S@<0T8j=102@SX`4092=R`@0T8b:102?
RhT408j:Q`<0SXV6102=R8D408f7Q@@0SHF3102;Q84408Z2O`@0RH1l0`27O7P408V1O@@0RX>0102;
Q88408^5P`@0RhJ40`2<QX@808b7Q@`0S8R61`2=RHL408f9R0@0SHZ85P3oool001@0oooo102=RXT;
08f;R@`0SX^:102>S8X;08j<R`@0SXf;302>SH`408j=S@/0SXj=102>SXh408j?SP@0SXn?0`2>T904
08nBT`@0SXn?102>SXh808j>S@<0Shf<302?SXd408n?S@@0T8j=102@Shd3092>S@@0T8j<102@SH/4
092<RP@0Sh^9102>RXL308j9QP@0SHR5102=QhD408f5P`@0RhB1102:PWl408V0O0<0Qgah1029PGd4
08Z3P0@0RhB2102;QH<408^6Q0<0S8J4202<QhD<08b8QPL0SHV7102=RHP408f:R1H0oooo000D0?oo
o`@0SHZ92`2=RhT<08j;RP@0SXb:2`2>S8/408j=R``0SXf<102>SHd;08j>S@@0SXj>102>Shh408j?
S`<0SY2@102?TY<408j?S`@0SXj>202>SXd308n=S0`0Shj=102?Shd4092>S@@0T8n=0`2@SXd4092>
S0@0T8f;102@S8X408n;R@@0SXZ70`2>RHH408f8Q@@0SHN5102=QH<408^4P@@0RX9o1029P7`308Ml
N0@0RH5m102:Ph0408^4PP@0RhF3102;QX@308b6Q0P0S8N5302<R8H708f9Q`@0SHV8102=RXPF0?oo
o`00503oool408f:R@/0SH^9302>RhX408j<RP/0SXb;102>SH/<08j=S0@0SXf=2`2>SXd408j>SP@0
SXn>102>Shl308j@T0@0Si:C102>Shl408j>SPP0SXj=0`2?SH`<08n>S@@0Shn=102@SXd4092?S@<0
T8j=102@SX`4092=R`@0T8b:102?RhT408j:Q`<0SXV6102=R8D408f7Q@@0SHF3102;Q84408Z2O`@0
RH1l0`27O7P408V1O@@0RX>0102;Q88408^5P`@0RhJ40`2<QX@808b7Q@`0S8R61`2=RHL408f9R0@0
SHZ85P3oool001@0oooo102=RhT408f;RP@0SX^:0`2>S8X808j<R`P0SXf<1`2?SXd808n?SP@0Shn?
202?T90708nAT@P0Si:B102?Ti<408nCU0@0SiBE0`2?UIL408nGVP@0SiBF102?Ti<808nBT@<0T96@
102@TI44096BT@`0TY:A102CTY4309>AT0@0TY2?102BSX`4096=R`@0T8^8102?RHH308j7Q0@0SHF2
102<Ph0408^1O@@0RGii1027NWH408EgL@<0PgA^1026NGD408MmN0@0R7mk1029PGd408Z2O`<0RX>0
102:Q84408^4PP@0RhF3102;QX@408b7Q0<0S8N5102<R8H408f9Q`@0SHV85P3oool001@0oooo102=
RhT408f;RP@0SX^:0`2>S8X808j<R`P0SXf<1`2?SXd808n?SP@0Shn?202?T90708nAT@P0Si:B102?
Ti<408nCU0@0SiBE0`2?UIL408nGVP@0SiBF102?Ti<808nBT@<0T96@102@TI44096BT@`0TY:A102C
TY4309>AT0@0TY2?102BSX`4096=R`@0T8^8102?RHH308j7Q0@0SHF2102<Ph0408^1O@@0RGii1027
NWH408EgL@<0PgA^1026NGD408MmN0@0R7mk1029PGd408Z2O`<0RX>0102:Q84408^4PP@0RhF3102;
QX@408b7Q0<0S8N5102<R8H408f9Q`@0SHV85P3oool001@0oooo102=RhT408f;RP@0SX^:0`2>S8X8
08j<R`P0SXf<1`2?SXd808n?SP@0Shn?202?T90708nAT@P0Si:B102?Ti<408nCU0@0SiBE0`2?UIL4
08nGVP@0SiBF102?Ti<808nBT@<0T96@102@TI44096BT@`0TY:A102CTY4309>AT0@0TY2?102BSX`4
096=R`@0T8^8102?RHH308j7Q0@0SHF2102<Ph0408^1O@@0RGii1027NWH408EgL@<0PgA^1026NGD4
08MmN0@0R7mk1029PGd408Z2O`<0RX>0102:Q84408^4PP@0RhF3102;QX@408b7Q0<0S8N5102<R8H4
08f9Q`@0SHV85P3oool001@0oooo102=RhT408f;RP@0SX^:0`2>S8X808j<R`P0SXf<1`2?SXd808n?
SP@0Shn?202?T90708nAT@P0Si:B102?Ti<408nCU0@0SiBE0`2?UIL408nGVP@0SiBF102?Ti<808nB
T@<0T96@102@TI44096BT@`0TY:A102CTY4309>AT0@0TY2?102BSX`4096=R`@0T8^8102?RHH308j7
Q0@0SHF2102<Ph0408^1O@@0RGii1027NWH408EgL@<0PgA^1026NGD408MmN0@0R7mk1029PGd408Z2
O`<0RX>0102:Q84408^4PP@0RhF3102;QX@408b7Q0<0S8N5102<R8H408f9Q`@0SHV85P3oool001@0
oooo102=RhT408j<RPL0SXb;102>SH`408n>S@@0Shj>202?Shl3092@T0@0T96@102@TI44092BTP@0
T9>C102@Ti@7096DU@@0TIFF102AUYL4096GV0@0T9NJ102@VI/3092JW@@0T9bP102?VI/4092GV0@0
T9FF102@UID3096EU@@0TYFE102CUID409BFU@@0TiJE102DUYD409FEU0<0U9>B102DTY0409>@SP@0
Thj<102ARhP40928Q@<0SXF2102=Pgl408]oO0@0RWag1027N7<408EcK@@0PFiV0`21L6T408=dKP@0
QGMb1026NWD408MlN0@0R7ij0`29Og`408V0O@@0RX9n102:Ph0408^4P@@0RhF30`2;QX@408b7Q@@0
S8R6102=RHLF0?ooo`00503oool408f;R@@0SXb:1`2>S8/408j=S0@0Shj=102?SXh808n?S`<0T92@
102@TI04092AT@@0T9:B102@Ti<4092CU0L0TIBE102AUIH4096FU`@0TINH102@UiX4092IV`<0T9ZM
102@W:0408nIV`@0T9NH102@UIH4092EU@<0TIFE102BUID409>EU@@0U9JE102CUYD409BFU@@0UIFD
0`2DTi8409BBT0@0Ti2>102CSX`4096;R0@0T8R50`2>QH8408f3O`@0Rgml102:O7L408MhL`@0QG=]
1021KVH3085`J@@0PgA^1025Mg8408IjM@@0Qgah1028OWX308UoO0@0RH1m102:PWh408Z3P0@0RhB1
102;QH<308^6Q0@0S8N5102<R8H408f9QaH0oooo000D0?ooo`@0SH^9102>S8X708j<R`@0SXf<102?
SXd408n>SPP0Shn?0`2@T904092AT0@0T96A102@TY84092CT`@0T9>D1`2AU9D4096EUP@0TIJG102A
UiP4092GVP@0T9VK0`2@VYd4092LX0@0SiVK102@UiP4092EUP@0T9FE0`2AUID409:EU@@0TiFE102D
UYD409>FU@@0U9JE102EUI@309BCTP@0U9:@102CT8h409>>S0@0TH^8102@R8D308j5PP@0SH=o102;
Og`408YlM`@0QgQc1025Lfd4085^IP<0PG1Y1023M6h408EgLP@0QWYe1027O7P408QnNP<0RGml1029
P7d408Z2OP@0RX>0102;Q84408^5P`<0RhJ4102<QhD408b8QP@0SHV75P3oool001@0oooo102=RhT4
08j<RPL0SXb;102>SH`408n>S@@0Shj>202?Shl3092@T0@0T96@102@TI44092BTP@0T9>C102@Ti@7
096DU@@0TIFF102AUYL4096GV0@0T9NJ102@VI/3092JW@@0T9bP102?VI/4092GV0@0T9FF102@UID3
096EU@@0TYFE102CUID409BFU@@0TiJE102DUYD409FEU0<0U9>B102DTY0409>@SP@0Thj<102ARhP4
0928Q@<0SXF2102=Pgl408]oO0@0RWag1027N7<408EcK@@0PFiV0`21L6T408=dKP@0QGMb1026NWD4
08MlN0@0R7ij0`29Og`408V0O@@0RX9n102:Ph0408^4P@@0RhF30`2;QX@408b7Q@@0S8R6102=RHLF
0?ooo`00503oool408f;RP@0SXb;102>SH`308n=S0@0Shj=102?Shh4092@S`P0T96A0`2@TY<4096C
T`@0TIBD102AUID4096FU`@0TYNH102BUiT309:HVP@0TYVK102BVY`409:KW@@0TYbO102AWJ03096N
XP@0TJ2U102@W9l4092JW0@0TIVJ102AV9T309:HV0@0TiRH102DV9P409FHV0P0UIVH102FUiL309JE
U0@0UI>A102DTHl409B?S0@0Th^8102AQh@308n4P0@0SH1l102:O7L408QgLP@0QG=/1022KFH407iW
GP<0P6]T1022KfP408=cK@@0QGI`1026N7<408IjMP<0Qgah1028OGT408QoN`@0RH5m102:PWl408Z3
P@<0RhF2102;QX@408b7Q@@0SHV75P3oool001@0oooo102=RhX408j<R`@0SXf<0`2?SH`408n>S@@0
Shn>102@T8l8092AT@<0T9:C102ATi<4096DU0@0TIFE102AUYL409:GV0@0TYNI0`2BV9X409:IV`@0
TYZL102BVid409:LW`@0TIfP0`2AWZ84096PY@@0T9bO102@VY`4096IVP@0TIRI0`2BV9P409>HV0@0
U9RH102EV9P809FIV0@0UYNG0`2FUI@409FCT@@0U96?102DSh`409>;R0@0THN40`2?Q80408f0O0@0
RWag1028Mg8408EcK0@0PVeV101nIeh3081[I0@0PVmX1023Lfd408EfL0@0QWQc1026NWH308MlN0@0
R7ei1028Og/408V1O@@0RX9o102:Ph4308^5PP@0RhJ4102<QhD408f9QaH0oooo000D0?ooo`@0SH^:
102>S8/408j=S0<0Shf<102?SXd408n?SP@0T92?202@TI43092BT`@0TI>C102AU9@4096EU@@0TIJG
102BUiP409:GV@<0TYRJ102BVI/409:JW0@0TY^M102BW9l4096MX0<0TIjR102AX:D4092LW`@0T9ZL
102AVIX4096HV@<0TYRH102CV9P409BHV0@0UIRH202EVIP409JGU`<0UYFD102ETi4409BAS`@0U8n<
102CRhP40967Q0<0ShB0102=P7`408YlM`@0R7Mb1025Lf`4089]IP@0OVMN0`20Jf@4089_J0@0Pg=]
1025MW0408IhL`@0QWYf0`27O7P408QmN@@0R7mk1029PGd408Z2O`@0RX>10`2;QH8408^6Q0@0S8N5
102=RHLF0?ooo`00503oool408j;RP@0SXb;102>SH`308n>S@@0Shn?102@T904092AT@@0TI:B102A
Ti@3096DU@@0TYFF102BUYL409:HV@@0TiVJ102CVY/409>KW@<0TibN102CWIl409>NX@@0TinR102C
X:@409:PY@<0TZ6W102AXjT4096OX`@0TIfP102BW9d409:KW0<0TiZK102DVY/409FJVP@0UYZJ102F
Vi/409JKVP@0UiZI0`2GUiH409JETP@0UY:@102ESh`409B<R0@0TXN30`2?PWh408enN@@0RGUd1026
Lfd408A^I`@0P6QP101mHeT307mWG`@0P6]T1022KfP408=bJ`@0Q7A^1025Mg4308IiM0@0Qg]f1027
OGP408QnN`@0RH1m102:PWl308Z4P@@0RhF3102<QhD408b8QaH0oooo000D0?ooo`@0SX^:102>S8/4
08j=S0<0Shj=102?Shl4092@T0@0T96A102ATY84096CU0<0TIBE102BUIH409:FU`@0TYRI102CVIX4
09>JV`@0Ti^M0`2CW9h409>MW`@0TijQ102CWj8409>PY0@0TZ2U0`2BXJL4096SZ@@0TInS102AWJ04
09:LW@@0TY^L0`2CVY/409BJV`@0UIZJ102FVYX409JKV`@0UY^J102GVYT309NGUP@0UYFB102FTY04
09F?S0@0U8b8102BQh<308n2OP@0SGii1029NG@408IcK@@0Q6iW1020J60407eSF@<0OfMO1020Jf@4
089_J0@0Pg9[1024M6h408EgL@<0QWUd1027NgH408MmN0@0R7ik1029P7d408Z2O`<0RXB1102;QH<4
08b7Q@@0S8R75P3oool001@0oooo102>RhX408j<R`@0SXf<0`2?SXd408n?S`@0T92@102@TI44096B
TP@0TI>D0`2AU9D409:EUP@0TYJG102BV9T409>IVP@0TiZK102CVid309>LWP@0TifO102CWZ4409>O
XP@0Tj2T102BX:D309:QY`@0TJ>Y102AWj<4096MX0@0TYbM102BVi`309>JV`@0U9ZK102EVYX409JJ
VP@0UY^K102FViX409NJV@<0UiNF102FUI8409JBT0@0UHn<102DS8P409:7P`<0Sh9n102=OWT408Ui
M0@0QW=]1024KVL4081XH0@0OF=I0`1oIel4081[I0@0PVmX1023LV/408AdKP@0QGMa0`26NG@408Mk
MP@0Qgeh1028OW/408V0O@@0RX9o0`2:Q84408^5P`@0S8N5102<R8LF0?ooo`00503oool408j;RP@0
SXb;102>SH`308n>S@@0Shn?102@T904092AT@@0TI:B102ATi@3096DU@@0TYFF102BUYL409:HV@@0
TiVJ102CVY/409>KW@<0TibN102CWIl409>NX@@0TinR102CX:@409:PY@<0TZ6W102AXjT4096OX`@0
TIfP102BW9d409:KW0<0TiZK102DVY/409FJVP@0UYZJ102FVi/409JKVP@0UiZI0`2GUiH409JETP@0
UY:@102ESh`409B<R0@0TXN30`2?PWh408enN@@0RGUd1026Lfd408A^I`@0P6QP101mHeT307mWG`@0
P6]T1022KfP408=bJ`@0Q7A^1025Mg4308IiM0@0Qg]f1027OGP408QnN`@0RH1m102:PWl308Z4P@@0
RhF3102<QhD408b8QaH0oooo000D0?ooo`@0SX^:102>SH`408n>S@<0Shn>102@T904092AT@@0TI>C
102AU9@409:EUP<0TYJG102CV9T409>IVP@0TiZL102DVih409BMW`@0U9jQ0`2EWj8409FPY0@0UJ:V
102EXjL409BTZ0@0TjBZ0`2BYJX4096UZ`@0TJ:V102AX:<409:NX0@0TifO0`2DWIh409FLW@@0UIbL
102FW9`409NLW0@0V9bL102HViX309RIV0@0UiJD102GTi4409J?S0@0UHb8102CQX830920O0@0SGaf
1029MW4408I`J@@0PVYQ101nHeT407aPEP<0OVAK101oJ5l4081[H`@0PViW1023LFX408AcK@<0QGI`
1025N7<408IjM@@0Qgah1028OW/408V0O@<0RX9o102;Q84408^6Q0@0S8R65P3oool001@0oooo102>
RhX408j=S0@0Shj=0`2?Shh4092@T0@0T96A102ATi<4096DU0@0TYFF0`2BUYL409>HV@@0TiVJ102C
VY`409BKWP@0U9fO102DWZ4309FOXP@0UJ2T102EXZH409FSY`@0U:BX102CY:X309:UZP@0TJF[102A
XZH4096PX`@0TYjP102CWIl309BMWP@0UIbM102EW9`409JLW0@0UibL102HW9`409RKVP<0V9VH102G
UY@409NCT@@0UXn<102ES8P409>6PP<0T81l102=O7H408UfL@@0QW1Y1022JV4407iSF@@0O61F0`1n
I5/407mXG`@0P6]S1022KVL408=aJP@0Q7=]0`25MW0408EhL`@0QWYe1027O7P408QnN`@0RH1m0`2:
PWl408^4P@@0RhJ4102<R8HF0?ooo`00503oool408j;RP@0SXf<102?SXd308n?SP@0T92@102@TI44
096CT`@0TIBD102BUIH309:FU`@0TiRI102CVIX409>JW0@0U9^N102DWIl409BNX@<0UInR102EX:@4
09FRYP@0UJ>W102DY:P409>TZP<0TZFZ102AYJ/4096RYP@0TJ2S102BWZ0409>MW`<0U9fN102EW9d4
09FLW0@0UYbL102GW9`409RLW0@0V9^J0`2HVIP409NFU0@0Ui>A102FSh`409F<R0@0ThJ20`2@P7`4
08elMP@0RGIa1026L6T4089ZH@@0OV=I101lH5H307iTF`@0OfQO1020Jf<4089^I`@0Pg5Z1024Lfd3
08EfL0@0QGQc1026NWD408MlN0@0R7ik1029P7d308Z2O`@0RhB1102;QX@408b8QQH0oooo000D0?oo
o`@0SX^:102>SH`408n>S@<0Shn>102@T904092AT@@0TI>C102AU9@409:EUP<0TYJG102CV9T409>I
VP@0TiZL102DVih409BMW`@0U9jQ0`2EWj8409FPY0@0UJ:V102EXjL409BTZ0@0TjBZ0`2BYJX4096U
Z`@0TJ:V102AX:<409:NX0@0TifO0`2DWIh409FLW@@0UIbL102FW9`409NLW0@0V9bL102HViX309RI
V0@0UiJD102GTi4409J?S0@0UHb8102CQX830920O0@0SGaf1029MW4408I`J@@0PVYQ101nHeT407aP
EP<0OVAK101oJ5l4081[H`@0PViW1023LFX408AcK@<0QGI`1025N7<408IjM@@0Qgah1028OW/408V0
O@<0RX9o102;Q84408^6Q0@0S8R65P3oool001@0oooo102>S8X408j=S0@0Shj>0`2@T8l4092AT@@0
TI>C102AU9D409:FUP@0TiNH0`2CVIX409BJW0@0U9^M102EWIl409FNX@@0UJ2S102FXJD309JSY`@0
UZBX102FYZX409JW[0@0UZR^102EZ:l309:X[`@0T:F/102AXjP409:RY@@0Tj6S102CX:4309BOX0@0
UInO102FWYl409NNWPP0V9jM102IW9/309VJV@@0V9NE102HU94409N?S0@0UH^7102CQH830920N`@0
SGUd1029M6d408E]I@@0PFIM101lGU<407aNE0<0OF5H101nIE`407mXG`@0P6]S1021KVH4089`JP<0
Pg=]1024MW0408EhL`@0QWYf1027OGP408QoN`<0RH5n102:Ph0408^5P`@0S8R65P3oool001@0oooo
102>S8X408j=S0@0Shj>0`2@T8l4092AT@@0TI>C102AU9D409:FUP@0TiNH0`2CVIX409BJW0@0U9^M
102EWIl409FNX@@0UJ2S102FXJD309JSY`@0UZBX102FYZX409JW[0@0UZR^102EZ:l309:X[`@0T:F/
102AXjP409:RY@@0Tj6S102CX:4309BOX0@0UInO102FWYl409NNWPP0V9jM102IW9/309VJV@@0V9NE
102HU94409N?S0@0UH^7102CQH830920N`@0SGUd1029M6d408E]I@@0PFIM101lGU<407aNE0<0OF5H
101nIE`407mXG`@0P6]S1021KVH4089`JP<0Pg=]1024MW0408EhL`@0QWYf1027OGP408QoN`<0RH5n
102:Ph0408^5P`@0S8R65P3oool001@0oooo102>S8X408j=S0@0Shj>0`2@T8l4092AT@@0TI>C102A
U9D409:FUP@0TiNH0`2CVIX409BJW0@0U9^M102EWIl409FNX@@0UJ2S102FXJD309JSY`@0UZBX102F
YZX409JW[0@0UZR^102EZ:l309:X[`@0T:F/102AXjP409:RY@@0Tj6S102CX:4309BOX0@0UInO102F
WYl409NNWPP0V9jM102IW9/309VJV@@0V9NE102HU94409N?S0@0UH^7102CQH830920N`@0SGUd1029
M6d408E]I@@0PFIM101lGU<407aNE0<0OF5H101nIE`407mXG`@0P6]S1021KVH4089`JP<0Pg=]1024
MW0408EhL`@0QWYf1027OGP408QoN`<0RH5n102:Ph0408^5P`@0S8R65P3oool001@0oooo102>S8X4
08j=S0@0Shj>0`2@T8l4092AT@@0TI>C102AU9D409:FUP@0TiNH0`2CVIX409BJW0@0U9^M102EWIl4
09FNX@@0UJ2S102FXJD309JSY`@0UZBX102FYZX409JW[0@0UZR^102EZ:l309:X[`@0T:F/102AXjP4
09:RY@@0Tj6S102CX:4309BOX0@0UInO102FWYl409NNWPP0V9jM102IW9/309VJV@@0V9NE102HU944
09N?S0@0UH^7102CQH830920N`@0SGUd1029M6d408E]I@@0PFIM101lGU<407aNE0<0OF5H101nIE`4
07mXG`@0P6]S1021KVH4089`JP<0Pg=]1024MW0408EhL`@0QWYf1027OGP408QoN`<0RH5n102:Ph04
08^5P`@0S8R65P3oool001@0oooo102>S8X408n=S@@0Shn>0`2@TI04096BTP@0TIBD102BUYH409>G
V0@0TiVJ0`2DVi`409FLWP@0UIjP102FX:<409JQY@@0Uj>W102GYJT309RVZ`@0V:R]102HZZl409V[
/@@0VJfc102I[[D308nW[`@0SZB[102@Y:T409:SY`@0Tj:U102DXZ<309FQXP@0UZ6R102GX:4409RP
X0@0VJ2P102IWil409ZMW@<0VY^J102IV9H409RDT@@0Uhn<102FRXL409>5P@<0T7ii102=N78408Qa
JP@0PfYR1020HeT407]JC`@0NeaA0`1lGe@407eRF0@0OVEL101oJ5l4081ZH`@0PFeV0`22L6X408=c
K@@0Q7E`1025N7<408IkMP@0Qgij0`29P7`408Z2O`@0RhF2102<QhDF0?ooo`00503oool408j<RP@0
Shf=102?Shh3092AT0@0TI:B102AU9@409:FUP@0TiNH102CVIX309BKW0@0UIbN102EWZ0409JPX`@0
UZ6U102GXjL409NUZ@<0V:J[102HZ:d409RZ[`@0VJ^a102I[K<409V^]@<0SjN_102>Y:/4092TZ@@0
TZ>W102CXZD409BRX`<0UJ6R102FXJ8409NPX@@0V:2P102IX:0409VOW`@0VYfM0`2JViX409VHUP@0
V9BA102GSh`409J:Q`@0ThF10`2@OWT408ehLP@0R75Z1023JV84081SF@@0NeY?101kG54307aOE0@0
OF9H101nIE`407mXG`@0P6YS1021KFH3089`JP@0Pg=]1024MG0408EhL`@0QW]f1027OWX308V0O0@0
RX9o102;QH8408b7QAH0oooo000D0?ooo`@0SXb:102?SHd408n?SP<0T96@102ATY84096DU0@0TYJF
102CUiP409>IVP<0U9^L102EW9h409FNX0@0UZ2S102FXJD409NSY`@0UjFY0`2HYZ/409RX[@@0V:Z_
102IZk4409V]/`@0VJje0`2?Yjl408jTZ`@0T:BY102BXjL409>RY@@0U::S0`2EXJ8409JQXP@0Uj2Q
102HX:0409VPX0@0VInO102JWId309ZKVP@0VIRF102HU94409N?S0@0UXZ7102CQH43091nN@@0SGQb
1028LFX408=ZHP@0P6=I101kFTl407]LD@<0O5mD101mHUP407iUG0@0OfQO1020JV<4085]IP<0PW1Z
1023Lfd408AeL0@0QGQc1026NgH408MnNP<0RH1l102:PWl408^5PP@0S8N55P3oool001@0oooo102>
S8X408n=S@@0Shn>0`2@TI04096BTP@0TIBD102BUYH409>GV0@0TiVJ0`2DVi`409FLWP@0UIjP102F
X:<409JQY@@0Uj>W102GYJT309RVZ`@0V:R]102HZZl409V[/@@0VJfc102I[[D308nW[`@0SZB[102@
Y:T409:SY`@0Tj:U102DXZ<309FQXP@0UZ6R102GX:4409RPX0@0VJ2P102IWil409ZMW@<0VY^J102I
V9H409RDT@@0Uhn<102FRXL409>5P@<0T7ii102=N78408QaJP@0PfYR1020HeT407]JC`@0NeaA0`1l
Ge@407eRF0@0OVEL101oJ5l4081ZH`@0PFeV0`22L6X408=cK@@0Q7E`1025N7<408IkMP@0Qgij0`29
P7`408Z2O`@0RhF2102<QhDF0?ooo`00503oool408j<R`@0Shj=102@T8l3092AT@@0TI>C102BUIH4
09>GV0@0TiVJ102DVid309FMW`@0UYnQ102FX:<409NRYP@0V:BX102HYZX409VX[@<0VJZ_102J[;44
09Z^]0@0Vk2f102L/[T409^c^`<0RJ>/102>YJ`4092UZP@0TZFY102DY:L409FTYP<0UZ>T102GXj@4
09RSX`@0VJ>R102JXZ8409ZQX0@0VijN0`2KViX409ZHUP@0VI>A102HSX/409J9QP@0ThAo0`2@OGP4
08agL0@0R6mX1023J5l407mPEP@0NUQ<101jFDh307]LD@@0O5mD101mHEP407iTF`@0OfMO1020JV<3
085]IP@0PW1Z1023Lfd408AfL@@0QGUd1027O7P308QoN`@0RH5n102;Q88408b7QAH0oooo000D0?oo
o`@0SXb;102?SXd4092@S`<0T96A102ATi<409:EUP@0TiNH102CVIX409BKW@<0UIfO102FWj4409JP
X`@0Uj:V102HY:P409RVZP@0VJR]0`2IZZl409Z//@@0VZjd102K/;H409bb^@@0Vk>k0`29Xj`408jU
[0@0T:FZ102BYJT409BTY`@0UJBV0`2FXj@409NSY0@0V:>S102IXj8409ZRXP@0VZ6P102KWYh309^K
VP@0VYRF102ITi4409R>R`@0UXV6102CQ7l3091mN0@0S7M`1028KfP408=XG`@0Of1F101jF4`407YI
CP<0NeaA101lGe@407eQF0@0OVAK101oIel4081ZH`<0PFeV1022L6X408=cK@@0Q7Ia1025NG@408Ml
N0<0R7mk1029PGh408^4PP@0S8N55P3oool001@0oooo102>S8/408n>S@@0T92?0`2@TI44096CT`@0
TYFF102CUiP409>IVP@0U9^M0`2EWIl409JOX@@0UZ2S102GXZH409RTZ0@0V:JZ102IZ:d309VZ[`@0
VZba102J[[@409^`]P@0W;:i102K/k/308VS[0@0SZF/102@YJX409:UZ@@0U:BW102EY:H309JSY0@0
Uj>T102HXj<409VSXP@0VZ:R102JXJ0409^NWP<0Vi^J102JV9H409VCT@@0V8j;102FRHH409>4O`<0
T7eh102<Mg0408Q_J0@0PfQO101oH5H407YHC0@0NUU>0`1kG54407aOE0@0OF5H101nI5/407mWG`@0
P6YS0`21KFH4089`JP@0Pg=]1024MW4408EiM0@0Qgah0`28Og/408V1OP@0RhB2102<QhDF0?ooo`00
503oool408j<R`@0Shj=102@T8l3092AT@@0TI>C102BUIH409>GV0@0TiVJ102DVid309FMW`@0UYnQ
102FX:<409NRYP@0V:BX102HYZX409VX[@<0VJZ_102J[;4409Z^]0@0Vk2f102L/[T409^c^`<0RJ>/
102>YJ`4092UZP@0TZFY102DY:L409FTYP<0UZ>T102GXj@409RSX`@0VJ>R102JXZ8409ZQX0@0VijN
0`2KViX409ZHUP@0VI>A102HSX/409J9QP@0ThAo0`2@OGP408agL0@0R6mX1023J5l407mPEP@0NUQ<
101jFDh307]LD@@0O5mD101mHEP407iTF`@0OfMO1020JV<3085]IP@0PW1Z1023Lfd408AfL@@0QGUd
1027O7P308QoN`@0RH5n102;Q88408b7QAH0oooo000D0?ooo`@0SXb;102?SXh4092AT0<0TI:B102B
U9D409>FU`@0TiRJ102DVi`409FMW`<0UYnQ102GXJ@409NSYP@0V:FY102IYj`409ZY[P@0VZ^a0`2K
[K<409^`]P@0W;:i102L];/409ng_`@0U:ng0`2;YJd408nW[@@0TJN/102CYj/409BVZ@@0UZJX0`2G
YJH409RUY@@0VJFU102JYJD409^UY@@0W:BR102LX9l309bLV`@0VYNE102ITY0409R=R`@0UXR5102B
PWh308mkMP@0RgE_1027KVH408=VG@@0OUmD201jETX307YIC@@0Ne]A101lGU@407eQF0@0OFAK101n
Iel3081[H`@0PFiW1022LF/408=dKP@0QGMb1026NWH308MmNP@0RH5m102:Q84408b7QAH0oooo000D
0?ooo`@0SXb;102?SXh4092AT0<0TI:B102BU9D409>FU`@0TiRJ102DVi`409FMW`<0UYnQ102GXJ@4
09NSYP@0V:FY102IYj`409ZY[P@0VZ^a0`2K[K<409^`]P@0W;:i102L];/409ng_`@0U:ng0`2;YJd4
08nW[@@0TJN/102CYj/409BVZ@@0UZJX0`2GYJH409RUY@@0VJFU102JYJD409^UY@@0W:BR102LX9l3
09bLV`@0VYNE102ITY0409R=R`@0UXR5102BPWh308mkMP@0RgE_1027KVH408=VG@@0OUmD201jETX3
07YIC@@0Ne]A101lGU@407eQF0@0OFAK101nIel3081[H`@0PFiW1022LF/408=dKP@0QGMb1026NWH3
08MmNP@0RH5m102:Q84408b7QAH0oooo000D0?ooo`@0SXb;102?SXh4092AT0<0TI:B102BU9D409>F
U`@0TiRJ102DVi`409FMW`<0UYnQ102GXJ@409NSYP@0V:FY102IYj`409ZY[P@0VZ^a0`2K[K<409^`
]P@0W;:i102L];/409ng_`@0U:ng0`2;YJd408nW[@@0TJN/102CYj/409BVZ@@0UZJX0`2GYJH409RU
Y@@0VJFU102JYJD409^UY@@0W:BR102LX9l309bLV`@0VYNE102ITY0409R=R`@0UXR5102BPWh308mk
MP@0RgE_1027KVH408=VG@@0OUmD201jETX307YIC@@0Ne]A101lGU@407eQF0@0OFAK101nIel3081[
H`@0PFiW1022LF/408=dKP@0QGMb1026NWH308MmNP@0RH5m102:Q84408b7QAH0oooo000D0?ooo`@0
SXb;102?Shh4092AT@<0TI>C102BUIH409>HV@@0U9ZK102EW9h409JOX@<0Uj6T102HXjL409VUZ@@0
VJR/102JZZl409^//P@0W:ne0`2L/KL409fc^P@0W[Jm102O^L4409Rc_0@0Sj^d0`2?Z[84096Z[`@0
TjV^102DZJd409JY[0@0UjRY0`2HYjP409VWY`@0VZNW102KZ:L409bXY`@0WJFT102MXJ0309fLV`@0
ViNE102JTHl409R<RP@0UXN3102BPG`308ijM@@0RW=/1026K6D408=VG@@0OUmD101kEd/407QCAP<0
NEE9101jF4`407YKD0@0NeiD101lHEP407eTG0<0OVQP101oJf@4085_J0@0PW9/1024MG0408EiM0<0
Qgah1028P7`408Z3P0@0S8N45P3oool001@0oooo102>S8/408n?SP@0T96A0`2ATi<409:EUP@0TiRI
102DVY/409FLWP@0UYnQ0`2GXJ@409RSY`@0VJFY102IZ:`409ZZ[`@0Vjbb102L[kD309ba]`@0WK>j
102N][d409ni`@@0V;>l102?Zk@308nZ/P@0TJZ_102CZJh409BY[@@0UZV/102GZ:T309RWZ0@0VJNW
102JYjL409^XY`@0W:RW102MYJ@409fQX0<0WIbK102KUiD409ZAS`@0V8b:102FQh<409:1O0<0SWYe
102:Lf`408I/I@@0PfIM101nGe@407]GB`@0N5=60`1iEDT407YHC0@0NU]@101kGU@407aQF0@0OFAL
0`1nJ60407m[I0@0PFmX1022LV`408AeL0@0QGUd0`27O7P408R0O0@0RX>0102<Qh@F0?ooo`00503o
ool408j<R`@0Shn>102@TI43096CT`@0TYFF102CV9T409BJV`@0UIbN102FWj4309NQY0@0V:>W102I
YJT409VX[0@0VZZ_102K[;8409b_]@<0W;6g102M/kX409jf_@@0WkW1102H/k`408n[]0<0SjZb102A
ZZl409>Y[P@0U:V]102FZJ`409NXZ@<0V:NX102IYjL409ZWY`@0VjRW102LZ:L409fUY0@0WJ6P0`2M
W9/409^GU@@0VY6?102HS8X409J7P`@0TX5l0`2>NWD408YcK0@0QVaU1023IUd407iOE0@0NeM;101h
DdH307UEB@@0NUQ<101jFe0407]NE0@0O65H101mI5`307iXH0@0Of]T1021KfP4089bK0@0Q7E`1025
NG@308MlN0@0R81l102:Ph0408b7Q1H0oooo000D0?ooo`@0SXb;102?Shh4092AT@<0TI>C102BUIH4
09>HV@@0U9ZK102EW9h409JOX@<0Uj6T102HXjL409VUZ@@0VJR/102JZZl409^//P@0W:ne0`2L/KL4
09fc^P@0W[Jm102O^L4409Rc_0@0Sj^d0`2?Z[84096Z[`@0TjV^102DZJd409JY[0@0UjRY0`2HYjP4
09VWY`@0VZNW102KZ:L409bXY`@0WJFT102MXJ0309fLV`@0ViNE102JTHl409R<RP@0UXN3102BPG`3
08ijM@@0RW=/1026K6D408=VG@@0OUmD101kEd/407QCAP<0NEE9101jF4`407YKD0@0NeiD101lHEP4
07eTG0<0OVQP101oJf@4085_J0@0PW9/1024MG0408EiM0<0Qgah1028P7`408Z3P0@0S8N45P3oool0
01@0oooo102>SH`408n?S`@0T9:B0`2BU9@409>FU`@0U9VJ102EVid409JNX0@0Uj2S0`2HXjH409VU
Z@@0VZR/102KZjl409b]/P@0WK2f102M/[T309jd_0@0W[No102O^L8409bi`P@0TJnh102A[[L309:]
]0@0Tjbb102D[;4409J//0@0Uj^^102HZJ/309VYZ@@0VJRX102JZJT409bYZ0@0WJZY102NYZD409jR
X@<0WIfK102MV9L409^AS`@0VHb9102EQH84095oN`<0SGQc1028LF/408E[H`@0PVEL101nGe@407aH
C0@0N5950`1gDD@407QDB0@0NEM<101jFe0407]NE0@0O65H0`1mIE`407iXH@@0P6aU1021L6X408=d
KP@0Q7Qc0`26NgL408QoN`@0RX>0102;QX@F0?ooo`00503oool408j=S0@0Shn?102@TY8309:DU0@0
TiJG102DVIX409FKW@@0UYjP102GX:<309RSYP@0VJFY102JZ:`409^[[`@0W:fb102M/;H409fb^@<0
W[Bl102N]kl409ni`P@0W;W2102A[kP4096^]`<0TZfd102C[;8409B//@@0UZb`102GZjh409RYZ`<0
VJVY102IZ:P409ZYZ@@0W:VX102MZZT409jVY@@0WZ:Q0`2MWI/409fHU`@0Vi6?102IS8T409F5PP@0
TGmk0`2=N7<408QaJ`@0QF]S1022IE`407iOE0@0O5Q<101hDTD307MAA0@0N5A8101iEd`407YKD0@0
NeiD101lHEP307eUG0@0OVQQ1020K6D4085`JP@0PgA^1024N7<308IkM`@0R7mk102:Ph0408^6Q1H0
oooo000D0?ooo`@0SXf<102?Shl4092BTP<0TYBD102CUYL409BIVP@0UI^M102FWZ0409NPX`<0V:>V
102IYJT409ZX[0@0Vj^_102L[K8409f`]P@0WK:i0`2N];`409jg_`@0WkW2102L^L84096_^0@0TJjg
0`2B[K@409>//P@0U:ba102F[;0409N[[P@0V:V[0`2IZJT409VXZ0@0VZVY102LZJP409fZZ@@0WZJU
102NXZ4309fMV`@0WIRG102KTHl409V<R@@0UHF2102AOg/308ehL`@0R75[1025Jf<4089UG0@0OUmD
101lF4`407QBA@<0Me54101hE4P407UGC0@0NU]@101kGU@407aQF0<0OFEL101nJ644081/I@@0PG1Z
1023M6h408AhL`<0QW]g1028Og/408Z3P0@0RhJ45P3oool001@0oooo102>SH`408n?S`@0T9:B0`2B
U9@409>FU`@0U9VJ102EVid409JNX0@0Uj2S0`2HXjH409VUZ@@0VZR/102KZjl409b]/P@0WK2f102M
/[T309jd_0@0W[No102O^L8409bi`P@0TJnh102A[[L309:]]0@0Tjbb102D[;4409J//0@0Uj^^102H
ZJ/309VYZ@@0VJRX102JZJT409bYZ0@0WJZY102NYZD409jRX@<0WIfK102MV9L409^AS`@0VHb9102E
QH84095oN`<0SGQc1028LF/408E[H`@0PVEL101nGe@407aHC0@0N5950`1gDD@407QDB0@0NEM<101j
Fe0407]NE0@0O65H0`1mIE`407iXH@@0P6aU1021L6X408=dKP@0Q7Qc0`26NgL408QoN`@0RX>0102;
QX@F0?ooo`00503oool408j=S0@0T92?102ATY8309:EU@@0TiRI102DVY`409FMW`@0Uj2R102HXZD3
09VUZ@@0VZR/102KZjl409b]/`@0WK2f102N/kT409ne_@<0X;S0102P^/<40:6ma`@0T[:l102A/;X4
09:_^0<0Tjnf102E[k@409J_]0@0V:nc102I[K0409V[[0<0VJZZ102JZZX409ZZZ@@0W:VX102NZ:L4
09nVYP@0WZ6P0`2NWY`409nKV@@0W9>A102JS8X409F4PP@0T7ej0`2<Mg8408M`J@@0Q6YR1021I5/4
07mOE0@0O5Q=101iDdL307I>@0@0Me54101hE4P407QGC0@0NE]@101jGUD307]RF@@0OFIN101nJV<4
081^I`@0PW9/1023MW4308EjM@@0Qgij1029PWl408^6Q1H0oooo000D0?ooo`@0SXf<102@T8l4096B
TP<0TYFE102CV9T409BJW0@0UIfO102GX:8409RRY@<0VJFY102JZ:`409^[[`@0W:fc102M/;H409jc
^@@0WkFm0`2P^<040:2j``@0XKg7102B/[`4096`^P@0TZnh0`2C[kH409F_]0@0UZnd102H[k<409V]
/0@0VJ^/0`2IZZX409ZZZP@0VZZY102LZJP409jXY`@0WjJV102NXJ0309jNW0@0Wi^I102LTi4409Z<
RP@0UHB2102@OGX308agLP@0Qg1Y1024JV84085TF`@0OemD101lF4d407UCA`<0MTi0101gDD@407QD
B0@0N5M<101iFe0407YNE@<0Nf9I101mIUh407iZH`@0P6iW1022LV`408=fL@<0QGYe1027OWX408V2
O`@0RhJ45P3oool001@0oooo102>SH`4092@S`@0TI:B0`2BUID409>HV@@0U9ZL102EWIl409NPXP@0
V::U0`2IYJT409ZX[0@0Vj^_102L[K<409f`]P@0W[>i102O]Kd30:2h`0@0X;[3102Q_LL409:b_0@0
TK2j102B[kP309>_]P@0UJnd102F[k@409R_/`@0VJf`102IZj`309VZZP@0VZZZ102JZZT409bYZ0@0
WZRW102OYZH409jQX0<0WYjL102OViT409bCT@@0VXb:102EQ884091mNP<0S7Mb1027L6T408AZHP@0
PFAK101oGe@407aHC@@0NE=70`1fCT0407MAA0@0N5A8101hEd`407UKD0@0NUiE0`1kHUT407eVGP@0
OVYS1020KVL4089bK0@0PgIa0`25NWD408MnNP@0RH9o102;QX@F0?ooo`00503oool408j=S0@0T92?
102ATY8309:EU@@0TiRI102DVY`409FMW`@0Uj2R102HXZD309VUZ@@0VZR/102KZjl409b]/`@0WK2f
102N/kT409ne_@<0X;S0102P^/<40:6ma`@0T[:l102A/;X409:_^0<0Tjnf102E[k@409J_]0@0V:nc
102I[K0409V[[0<0VJZZ102JZZX409ZZZ@@0W:VX102NZ:L409nVYP@0WZ6P0`2NWY`409nKV@@0W9>A
102JS8X409F4PP@0T7ej0`2<Mg8408M`J@@0Q6YR1021I5/407mOE0@0O5Q=101iDdL307I>@0@0Me54
101hE4P407QGC0@0NE]@101jGUD307]RF@@0OFIN101nJV<4081^I`@0PW9/1023MW4308EjM@@0Qgij
1029PWl408^6Q1H0oooo000D0?ooo`@0SXf<102@T904096CT`<0TYJF102DVIX409FKW@@0UYjQ102G
XJ@409VTZ0<0VZN[102KZZl409b]/P@0W[2f102O/kT40:2f_@@0XKW00`2R_<@40::ob0@0WKc7102>
[kX4096`^@@0Tk6i0`2D/;L409Ja]`@0V;:g102K/[H409^`/P@0VJb/0`2JZj/409b[Z`@0UjJU102K
YjL409fUY0@0WjFT102PY:830:6PWP@0XIfK102NUY<409b@S@@0UHJ3102@O7T308YeL@@0QViX1023
J604085SF`@0OemE101mFDh407YDB0<0Mdm1101fCCl407I@@`@0MeA8101gEd`407QKD@<0NEmF101k
He/407eWH0@0OfaU1021L6X408=dK`<0QGUd1027OGT408V1OP@0RhJ35P3oool001@0oooo102>SH`4
092@T0@0TI>C0`2BUYH409BIVP@0UI^M102FWZ4409NQY0@0VJBX0`2JYj/409^Z[`@0W:fb102N/;H4
09nc^@@0X;Jm102Q^L030::la0@0X[o8102M_<L408j_^P@0TK2i102C/KT309B`]`@0U[6g102H/[L4
09^b]P@0Vk2b102I[:`309Z[Z`@0W:^[102GYZD409^WY`@0WJFT102OYJ@40:2TXP<0XJ2N102QWI/4
09jFT`@0W92=102EQX<4091lN@<0RWEa1026KVP408=XH0@0PF=K101oGeD407eICP@0NUA80`1gCd44
07I=?`@0MU13101gE4P407MGC0@0N5]A0`1iGeH407]SF`@0OFMP101oK6D4085`JP@0PgA_0`25NG@4
08MmN@@0RH5n102;QX<F0?ooo`00503oool408j=S0@0T92@102ATi<309:FUP@0U9VJ102EVid409JN
X@@0Uj6T102IY:P309ZWZ`@0VjZ_102L[K8409j`]P@0Wk>i102P][d40:6i`0<0X[c4102R_lP409fl
a`@0SZnj102A/;T409>a^@<0U;2g102F/KL409Rb]`@0Vk:f102K/;8409V/[0<0VZ^[102LZj/409NV
Y@@0VjNW102MYJ@409nUY0@0X:BR0`2QX9h40:6MV`@0WYJC102LT8d409F6P`@0T7ai0`2:MG4408I^
J0@0PfQP1021He/407mOE@@0OEU>101jE4P307M?@@@0MTdo101fD4<407MDB0@0MeM<101hFe4307UO
EP@0Nf=K101mIf0407m/I@@0PG1Z1023M6l308EiM0@0Qgei1029PGh408^6PaH0oooo000D0?ooo`@0
SXf<102@T904096CT`<0TYJF102DVIX409FKW@@0UYjQ102GXJ@409VTZ0<0VZN[102KZZl409b]/P@0
W[2f102O/kT40:2f_@@0XKW00`2R_<@40::ob0@0WKc7102>[kX4096`^@@0Tk6i0`2D/;L409Ja]`@0
V;:g102K/[H409^`/P@0VJb/0`2JZj/409b[Z`@0UjJU102KYjL409fUY0@0WjFT102PY:830:6PWP@0
XIfK102NUY<409b@S@@0UHJ3102@O7T308YeL@@0QViX1023J604085SF`@0OemE101mFDh407YDB0<0
Mdm1101fCCl407I@@`@0MeA8101gEd`407QKD@<0NEmF101kHe/407eWH0@0OfaU1021L6X408=dK`<0
QGUd1027OGT408V1OP@0RhJ35P3oool001@0oooo102?SH`4092AT0@0TIBD0`2CUYL409BJV`@0UYfO
102GX:8409RSYP@0VZJZ0`2KZJh409b//@@0W[2e102O/kT40:6f_@@0X[W1102S_<@30:>ob0@0YL?<
102C]<0408n`^`@0TK6j102D/[X309Fa]`@0V;>i102J]KX409fe^@@0WK:d102L[Zh309RWY`@0VZNX
102GXj<409^UY@@0WJFT102OY:@40:6VY@<0XZ2N102RWI/40:6IUP@0X9FB102GRXH408imN@<0R7=_
1024KFL4085VG`@0P69J101oGeD407iKC`@0NeI90`1iD48407I<?@@0MDe0101dD4<407ECB0@0MUM=
0`1gG58407UPF0@0NfEM101mJF8407m^J0@0PW=]0`24Mg<408IlN0@0R85n102;QH<F0?ooo`00503o
ool408n=S0@0T96@102AU9@309>FU`@0U9ZK102FWIl409NPXP@0V:>V102JYZX309^Y[P@0W:ba102N
/;D409nc^@@0XKJm102R^L440:>la0<0Xko8102U`l`409>d`0@0Sk2k102A/KX409Bb^P<0UK6g102H
/kT409Ze^P@0WKFi102M/[@409b^[P<0V:NW102JYjP409NSX`@0VjFU102MYJ@409nTY0@0XJJU0`2R
X9h40::MV`@0XIVF102PUI8409N:QP@0SWei0`28Lfl408A]I`@0PFIO1020HUX407mOE@@0OU]?101k
ETT307U@@P@0MT`m101eCD0407A@@`@0ME=8101fEdd307MLDP@0NF1H101kIEd407eYHP@0OfiX1022
Lfd308AgL`@0QWah1028PGh408^5PaH0oooo000D0?ooo`@0Shf<102@TI04096DU0<0TiJG102DVY/4
09JMW`@0Uj2R102HXjH409ZVZP<0VjV^102L[;4409j`]@@0Wk>i102Q][d40::i`@@0Xkc40`2S_lP4
0:G3c0@0TkC0102?/;/4096a^P@0U;:j0`2E/KL409Rc^@@0V[Fj102M]KT409fb]0@0W:j^0`2HYjL4
09ZWZ0@0Uj>S102KYJD409fUY0@0WjBT102QYZD30::PWP@0XYfK102QVIH40:2ETP@0UhZ6102>OGT3
08QcK`@0Q6eW1021IUl4081RFP@0OemE101nFdl407]FB@<0NE12101fC3d407E=@0@0M513101eDdP4
07IGC@<0MeaB101iH5P407]UG@@0OFUR101oKVP4089cK@<0Q7Mc1026O7P408R1OP@0RhF35P3oool0
01@0oooo102?SH`4092AT0@0TIBD0`2CUYL409BJV`@0UYfO102GX:8409RSYP@0VZJZ0`2KZJh409b/
/@@0W[2e102O/kT40:6f_@@0X[W1102S_<@30:>ob0@0YL?<102C]<0408n`^`@0TK6j102D/[X309Fa
]`@0V;>i102J]KX409fe^@@0WK:d102L[Zh309RWY`@0VZNX102GXj<409^UY@@0WJFT102OY:@40:6V
Y@<0XZ2N102RWI/40:6IUP@0X9FB102GRXH408imN@<0R7=_1024KFL4085VG`@0P69J101oGeD407iK
C`@0NeI90`1iD48407I<?@@0MDe0101dD4<407ECB0@0MUM=0`1gG58407UPF0@0NfEM101mJF8407m^
J0@0PW=]0`24Mg<408IlN0@0R85n102;QH<F0?ooo`00503oool408n>S@@0T96A102BU9D309>GV0@0
UI^L102FWZ0409RQY0@0VJFX102JZ:`309b[/0@0WJnd102O/[P40:6f_0@0X[W1102T_LD40:G0b@<0
YL;;102T`ld408b__0@0Sk2k102A/K/409Bb^P<0U[:h102I];X409bg_0@0WkNj102N];D409j`[`<0
U::S102GXj@409VTY0@0VjBS102NYZH40:2VY@@0XZJU0`2RX9h40::NW0@0XYVF102QUi<409^=R0@0
TH9n0`27M704089[I@@0P6AN101oHET4081OEP@0Oea@101lEdX307YA@`@0N4`m101eC3h4079<?`@0
LDm3101cDdT307EHC`@0MeeD101iHUX407aWH0@0OVaV1021LF`308=fL@@0QW]g1028P7d408^5PaH0
oooo000D0?ooo`@0Shj=102@TI4409:DU@<0TiNH102EVi`409JNX0@0V:6T102IYJP409ZX[0<0W:^`
102M[k@409nb^0@0XKJl102R^L440:Bma@@0YL390`2U`//40:C3c@@0S:nl102?/;/4096a^`@0U;:j
0`2F/[P409Vd^P@0W;Nl102O]kX409jd]@@0W[2_0`2DXZ<409NSY0@0VJBT102KY:<409jVYP@0X:JU
102RYZD30::PWP@0XYjL102RVIH40:6GT`@0Vhf8102APWh308MdL0@0PV]U1020I5h407mQF@@0P5mF
101oG50407aGBP<0NU53101hC3d407E<?P@0LT`o101aCd<407=CB@<0MEQ?101gGE@407URFP@0O6MP
101nK6H4085aK0<0PgIa1026NgL408R0O@@0RhF35P3oool001@0oooo102?SXd4092AT@@0TYBE0`2C
UiP409FKW0@0UYjP102HXJ@409VUZ0@0VZR/0`2LZk0409f_]0@0Wk:h102Q][`40::i`@@0Y;g5102U
`<T30:G2b`@0Y<?=102<[k`408n`^`@0TK6k102D/[X309Jb^0@0VKBj102L]k`409ng^P@0W[Be102N
/:l309BRX`@0Uj>T102IY:@409^TX`@0WZJV102PYZD40::VY@<0XZ2N102RWY`40::IUP@0XINC102K
SHP40962OP<0QgA`1022JfD4081TGP@0Of5I1020GeH407mLD0@0O5M:0`1jDD<407Q<?@@0MD`n101b
C3l4075?@`@0Le=90`1eF4l407MME0@0NF9J101lIf0407i/IP@0PG5/0`23MW4408IkM`@0R81m102;
QH<F0?ooo`00503oool408n>S@@0T96A102BU9D309>GV0@0UI^L102FWZ0409RQY0@0VJFX102JZ:`3
09b[/0@0WJnd102O/[P40:6f_0@0X[W1102T_LD40:G0b@<0YL;;102T`ld408b__0@0Sk2k102A/K/4
09Bb^P<0U[:h102I];X409bg_0@0WkNj102N];D409j`[`<0U::S102GXj@409VTY0@0VjBS102NYZH4
0:2VY@@0XZJU0`2RX9h40::NW0@0XYVF102QUi<409^=R0@0TH9n0`27M704089[I@@0P6AN101oHET4
081OEP@0Oea@101lEdX307YA@`@0N4`m101eC3h4079<?`@0LDm3101cDdT307EHC`@0MeeD101iHUX4
07aWH0@0OVaV1021LF`308=fL@@0QW]g1028P7d408^5PaH0oooo000D0?ooo`@0Shj=102ATI4409:E
U@<0U9RI102EW9h409NOXP@0V:>V102JYZX409^Z[P<0WJfb102N/KL40:2d^`@0X[S0102T_<@40:O1
bP@0ZlK?0`2T`l`409VjaP@0Rjjj102?/;/409:b^`@0UK:j0`2G/kT409Ze^`@0WKRm102N]KP409fa
/`@0W:f^0`2FYZH409RUYP@0VjJV102LYJD409nXY`@0XJNV102SYjD30::RW`@0XYjK102QUi@40:2F
TP@0W8j8102GQX4308]iM0@0P6UT101nHed407mQF0@0P61F1020GE4407iHB`<0Ne94101iCCh407E:
>`@0LDXk101^BSh4071?A@<0LeE;101eFU4407QPE`@0NVEN101mJV@4081`JP<0PWE`1025NWH408R0
O0@0RXF25P3oool001@0oooo102?SXd4096AT@@0TYFE0`2DV9T409FLWP@0UinR102HXjH409ZVZP@0
VjZ^0`2M[K8409ja]`@0X;Bk102R^<040:Bla0@0Yl7:102[a/l30:C3c0@0VK[6102;[[X408n`^`@0
T[:k102E/[X309Nc^@@0V[Fk102M^;d409je^0@0WK6c102L[Jh309JVYP@0V:FV102KYZH409bUY@@0
WjRW102QYjH40:>WY@<0XZ:O102RWY/40:6GU0@0X9JB102LSXP409N6P@<0RgUd1020JF@407iSG@@0
Of5H1020H5H4081MD@@0OUQ;0`1kDT@407U=?P@0MDXk101aBS/406i:?P@0L4m50`1cED/407EJD@@0
N61G101jIEh407eZI0@0P71Z0`22MG0408EjMP@0R81l102:QH8F0?ooo`00503oool408n>S@@0TI6A
102BUID309BHV@@0UIbN102GWj8409RSYP@0VZJZ102KZZh309f]/P@0W[6g102P];/40::h`0@0Y;c4
102W`LX40:_6c`<0Y<?<102I^/H408^^^P@0Sk2k102B/[/409Fb^P<0Uk>i102J]K/409fh_@@0W[Fh
102M/K<409b][P<0UZJV102HYJH409^VYP@0W:FU102OZ:L40:6WYP@0XjNU0`2RXYl40::NV`@0XIND
102PUY8409b>R0@0UhJ10`2;NG@4081YI0@0OV=M101oHEP4081PEP@0P5eA101nF4/307]BA0@0NDdn
101eBS/4075:>`@0KTXn101`CdD307=EB`@0MEYA101hH5L407YUGP@0OFYT1020L6X3089eL0@0QGYf
1028P7`408Z5PQH0oooo000D0?ooo`@0Shj=102ATY8409>FUP<0U9VK102FWIl409RQX`@0VJBW102K
Z:`409b[/0<0WZne102O/kT40:6g_P@0Xk_2102U_lL40:[5cP@0[l_E0`2Q`</408fa_@@0SJnk102@
/K/409>c^`@0UK:j0`2G/kX409Ze^`@0WKNl102M/kL409Z/[P@0VZZ/0`2IZJT409^XZ0@0W:NX102N
Z:P40:2YZ@@0XZVX102SYjD30:>SX@@0XijK102QV9D409jET0@0W8j8102GQX03091lMP@0PV]V101n
HU`407mQF0@0PF5G1021GU8407mIC0<0O5A6101jCd0407Q<?0@0K4@f101[ASX406e;@0<0L597101c
Edh407IME@@0NF=K101lJF8407i^J0<0PGA_1024NGD408MoO0@0RXF25P3oool001@0oooo102?SXd4
096BTP@0TiJF0`2DVI/409JMW`@0V:6S102IY:L409^X[0@0W:^`0`2N[kD409nc^@@0XKNn102S^l84
0:Foa`@0Z/G>102_bmD30:70b`@0SK6m102=[k/4092a^`@0Tk>k102E/[X309Nc^P@0V[Fk102M]k`4
09fc]`@0VZb^102JZZ`309VYZ@@0VjRX102LYjP409jXZ0@0X:VY102RZJP40:>WY@<0Xj>Q102SWY/4
0:6HU@@0WYF@102LSXP409N6P0<0T7af1022JfH407iRG0@0Of5H1021HEL4085NDP@0OeU<0`1lE4H4
07Y?@0@0N4`l101/A3H406]6>P@0KD]00`1`DTL407=GCP@0MUeE101iHe/407aYHP@0OViX0`21M6l4
08AiM@@0Qgml102:QH8F0?ooo`00503oool408n>S@@0TI:B102CUYH309BIV`@0UYfO102HXJ<409VT
Y`@0VjR/102LZk0309j_]@@0Wk>i102Q]kh40:>k`P@0YKo7102ZaLh40:o;e@<0XL3;102=/Kd408f_
^`@0T;6k102C/k/409Fb^P<0Uk>j102J]K/409fg_0@0WK>g102J[:h409ZZ[0<0VJVY102KZ:P409bW
Z0@0WZRX102PZJT40::YZ0@0XjNU0`2SXj440:>NV`@0XIRE102NUI0409b>R0@0UhJ00`2@O7H4089[
IP@0OV9L101oHEP4085QE`@0PEiB101oFD`307aDAP@0NTm0101hC3`406a4=P@0JdHj101]Bd03071B
A`@0LeM>101fGED407USF`@0O6UR101nKVP3085dK`@0Q7Ue1027Og`408Z5PQH0oooo000D0?ooo`@0
Shj=102ATY8409>FUP<0U9VK102FWIl409RQX`@0VJBW102KZ:`409b[/0<0WZne102O/kT40:6g_P@0
Xk_2102U_lL40:[5cP@0[l_E0`2Q`</408fa_@@0SJnk102@/K/409>c^`@0UK:j0`2G/kX409Ze^`@0
WKNl102M/kL409Z/[P@0VZZ/0`2IZJT409^XZ0@0W:NX102NZ:P40:2YZ@@0XZVX102SYjD30:>SX@@0
XijK102QV9D409jET0@0W8j8102GQX03091lMP@0PV]V101nHU`407mQF0@0PF5G1021GU8407mIC0<0
O5A6101jCd0407Q<?0@0K4@f101[ASX406e;@0<0L597101cEdh407IME@@0NF=K101lJF8407i^J0<0
PGA_1024NGD408MoO0@0RXF25P3oool001@0oooo102?SXd4096BTP@0TiJG0`2EVY`409NNX0@0V::U
102JYZT409bZ[P@0WJfc0`2O/KL40:2e_0@0XKS0102S_<D40:G1bP@0ZLK?102Zb=<309fnb@@0T;:n
102A/[d409:b_0@0U;:j102F/[X309Rb^P@0V[Fk102M][/409fc]`@0VJ^]102IZJ/309ZYZP@0VjVY
102MZ:T409nYZ@@0XJZZ102SZZT40:BWYP<0Y:BR102SWi`40:6JUP@0WIF?102JSHP409J5O`<0Sgae
1027L6T4081UG`@0P69I1021HEL4089OD`@0P5Y>0`1mEDL407aA@P@0O4hn101W?c4406Q2=P@0JTPl
0`1^CT@4075EB`@0M5]B101gHET407YWH0@0OFeW0`21Lfh408AiM0@0Qgik102:Q88F0?ooo`00503o
ool408n>S@@0TI:B102CUYL309FJW0@0UijP102HXZD409ZVZ@@0W:Z^102M[K<309na]`@0X;Fl102Q
^<040:>la@@0YL7:102Ya/l40:[8d`<0WKk9102@/[h4096b_@@0T[:l102D/[X409Jb^P<0V;:j102J
]K/409ff^`@0WK>g102IZjd409VYZ`<0VZVZ102KZJT409fXZ@@0WjVY102QZZX40:>ZZ@@0Y:NV0`2T
Y:840:>OW0@0XIZF102MUHl409Z=R0@0UXEo0`2?O7D408M`J@@0P6EO1020HUT4085QE`@0PUmC1020
FTh307eEA`@0O552101lCSh406Lo<@@0J48f101ZB3`306i>A0@0LEE;101dFe8407MQF@@0NVMP101m
KFL3085cKP@0Q7Ud1027OW/408Z4PQH0oooo000D0?ooo`@0Shj=102ATY8409>FU`<0UIZL102GWZ04
09RRY@@0VZJY102LZZh409f]/`<0Wk6g102P]K`40:6h`0@0Xkc5102U`LX40:W6c`@0Z/SC0`2M_/T4
092b_P@0TK:m102B/[`409Bb^P@0U[:j0`2H/[X409Ze^`@0WKJk102M/kL409V[[@@0VJV[0`2JZJX4
09^YZ@@0WJRY102OZJT40:6ZZP@0XjZY102TYjH30:BTXP@0XinL102QVYH409fES`@0VXf8102FQGl3
08mlM@@0Qg1Y1020IEl4081RF@@0PF5G1022Ge<4081JCP<0OEE7101lDD8407a>?P@0Icla101X@SH4
06Y8?0<0KTi4101aED/407AKDP@0Mf5I101jIf0407e]I`<0PG=^1024NG@408MnN`@0RXB25P3oool0
01@0oooo102?SXd4096BTP@0TiJG0`2EVY`409NNX0@0V::U102JYZT409bZ[P@0WJfc0`2O/KL40:2e
_0@0XKS0102S_<D40:G1bP@0ZLK?102Zb=<309fnb@@0T;:n102A/[d409:b_0@0U;:j102F/[X309Rb
^P@0V[Fk102M][/409fc]`@0VJ^]102IZJ/309ZYZP@0VjVY102MZ:T409nYZ@@0XJZZ102SZZT40:BW
YP<0Y:BR102SWi`40:6JUP@0WIF?102JSHP409J5O`<0Sgae1027L6T4081UG`@0P69I1021HEL4089O
D`@0P5Y>0`1mEDL407aA@P@0O4hn101W?c4406Q2=P@0JTPl0`1^CT@4075EB`@0M5]B101gHET407YW
H0@0OFeW0`21Lfh408AiM0@0Qgik102:Q88F0?ooo`00503oool408n>SP@0TI>C102DUiP309JKW@@0
UinR102IXjL409^WZ`@0WJ^`102N[kD309nc^@@0XKNn102R^/840:>na`@0Y<7;102UaLl40:;2cP<0
WKg8102F]/4409>c_@@0Tk:k102E/[X409Jb^P<0V;:i102J];X409be^`@0W;>g102J[K0409VXZP<0
VZRY102LZJT409jYZP@0X:ZZ102RZj/40:B[ZP@0YJRW0`2UY:840:BPW0@0XYZF102MThl409V<QP@0
U8Am0`2>Ng@408UbJ`@0PfUR1022IE/4089SF@@0Pf1D1021Fdl307mFB0@0OU93101mCch406Dm;`@0
I3lb101XACT306];@@@0Ke98101bF4l407IOE`@0NFEN101lJfD3081aK0@0PgQc1026OWX408Z4PAH0
oooo000D0?ooo`@0Shj>102ATi<409BGV0<0UY^M102GWj8409VSY`@0VjN[102MZk0409j_]@<0Wk>i
102Q]kh40::j`P@0Xkk7102T`L/40:G5c`@0X/;>0`2M_LP409Jf`@@0Tk>m102C/[/409Fb^P@0U[:j
0`2H/[T409Zd^P@0W;Fk102L/kL409Z]/0@0VJRZ0`2JZ:T409bYZ@@0WZVZ102PZZX40::[Z`@0Y:^Z
102UZ:L30:FTXP@0Y:2L102RVYH409fCS`@0VHb6102DQ7d308ikM0@0RG9[1023JF84089UF`@0PV=I
1023H5@4085KC`<0OeI8101nDT<407e??P@0ICd_101T?c8406Q5>@<0Jd]1101_DTP4079HC`@0MUmG
101iIEh407a[I@<0P75/1023N7<408InNP@0RXB15P3oool001@0oooo102?SXh4096CT`@0U9NH0`2F
Vid409NOXP@0VJ>W102KYj/409f[/0@0WZne0`2O/kT40:6g_P@0X[[2102S_/L40:C1b`@0YLG?102R
`/h309fmb0@0U[K1102C/kd409>b^`@0UK:j102F/[X309Rb^@@0V[Bj102L]K/409bc]`@0VZf`102I
Z:X309ZXZ@@0W:VY102NZJX40:2ZZP@0XZ^[102TZjX40:FXY`<0YJBR102TX9`40::JUP@0WI>?102I
S8H409B4O@<0SW]d1029LV/408=YHP@0PVEK1022HeT408=PE0@0PE]?0`1oETP407iB@`@0ODln101U
?Bl406@o<P@0J4Di0`1[Bd4406mBB0@0LUQ?101fGeL407UUGP@0O6]U0`20LF`408=hL`@0QWij102:
Q84F0?ooo`00503oool408n>SP@0TI>C102DUiP309JKW@@0UinR102IXjL409^WZ`@0WJ^`102N[kD3
09nc^@@0XKNn102R^/840:>na`@0Y<7;102UaLl40:;2cP<0WKg8102F]/4409>c_@@0Tk:k102E/[X4
09Jb^P<0V;:i102J];X409be^`@0W;>g102J[K0409VXZP<0VZRY102LZJT409jYZP@0X:ZZ102RZj/4
0:B[ZP@0YJRW0`2UY:840:BPW0@0XYZF102MThl409V<QP@0U8Am0`2>Ng@408UbJ`@0PfUR1022IE/4
089SF@@0Pf1D1021Fdl307mFB0@0OU93101mCch406Dm;`@0I3lb101XACT306];@@@0Ke98101bF4l4
07IOE`@0NFEN101lJfD3081aK0@0PgQc1026OWX408Z4PAH0oooo000D0?ooo`@0Shn>102BTi<409BH
V@<0UYbN102HXJ<409ZUZ0@0W:V]102N[K8409na]`<0X;Fl102Q^L040::la@@0Xko9102S`/d40:;3
d0@0X<3<0`2L^lH409Rf`0@0U;>m102D/KX409Fa^@@0U[6i0`2H/[T409Zc^P@0VkFj102L/kL409b_
/P@0VZV[0`2JYjP409bXZ@@0WjZ[102QZZX40:>[Z`@0YJb[102VZJP30:JUX`@0Y9nL102QVYH409bB
SP@0Uh^5102BPWd308ikM0@0RG=[1025Jf8408AXGP@0Q6EJ1024HED4089LC`<0P5M9101oE4@4081A
@0@0Hc`]101Q?2l406E2=P<0JDPm101/CdD4071FC@@0M5eE101hHe`407]ZI0<0Og1[1022Mg8408Im
NP@0RXB15P3oool001@0oooo102?Shh409:CT`@0U9RI0`2FW9h409RQX`@0VZFX102LZJd409j]/P@0
Wk6g0`2P]K`40:6i`0@0X[c5102S_lT40:?2c@@0X/?@102P`<`309bkaP@0V;K0102D/kd409Ba^P@0
UK6i102F/KT309Rb^@@0V[>j102K]KX409bc]`@0W:nb102JZJ/309ZWZ0@0W:RY102OZZ/40:6ZZP@0
Xj^[102U[:/40:JYZ0<0YZFS102TWi`40:6JUP@0W9:>102GRhD409:2O@<0SW]d1029Lf/408E[HP@0
Q6QN1024IEX408AQE@@0PUa?0`20EdT407mDA0@0P550101S?2d4064l;`@0ID8f0`1YB3d406a?A@@0
L5I=101dGED407QSG0@0NfYT0`1oL6/4089gLP@0QWej102:Q84F0?ooo`00503oool408n?SP@0TY>C
102DV9T309JLWP@0V:6S102JYJP409bY[@@0WZfb102O/KL30:2e_0@0XKW0102R_<D40:>ob@@0Xl;=
102R`m040:30c0<0W;_6102H]/0409Bc_@@0U;6j102E/KT409Ja^@<0V;:i102J/kX409^e^P@0W;>g
102L[k8409ZYZ`<0VZNX102LZ:T409nZZ`@0XJZZ102SZj/40:F/Z`@0YZVX0`2VYJ<40:BOW0@0XIZF
102LTXh409N;Q@@0TX9m0`2>Ng@408UcJ`@0QF]R1024J5h408AUFP@0Q65E1022G4l3081GB@@0OeA4
1020DD0406<l;@@0HC`_101U@SH306U8?@@0K4m5101`ETd407AME@@0N6=L101kJV@307m`J`@0PWMb
1026OGX408Z4PAH0oooo000D0?ooo`@0Shn>102BTi<409BHV@<0UYbN102HXJ<409ZUZ0@0W:V]102N
[K8409na]`<0X;Fl102Q^L040::la@@0Xko9102S`/d40:;3d0@0X<3<0`2L^lH409Rf`0@0U;>m102D
/KX409Fa^@@0U[6i0`2H/[T409Zc^P@0VkFj102L/kL409b_/P@0VZV[0`2JYjP409bXZ@@0WjZ[102Q
ZZX40:>[Z`@0YJb[102VZJP30:JUX`@0Y9nL102QVYH409bBSP@0Uh^5102BPWd308ikM0@0RG=[1025
Jf8408AXGP@0Q6EJ1024HED4089LC`<0P5M9101oE4@4081A@0@0Hc`]101Q?2l406E2=P<0JDPm101/
CdD4071FC@@0M5eE101hHe`407]ZI0<0Og1[1022Mg8408ImNP@0RXB15P3oool001@0oooo102@Shh4
09:DU0@0UIVI0`2GWIl409VRY0@0VjNZ102MZjl409n_]0@0X;>i0`2R]kh40::k``@0Xkk7102S`L`4
0:?4d0@0XL?>102O`</309^ja0@0UkBm102D/[/409B_^0@0UJnh102G/KP309Rb^0@0VK>i102K];T4
09bb]`@0W;2c102KZjd309^WZ0@0WJRY102OZj/40:6ZZ`@0Xj^[102V[J`40:NZZ0<0YZJS102TWi`4
0:6JUP@0W96=102GRH@40961N`<0SG]c102:Lf`408M]I0@0QVYP1025IU`408AREP@0PUe@0`20F4X4
07mDA@@0PE=2101W?c0405dh:P@0HShb0`1VACX406Y=@P@0KeA;101cFe<407IRFP@0NVUR0`1nKfX4
089fLP@0QWei1029Ph4F0?ooo`00503oool4092?SP@0TYBD102EVIT309NMW`@0VJ:T102KYjX409f[
[`@0Wjnd102P/kT30::g_P@0X[_3102S_/L40:?1c0@0XlC@102Q`lh409o0b`<0Vk[4102G];d409Bb
^`@0U:nh102E[kP409Na^0<0V;:h102I/kT409^d^@@0W;:g102L/;<409^[[@<0VjNX102MZ:T409n[
Z`@0XJZ[102SZj/40:J][0@0YjZX0`2VYZ<40:BOW0@0XIZF102LTHd409N9Q0@0TH5k0`2=Ng<408Yc
K0@0QfeT1026JV0408EVG0@0Q69F1022GE03081HBP@0OeA51021Dd8406Lo<0@0GCPZ101R?S8306I5
>P@0JTe2101_E4/407=KD`@0MV9J101jJF8307i_JP@0PWIb1026OGT408V3PAH0oooo000D0?ooo`@0
T8n>102BU9@409FIV@<0UifO102IXZ@409^WZP@0WJ^_102O[k@40:2c^@<0X[Nn102R^l<40:>na`@0
Xl7<102Sa=040:73cP@0Wl3;0`2K^/@409Nd_@@0U;:k102D[kP409F_^0@0Uk6h0`2H/[P409Vc^@@0
VkBi102L/[L409b`/`@0Vj^]0`2KYjP409fXZ@@0Wj^[102QZZ/40:>[Z`@0YZf/102WZZP30:JVX`@0
Y9nL102QVYH409bAS@@0UhV4102APG/308ekL`@0RW=/1027KF@408IZH0@0QFIL1024HUH4089MD0<0
P5Q:101oE4D4085C@P@0Icl`101M>2X4068n<P<0ITDj101ZCD8406mDB`@0Le]C101fHUX407YYHP<0
OVmZ1022MW8408ImN@@0RH>15P3oool001@0oooo102@Shh409:DU0@0UIVI0`2GWIl409VRY0@0VjNZ
102MZjl409n_]0@0X;>i0`2R]kh40::k``@0Xkk7102S`L`40:?4d0@0XL?>102O`</309^ja0@0UkBm
102D/[/409B_^0@0UJnh102G/KP309Rb^0@0VK>i102K];T409bb]`@0W;2c102KZjd309^WZ0@0WJRY
102OZj/40:6ZZ`@0Xj^[102V[J`40:NZZ0<0YZJS102TWi`40:6JUP@0W96=102GRH@40961N`<0SG]c
102:Lf`408M]I0@0QVYP1025IU`408AREP@0PUe@0`20F4X407mDA@@0PE=2101W?c0405dh:P@0HShb
0`1VACX406Y=@P@0KeA;101cFe<407IRFP@0NVUR0`1nKfX4089fLP@0QWei1029Ph4F0?ooo`00503o
ool4092?SP@0TiBD102EVYX309ROX0@0Vj>V102MZ:`409n]/@@0XK6g102R][`30:>j`@@0Y;g6102T
`LX40:C4cP@0XlKB102Q`/h409nobP<0VKK0102E/[/409B`^@@0U:jg102E[kL409J`]`<0V;6h102I
/[P409Zb^0@0Vk6g102M/;@409^/[P<0VjNY102MZ:T409nZZ`@0XZ^[102T[:`40:N][0@0Z:^Y0`2V
YJ<40:BOW0@0X9VE102KTH`409J9P`@0T81j0`2<NW8408YdK0@0RG1W1028K68408IXG@@0Q6=G1022
GU4307mHB`@0OEA5101mDD8406i4=@@0H3PZ101M>2`306A2=`@0JDY0101]DTP4075ID@@0MF1I101i
If4307e^J@@0PGEa1025O7T408V3PAH0oooo000D0?ooo`@0T8n>102CU9@409FJVP<0V9nP102KXjH4
09fX[0@0Wjfa102Q/KL40::f_0<0Xk[1102T_LH40:C1bP@0Y<C>102Sa]840:72cP@0Wko:0`2I]/04
09Fb^`@0U;2i102D[[L409F_]`@0U[2g0`2H/KP409Vb^0@0V[:h102K/KL409f`]0@0Vjb^0`2KYjT4
09fXZ@@0WjZ[102RZj/40:B/[0@0Yjf/102XZjT30:JUX`@0Y9nL102PVID409^AS0@0UXV3102@P7X3
08ajLP@0RWA/1029L6L408Q/HP@0QVQM1024HeL4089ND@<0OeQ;101mE4D407eA@P@0KT@e101P>2X4
05dh;0<0I48g101YBT0406eBB0@0LEUA101eH5T407UWH@<0OFiY1021MG4408ElN@@0RH>15P3oool0
01@0oooo102@Shh409>DU0@0UIZJ0`2HWj0409^SYP@0WJR/102O[K440:6a]`@0X[Jl0`2S^/440:Bm
aP@0Y<7:102Ta<h40:?6dP@0XL;>102O_lX309Vf`0@0UK:k102D/;T409B^]`@0UJng102F/;L309Ra
^0@0VK:h102J/[P409^a]`@0WK2d102K[:h309^WZ@@0WJRY102OZZ/40::[Z`@0Y:b/102W[J`40:R[
Z@<0YZFS102TWi`40:2IU@@0Vi6<102FRH<40920NP<0S7Yb102:M6`408U`I`@0R6aR1026J5d408AS
E`@0PUiA0`1oF4/407eDA@@0OE52101^A3D4060h:P@0GCP/0`1T@SL406U:@0@0KE98101aFE4407EP
F@@0NFMQ0`1mKVT4085eL@@0QGai1029Ph4F0?ooo`00503oool4092@S`@0TiFE102FVi/309VPXP@0
W:FX102NZZh40:6_]0@0X[Bi102T^;l30:Fla0@0Y/39102Va<h40:G7dP@0Y<OC102Q`/h409fjaP<0
U[6k102C[kT409>^]`@0U:jf102E[[H409J_]P<0V;2g102I/KL409Za]`@0Vk2f102L[k<409^[[P<0
VjRZ102MZJX40:2[Z`@0XZ^[102U[J`40:R][0@0ZJ^Y0`2WYJ840:BOV`@0WiRD102KT8/409F8PP@0
T7mi0`2<NW8408]eK@@0RW9Y1029KV<408IYGP@0Q6AH1021GU4307eHB`@0NU94101gCT0406m5=P@0
I3X[101M>2/306=1=@@0J4Tn101/D4H4071GC`@0M5mG101hIUl307a]J0@0P7A`1025O7P408V3P1H0
oooo000D0?ooo`@0T92?102CUID409JKV`<0VJ2R102LYJP409jZ[P@0XJnd102R];T40:Bh_`<0YKc4
102V`<T40:K4cP@0YLOB102Tam<40:72cP@0WK[60`2F/K/409>_^@@0Tjjg102D[[H409F^]P@0UZnf
0`2H/;L409Va]`@0V[6g102K/;H409b_/`@0Vj^^0`2KZ:X409fYZP@0X:^[102RZj/40:F][0@0Z:f/
102YZjT30:NUXP@0Y9nK102OV9@409^@R`@0UHR2102@OgT308ajLP@0RgE]102:LVT408U^H`@0QVUN
1024I5P4085ND@<0OEQ;101jDT@407M>@0@0KdDf101T>R/405dh:`<0Hd4e101XBCh406a@AP@0L5M?
101dGeL407QVG`<0O6eX1020M70408ElN0@0RH>05P3oool001@0oooo102@T8l409>EU@@0UY^K0`2I
X:8409bUZ0@0WZZ^102Q[k@40::d^@@0Y;Ro0`2U_<@40:K0b@@0Y/C>102Uam840:C7d`@0XL;>102M
^/H309Ja^`@0Tjni102C[[L409B^]P@0UJjf102F[kH309R`]`@0VK6g102J/KL409^`]P@0W:nc102K
Zjh309^XZP@0WJVZ102PZj/40::[Z`@0YJf/102X[J`40:V[Z@<0YjFR102TWi/409nHU0@0Vi2;102E
R884091oN@<0S7Yb102;MFd408YbJ@@0RFiS1026JEh408ATF0@0PEiA0`1mF4/407YBA0@0Mdi0101_
ACH406@j:`@0GCP[0`1S@CD406Q9?P@0K516101`Edl407AOE`@0N6IO0`1lKFP4081dL0@0QGah1029
Ph0F0?ooo`00503oool4092@S`@0TiFE102FVi/309VPXP@0W:FX102NZZh40:6_]0@0X[Bi102T^;l3
0:Fla0@0Y/39102Va<h40:G7dP@0Y<OC102Q`/h409fjaP<0U[6k102C[kT409>^]`@0U:jf102E[[H4
09J_]P<0V;2g102I/KL409Za]`@0Vk2f102L[k<409^[[P<0VjRZ102MZJX40:2[Z`@0XZ^[102U[J`4
0:R][0@0ZJ^Y0`2WYJ840:BOV`@0WiRD102KT8/409F8PP@0T7mi0`2<NW8408]eK@@0RW9Y1029KV<4
08IYGP@0Q6AH1021GU4307eHB`@0NU94101gCT0406m5=P@0I3X[101M>2/306=1=@@0J4Tn101/D4H4
071GC`@0M5mG101hIUl307a]J0@0P7A`1025O7P408V3P1H0oooo000D0?ooo`@0TI2?102DUYH409NL
W0<0Vj6S102NYjX40:2//0@0Xk6f102U][`40:Jk`P<0Yko7102Xa<d40:S7d@@0Yl[F102Ub=@40:71
c0@0V[G00`2C[[P4096]]`@0TZff102C[KH409F^]P@0UZnf0`2G/;L409V`]`@0V[2f102K[kD409Z]
/@@0VjZ]0`2KZ:X409fYZP@0X:^[102RZj/40:F^[@@0ZJf/102YZjT30:NUXP@0Y9jK102OUY<409Z?
RP@0U8N0102@OgT308ejL`@0RgI^102;LfX408U_I@@0QVYO1023I5P4081NDP<0O5Q;101gDD<407==
?P@0K4<d101S>2T4068k;@<0I40d101WAc`406]>A@@0KeI=101cGEH407MUGP<0NfaW1020M6l408Ak
N0@0RH>05P3oool001@0oooo102AT8l409BFUP@0UibL0`2KXJ<409jWZP@0X:b`102S/KH40:Ff_0@0
Y[_20`2W_lL40:S4c@@0Z<OA102Wb]H40:G8e0@0XL7<102J]L0309>^^0@0TJfg102B[KH409>]]P@0
UJjf102F[kH309N`]`@0VK2g102J/;H409^_]@@0VZfa102KZZd309^XZP@0WJVZ102PZj/40::[Z`@0
YJj]102Y[J`40:V[Z@<0YjFR102TWY/409nFT`@0VXn:102DQh04091oN@<0SGYc102;MVh408]cJP@0
RFmU1026JUl408=TF0@0P5iB0`1lF4/407MA@`@0Lddn101/@c@406<h:@@0HS/]0`1T@3@406M7?0@0
Jdi5101_ETd407=MEP@0MfEN0`1kK6L4081dK`@0Q7]h1029Ph0F0?ooo`00503oool4096@S`@0U9JF
102GW9`309^QX`@0WZNZ102P[;040:>a]P@0YKJl102V^l830:Noa`@0Z<C=102Xam440:O:eP@0YLSD
102Q`L`409Ze`0<0Tjjh102A[KL409:]]P@0Tjff102E[[H409J_]P<0Uk2g102I/;L409Z`]P@0Vjne
102J[K4409^Z[@<0VjRZ102MZJX40:2[Z`@0XZ^[102U[Zd40:V][0@0ZJ^Y0`2WYJ840:BNV`@0WiJC
102JShX409B7P0@0T7mi0`2=NW<408]fKP@0Rg=Z1029KfD408IZG`@0PfAH1020GU8307aHB`@0Me53
101cCCh406a3=0@0HcPY101R>bd306A0=0@0IdLl101[CTD406mFC@@0LeeF101gIEh307]/I`@0P7A_
1024NgP408V3P1H0oooo000D0?ooo`@0TI2?102DUYH409NLW0<0Vj6S102NYjX40:2//0@0Xk6f102U
][`40:Jk`P<0Yko7102Xa<d40:S7d@@0Yl[F102Ub=@40:71c0@0V[G00`2C[[P4096]]`@0TZff102C
[KH409F^]P@0UZnf0`2G/;L409V`]`@0V[2f102K[kD409Z]/@@0VjZ]0`2KZ:X409fYZP@0X:^[102R
Zj/40:F^[@@0ZJf/102YZjT30:NUXP@0Y9jK102OUY<409Z?RP@0U8N0102@OgT308ejL`@0RgI^102;
LfX408U_I@@0QVYO1023I5P4081NDP<0O5Q;101gDD<407==?P@0K4<d101S>2T4068k;@<0I40d101W
Ac`406]>A@@0KeI=101cGEH407MUGP<0NfaW1020M6l408AkN0@0RH>05P3oool001@0oooo102AT904
09FGU`@0VIfN0`2LXjD409nYZ`@0XZjb102U];T40:Ni_`@0ZKk50`2Z`l/40:_7d@@0Zl_F102Yc=L4
0:K8d`@0Wkk9102F/K`3092[]P@0Sj^d102AZk@409:]]@@0U:jf102F[kH309R`]`@0V;2f102I/;D4
09Z^/`@0VJ^`102JZ:`309ZWZ@@0W:RY102OZZX40::[Z`@0YZj]102Z[Zd40:Z[Z0<0Z:FR102TWYX4
09nFT@@0VHj9102DQX040920N@<0SW]d102=N6l408]dJ`@0RW1U1026Jf0408=UF@@0OeiB0`1kEd/4
07E@@P@0LD`n101Z@S<406<i:@@0HCT/0`1S?c8406I5>P@0JDe3101]E4/4075LE0@0MV=M0`1jJfH4
07mcKP@0Q7]g1028PX0F0?ooo`00503oool4096@T0@0UING102IWIh309bSY@@0WjV[102R[[840:Fd
^@@0YkVo102Y_/D30:[3b`@0ZlOA102[bmH40:W<e`@0Y/SC102O_/T409Ja_0<0T:^f102?Zk@4096[
]0@0TZfe102D[[H409J_]P<0V;2g102H/;H409V`]@@0VZjc102IZk0409ZX[0<0VZNY102LZ:T409nZ
ZP@0XZ^[102V[Zd40:Z^[@@0ZZ^X0`2XYJ840:BNVP@0WiJA102ISXT409B6P0@0T81i0`2>Ng@408eh
K`@0RgA[102:L6D408I[H0@0PfEI101oGU8307]GB`@0ME12101aC3h406Y2<`@0HcTY101Q>B`306<o
<P@0ITDj101YCD<406eDB`@0LEaD101fHed307Y[IP@0Og=^1024NgL408R2P1H0oooo000D0?ooo`@0
TI2@102EUiL409VMWP<0W:>U102OZJ/40::^/P@0YKBi102W^Kl40:Vna@<0Z/?;102[am440:_;eP@0
ZLcG102Vb=<409nnb@@0U[6l0`2@ZkH408n[]0@0TJ^d102B[KD409B^]P@0UZnf0`2H/;L409R`]P@0
VK2e102J[[<409V[/0@0VZR/0`2JYjT409bXZ@@0WjZZ102RZj/40:J^[@@0ZZj]102ZZjP30:RUXP@0
Y9jJ102OUY4409V>R@@0U8J0102@P7T308ikM0@0SGQ_102;M6/408Y`I@@0QV]P1023IET407mNDP<0
NeM;101eD484075<?P@0JT8c101S>BT4064i;0<0Hclb101VACX406U=@`@0KEA;101aG5@407ISG@<0
NV]V101oLfh408AkM`@0R8:05P3oool001@0oooo102AT90409FGU`@0VIfN0`2LXjD409nYZ`@0XZjb
102U];T40:Ni_`@0ZKk50`2Z`l/40:_7d@@0Zl_F102Yc=L40:K8d`@0Wkk9102F/K`3092[]P@0Sj^d
102AZk@409:]]@@0U:jf102F[kH309R`]`@0V;2f102I/;D409Z^/`@0VJ^`102JZ:`309ZWZ@@0W:RY
102OZZX40::[Z`@0YZj]102Z[Zd40:Z[Z0<0Z:FR102TWYX409nFT@@0VHj9102DQX040920N@<0SW]d
102=N6l408]dJ`@0RW1U1026Jf0408=UF@@0OeiB0`1kEd/407E@@P@0LD`n101Z@S<406<i:@@0HCT/
0`1S?c8406I5>P@0JDe3101]E4/4075LE0@0MV=M0`1jJfH407mcKP@0Q7]g1028PX0F0?ooo`00503o
ool4096AT0@0UYNG102JWYl309jTYP@0XJ^]102U/KD40:Rg^`@0Z[c2102/`/T30:k7c`@0[l_E102`
d=/40:g>f0@0YlKA102K^LD408n/^0<0S:Rc102=ZK8408nZ/`@0TJbe102D[[H409J_]P<0V;2g102I
/;H409V_]0@0VJba102HZJh409RWZP<0V:FX102KYZP409jXZ@@0XZ^[102W[Zd40:Z^[@@0Zj^X0`2X
YJ840:BMV@@0WiF@102ISXP409F7P@@0TX5j0`2?OGD408ihL0@0RgE[1029L6H408I[H0@0PfEI101o
Ge8307YHB`@0M553101`C3l406U1<P@0HcX[101N=BL3064l;`@0I4<h101WBd4406]BBP@0L5YB101d
HU/307UZI0@0OW9]1023NWH408R2OaH0oooo000D0?ooo`@0TI6@102FUiL409ZNW`<0WZBV102QZjd4
0:Fa]@@0Z;Nk102Z_<840:c2b@<0[/O?102_bmD40;3@f`@0[LkH102Wa]4409^ia@@0Sjbh0`2<Z;<4
08fY/P@0SjZc102A[;D409B^]P@0UZnf0`2H/;L409V`]P@0VJnd102I[;4409RY[P@0V:NZ0`2HYJP4
09^VZ0@0WZRY102RZj/40:N^[@@0ZZj]102[ZjP30:RUXP@0Y9fI102OUI0409V>R0@0UHN1102BPGX3
08mmM@@0SWQ`102;MF/408U`IP@0QV]P1023IET407mODP<0NUQ;101dDD<4071<?`@0JD4b101S>R/4
05he9`<0HC`_101T@cP406M;@@@0Je9:101`FU8407ARF`<0NFYT101nLVd408=jMP@0R89o5P3oool0
01@0oooo102ATI0409JGU`@0VYjO0`2NY:H40:6[[@@0YK6e102X]k/40:Zl`P@0[<;90`2^all40:o;
e@@0/=3K102]c]P40:O6d@@0VkW5102?[;P308bX/`@0SJVb102?Z[<4096/]@@0U:jf102F[kH309R`
]`@0VK2f102I[k@409V//@@0V:V^102HYjX309RUZ0@0VjJX102NZ:T40::[Z`@0Yjj]102Z[Zd40:^[
Z0<0Z:FR102TWIT409nET0@0VHj8102EQh4409:1NP<0Sgee102>N70408]eJ`@0RG1V1026Jf0408=U
F@@0OemB0`1jF4/407AA@`@0L4`o101Y@C8406<j:`@0GSDW0`1Q?2l406A3>0@0Id]1101[DTX4071J
DP@0M69K0`1iJV@407ibK@@0PgYf1028PWlF0?ooo`00503oool4096AT0@0UYNG102JWYl309jTYP@0
XJ^]102U/KD40:Rg^`@0Z[c2102/`/T30:k7c`@0[l_E102`d=/40:g>f0@0YlKA102K^LD408n/^0<0
S:Rc102=ZK8408nZ/`@0TJbe102D[[H409J_]P<0V;2g102I/;H409V_]0@0VJba102HZJh409RWZP<0
V:FX102KYZP409jXZ@@0XZ^[102W[Zd40:Z^[@@0Zj^X0`2XYJ840:BMV@@0WiF@102ISXP409F7P@@0
TX5j0`2?OGD408ihL0@0RgE[1029L6H408I[H0@0PfEI101oGe8307YHB`@0M553101`C3l406U1<P@0
HcX[101N=BL3064l;`@0I4<h101WBd4406]BBP@0L5YB101dHU/307UZI0@0OW9]1023NWH408R2OaH0
oooo000D0?ooo`@0TY6@102GV9P409^OX0<0X:JX102T[K040:Rd]`@0ZkZn102^`<D40;35c0<0//_C
102cd=T40;GEh@@0]=7K102Wa<h409Ne`@@0QjJc0`27Y;0408ZV/@@0SJRb102@Zk@409B]]@@0Ujnf
0`2I/;L409V`]P@0VJnd102H[;4409JW[0@0UJBX0`2FXjH409VTY@@0WJNW102RZZX40:N^[@@0Zjj]
102/ZjP30:VUXP@0YIjI102OUI0409^>R0@0UXV2102CPW/3091nM@@0SWU`102;M6/408U`IP@0QV]P
1022IET407iOD`<0NEQ;101dDDD406m=@0@0Id4b101P>R/405/a8`<0GST/101Q@CD406E8?`@0JE18
101^F54407=QFP<0N6US101mLFd4089iMP@0R89o5P3oool001@0oooo102BTI0409NHV0@0VinP0`2P
YZP40:B]/0@0Z;Bg102[^[h40:k0a@@0/<G<0`2bbm<40;?@f@@0]MGQ102ddM/40:O4cP@0UkG11027
Y[<308NT/0@0RZJa102=Z;84092[]0@0U:fe102G[kH309V`]`@0VK2f102I[k@409R//@@0UZN/102E
Y:P309JSYP@0VJBU102MYjL40::ZZP@0Yjj]102[[Zd40:b[Z0<0ZJFR102UWYT409nET0@0Vhj8102F
RH8409>2N`<0T7ie102>NG0408]dJ`@0RG1V1026Jf04089UF@@0OUmC0`1iF4/407AAA@@0Kde0101W
@C84060j:`@0Fc4S0`1N>B`40651=@@0IDPo101YD4P406iHD@@0Lf5J0`1hJF<407eaK@@0PWUf1028
PWlF0?ooo`00503oool409:AT0@0UiRH102KWj030:2VZ0@0Y:f`102X];L40:^j_P@0[/35102`aL`3
0;;;d`@0/m3I102eeN440;CAf`@0YlC>102G]L4408NV/`<0QjB`102:Y[4408fX/P@0T:^d102D[KD4
09N_]P<0VK2g102I/;H409V_]0@0V:ba102FYj`409FTZ0<0UZ>V102IY:D409fWY`@0XZZZ102W[Zd4
0:^^[@@0[:^X0`2YYJ840:FNV@@0WiF@102KSXP409J9PP@0Th9k0`2@OWD408iiL0@0RgA[1029L6H4
08I[H0@0PVEI101nGe<307UHB`@0M555101_CD0406M1<P@0H3X[101K<B<305hi;0@0HD4e101UB3l4
06U@B0@0KUQA101cHEX307QYH`@0OG5]1022NGH408R2OaH0oooo000D0?ooo`@0TY6@102GV9P409^O
X0<0X:JX102T[K040:Rd]`@0ZkZn102^`<D40;35c0<0//_C102cd=T40;GEh@@0]=7K102Wa<h409Ne
`@@0QjJc0`27Y;0408ZV/@@0SJRb102@Zk@409B]]@@0Ujnf0`2I/;L409V`]P@0VJnd102H[;4409JW
[0@0UJBX0`2FXjH409VTY@@0WJNW102RZZX40:N^[@@0Zjj]102/ZjP30:VUXP@0YIjI102OUI0409^>
R0@0UXV2102CPW/3091nM@@0SWU`102;M6/408U`IP@0QV]P1022IET407iOD`<0NEQ;101dDDD406m=
@0@0Id4b101P>R/405/a8`<0GST/101Q@CD406E8?`@0JE18101^F54407=QFP<0N6US101mLFd4089i
MP@0R89o5P3oool001@0oooo102BTY4409RIV@@0WJ6R0`2RZ:X40:N`/P@0ZkNj102__L840;;4b@@0
]LW@0`2fcmL40;SDg@@0^MSR102hd]`40:S3c@@0UK:n1020XJl308:Q[@@0QZB_102:Y[4408nZ/`@0
U:jf102H/;L309^b^0@0Vk6f102I[k@409J[/0@0U:F[102CXZH309BPX`@0UZ6R102KY:D40:6YZ@@0
Yjf/102/[jd40:f/Z@<0ZZFR102WWYT40:6FT@@0WHn9102IRX<409B4O0<0TGif102?NW4408]dJ`@0
R71U1025Jf04089UF@@0OV1C0`1iFD`407ACAP@0L4i0101U@S@405`f:0@0EbhO0`1K=RT405hn<`@0
HdHl101WCTH406aGC`@0LEmI0`1fJ68407a`K0@0PWUe1027PGlF0?ooo`00503oool409:BT@@0V9VI
102MXJ830::XZP@0Yk2b102[]kX40:nm`P@0//C9102ebM030;K?e`@0^=CM102if>840;SBg0@0Z<?=
102E/[h4082Q[`<0PZ6]1026Y:l408ZV/@@0SjZc102D[[H409R`]`<0Vk:h102K/KH409V_]0@0UZ^`
102DYJ/409>RYP<0U:2S102FXJ8409^TY@@0XJVY102W[J`40:b_[@@0[JbY0`2ZYJ840:NNV@@0XIJA
102MShT409V:P`@0U8Al0`2AOWH408mjL@@0RgA[1028L6D408E[H0@0PVEI101nH5<307UIC0@0M5=6
101`CT0406E2=0@0G3HX101G;Ql305/f:@@0GShc101SAS`406M>AP@0K5M?101aGeT307IXHP@0O71/
1022NGD408N1OaH0oooo000D0?ooo`@0TY:A102HVIT409fQXP<0XZRZ102W/;840:^g^P@0[kg2102b
a<T40;G9d0<0]/oG102he=d40;WHhP@0^=;L102X`ld409Fb_P@0P:6_0`22XJd408JT[`@0RZJa102?
Z[<409B^]P@0V;2g0`2K/[P409^a]P@0VJnd102FZk0409BUZ`@0Tj:V0`2DX:<409JQXP@0VjBU102Q
ZJT40:N][0@0[:n]102][:T30:ZUXP@0YijI102QUY4409f?R@@0VHZ3102DQ7`3095nMP@0SgYa102;
M6/408Q`I@@0QF]P1022IET407iPD`<0NEU<101dDdH4071>@0@0ID8d101L=RP405L^7`<0FcHY101N
?S<406=6?0@0Idi6101/Edl4075OF@<0MVQR101lL6`4089iM@@0Qh5o5P3oool001@0oooo102CTY44
09VJVP@0Wj:S0`2TZZ`40:Zb]@@0[kZm102d`LD40;O8c@@0^/kD0`2kdm/40;cGh@@0_=SQ102le=`4
0:S1b`@0T:jj101iW:/307fMZ`@0PZ6]1027Y:h408fY/P@0U:je102I/KP309fc^0@0W[:g102K[k@4
09BY[`@0Sj>X102@XJD3096NX@@0TY^M102IXJ840:6WY`@0Z:f/102][jd40:j/ZP<0[:NS102YX9X4
0:>GT@@0X96;102LS8@409N6OP<0TWmg102?NW4408UcJP@0QfmU1025Jf04089VFP@0OV1C0`1iFT`4
07ADA`@0L4m1101S@C@405Lc9P@0DbXL0`1G<bL405/k<0@0H4@j101TC4@406YECP@0KeiG0`1eIV44
07]_J`@0PGQe1027PGlF0?ooo`00503oool409>BT@@0VIZJ102OXZ<30:BZ[0@0Z[:e102_^[d40;C1
a@@0]lS=102jc]@30;_Cf`@0_=OQ102lf>440;cDg0@0Z<7;102@[[X407VLZ`<0OIf[1022XJd408NT
[P@0SJVb102D[[D409Va^0<0WK>h102N/[L409^_]0@0U:V_102?XjP4092QY@<0TIjQ102BVid409VQ
XP@0XJNW102X[J`40:f_[@@0[ZbZ0`2/Yj<40:VPVP@0XiNA102PTH/409b<Q0@0UhIn0`2BOgL408mj
L@@0RG=Z1027KfD408E[H0@0PVIJ101nH5<307UJC0@0M5A7101`Cd4406=1=0@0Ec<V101C:Q`305Lc
9`@0Fc/`101PA3X406A<A0@0JUE>101_GUL307EVH@@0Nfm[1021N7D408N1OaH0oooo000D0?ooo`@0
Ti:A102IVYX409nRX`<0Y:Z/102Z/[D40:nj_@@0]<75102gb<d40;[>e0<0^m?K102len440;cHh@@0
_=CL102X`L/4092^^P@0NIb[0`1mWJ/408:Q[@@0QjB^102=ZK8409B^]@@0VK6h0`2M/kP409jb]`@0
Vjnd102DZJl408nSZ0@0T:6U0`2AWZ4409:KW@@0VJ6R102QYjL40:R][0@0[Jn]102^[:X30:bWX`@0
ZJ2J102SUi440:2AR`@0W8b4102GQWh3099oM`@0SgYa1029LfX408M_I@@0QF]P1022IUX407iPD`<0
NEY<101dE4L4071?@@@0Hd4d101G<bH405<Z70<0Ec<W101K>c040614>P@0I4a4101ZEDh406mNE`<0
MFIQ101kKf/4085hM@@0Qh5o5P3oool001@0oooo102CTY4409VJVP@0Wj:S0`2TZZ`40:Zb]@@0[kZm
102d`LD40;O8c@@0^/kD0`2kdm/40;cGh@@0_=SQ102le=`40:S1b`@0T:jj101iW:/307fMZ`@0PZ6]
1027Y:h408fY/P@0U:je102I/KP309fc^0@0W[:g102K[k@409BY[`@0Sj>X102@XJD3096NX@@0TY^M
102IXJ840:6WY`@0Z:f/102][jd40:j/ZP<0[:NS102YX9X40:>GT@@0X96;102LS8@409N6OP<0TWmg
102?NW4408UcJP@0QfmU1025Jf04089VFP@0OV1C0`1iFT`407ADA`@0L4m1101S@C@405Lc9P@0DbXL
0`1G<bL405/k<0@0H4@j101TC4@406YECP@0KeiG0`1eIV4407]_J`@0PGQe1027PGlF0?ooo`00503o
ool409BCTP@0VY^K102QY:D30:N/[P@0[KFg102c_/440;W6bP@0_/gB1031e=X30<7Hg`@0_m[S102n
eml40;kBfP@0Y[o9102;ZkL407>GY`<0NIZX101oWjX408BR[@@0RjN`102B[;<409Va]`<0W;:g102R
];P409f`]0@0TjR^102>XJH408bOY0<0SI^N102@VI/409ROX0@0X:JV102X[J`40:j`[P@0/:j[0`2_
Z:@40:fTW@@0Y9NA102SU8d40:2?QP@0VXR00`2BOgL408iiL@@0R7=Z1026KV@408AZG`@0PfIJ101n
H5<307UJC@@0MUE7101_CT0405lo<P@0DS4T101>9aX305<`9@@0EcT^101L@CP4065:@P@0Ie=<101]
G5H307=UH0@0NViZ1020N7@408N1OQH0oooo000D0?ooo`@0U9>B102JVi/40:6TY@<0Yjb^102]]KL4
0;>n`@@0^LK:102ncM840<7DfP<0`MSO102of^<40;kGg`@0_];J102V_lT408^[]`@0LiNW0`1iVZP4
07nOZP@0Q::]102;Yk0409://`@0VK6g0`2L/[L40::d^0@0WK2d102CZ:h408jQYP@0S9nT0`2=Vih4
092IV`@0V9nP102PYZH40:R][0@0[[2^102`[Z/30:nXY0@0[JBM102TUi440:>DS@@0X8n6102JR803
099oM`@0SWUa1028LfX408I^I0@0Q6YO1023IUX407iPD`<0NEY=101fEDL406m>@0@0Gclb101B<B@4
04hW6P<0Dc0U101G>Bh405a1>0@0HDY2101WDd`406eLEP<0LfEP101jKVX4081hM0@0Qh5n5P3oool0
01@0oooo102DTi8409ZKV`@0XJBU0`2W[:h40:fe]`@0/kk1102ia/X40;k=dP@0`MCJ0`31f=l40;oJ
h`@0_]OO102nd]X40:Job@@0Rj^g101cUjL307VJZ0@0OinZ1024XZd408^W/0@0TZbc102I/KL309bb
]`@0X[Bh102M/;@409>X[P@0SZ6V102<Wj@308fKWP@0T9VK102HWj040:2VYP@0Z:f/102^/:h40;2^
Z`<0[jRT102]Y9d40:BGT@@0XiB=102PShH409Z8P0<0TWmg102>NG4408QcJP@0QViT1024JUl408=V
FP@0OV1C0`1iFTd407IEA`@0Kdi0101O?c84058a90@0CRLJ0`1C<2D405Li;P@0G44h101QBT8406MC
C0@0KEaF0`1cIF0407Y^JP@0P7Qd1027PGhF0?ooo`00503oool409BCTP@0VY^K102QY:D30:N/[P@0
[KFg102c_/440;W6bP@0_/gB1031e=X30<7Hg`@0_m[S102neml40;kBfP@0Y[o9102;ZkL407>GY`<0
NIZX101oWjX408BR[@@0RjN`102B[;<409Va]`<0W;:g102R];P409f`]0@0TjR^102>XJH408bOY0<0
SI^N102@VI/409ROX0@0X:JV102X[J`40:j`[P@0/:j[0`2_Z:@40:fTW@@0Y9NA102SU8d40:2?QP@0
VXR00`2BOgL408iiL@@0R7=Z1026KV@408AZG`@0PfIJ101nH5<307UJC@@0MUE7101_CT0405lo<P@0
DS4T101>9aX305<`9@@0EcT^101L@CP4065:@P@0Ie=<101]G5H307=UH0@0NViZ1020N7@408N1OQH0
oooo000D0?ooo`@0U9>B102LW9`40:>VYP<0ZZn`102a^;X40;S2a0@0_l_>1035e=P40<[Kh@<0bn7W
102nf>040;cCf`@0^LkF102U_LH408RX]@@0KY>S0`1eUjD407^LZ0@0PZ2[1028Y:d408jX/0@0UJfd
0`2I[kD409nb]`@0Vjjc102EZ:h408nQYP@0RifR0`2<VYh4096JW@@0V9nP102QYZH40:R][0@0[k2^
102b[j`30;6ZY@@0/:FO102YVY<40:VHT0@0Yi>:102JR80309=oM`@0SgYb1027LVT408A^I0@0PVUN
1022IET407mQE0<0Nea>101hEdT406m>@0@0Fcd`101<;B4404TU6@<0CbhR101C=R`405Po=P@0GTQ0
101TDDX406]JE0<0LFAO101hKFT407mgM0@0QX1n5P3oool001@0oooo102DTi8409bLW0@0XjJV0`2Z
[k040;6h^P@0^<;4102oblh40<GDf0@0b]_Q0`3;hNL40;kHh0@0_=?K102ic]H40:FmaP@0R:Re101^
Tj<307FGY@@0NibX1022X:/408RT[@@0SZR`102E[K@309V_]@@0Wk:g102K[[<409FX[P@0Sj6V102;
WJ8308bJWP@0TIZM102HWj040:6VYP@0Z:f/102_/:h40;:_[0<0/JZU102`YIl40:VJT`@0ZIR@102W
ThX409Z8P0<0Tgmg102?NW8408MbJ@@0Q6iT1022JEh4089UF@@0Of5D0`1kG4h407QGB@@0Kdi0101K
?C0404`]8@@0BBDI0`1?;R8405<f;0@0F3lf101NB40406AABP@0JeYD0`1aI5l407Q]J@@0OgMd1026
P7hF0?ooo`00503oool409BCTP@0W9bL102SYZH30:Z_/0@0/KRj102h`/@40;o;cP@0aMCH103:fn43
0<_Qi`@0_]SP102ldm/40;W>eP@0YKg61028Z;D406jCX`<0MINU101kW:P408:PZ`@0R:B]102>Z;04
09F]]0<0VJne102O/[L409^^/`@0UJR^102?XJH408^MXP<0S9ZN102AVYd409ROX0@0XJJV102X[J`4
0:n`[P@0/Zn/0`2aZZD40;2UW`@0ZIZC102YV9040:NCRP@0VXR00`2COgL408mjLP@0Qg9Y1024KV@4
089YGP@0PVEI101oHE@307]LCP@0N5M9101_CT0405/m<0@0C2dQ10199AT304l^8P@0DcH/101H?cH4
05i8@0@0I55:101[FU@3075TG`@0N6eY101oMg@408J0OQH0oooo000D0?ooo`@0U9>B102LW9`40:>V
YP<0ZZn`102a^;X40;S2a0@0_l_>1035e=P40<[Kh@<0bn7W102nf>040;cCf`@0^LkF102U_LH408RX
]@@0KY>S0`1eUjD407^LZ0@0PZ2[1028Y:d408jX/0@0UJfd0`2I[kD409nb]`@0Vjjc102EZ:h408nQ
YP@0RifR0`2<VYh4096JW@@0V9nP102QYZH40:R][0@0[k2^102b[j`30;6ZY@@0/:FO102YVY<40:VH
T0@0Yi>:102JR80309=oM`@0SgYb1027LVT408A^I0@0PVUN1022IET407mQE0<0Nea>101hEdT406m>
@0@0Fcd`101<;B4404TU6@<0CbhR101C=R`405Po=P@0GTQ0101TDDX406]JE0<0LFAO101hKFT407mg
M0@0QX1n5P3oool001@0oooo102EU9<409fMW@@0YJNX0`2]/K840;Fk_@@0_LK81036d=<40<kKg`@0
f>O[0`3Ci^`40<7Gg`@0^LkG102db=0409jg`P@0PjBb101ZT:03076EX`@0N9VU1020WjX408JQZ`@0
RjB/102AZK0309J]/`@0VJjc102H[;4409BW[@@0T::W102=WJ4308jKWP@0TibN102IX:040:6WYP@0
ZJf/102_/:h40;:_[0<0/ZZU102`YIh40:fMU@@0[I^B102]V8h409^9P@<0UX5i102AO7<408IbJP@0
Q6eT1022JEh408=VF@@0PF9D0`1nGU0407aJBP@0KDdo101H>bl404HZ7`@0A28F0`19:R0404hc:@@0
E3`c101JACh4065?B0@0J5QC0`1_HUh407M/J0@0OWIc1026P7hF0?ooo`00503oool409FDT`@0WIfM
102UYjP30:fa/P@0]K^m102ma/P40<K@d`@0c]_O103Hin/30=?Vk0@0`MOO102ic]L40;C8d0@0W[O2
1023Y;8406Z@X0<0LIFS101hVJD4082OZP@0QZ6[102;Y:`4096Y/0<0UZfc102I[[<409R//@@0U:N]
102@XZL408fMX@<0SY^N102CW9h409VPX0@0XJNV102Y[J`40:n`[P@0/Zn/0`2bZZD40;2UWP@0[IfE
102]Vi840:fHSP@0VhV10`2FPGT4095lL`@0QW9Z1024KF@4089YGP@0PfII1021HU@307iND0@0O5Y:
101]CCl405Pk;`@0ARXO10148QH304TZ80@0CS<Y101D?3<405Y5?P@0HDm8101XF5<306mRGP@0MfaX
101nMW<408J0OQH0oooo000D0?ooo`@0UIBC102MWId40:FWZ0<0[K6b102e^kd40;g6b0@0a]3C103>
fml40=SWj`<0dnK/1031eml40;W>e`@0]<S@102N]l8408>T/P@0JY2P0`1aUJ<407RIY@@0P9nZ1026
XJ/408^T[0@0TJV`0`2F[K<409V^/`@0V:ba102DYjd4092RY`@0SIfQ0`2>Vih409>LWP@0VJ2P102Q
YjH40:V][0@0[k2^102b[j`30;:ZY@@0/:FN102]WID40:fKTP@0[IR>102KRH4309J1N@@0TGac1026
LVX408A]I0@0PVUN1023IUT4085RE0<0OUi@101lFTX406e=?`@0F3/_1016:Ql404@R5P<0BBXP101>
<bT405@l<`@0FTDn101QCdP406QHD`<0Kf9N101gK6P407ifL`@0QX1n5P3oool001@0oooo102EU9<4
09fMW@@0YJNX0`2]/K840;Fk_@@0_LK81036d=<40<kKg`@0f>O[0`3Ci^`40<7Gg`@0^LkG102db=04
09jg`P@0PjBb101ZT:03076EX`@0N9VU1020WjX408JQZ`@0RjB/102AZK0309J]/`@0VJjc102H[;44
09BW[@@0T::W102=WJ4308jKWP@0TibN102IX:040:6WYP@0ZJf/102_/:h40;:_[0<0/ZZU102`YIh4
0:fMU@@0[I^B102]V8h409^9P@<0UX5i102AO7<408IbJP@0Q6eT1022JEh408=VF@@0PF9D0`1nGU04
07aJBP@0KDdo101H>bl404HZ7`@0A28F0`19:R0404hc:@@0E3`c101JACh4065?B0@0J5QC0`1_HUh4
07M/J0@0OWIc1026P7hF0?ooo`00503oool409JDT`@0WYjN102WZJT30;2c]0@0^Kk01032bL/40<cE
f0@0en;U103TlOD30=KVj`@0b=_Q102icMD40:k3c0@0U[:n101nX:h406N>WP<0KI:P101eUZ8407fL
YP@0Q9nY1029Xj/408jU[@<0TjV_102EZk0409FY[`@0TZF[102?XJL408jMXP<0SY^N102DWIl409ZQ
XP@0XZNW102Y[J`40;2_[@@0/jn/0`2cZjH40;2UWP@0[IjF102]Vi840:bGS@@0X8f40`2IQG`409=m
M0@0RGA[1027KfD408I[G`@0QFQK1025I5H3089PDP@0P5a=101[Bch405@i;P@0@RTO100n7A8304<V
70@0BBlV101?>34405I2>`@0GDa6101UEU4306eQG0@0MF]W101mMG8408F0OAH0oooo000D0?ooo`@0
UYBC102NWYh40:NYZ@<0/;>d102i_/040<;9b`@0c=GH103Gh^D40>Cam@<0e^K[1038fn440;W=e@@0
[/?<102F/[h407jP[P@0IhjN0`1]TZ0407FFXP@0OIbV1024WjT408VSZ`@0SZF]0`2CZJl409F[/0@0
UJV_102BYJ/408nQY`@0SYfR0`2>Vih409BMW`@0VZ6R102RYjL40:V][0@0/:n]102c[j`30;>[YP@0
/:FN102]WYH40:fKTP@0[9N=102PSH@309V5O0@0Tged1029M6/408M_I@@0QV]O1025J5/408ETEP<0
PV1B1020G4d406];?P@0E3T^1012:Al403hM4P<0@bHL1019;bH404lh<@@0ET8k101MC4H406EFD@<0
KF5L101eJfL407eeLP@0QH1m5P3oool001@0oooo102FU9<409jNWP@0YjVY0`2`/k@40;Vn`0@0`/W;
103<eMP40=ORi@@0i?7e0`3Fi^/40<SKh@@0^LgE102^`l`409Jb_P@0OZ2^101WSYh306fBX0@0MIJR
101mW:H408BOZ@@0RJ>[102>YJd309>Y[`@0UJ^`102EZJl409:UZ`@0Sj6W102>WJ8308jKWP@0U9fO
102JXJ840::WY`@0ZJf/102`[jd40;>_[0<0/j^V102`YIh40:fNUP@0[I^B102/Uhd40:2=Q0<0VHEl
102COG@408UdJ`@0QfmU1026Jel408EXF`@0QFAF0`22H584081LC@@0Jd/n101D>Bh4048Y7`@0?QdB
0`139Q`404T_9P@0CcPa101F@S/405e<AP@0IEIA0`1]HE`407E[I`@0OGEb1025P7dF0?ooo`00503o
ool409JDT`@0WYjN102WZJT30;2c]0@0^Kk01032bL/40<cEf0@0en;U103TlOD30=KVj`@0b=_Q102i
cMD40:k3c0@0U[:n101nX:h406N>WP<0KI:P101eUZ8407fLYP@0Q9nY1029Xj/408jU[@<0TjV_102E
Zk0409FY[`@0TZF[102?XJL408jMXP<0SY^N102DWIl409ZQXP@0XZNW102Y[J`40;2_[@@0/jn/0`2c
ZjH40;2UWP@0[IjF102]Vi840:bGS@@0X8f40`2IQG`409=mM0@0RGA[1027KfD408I[G`@0QFQK1025
I5H3089PDP@0P5a=101[Bch405@i;P@0@RTO100n7A8304<V70@0BBlV101?>34405I2>`@0GDa6101U
EU4306eQG0@0MF]W101mMG8408F0OAH0oooo000D0?ooo`@0UYFD102OWil40:VZZP<0/[Ff102l`L84
0<K=cP@0dMWK103MinX40>_fn@<0gNW^103<g>840;_>eP@0ZL79102A[kX407ZMZ`@0IHbM0`1ZSYd4
07:CW`@0NINR1021WJH408NQZ@@0S:B[0`2AYZ`4096V[@@0TjN]102AXjT4092QYP@0SYjR0`2?Vil4
09FOX@@0W:BT102SZJP40:Z/Z`@0/:j/102c/:/30;F/Z0@0/ZFO102]WYL40:^JT@@0YiB;102QSX@3
09f7OP@0UWme102?Mfd408acJ0@0RViQ1029JUd408QVF0<0R6=D1022GDd406U:?@@0CCH/1012:R04
03TK4@<0?B8I1012:b<404Te;P@0DCli101JBT@4069DD0<0JemK101cJVH407aeLP@0Q7mm5P3oool0
01@0oooo102FUI@409nOW`@0ZJZZ0`2b]KH40;c1`P@0a/g>103AfM/40=gWjP@0joKi0`3MjNh40<cL
hP@0^lkF102Y`LT4096_^P@0NYf[101US9d306Z>W@@0LY>O101iUj84086MYP@0Qj6Y102<Y:/3096V
[0@0TJJ]102CYjd4096SZ@@0T:6V102>WZ8308nKW`@0UInQ102LY:@40:>YZ0@0ZZb[102`[Z`40;>`
Z`<0]JbX102bYIl40:fNU`@0ZiZA102WU8/40:6>Q0<0WHMn102FOgD408mgK@@0S7=X102:KV4408UZ
G@@0R6IH0`28He@4089MC@@0JDXm101==R`4048Z80@0>A/A0`0m8QT4048[8`@0BCD^101A?cT405Y:
A0@0HUA@0`1[Ge/407=ZIP@0O7Eb1024OgdF0?ooo`00503oool409JEU0@0WinO102YZZX30;:e]P@0
_<721036cLh40=7If`@0gNOZ103[m_T30=gYkP@0c=cR102kc]H40:W1b@@0TJnj101jWJ/406F<W@<0
JXjM101bTil407VGXP@0PIfV1027XJT408bTZ`<0TJJ/102AYZd409>W[@@0TJ>Y102@XJH408jNXP<0
Si^O102EWj4409bTY0@0XjVX102Z[:/40;2^[0@0/k2[0`2e[:P40;:UW`@0[IjG102[VY440:NDR`@0
XHj40`2MQgh409IoM@@0SgM]102<LfP408Y^H@@0RFYM1028IUP308QSE0@0PUe=101YBSd404df;0@0
@RXP100i6a4303dR6@@0@R/S1019=Bh4054o>@@0FTY4101RE50306]OF`@0LfYV101lMG8408AoOAH0
oooo000D0?ooo`@0UYFD102OWil40:VZZP<0/[Ff102l`L840<K=cP@0dMWK103MinX40>_fn@<0gNW^
103<g>840;_>eP@0ZL79102A[kX407ZMZ`@0IHbM0`1ZSYd407:CW`@0NINR1021WJH408NQZ@@0S:B[
0`2AYZ`4096V[@@0TjN]102AXjT4092QYP@0SYjR0`2?Vil409FOX@@0W:BT102SZJP40:Z/Z`@0/:j/
102c/:/30;F/Z0@0/ZFO102]WYL40:^JT@@0YiB;102QSX@309f7OP@0UWme102?Mfd408acJ0@0RViQ
1029JUd408QVF0<0R6=D1022GDd406U:?@@0CCH/1012:R0403TK4@<0?B8I1012:b<404Te;P@0DCli
101JBT@4069DD0<0JemK101cJVH407aeLP@0Q7mm5P3oool001@0oooo102GUI@40:6PX0@0ZZb/0`2e
]kL40;o3a0@0b/oA103Eg=h40>;Zk0@0koWk0`3RkO440=3Nh`@0_LoF102X`<T4092]^@@0N9^Y101U
S9`306N;VP@0KXnK101eTih407bHX@@0PibU1029X:L308fRZ0@0SJ:Y102@XjX4092RZ0@0TJ:W102@
X:@309>OX`@0Uj:S102NYZL40:>ZZ@@0ZJbZ102_[JX40;:^Z@<0]ZfX102eZ:840;2PV@@0[9^B102U
Th/40:6=Q0<0WXMn102IPGL409AkL0@0TGIZ102>LF@408a/G`@0S6UK0`2=IeL4085LC@@0ITPl101:
=B/4048[8@@0>1`B0`0b6Q8403/U7P@0@c4Z101<?3H405I7@P@0Ge9>0`1XGUX4075YI@@0NgAa1024
OgdF0?ooo`00503oool409NEU0@0XJ2P102Z[:`30;Fg]`@0_l?4103:cm440=GLgP@0h^[/103_nO/3
0>;]l@@0d=kS102mcmH40:S0b@@0T:fi101hVjT406F<W0<0Ih^J101^Si/407FCWP@0O9RQ1023W:D4
08VPY`<0SJ:X102=XZT4092SZP@0T::X102AXZL4092PY0<0TinS102GXZ<409jVY`@0XjZY102Y[:X4
0:n]ZP@0/ZjY0`2f[JP40;FXXP@0/:2I102/Vi840:FCR`@0XHf40`2NQgh409V1M`@0U7]`102AMVX4
08iaI0@0S6aO102<JE/308eWE`@0PEa=101VB3`404Xe:`@0@R/Q100h7183038J4P@0>bDN1013<BX4
04`l=P@0ETM2101ODTh306QNFP@0LFUU101kM74408AoOAH0oooo000D0?ooo`@0UiFD102QX:040:Z/
[0<0]KNg102o`l@40<[?d@@0eMcN103Rj^`40>oin`<0h^ga103@g^<40;g?eP@0Z<39102@[KT407RK
Z@@0IHbL0`1WRiX406j?V`@0MI>N101lV:4408>LY@@0RJ2W0`2=XZP408fRZ@@0T:>Z102@XZP4096R
Y`@0T:2T0`2CWj<409NRX`@0WZJW102SZZT40:V/ZP@0[jfZ102b[ZT30;J]Z0@0]JRR102`X9T40:bK
TP@0YI>;102QSH@309j7OP@0VH5g102DNg04095fJP@0SW5T102<K5l408aYF`<0SFMG1021G4d406I8
?0@0BSD[1012:b4403PL4P<0<QXB100k9Ah404<a:P@0C3`f101FAd8405mBCP<0J5iJ101aJFD407]d
L@@0Q7mm5P3oool001@0oooo102GUY@40::QX0@0[:f]0`2g^;T40<75a@@0cM7B103Ign040>G/kP@0
lo[m0`3Vko840=CPi@@0_m3G102Z`<T4092]^@@0NI^Y101VSI`306F9V0@0Jh^H101bT9X407VCW@@0
OiRP1024Vj8308RNY0@0Rj2V102>XJL408nQY`@0TJ:X102CXZL309JSY`@0VZBV102OZ:P40:BZZ@@0
ZJ^Y102][:P40;2/Y`<0]:^U102fZJ840;BSW0@0/IjE102YUXd40:B>Q@<0WXQo102KPWP409MmLP@0
TgQ[102@LVD408m_H@@0TFaM0`2BJET407mJB`@0IDPk101==bd403lY80@0=A`C0`0W4``4038P6P@0
?B`W1017>C<40595@0@0G51<0`1VG5T4071XI@@0NW=a1023OgdF0?ooo`00503oool409NFU0@0XZ6P
102/[Jd30;Nh^@@0`LG5103=dM840=WOh0@0iNc^103cn_d30>K_lP@0e>3U102od=L40:[0b@@0T:fi
101iVjT406J=W0<0IHVH101[RiP407:@VP@0NI>M101oV:0408BKXP<0R9jT102;X:H408jQY`@0Sj6W
102AXZP409>RY`<0UZ>W102JY:H409nXZ0@0Y:ZY102YZjT40:f/Z0@0/:bW0`2dZjD40;JYXP@0]:>L
102aWYD40:VFS@@0Y8j50`2NR7l409^2N0@0Ugeb102CN6/4091bI@@0SfmQ102AK5d3099YF@@0OeY;
101UB3/404dg;@@0?bTP100e71<302LC30@0<R0J100m;2L404Li<`@0DTE0101LD4`306ILF@@0L6QU
101jLg4408=oOAH0oooo000D0?ooo`@0UiJD102RXJ040:b][@<0]kRi1031aLD40<gAdP@0fMoP103U
k>h40??jo@<0i^ob103Dh>D40;o@e`@0Z/39102@[KT407VKZ@@0IXfL0`1URIP406^;V0@0LY2J101i
Tid407nHX0@0Q9^R0`28WZ@408^PYP@0SZ6W102?XJL4096RZ0@0Tj:W0`2FXjL409ZTYP@0WjRX102T
ZZT40:V[Z@@0[JbX102`[:L30;B[Y@@0]ZVR102dXi`40;6NU@@0ZIJ=102TSXD309j8O`@0Vh9h102G
OG8409=hJ`@0T79U102?Kf44095/G@<0TVUI101oFT/406E8>`@0CCL]100o:B0403DL4`<09a<<100b
81X403d/9`@0AcTc101BAD0405a@C0<0IUaI101`J6D407YcL@@0Pgmm5P3oool001@0oooo102GUY@4
0::QX0@0[:f]0`2g^;T40<75a@@0cM7B103Ign040>G/kP@0lo[m0`3Vko840=CPi@@0_m3G102Z`<T4
092]^@@0NI^Y101VSI`306F9V0@0Jh^H101bT9X407VCW@@0OiRP1024Vj8308RNY0@0Rj2V102>XJL4
08nQY`@0TJ:X102CXZL309JSY`@0VZBV102OZ:P40:BZZ@@0ZJ^Y102][:P40;2/Y`<0]:^U102fZJ84
0;BSW0@0/IjE102YUXd40:B>Q@<0WXQo102KPWP409MmLP@0TgQ[102@LVD408m_H@@0TFaM0`2BJET4
07mJB`@0IDPk101==bd403lY80@0=A`C0`0W4``4038P6P@0?B`W1017>C<40595@0@0G51<0`1VG5T4
071XI@@0NW=a1023OgdF0?ooo`00503oool409RFU@@0XZ:Q102][Zd30;Rj^P@0a<K7103?dm@40=_P
h@@0j>k_103eo?d30>O`l`@0f>?W1031d]T40:c1bP@0Tjnj101kWJX406R>W@<0I8RF101XRID406n=
U`@0MI2I101kU9`4086GWP<0QIZQ1029WJ<408bOY@@0Sj6V102BXjP409BTZ0<0V:FY102KYjT40:2X
Z@@0Y:^Z102XZjT40:^ZY`@0[jZU0`2aZJ<40;BWX0@0/j>L102bWiL40:jIT0@0Z9:80`2RRh4409j4
N@@0VGic102GNF`409=eIP@0UG5S102EKUl309=ZFP@0OEU;101VB3`404lh;P@0>bPO100]6A8301l?
2@@0:a`F100g:2<4048e<@@0CT8n101ICd/306=KE`@0KVMT101iLg0408=nO1H0oooo000D0?ooo`@0
V9JE102RXZ440:f^[@<0^;Zj1034a/L40<oCe0@0fn3Q103Xk^l40?Glo@<0io3c103HhnL40<7Bf@@0
[<7:102C[kX407^MZP@0J8jM0`1TR9H406R9U@@0KhfG101eT9T407^DW0@0PINN0`25VZ4408VMX`@0
S9nU102?XJH409:SZ0@0U:BX0`2HYJT409^WZ@@0X:RY102TZjX40:R[Z@@0ZjZW102_ZZD30;6YX`@0
]:NP102cXi`40;:OU`@0[YV@102XTXP30::;P@@0WXAi102IOW<409MiK0@0TgEV102ELF<409E^G`<0
TfYJ101mFD/406I8?0@0CcP^100k:1l402dI4P<07`l9100[71H403LX8`@0@SDa101>@Sh405U?B`<0
He]G101^If@407UcL0@0Pgil5P3oool001@0oooo102HUYD40::RX@@0[Jj]0`2h^[X40<C6a`@0cm?D
103Kh>440>S^k`@0mOcm0`3Wl?<40=SSi`@0`M;I102/`LX409>_^P@0NifZ101XSYd306B8UP@0J8VE
101_SIL407F@V@@0NiBL1021Uih308FJX@@0RIfS102<WjD408nQYP@0TZ>X102DY:P309RUZ@@0VjNY
102PZ:T40:B[ZP@0Z:^Y102[ZZL40:nZY@<0/JVS102dYj040;>SW0@0/YnG102^VI040:RBR0<0XX^1
102NQ7T409UnL`@0UgU/102CMFH409EaH`@0UFiO0`2CJUX407eIB`@0ITPl101?>2h403/X7`@0;ATB
0`0O3`T402/L5P@0=bPS1012=C4404i2?P@0FDm;0`1SFeL406iWI0@0NG=`1023OW`F0?ooo`00503o
ool409RFU@@0XZ:Q102][Zd30;Rj^P@0a<K7103?dm@40=_Ph@@0j>k_103eo?d30>O`l`@0f>?W1031
d]T40:c1bP@0Tjnj101kWJX406R>W@<0I8RF101XRID406n=U`@0MI2I101kU9`4086GWP<0QIZQ1029
WJ<408bOY@@0Sj6V102BXjP409BTZ0<0V:FY102KYjT40:2XZ@@0Y:^Z102XZjT40:^ZY`@0[jZU0`2a
ZJ<40;BWX0@0/j>L102bWiL40:jIT0@0Z9:80`2RRh4409j4N@@0VGic102GNF`409=eIP@0UG5S102E
KUl309=ZFP@0OEU;101VB3`404lh;P@0>bPO100]6A8301l?2@@0:a`F100g:2<4048e<@@0CT8n101I
Cd/306=KE`@0KVMT101iLg0408=nO1H0oooo000D0?ooo`@0V9JE102SXZ440:j^[P<0^[^k1035alL4
0=7De@@0gN7R103Zko040?OmoP<0jO7c103Ji>P40<GEfP@0[/C<102G/K/4082P[@@0KI6O0`1SR9H4
06F6T`@0K8ZD101cSIH407VAV0@0OYBK0`23V9h408RKX@@0RijT102?X:H409:SZ0@0UJBY0`2IYZX4
09bXZP@0X:VZ102TZjX40:NZZ0@0ZZVV102]Z:@30;2WX@@0/ZFN102bXYX40;6NU@@0[YV?102ZThT3
0:J=P`@0XHMk102MPG@409]lKP@0VGQZ102IM6H409QaH@<0TFUI101kF4X406A7>`@0CcL^100i9al4
02LG4P<06Pd8100S5Q84030T80@0?C8_101:@3`405I=BP<0HEYG101]IV<407QbL0@0PWil5P3oool0
01@0oooo102HUYD40:>RX@@0[Zj^0`2j^k/40<G7a`@0dMCE103MhN840>[_l0@0mogn0`3YlO<40=[T
j0@0aMGJ102^a<`409Na^`@0P:2]101]TIl306>8UP@0IHJC101/RY@407>=UP@0NI6H101nU9/308>H
WP@0R9^Q102;WZ@408nPYP@0TZ>X102EY:T309VVZP@0W:RZ102PZJX40:B[ZP@0YjZX102ZZJH40:fX
Y0<0/:NQ102bYIh40;:RVP@0/IjE102^VHl40:ZCR@<0YXf3102QQg/409f1M0@0Vga^102IN6X409Ud
IP@0V75Q0`2AJET407]HBP@0I4Lk101?=bh403TW7`@09aLB0`0J3@P402<F4P@0<2@P100m<Rl404Y0
?0@0ETe:0`1QFUL406eVH`@0N79`1022OW`F0?ooo`00503oool409RFU@@0Xj:Q102^[Zh30;Zk^`@0
aLO7103Ae=D40=gQhP@0j^o`103goOh30>Wal`@0f^CX1035eMX40:k4c0@0Uk6k1020X:d406fAW`<0
HhRF101UQY<406b:U0@0LhfF101iTIP407jDV`<0PiRN1028Vj4408^NY0@0Sj2V102BXjP409FTZ@<0
VJJZ102LZ:X40:2YZP@0Y:^Z102WZZP40:ZYYP@0[JRT0`2`Yj440;:UWP@0/Z:J102aWYD40:jIS`@0
ZY>90`2VSH<40:67N`@0WH5d102KO6h409UhJP@0VGAV102HLF43095YF@@0NeQ:101TAc/404lg;P@0
>BLO100W5a8301X=20@08aHB100`920403db;`@0BT0l101FCDX3065JE`@0KFIS101hLW04089nO1H0
oooo000D0?ooo`@0V9JE102SXZ440:j^[P<0^[^k1035alL40=7De@@0gN7R103Zko040?OmoP<0jO7c
103Ji>P40<GEfP@0[/C<102G/K/4082P[@@0KI6O0`1SR9H406F6T`@0K8ZD101cSIH407VAV0@0OYBK
0`23V9h408RKX@@0RijT102?X:H409:SZ0@0UJBY0`2IYZX409bXZP@0X:VZ102TZjX40:NZZ0@0ZZVV
102]Z:@30;2WX@@0/ZFN102bXYX40;6NU@@0[YV?102ZThT30:J=P`@0XHMk102MPG@409]lKP@0VGQZ
102IM6H409QaH@<0TFUI101kF4X406A7>`@0CcL^100i9al402LG4P<06Pd8100S5Q84030T80@0?C8_
101:@3`405I=BP<0HEYG101]IV<407QbL0@0PWil5P3oool001@0oooo102HUYD40:BRXP@0[jn^0`2k
^k/40<O8b0@0dmGE103Oh^<40>c`l@@0nOko0`3[lO<40=cUj@@0b=OL102calh409be_P@0QZB`101b
U:8306F9U`@0HhBA101YQi84076;U0@0MhjF101mTYT308:FW@@0QiZP102;WJ8408jPYP@0TZ>X102F
YJT309VWZ`@0WJRZ102QZZ/40:BZZ@@0YjVW102YZ:D40:bWXP<0[ZFP102`Xid40;2PV@@0[ibD102]
V8h40:^CR@<0Z8j3102URGd40::4M`@0X7ma102NNf`409igJ0@0Vg9R0`2>IeL407MFB0@0HTHj101=
=Rd403LV7`@08QHA0`0E30P401X@3@@0:b4N100i<2d404Ln>`@0E4a90`1PFEH406]UH`@0Mg9`1022
OW`F0?ooo`00503oool409RFU@@0Y::R102_[jh30;^k^`@0alS8103CeMD40=oRh`@0k?3a103io_l3
0>_al`@0g>GY1038em`40;?7cP@0W;Fn1026Y;0407:DXP<0IHVG101SQ94406V7TP@0LH^D101gSYH4
07fBV@<0PYJM1027VZ0408^MXP@0SZ2V102BXjP409JUZ@<0VJN[102MZ:X40:6ZZ`@0Y:ZY102WZJL4
0:VXY@@0[:NR0`2^YJ040;2SW@@0/:2I102_W9@40:fHSP@0Zi>90`2XSX<40:F9O@@0XXAg102POg44
09ikK0@0WWMX102KLV8308iWE`@0MeI8101RASX404df;@@0=bHO100R5Q4301D<20@06Q0=100[8Ah4
03T`;@@0Achk101DC4T3061IEP@0JfES101gLW04089nO1H0oooo000D0?ooo`@0V9JE102TXZ840:n_
[P<0^k^k1037b<P40=?Ee@@0gn;S103/l?440?Wno`<0jo7c103LiNT40<SGg0@0/lO>102L]Kh408JT
/0@0LYBR0`1URIL406>4T@@0JHNB101aRi@407N>UP@0OI:I0`22UYd408NJX0@0RifR102>X:H409:S
Z0@0UZFY0`2IYj/409fXZP@0XJZ[102TZZT40:NYY`@0ZJRU102/Yj830:jUX0@0/:>M102`X9T40:nL
U0@0[IR>102[ThT30:R>P`@0YHUm102RQ7L40:1oL@@0WW]/102NMfP409]bHP<0SVMG101gETP40696
>P@0CCH]100g9Ql4028F4@<05@`8100J40d402/Q7P@0>C0]1017?S/405A<B@<0H5UF101[IF<407Mb
L0@0PWil5P3oool001@0oooo102HUYD40:BRXP@0[jn^0`2k^k/40<O8b0@0dmGE103Oh^<40>c`l@@0
nOko0`3[lO<40=cUj@@0b=OL102calh409be_P@0QZB`101bU:8306F9U`@0HhBA101YQi84076;U0@0
MhjF101mTYT308:FW@@0QiZP102;WJ8408jPYP@0TZ>X102FYJT309VWZ`@0WJRZ102QZZ/40:BZZ@@0
YjVW102YZ:D40:bWXP<0[ZFP102`Xid40;2PV@@0[ibD102]V8h40:^CR@<0Z8j3102URGd40::4M`@0
X7ma102NNf`409igJ0@0Vg9R0`2>IeL407MFB0@0HTHj101==Rd403LV7`@08QHA0`0E30P401X@3@@0
:b4N100i<2d404Ln>`@0E4a90`1PFEH406]UH`@0Mg9`1022OW`F0?ooo`00503oool409VFU@@0Y:>R
102`[jh30;bl^`@0b<W8103De]H40>7Sh`@0kO7a103ko_l30>cbl`@0gNKY103;fMh40;S:d@@0X[W2
102<Z;<407NHY@<0JHbJ101RQ94406R5T0@0KhVB101fSID407b@U`<0PIBK1026VIh408ZLX@@0SZ2U
102BXjL409JUZ@<0VZN[102NZJ/40:6ZZP@0Y:ZY102VZJH40:RWY0@0ZjJQ0`2]Y9h40:jRV`@0[inG
102^Vi<40:fGSP@0Zi>90`2YSh<40:R:OP@0YXIi102SPG<40:9mKP@0XGUY102JLF4308QSE0@0Le=6
101N@cP404Pc:`@0<R<M100N5143014:1`@05@d:100W7a`403H_;0@0ACdk101BBdP305iHEP@0JVES
101fLFl4089nO1H0oooo000D0?ooo`@0VIJE102TXj840;2_[P<0_;bk1038bLP40=CFeP@0hN?S103]
lO440?_no`<0k?;c103Mi^T40<_IgP@0^<[A102R^L8408bX/`@0MiRU0`1YS9X406:4T@@0J8F@101_
RI8407J=U@@0O92G0`21U9/408JIWP@0RYbQ102>X:D409:SY`@0UZFY0`2JYj/409jYZ`@0XJZZ102T
ZZT40:JYYP@0Z:NT102[YZ430:fTWP@0[Z:K102_WiL40:jKT`@0[IN>102[ThT30:V?P`@0Z8Yn102V
QWT40:>1L`@0XWe^102QNFT409YaH@<0R6=D101cDdH405i3>0@0B3<[100b8ad401hD4@<04@X7100E
3@X402LO70@0=Rl/1015?C/4059;B0<0GUQF101ZIF<407IaK`@0PWil5P3oool001@0oooo102IUYD4
0:BSXP@0/:n^0`2l_;/40<S9b0@0e=KF103Qhn<40>gal@@0noko0`3/l_<40=gVj@@0bmWN102hb]44
0::i`P@0S:Rc101gV:D306V<VP@0HXBA101XQI0406n9TP@0MXfE101lT9L3086DV`@0QYVN102:W:44
08jPY@@0TZ>W102FYJT309ZWZ`@0WZV[102QZZX40:BZZ@@0YZVV102XYj@40:^VX@<0[JBN102^XY/4
0:nOU`@0[Y^C102]Uhh40:^CR@<0ZHn3102XRWh40:J6N@@0Xh5c102ROFh40:5iJ@@0VW5Q0`28He@4
07=CAP@0GT<h1018<b/4038S7@@07Q@A0`0A2PL401D=2P@09alL100f;b`404Dm>`@0DT]80`1NF5H4
06YUH`@0MW5_1022OW`F0?ooo`00503oool409VFU@@0Y:>R102`[jh30;bl^`@0b<W8103De]H40>7S
h`@0kO7a103ko_l30>cbl`@0gNKY103;fMh40;S:d@@0X[W2102<Z;<407NHY@<0JHbJ101RQ94406R5
T0@0KhVB101fSID407b@U`<0PIBK1026VIh408ZLX@@0SZ2U102BXjL409JUZ@<0VZN[102NZJ/40:6Z
ZP@0Y:ZY102VZJH40:RWY0@0ZjJQ0`2]Y9h40:jRV`@0[inG102^Vi<40:fGSP@0Zi>90`2YSh<40:R:
OP@0YXIi102SPG<40:9mKP@0XGUY102JLF4308QSE0@0Le=6101N@cP404Pc:`@0<R<M100N5143014:
1`@05@d:100W7a`403H_;0@0ACdk101BBdP305iHEP@0JVES101fLFl4089nO1H0oooo000D0?ooo`@0
VIJE102TXj840;2_[P<0_;bk1038bLP40=GFeP@0h^?T103_lO440?coo`<0k_?d103NinX40<oKg`@0
_LgC102Y_LD4096[]P@0OIbX0`1^T9d406F7U0@0J8F@101_R94407F<U0@0Ni2G0`21TiT408JGW@@0
RYbQ102?X:D409>SY`@0UjFY0`2JYjX409jYZ`@0XJZZ102SZJP40:FXY@@0YjJR102ZY:030:^SW@@0
[J2I102^WYH40:fJTP@0[IN=102/ThP30:^?Q0@0ZH]o102XQgT40:J3M0@0YGi_102QNFT409I^GP<0
PemA101_D4<405Q0=P@0@S0X100]81X401TB3P<02PH4100D3P`402DO7@@0=Bl/1013?C/4055;B@<0
GEQF101ZIF<407IaK`@0PGil5P3oool001@0oooo102IUYD40:BSXP@0/:n^0`2l_;/40<S9b0@0eMKF
103Rhn@40>oal@@0o?oo0`3^lo@40=kWjP@0cm_O102mcM<40:Vma@@0TJ^f101mW:P306j@W@@0IHND
101XQI0406n8T@@0MHbD101kT9L3086CV@@0QYNM102:W:4408nPY@@0Tj>W102GYJT309ZWZP@0WZV[
102QZZX40:>YZ0@0YJRU102WYZ840:ZTX0<0Zj>M102]X9T40:jNUP@0[IZB102]Uhd40:bCR0<0Zhn4
102YRgl40:R7N@@0YX=d102UOVl40:5iJ@@0UViN0`23Ge4406m@@`@0F40f1012<2P402dP6P@06A8>
0`0:1P@401@>30@09AlM100e;b`404<m>`@0DD]90`1MF5H406YUH`@0MW5_1021OW`F0?ooo`00503o
ool409VFU@@0Y:>R102`[jh30;bl^`@0b<W8103Ee]H40>;Si0@0ko7a103lool30>kcm0@0g^OZ103?
fml40;g=d`@0ZKg5102AZkH407fLZ0<0KY2M101UQi@406R5T0@0KhRA101eS9@407^@U`<0PI>I1026
Uid408ZLX@@0Sj2U102CXjL409NUZ@<0VZNZ102NZJ/40:6ZZP@0XjVX102UZ:D40:NVXP@0ZZBP0`2[
Xid40:fPV@@0[YjF102]VY840:fGS@@0[9>80`2[Sh@40:V;O`@0Z8Mi102VPg@40:EnK`@0XGUY102F
KUh308=OD@@0Ke13101H@3H4048`:0@0;B0J100I4Ph300X610@050h<100U7ad403D_;0@0@cdk101A
BdT305eHEP@0JVES101fLFl4085nO1H0oooo000D0?ooo`@0VIJE102UXj840;2_[P<0_;bk1039bLP4
0=KFeP@0hnCT103`lO440?goo`<0ko?d103Pj>X40=;Lh0@0`]3F102^`<P409R`^@@0Q:6/0`1cTj04
06Z;U`@0JXJA101_R94407F<U0@0O92F0`21TiT408JGW0@0Ri^P102?Wj@409>SY`@0UjFY0`2KZ:X4
09jXZP@0XJVY102SZ:L40:FVY0@0YjFQ102YXih30:ZQV`@0[9jH102]W9D40:fIT@@0[9J<102/TXP3
0:^?P`@0Zhao102YQgT40:R3M@@0YGi^102NMfL4091ZF`<0OE]>101WBd04058l<`@0?2`U100W71P4
01<>30<01@80100F4A0402DP7`@0=2l]1013?S`4051;B@<0GEQF101YIF<407EbL0@0PGil5P3oool0
01@0oooo102IUYD40:FSXP@0/:n^0`2l_;/40<W9b0@0e]KF103Si>@40?3al@@0oOoo0`3_lo@40>3X
jP@0d]cP1032d=H40:k0b0@0V;2i1024XJ`307>CX0@0JX^G101ZQY4406n8T@@0MHbD101lT9H3086C
V@@0QYNL102;Vj0408nOY0@0Tj>W102GYJT309^XZP@0WZRZ102QZJT40:>XY`@0YJJT102WYJ440:VS
WP<0ZZ6K102/WYP40:fLU@@0[IVA102/UX`40:bBR0<0Zhn3102[S7l40:V7N@@0Z8=e102UOVh409ig
I`@0T6YK0`1mFdh406M;@0@0DS`c100l;2D402LL60@04`h<0`050P0401HA40@09B0O100d;bd404<n
?0@0D4]90`1MF5H406UUH`@0MG9`1021OW`F0?ooo`00503oool409VFU@@0YJ>R102`[jh30;bl^`@0
bLW8103Fe]H40>?Ti0@0l?7a103mool30>ocm0@0h>SZ103Bg>040<;@eP@0[/38102H/;T408BQ[0<0
Li>P101ZRiL406Z6T@@0KhRA101eS9@407b@UP<0PI>I1026Ui`408^KX0@0SinT102CXjL409NUZ@<0
VjRZ102NZ:X40:6YZ@@0XjRW102UYZ@40:NUX@@0ZJ>N0`2ZXI/40:bNV0@0[IbE102]VI440:bFS0@0
[9:80`2[Sh<40:^<O`@0ZHMi102XPgD40:EnKP@0WWMW102@JU/307eKCP@0Id]0101B?3<403`/9@@0
9a`H100C3P`300D200@05Q4@100U81l403@_;@@0@chl101@BdT305eHEP@0JFES101eLW04085nO1H0
oooo000D0?ooo`@0VIJE102UXj840;2_[P<0_;bk1039bLP40=KFeP@0hnCT103`lO440?goo`<0ko?d
103Pj>X40=;Lh0@0`]3F102^`<P409R`^@@0Q:6/0`1cTj0406Z;U`@0JXJA101_R94407F<U0@0O92F
0`21TiT408JGW0@0Ri^P102?Wj@409>SY`@0UjFY0`2KZ:X409jXZP@0XJVY102SZ:L40:FVY0@0YjFQ
102YXih30:ZQV`@0[9jH102]W9D40:fIT@@0[9J<102/TXP30:^?P`@0Zhao102YQgT40:R3M@@0YGi^
102NMfL4091ZF`<0OE]>101WBd04058l<`@0?2`U100W71P401<>30<01@80100F4A0402DP7`@0=2l]
1013?S`4051;B@<0GEQF101YIF<407EbL0@0PGil5P3oool001@0oooo102IUYD40:FSX@@0/:n^0`2m
_;/40<W9b0@0e]KE103Si><40?7al@@0oooo0`3`m?D40>?Yj`@0e=kQ1036d]L40;?4bP@0WkFm102<
Y[0307ZHY0@0LI2K101]RI@40728TP@0MXbD101lT9L308:DVP@0QiNM102<Vj04092OX`@0U:>W102H
YJT309^WZP@0WZRY102QZJP40::WYP@0Y:FR102UXj040:NQW0<0ZInJ102[WIH40:^KT`@0[9R@102/
UH/40:bBQ`<0[8j3102/Rgh40:^7NP@0Z8=d102SO6d409UcI0@0R6EG0`1eETX40617?0@0BcL_100e
:28401lH50@03@X90`040P4401LC4P@09R8Q100e<Bl404<o?@@0D4a:0`1MFEL406UUI0@0MG9`1021
OW`F0?ooo`00503oool409VFU@@0YJ>Q102`[jh30;fl^`@0bLW8103Fe]D40>?Th`@0lO7a103oool3
0?3dm@@0hnW[103Dg^440<KBe`@0/lC:102O]Kd408bV/0<0NYRT101aT9/406f9U0@0L8RB101fS9@4
07b@U`<0PYBJ1027Uid408bKX0@0T9nS102DXjL409RUZ@<0VjNZ102NZ:T40:6YZ0@0XZNV102TYJ84
0:FSX0@0Yj6L0`2YWiX40:^MUP@0Zi^C102/V9040:bER`@0[9:70`2/SX<40:b;OP@0ZhMj102XPg@4
0:=lK@@0VG=T1028IEL307EFBP@0H4Ll101;=bl403DX8P@07aPD100=2PT300@20@@05a<B100V8R44
03Da;`@0@clm101@C4X305eIE`@0JFET101eLW04085nO1H0oooo000D0?ooo`@0VIJE102UXj440;2_
[P<0_Kbk1039bLP40=KFe@@0hnCS103alO440?ooo`<0l?Ce103SjN/40=CNh@@0a];G102ca<X409ne
_@@0S:J`0`1jV:@4076@V`@0KHVD101`R98407J<U0@0O92G0`22U9X408NGW@@0S9^P102@Wj<409BS
Y`@0V:FY0`2KYjX409jXZ@@0XJVX102RYjH40:BUXP@0YJ>P102WXI`30:VOVP@0ZifF102[Vi<40:bH
T0@0[9F;102/TXL30:b>P`@0[8]n102[QgX40:R3M0@0Xga]102ILf@408QUE`<0MEI:101PAc`404/g
;`@0=BPR100O61@400d:2@<01081100G4a8402HR8@@0=C4_1013?cd4051<BP<0GEUG101YIF@407Eb
L0@0PGil5P3oool001@0oooo102IUYD40:FSX@@0/:n^0`2m_;/40<W9b0@0e]KE103Si><40?7al@@0
oooo0`3`m?D40>?Yj`@0e=kQ1036d]L40;?4bP@0WkFm102<Y[0307ZHY0@0LI2K101]RI@40728TP@0
MXbD101lT9L308:DVP@0QiNM102<Vj04092OX`@0U:>W102HYJT309^WZP@0WZRY102QZJP40::WYP@0
Y:FR102UXj040:NQW0<0ZInJ102[WIH40:^KT`@0[9R@102/UH/40:bBQ`<0[8j3102/Rgh40:^7NP@0
Z8=d102SO6d409UcI0@0R6EG0`1eETX40617?0@0BcL_100e:28401lH50@03@X90`040P4401LC4P@0
9R8Q100e<Bl404<o?@@0D4a:0`1MFEL406UUI0@0MG9`1021OW`F0?ooo`00503oool409VFU@@0Y::Q
102`[jd30;bk^P@0bLS7103FeM@40>?ShP@0lO7`103oool30?;emP@0i^[[103Hgn840<[Ef@@0^LS>
102V^L4409F/]@<0Q9jY101iUZ44076=U`@0LXZC101gSID407fAV0<0PiFJ1028V9h408fLX0@0TInS
102EXjH409VUZ0<0W:NY102NYjP40:2WY`@0XZFT102SXj040:BQWP@0YInJ0`2WWYP40:VKU@@0ZYVA
102ZUhh40:^DRP@0Zi660`2/SX840:b;OP@0ZXMi102VPW<409iiJP@0TFeO101oGe8306]@AP@0F48h
1013<b`402dS7P@05a8@100510<300T71`@06AHF100X9B@403Hc<@@0A40o101ACD`305eJF0@0JVIU
101fLW44085nOAH0oooo000D0?ooo`@0VIJE102TXZ440;2_[@<0_;^j1039b<L40=KEe0@0hn?R103a
lO040?ooo`<0l_Gf103Vj^/40=SOhP@0b]GI102ib<h40:Ji`@@0UJbe0`24WZT407VFX@@0LHfG101b
RY<407N=U@@0OI6H0`23UIX408RHWP@0SIbP102AWj<409FSYP@0VJFX0`2LYjT409jWZ0@0X:NW102R
YJ@40:>SX0@0Y:6N102UWiX30:NNV0@0ZI^E102ZVI440:ZGSP@0ZiB:102[THH30:b>PP@0[8]n102Z
QgT40:J2L`@0WWUZ102AKEl407mODP<0Je16101H@SP404<c;0@0;B<N100G4Q0400D40`<02@L7100I
5QH402PU90@0=S<a1014@3l4055=C0<0GEYH101ZIVD407IbL@@0PGim5P3oool001@0oooo102IUYD4
0:BRX@@0/:n]0`2l^kX40<W8a`@0e]GD103Shn840?7al0@0oooo0`3bmOH40>KZj`@0f=oR103:eMT4
0;W8cP@0Y[W1102E[;D308BNZ@@0NIJQ101aSIL407::T`@0MhfE101mTIP308>EVP@0R9RN102=W:04
096OX`@0UJ>V102IYJP309bWZ@@0WZNX102PYjL40::UY0@0Xj>P102TXIh40:FOVP<0YijH102YViD4
0:ZIT@@0ZYN>102[U8X40:^AQP<0[8j2102/Rgh40:Z7N@@0YX9c102NNFX4095]G`@0OemB0`1[D4H4
05Q2>0@0@c</100]8ah401LB40@01@@30`091`L401TF5P@0:2DT100f<c4404A0?`@0DDe<0`1MFUP4
06YVI@@0MW9a1021OWdF0?ooo`00503oool409VFU@@0Y::Q102`[jd30;bk^P@0bLS7103FeM@40>?S
hP@0lO7`103oool30?;emP@0i^[[103Hgn840<[Ef@@0^LS>102V^L4409F/]@<0Q9jY101iUZ44076=
U`@0LXZC101gSID407fAV0<0PiFJ1028V9h408fLX0@0TInS102EXjH409VUZ0<0W:NY102NYjP40:2W
Y`@0XZFT102SXj040:BQWP@0YInJ0`2WWYP40:VKU@@0ZYVA102ZUhh40:^DRP@0Zi660`2/SX840:b;
OP@0ZXMi102VPW<409iiJP@0TFeO101oGe8306]@AP@0F48h1013<b`402dS7P@05a8@100510<300T7
1`@06AHF100X9B@403Hc<@@0A40o101ACD`305eJF0@0JVIU101fLW44085nOAH0oooo000D0?ooo`@0
VIJD102TXZ040;2^[@<0_;Zi1038alH40=GDd`@0h^7P103`knh40?ono@<0m_Og103Yk>d40=_Ri0@0
cmSL102oc=040:jna@@0WK6i0`2?YZl408:LYP@0Mi:M101eSIL407V?U`@0Oi>I0`24UY/408ZIWP@0
SYfQ102CX:<409JRY@@0VJFW0`2MYjP409nWZ0@0X:JU102QY:840:6QWP@0XYnK102SWIT30:FLUP@0
YiVC102XUi040:VDS0@0ZY:9102[T8D30:^=P@@0ZhYm102YQWP40:=nL0@0UgAV1028IeX407EIC@<0
HDY1101??3@403/^:0@091dJ100?3P`4000000<03Pd<100L6QX402XX9`@0>3Dd1015@T44059?C@<0
GU]J101ZIfH407IcL@@0PWmm5P3oool001@0oooo102IUY@40:BRX0@0/:j]0`2l^[T40<S7aP@0eMCC
103RhN040?3_kP@0ookm0`3fmoL40>W/k@@0fn;T103?f=`40;o<d0@0[[k5102M/KT308nV[`@0PYbV
101gTYd407F=U`@0NHnG101oTiT308BFV`@0RYVN102>WJ4409>PX`@0UZ:U102IYJL309fWZ0@0WjNX
102PYZD40:6TXP@0XJ6N102RWi/40:>MV@<0YIbF102WVI<40:RGT0@0ZIB<102ZTXT40:^@Q@<0Zhf1
102[RWd40:V6N0@0Xgi`102GM6H408QWFP@0MEU=0`1QBT4404ll=0@0>bhX100T7AX400l>30@00000
0`0>3@`401`J6P@0:RPW100h=C@404E2@@@0DTm=0`1NFeX406YWIP@0MW=a1022OgdF0?ooo`00503o
ool409VFU0@0Y::P102`[Zd30;bj^@@0b<O6103Ee=<40>;Qh0@0l>o^103oo_d30?Kgm`@0jNc]103K
h^@40<oHg0@0_lc@102^_/D409fa^@<0SjJ_1022W:H407NBW@@0MHfG101iSiL407nCV@<0Q9JK102:
VIh408jMX@@0Tj2S102FXZD409VUY`<0WJNX102OYjP40:2VY@@0XJBR102QXIh40::OV`@0XifI0`2U
W9H40:NIT`@0Z9N@102YU8`40:ZBR@@0Zi250`2[SH440:^:O@@0ZHIh102SOW0409MdIP@0R6MJ101e
FDd3065:@@@0Cc`d100k;RP402@M6P@03`h<1000000300h=30@071XJ100Z:2L403Pe=0@0AD91101B
Cdd305iKFP@0JVMV101fLg44089oOAH0oooo000D0?ooo`@0VIJD102TXZ040;2^[@<0_;Zi1038alH4
0=GDd`@0h^7P103`knh40?ono@<0m_Og103Yk>d40=_Ri0@0cmSL102oc=040:jna@@0WK6i0`2?YZl4
08:LYP@0Mi:M101eSIL407V?U`@0Oi>I0`24UY/408ZIWP@0SYfQ102CX:<409JRY@@0VJFW0`2MYjP4
09nWZ0@0X:JU102QY:840:6QWP@0XYnK102SWIT30:FLUP@0YiVC102XUi040:VDS0@0ZY:9102[T8D3
0:^=P@@0ZhYm102YQWP40:=nL0@0UgAV1028IeX407EIC@<0HDY1101??3@403/^:0@091dJ100?3P`4
000000<03Pd<100L6QX402XX9`@0>3Dd1015@T44059?C@<0GU]J101ZIfH407IcL@@0PWmm5P3oool0
01@0oooo102HUY@40:BQX0@0[jf/0`2k^KP40<O5a0@0dm;A103Qgmh40>k]k0@0oOck0`3hn?L40>c^
k`@0h>GV103Dfmh40<K@d`@0]/?8102V]kd309V/]0@0SJ>/1022VZ<407bCW0@0OI:J1021UI/308JG
W@@0S9^O102@WJ4409BPX`@0Uj:U102JY:H309fWZ0@0WjNW102OY:@409nRX0@0WinL102PW9T40:6K
UP<0XiVD102UUi440:JES@@0Yi>:102XT8L40:Z>P`<0ZH^0102XQgX40:F3M@@0W7U[102>KV4407iQ
E@@0K5=90`1HAC`404Hg<0@0<BPS100K61H400X;2P@000010`0A410401lN7P@0;B/[100j>3L404M5
@`@0De5?0`1OGE/406]XI`@0MgAb1022OgdF0?ooo`00503oool409RFU0@0Y:6P102_[J`30;^i^0@0
alG4103Cd]440>7OgP@0k^g/103mo?/30?Shm`@0k>k_103PiNH40=CKgP@0a]3C102f`lP40:Jg_@<0
VJbd102=Xj`408:JX`@0O9>L101mTYX4086EV`<0QYNM102<Vil4092MX@@0U:2S102GXZD409ZTYP<0
WJNX102OYjL409nTY0@0Wj:P102OWi`40:2LV@@0XI^F0`2SVI@40:FGT@@0YYF=102WThX40:R@Q`@0
ZXj30`2YRh040:R7NP@0YH=e102LNF/408i^H@@0OV5E101/DdT305Q5?0@0ASL`100a:2<401/H5P@0
2P/:10000043014@40@07ahN100]:b/403Xh=`@0AdE3101CDDl305mMF`@0JfQW101gM784089oOAH0
oooo000D0?ooo`@0V9JD102TXJ040:n][0<0^kVh1037aL@40=?Bd@@0hMoN103^kN`40?gln`<0n?Sg
103/k^l40>3UiP@0e=_N1036d=<40;K3b0@0Y[Nm0`2I[;@408fS[0@0PYZS101lTi`407fBVP@0PIFK
0`26Uid408bKW`@0T9fQ102DX:<409NRY@@0VZBV0`2MYjP409nWY`@0WjBT102OXZ0409nOW0@0X9bI
102QViH30:>IU0@0YINA102VUHd40:NCRP@0Z927102ZSX<30:V;P0@0Z8Mj102UPgD409aiJ`@0SViQ
101nHED406aCB@<0F4Dl1016=c04034X8`@06aPF100:2`X400000@<04A0@100O7Qh402d[:`@0>SPg
1017AD<405=AC`<0GeeK101[J6L407MdLP@0PWmm5P3oool001@0oooo102HUY@40:BQX0@0[jf/0`2k
^KP40<O5a0@0dm;A103Qgmh40>k]k0@0oOck0`3hn?L40>c^k`@0h>GV103Dfmh40<K@d`@0]/?8102V
]kd309V/]0@0SJ>/1022VZ<407bCW0@0OI:J1021UI/308JGW@@0S9^O102@WJ4409BPX`@0Uj:U102J
Y:H309fWZ0@0WjNW102OY:@409nRX0@0WinL102PW9T40:6KUP<0XiVD102UUi440:JES@@0Yi>:102X
T8L40:Z>P`<0ZH^0102XQgX40:F3M@@0W7U[102>KV4407iQE@@0K5=90`1HAC`404Hg<0@0<BPS100K
61H400X;2P@000010`0A410401lN7P@0;B/[100j>3L404M5@`@0De5?0`1OGE/406]XI`@0MgAb1022
OgdF0?ooo`00503oool409REU0@0Xj6O102^[:/30;Zh]P@0a/C2103Bd<h40=kLf`@0k>[X103jn?L3
0?_jn@@0lO7a103Uj>P40=SMg`@0c=CG102mb<`40:jk`@<0X[:i102GZ[4408jRZP@0QIZR1024VJ04
08FHW`<0RIVN102?WJ4409>NX@@0UZ6S102HXZD409^TY@<0WjJW102PYZH409jSXP@0W9nN102LW9X4
09fJU`@0WYRD0`2PUY440::ES`@0Xi>;102UT8P40:J>Q@@0Yhb10`2VRGh40:>4M`@0WWe`102CLfH4
08AWG0@0M5]@101RCD@304lo>0@0?C4/100W8Ql401<C4P@010H610061PL301DE5@@08b8R100`;bl4
03dk>`@0BDM6101EDe83065NG@@0K6UX101gM7<4089oOQH0oooo000D0?ooo`@0V9FD102SXIl40:j/
Z`<0^[Rf1036a<840=;@cP@0g]cK103/j^P40?[hm`<0no[i103alO440>GXj0@0f=gO103<e=L40;g8
c0@0[[_10`2R/[T409NZ/@@0SZ:Z1025VZ8408BIX0@0QIRO0`29VIh408nMX@@0TijQ102FXJ<409RR
Y@@0VjBU0`2OYZL40:2VYP@0WZ>R102LWih409bLVP@0WIZG102NV9@30:2FT@@0XYF?102STh/40:F@
R0@0YXj5102WS8430:J9OP@0XhAg102NOG0409=cIP@0Q6ML101dFe04069=A0<0Cclh100m<B`402LR
7`@04a<B10041PH400H61`<05ADE100S8R84030_;`@0?C/k1019AdH405ECDP<0HEiM101/JFP407Md
L`@0PWmn5P3oool001@0oooo102HUI@40:>QW`@0[Zb[0`2j^;H40<K4`P@0d]3>103Ng=/40>cZj0@0
n_Sg0`3kn_T40?7al@@0iNSX103HgMl40<cDe`@0_LS<102^^l430::b^@@0UjZa102>XZX408FJXP@0
Q9VP1025V9l308VIWP@0SifQ102CWZ4409JQX`@0V::U102KY:D309nVY`@0X:JV102NXj8409bOWP@0
W9bJ102MVYL409jHU0<0X9JA102RUHl40:>CR`@0YI28102VSXD40:N<P@<0YXUn102SQ7L409imL0@0
Tg=V1024Ie`407AKD0@0HTe40`1??cP403da;0@09b8O100C4a8400@61P@01PH70`0E5AD402<R8P@0
<2l_100m>c/404U7AP@0EE=B0`1QGUd406aYJ0@0MgAc1022OghF0?ooo`00503oool409REU0@0Xj6O
102^[:/30;Zh]P@0a/C2103Bd<h40=kLf`@0k>[X103jn?L30?_jn@@0lO7a103Uj>P40=SMg`@0c=CG
102mb<`40:jk`@<0X[:i102GZ[4408jRZP@0QIZR1024VJ0408FHW`<0RIVN102?WJ4409>NX@@0UZ6S
102HXZD409^TY@<0WjJW102PYZH409jSXP@0W9nN102LW9X409fJU`@0WYRD0`2PUY440::ES`@0Xi>;
102UT8P40:J>Q@@0Yhb10`2VRGh40:>4M`@0WWe`102CLfH408AWG0@0M5]@101RCD@304lo>0@0?C4/
100W8Ql401<C4P@010H610061PL301DE5@@08b8R100`;bl403dk>`@0BDM6101EDe83065NG@@0K6UX
101gM7<4089oOQH0oooo000D0?ooo`@0V9FC102RX9h40:f[Z@<0^;Jd1034`L040<o=b`@0fmWG103X
i^@40?Gbl0<0o__j103em?<40>WZjP@0gN3Q103Bf=X40<C=d0@0]L350`2[^;`40:2_]@@0VZZ`102B
XjT408jPYP@0S9jS0`2?WJ8409BPX`@0UZ6S102GXZ@409VRY0@0W:>T0`2PYZD40:2UY0@0WJ6P102J
WI`409VJU`@0VYND102KUY8309jDS`@0Wi:=102PT8P40:6=Q@@0XX^2102RRGh30:65NP@0W7mc102E
MV/408U/H@@0NV5F101ZE4/405Q6?`<0ASTd100c:bL401lL6`@03Pl?10000`@400d>3`<06a/K100X
9bL403@c<`@0@Cln101<BTT405QEE0<0Hf1O101]JfT407QeM0@0Ph1n5P3oool001@0oooo102HUI<4
0::PWP@0[J^Y0`2h][@40<C1`0@0clg;103KfML40>SVi0@0mO;`0`3nnoX40?Gdl`@0jN[Z103Mh>44
0=;HfP@0a<g@102e`<D30:^h_0@0X:ne102JZ[0409:SZ@@0SZ2V102<WZ<308nMXP@0U:2S102FXJ<4
09NRY0@0VJ:T102LXj@30:2VY@@0X:FT102MXJ0409ZMW0@0VIZG102JUi@409^FTP<0WYB?102OTXd4
0:2@R0@0XHf5102RRh840::9OP<0XHEj102LOg<409EfJ`@0RFaQ101jHEH406YDB`@0F4Ho0`16>C@4
03<[9`@07a`K100>3`l4000310@03@h?0`0K6a/402PW9`@0=3<c1011?ch404a:B@@0F5ED0`1SH5l4
06e[J@@0N7Ed1023P7hF0?ooo`00503oool409RET`@0XZ2N102]ZjT30;Rf]0@0a<70103?cL/40=_I
e`@0j>KT103el_030?kknP@0mOCc103Yj^X40=gPh@@0d]SJ1034cM040;G0a@<0ZkRl102P[kD409ZZ
/0@0TZ>Y102>X:H408bNX`<0SifR102DX:<409JQX`@0Uj:T102IXZ@409bSY0<0X:JU102PYJ@409fQ
X0@0VYfL102IVYL409ZGU0@0ViJB0`2NU8l409nBS@@0X928102QSHD40::;PP@0XXUn0`2QQGX409ao
L`@0UGI[1029K64407YQEP@0JUA;101HASl304Hi=0@0<b/W100O71/400h?3`@000<4100=3Pl301/K
6`@0:2LW100d<c<4044o?P@0C4Y9101HEE@306=PG`@0KF]Y101hMG@408>0OQH0oooo000D0?ooo`@0
UiBC102RWid40:bYZ0<0]kBb1031_kd40<c:b0@0f=GD103ThMl40?3]j`<0oOWg103jmoD40>g/k0@0
h^?T103Gf]`40<_Ad`@0^lG80`2a_<040:Ve^@@0Xk2d102MZk0409RWZ`@0UjFY0`2HY:L809^TYP@0
Vj>U102KXZ@409fSX`<0X:BT102OXZ8409bOW`@0VY^J102HV9H409NDTP@0V9>?0`2KTHd409^?RP@0
W8f6102LRH8409f7O`@0W8Ak0`2IP7H409=hKP@0RW1V101mIE`406mJD@@0Gdi6101>@3X303/c;`@0
:BDS100I61P400T<3@@010L8100D5AH3024Q8@@0;Bd]100i>3P404A3@P@0Cdi=101JF5L306ERH@@0
Kfa[101iMWD408>0OaH0oooo000D0?ooo`@0UiBC102RWid40:bYZ0<0]kBb1031_kd40<c:b0@0f=GD
103ThMl40?3]j`<0oOWg103jmoD40>g/k0@0h^?T103Gf]`40<_Ad`@0^lG80`2a_<040:Ve^@@0Xk2d
102MZk0409RWZ`@0UjFY0`2HY:L809^TYP@0Vj>U102KXZ@409fSX`<0X:BT102OXZ8409bOW`@0VY^J
102HV9H409NDTP@0V9>?0`2KTHd409^?RP@0W8f6102LRH8409f7O`@0W8Ak0`2IP7H409=hKP@0RW1V
101mIE`406mJD@@0Gdi6101>@3X303/c;`@0:BDS100I61P400T<3@@010L8100D5AH3024Q8@@0;Bd]
100i>3P404A3@P@0Cdi=101JF5L306ERH@@0Kfa[101iMWD408>0OaH0oooo000D0?ooo`@0UiBC102R
Wid40:bYZ0<0]kBb1031_kd40<c:b0@0f=GD103ThMl40?3]j`<0oOWg103jmoD40>g/k0@0h^?T103G
f]`40<_Ad`@0^lG80`2a_<040:Ve^@@0Xk2d102MZk0409RWZ`@0UjFY0`2HY:L809^TYP@0Vj>U102K
XZ@409fSX`<0X:BT102OXZ8409bOW`@0VY^J102HV9H409NDTP@0V9>?0`2KTHd409^?RP@0W8f6102L
RH8409f7O`@0W8Ak0`2IP7H409=hKP@0RW1V101mIE`406mJD@@0Gdi6101>@3X303/c;`@0:BDS100I
61P400T<3@@010L8100D5AH3024Q8@@0;Bd]100i>3P404A3@P@0Cdi=101JF5L306ERH@@0Kfa[101i
MWD408>0OaH0oooo000D0?ooo`@0UiBC102RWid40:bYZ0<0]kBb1031_kd40<c:b0@0f=GD103ThMl4
0?3]j`<0oOWg103jmoD40>g/k0@0h^?T103Gf]`40<_Ad`@0^lG80`2a_<040:Ve^@@0Xk2d102MZk04
09RWZ`@0UjFY0`2HY:L809^TYP@0Vj>U102KXZ@409fSX`<0X:BT102OXZ8409bOW`@0VY^J102HV9H4
09NDTP@0V9>?0`2KTHd409^?RP@0W8f6102LRH8409f7O`@0W8Ak0`2IP7H409=hKP@0RW1V101mIE`4
06mJD@@0Gdi6101>@3X303/c;`@0:BDS100I61P400T<3@@010L8100D5AH3024Q8@@0;Bd]100i>3P4
04A3@P@0Cdi=101JF5L306ERH@@0Kfa[101iMWD408>0OaH0oooo000D0?ooo`@0UiBB102QWY`40:^X
YP<0]K:`102o_;X40<W7a@@0e=7?103Og=X40>_Xi@<0moCa103ln?L40?7_kP@0i^KV103KgMd40=3D
e@@0`/W;0`2h`L<40;:k_P@0[;Ji102V/K@40::]/@@0X:Z]0`2QZJ/40::XZ@@0XJNX102OYJH409nT
Y@@0Wj:R0`2PXj8409nQX0@0W9jM102JVYT409NFU0@0UI:@102FT8d309N>RP@0Uhb7102GRX@409J6
O`@0UX=k102DOWH3091iL0@0R75Y101oJF44079NE`@0I5=<101EAd4404<j=P<0<B`Z100Q820401@E
5@@01`/<100?4A8401/M7@<09bPX100c<c8403hm?@@0B4M7101CDE0405eKFP<0IfES101aKVd407Yg
MP@0Q85o5P3oool001@0oooo102GU9840:6NW0@0ZjRV0`2e/[040;nl^P@0bLO5103DdLl40=oLfP@0
jnSU0`3gm?440?chm`@0lNo^103Vi^H40=_Mg@@0d=CE1032bL/30;S1``@0/[^n102/][T40:Ja]0@0
XZfa102PZZd30:6YZ`@0XZRY102QYjP409nUYP@0WjBU102OXZ830:2SXP@0Wj6P102LWYd409ZJV@@0
UiJD102ETY0409J@S@<0Uhj:102GS8L409N:Q0@0UXIo102FPg/409AnMP<0T7U`1028LFT407mYH@@0
LUiG101TDd`405E7@@@0@cXf0`0a;2X4024P80@051DE10072``400lA4P@06adM0`0W:2P403<c<P@0
?Sdm1018AdL405=AD0@0GE]J0`1WIF<4075^K@@0NWMf1024PGlF0?ooo`00503oool409NDTP@0XIjL
102[Z:H30;Fb/0@0_kbj1039alD40=CAc`@0gmcJ103[j>D30?Odl@@0o?Sg103aknh40>KViP@0fmgM
103@e=D40<;9b`<0^<73102b^kh40:bf^@@0Y[6d102R[K440:2Z[@<0XJV[102RZ:T40:6WZ0@0WjFV
102OY:D409nRXP<0X:>R102OXJ0409bNW@@0VYZI102GUY@409FBT0@0UY2=0`2GSXX409N<Q`@0UhZ4
102FQWl409J3N`@0U7if0`2@NG0408QaJ@@0OfUQ101bGUL406ACC0@0EDM11013>SH3034/:P@08B0P
100D5AD400L;30@03a4B100K7Ad302LX:0@0<c<b100n?Cd404Q7A`@0De5@101MFeX306MUH`@0LFi]
101jMgH408B1OaH0oooo000D0?ooo`@0UiBB102QWY`40:^XYP<0]K:`102o_;X40<W7a@@0e=7?103O
g=X40>_Xi@<0moCa103ln?L40?7_kP@0i^KV103KgMd40=3De@@0`/W;0`2h`L<40;:k_P@0[;Ji102V
/K@40::]/@@0X:Z]0`2QZJ/40::XZ@@0XJNX102OYJH409nTY@@0Wj:R0`2PXj8409nQX0@0W9jM102J
VYT409NFU0@0UI:@102FT8d309N>RP@0Uhb7102GRX@409J6O`@0UX=k102DOWH3091iL0@0R75Y101o
JF44079NE`@0I5=<101EAd4404<j=P<0<B`Z100Q820401@E5@@01`/<100?4A8401/M7@<09bPX100c
<c8403hm?@@0B4M7101CDE0405eKFP<0IfES101aKVd407YgMP@0Q85o5P3oool001@0oooo102FTi84
0:2MV`@0ZJJT0`2b[jh40;bi]`@0a/?1103@cL/40=[Ge@@0iN;O0`3`kNX40?_fm0@0m_;`103Zj>L4
0=oOg`@0e=KG1039cLh30<76b0@0^Ko1102e_;h40:jf^0@0Z[:d102Y/;430:R^[P@0Yj^[102VZZT4
0::WYP@0Y:NV102QXj830:2RX@@0Wj2O102MWI`409ZIU`@0UYFC102CTHl409>>R`<0U8b8102CRH@4
09:6P@@0Sh9l102?OWL408]iLP<0QW=/101nJf@407=RF`@0IeQB101ICDP404Y0?@@0>3<a0`0W9RD4
01`L7@@03a4B100?4Q<401XL70@092DV0`0_;bl403Ti>@@0@d92101=C4/405IEE0@0H5iM0`1YIfH4
079`K`@0NgUg1024PH0F0?ooo`00503oool409JCTP@0X9fK102YYZ@30;:_[P@0_;Vg1036`l440=3=
b`@0f]OE103Uh]l30?3]jP@0noKd103fl_040>[Xi`@0gmoO103De]L40<W=cP<0`LK8102i_l440;Fl
_P@0[[Jh102Z/[@40:V`/@<0Z:j^102WZj/40:JZZ@@0XZNV102TYjH40:6SXP<0X::Q102OX9l409fM
W0@0VYVG102FUI<409>AS`@0Thj;0`2DS8P409>9Q0@0TXJ1102?PW`408mnM`@0RgUb0`26Lf`407i[
I0@0Lf9K101WF58405U=B0@0BT0m100h<c4302LV9@@071`M100?4A8400lB4`@06Q`L100T9BH302l_
;`@0>CTi1013@T8404e<B`@0EUED101PGUd306UWIP@0LW1_101kNGL408B1P1H0oooo000D0?ooo`@0
UY>B102PWI/40:VVY0<0/Zn^102l^KL40<K3`@@0d<g;103JemD40>GRg`<0l>gZ103km_@40?Kbl0@0
j^SW103Ogml40=CFe`@0bLg>0`31a/P40;Vo`@@0]Kbn102^][P40:Zb]0@0ZK2a0`2X[Zh40:N[Z`@0
YZZY102RYjH40:BWYP@0XJ>R0`2PXZ4409nPW`@0WIfL102JVIL409JET`@0Ti6?102CSX/309B<R0@0
ThV4102BQX4408n2O0@0Sgig102;NG8308IcK0@0OV]T101cHU/406MHDP@0FDe8101:@3d403Pc<@<0
9bHU100L71d400lA4P@03a8C100J71`402@U9P<0;bl_100i>CT404=2@P@0CDa;101FEE@4061NG@<0
JFMV101bL6l407]iM`@0Q8605P3oool001@0oooo102FTi840:2MV`@0ZJJT0`2b[jh40;bi]`@0a/?1
103@cL/40=[Ge@@0iN;O0`3`kNX40?_fm0@0m_;`103Zj>L40=oOg`@0e=KG1039cLh30<76b0@0^Ko1
102e_;h40:jf^0@0Z[:d102Y/;430:R^[P@0Yj^[102VZZT40::WYP@0Y:NV102QXj830:2RX@@0Wj2O
102MWI`409ZIU`@0UYFC102CTHl409>>R`<0U8b8102CRH@409:6P@@0Sh9l102?OWL408]iLP<0QW=/
101nJf@407=RF`@0IeQB101ICDP404Y0?@@0>3<a0`0W9RD401`L7@@03a4B100?4Q<401XL70@092DV
0`0_;bl403Ti>@@0@d92101=C4/405IEE0@0H5iM0`1YIfH4079`K`@0NgUg1024PH0F0?ooo`00503o
ool409JCT@@0WY^J102WY:830;2]Z`@0^KJd1032_kd40<c8aP@0eM;@103Og=T30>[Vh`@0m?3]103h
m?840>gYj0@0hn7P103IfMP40<o@d0<0al[:102o`l@40;c0`@@0][^l102a][L40;6d]0<0[[2`102/
[Zd40:Z/ZP@0YZRW102VYjH40:>TX`<0XZ:P102OWYd409fKVP@0VINF102ETi4409:?S@@0THb:0`2A
RXH408n6PP@0S89n1029OWT408QjM@@0PgA^0`1lKFP407=UG`@0JEeG101MDTd404m7@`@0?cXh100_
;R`3024R8P@05ALH100C5AH401/M7P@092DV100];Rh303Hf=P@0?clo1018B4L4055@D0@0FUUH101S
HF0306aZJ0@0M79`101lNWP408F2P1H0oooo000D0?ooo`@0UY>A102NViX40:NTXP<0/:f[102i][@4
0<:o_@@0c<S6103Ed]040=oLf@<0j^KS103dl>d40?SdlP@0kNWX103ShN040=WIf0@0cm3@0`37b/X4
0;o3a0@0_<31102f^k`40;6f]`@0/KBd0`2^/;040:b^[@@0ZZbZ102VZ:L40:JWYP@0XjBS0`2RXZ04
09nNW@@0WI^J102IUiH409FCT@@0TXn=102AS8X3096:QP@0ShJ2102<PWh408UnN@@0R7Ye1023M6h3
07a]J0@0LfEO101YGEL405eBC@@0CdM3100o>SP402l^;0<08B8R100E5aP401<E5P@06adN100T9BH4
02d^;P<0=SHf100o?cl404Q8A`@0DE1@101JFEP406=QH0<0K6YX101dLW0407ajN0@0QH:05P3oool0
01@0oooo102FTi4409jKVP@0YjBR0`2`[J/40;Vf]0@0`[nm103<b<H40=GBd0@0gmcI0`3Zi^<40?C`
k@@0n?Cb103]jNP40>?Qh0@0fMWH103?d=030<O:bP@0_l?4102l`<440;Jk_0@0/KJg102a];@30:j`
/0@0[:j]102Z[:X40:JXY`@0YZNV102SY:<30::RX0@0WijM102MViX409VGUP@0UI>A102BShd4096<
RP<0THZ6102?QX8408b2OP@0RGii1028NWD408=dKP<0O6eX101cIEl406UME`@0GE9=101?Ad<403lj
>0@0;bh/0`0Q8R8401DG60@04aDF100K7Ah402@U9P@0;Bh^0`0f=SH403lo?`@0B4Q7101AD50405YI
F0@0Hf5P0`1/JVP407AbL0@0O7Yh1025PX0F0?ooo`00503oool409JCT@@0WY^J102WY:830;2]Z`@0
^KJd1032_kd40<c8aP@0eM;@103Og=T30>[Vh`@0m?3]103hm?840>gYj0@0hn7P103IfMP40<o@d0<0
al[:102o`l@40;c0`@@0][^l102a][L40;6d]0<0[[2`102/[Zd40:Z/ZP@0YZRW102VYjH40:>TX`<0
XZ:P102OWYd409fKVP@0VINF102ETi4409:?S@@0THb:0`2ARXH408n6PP@0S89n1029OWT408QjM@@0
PgA^0`1lKFP407=UG`@0JEeG101MDTd404m7@`@0?cXh100_;R`3024R8P@05ALH100C5AH401/M7P@0
92DV100];Rh303Hf=P@0?clo1018B4L4055@D0@0FUUH101SHF0306aZJ0@0M79`101lNWP408F2P1H0
oooo000D0?ooo`@0UI:@102MVYP40:FRX0<0[JZX102f/k440;jk^@@0alC1103@c<X40=WEd`<0hmoL
103]j>H40?KakP@0l>[X103Vh^440=gKfP@0e=?B0`3;c<`40<G7a`@0`/C3102m_kl40;Rj^P@0][Nf
0`2a/[440;2`[P@0[Jf[102ZZZP40:RWY@@0YJBS0`2SXIl409nMW0@0ViZH102HUY@409>AS`@0THj<
102>RXL308f7Q0@0RX>01027Og`408EkM`@0PWMb101mLF`307AXI0@0JV1L101PEe<405=<B@@0AD4o
100g=S@402PY:@<06Q`M100G6AX401lP8@@09RLW100];Rh403Df=P<0?Shm1016ADD404i=C@@0EUED
101NGE`406ITH`<0KVa[101fM78407ikNP@0QH>15P3oool001@0oooo102ETY0409fJV0@0YJ:P0`2]
ZZP40;Jc/@@0_[^i1037a<440=3<bP@0fMGC0`3Sgm`40>gXiP@0m_7^103`j^P40>KRh@@0gM_J103D
dm830<_<c0@0aLO71032a<<40;fo_`@0^;Zj102f]kH30;6b/@@0/;2^102][J/40:ZZZ0@0Z:NU102U
Y:<30:>QW`@0WifL102KVYP409RFU0@0Ti6?102ASX`408j:Q`<0SHN4102:Ph0408MoO0@0QG]g1022
Mg8407eaK0<0M6QT101ZH5`4061GD`@0Dda91015@Cl403Lf=0@0:2TY0`0J71d401LI6P@07b0Q100V
9bL402d^;P@0=CHf0`0n?Sd404I5A@@0CTe=101FEE@405iMG0@0IVAS0`1^K6/407IdLP@0OW]j1025
Ph4F0?ooo`00503oool409FBT0@0WIZH102UXZ030:fZZ0@0][>a102n^kT40<O4`@@0d<c:103IeM<3
0>?Og0@0kNSV103flNh40?3Zj0@0i^;Q103MfmX40=CCdP<0blc<1035alL40<;4``@0_Kno102h^[X4
0;Jg]P<0/K:a102`/:h40:f]Z`@0ZZZX102XYjD40:FTX`<0Xj6O102OWI`409^JV0@0V9JD102CTHl4
096>S0@0SXZ70`2=Qh@408Z3P0@0Qgml1025NgL4089gLP@0OG5/0`1dJ6@406YPG0@0H5MC101CC4T4
04E1?`@0=cHd100X:BT301XL7@@05aTJ100O824402HW9`@0;Bh^100e=SH303hn?@@0ATE5101>CDd4
05IEE0@0GUeL101VI6<306i/J`@0MWAb101nNgX408F3PAH0oooo000D0?ooo`@0UI:@102MVYP40:FR
X0<0[JZX102f/k440;jk^@@0alC1103@c<X40=WEd`<0hmoL103]j>H40?KakP@0l>[X103Vh^440=gK
fP@0e=?B0`3;c<`40<G7a`@0`/C3102m_kl40;Rj^P@0][Nf0`2a/[440;2`[P@0[Jf[102ZZZP40:RW
Y@@0YJBS0`2SXIl409nMW0@0ViZH102HUY@409>AS`@0THj<102>RXL308f7Q0@0RX>01027Og`408Ek
M`@0PWMb101mLF`307AXI0@0JV1L101PEe<405=<B@@0AD4o100g=S@402PY:@<06Q`M100G6AX401lP
8@@09RLW100];Rh403Df=P<0?Shm1016ADD404i=C@@0EUED101NGE`406ITH`<0KVa[101fM78407ik
NP@0QH>15P3oool001@0oooo102DTI0409bIU`@0Xj2N0`2[Z:H40;:_[@@0^[Ne1032_k`40<[7a0@0
d/o<0`3Kem@40>COg@@0kNSU103`j^P40>WThP@0h=cK103HeM<30=3>c@@0bLW81037a/D40<;2`@@0
_[fk102k^KL30;Fd/P@0/k6_102_[J/40:f[Z0@0ZJNT102VXj430::PWP@0WYbJ102JV9H409NDT`@0
TXn>102>S8X408Z7Q@<0RXF21026P7h408=mNP@0PWUf101nM74407I]JP<0KFEQ101RFeP405MBD0@0
BdQ6100n?Cd4034b<P@092HW0`0J71`4028S8`@0:BXZ100_<30403Hg=`@0?Shn0`15AD@404a<B`@0
E5=B101KFUT4069QH0@0JVQW0`1aKfh407QfM0@0Ogak1026Ph8F0?ooo`00503oool409BAT0@0W9VG
102SX9h30:^XYP@0/Zn]102j]kD40<:o_0@0b/O4103Bcl`30=_Ge0@0i=oM103]j>D40?3Zj0@0jNCR
103Pg=/40=SEd`<0d<k=1039bLP40<O6a@@0`/;1102n_K/40;^i]`<0]KBb102c/Jl40:n]Z`@0[J^X
102YYj@40:JSX@<0XZ2N102NW9X409ZHUP@0UiBC102BShh408j<RP@0RXN50`2:QH8408J0OP@0Pgej
1022NGH407idL@@0MVeZ0`1]IF44069KF0@0Ee9@101;B4H403hm?@@0<C8b100T9RL301XL70@08R<S
100Y:RX402l`<0@0=SLg100n?Sh304E5A0@0C4a;101DDe8405]JF@@0HV5P101ZJ6L3075_KP@0N7Id
101oO7/408J3PQH0oooo000D0?ooo`@0U96@102LVIL40:>PWP<0ZjRV102b[jd40;Zg]@@0`[nl103:
al@40=;?c0<0fmOD103Tgmd40>gXi@@0l>[X103Yi>840>3Lf`@0f=GC0`3@c/d40<W9b0@0alK51032
`/440;jm^`@0^kVg0`2e];840;>a[`@0[jf[102]ZjP40:VWY0@0YZ>Q0`2RX9h409jLVP@0VYRF102G
U9<409:?SP@0SXb:102:QhD308Z5PP@0QX1n1023OGX4089iMP@0OWAa101fKFX306eUH@@0HU]H101G
DU0404]8AP@0?Sdm100a<S8402@V9`<06Q`L100R8b<402TZ:P@0;c0`100f=cL403hn?P<0ADE4101<
C4/405ACDP@0FeYI101RHF0406YXI`<0LFm^101hMW@407mlN`@0QX>25P3oool001@0oooo102DTHl4
09^GUP@0XIjL0`2XYJ<40:n/ZP@0][>`102m^KL40<C1_P@0c<S50`3Ccl`40=_Fe0@0h]gJ103Yi>44
0>_UhP@0i=kK103KemD30=;?c@@0c<[81039a/@40<K3`@@0`Kjl102n^kP30;Vf/`@0];6_102a[Z/4
0:fZY`@0ZJJT102VXj030::OW@@0WY^I102IUiD409FCT@@0T8j<102;RHP408N4P`<0QH5o1022OW`4
085lNP@0OgQe101iLFl4075ZJ0<0If9P101LF5H4051>C@@0ATE5100i>c/402d`<0@092HV0`0U9RH4
02`];@@0<c<c100i>CT403lo?`@0ATI50`1<C4/405=BD@@0FUQH101PGeh406MUI0@0KF]Z0`1dLG04
07YhMP@0P7il1027Q88F0?ooo`00503oool409BAS`@0ViNF102QWY`30:RUX`@0[jbZ102f/k040;fi
]`@0a<6n103<b<D30=??c0@0fmKD103RgMX40>WTh@@0jnGR103Tg]/40=_Ge@<0d/o=103<b/P40<W6
a0@0a/?11031_[`40;jk^0<0^KJc102d/Jl40;6^Z`@0[JZW102YYZ@40:JSX0<0XYnM102NViT409VG
U@@0UI>A102@SX`408^9R0@0QhB30`25PGl4089nO0@0PGaj101oN7D407UaK`@0LFYX0`1WHV0405aH
EP@0D4i=1016ADD403Tk>`@0;C0`100T9RH302DV9P@0;2d]100c<c<403Ti>@@0?clo1016ATD304a<
B`@0De9A101JF5P4061OGP@0IfET101]JfX307AaL0@0NWQf1020OW`408N4PQH0oooo000D0?ooo`@0
U96?102KUiH40:6NW0<0Z:FS102_[:X40;Jc/0@0_KVg1034`Kh40<c8a@<0dlo<103Ke]@40>;MfP@0
jNCQ103[iN840>CNf`@0fmOE0`3Bcld40<c:b0@0bLK41036`l440<6n_0@0_[^h0`2i][<40;Ba[`@0
/Jj[102]ZZL40:VVY0@0YZ>P0`2RWid409jKV@@0VINE102ETi44092>S0@0RhV81027Q8<308F1O`@0
PWil1021O7X407mhM@@0NG5_101aJVP306MRH0@0G5QF101@CTd404I5A@@0>C/k100]<30402@V9P<0
9BHV100/;Bd403<c<`@0>CTi100o?cl404I6A@<0C4a;101CDU4405YHF0@0H5mN101WIF@406e[JP<0
M75`101jN7H4081nO0@0QhB25P3oool001@0oooo102DTHl409^GUP@0XIjL0`2XYJ<40:n/ZP@0][>`
102m^KL40<C1_P@0c<S50`3Ccl`40=_Fe0@0h]gJ103Yi>440>_UhP@0i=kK103KemD30=;?c@@0c<[8
1039a/@40<K3`@@0`Kjl102n^kP30;Vf/`@0];6_102a[Z/40:fZY`@0ZJJT102VXj030::OW@@0WY^I
102IUiD409FCT@@0T8j<102;RHP408N4P`<0QH5o1022OW`4085lNP@0OgQe101iLFl4075ZJ0<0If9P
101LF5H4051>C@@0ATE5100i>c/402d`<0@092HV0`0U9RH402`];@@0<c<c100i>CT403lo?`@0ATI5
0`1<C4/405=BD@@0FUQH101PGeh406MUI0@0KF]Z0`1dLG0407YhMP@0P7il1027Q88F0?ooo`00503o
ool409>@SP@0VIJD102OW9X30:FRX0@0ZjRV102b[Z`40;Rd/P@0_[Zh1035`Kh30<_7a@@0d/g;103H
dm040=kIeP@0i=kK103Ugm`40=kHe@<0eM7>103>b/P40<W5``@0a/;01033_k`40<2k]`<0^kJc102e
/Jh40;:]ZP@0[JVV102YYZ840:JRW`<0XIjL102LVYL409RFU0@0Ti6?102?SH/408V7QP@0Q8:00`21
Ogd407ilN`@0Og]i101lMWD407A_KP@0KVUW0`1UHEl405QFE@@0C4a<1012@d<403Pj>`@0;Bl`100/
;Bd3038b<`@0>3Ph100m?Cd404=3@P@0B4Q8101>CDd305ACDP@0FEQH101OGUd406ESH`@0JfUX101a
Kfd307IdL`@0O7Yh1022Ogh408N5PaH0oooo000D0?ooo`@0Ti2>102IUY@409nLVP<0YJ:P102[Z:H4
0;:^[0@0^;Bb102n^[P40<G1_P<0blO5103BcL/40=SCd0@0g]WF103Tg]/40>GOg0@0g]SE0`3EdLh4
0<k:b0@0bLG31036`/040<>o_0@0`;^g0`2k][<40;Fa[P@0/ZfZ102]ZJH40:VVXP@0YZ:O0`2QWY`4
09bJU`@0V9JD102CTHl408n=R`@0RHN61024PX03085oO@@0OWak101oNgT407afM@@0M6m^101^JFL3
06EQG`@0F5IE101<C4`40493@`@0>3Xk100];c0402`];@<0<S8c100h>3P403dm?@@0@d=21018B4P4
04i=C@<0E5=B101IF5P405mNG@@0IF=S101[JFP4075_K@<0MWAc101lNWP4089oOP@0QhF35P3oool0
01@0oooo102CT8h409VFU0@0WibJ0`2UXZ040:^XYP@0/Zj/102h];840;jj^0@0aL6n0`3;alD40=;=
b`@0f=?@103NfMH40>CNf`@0iMoL103Nf=D30=GAcP@0c/[81039aL<40<K2`0@0`knl1030^kL30;^f
/`@0]K6^102b[JX40:fYYP@0ZJJR102VXYl30:6NW0@0W9ZG102HUY@409>AS`@0Shf;1029QhH408B2
P0<0PGmm101nO7/407mkN@@0O7Ie101dKfh406iYI`<0IF5O101HEUD404a<C0@0@T=3100h>S/402d_
<0@0;2d]0`0b<S<403Ph>0@0?Cdm1013@d8404Q8B0@0CTe=0`1DDe8405UHF0@0GeiM101UHf<406]Y
J0@0LFm]0`1fM7<407ajN0@0PWmn1027QH<F0?ooo`00503oool409>@SP@0VIJD102OW9X30:FRX0@0
ZjRV102b[Z`40;Rd/P@0_[Zh1035`Kh30<_7a@@0d/g;103Hdm040=kIeP@0i=kK103Ugm`40=kHe@<0
eM7>103>b/P40<W5``@0a/;01033_k`40<2k]`<0^kJc102e/Jh40;:]ZP@0[JVV102YYZ840:JRW`<0
XIjL102LVYL409RFU0@0Ti6?102?SH/408V7QP@0Q8:00`21Ogd407ilN`@0Og]i101lMWD407A_KP@0
KVUW0`1UHEl405QFE@@0C4a<1012@d<403Pj>`@0;Bl`100/;Bd3038b<`@0>3Ph100m?Cd404=3@P@0
B4Q8101>CDd305ACDP@0FEQH101OGUd406ESH`@0JfUX101aKfd307IdL`@0O7Yh1022Ogh408N5PaH0
oooo000D0?ooo`@0TXn>102HU9<409fJV0<0XYnM102XY:840:fZZ0@0/jn]102h];840;jj^0<0`knm
1039a<840<k9a`@0dlk<103Hdm080=kHe@<0em7=103?b/L40<S3`@@0aL2m1032_KX40<2j]P<0^kFa
102e/:`40;6/Z@@0[JRU102YYJ440:JQWP<0XIfJ102LVIH409NDTP@0THn>102>S8/408R6QP@0PX60
0`1nOWd407akNP@0OGYh101iMG@4079^K@@0JfQW0`1QGel405EEE@@0Bda<1010@T8403Tk>P@0=CDf
100j>SX303hn?P@0@d921017AdL404a<B`@0DE1@101FEE@305]JF@@0H5mN101UHf<406YXI`@0Kfe/
101dLW4307UgMP@0OWaj1023P7l408R5Q1H0oooo000D0?ooo`@0TXn>102HU9<409fJV0<0XYnM102X
Y:840:fZZ0@0/jn]102h];840;jj^0<0`knm1039a<840<k9a`@0dlk<103Hdm080=kHe@<0em7=103?
b/L40<S3`@@0aL2m1032_KX40<2j]P<0^kFa102e/:`40;6/Z@@0[JRU102YYJ440:JQWP<0XIfJ102L
VIH409NDTP@0THn>102>S8/408R6QP@0PX600`1nOWd407akNP@0OGYh101iMG@4079^K@@0JfQW0`1Q
Gel405EEE@@0Bda<1010@T8403Tk>P@0=CDf100j>SX303hn?P@0@d921017AdL404a<B`@0DE1@101F
EE@305]JF@@0H5mN101UHf<406YXI`@0Kfe/101dLW4307UgMP@0OWaj1023P7l408R5Q1H0oooo000D
0?ooo`@0TXn>102HU9<409fJV0<0XYnM102XY:840:fZZ0@0/jn]102h];840;jj^0<0`knm1039a<84
0<k9a`@0dlk<103Hdm080=kHe@<0em7=103?b/L40<S3`@@0aL2m1032_KX40<2j]P<0^kFa102e/:`4
0;6/Z@@0[JRU102YYJ440:JQWP<0XIfJ102LVIH409NDTP@0THn>102>S8/408R6QP@0PX600`1nOWd4
07akNP@0OGYh101iMG@4079^K@@0JfQW0`1QGel405EEE@@0Bda<1010@T8403Tk>P@0=CDf100j>SX3
03hn?P@0@d921017AdL404a<B`@0DE1@101FEE@305]JF@@0H5mN101UHf<406YXI`@0Kfe/101dLW43
07UgMP@0OWaj1023P7l408R5Q1H0oooo000D0?ooo`@0TXn>102HU9<409fJV0<0XYnM102XY:840:fZ
Z0@0/jn]102h];840;jj^0<0`knm1039a<840<k9a`@0dlk<103Hdm080=kHe@<0em7=103?b/L40<S3
`@@0aL2m1032_KX40<2j]P<0^kFa102e/:`40;6/Z@@0[JRU102YYJ440:JQWP<0XIfJ102LVIH409ND
TP@0THn>102>S8/408R6QP@0PX600`1nOWd407akNP@0OGYh101iMG@4079^K@@0JfQW0`1QGel405EE
E@@0Bda<1010@T8403Tk>P@0=CDf100j>SX303hn?P@0@d921017AdL404a<B`@0DE1@101FEE@305]J
F@@0H5mN101UHf<406YXI`@0Kfe/101dLW4307UgMP@0OWaj1023P7l408R5Q1H0oooo000D0?ooo`@0
TXn=102FTi4409^GUP<0WibJ102TXIl40:VUX`@0[JZX102b[Z`40;Nc/@<0^kNe1030_;T40<G0_P@0
bLC2103=b<H40=;<b@@0e]7>0`3Fcl`40<o9a@@0al:n1031_;T40;ni]P@0_KNd0`2h/jl40;:]ZP@0
[jZW102[YZ<40:VSX0@0YJ2M0`2PW9T409^HU@@0UY>A102@SXd408f;RP@0QhJ61025Ph8307emO@@0
OGak101lNGP407IcL`@0L6i]101XIVH305mNGP@0EUIF101:C4`40493@`@0@D501013@T8404I6A@<0
BTU9101>CDd4059AD0@0EUED101JFEP405iMG0<0HV5P101WIF@406]YJ0@0Kfe/101cLG0407QeM0<0
O7Yh1020OW`408F2P0@0RHJ45P3oool001@0oooo102BShd409JCT@@0ViNF0`2OW9X40:BQW`@0ZJFS
102]ZZP40;:^[0@0]k>a0`2k]kD40<2l^@@0aL2n1039a<840<g8aP@0d/c9103FdLh30=K?c0@0clW5
1037`[h40<6l^@@0_kVf102m]k@30;Rc[`@0/ZfZ102_ZZL40:^VX`@0ZJ>P102UX9d30:2LV@@0ViRE
102FTi44092>S@@0SH^:1027QXH408F3PP<0OGem101mO7/407aiN0@0MW=c101`KVd406QVIP<0GeiN
101FEUH404Y<C0@0@T=31011@D0404=2@P@0ATI50`1:BDT404i=C@@0DU5@101FEE@405YIF0@0GUeL
0`1RHF0406MUI0@0JfUX101_KF`407=aL0@0N7Ed0`1lNWP4081nO0@0QH:01029QX@F0?ooo`00503o
ool409:?S@@0UY>A102KUiH309nLVP@0Y:6O102YYJ<40:fZZ0@0/Zj/102g/k430;^g]@@0`;bi1035
`;h40<W4`P@0cLS6103Bc<T40=KAcP<0e/o<103?bLD40<O2_P@0`Kbi102o^KH40;fg]0<0^;>_102b
[JX40:nZY`@0ZjJS102YXj040:FPW@<0X9bI102KV9D409JCT@@0T8j=102=RhX408N6QP@0QH>20`1m
OGd407elN`@0O7Uh101fLg<4071^K@@0J6IV0`1OGUh405IFEP@0BTa<1012@d<40451@0@0@d921016
ATD304Y9B@@0CTe=101BDE0405IEE0@0FUUH101NGE`3069QH0@0IfET101[JFP406m]K0@0Lg5`101h
MG@307ajN0@0P7il1025PX0408V6Q1H0oooo000D0?ooo`@0TXn=102FTi4409^GUP<0WibJ102TXIl4
0:VUX`@0[JZX102b[Z`40;Nc/@<0^kNe1030_;T40<G0_P@0bLC2103=b<H40=;<b@@0e]7>0`3Fcl`4
0<o9a@@0al:n1031_;T40;ni]P@0_KNd0`2h/jl40;:]ZP@0[jZW102[YZ<40:VSX0@0YJ2M0`2PW9T4
09^HU@@0UY>A102@SXd408f;RP@0QhJ61025Ph8307emO@@0OGak101lNGP407IcL`@0L6i]101XIVH3
05mNGP@0EUIF101:C4`40493@`@0@D501013@T8404I6A@<0BTU9101>CDd4059AD0@0EUED101JFEP4
05iMG0<0HV5P101WIF@406]YJ0@0Kfe/101cLG0407QeM0<0O7Yh1020OW`408F2P0@0RHJ45P3oool0
01@0oooo102ASX`409FAT0@0VIFC0`2LVIL40:2MV`@0Y:6O102XY:840:bXYP@0/:bZ0`2d/:d40;Nc
/@@0^kNd102o^[P40<:n^`@0a/6n1039a<430<g7a0@0blG11036`;d40;nj]P@0^kFb102g/Jh30;>^
Z`@0[jZW102[YZ<40:VTX@@0YZ6M102RWYX309jJV0@0ViRE102FTi44092>SP@0S8^91028QhL408F4
Q0<0OWin101mOG`407YiN0@0MG=c101`KFd406MVIP<0GemO101JFEP404a=C@@0Bd]:101>CDd4051?
C`@0DU9A0`1EE5@405QGE`@0G5]J101OGUd4069QH0@0IVAS0`1YJ6L406e[JP@0LFm]101dLW4407Qe
M0@0NgUh0`1oO7/408:0OP@0QX>2102:QhDF0?ooo`00503oool4096>S0@0UI6@102IUI<309bIU`@0
X9fK102TXIl40:RTXP@0[:RV102`[:X30;B`[@@0]k>a102k]k@40;nj^0@0`[jk1036`Kh40<W4`@<0
cLO4103;aL440<K0_@@0_kZf102k]K840;Na[P<0/jj[102_ZZL40:^VX`@0ZJBQ102VXId40::NVP<0
WYZH102KV9D409JCT@@0T8j>102<RhT408R7Q`@0QHB40`1nOWh407emO0@0NWUh101eLg<4071]K@@0
IfIV0`1OGel405YIF0@0C4e=101;BdX404i=C@@0D4m?101BDU4305EDE0@0F5MG101LFeX405mNG@@0
HV5P101VI6<306UXI`@0KF]Z101aKfd407AbL@@0N7Ed101kNGP307mlN`@0PX1n1026Ph8408Z7QAH0
oooo000D0?ooo`@0THj<102ETI0409VET`<0W9VG102PWI/40:BQW`@0Z:BR102/Z:H40;2/ZP<0];2]
102g/k440;^g]0@0_kZh1032_[/40<K1_P@0bLC10`3=al@40<_5`@@0a/2m102o^[H40;^e/P@0]k6^
0`2c[Z/40:nZY`@0ZjJS102YY:440:JQW@@0XYjJ0`2NVYP409^HU@@0UY>A102@SXh408b;R@@0R8N7
1025Q8@307inOP@0OGel101jNGP407EcL`@0L6e]101WIVH305mOG`@0FUUH101<CDd404];BP@0CTe=
101@Cdl4059BD@<0EEAD101HEeL405aKFP@0GeiM101RHF0406ITH`<0JFQW101]JfX4075_K@@0M79a
101hMG@407]iN0<0Ogak1022P7h408J3PP@0RXN55P3oool001@0oooo102ASX`409FAT0@0VIFC0`2L
VIL40:2MV`@0Y:6O102XY:840:bXYP@0/:bZ0`2d/:d40;Nc/@@0^kNd102o^[P40<:n^`@0a/6n1039
a<430<g7a0@0blG11036`;d40;nj]P@0^kFb102g/Jh30;>^Z`@0[jZW102[YZ<40:VTX@@0YZ6M102R
WYX309jJV0@0ViRE102FTi44092>SP@0S8^91028QhL408F4Q0<0OWin101mOG`407YiN0@0MG=c101`
KFd406MVIP<0GemO101JFEP404a=C@@0Bd]:101>CDd4051?C`@0DU9A0`1EE5@405QGE`@0G5]J101O
GUd4069QH0@0IVAS0`1YJ6L406e[JP@0LFm]101dLW4407QeM0@0NgUh0`1oO7/408:0OP@0QX>2102:
QhDF0?ooo`00503oool4092=R`@0Ti2>102FTi4309VFU0@0W9VG102OW9X40:>OW@@0YZ:P102YYJ<3
0:bXYP@0[j^Y102b[Z/40;F`[P@0]k>a102j]K<40;fh]@<0_kVf2030^[L40;jh]0@0][6]102b[:P3
0:bXY@@0ZZFR102WXZ040:JQWP@0XYjJ102OViP309bIU`@0ViRE102FTi0409:?SP@0SH^:1029R8P4
08F4Q0<0PH20101mOGd407YiN@@0MWAd101`KVd406YYJ@<0Hf9Q101MG5/405MFE@@0FEQG101KFUT4
05aKF`@0GeeM0`1QGel406=RH@@0IVAS101XIfH406]YJ0@0KVa[0`1aKfh407=aL0@0MWAc101iMgH4
07ajN0@0Ogak0`22Ogh408F2P0@0QhF3102:QhHF0?ooo`00503oool4092=R`@0Ti2>102FTi4309VF
U0@0W9VG102OW9X40:>OW@@0YZ:P102YYJ<30:bXYP@0[j^Y102b[Z/40;F`[P@0]k>a102j]K<40;fh
]@<0_kVf2030^[L40;jh]0@0][6]102b[:P30:bXY@@0ZZFR102WXZ040:JQWP@0XYjJ102OViP309bI
U`@0ViRE102FTi0409:?SP@0SH^:1029R8P408F4Q0<0PH20101mOGd407YiN@@0MWAd101`KVd406YY
J@<0Hf9Q101MG5/405MFE@@0FEQG101KFUT405aKF`@0GeeM0`1QGel406=RH@@0IVAS101XIfH406]Y
J0@0KVa[0`1aKfh407=aL0@0MWAc101iMgH407ajN0@0Ogak0`22Ogh408F2P0@0QhF3102:QhHF0?oo
o`00503oool4092=R`@0Ti2>102FTi4309VFU0@0W9VG102OW9X40:>OW@@0YZ:P102YYJ<30:bXYP@0
[j^Y102b[Z/40;F`[P@0]k>a102j]K<40;fh]@<0_kVf2030^[L40;jh]0@0][6]102b[:P30:bXY@@0
ZZFR102WXZ040:JQWP@0XYjJ102OViP309bIU`@0ViRE102FTi0409:?SP@0SH^:1029R8P408F4Q0<0
PH20101mOGd407YiN@@0MWAd101`KVd406YYJ@<0Hf9Q101MG5/405MFE@@0FEQG101KFUT405aKF`@0
GeeM0`1QGel406=RH@@0IVAS101XIfH406]YJ0@0KVa[0`1aKfh407=aL0@0MWAc101iMgH407ajN0@0
Ogak0`22Ogh408F2P0@0QhF3102:QhHF0?ooo`00503oool408n<R`@0TXj=102DTHl309JCT@@0VIFC
102KV9H409fJV0@0X9bJ102RWY`30:BQW`@0YZ>Q102YYJ<40:^WY@@0[JVV102_ZZP40;2/Z@<0/ZfZ
202c[Z/40;B_Z`@0[jZW102/YZ<30:RTX@@0XinM202QWIX409nKV0@0WIVG0`2KUiD409RET`@0UI6@
102BShh408j;R`@0RhV81026QH@308>2PP@0Ogmo101kNWX407QgM@@0L6m^101^KF`306YXJ0P0IVAT
101WIF@406QVI@@0JFMV101ZJFP306aZJ@@0KVa[101`KVd4079`K`@0M79`101fM78307QfM0@0NWQf
101lNWP407ilNP@0P7il1022P7h308F2P0@0QhB21029QX@408^8QQH0oooo000D0?ooo`@0Shb;102B
SXd409BAS`<0UY>A102IUI<409^HUP@0WIZH102PW9X40::NW0<0Y:6O102VXj440:VUX`@0ZjNU102]
ZJH40:nZZ0@0/:bY0`2b[JX80;>^Z`@0]:n[102_ZZL40:bVX`<0Z:BQ102SWid80:6MVP@0Wi^H102M
VIL309^GU@@0V9FC102ETI0409:?SP@0SX^;102;RHP408J5Q0<0Ph:2101oOgl407]jNP@0N7Me101`
Kfh406i]K0<0JVQX201VI6@406MUI0@0J6IU101YIfH406YYJ0<0K6YY101^K6/4071^K@@0LW1_101d
LW0407IdLP<0N7Id101jN7H407ajN0@0OWaj1020OW`408:0OP<0QH:01027Q88408V6Q0@0RhR65P3o
ool001@0oooo102?S8/409:>S@@0U96?0`2FTi4409VET`@0ViRF102MVYP40:2LVP@0XYjL0`2TXIl4
0:JSX@@0ZJFS102[YjD40:fYYP@0[jZX102`[:T30;:]ZPP0/jj[102d[j/40:nZY`@0[:JS0`2XY:44
0:>OW@P0XIfJ102OViP409fIU`<0ViNE102HUI<409FAT0@0TXn>102>Rh/408^9R0@0QXF40`23PX84
07moO`@0NgYj101hMgD4071_KP@0KVe/0`1ZJ6P806ITI0@0IfET101XIVD406UWIP@0JVUX0`1/JVT4
06i/J`@0L6i]101bL6l407AbL0@0MWAb0`1hMW@407YhMP@0O7Yh101nO7X4081nO0@0PX1n0`25PX04
08N4PP@0RHJ4102;R8HF0?ooo`00503oool408n<R`@0TXj=102DTHl309JCT@@0VIFC102KV9H409fJ
V0@0X9bJ102RWY`30:BQW`@0YZ>Q102YYJ<40:^WY@@0[JVV102_ZZP40;2/Z@<0/ZfZ202c[Z/40;B_
Z`@0[jZW102/YZ<30:RTX@@0XinM202QWIX409nKV0@0WIVG0`2KUiD409RET`@0UI6@102BShh408j;
R`@0RhV81026QH@308>2PP@0Ogmo101kNWX407QgM@@0L6m^101^KF`306YXJ0P0IVAT101WIF@406QV
I@@0JFMV101ZJFP306aZJ@@0KVa[101`KVd4079`K`@0M79`101fM78307QfM0@0NWQf101lNWP407il
NP@0P7il1022P7h308F2P0@0QhB21029QX@408^8QQH0oooo000D0?ooo`@0Sh^:102@SH/409:>S@<0
Ti2>102ETY0409JCT@@0V9FC102IUY@409^HUP<0W9VG102NVYT409nLVP@0XIfK102RWY`40:>OW@@0
Y:2N0`2UXIl80:JRW`@0YZ6N102TX9d40:>NV`<0XYjK102LVIL409ZGU0@0ViRF102JUiD409^GU0<0
VIFC102ETY0409>@S`@0THj=102>RhX408b9R@@0RHN60`26Q8@408>1P0@0O7]j101lNgT407MeM0@0
MWAc0`1fLg8407AbL@@0M75`201dLW4407EcLP@0MWAc0`1gMG@407QfM@@0NWMf101kN7L407ajN0@0
OW]j0`1oO7/4081nO0@0PWmn1023P7l408F2P0@0QX>20`27QH<408V6Q0@0RXN6102<RHLF0?ooo`00
503oool408n;RP@0T8f;102BSXd309>@SP@0UI:@102FTi4409RET`@0VIJD102KV9H309bIU`@0WYZI
102OW9X40:6MV`@0XYjL102SWid40:BPWP<0YJ6O202VXYl40:JQWP@0Y:2M102SWY/30::NV`@0W9VG
102JUi@409^HUP@0VYNE102KUi@309VET`@0UI:@102CT8l4096>S@@0SX^:102<RHT408V7QP<0QXB4
1023PH0407akNP@0O7]i101gMG@407IdL`<0MW=b101dLW4407AaL0P0M79a101eLg8407IdL`<0MgEd
101hMWD407YgMP@0NgQg101lNWP407ikNP<0Ogak1020OW`4089oOP@0Ph1o1025PX0408J3PP<0QhF3
1029QX@408Z7QP@0S8V75P3oool001@0oooo102?RhX4092=R`@0TXj=0`2CT8h409FBT0@0UY>A102H
UI<409VFU0@0ViRF0`2LVIL409jJV@@0WibJ102QWI/40::NW0@0XinM102TX9h30:FQW`P0YZ:O102V
XIh40:BPW@@0XijK0`2RWY/409bIU`@0VYND102KV9H409ZGU@@0ViND0`2IUI<409FBT0@0Ti2?102A
SXd408j;RP@0S8V91029QhH308J4Q0@0Ph60101lNgX407akN@@0MgEd101fM7<307IcLP@0M79a101d
LG0807AbL@@0MG=b101fM7<307MeM0@0N7Ie101jMgH407]hM`@0O7Yh101nNgX307mlN`@0P7il1022
Ogh408>0O`@0QH:01026Ph8308N5P`@0RHJ4102:QhH408b9QaH0oooo000D0?ooo`@0Sh^:102@SH/4
09:>S@<0Ti2>102ETY0409JCT@@0V9FC102IUY@409^HUP<0W9VG102NVYT409nLVP@0XIfK102RWY`4
0:>OW@@0Y:2N0`2UXIl80:JRW`@0YZ6N102TX9d40:>NV`<0XYjK102LVIL409ZGU0@0ViRF102JUiD4
09^GU0<0VIFC102ETY0409>@S`@0THj=102>RhX408b9R@@0RHN60`26Q8@408>1P0@0O7]j101lNgT4
07MeM0@0MWAc0`1fLg8407AbL@@0M75`201dLW4407EcLP@0MWAc0`1gMG@407QfM@@0NWMf101kN7L4
07ajN0@0OW]j0`1oO7/4081nO0@0PWmn1023P7l408F2P0@0QX>20`27QH<408V6Q0@0RXN6102<RHLF
0?ooo`00503oool408j;R@@0Sh^:102?S8/3092=R`@0THj<102BShd409:?SP@0Ti2>102DTHl309FB
T0@0UY:@102FTi4409NDTP@0V9BB102HUI<409VET`/0VIJD202IUI<409RDTP<0Ui>A102ETY0409BA
S`@0UI6?102DT8l709FAS`@0TXn=102@SXd408n<R`@0SX^9102<RXP408^9Q`<0RHN61027Q8<408:0
OP@0Ph5o1022P7l4089oOP<0PGmm4021OWd4085oO@@0PWmn0`22P7h408>0O`@0Ph5o1024PH0408F2
P0@0QH>10`26Ph8408N4PP@0QhF31028QH@408V6Q0@0RXN50`2:QhH408^8QP@0S8V7102<RHPF0?oo
o`00503oool408j;R@@0Sh^:102?S8/3092=R`@0THj<102BShd409:?SP@0Ti2>102DTHl309FBT0@0
UY:@102FTi4409NDTP@0V9BB102HUI<409VET`/0VIJD202IUI<409RDTP<0Ui>A102ETY0409BAS`@0
UI6?102DT8l709FAS`@0TXn=102@SXd408n<R`@0SX^9102<RXP408^9Q`<0RHN61027Q8<408:0OP@0
Ph5o1022P7l4089oOP<0PGmm4021OWd4085oO@@0PWmn0`22P7h408>0O`@0Ph5o1024PH0408F2P0@0
QH>10`26Ph8408N4PP@0QhF31028QH@408V6Q0@0RXN50`2:QhH408^8QP@0S8V7102<RHPF0?ooo`00
503oool408j;R@@0Sh^:102?S8/3092=R`@0THj<102BShd409:?SP@0Ti2>102DTHl309FBT0@0UY:@
102FTi4409NDTP@0V9BB102HUI<409VET`/0VIJD202IUI<409RDTP<0Ui>A102ETY0409BAS`@0UI6?
102DT8l709FAS`@0TXn=102@SXd408n<R`@0SX^9102<RXP408^9Q`<0RHN61027Q8<408:0OP@0Ph5o
1022P7l4089oOP<0PGmm4021OWd4085oO@@0PWmn0`22P7h408>0O`@0Ph5o1024PH0408F2P0@0QH>1
0`26Ph8408N4PP@0QhF31028QH@408V6Q0@0RXN50`2:QhH408^8QP@0S8V7102<RHPF0?ooo`00503o
ool408j;R@@0Sh^:102?S8/3092=R`@0THj<102BShd409:?SP@0Ti2>102DTHl309FBT0@0UY:@102F
Ti4409NDTP@0V9BB102HUI<409VET`/0VIJD202IUI<409RDTP<0Ui>A102ETY0409BAS`@0UI6?102D
T8l709FAS`@0TXn=102@SXd408n<R`@0SX^9102<RXP408^9Q`<0RHN61027Q8<408:0OP@0Ph5o1022
P7l4089oOP<0PGmm4021OWd4085oO@@0PWmn0`22P7h408>0O`@0Ph5o1024PH0408F2P0@0QH>10`26
Ph8408N4PP@0QhF31028QH@408V6Q0@0RXN50`2:QhH408^8QP@0S8V7102<RHPF0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00V`3oool2@00008<0oooo002M0?ooo`03@000003oool0oooo0800oooo001h0?ooo`=00000
0P3oool3@00000<0oooo00=000000?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=00000
1@3oool00d000000oooo0?ooo`1j0?ooo`00N03oool00d000000oooo0?ooo`020?ooo`03@000003o
ool0oooo0080oooo00=000000?oood0000002`3oool01T000000oooo0?oood000000oooo@00000@0
oooo00A000000?ooo`3ooom00000PP3oool007T0oooo00=000000?ooo`3oool00P3oool00d000000
oooo0?ooo`030?ooo`03@000003oool0oooo00T0oooo00E000000?ooo`3ooom000000?ooo`03@000
0080oooo00A000000?ooo`3ooom00000PP3oool007T0oooo00=000000?ooo`3oool00P3oool01400
0000oooo0?ooo`3oool2@00000d0oooo0d000000103ooom00000@000040000030?ooo`=00000PP3o
ool007P0oooo00=000000?oood0000000P3oool00d000000oooo@00000020?ooo`03@000003oool0
oooo00h0oooo00=000000?ooo`3oool0RP3oool007T0oooo00=000000?ooo`3oool00P3oool01400
0000oooo0?ooo`3oool3@00000d0oooo0T00002<0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(270) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
767E7F767E80777F80777F80777F81778081778081788082788182788182788183788283798283\
7982847983847983857983857984857A84867A84867A85877A85877A86887A878A
7985877A85867A84867A84867A84857A84867A85867B85867B85867B85867C85867B85857B8485\
7B83847B82837A8182798081798080787F7F787E7E787C7C777B7A767979757776
737473757877757A7A767B7B767C7C767C7C767C7C767C7D767D7D767D7E767D7E767D7E767D7E\
767D7E767E7E767E7F
767E80777F807780817880827881827982837982847983847A84857A84867B85877B85877B8688\
7C87897C878A7C888B7D898B7D898C7D8A8D7D8B8E7D8B8F7E8C907E8D917D8F93
7D8D907D8C8E7D8B8D7E8B8D7E8A8C7E8B8C7F8B8D808C8D808C8E808C8D818C8D818B8B808A8A\
7F88887F87867D85847D83837C81817B807F7A7E7D797B7A77787675757373716E
726F6C747472757775767877767A79767A7A777B7B777B7B777C7C777C7C777D7D767D7D767D7E\
767D7E767D7E767E7E
777F807780817881827981837982847A83857A84867B86877C86887C888A7D888A7D898B7E8A8D\
7F8B8E7F8C8F808D90808E91818F9281909481919581929681939881959981969C
819498819295819194819193829192829193839193849292849292849292849191848F8F838D8D\
828B8B818A898188878086857F83827E817F7C7D7C7A7A7878767375726E726C67
726D6974716E757472767775777877777978777A79777B7A777B7B777C7B777C7C777C7D777D7D\
767D7D767D7E767D7E
777F807880827982837982847A84857B85877C86887D888A7E898B7E8A8D7F8B8E808D90818E91\
81909382919483929684949784959985969B85989C85999E859A9F859BA1859DA3
849A9F85989C85979A859799859698869698869697869596859596869595869494869392859190\
858F8E848E8C848B898287868184827F817F7D7D7B7B797679757176706B736A65
746D6975706D767370777573777775777876787978787979777A7A777B7A777B7B777C7C777C7D\
777D7D767D7E767D7E
777F807881827982847A84857B85877C87897D898B7E8A8D808C8E818D90828F92839194839396\
84949885969A86989C87999E889BA0899DA2899EA489A0A589A1A789A2A989A3AA
88A0A5889EA3889DA0899C9F899B9E899B9D8A9A9B8A9A9B8A9A9A8A99998A9898899696889493\
889291878F8E878D8B858A8883858382827F7F7E7B7C79757A746F776E69746963
756D6876706C77726F787471787673787775787877787978787A79787A7A787B7B777C7B777C7C\
777C7D777D7D767D7E
7780817982837A83857B85877C87897E898B7F8B8D808D8F818F9283919484939685959886979B\
87999D889B9F8A9DA18B9FA48CA1A68DA3A98DA5AB8EA7AD8EA8AF8DA9B08CA9B0
8CA6AC8BA4A88CA2A68CA1A48CA0A28DA0A18D9FA18E9FA08E9F9F8E9E9E8D9C9C8D9B9A8D9998\
8C96958C93928B908E898B8A878785848380827E7B7F79757C736E776C66766A63
776D6878706B78726E797470797572797774797876797977787978787A79787B7A787B7B777C7C\
777C7C777D7D767D7E
7780817982847B84867C87887E898B7F8B8D808D90828F9283929585949786969A88999D899B9F\
8A9DA28CA0A58DA2A78EA4AA8FA7AD91A9B092ACB393AEB593B0B892B1B98FAEB6
8EAAB08EA8AD8FA7AB8FA6A890A5A791A5A691A5A691A4A592A4A492A4A492A2A292A0A0919E9D\
919A999097958F93918D8F8D8A8A8888858285807D817A757D736E796C65796C65
796E6879716B7A726E7A74707A75727A76737A7775797876797977797A78787A79787B7B787C7B\
777C7C777D7D767D7E
7880827983847B85877D888A7F8A8D808D8F828F9284929585959887979B899A9E8A9CA18C9FA4\
8DA2A78FA4AA90A7AD92AAB093ADB395B0B796B3BA98B6BE9BBBC394B5BE90AFB7
91AEB391ACB192ABAF93ABAD94AAAC94AAAC95AAAB95AAAA96AAAA96AAA997A8A897A6A597A3A2\
969F9E949B999397959192908E8C8A8B878487817D837B7680746F7B6D667B6E67
7B706A7B716C7B736E7B74707B75717B76737A77747A78757A7876797977797A79787B7A787B7A\
777B7B777C7D767D7E
7881827A84857C87887E898B808C8E828F9184929586959887979B899A9E8B9DA28DA0A58FA3A8\
90A6AC92A9AF94ACB395AFB697B3BA99B6BD9BB9C19DBEC69EC0C88FB2BB91B1B9
93B0B694B0B595B0B396AFB297AFB198AFB099AFB09AAFAF9AB0B09BB0AF9CAEAE9CACAB9BA8A6\
9AA3A2999F9D979A98949592918F8C8E89868A837F867D788377717E70697E716A
7E726B7D726D7D736E7D746F7C75717C76727B77737B78757A78767A7977797A78797A79787B7A\
787B7B777C7C767D7E
7881827A84867D87897F8A8D818D9083919485949787979B899A9E8B9DA28EA1A590A4A992A7AD\
94ABB195AEB497B1B899B5BC9BB8C09DBCC49EBFC8A1C4CD96BAC48CB0BA92B3BB
95B4BA97B5B999B4B89AB4B79BB4B69CB4B59DB4B49EB5B59FB6B5A0B5B4A0B3B2A0B0AE9FABA9\
9EA7A59DA2A09B9D9B97979494918E908B878C8580897F7A85797381746D81736C
80736D80746D7F746E7E756F7E75717D76727C77737C77747B78757A79767A7978797A79787B7A\
787B7B777C7C777D7D
7881837B85867D888A808C8E828F91849296879699899A9D8B9DA18EA1A590A4A992A8AD94ABB1\
97AFB599B3BA9BB6BE9DBAC29FBEC6A1C2CBA4C7D19BC0CA90B6C093B6BF96B7BE
98B8BE9AB9BE9CB9BD9DB8BB9FB8BA9FB8B9A0B9B9A1BAB9A3BCBAA3BAB8A4B7B5A4B4B1A3AFAC\
A2A9A7A1A5A29E9F9C9B9996979390938D898F87828C817C887D7686787183746E
82746E82746E81756F80756F7F75707E76717D76727C77737C78757B78767A7977797A78797A79\
787B7B777C7C777D7D
7982837B85877E898B818D8F83909386949888989C8B9CA08DA0A490A4A992A8AD95ACB197AFB6\
9AB3BA9CB7BF9EBBC3A1BFC8A3C3CCA4C7D19FC4CF94BBC696BBC597BBC49ABBC2
9CBCC29EBDC3A0BDC1A1BDBFA2BCBEA3BCBDA4BDBDA5BDBCA6BDBCA7B9B8A7B6B5A7B2B0A7AEAD\
A6AAA8A5A6A4A1A09E9E9A979A9490958E899188838E837E8A7F78887A73867770
85756E84756E83756E82756F8075707F76717E76727D77737C77747B78757A79767A7978797A79\
787B7A777C7C777D7D
7982837C86887F8A8C828E9184929587969A8A9A9E8D9FA390A3A792A7AC95ABB198AFB59AB4BA\
9DB8BFA0BCC4A2C0C9A4C5CEA7C9D2AACED89DC4D099C0CB9ABEC89BBEC79EBFC6
A0C0C7A3C2C7A5C2C5A5C0C2A6C0C0A7C0C0A7C0BFA8BDBDA9BABAAAB7B7A9B1B1A9AEADAAAEAD\
A9ABA9A8A6A4A4A19EA09A989B9592978E8A93898490847F8D807A8B7C75897971
86756D86766E85766E83756F82756F8076707F76717E76727D77737C78747B78767A7977797A79\
787B7A777C7C777D7D
7982847C87887F8B8D83909286949789989C8C9DA18FA1A592A5AA95AAAF97AEB49AB3B99DB8BE\
A0BCC4A3C1C9A6C5CEA9CAD3ABCFD9A5CCD898C0CC9BC1CB9DC1CB9FC1C9A1C2C9
A4C4CAA7C6CBA9C6C9A9C4C4AAC3C3ADC3C3A9BBBBA8B7B8A9B3B4A9B1B1A9B1B0ACB0AFADAEAD\
ACA8A7ACA6A4A8A2A0A39B999D9592988F8A94898491847F90817B8E7D768C7B73
8A787088766E87766E85756E83756F81756F8075707E76717D76727C77747B78757A7977797A78\
787B7A787C7B777D7D
7983847D8789808C8F8491938795998A9A9D8D9FA391A4A894A8AD97ADB39AB2B89DB7BDA0BCC3\
A4C1C8A7C6CEAACBD3ACCFD8B0D4DEA1C8D49BC1CD9DC2CC9FC3CCA1C3CAA4C5CB
A7C7CDABC9CDACC8CAAEC6C7ABBEBFA8B7B8A3B1B2A7B2B3A9B1B2ABB2B2ADB3B3ADADACACABAA\
ADA9A7AEA9A7ABA3A1A59C999E95929A8F8A96898493857F92827C9180788F7D75
8D79718B766C8A766D87766D84756E82746E80756F7F75707D76717C76737B77747A7876797978\
787A79787B7B777D7D
7A83847D888A818D8F85929588979A8C9CA08FA1A593A6AB96ABB099B0B69CB5BBA0BAC1A3BFC7\
A7C5CDABCBD3AFD0D9B0D4DDAFD5DF9CC3D09CC2CE9FC3CDA1C4CCA4C4CBA7C6CC
AAC9CEAEC8CCADC5C7ADC1C2A4B6B8A6B6B8A8B7B8AAB6B7ACB7B9AEB8B9B0B8B8B0B4B2B0B2B1\
AEADACACA9A8A8A29FA59D9AA097939B908B97898495868094847D94827A927F76
907B728E786E8C776F89766D85746C82736D80746E7F746F7E75707C76727B77747A7875797977\
787A79787B7B777C7D
7A83857E898A828E908693968A999C8D9EA291A3A895A9AD98AEB39CB3B99FB8BFA2BEC5A6C3CB\
AAC9D1AFD0D9B6D8E2B5D9E3A7CEDA98C0CD9DC2CDA1C4CDA4C5CDA6C5CCA9C6CC
ACC8CDACC4C8A9BDC0A6B6B9A3B2B4A8B4B6ABB7B8ADB8B9B0BCBCB2BCBCB3BCBBB3B8B7B3B6B5\
B1AFADAFADAAABA6A2A7A09CA199949B8F8A98898497868097867F97847C958078
937C7391796F8D766C89746A84716A82726B80726C7F736E7E746F7C75717B76737A7775797977\
787A79787B7B777C7D
7A83857F898B838F918795988B9A9E8FA0A493A6AA97ABB09AB1B69EB6BCA1BBC2A5C1C8A8C6CE\
ACCCD5B1D3DCB7DAE4ACD1DC9BC3CF9BC1CDA0C4CDA3C5CDA6C5CCA9C5CBABC7CC
AEC7CCAEC4C7ABBDBFAAB9BBAAB7B9ACB6B8ADB7B8AFB8B9B1B9BAB4B9BAB4B8B8B5B5B5B4B1B0\
B3AEADB0ADAAADA7A3A9A19DA399959B8E8A99888499878199878099857C988279
957E75947C71947B708A736A846F6882706980716A7F726C7D736E7C74707B75727A7774797876\
787978787B7A777C7C
7B84857F8A8C8490928896998D9CA091A2A695A8AC99AEB39DB3B9A0B9BFA4BFC6A7C4CCAAC9D2\
ADCED7AFD3DCABD1DD9EC6D399C0CDA0C3CEA3C5CEA6C5CCA9C5CCABC5CBADC6CB
B0C6CBAFC4C7ADBDC0AEBCBEAEBBBCB0BABBB1BABBB3BBBCB5BDBDB7BCBDB8BABAB8B8B7B7B4B3\
B6B1AEB3ACA9AFA4A2A99D9AA394909C8C879987829A87819C87809C867D9A8379
987F75977D72967B6F866E64836D65816E667F6F687E706A7D726C7C736F7B75717A7673797875\
787978787B7A777C7C
7B8486808B8D8591948A989A8E9EA193A4A897AAAF9CB0B69FB6BCA3BCC3A7C2C9AAC7CFACCCD5\
AED1DBAED4DFABD1DDA7CCD7A5C7D2A5C6D0A7C6CEA9C6CCACC6CBAEC5CBB0C6CB
B1C7CBB1C5C8B1C1C3B1BEC0B2BDBEB3BDBEB5BEBEB7BEBEB9BFBFBBBFBFBCBEBDBCBBB9BBB7B5\
BAB3B0B5ADA9B1A6A2AC9F9BA69793A1908B9D8A859D89819E89809E887E9C847A
9A8076997E72997C6F866D62816B61806C647F6E667E6F697D716B7C726D7B74707A7572797775\
787977787A7A777C7C
7B8586818B8D8692958B999C90A0A395A6AA9AADB19EB3B9A2BABFA6C0C6AAC6CDADCBD3AFD0D9\
B1D4DFB1D6E2B0D4DFAED1DBACCCD5AAC9D1ABC7CEADC7CDAFC7CCB1C7CCB2C8CC
B4C8CCB4C6C9B4C3C6B4C0C1B5BFC0B7C0C0B8C1C1BBC1C1BCC1C1BFC2C1BFC0BEBFBDBBBEB9B5\
BBB4B0B6ADA9B2A6A1AD9F9AA89893A4928CA18D86A08C83A18B82A0887F9E847A
9B81769A7E729A7C6F856C62816A617F6B627E6C647D6E677C6F697C716C7B736F7A7571797774\
787877787A79777C7C
7C8586818C8E8793968D9B9D92A2A597A9AD9CB0B4A1B6BCA6BDC3AAC3CAADC9D1B0CFD7B3D4DE\
B4D9E4B4D9E4B5D8E1B2D3DCAFCDD5ADCBD2AFC9CFB0C8CEB2C8CEB4C9CDB5C9CD
B7C9CDB7C7CBB8C6C8B8C3C4B8C0C1BAC1C1BCC2C2BEC2C1BFC3C1C2C4C2C2C2BFC2BEBBBFB9B5\
BDB5B0B8AEA9B4A7A1AE9F99AA9992A6938CA48F87A48E85A48C82A2897F9F857A
9C8176997D72997C6F876E6480685F7E69607D6A627D6C657C6E687B706B7B726E7A7470797673\
787876787A79777C7C
7C8587828D8F8895978E9C9F94A4A79AABAF9FB2B7A4BABFA9C1C6AEC7CEB1CED5B5D4DCB7D9E3\
B9DEE8BADDE6B9DBE4B5D2DAB1CDD4B1CBD2B2C9D0B4CACFB6CACFB7CBCFB9CBCF
BACBCEBBCACCBCC8CABBC5C6BBC2C2BDC3C3BFC4C4C1C5C3C3C6C4C5C6C4C6C5C2C5C0BDC3BBB6\
BFB5B0BBAEA9B6A7A1B1A099AC9A92AA958DA9928AA89087A68D83A48A80A1867B
9C8176987C7092776C856D637F675D7C655C7C685F7C6B637C6D667B6F697B716D7A7370797573\
787876777A79777C7C
7D8687838E908A9698909EA196A6A99DAEB1A2B5BAA8BDC2ADC4CAB2CCD2B6D2DABAD9E1BDE0E9\
BFE4EDBFE2EABCDAE2B7D0D8B5CDD4B5CBD2B6CBD1B7CCD0B9CDD1BBCED2BCCED1
BDCED0BFCCCFBFCACBBEC6C6BEC4C3C0C5C4C2C7C5C4C7C5C6C9C6C9C9C6CAC7C3C8C2BDC6BDB8\
C2B6B1BEB0AAB8A8A1B3A099B09B93AE9890AD968DAC948AA99186A68C81A2877C
9D8276977C7091766B866C607B6055765E557B665D7C69617C6C657B6E687B716C7A736F797572\
787775777978777C7B
7D8688848F918B979992A0A299A8ABA0B0B4A6B9BDACC1C5B2C8CEB7D0D6BCD8DEC0DEE6C3E5ED\
C4E6EEC3E0E8BED6DEB8CFD6B6CDD3B8CDD2B9CDD2BBCED2BDCFD3BED0D3C0D1D3
C1D0D2C2CFD0C1CCCDC1C9C8C1C7C5C3C7C5C5C8C5C6C8C5C9CAC7CCCAC6CDC8C3CBC3BEC9BEB8\
C4B7B1C0B0A8B9A8A0B6A29AB49E96B29C92B29A8FB0978CAC9387A98E82A4897D
9F8377997C7093786B8A6E628164587E64597D665D7D69607C6B647B6E677B706B7A726E797471\
787775777978777B7B
7E87888590918D999B94A2A49CAAADA3B3B7AABCC0B0C4C9B7CDD2BCD5DBC2DDE4C7E5EDCAE9F1\
CBE7EFC7DFE7C0D4DCBACED5B9CED3BACED3BCCFD3BED0D4C0D2D5C2D3D6C4D3D5
C5D3D4C5D1D2C5CFCEC5CBCAC4C9C7C5C9C6C7C9C6C9CAC6CCCCC7CFCCC7CFC9C4CEC4BECABEB7\
C6B7B0C1B0A8BDAAA2BBA69DB9A298B7A095B69D92B4998EB09589AC9084A88A7E
A284789C7E7195796D8D706386685C82675B7F675D7E685F7D6B637B6D667B6F6A7A716D797470\
787674777978777B7B
7E87888691928E9A9C96A3A69EADAFA6B6B9AEBFC3B5C8CCBCD1D6C2DADFC9E3E9CFECF3D4EFF5\
D4EBF1CCE0E6C1D4DABBCED4BBCED3BCCFD3BED0D4C1D2D6C4D4D6C6D5D7C8D6D6
C9D5D5C9D3D3C8CFCFC7CCCBC7CAC8C7C9C6C9CAC6CCCBC7CFCCC8D1CCC7D2C9C4D0C5BECDBFB8\
C9B8B1C5B3AAC2AEA4C0A99FBEA69BBCA398BA9F94B79B8FB3978AB09184AB8C7F
A586799F8073997C709172668A6C5F83665A80665C7E685E7D6A627C6C657A6E687A716C797370\
787673777877777B7B
7F8889879293909B9D99A5A7A1AFB2AAB9BCB2C3C6BACCD0C1D6DAC9DFE4CFE8EDD7F1F7DDF2F7\
D8EAEECDDFE3BFD1D7BCCDD3BCCED2BECFD3C0D1D4C4D3D6C7D5D7CAD7D7CCD7D7
CDD7D6CCD5D4CBD1D0C9CECCC8CBC8C9CAC6CBCAC6CDCBC7D1CDC8D4CEC8D5CBC4D3C6BFD0C1B9\
CDBAB2CAB5ACC7B1A7C6ADA2C3AA9EC1A69ABEA296BB9E91B7998CB39486AE8E80
A8887AA383759E7E719574678C6D608463568165597F675D7D69607C6B647A6D6779706B78736F\
787573777877767B7B
7F8889899294929D9E9BA7A9A5B2B4AEBCBFB7C7C9C0D1D4C8DBDECFE4E8D6EDF1DCF4F8DFF1F4\
D7E8EBCBDCE0BBCDD3BACBD1BCCDD1BECED2C1D0D3C6D4D6CBD7D8D0DADAD2DBDA
D3DAD8D0D7D5CDD1D0CACECCC9CBC8C9C8C4CBC8C4CECAC5D2CDC7D6CDC8D7CBC5D6C7C0D4C2B9\
D1BDB3CFB8AECEB5AACBB0A5C8ACA0C6A89CC2A397BE9F92BA9A8CB69587B19082
AC8A7CA78577A281739878698D6C5E8461548163577F655B7D675F7B6A627A6C66796F6A78726E\
777572777876767B7B
80898A8A9395949EA09EA9ABA8B4B6B2BFC1BCCBCDC6D6D8CFE0E3D6EAEDDDF2F6E2F6F9E7F5F7\
DDE8EBCAD9DDB7C9CFB8C9CEBACACFBDCCCFC1CFD1C6D2D4CBD5D6D0D8D7D4D9D7
D4D9D6D0D5D3CCCFCDCACDCAC9C9C6C7C5C1CAC6C1CEC8C3D3CCC6D7CDC7D9CCC5D9C8C0D8C4BA\
D4BEB4D3BAAFD1B7ABCFB3A7CDAFA2CAAB9EC4A598C0A092BD9C8DB99788B59283
AF8C7DAB8778A582739876678B695A835F508061557E64597C665D7B6961796B65786E6978716D\
777472777776767A7A
80898A8B9495959FA1A0ABACABB7B8B6C3C4C1CFD0CCDBDDD7E7E9DFF0F3E3F7FAE6F6F8E7F2F4\
D8E3E6C5D4D8B2C5CBB5C5CBB8C8CCBCCACDC0CCCEC4CFD0C8D2D1C9D2D0CED3D1
CDD2D0C7CDCBC4C7C5C2C4C2C0BFBCC2BDB9C8C2BDCEC6C0D4CBC5D8CEC6DBCDC5DBCAC0DCC8BD\
D8C0B5D9BEB2D9BCAFD7B8ABD1B2A4CDAC9EC6A698C3A293BF9D8EBC9889B79383
B28E7EAF8A79A984739A76668B6758825C4E805F537D62577B655B7A675F786A64776D6877706C\
767371767775767A7A
81898A8C959697A1A2A2ACAEAEB9BABAC5C7C6D3D4D4E1E2E1EFF0EEFDFEEBFBFDEAF6F6E7EFF0\
D7E1E3C2D1D5AFC1C7B2C3C8B6C5C9BAC8CABECACBC2CCCCC5CDCDC6CECCC8CECC
C2C8C7BDC3C3BBBFBEBABCBBBDBBB8C2BCB8C8C0BBCEC6C0D4CBC5D9CDC6DBCCC3DBC8BFDBC5B9\
D8BDB1DDBFB1E0BFB0D7B8A9D2B1A2D0AE9FC8A798C4A293BF9D8EBD9888B99483
B6907FB48C7BAD85739B75658A6657815C4E7F5E527C61567A635A78665E776962766C67766F6B\
767370767675767A7A
81898A8D959698A1A2A4ADAEB0BABBBDC8C9CBD6D7DAE6E6EEF9F9F4FFFFEDF8F9EDF4F4E8EEED\
D5DEE0BECDD2AABDC3AFBFC4B3C2C5B9C7C8BDC8C9C0C9C8C3CAC9C5CAC9C5CAC7
C3C7C5BFC2C1BCBEBBBBBAB8BEBAB6C3BCB7C8C0BACFC5BFD5CBC3D9CCC4DCCBC2DBC7BDD9C3B7\
D7BDB1D7BCAFD8BAACCEB1A4CCAD9FC9A99BC1A294BE9E8FBC9989BD9786BC9483
BA917FBA8F7CAE85739A7565886657805C4D7D5D507A5F5478615876645C756761756A65756E6A\
75726F757674757A79
82898A8D959699A2A3A6AFAFB2BCBCC0C9CACED8D8DEE8E8F0FAFAEEF7F7EAF2F3E5EBEBDFE5E5\
CBD7DAB8C8CDA7BAC0ACBCC1B0BEC2B5C1C3B9C2C3BEC6C5C2C8C7C5CAC7C7C9C6
C6C7C4C2C2BFC0BFBCBFBCB9C0BAB5C4BCB6C9C0B9CFC6BFD5CAC2DACBC2DCCBC1DCC8BCDBC3B7\
D8BEB1D6BAADD1B5A7C7AC9FC4A89BC1A496BC9E90BC9B8CBE9989BF9886BF9583
BF9380BE917DAD83719773638664567E594A7B5B4E785C52765F5674625A73655F736964736D69\
74716E747574757979
828A8B8E96979AA2A3A7AFB0B4BCBDC1CACAD0D8D8DFE8E8F0F8F8EDF4F4E8EEEEE0E6E7D5DDDF\
C4D0D4B4C3C8A5B7BDA9B9BDAEBBBDB2BCBEB6BEBFB9BFBEBCC0BEBFC1BEBDBFBC
BCBDBBBABAB7BAB8B5BBB7B3BDB6B2C4BBB5CAC1BAD0C6BED6C9C1DACAC0DCCBBFDEC9BDDEC5B8\
DABFB1D8BBADD3B6A8CDAFA1C8A99BC4A495C19F90C29E8DC29C89C39A87C39884
C49682C0927DAC816F926F5F8564557C574978584C745A4F725C53715F5871635D716762716B67\
72706D737473757979
828A8B8E96979BA3A3A7AFB0B4BCBDC2CACAD0D8D8DFE7E6EEF6F5EBF1F0E3E9E9DAE1E2CFD9DA\
C0CCCFB0C0C4A4B6BCA7B6BAABB7BAB0B9BAB4BBBAB7BBBAB9BBB9B9B9B7B8B8B5
B9B7B4B9B6B2BAB5B1BCB6B2C1B9B4C7BEB7CDC3BCD2C7BFD7C8C0D9C9BFDBC8BCDCC5B9DCC2B4\
DCBFB0DCBDAED6B8A8D1B2A2CEAD9DCBA898C8A493C7A18FC69E8BC69B88C69A85
C99983BF907BA87F6C926F5F896657805B4C74554970554B6E58506D5C556D605A6E65606F6966\
716E6C727372747978
828A8B8E96979BA3A3A7AFAFB4BCBCC2C9C9D0D7D6DEE5E4EDF3F2E8EEECE0E6E5D6DEDECAD4D6\
BBC9CCAEBEC2A3B5BAA5B3B7A9B5B7AEB7B7B2B8B8B5B9B8B8BAB7BAB9B6BBB9B6
BCBAB6BEBAB5C0BBB6C2BCB7C6BFB9CBC2BBD0C6BED4C8C0D7C9C0DAC9BEDAC7BBDBC5B7DAC1B3\
D7BBADD6B8AAD4B5A6D5B3A3D3B09FD1AB99CDA795CBA390C89E8AC79C87CA9B86
CC9983BC8D78A87D6A9671608965557B5749694B4069504668544C6958516A5D576B625E6D6864\
6F6D6B717371747878
828A8B8E96979BA2A3A7AFAFB4BBBBC1C8C8CFD6D5DDE3E2EAF0EFE4EAE9DEE4E3D3DBDBC7D2D3\
BAC7C9AEBDC1A5B5BAA5B2B6A8B3B5ADB5B6B1B7B6B5B8B6B8B9B7BBBAB7BDBBB8
C0BCB8C2BDB9C5BFBBC8C1BCCBC3BDCFC6BFD3C8C0D7CBC1D9CAC0DBC9BEDCC8BBDCC5B8DCC2B4\
DABEAFD7B9AAD3B3A4CFAE9FCDAB9ACCA896C9A492C9A08DC89E89CC9D88CD9B86
CB9881B98975A67B68946D5D825E5072504461453B614A41624F4763544E655A5568605B6A6662\
6D6C6A707271737878
828A8A8E96969AA2A2A7AEAEB4BABAC1C7C7CED4D3DBE1E0E9EFEDE3E9E8DCE2E1D1D9D9C6D0D1\
BAC6C9B0BDC1A8B6BAA5B2B5A7B2B3ACB4B4B1B6B4B5B7B5B9B9B6BDBBB8C0BDB9
C3BFBBC6C1BCC9C4BECCC5BFD0C8C1D3CAC2D7CCC3DACDC3DCCCC1DDCBBFDEC9BCDEC7B9DEC4B5\
DCC0B1DABBABD6B6A5D2B0A0CFAC9ACCA795CBA491CCA28DCDA08BCF9E89D09C86
C9957FB58671A076648E68587A5A4C694C415A423859443C5B49425E504A615651645D59686361\
6B6A686F7170727777
82898A8E95969AA1A1A6ADADB3B9B9C0C6C5CDD2D1DADFDEE7ECEBE1E5E4DADFDED0D7D7C7CFD0\
BCC6C8B3BEC1AAB7BAA6B2B5A6B0B2ABB3B2B1B5B3B6B7B5BABAB6BFBDB9C3BFBB
C6C2BDCAC5C0CDC7C2D1C9C3D4CCC4D8CDC5DBCFC6DECFC4DFCEC2E0CDC0E1CBBDE1C8BAE1C5B6\
E0C1B2DDBDACDAB8A7D7B3A2D5AF9DD3AB98D3A894D3A590D3A28DD4A08AD29C85
C5917BB0816D9C726088635474554860463C513C334E3B3453433D584B465C534E615A5765615F\
6969676E706F727777
82898A8D959599A0A0A5ACACB2B8B8BEC4C3CBD1CFD8DDDCE5EAE8DEE3E1D7DCDBCFD5D5C6CECE\
BCC5C6B3BDBFAAB6B8A6B2B4A5AFB0ABB2B1B1B5B3B7B8B5BCBBB7C1BEBAC5C1BC
CAC4BFCDC8C2D1CAC4D5CDC5D9CFC7DCD1C8DFD2C8E1D2C6E2D0C4E3CEC1E4CCBEE4CABBE4C7B7\
E3C3B2E0BEADDEBAA8DCB6A3DAB29ED9AE9AD8AB96D6A791D6A48ED5A18ACE9982
BC8B75A87B68946C5B7F5C4E694D41543E3546332B43322C4B3D38524742584F4B5D585562605D\
6767666C6F6E717676
81898A8D9494999F9FA4ABABB0B7B6BDC2C1C9CFCDD6DBD9E3E7E5DDE0DED5DAD8CED4D3C6CDCD\
BEC6C6B3BDBFABB7B8A6B2B4A5B0B1ABB1B0B2B5B3B9B9B5BEBCB8C4C0BBC9C4BE
CDC7C1D1CBC4D6CEC6D9D0C8DDD3CAE0D4CAE3D5C9E5D4C8E6D2C5E6D0C2E7CEBFE7CBBBE6C8B7\
E6C4B3E4C0AEE2BCA9E0B8A5DFB4A0DDB19CDBAC97DAA992DAA58ED59F88C8947D
B58570A075628964547354475D443948352D362721392B264438334C433F534C495A5553605E5C\
6666656B6E6E717676
8189898C9394989E9EA3A9A9AFB5B4BBC0BFC7CCCBD4D9D7E1E5E2DADEDCD3D8D6CDD2D1C7CDCC\
BEC4C4B4BDBDAEB7B8A9B2B4A9B1B1ADB1B0B4B5B2BBBAB6C1BEB9C7C2BCCCC6C0
D1CAC3D6CEC7DAD1CADED4CBE2D6CDE4D7CDE7D8CCE8D6C9E9D4C6EAD2C2EACFBFEACCBBE9C8B7\
E8C5B3E7C2AFE5BDAAE4B9A5E2B5A0E0B19CDFAD97DDA992D9A38CD09B84C08D77
AC7D6A956C5B7E5C4E674B40513B323D2D262D201B362A263F353148403D504A475753515E5C5B\
6465646A6D6D707676
8188898C9393979D9DA2A8A7ADB3B2B9BEBDC5C9C8D1D5D3DEE1DFD7DBD9D1D5D4CCD0CEC6CBC9\
BEC4C3B7BEBEB1B8B9ADB4B4AEB4B3B1B4B2B7B6B3BDBBB7C4C0BBCAC5BED0C9C2
D5CEC6DAD1CADFD5CCE3D8CEE7DACFE9DACEEBDACDEDD8CAEDD6C7EDD3C3EDD0BFECCDBBECC9B7\
EAC6B3E9C2AFE7BEAAE6BAA5E4B6A0E4B29CE2AE97DEA991D7A189CB967FB88671
A276638A65547454475D443945332A30231E261B173228243C3330453E3B4D48465552505C5B5A\
636463696D6D707576
8088888B9292959C9CA0A6A5ABB0AFB6BBBAC1C6C4CDD1CFDADDDBD4D8D6D0D2D0CACECCC6CAC8\
C0C5C3B9BEBEB5BAB9B2B7B5B3B7B5B4B6B3B9B8B4C0BDB8C8C2BDCEC7C1D4CCC5
DAD1C8DFD4CCE4D8CEE8DACFEBDCD0EEDDCFF0DDCEF1DACBF0D7C7F0D4C3EFD1BFEFCEBCEECAB7\
ECC6B3EBC2AEEABEA9E8BAA5E7B6A0E6B29BE2AE96DDA78ED29C84C18E78AC7D69
946C5B7E5C4C674B3F4F3A303628212016122117142E262339322F423D3A4B47455351505A5B59\
626463696C6C6F7576
8087888A9191949A9A9EA4A3A8AEADB3B8B6BEC2C0C9CDCBD5D8D6D2D4D2CDD0CDC9CCC9C5C8C6\
C1C4C2BCBFBDB8BBB9B7B9B7B7B9B6B8B8B5BDBAB6C4C0BACCC5BED2CAC2D9CFC6
DFD3C9E5D7CCE9DACFEDDDD0F1DFD1F3DFD1F4DECFF4DBCBF4D8C7F3D4C3F2D1BFF1CEBBF0CAB6\
EEC6B2EDC2ADECBEA9EABAA4E8B59EE5B099E0AB93D7A189C8947EB685709F7461
8763537152455A42374130282B1F1A1B120E231B182D262337312F403C3A49474551514F595A59\
616363686C6C6F7576
7F87878990909299989CA2A1A6ABAAB0B4B3BABEBCC4C8C6D0D3D0CFD1CECBCDCAC7CAC7C5C6C4\
C1C3C0BDBFBCB9BBB8B8B9B6B9B9B6BCBAB6C1BCB7C8C2BBD0C8C0D7CDC4DED2C8
E5D6CBEADACDEEDDCFF2DFD1F6E1D2F9E1D1F9DFCEF8DCCAF6D8C6F5D4C2F4D1BEF3CDBAF1CAB5\
F0C5B1EEC1ACECBDA7EAB9A2E7B49CE2AD96DBA68ECE9982BC8A75A77A67906A58
79594A64493D4C372E32251F1F1713150D0B201A182B262435312F3F3C3B484745515150595A59\
606363686C6C6F7576
7F8687888E8F9197979A9F9FA3A8A7ACB1AFB5B9B8BFC2C0C8CBC8CBCDCAC9CAC7C6C7C4C2C3C1\
C0C1BEBCBDBAB9BAB6B9B9B5BAB9B5BEBBB5C3BDB7CCC3BBD3C9C0DBCEC4E4D4C8
EAD8CBEFDCCEF4DFD0F7E1D1FBE3D2FEE3D2FDE0CEFADCCAF8D7C5F6D3C0F5D0BDF4CCB8F2C8B4\
F0C4AEEEBFA9EBBAA4E8B59EE3B098DBA890D19D86C08F79AC7F6C976F5E805F4F
6A4E41533D333B2B25241B17120B09110B091F1A182A26253532303F3D3B484746505150585A5A\
606363676C6D6F7576
7E8586868D8E8F9595979D9CA0A5A4A8ADABB1B5B3B9BDBAC1C4C1C9CAC7C7C8C5C4C5C1C1C1BE\
BFBFBCBCBCB8B8B8B5B8B7B3B9B7B2BEB9B4C2BCB5CAC2B9D2C7BEDDCEC2E8D5C7
EFD9CBF3DDCEF7DFCFFBE1D0FFE3D0FFE1CFFDDDCBFBD9C6F9D5C2F7D1BEF5CDB9F4C9B5F2C6B1\
EFC2ABEBBCA5E8B69FE3B099DBA992D19E88C3917CB0836F9C7462866354705245
5942374230292B201B18110F0A0604140F0E1F1C1A2B28273533323F3E3D484847505251585B5B\
606464676D6D6F7576
7E8586858C8C8D9393959B9A9CA2A1A4A9A8ACB0AEB4B7B5BBBEBBC4C6C2C4C5C1C0C1BEBEBEBB\
BCBCB8BABAB6B6B6B2B6B4B0B8B5B0BDB8B2C1BBB4C7BFB7D0C4BBDBCBBFE5D1C3
EBD6C7F0D9C9F4DBCAF8DCCAFCDDCAFBDBC8F9D8C5F7D4C1F6D1BCF4CCB8F2C9B4F1C6B0EEC1AB\
EABCA6E5B59FE0B099D9A892CF9F89C2927DB285729E76658967577356495D453B
46342D2F241F1C15120B0806060403151211211E1D2C2A293635343F3F3F484949515352585C5C\
606465686D6D6F7576
7D8485848B8B8B9291929898999F9EA0A5A4A7ACAAAEB2B0B5B8B6BCBEBBC0C2BFBDBEBBBBBBB8\
B8B8B5B6B6B2B2B2AEB4B2AEB7B4AFBCB7B1C1BAB3C7BEB5CEC3B8D7C7BCDFCCBE
E5CFC0E8D0C1EDD3C2F1D3C2F3D4C2F3D3C0F2D0BEF1CDBAEFC9B5EDC5B1EBC2ADE9BEA9E5B9A4\
E1B49EDAAD97D4A691CA9D88BF927FB086749F79688B695A765A4D61493F4A3830
3227211E18150E0B090100000907071715152322212E2D2C373837414141494B4B515454595D5D\
616566686D6E6F7676
7C8484838A8A899090909695969C9B9DA1A0A3A7A6A9ADABAFB2B0B5B7B5BBBCB9BABBB8B7B7B4\
B4B4B1B3B2AFB1B0ACB3B1ACB6B2ACBBB5AFBEB7B0C3BAB1CBBEB3D2C1B6D7C4B7
DCC7B9DEC7B9E3CABAE5CAB9E7CAB9E7C9B8E6C7B5E5C3B1E1BFADDEBAA8DCB6A3DAB39FD6AE9A\
D0A894C9A08DC19886B78F7DAB85749B78688A6B5C765C4F634C424D3C34362B26
201A17100D0C0100000201010F0F0F1B1B1A2626263031303A3B3A4244444B4D4D5356565A5E5E\
616667686E6F6F7677
7C8384828989888E8E8D9393939998999E9D9EA3A2A4A8A6A9ACAAAEB1AFB4B6B3B7B8B5B3B3B0\
B0B0ADB0AFABAFAEAAB0ADA9B1AEA8B7B1ABBAB3ACBFB6AEC7BAB0CBBBB0CFBDB1
D3BFB2D5C0B2D9C1B2D9C0B1DAC0B0DABEAED9BBABD6B7A7D2B3A2CFAF9ECCAB9AC9A695C3A18F\
BD9A89B59382AE8B7BA48273967769866A5D755D52634F454E3F38392F2A231E1B
12100E0201010000000B0B0B1616162021212A2B2B3435353C3E3E4547474D50505458585B6060\
626768696F706F7677
7B8383818788868C8C8B9191909695959A999A9F9E9FA3A2A3A7A5A8ABA9ACAEACB1B2B0AEAEAC\
ACACA9ABABA7AAA9A5ABA9A4AEAAA5B2ADA7B6AFA8BAB0A8C0B3A9C1B3A9C5B6AA
C8B7AACAB7ABCCB7AACDB7A9CDB5A7CBB2A4C8AFA1C5AC9DC1A798BEA394B99E8FB5998AAF9384\
A78C7EA185789A7E71907568826A5E725E536250484E413B3B322E292421161514
0405050000010A0A0B1314141D1E1E2627272F3131383A3A404242484B4B4F5253565A5A5D6262\
6369696A7071707778
7B82837F8687848B8B898F8F8D9393929796969B9A9A9E9D9EA2A0A1A5A3A5A7A5A7A8A6A7A8A5\
A6A7A4A6A6A2A5A4A1A6A4A0A7A4A0AAA6A0AEA8A1B1A9A1B5ABA2B7ABA2BAADA2
BCADA2BEADA2BEACA0BEAB9FBCA99DBAA69AB7A397B4A093AF9B8FAB968AA49084A18C7F9A8579\
947F748E796E8672687B685F6C5C545D50494C433D3B35322A2826191919090B0C
010203090A0B1213141B1C1D2425262C2E2E3437373C3F3F4447474B4E4F525656585D5D5E6464\
646A6B6A7172707778
7A82827E8586828989868D8D8A90908E9493929796959A99999D9B9B9F9E9EA19F9FA2A0A0A29F\
A0A19F9FA09D9F9F9C9E9E9B9F9E9AA29F9AA5A09AA6A09AAAA29AABA299ACA299
AEA299AEA198ADA096AD9F95AC9E93AA9B91A7988DA3948A9F8F85998A8093847B8E7E7486776F\
82746B7C6E6673655E665B5559504B4B45403B38352C2B2A1D1F1F0F1213050708
0809091214141B1D1D2325262B2D2E3335363A3D3D414445484B4C4E52535459595A5F60606666\
666C6D6B7273717879
7A81827D8485818888848B8B888E8E8B91908E9393919695949897969A99989B9A999C9A999C9A\
999B99999B98989A979899959998949997939B98939B98939E99929F98919E9790
9F978F9F968E9F958D9E948B9C928A998F87968C849288808E847D897F788379727D746D78706A\
736B666C645F615A5657524E4C48453E3C3A2F302F222424151919090C0D0A0C0D
1416161C1E1F2426272B2E2F323536393D3D404344464A4A4C5051525757585D5D5D6263626869\
676E6E6C7374717879
7981817C83847F8687828989858B8B888E8E8B90908D92928F9493919594929695939795949795\
94969594969493959392939091918E90908C91908C918F8B938F8A928E898F8C86
8F8B858F8A848F8A838F89828D87808A847E87827B837D787F7A757A757176716D716E6A6D6966\
6B666364605C5A5654504E4B424241333635262A2B191F201115160F1213181A1B
1F222326292A2D30313437383A3E3E404445464A4B4C5051515656565B5C5B6061606566646A6B\
696F706D747572797A
7980817B82837E8585808787838989858B8B878D8D898F8E8B90908C91918D92918E92918E9291\
8E92908E918F8D8F8D8B8D8A8B8C89888A8688888588878388878286858084837E
83827E82807C817F7A817F797E7D787B7A7578777375747172726E6D6D6B6B6B68646564626361\
5E5F5D5557564D4F4E424545363A3B2C31321F2627161B1C171A1B1D2021242728
2B2E2F313536373B3C3D4142424647474C4D4C5152515657565B5C5A60605F6465636969676D6E\
6B71726E7576727A7B
7880807A82827C83847E8586808787828989848A8A868B8B878D8C888D8D898E8D898E8D8A8E8D\
898D8C898C8B878B8985888680838180828080827F80817E7F7F7B7B7C79777976
7677747778747677737375716F726F6F726F6E716E6B6E6D686B6A6569696367665D61625B5F5F\
565A5A4F5353464B4B3C424332393A2C3233202527202425272A2B2C3031323637
373B3C3C4141414646464B4B4B4F504F5455535859575C5D5B61615F6465626869666C6D697071\
6C7374707778737A7B
787F807981817B82837D84847E8585808687818788828889838989848A8A858A8A858A8A858A8A\
858A898489888387868185837E82807B7E7C797C7A777A77757875727673717472
7073716F72706C706E6B706E6B706F6C706F686D6D676C6C656A6B6368695F64655B6161565D5E\
5157594B50514348493C4243353A3B2E32332A2F30313637363B3C3B3F403F4445
434849484D4D4C51514F5555535859565C5D5A60605D636460666763696A666C6D696F706C7273\
6E7576717879737B7C
777F807880817A81827B82837C83847D84847E85857F8686808686808787818787818787818787\
8186868085857F84847D82827B807F797D7C757A796E73726B716F6C72706B7070
696E6D686E6D686F6E696F6F696F6E686E6D656C6C646A6B6067695E65675C6364596062565C5E\
5157584D525344494A3E43443B3F403B3F413F4445424749464B4C494F504D5253
50555653595A565C5D595F605C62625E6465616768636A6A666C6D686E6F6A71726C73746E7576\
70777872797A747C7D
777E7F787F807880817981817A81827B82837B82837C83837C83847D84847D84847D84847D8484\
7D83837C83837C82827B8180797F7F777D7D757A7A7277776F75756C7273676E6F
676D6E686F6F676E6E686E6E696F6F686F6E686E6F666D6E646B6C62696A6067685E65675B6163\
52595A4F55564B51534D52544F54554F5556515758545A5B565C5D585E5F5A6162
5D63645F656661676862696A646B6C666D6E686F6F6970716B72736C73746E75766F7777717879\
72797A737B7C757C7D
767E7F777E7F777F80787F80787F807880817980817980817980817981817981817A81817A8181\
798081798081798080787F7F777E7F767D7E757C7C747B7B72797A7178796F7677
6F76776F76776E75766E75766D7375697172687072676E70666D6F656C6E646B6D626A6B606768\
5E656661686961686962686962696A636A6B646B6C656C6D666D6E676E6F686F70
6970716A71726B72736C73746D74756E75766F767770777870787971797A72797A737A7B737B7C\
747C7D757C7D757D7E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool407InO`@0MWj01`1g
Oh0407MoP@P0Mh21101hP88707R1PP@0N863101hPX<407V2P`@0NH:4101iPh@707V3Q@@0NHB5201j
Q8H807Z5Q`<0NXJ8101jQhX407V5Q`@0NXF6201jQ8H307Z4Q@@0NXB6101jQHH<07^5QP@0O8F60`1k
QHD407^4Q@@0Nh>4101kPX<407Z1PP@0NH210`1iP80407QoO`@0N7in101hO7`407MkNP@0MWUi101e
MgH307=dL`@0MGQg101eNWX407IkN`/0MWal101fO7d407ImOA<0MWen101fOWh407InOaH0oooo000D
0?ooo`@0MWio101fOX0707MoP0@0Mgn1201gP84407R0PPL0N862101hPH<407R2P`@0NH:3101iPX@4
07V3Q0L0NH>5101iQ8D807Z4QPP0NXF70`1jQXP407Z7RP@0NHF7101jQHH807Z4QP<0NXB5101jQ8H4
07Z5QP`0NhF6101lQHH307^5Q@@0NhB5101kPh@407^2P`@0NX62101iP84307V0P0@0N7mo101hOWh4
07QlO0@0Mg]j101fNGT407EgMP<0LgAc101eN7L407EjNP@0MW]k2`1fO7`407IlO@@0MWem4`1fOGh4
07InOP@0MWio5P3oool001@0oooo101fOWl407InP0L0Mgn0101gOh4807N0P@@0N8221`1hPH8407R1
P`@0N8:3101iPX<407V2Q0@0NH>41`1iPhD407V4Q@P0NXB6201jQHL307Z6R0@0NXN:101iQHL407Z5
QPP0NXB60`1jQ8D407Z4QP@0NXF6301kQHH407b5QP<0NhF5101kQ8D407^3Q0@0Nh:3101jPH8407V0
P@<0NH20101hOgl407QnOP@0N7al101gNgX407IiN@@0MGMf0`1cM7<407EhM`@0MGYj101fNg/;07Il
O0@0MWam101fOGdC07ImOP@0MWin101fOWlF0?ooo`00503oool407InO`@0MWj01`1gOh0407MoP@P0
Mh21101hP88707R1PP@0N863101hPX<407V2P`@0NH:4101iPh@707V3Q@@0NHB5201jQ8H807Z5Q`<0
NXJ8101jQhX407V5Q`@0NXF6201jQ8H307Z4Q@@0NXB6101jQHH<07^5QP@0O8F60`1kQHD407^4Q@@0
Nh>4101kPX<407Z1PP@0NH210`1iP80407QoO`@0N7in101hO7`407MkNP@0MWUi101eMgH307=dL`@0
MGQg101eNWX407IkN`/0MWal101fO7d407ImOA<0MWen101fOWh407InOaH0oooo000D0?ooo`@0MWj0
101gOh0407N0P@<0N822101hPH8407V2P`@0NH:4101iPh@407Z4Q@<0NXB6201kQHL407^6R0@0O8N9
101lQhX407b8R`<0OHV;101mRH`407f:S@@0OH^>101mRhl407j<T0<0OXfA101mSi<407f=T0@0OHb>
101mRhd407j;S@<0OXZ<101nRh`407n;S@@0P8b=1020S8h4082<S@@0PHb=0`21Rh/4082:RP@0OhR8
101oQhH407f5Q0@0OH>30`1lPH4407^0O`@0NWim101iNgX407MhMP@0MGEc101cLFh3079_K0@0M7Ab
101eMgD407IhM`@0MWYi101fNWX707MkN`P0Mgal101gOGd407ImO@/0MWen101fOWhF0?ooo`00503o
ool407InP0@0Mgn0101gP84307R0PP@0N862101iPX<407V2Q0@0NH>4101jQ8D307Z4QPP0NhF7101k
QXP407b7R@@0O8N:101lR8/307f9R`@0OHV<101mRXd407f;SP@0OH^?101nS90307j=T@@0OHnC101m
SI0407f<SP@0OH^=101nRhd307j:S0@0OX^<101oRhd4082<S@@0P8b>1020S8d4086<S@<0PH^;1020
RXX407n8R0@0OhN6101mQH@407f3P`<0O861101kP7l407YnO@@0NG]j101gN7H407EeL`@0Lg5^0`1b
Kf`407AdLP@0MGMe101fN7L407IjN@@0MWYj1`1gNg/807MlO0@0Mgem101fOGd;07ImOP@0MWin5P3o
ool001@0oooo101fOX0407MoP0@0Mh210`1hP88407R1PP@0NH:3101iPX@407V3Q0@0NXB50`1jQ8H8
07^5Q`@0NhJ8101lQhT407b7RP@0O8R;0`1mRH/407f9S0@0OHZ=101mRhh407f;S`@0OXb@0`1nSI44
07f?T`@0OHf@101mS8h407f;S@@0OX^=0`1nRX`407j;S0@0Oh^=1020S8d4082<SP@0P8b=1021S8d3
086;R`@0P8Z:101oR8P407n7QP@0OHF4101mPh<307b1P@@0Nh1o101jOWd407UkNP@0MgQf101eMG<4
07=aKP<0LVm/101dM78407EgM@@0MWQg101fNWT407IjNPL0Mg]k201gO7`407MmO@@0MWem2`1fOGh4
07InOQH0oooo000D0?ooo`@0MWj0101gOh0407N0P@<0N822101hPH8407V2P`@0NH:4101iPh@407Z4
Q@<0NXB6201kQHL407^6R0@0O8N9101lQhX407b8R`<0OHV;101mRH`407f:S@@0OH^>101mRhl407j<
T0<0OXfA101mSi<407f=T0@0OHb>101mRhd407j;S@<0OXZ<101nRh`407n;S@@0P8b=1020S8h4082<
S@@0PHb=0`21Rh/4082:RP@0OhR8101oQhH407f5Q0@0OH>30`1lPH4407^0O`@0NWim101iNgX407Mh
MP@0MGEc101cLFh3079_K0@0M7Ab101eMgD407IhM`@0MWYi101fNWX707MkN`P0Mgal101gOGd407Im
O@/0MWen101fOWhF0?ooo`00503oool407MoP0@0Mh21101hPH8307V1P`@0NH:4101jPhD407Z4QP@0
NhJ7101lQXP307b8RP@0OHR:101mRH/407j:S@@0Oh^>101oS8l4082=T0<0P8jA1021Si84086@U0@0
PI6E1021TYH4086CV0<0PIFI1021UY`4086DV0@0PI:E1021TI@4086AT`<0PY6B1022TI<408>AT``0
Q9:B1024TI4308B?S`@0Phf=1022Rh/4086:R@@0PHR71020QXD307n3PP@0OX5o101lOG`407YjN0@0
N7Ic101eLVh4079/I`<0LVeY101dLFh407EdLP@0MWMe101gN7L407MiN0<0MgYi101gNgX407MkN`@0
Mgak101gO7`407MlO@<0Mgem101fOGd807ImOQH0oooo000D0?ooo`@0Mgn0101gP84407R1PP<0NH63
101iPX@407Z3Q@@0NXB6101kQXL407b6R0<0O8R:101mR8X407f9R`@0OXZ=101oRhh407n<S`@0P8f@
0`20SY44086?TP@0PI2D1021TID4086BUP@0PI>H0`21UIT4086FW0@0PIBH1021TYD4086AU0@0PI6C
0`22TI8408:AT`@0Pi6C3024TY8408BAT@<0Q8n?1023SHd408:;R`@0PHZ91021R8L40826Q@<0Oh>2
101nPGl407amO0@0NWYh101hMW<407EbKP@0LVaW0`1bKFT407AaKP@0MGAb101fMgD407MhM`@0MgUh
0`1gNWT407MkNP@0Mg]k101gO7/407MlO0@0Mgam0`1gOGd407ImO@P0MWen5P3oool001@0oooo101g
Oh0407N0P@@0N8620`1iPH<407V2Q0@0NX>5101jQ8H407^6Q`@0O8J80`1lR8X407f8RP@0OHV;101n
RXd407n;SP@0Ohb?1020SI03082>T@@0PHnB1021T9@4086AU@@0PI:F1021TiP3086EV@@0PIJL1021
U9P4086BU@@0PI6D1021TI<308:ATP@0PY6C1023TI<<08BBTP@0Q96A0`24Shl408>=S@@0PX^;1021
RXT40868Q`@0P8J50`1oPh8407j1O`@0O7el101jNWP407QfL`@0MG9^101bK6L3079]J@@0M75^101e
M78407IgM@@0MgQg101gNGP307MjN@@0Mg]j101gNg/407MlN`@0Mgal101gO7d307MmO@@0MWem201f
OGhF0?ooo`00503oool407MoP0@0Mh21101hPH8307V1P`@0NH:4101jPhD407Z4QP@0NhJ7101lQXP3
07b8RP@0OHR:101mRH/407j:S@@0Oh^>101oS8l4082=T0<0P8jA1021Si84086@U0@0PI6E1021TYH4
086CV0<0PIFI1021UY`4086DV0@0PI:E1021TI@4086AT`<0PY6B1022TI<408>AT``0Q9:B1024TI43
08B?S`@0Phf=1022Rh/4086:R@@0PHR71020QXD307n3PP@0OX5o101lOG`407YjN0@0N7Ic101eLVh4
079/I`<0LVeY101dLFh407EdLP@0MWMe101gN7L407MiN0<0MgYi101gNgX407MkN`@0Mgak101gO7`4
07MlO@<0Mgem101fOGd807ImOQH0oooo000D0?ooo`@0Mgn0101hP88407V2P`<0NH:4101jQ8D407^5
Q`@0O8J8101mR8X407j9R`<0OXZ=101oRhh4082=T0@0PHjA1021T9<408:AU0@0Pi:F0`24U9L408BE
V@@0QIJK1025V9`408FIWP@0QIZO0`25Vj4408FMX`@0Q9ZO1025V9`408FGVP@0QINI0`25UYP408JF
V0@0QYJG1026UIH408FEUP@0QYFE1026U9@308JCTP@0QI6@1025Shh408B>S0@0Q8^91022QhH30864
PP@0Oh5o101mOG/407]iMP@0NGEa101fL6/407=ZI@<0M6eY101eL6d407IcL0@0MgEc101gMgD407Mh
MP<0N7Uh101hNGT407MjNP@0Mg]j101gNg/407MlO0<0Mgam101gOGd807ImOQH0oooo000D0?ooo`@0
Mgn0101hP88407V2P`<0NH:4101jQ8D407^5Q`@0O8J8101mR8X407j9R`<0OXZ=101oRhh4082=T0@0
PHjA1021T9<408:AU0@0Pi:F0`24U9L408BEV@@0QIJK1025V9`408FIWP@0QIZO0`25Vj4408FMX`@0
Q9ZO1025V9`408FGVP@0QINI0`25UYP408JFV0@0QYJG1026UIH408FEUP@0QYFE1026U9@308JCTP@0
QI6@1025Shh408B>S0@0Q8^91022QhH30864PP@0Oh5o101mOG/407]iMP@0NGEa101fL6/407=ZI@<0
M6eY101eL6d407IcL0@0MgEc101gMgD407MhMP<0N7Uh101hNGT407MjNP@0Mg]j101gNg/407MlO0<0
Mgam101gOGd807ImOQH0oooo000D0?ooo`@0Mgn0101hP88407V2P`<0NH:4101jQ8D407^5Q`@0O8J8
101mR8X407j9R`<0OXZ=101oRhh4082=T0@0PHjA1021T9<408:AU0@0Pi:F0`24U9L408BEV@@0QIJK
1025V9`408FIWP@0QIZO0`25Vj4408FMX`@0Q9ZO1025V9`408FGVP@0QINI0`25UYP408JFV0@0QYJG
1026UIH408FEUP@0QYFE1026U9@308JCTP@0QI6@1025Shh408B>S0@0Q8^91022QhH30864PP@0Oh5o
101mOG/407]iMP@0NGEa101fL6/407=ZI@<0M6eY101eL6d407IcL0@0MgEc101gMgD407MhMP<0N7Uh
101hNGT407MjNP@0Mg]j101gNg/407MlO0<0Mgam101gOGd807ImOQH0oooo000D0?ooo`@0Mgn0101h
PH8407V2Q0<0NXB5101kQHL407b7R@@0OHV;101nRXd4082<SP<0PHf@1022Si8408>AU0@0Pi>F1024
U9P408FFVP@0QYRL0`27VIh408RKX0@0RIfR1029WZ@408VPY@@0RJ6W0`29XZT408VSZP@0R:2U1028
WZ<408RMX0@0RIbO0`29Vih408VKW@P0RYZK102:VYX408ZIV@@0RYRH0`29UYH408RDT`@0R9:A1027
Shh408N=R`@0QHZ80`23QH<408:2O`@0Ogik101lNGD407YdK`@0MfiY101dJF<307E]J0@0MW1/101g
LVl407QdL@@0N7Ic101hMgD307QhM`@0N7Uh101hNWT407QjNP@0N7]k101gO7/307MlO0@0Mgam101g
OGd407ImOQH0oooo000D0?ooo`@0Mgn0101hPH8407V2Q0<0NXB5101kQHL407b7R@@0OHV;101nRXd4
082<SP<0PHf@1022Si8408>AU0@0Pi>F1024U9P408FFVP@0QYRL0`27VIh408RKX0@0RIfR1029WZ@4
08VPY@@0RJ6W0`29XZT408VSZP@0R:2U1028WZ<408RMX0@0RIbO0`29Vih408VKW@P0RYZK102:VYX4
08ZIV@@0RYRH0`29UYH408RDT`@0R9:A1027Shh408N=R`@0QHZ80`23QH<408:2O`@0Ogik101lNGD4
07YdK`@0MfiY101dJF<307E]J0@0MW1/101gLVl407QdL@@0N7Ic101hMgD307QhM`@0N7Uh101hNWT4
07QjNP@0N7]k101gO7/307MlO0@0Mgam101gOGd407ImOQH0oooo000D0?ooo`@0Mgn0101hPH8407V2
Q0<0NXB5101kQHL407b7R@@0OHV;101nRXd4082<SP<0PHf@1022Si8408>AU0@0Pi>F1024U9P408FF
VP@0QYRL0`27VIh408RKX0@0RIfR1029WZ@408VPY@@0RJ6W0`29XZT408VSZP@0R:2U1028WZ<408RM
X0@0RIbO0`29Vih408VKW@P0RYZK102:VYX408ZIV@@0RYRH0`29UYH408RDT`@0R9:A1027Shh408N=
R`@0QHZ80`23QH<408:2O`@0Ogik101lNGD407YdK`@0MfiY101dJF<307E]J0@0MW1/101gLVl407Qd
L@@0N7Ic101hMgD307QhM`@0N7Uh101hNWT407QjNP@0N7]k101gO7/307MlO0@0Mgam101gOGd407Im
OQH0oooo000D0?ooo`@0Mgn0101hPH8407V2Q0<0NXB5101kQHL407b7R@@0OHV;101nRXd4082<SP<0
PHf@1022Si8408>AU0@0Pi>F1024U9P408FFVP@0QYRL0`27VIh408RKX0@0RIfR1029WZ@408VPY@@0
RJ6W0`29XZT408VSZP@0R:2U1028WZ<408RMX0@0RIbO0`29Vih408VKW@P0RYZK102:VYX408ZIV@@0
RYRH0`29UYH408RDT`@0R9:A1027Shh408N=R`@0QHZ80`23QH<408:2O`@0Ogik101lNGD407YdK`@0
MfiY101dJF<307E]J0@0MW1/101gLVl407QdL@@0N7Ic101hMgD307QhM`@0N7Uh101hNWT407QjNP@0
N7]k101gO7/307MlO0@0Mgam101gOGd407ImOQH0oooo000D0?ooo`@0Mh21101iPX<407Z3Q@<0NhF7
101lQhT407j9R`@0Oh^=1020SHl4086?TP<0Pi6D1024TiH408FEV0@0QYNK1027VId408RKW`@0RYfQ
0`2;Wj@408bQYP@0SJ>Y102=YJ/408jW[@@0SZR_0`2=ZK0408bY/0@0S:J/102;Y:P408bRYP@0S:6T
0`2<X:8408fPX@@0SInQ102>Wj0408jOW`@0SYjN102=W9`308fKVP@0SIVH102<UYD408bCTP@0Ri2>
1029RhX308N7Q@@0Q8>01022OW/407miM@@0O7=^101gK6H407IZH`<0MfeX101hL6/407QbKP@0NGA`
101iMG8407UgM0<0NGQf101iNGL407QiN0@0N7Yi101hNgX407QkN`L0Mgal101gOGd407ImOQH0oooo
000D0?ooo`@0Mh21101iPX<407Z3Q@<0NhF7101lQhT407j9R`@0Oh^=1020SHl4086?TP<0Pi6D1024
TiH408FEV0@0QYNK1027VId408RKW`@0RYfQ0`2;Wj@408bQYP@0SJ>Y102=YJ/408jW[@@0SZR_0`2=
ZK0408bY/0@0S:J/102;Y:P408bRYP@0S:6T0`2<X:8408fPX@@0SInQ102>Wj0408jOW`@0SYjN102=
W9`308fKVP@0SIVH102<UYD408bCTP@0Ri2>1029RhX308N7Q@@0Q8>01022OW/407miM@@0O7=^101g
K6H407IZH`<0MfeX101hL6/407QbKP@0NGA`101iMG8407UgM0<0NGQf101iNGL407QiN0@0N7Yi101h
NgX407QkN`L0Mgal101gOGd407ImOQH0oooo000D0?ooo`@0Mh21101iPX<407Z3Q@<0NhF7101lQhT4
07j9R`@0Oh^=1020SHl4086?TP<0Pi6D1024TiH408FEV0@0QYNK1027VId408RKW`@0RYfQ0`2;Wj@4
08bQYP@0SJ>Y102=YJ/408jW[@@0SZR_0`2=ZK0408bY/0@0S:J/102;Y:P408bRYP@0S:6T0`2<X:84
08fPX@@0SInQ102>Wj0408jOW`@0SYjN102=W9`308fKVP@0SIVH102<UYD408bCTP@0Ri2>1029RhX3
08N7Q@@0Q8>01022OW/407miM@@0O7=^101gK6H407IZH`<0MfeX101hL6/407QbKP@0NGA`101iMG84
07UgM0<0NGQf101iNGL407QiN0@0N7Yi101hNgX407QkN`L0Mgal101gOGd407ImOQH0oooo000D0?oo
o`@0Mh21101iPX<407Z3Q@<0NhF7101lQhT407j9R`@0Oh^=1020SHl4086?TP<0Pi6D1024TiH408FE
V0@0QYNK1027VId408RKW`@0RYfQ0`2;Wj@408bQYP@0SJ>Y102=YJ/408jW[@@0SZR_0`2=ZK0408bY
/0@0S:J/102;Y:P408bRYP@0S:6T0`2<X:8408fPX@@0SInQ102>Wj0408jOW`@0SYjN102=W9`308fK
VP@0SIVH102<UYD408bCTP@0Ri2>1029RhX308N7Q@@0Q8>01022OW/407miM@@0O7=^101gK6H407IZ
H`<0MfeX101hL6/407QbKP@0NGA`101iMG8407UgM0<0NGQf101iNGL407QiN0@0N7Yi101hNgX407Qk
N`L0Mgal101gOGd407ImOQH0oooo000D0?ooo`@0Mh21101iPX@407^4QP<0O8N8101nRH/407n;S@@0
P8f@1022Si8408>BU@<0QIBG1026UYX408RIW@@0RI^O102:WJ8408bPY@@0SJ:W0`2>Y:X408nW[@@0
TJV`102B[;<409>^]@@0Tk2h0`2B/KT408n^]P@0SZZ`102>Z:d408nWZ`@0SjJX0`2@YJL8096UYP@0
TJBU202BY:@409:RXP<0TZ2P102AWYd4096JV@@0T9NE102?Ti4408f?S@<0RXZ81028QH8408F0O@@0
PGYe101mLfh807U/I@<0NFiX101iLF/407YbKP@0NWA`101jMG8407YfL`<0NWMe101iN7H407UiM`@0
NGYh101hNWT407QkN`<0N7ak101gO7`407MmO@@0MWen5P3oool001@0oooo101gP84407V2Q0@0NhB6
0`1lQhP407j9R`@0Oh^=1020SI0408:?TP@0Pi:E0`25U9L408JFVP@0R9VM1029Vil408ZMXP@0S:2U
102=XZL308jTZP@0SjN]102AZK0409://`@0Tjje102C/;P309:a^@@0Sjjf102>Z[0408jX[@@0SjN[
102?YZP3092UY`P0TJFV102AY:D809:TY0@0TZ:R0`2BX:04096NW@@0TIZI102@UiD408nCT@@0SHn=
0`2:RXP408R5PP@0QH1m1021NWD407ecKPP0NFaU0`1iKVP407UaJ`@0NW9^101jM70407YeLP@0NWIc
0`1jMgD407UhMP@0NGUg101iNWP407QjN@@0N7]k0`1hO7/407MlO0@0Mgem101fOGhF0?ooo`00503o
ool407N0P@@0NH:4101kQ8H307b7R0@0OXV;101oRhd4082=T0@0PXnB1023TYD308FDU`@0QYJJ1028
VId408VKW`@0RYfR102<X:D408fRY`<0SZBZ102?Yjd4096Y/0@0TZbc102C[[D409>`^0<0T[6i102?
[[H408jZ/0@0SZR]102?Yj/408nVZ0<0T:FW202AYJH4096TY@P0TZBT102BXZ8309:PX0@0TIjM102A
VYT4092GU@@0Si>A102=Shd308Z:R0@0R8F21025P7d4085jM@@0OG=^201iK6D307U^J0@0NG5[101j
LVh407YdL0@0NWEb101jMW<307YgM@@0NGQf101iNGL407UjN0@0N7Yi101hNg/307QlN`@0Mgal101g
OGd407ImOQH0oooo000D0?ooo`@0Mh21101iPX@407^4QP<0O8N8101nRH/407n;S@@0P8f@1022Si84
08>BU@<0QIBG1026UYX408RIW@@0RI^O102:WJ8408bPY@@0SJ:W0`2>Y:X408nW[@@0TJV`102B[;<4
09>^]@@0Tk2h0`2B/KT408n^]P@0SZZ`102>Z:d408nWZ`@0SjJX0`2@YJL8096UYP@0TJBU202BY:@4
09:RXP<0TZ2P102AWYd4096JV@@0T9NE102?Ti4408f?S@<0RXZ81028QH8408F0O@@0PGYe101mLfh8
07U/I@<0NFiX101iLF/407YbKP@0NWA`101jMG8407YfL`<0NWMe101iN7H407UiM`@0NGYh101hNWT4
07QkN`<0N7ak101gO7`407MmO@@0MWen5P3oool001@0oooo101hP88407V3Q0@0NhF70`1mR8X407n:
S@@0P8f?1022Si8408BBU@@0QIFH0`27Ui/408VJWP@0RYbQ102<Wj@408fRY`@0SjBZ102@Yjd309:Z
/0@0Tjfc102E/;L409Jc^P@0V;Jn102K^l<309Be_P@0T:ng102A[[<4096//@@0TZ^_102CZjd709BZ
[0@0UJZ[102EZZX409JZZP@0UZZY102GZ:P309NVY@@0Uj>R102FWih409BKV@@0TiNE102ATY0308j<
RP@0RhN41027PGd408=kMP@0P7A_101kKFH407]^I`<0Ng1Z101kLF`407]cKP@0NgA`101kMG4407]f
L`<0NWMd101jN7D407YhMP@0NGUg101iNWT707QkNP@0Mg]k101gO7d407ImOQH0oooo000D0?ooo`@0
N822101iPh@407^5Q`<0OHR:101oRXd4082=S`@0PXnB1024TYD408FEV0<0QiNK1029VYh408ZLX@@0
S9nT102=XZL408nTZP@0T:N]0`2BZ[0409>]/`@0UK2g102F/kX409Rf_P@0Vk_30`2D]Kh4092_]`@0
TJjc102A[;4409:[[`@0Tj^]1`2DZZ`409FZZ`@0UJZZ102FZZX409JZZ@@0UjRX0`2GYZD409NSXP@0
UYnN102DViT409>GU@@0TI:@0`2>S8X408^7Q0@0Qh5m1023NgH4081dK`@0NfeV101kKVL307]`JP@0
Ng5/101kLfh407]dL0@0NgEa101kMW<307YgM0@0NWQe101jN7H407UiM`@0NGYi1`1hNgX407MkN`@0
Mgam101fOGhF0?ooo`00503oool407R0PP@0NH>4101kQHL307f8RP@0OhZ=1020SHl408:?TP@0Q9:E
1025UIP308NGV`@0RIZN102:W:4408bOY0@0SJ:W102?Y:X4092W[@<0TZZ`102C[K<409F`]`@0U[>j
102H][h409^k``<0U;Fn102@[kL4096^/`@0TJba102BZjl409>[[@L0U:Z/102EZZ/409FZZP@0UZZZ
102FZZT409NXZ0<0UjJU102GXj8409JOWP@0U9^I102CUiD4096BT0<0SXb:102;Qh@408N1O@@0Pg]f
1020M6l407]]IP@0NfiW0`1kL6X407]aK0@0Ng=^101kM70407]eL@@0NgIc0`1jMg@407YhM@@0NWQf
101iNGL407UjN@L0N7]j101gNg/407MlO@@0MWen5P3oool001@0oooo101hP88407V3Q0@0NhF70`1m
R8X407n:S@@0P8f?1022Si8408BBU@@0QIFH0`27Ui/408VJWP@0RYbQ102<Wj@408fRY`@0SjBZ102@
Yjd309:Z/0@0Tjfc102E/;L409Jc^P@0V;Jn102K^l<309Be_P@0T:ng102A[[<4096//@@0TZ^_102C
Zjd709BZ[0@0UJZ[102EZZX409JZZP@0UZZY102GZ:P309NVY@@0Uj>R102FWih409BKV@@0TiNE102A
TY0308j<RP@0RhN41027PGd408=kMP@0P7A_101kKFH407]^I`<0Ng1Z101kLF`407]cKP@0NgA`101k
MG4407]fL`<0NWMd101jN7D407YhMP@0NGUg101iNWT707QkNP@0Mg]k101gO7d407ImOQH0oooo000D
0?ooo`@0N862101jQ8D407b7R0<0OXV;1020S8h408:?T@@0Q9:E1026UIP408NGV`<0RIZN102;WJ84
08fPY@@0Sj>X102@YZ`409:Y[`@0U:bc0`2E[kH409Nc^P@0VKJm102K^L4409fnaP@0W/380`2?/[/4
096a^@@0Tk2f102D/;D409F`/`@0UZnb0`2G[k4409R_/0@0VJn`102J[jl409Z`/0@0Vk2_102L[Zh3
09b/Z`@0VjRV102JXj8409VOW@@0UiZH102DUI83096?S0@0SXV6102:Pgl408ImN0@0PgMa101nL6T4
07iaJP<0OW9[101mLVd407ecKP@0OGA_101lMG4407afLP<0NgMc101kN7D407YhMP@0NWUg101iNWP4
07UjN@<0N7]j101hNg/407MlO0@0MWen5P3oool001@0oooo101hPH8407Z4Q@@0O8N80`1nRH/4082<
SP@0PXnA1024TYD408JEV0@0QiNK0`29VYh408^MXP@0SJ2U102?XjP4092V[0@0TZV_102D[;<309F_
]P@0Uk>j102I][d409^i`@@0WKk6102N`<P308nb^`@0TK6i102C/;H409B`]@@0UK2c102F[k8309N_
/@@0V:n`102I[k0409Z_[`@0V[2`102K/:l409b^[P<0W:b[102KZ:H409ZSXP@0VInM102GVYP409BE
TP<0THn<102>RHH408Z3O`@0QWeh1023Mg4407i`J@@0OW5Z0`1nLV/407ebK@@0OG=^101mM6l407ae
L@@0O7Ib0`1kMg<407]hM@@0NWQf101jNGL407UjN0@0NGYi0`1hNgX407QkN`@0Mgal101fOGhF0?oo
o`00503oool407R1PP@0NXB5101lQhP307j9R`@0P8b>1022Si4408BBU@@0QYFH1027Ui/308VJWP@0
RifR102=X:D408nSZ0@0T:J/102BZJl409B//`<0UJnf102G/kX409Vf_@@0VkW1102M_/H409k0b0<0
Sk:k102A/KT409>`]P@0U;2e102E/;<409J_/P<0Ujna102H[k0409V_/0@0VZn_102J/;0409^`[`@0
W:j^0`2L[:/409^XYP@0VZ>R102IWid409NJV0@0U9FB0`2ASh`408j9QP@0RX=o1026OGP408=gL@@0
OW1Y101nLFX307ibJ`@0OG9]101mLfh407edK`@0O7Ea101lMW8307]gL`@0NgQe101jN7H407YiM`@0
NGYh101iNWT307QkNP@0N7]k101gO7`407ImOQH0oooo000D0?ooo`@0N862101jQ8D407b7R0<0OXV;
1020S8h408:?T@@0Q9:E1026UIP408NGV`<0RIZN102;WJ8408fPY@@0Sj>X102@YZ`409:Y[`@0U:bc
0`2E[kH409Nc^P@0VKJm102K^L4409fnaP@0W/380`2?/[/4096a^@@0Tk2f102D/;D409F`/`@0UZnb
0`2G[k4409R_/0@0VJn`102J[jl409Z`/0@0Vk2_102L[Zh309b/Z`@0VjRV102JXj8409VOW@@0UiZH
102DUI83096?S0@0SXV6102:Pgl408ImN0@0PgMa101nL6T407iaJP<0OW9[101mLVd407ecKP@0OGA_
101lMG4407afLP<0NgMc101kN7D407YhMP@0NWUg101iNWP407UjN@<0N7]j101hNg/407MlO0@0MWen
5P3oool001@0oooo101hPH8407Z4QP@0OHN90`1oRXd4086=T0@0Pi6D1025U9L408NGV`@0RIZN0`2;
WJ8408jQY@@0T:BY102BYjd409B[/@@0UJjd102G/KP309Ve_0@0VkS0102M_<@409job0@0XLC=102F
^/@308b`^P@0T[>k102E];X409Ne^@@0VKBh102J];L309^d]P@0W;Be102M];@409je]@@0WkJe102P
]K@40:2c/P<0X;2^102OZjT409jWY@@0WJ:P102KWI/409NGU0<0U96>102@RhL408b5P0@0RGmj1025
NG<4085dK@@0PG=/0`20Lfd4081dK@@0OgA^101nMFl407ieL@@0OGIb0`1lMg<407agM0@0NgQe101j
NGH407YiN0@0NGYi0`1hNgX407QkN`@0Mgal101gOGdF0?ooo`00503oool407R1PP@0NXB6101mQhT3
07n:S@@0PHf@1023TI@408FDU`@0QiNK1029VYh308^MXP@0SZ6U102@Y:T409:W[@@0U:^a102E[[@4
09Na^0<0VKFl102K^<0409fla0@0W[o8102Qa<d409Jja0<0S;2j102B/k/409Fd^P@0UkFi102I];P4
09Zd]`<0VkBf102L];D409fd]0@0W[Fe102O][D40:2e]0@0X;>b0`2P/:h409n[Z@@0WZNU102MXZ04
09^MV`@0UiND0`2DTHh4092;Q`@0S8F01029OgX408EiL`@0PGA]1021Lf`3081cK@@0P7A]101oM6h4
07ieK`@0OWEa101mMW8307agL`@0O7Md101kN7D407YiMP@0NWUh101iNWT307QkNP@0N7]k101gO7`4
07MmOAH0oooo000D0?ooo`@0N862101jQ8H407f7R@<0OhZ=1021SI0408>AU0@0QIBG1027Ui/408VJ
WP<0RifR102>XJD4092TZ@@0TZN]102DZk4409F^]0@0Uk6h0`2I]K`409^h`0@0WKc4102N_lP40:74
c@@0U[[40`2</;X409:c^`@0UKBj102G]KT409Vd^0@0V[Bg0`2K];H409bd]@@0WKBd102N]KD409nf
]@@0X;Fd102P/k830:2`[P@0Wj^Y102NYjD409fRX0@0VifK102GUi@309BASP@0T8^7102<QH0408Uo
NP@0QGUc1021M6d4085cK0<0P7=]1020M6d407mdKP@0OWE_101nMG4407efLP<0O7Mc101lMg@407]h
M@@0NWUf101jNGP407UjN@<0N7]j101hNg/407MlO0@0Mgem5P3oool001@0oooo101hPH<407^5QP@0
OHR:0`20S8h408:?T@@0Q9:F1027UYT408VJW@@0RifQ0`2>XJD4092TZ@@0TZR]102DZk4409N_]@@0
VK>j102K][h309fj`P@0Wkk6102Q`//40:C7d@@0Vl3:102@]/0309>f_`@0U[Nn102H^;h409Zi_P@0
W;Vm102M^;/309nh^P@0WkRi102P^KT40:6j^@@0Xkbj102S^[P40:Bg]@<0Y;Ba102S[j`40::YY`@0
XJFR102NWi`409^IUP<0Ui>@102CSHT408n7PP@0S85l1028OGH408IhL@@0PgA^1`22M6h4085eK`@0
P7E_101oMG0407ifL@<0OGIb101lMg<407ahM@@0NgQf101jNGL407UjN0<0NGYi101hNg/407MlO0@0
Mgem5P3oool001@0oooo101hPH<407^5QP@0OHR:0`20S8h408:?T@@0Q9:F1027UYT408VJW@@0RifQ
0`2>XJD4092TZ@@0TZR]102DZk4409N_]@@0VK>j102K][h309fj`P@0Wkk6102Q`//40:C7d@@0Vl3:
102@]/0309>f_`@0U[Nn102H^;h409Zi_P@0W;Vm102M^;/309nh^P@0WkRi102P^KT40:6j^@@0Xkbj
102S^[P40:Bg]@<0Y;Ba102S[j`40::YY`@0XJFR102NWi`409^IUP<0Ui>@102CSHT408n7PP@0S85l
1028OGH408IhL@@0PgA^1`22M6h4085eK`@0P7E_101oMG0407ifL@<0OGIb101lMg<407ahM@@0NgQf
101jNGL407UjN0<0NGYi101hNg/407MlO0@0Mgem5P3oool001@0oooo101hPH<407^5QP@0OHR:0`20
S8h408:?T@@0Q9:F1027UYT408VJW@@0RifQ0`2>XJD4092TZ@@0TZR]102DZk4409N_]@@0VK>j102K
][h309fj`P@0Wkk6102Q`//40:C7d@@0Vl3:102@]/0309>f_`@0U[Nn102H^;h409Zi_P@0W;Vm102M
^;/309nh^P@0WkRi102P^KT40:6j^@@0Xkbj102S^[P40:Bg]@<0Y;Ba102S[j`40::YY`@0XJFR102N
Wi`409^IUP<0Ui>@102CSHT408n7PP@0S85l1028OGH408IhL@@0PgA^1`22M6h4085eK`@0P7E_101o
MG0407ifL@<0OGIb101lMg<407ahM@@0NgQf101jNGL407UjN0<0NGYi101hNg/407MlO0@0Mgem5P3o
ool001@0oooo101hPH<407^5QP@0OHR:0`20S8h408:?T@@0Q9:F1027UYT408VJW@@0RifQ0`2>XJD4
092TZ@@0TZR]102DZk4409N_]@@0VK>j102K][h309fj`P@0Wkk6102Q`//40:C7d@@0Vl3:102@]/03
09>f_`@0U[Nn102H^;h409Zi_P@0W;Vm102M^;/309nh^P@0WkRi102P^KT40:6j^@@0Xkbj102S^[P4
0:Bg]@<0Y;Ba102S[j`40::YY`@0XJFR102NWi`409^IUP<0Ui>@102CSHT408n7PP@0S85l1028OGH4
08IhL@@0PgA^1`22M6h4085eK`@0P7E_101oMG0407ifL@<0OGIb101lMg<407ahM@@0NgQf101jNGL4
07UjN0<0NGYi101hNg/407MlO0@0Mgem5P3oool001@0oooo101iPX<407^5Q`@0OXV;0`21SHl408>@
T`@0QYBH1028V9`408^LX0@0SJ2T0`2@Y:T409:X[@@0UJba102G[kH409Zc^P@0W;No102N^l<30:6o
b0@0Xl?<102Tam4409o4c`@0U;_6102F^lD309Nka0@0V[_2102L_<8409jm``@0X;g1102Q_Kl30::l
_P@0Xkbm102T_Kd40:Fm_0@0Y[fl102W^KP40:Nf]@<0Yk:`102W[Zd40:JZZ0@0YJJT102QX9h409jJ
U`<0VYB@102ESXT40968P`@0SX=n102:OgP408QjL`@0QWM`0`25MFh408AeKP@0PgE^1022MFl4081e
L0@0OgIa0`1nMW8407egL`@0O7Md101kN7D407YiMP@0NWUh0`1iNWT407QkNP@0Mgal101gOGdF0?oo
o`00503oool407V2P`@0NhF7101nRH/3086=S`@0Pi2C1026U9P408RHW0@0RibP102=X:@3092TZ@@0
TZR]102E[;4409N_]P@0V[>j102L]kl409jk``<0XKo8102S`l`40:C7d@@0WlC?102D^lH409Jka@<0
Uk_4102J^l8409bl`P@0W[g3102P_L440:6m_`<0X[bn102S_;d40:Bm_@@0YKfl102V_K`40:Ni^0@0
YkJe0`2W/[040:N^[@@0YZZX102UYZ@40:6PWP@0WYZG0`2JU90409F>R@@0THR3102>Pgh408YoN0@0
R7Yc1026Mg0308EeKP@0Q7E^1023MFh4089eK`@0P7E`101oMW4307ifLP@0OGMc101lMg@407]hM@@0
NWUf101jNGP307UjN@@0N7]j101gO7`407MmOAH0oooo000D0?ooo`@0NH:3101kQHL407j9R`<0PHf?
1023T9<408JDV0@0R9RL102;W:0408fPY0<0T:BY102BZ:d409F//@@0Ujnf102J/kX409bg_`@0W[_3
0`2Q_lP40:?3c0@0Y<OA102Oa<l409BkaP@0U[_50`2G^l@409Zk`P@0W;c2102N_L<40:2m`@@0XKfo
0`2R_;h40:>l_@@0Y;fm102U_K`40:Jm_0@0YkVh102W][D30:Nb/0@0Yjj]102VZZP40:FVY0@0XJ2N
102NVYL309ZDT0@0UHj9102AR8<408j3OP@0RWmh1028NW<408IgL0<0QGE^1024MFh408=eKP@0PWE_
1020MG0407mfL@<0OWIb101mMg<407agM0@0NgQe101jNGH407YiN0<0NGYi101hNgX407MlO0@0Mgem
5P3oool001@0oooo101iPX<407^5Q`@0OXV;0`21SHl408>@T`@0QYBH1028V9`408^LX0@0SJ2T0`2@
Y:T409:X[@@0UJba102G[kH409Zc^P@0W;No102N^l<30:6ob0@0Xl?<102Tam4409o4c`@0U;_6102F
^lD309Nka0@0V[_2102L_<8409jm``@0X;g1102Q_Kl30::l_P@0Xkbm102T_Kd40:Fm_0@0Y[fl102W
^KP40:Nf]@<0Yk:`102W[Zd40:JZZ0@0YJJT102QX9h409jJU`<0VYB@102ESXT40968P`@0SX=n102:
OgP408QjL`@0QWM`0`25MFh408AeKP@0PgE^1022MFl4081eL0@0OgIa0`1nMW8407egL`@0O7Md101k
N7D407YiMP@0NWUh0`1iNWT407QkNP@0Mgal101gOGdF0?ooo`00503oool407V2P`@0O8J8101oRX`3
08:>T@@0Q9:E1027UYX408ZJWP@0SInS102@XjL309:W[0@0UJ^a102H[kD409Zd^P@0WKRo102P_<@4
0:;0b@<0Y<G>102WbM840:[>f0@0WLC@102I`</409Znb0<0Vkk7102N_lH40:30a`@0Xl;7102U`/D4
0:G0`P<0Y/30102W`<040:O0_`@0Z;fm102Y^[X40:Zg]`@0ZK6a0`2Y[Zd40:Z^[@@0ZJ^Y102XYZ@4
0:BQWP@0X9ZH0`2KUI8409N>RP@0ThV4102@Q7l408f0NP@0Rgae1029NG4308IeK@@0QWI^1025MVh4
08=eK`@0PWE_1020MW0307mfL@@0OWIb101mMg<407ahM0@0NgQf101jNGL307UjN@@0N7]j101gO7`4
07MmOAH0oooo000D0?ooo`@0NH:3101lQXP407n:S0<0PXjA1024TYD408NFVP@0RYZN102=Wj<4092S
Y`<0TZN/102EZk4409R_]@@0V[Bj102M^;l40:2la0@0X/390`2TaLh40:O9dP@0Z/kH102Ma=0409W0
b`@0V[k80`2K_/L409joaP@0X<37102S`/L40:G2a@@0YL320`2V`<040:O0`0@0Yl2o102X_Kd40:Vj
^P@0Z[Ng102Y/K430:V^[@@0ZZj]102YZjT40:RVY0@0Y:6N102PVYP309^ETP@0Uhj:102CRH@40924
O`@0SH1j102;O7D408UiL@<0QWE]1026MVh408EfKP@0PgE_1022MFl4081fL0<0OgIa101nMW8407eg
L`@0O7Qd101kN7H407YiM`<0NGYi101hNgX407MlO0@0Mgem5P3oool001@0oooo101iPX<407b6R0@0
OhZ<0`22SY4408BBU@@0QiJJ102:VYh408fOX`@0T:>W0`2BYj`409F[/@@0V:ne102J];X409fh_`@0
X;c4102R`<T30:C5cP@0YlWB102Zc]P409g4d0@0VL3;102J_/P309^na`@0W[o6102P`<L40:?2a`@0
YL;5102U`<830:K0`0@0Yl30102W`;l40:Rm_@@0ZKZj102Z]kL40:Va/@<0ZJj]102Z[Zd40:V[Z@@0
Z:JT102TXIh40:2JV0<0ViFB102GSXX409>9Q0@0T8Ao102=P7X408]lM@@0RGUa0`26MFd408IfKP@0
QGI^1023MFl4089eK`@0P7I`0`1oMW4407ifLP@0OGMc101lN7@407]hMP@0NWUg0`1iNWT407QkNP@0
Mgal101gOGdF0?ooo`00503oool407V2P`@0O8J8101oRX`308:>T@@0Q9:E1027UYX408ZJWP@0SInS
102@XjL309:W[0@0UJ^a102H[kD409Zd^P@0WKRo102P_<@40:;0b@<0Y<G>102WbM840:[>f0@0WLC@
102I`</409Znb0<0Vkk7102N_lH40:30a`@0Xl;7102U`/D40:G0`P<0Y/30102W`<040:O0_`@0Z;fm
102Y^[X40:Zg]`@0ZK6a0`2Y[Zd40:Z^[@@0ZJ^Y102XYZ@40:BQWP@0X9ZH0`2KUI8409N>RP@0ThV4
102@Q7l408f0NP@0Rgae1029NG4308IeK@@0QWI^1025MVh408=eK`@0PWE_1020MW0307mfL@@0OWIb
101mMg<407ahM0@0NgQf101jNGL307UjN@@0N7]j101gO7`407MmOAH0oooo000D0?ooo`@0NH:4101l
QhP407n;S@<0Pi2B1026U9L408VHW0@0S9fQ102?XJD409:UZP<0UJZ_102G[[@409Zc^@@0WKRn102P
_<@40:?1b@@0Y/G>0`2Yb]<40:_?f@@0YLcH102H`<`409_1b`@0WL7;0`2O`LT40:72b@@0Y<C:102W
a//40:W6b@@0ZLC40`2Z`l<40:g3``@0ZK^k102X]kP40:Vc]0@0ZK6a102Y/K030:b`[`@0[Jj]102/
Z:L40:bVY0@0Z::P102SViT309fETP@0V8n:102DRH@40964O`@0T85k102>OGH408akL`<0RWQ`1028
MVh408MfKP@0QGE^1023MFl4085eK`<0P7E`101nMW4407efLP@0O7Md101kN7D407YiM`<0NGYh101h
NgX407QlN`@0Mgem5P3oool001@0oooo101iPX@407b7R0@0Oh^=0`23T98408JDU`@0RIRL102<WJ44
08nQY@@0TZFZ0`2EZZl409N^]0@0V[>i102M^;h40:2la0@0Xl79102VaLh30:W:d`@0ZloI102Uc=P4
09S0c0@0Vl7;102M`L/309o1b@@0XL;9102Ta<X40:O6b`@0ZLK9102Ya<@30:[3``@0[L?3102Y^k/4
0:Rg^0@0ZK>d102Y/K440:Va/0<0[;2_102][Zd40:bXY`@0[:JT102XXZ040:>KV@<0WIFB102HShX4
09B9Q0@0THAo102@PG/408imMP@0S7]c0`2:N70408QfKP@0QgI^1025MFh408=eK`@0PGE_0`20MG04
07ifL@@0OGIb101lMg@407]hM@@0NWUg0`1iNWP407QkNP@0N7ak101gOGdF0?ooo`00503oool407V2
Q0@0O8N8101oRhd308>@TP@0QYBG1029V9`408bMX@@0Sj6U102BYJX309FZ[`@0Ujjd102J/kT409fh
_P@0X;c4102S`LT40:K5cP<0ZL[C102[cmT40:G<f0@0V<3<102K`L/409g1b`<0Wl79102Q`/T40:C4
bP@0YlK;102Ya/T40:W4a0<0Z/?3102]`l<40:Vk^`@0Z;Nh102Y/k@40:Va/@@0ZK6`0`2//:l40:f^
[@@0[:RW102/YZ@40:RRX0@0Xi^I0`2MUI8409R?RP@0U8V4102AQ7l40921N`@0SWef102<Ng<308Yh
L0@0R7I^1027MVh408EeKP@0PgE_1021MFl3081eL0@0OWIa101mMW8407agM0@0NgQe101jNGL307Uj
N0@0N7]j101hO7/407MmOAH0oooo000D0?ooo`@0NH:4101lQhP407n;S@<0Pi2B1026U9L408VHW0@0
S9fQ102?XJD409:UZP<0UJZ_102G[[@409Zc^@@0WKRn102P_<@40:?1b@@0Y/G>0`2Yb]<40:_?f@@0
YLcH102H`<`409_1b`@0WL7;0`2O`LT40:72b@@0Y<C:102Wa//40:W6b@@0ZLC40`2Z`l<40:g3``@0
ZK^k102X]kP40:Vc]0@0ZK6a102Y/K030:b`[`@0[Jj]102/Z:L40:bVY0@0Z::P102SViT309fETP@0
V8n:102DRH@40964O`@0T85k102>OGH408akL`<0RWQ`1028MVh408MfKP@0QGE^1023MFl4085eK`<0
P7E`101nMW4407efLP@0O7Md101kN7D407YiM`<0NGYh101hNgX407QlN`@0Mgem5P3oool001@0oooo
101iPh@407f7R@@0P8b?0`24TI<408NEV@@0RYZM102=Wj<4096TZ0@0U:R]0`2G[K<409Zb^0@0WKNm
102P_<<40:C1b0@0YlK>102Zbm<30:c?f0@0/=CN102Qb=@409_1c@@0WL;<102O`l`30:73bP@0Y<G;
102Wald40:_9c@@0[<S:102^a/L30:^n_`@0Z;Nh102S/K840:Nb/`@0ZK6b102[/[840:fc/`<0[Jf/
102/ZjX40:fYY`@0[ZVW102[Xj440:FLV@<0WYFB102JShX409J9Q0@0ThEo102BPW`40960N0@0Sgee
0`2=NG4408]fK0@0RWI]1027MVd408AeKP@0PWA^0`20MFl407meL0@0OGIa101lMW<407]gM0@0NWQf
0`1iNGP407QjN@@0N7]k101gOGdF0?ooo`00503oool407V3Q0@0OHN91020S8l308BAT`@0QiFI102:
VYd408fOX`@0TJBX102DZ:d309N]/`@0V[:h102M]kd40:2l``@0Y<78102Wa/h40:[;d`<0[<oH102`
e=h40:78e0@0Vl7=102M`/`409o3c0<0XL?:102TaL/40:O7c@@0ZlW=102/b<X40:k6a`<0Zkjo102X
]kP40:>a/P@0Yk:c102Y/K840:^b/P@0[K>c0`2][J`40:b[ZP@0[JVW102^ZJL40:^SX@@0YIbI0`2N
UI8409Z?RP@0UXV4102CQGl409:2O0@0TH1h102?OGD308eiL@@0RgI/102:MVd408MfK@@0Q7E^1022
M6h3081eK`@0OgE`101mMW4407afL`@0NgMd101jN7H307UiN0@0N7Yi101hNg/407MmOAH0oooo000D
0?ooo`@0NH>4101mQhT4082<S`<0Q96C1027UIT408ZJW@@0SInS102AY:P409BX[@<0Ujfc102J/[P4
09fg_@@0X;c3102T`LP40:O6cP@0Z/_C0`2/cmP40;3DgP@0XLSD102K`Ld409g2c0@0Wl?<0`2Q`lX4
0:C5b`@0YlO=102[bLd40:c8bP@0[/K70`2[_[l40:Rg^0@0Xk6b102W/[<40:Va/P@0Zk:b102]/k<3
0:f][0@0[:^Z102]ZJL40:jYY`@0Zj>Q102UW9T309jETP@0VXn:102FRH@409>5O`@0TX9l102AP7P4
08mmM@<0SGUa102;MV`408YfK@@0QgI]1024MFh4089dKP<0P7E_101oMG0407efL@@0O7Ic101kMg@4
07YhMP<0NGUh101hNWT407QkN`@0Mgem5P3oool001@0oooo101iPh@407f7R@@0P8b?0`24TI<408NE
V@@0RYZM102=Wj<4096TZ0@0U:R]0`2G[K<409Zb^0@0WKNm102P_<<40:C1b0@0YlK>102Zbm<30:c?
f0@0/=CN102Qb=@409_1c@@0WL;<102O`l`30:73bP@0Y<G;102Wald40:_9c@@0[<S:102^a/L30:^n
_`@0Z;Nh102S/K840:Nb/`@0ZK6b102[/[840:fc/`<0[Jf/102/ZjX40:fYY`@0[ZVW102[Xj440:FL
V@<0WYFB102JShX409J9Q0@0ThEo102BPW`40960N0@0Sgee0`2=NG4408]fK0@0RWI]1027MVd408Ae
KP@0PWA^0`20MFl407meL0@0OGIa101lMW<407]gM0@0NWQf0`1iNGP407QjN@@0N7]k101gOGdF0?oo
o`00503oool407Z3Q0@0OHR:1021SHl308FBU@@0R9NJ102<W:0408nQY@@0TjJ[102FZk0309V`]P@0
W;Fk102P^/440:>oa`@0YlG=102[bm<40:o@f@<0/=CM102_eMl409c3d0@0W<;>102O`ld40:74c0<0
Y<C;102Wa/`40:[9cP@0[/S<102]aLL40:g1`P<0Y;Jh102V][P40:Rg^0@0Z[Jg102/]kT40:jh^@@0
/;Rh0`2`];840;2b/@@0[Zf/102/ZJP40:RRW`@0YIfJ0`2PUi<409^@R`@0UhV4102EQX0409B4O@@0
U89j102BOgH3091kLP@0SWQ^102<Mfl408UfK@@0QGA/1022Lfd3081dKP@0OgA_101nMG0407afLP@0
NgMd101jN7D307UiM`@0N7Yi101hNg/407MlOAH0oooo000D0?ooo`@0NX>4101mR8X4086=S`<0QI:E
1028UiX408bLX0@0Sj6U102CYZ/409J[/0<0VK2f102L]K/40:2j`@@0Xko7102WaLd40:_;d`@0[m3I
0`2`e=d40:oEg`@0W<?@102L`/h409o3c@@0XLC<0`2Ta</40:O6c0@0Z/W>102^b<`40:g5a`@0[L72
0`2T][P40:Jf^0@0Z;Nh102Z][L40:bg^@@0[[Ri102`^;P30;2d/P@0/;:a102^[J`40:bYZ0@0Z::O
102UWIX30:2GT`@0Vi2;102GRH@409F6P0@0U8Am102DPWX4099oMP<0T7]b102>N6h408agK`@0RGI]
1025M6`4089cK@<0P7A^101oM6l407ieL0@0O7Ib101kMg@407YhM@<0NGUg101hNWT407QkN`@0Mgam
5P3oool001@0oooo101jPh@407f8RP@0PHf?0`25TYD408RGVP@0S9bP102?XJD409>VZ`@0UZ^`0`2I
/;H409be^`@0X;[1102S_lL40:O5c@@0Zl_C102_d=T30;3Dg@@0[mGO102L`m0409c2cP@0Wl?=102Q
a<`30:C4b`@0YlK<102ZbLh40:k8c0@0[LG7102]`L830:Bf^0@0Y[Jh102X]kP40:Zf]`@0[;Ni102^
^;T40;2h^0<0/;Bb102`/[440:j][0@0[:VX102XXYl40:FMVP<0X9NC102KT8/409N9Q0@0UHJ0102D
Q7d409B2NP@0TWmf0`2@Ng8408ihKP@0S7M_1029MVd408EdK0@0PW=]0`20M6h407mdK`@0OWE`101l
MW8407]gM0@0NWQe0`1iNGL407QjN@@0N7]k101gO7dF0?ooo`00503oool407Z3Q0@0OHR:1021SHl3
08FBU@@0R9NJ102<W:0408nQY@@0TjJ[102FZk0309V`]P@0W;Fk102P^/440:>oa`@0YlG=102[bm<4
0:o@f@<0/=CM102_eMl409c3d0@0W<;>102O`ld40:74c0<0Y<C;102Wa/`40:[9cP@0[/S<102]aLL4
0:g1`P<0Y;Jh102V][P40:Rg^0@0Z[Jg102/]kT40:jh^@@0/;Rh0`2`];840;2b/@@0[Zf/102/ZJP4
0:RRW`@0YIfJ0`2PUi<409^@R`@0UhV4102EQX0409B4O@@0U89j102BOgH3091kLP@0SWQ^102<Mfl4
08UfK@@0QGA/1022Lfd3081dKP@0OgA_101nMG0407afLP@0NgMd101jN7D307UiM`@0N7Yi101hNg/4
07MlOAH0oooo000D0?ooo`@0NX>5101nRHX408:>T0<0QY>F102:VI`408fNXP@0TJ>X102EZJd409R^
/`<0W;>i102O^;l40::na@@0Y/?;102ZbM440:o@f@@0]]SR0`2efN<40:O>fP@0V<3=102M`/d40:74
c@@0Y<G=0`2VaL`40:W6c0@0[<S=102/a<P40:Vm`0@0Y[Ji0`2S/[@40:Rd]P@0ZkNh102]^;T40;2l
_0@0/[bl102c_;/30;>h]`@0/kJe102a[jd40:n]ZP@0ZjJR102WX9`30:6IU0@0Vhn:102HRH@409N6
P0@0UhIo102GQ7`409F0N0<0Tgac102ANFl408efK0@0RGAZ1024LFX4089bJ`<0P79/101oLfh407id
K`@0O7Ea101kMW<407YgM@<0NGUg101hNWT407QkN`@0Mgam5P3oool001@0oooo101jPhD407j9RP@0
PXj@0`26TiH408ZIW0@0SIjR102AXjP409FY[@@0V:jc0`2L/kT409nh_`@0X[k5102V`l/40:[9d@@0
[m3I102ff>830;GIh`@0YlkJ102H`<d409g2c@@0XLC=102TaLd30:K5c0@0ZLK<102/b<d40:c4b0@0
ZKg0102V][T30:>b]0@0Z;Bf102[]kP40:fh^@@0/;bl102b_;`40;>l^`<0/kRg102c][D40;6_[@@0
[jfZ102[YZ840:NPW0<0XIVD102KShX409R9Q0@0UhJ0102GQWl409N4O0@0UH1h0`2CO7<4095iK`@0
SGI/1029M6X408AaJP@0PW9[0`20LV`407mcKP@0OWA_101lMG4407]fL`@0NWMe0`1iNGL407QjN@@0
N7]k101gO7dF0?ooo`00503oool407Z3Q@@0OXV:1022SY0308JCUP@0RYVL102=WZ84096SZ0@0UJV]
102H[[<309bc^@@0WkRo102R_/D40:K3b`@0Z/WA102_d=T40;KHhP<0]MWS102Wc]X409S0c@@0WL;=
102Qa<d40:C5c@<0Y/G<102Ya/`40:c8c@@0[<C8102Y_L040:Jf^@<0Xk:d102X];H40:^g^0@0[KRi
102`_;`40;:l_0@0/kbk0`2c^;L40;>f]@@0/Jn]102_[JX40:^VXP@0Yj2L0`2QVI@409^?RP@0V8V4
102GQX0409N6O`@0UhAl102EP7P309=lL`@0TGU_102=MV`408UdJP@0Q75Z1022LV/3081bK0@0Og=^
101nM6l407aeL@@0NgIc101jMgD307UiM`@0N7Yi101hNg/407MlOAH0oooo000D0?ooo`@0NX>5101o
RH/408>?T@<0QiFH102;VYh408nPY0@0TjJZ102GZk0409Za]P<0W[Jl102Q^l840:G1b0@0Z<K>102/
c=D40;7Cg0@0]m[T0`2/dM`409_3c`@0Vl7=102Pa<d40:?5c@@0Y/G<0`2YaL/40:_7c0@0[/O<102^
a<L40:^m_`@0Z[Vk0`2Z]kT40:bf^0@0[KNh102_^;T40;6i^P@0];Vj102d^;P30;Fe]@@0];6`102c
[Zd40;2]ZP@0[JNS102YXId30:>IU@@0Vhj:102IR8@409V7P@@0VHN0102IQG`409R2N@<0UGie102D
O74409AkL0@0RW=Z1024KfP4089`J@<0P75Z101oLV`407ecKP@0O7A`101kMG8407YgM0<0NGQf101h
NGP407QkNP@0Mgal5P3oool001@0oooo101jPhD407n9R`@0PhnA0`27UIP408^JWP@0Sj2T102CYZX4
09N[/0@0V[6f0`2N][`40:6k`P@0YL78102Xa/h40:c<e@@0/M?L102gf^@30:cAg0@0Vl??102K`Ld4
0:34c@@0XlG=102VaL`30:W5b`@0ZlO<102^al`40:k4a`@0Zkfo102Z^K/30:Zg^@@0[;Jh102]]kP4
0:nh^@@0/KVj102d^KX40;Bh^0<0]KFe102d/K040;>^[@@0/:fZ102]Yj<40:VQW@<0XiVE102KSXX4
09V8Q0@0VHN1102IQh0409V5O0@0V89i0`2EOWD409AlL@@0U7]`102:LfX408A_J0@0PW1Y0`20LFX4
07mbK0@0OG=^101lM70407]eLP@0NWMd0`1iN7H407QiN0@0N7]j101gO7`F0?ooo`00503oool407Z3
Q@@0OhV;1023Si4308NEV0@0RiZN102?X:@409>VZP@0Uj^`102J/KH309jf_0@0XK_2102U`LP40:S6
cP@0[<cE102adm`40;OJi0<0[=7L102K`ll409_1c@@0X<C=102SaLd40:K5c0<0ZLG;102[al`40:k7
c0@0[/C7102[_Kl40:Zi^`<0Z[Ni102/][P40:fg^0@0[kRi102a^KX40;Bi^P@0];Rh0`2e]KD40;Ba
/0@0/jj]102`[JX40:fWX`@0ZJ6M0`2SVID409^>RP@0VHR4102IQh4409V7P0@0VHEl102HPWT309En
M@@0U7aa102DNg0408YcJP@0Q6mX1022L6T3081aJP@0Og9/101mLfh407adL0@0NgEb101jMg@307Uh
MP@0N7Uh101hNgX407MlO1H0oooo000D0?ooo`@0NX>5101oRH/408>?T@<0QiFH102;VYh408nPY0@0
TjJZ102GZk0409Za]P<0W[Jl102Q^l840:G1b0@0Z<K>102/c=D40;7Cg0@0]m[T0`2/dM`409_3c`@0
Vl7=102Pa<d40:?5c@@0Y/G<0`2YaL/40:_7c0@0[/O<102^a<L40:^m_`@0Z[Vk0`2Z]kT40:bf^0@0
[KNh102_^;T40;6i^P@0];Vj102d^;P30;Fe]@@0];6`102c[Zd40;2]ZP@0[JNS102YXId30:>IU@@0
Vhj:102IR8@409V7P@@0VHN0102IQG`409R2N@<0UGie102DO74409AkL0@0RW=Z1024KfP4089`J@<0
P75Z101oLV`407ecKP@0O7A`101kMG8407YgM0<0NGQf101hNGP407QkNP@0Mgal5P3oool001@0oooo
101kQ8D407n:S0@0Q92B0`28UYT408fLX0@0TJ:V102EZ:`409V^/`@0WK>i0`2P^Kl40:BoaP@0YlC<
102ZbM840:g>e`@0[m?L102[dMd309k6d`@0VL3=102P`lh40:?5cP@0Y/G<102YaL`30:_5b`@0[LK;
102`a//40:o4a`@0[Kg0102^_;h30:jk_0@0/;Zk102a^[/40;>k_0@0]Kfm102g_;d40;Rj^P<0^;Rg
102g];<40;Ja[P@0/jbY102_Y:840:VMVP<0XiB@102LS8L409V7PP@0VXN1102LQh0409b6O@@0VX=i
0`2HOgD409MmLP@0UW]_1026KV@408=]I@@0PFiV0`1oKfP407i`JP@0OG9/101lLfl407]eL@@0NWIc
0`1iN7D407QiN0@0N7]j101gO7`F0?ooo`00503oool407^4Q@@0OhZ<1024T98308RFV@@0SIbP102A
XZH409FX[0@0VJjc102M/kT30:2i_`@0Y;o6102Wa<`40:[9dP@0[LkG102_dm`40:_Ag@<0W/KC102I
`<d40:33cP@0XlG>102VaL`40:W5c0<0ZlG;102]a//40;36b`@0[lC7102]_L040:jl_P<0[[^l102`
^[/40;6j^`@0/k^l102e_Kd40;Nl_@@0^;Zj0`2h^;L40;Nd/`@0][6^102c[:T40:nTXP@0ZIfJ0`2S
U90409b<Q`@0VHN2102JQh4409b7P0@0W8Im102JPgT309QoM@@0Ugeb102FNfl408I^I0@0PfeU1021
KVH307m_J0@0OW1Z101mLV`407acK`@0NgEa101jMW<307UhM@@0N7Uh101hNgX407MlO1H0oooo000D
0?ooo`@0NhB5101oRX`408B@TP<0R9JI102=W:04096RYP@0UJR/102I[[<409fc^@<0X;Vo102T_lH4
0:O4c0@0Z/WB102]c]L40:oCg0@0Zm7M0`2Na]<409W0c@@0X<?>102SaLh40:K5c0@0ZLG<0`2[aL/4
0:g6b`@0/<K;102_a<L40:fm`0@0[[bn0`2^^k`40;2j^`@0/KZk102c^k`40;Fm_@@0]kbm102h^[X3
0;Rh]`@0]kBc102f/Jh40;>/Z@@0[jBR102YWIX30:>DT0@0W8b7102IQh8409Z7P@@0W8N0102LQWd4
09Z3N@<0V7me102GOG8409IkK`@0QViT1023KFD4085^IP<0OfmX101nL6X407ebK0@0O7=_101kMG44
07YfL`<0NGQe101hNGP407QkNP@0Mgal5P3oool001@0oooo101kQ8D407n:S0@0Q92B0`28UYT408fL
X0@0TJ:V102EZ:`409V^/`@0WK>i0`2P^Kl40:BoaP@0YlC<102ZbM840:g>e`@0[m?L102[dMd309k6
d`@0VL3=102P`lh40:?5cP@0Y/G<102YaL`30:_5b`@0[LK;102`a//40:o4a`@0[Kg0102^_;h30:jk
_0@0/;Zk102a^[/40;>k_0@0]Kfm102g_;d40;Rj^P<0^;Rg102g];<40;Ja[P@0/jbY102_Y:840:VM
VP<0XiB@102LS8L409V7PP@0VXN1102LQh0409b6O@@0VX=i0`2HOgD409MmLP@0UW]_1026KV@408=]
I@@0PFiV0`1oKfP407i`JP@0OG9/101lLfl407]eL@@0NWIc0`1iN7D407QiN0@0N7]j101gO7`F0?oo
o`00503oool407^4QP@0P8^=1025TI@308ZHVP@0SYjQ102CY:P409NZ[`@0W;2f102O][`30:>l``@0
Yl;9102Zall40:c<e@@0[]7K102^e=l40:_Ag@<0YlcG102Uam840:G6d0@0YlK>102Ya/`40:c6b`<0
[/G;102`a//40;77b`@0/LG8102a`L<40;6n`0<0/[fn102c_Kh40;Fn_P@0]kjn102i_kl40;^o_`@0
_;jm0`2l^kT40;^g]@@0^[>`102e[JT40;6VXP@0[9nK0`2VUi<40:6@R`@0WHZ5102MRH4409j9P0@0
WXQn102LQ7X309Z0MP@0VGib102IO6l408I]HP@0PF]Q1020K6@307m^IP@0OVmY101mLF/407abK@@0
NgA`101jMG8307UgM@@0N7Ug101hNWX407MlO1H0oooo000D0?ooo`@0NhB61020Rhd408FAU0<0RYRJ
102>WZ4409>TZ0@0UjZ_102L/;H409nf_0<0Xkc3102W`/T40:[7c`@0[<cE102^dM/40:kDg`@0Zm7M
0`2Wc=L40:G7dP@0YLK@102Wa/h40:W6c0@0[<K;0`2^aL/40;36b`@0/LO;102aaLP40;71``@0/Kk0
0`2b_Kh40;>m_P@0]Kjn102g_[h40;Vo_`@0^kno102l_[d30;bk^@@0^kNe102j/k040;F]Z@@0/JJR
102/Wi/30:JGT`@0XI2;102MRXD409f9P@@0WXV0102NR7h409b4NP<0VX1f102IOW8409UlK`@0QVeR
1021Jf44081/I0<0OfiV101nKfT407eaJ`@0O79]101kM70407YeLP<0NGMe101hNGL407QjNP@0Mgal
5P3oool001@0oooo101kQ8H4082;S@@0QI6D0`2:V9X408jNX@@0TjBX102GZZl409b`]P@0WkJl0`2S
_<<40:O2b@@0Z/O?102/c=D40:kAf`@0[]CO102[dMd30:O<e`@0YLOB102Ua]040:O6cP@0ZLK<102/
a//30:k5b`@0/<K;102aal/40;75b0@0/L73102a_/030;:m_P@0/kfn102e_[h40;Nn_P@0^Kno102k
_kl40;bn_@<0_;^i102k]kD40;Zc/0@0]JfY102aYZ840:bOV`<0YYNC102QT8/409f:Q@@0WHV1102N
RH0409j8OP@0W8Aj0`2JP7H409UnLP@0VGa_1026KF84085[H@@0P6aT0`1oKVH407i_J@@0OG5[101l
LVd407]dL0@0NWEb0`1iMgD407QiM`@0N7Yj101gO7`F0?ooo`00503oool407^4QP@0P8^=1025TI@3
08ZHVP@0SYjQ102CY:P409NZ[`@0W;2f102O][`30:>l``@0Yl;9102Zall40:c<e@@0[]7K102^e=l4
0:_Ag@<0YlcG102Uam840:G6d0@0YlK>102Ya/`40:c6b`<0[/G;102`a//40;77b`@0/LG8102a`L<4
0;6n`0<0/[fn102c_Kh40;Fn_P@0]kjn102i_kl40;^o_`@0_;jm0`2l^kT40;^g]@@0^[>`102e[JT4
0;6VXP@0[9nK0`2VUi<40:6@R`@0WHZ5102MRH4409j9P0@0WXQn102LQ7X309Z0MP@0VGib102IO6l4
08I]HP@0PF]Q1020K6@307m^IP@0OVmY101mLF/407abK@@0NgA`101jMG8307UgM@@0N7Ug101hNWX4
07MlO1H0oooo000D0?ooo`@0NhF61021Rhd408JBU@<0RiVL102@X:<409FVZP@0VZfa102N/kT40::j
_`<0Y/36102Za/d40:g;d`@0[m3I102ae=l40;7FhP@0/=CO0`2^dM/40:c<e@@0Z/WA102[alh40:g7
c@@0[lO<0`2aal`40;;8c0@0]<S<102da/T40;C3aP@0]<310`2e_l040;O0`0@0^<71102k`L440;c1
`@@0_l;1102o`;h30;nm^`@0_[Ve102k];040;J]Z@@0/ZJQ102]WiX30:RHT`@0Y9:<102QSHH40:2<
P`@0XH^2102PR7l409j4NP<0Vh5f102JOW8409YlK`@0QFaR1021JV4407m[HP<0OVaT101mKVL407a_
J@@0O75/101kLfl407YeL@<0NGMd101hN7L407QjN@@0Mgal5P3oool001@0oooo101kQHH4086;S@@0
QY:E0`2;VI`4092PX`@0UJJZ102J[K4409jc^@@0X[Zo0`2V`<H40:[6c@@0[L_C102_d=T40;7Dg`@0
/MKR102`e=l30:kAf`@0[<cE102ZbM440:_7cP@0[LO=102_al`30;77c0@0//S<102db<`40;C6b@@0
]<?6102d`<430;Fo`0@0]l30102h`L440;_1`@@0_<71102o`/440;o0_P<0_kfk102n^KD40;^d/0@0
]ZfY102bYZ440:fOVP<0Z9RC102TTX`40:6=QP@0X8b3102QRh840:28O`@0WXAj0`2KPGH409YnLP@0
VWa_1025K684085ZH@@0Of]R0`1nK6@407e^I`@0O6mY101lLF`407]cK`@0NWEa0`1iMg@407QhM`@0
N7Yi101gO7`F0?ooo`00503oool407^5QP@0PH^=1026TYD308^IW0@0T:2S102EYZX409Z]/@@0W[>i
102R^[l30:K0aP@0Z/K=102]bm<40:o@f@@0/MCO102ae^840;3Dg`<0[]7K102/c=D40:[9d@@0ZlO>
102]ald40:o7c0<0/LO<102bb<`40;C8c0@0]<K9102d`lH40;C0`@<0]Ko0102g`<040;S1`@@0^l71
102l`L440;o2`@@0_l2n0`2o_K/40;ji]@@0^kB`102f[JT40;:VX@@0[InJ0`2XV9<40:BBS0@0XHf6
102PS8<40:6;PP@0X8Qo102NQ7X309^1MP@0VWib102JO6l408E/HP@0PFYQ101oJf8307i/I0@0OFiW
101lKfT407aaK0@0Ng=_101jMG4307UgM0@0N7Qg101hNWT407MlO1H0oooo000D0?ooo`@0NhF61021
Rhd408JBU@<0RiVL102@X:<409FVZP@0VZfa102N/kT40::j_`<0Y/36102Za/d40:g;d`@0[m3I102a
e=l40;7FhP@0/=CO0`2^dM/40:c<e@@0Z/WA102[alh40:g7c@@0[lO<0`2aal`40;;8c0@0]<S<102d
a/T40;C3aP@0]<310`2e_l040;O0`0@0^<71102k`L440;c1`@@0_l;1102o`;h30;nm^`@0_[Ve102k
];040;J]Z@@0/ZJQ102]WiX30:RHT`@0Y9:<102QSHH40:2<P`@0XH^2102PR7l409j4NP<0Vh5f102J
OW8409YlK`@0QFaR1021JV4407m[HP<0OVaT101mKVL407a_J@@0O75/101kLfl407YeL@<0NGMd101h
N7L407QjN@@0Mgal5P3oool001@0oooo101lQHH4086<SP@0Qi>F0`2=Vid409:RY@@0UjV]102L/;@4
0:6f_0@0Y[g30`2Z`lX40:g9d@@0/<oG102ce=h80;CIi0@0]MSQ0`2bdm`40:o=e@@0[L_B102_bLl4
0;38cP@0//S>0`2dbLd40;G9c@@0]lW=102gal/40;S6b0@0^<?40`2h`<440;[1`@@0_<;2102n`/44
0;o3`@@0`/C21032`[l30<:n^`@0_kVe102m]K040;R^Z@@0]:NQ102^WiT30:ZITP@0YY><102TShL4
0:B>Q@@0Y8b2102RRGl409n5NP<0W85f102IOG8409UlK`@0QfiT1020J5l407iYH0<0OFYR101mK6D4
07a^J0@0Ng1[101kLVh407YdL0<0NGIc101hN7H407QjN@@0Mgal5P3oool001@0oooo101lQHH4086<
SP@0Qi>F0`2=Vid409:RY@@0UjV]102L/;@40:6f_0@0Y[g30`2Z`lX40:g9d@@0/<oG102ce=h80;CI
i0@0]MSQ0`2bdm`40:o=e@@0[L_B102_bLl40;38cP@0//S>0`2dbLd40;G9c@@0]lW=102gal/40;S6
b0@0^<?40`2h`<440;[1`@@0_<;2102n`/440;o3`@@0`/C21032`[l30<:n^`@0_kVe102m]K040;R^
Z@@0]:NQ102^WiT30:ZITP@0YY><102TShL40:B>Q@@0Y8b2102RRGl409n5NP<0W85f102IOG8409Ul
K`@0QfiT1020J5l407iYH0<0OFYR101mK6D407a^J0@0Ng1[101kLVh407YdL0<0NGIc101hN7H407Qj
N@@0Mgal5P3oool001@0oooo101lQHH4086<SP@0Qi>F0`2=Vid409:RY@@0UjV]102L/;@40:6f_0@0
Y[g30`2Z`lX40:g9d@@0/<oG102ce=h80;CIi0@0]MSQ0`2bdm`40:o=e@@0[L_B102_bLl40;38cP@0
//S>0`2dbLd40;G9c@@0]lW=102gal/40;S6b0@0^<?40`2h`<440;[1`@@0_<;2102n`/440;o3`@@0
`/C21032`[l30<:n^`@0_kVe102m]K040;R^Z@@0]:NQ102^WiT30:ZITP@0YY><102TShL40:B>Q@@0
Y8b2102RRGl409n5NP<0W85f102IOG8409UlK`@0QfiT1020J5l407iYH0<0OFYR101mK6D407a^J0@0
Ng1[101kLVh407YdL0<0NGIc101hN7H407QjN@@0Mgal5P3oool001@0oooo101lQHH4086<SP@0Qi>F
0`2=Vid409:RY@@0UjV]102L/;@40:6f_0@0Y[g30`2Z`lX40:g9d@@0/<oG102ce=h80;CIi0@0]MSQ
0`2bdm`40:o=e@@0[L_B102_bLl40;38cP@0//S>0`2dbLd40;G9c@@0]lW=102gal/40;S6b0@0^<?4
0`2h`<440;[1`@@0_<;2102n`/440;o3`@@0`/C21032`[l30<:n^`@0_kVe102m]K040;R^Z@@0]:NQ
102^WiT30:ZITP@0YY><102TShL40:B>Q@@0Y8b2102RRGl409n5NP<0W85f102IOG8409UlK`@0QfiT
1020J5l407iYH0<0OFYR101mK6D407a^J0@0Ng1[101kLVh407YdL0<0NGIc101hN7H407QjN@@0Mgal
5P3oool001@0oooo101lQHL408:=S`@0R9FG0`2>W9l409BTY`@0VZ^_102O/[L40:Bj_`@0ZL760`2^
alh40;7>e@@0]MCL102gfN<40;WNj0@0^]gV102ifn@30;GBfP@0/LgD102abm840;;9d0@0]<[?102f
b/l30;O;c`@0^L_?102jblh40;_:c0@0_<S:102kaLH30;_2`P@0_L?3102oa<@40<75``@0`lK41035
a/@40<K5`P<0aL2m1033^kH40;ne/0@0^jjY102fYj440;6PV@<0[9ZB102ZUHd40:VBRP@0Z927102V
SH<40:B:P0@0XHIk0`2LPGH409QlL0@0TWM/1025KF<407mWG@@0O6EL0`1lJ5l407a[H`@0O6eV101k
KfT407]aK@@0NW=`0`1iMG<407QhMP@0MgYi101gO7`F0?ooo`00503oool407b5Q`@0PXf?1028UIL3
08jLW`@0U:BW102JZjl409nb]`@0Y;Zo102Y`LH30:k7cP@0/LkE102ee=`40;OIh`@0^MkX102jgNH4
0;WKi0<0]M;J102acM@40;7;dP@0//W@102db/l40;K:c`<0]l_?102ibll40;[;cP@0^l[<102lb<X4
0;_5aP<0^l;2102m`l<40;o4a0@0`LG31033a/@40<G6a0@0a/G20`35`;d40<>k]P@0_kF`102k[ZT4
0;JWX@@0/J2I0`2/VY840:ZES@@0ZI::102XT8L40:J=P`@0Y8Z0102QQW/309b1MP@0V7a`102BMf`4
08E]H`@0OfMM101lIE`307aXG`@0O6]S101lKFH407]_J@@0Ng5]101jLg0307UeL`@0N7Qf101gNWT4
07MlO1H0oooo000D0?ooo`@0O8F71022SHl408REU`<0SYbO102DY:L409Z[[`@0Wk:g102T^[l40:W1
aP<0[/O>102ac]D40;GDg0@0]mWS102ig^P40;[MiP@0^M_T0`2ed]X40;7=e0@0/L_B102bbM040;C:
c`@0]/[?0`2gbll40;W;c`@0^/_>102kb/`40;c8bP@0^lG60`2k`/840;g3``@0_lC41031aL<40<?6
a0@0aLK41036aL830<G0_@@0`k^f102o]K040;^^Z@@0]ZNQ102aX9T30:bJTP@0ZYF=102YTXX40:R@
Q`@0YXf3102TRX040:66N`<0W85f102HO704099gK0@0QFeS101oIed407aUG0<0O6QO101lJf<407a]
IP@0NfmY101kLFd407YcL0<0NGEc101hN7H407MjN@@0Mgal5P3oool001@0oooo101mQXL408>>T0@0
RYJH0`2@WZ4409JVZ@@0WJja102R]KX40:Rm`P@0[LC:0`2bc=840;KBfP@0^]WQ102mh>T40;oTk@@0
_n;Z102lf^830;O@f0@0]LgD102ebm840;K;d@@0]lc@102icM430;_>dP@0_<kA102mc]040;o<c`@0
_l[;102na/H30;k4``@0`<G41032alD40<C7a@@0a/W61039bLH40<[7``<0b<:m1036_KP40<:f/@@0
_[2Z102hZ:440;>PV@<0/9^C102^V9040:fFS@@0[9B:102YTHH40:J<P@@0XXMl0`2MPWH409MlL0@0
TGI[1026K60407]PE@@0MUiE0`1kIUd407aYH@@0O6aU101kKVP407]aK0@0NW=_0`1iMG8407QgM@@0
MgUh101gO7/F0?ooo`00503oool407f6Q`@0Phj@102:UYP3092NX@@0UZJY102M[[440::e^P@0Z;g2
102]a<X30;;<dP@0]];J102jfN440;gPj@@0_nC]102oh^X40;cJhP<0]m3H102ecM@40;G;dP@0]/_A
102gc=040;W=d@<0^lkB102lc]440;g>d0@0_lc?102ob//40;k6aP<0_/C31030aL@40<;7a@@0a<O5
1036bLH40<W9aP@0b/O30`38`[d40<Jm^0@0`[Ja102n/:X40;RXX@@0/j2I0`2`Vi<40:jHT0@0[IJ=
102/U8X40:VAQP@0YXb1102RQg`309f2MP@0Uga`102AMV/408I/H0@0Nf1E101fGUD307]VG@@0O6UQ
101lK6D407]^J0@0Ng5/101jLfl307UeLP@0N7Me101gNGP407MlNaH0oooo000D0?ooo`@0OHJ71023
SY0408ZFV0<0T9jQ102FYZT409f^/@@0X[Fj102X_L840:g4bP<0//cB102fd]X40;[Ih@@0_N3Y102o
i>d40;oRjP@0_=[R0`2gd=P40;G=e0@0]L_B102fbm440;O<d0@0^LgA0`2kc]840;c>d@@0_Lk@102o
c<l40;o:b`@0_/K60`2na<<40<35a0@0`/O51034alD40<K9aP@0bLW6103:al<30<S2_@@0a[fh1032
][440;j`ZP@0^:RQ102cX9T30;2KT`@0[YR@102]UXd40:bDRP@0ZI66102VS8440::7O0<0WH9f102G
O704095fJ`@0QVaP101kH5D407INE@<0NfIM101lJF4407a/I@@0NfiX101kLF`407YcK`<0NGEb101h
MgD407MiN0@0Mgak5P3oool001@0oooo101mQXL408>>T0@0RYJH0`2@WZ4409JVZ@@0WJja102R]KX4
0:Rm`P@0[LC:0`2bc=840;KBfP@0^]WQ102mh>T40;oTk@@0_n;Z102lf^830;O@f0@0]LgD102ebm84
0;K;d@@0]lc@102icM430;_>dP@0_<kA102mc]040;o<c`@0_l[;102na/H30;k4``@0`<G41032alD4
0<C7a@@0a/W61039bLH40<[7``<0b<:m1036_KP40<:f/@@0_[2Z102hZ:440;>PV@<0/9^C102^V904
0:fFS@@0[9B:102YTHH40:J<P@@0XXMl0`2MPWH409MlL0@0TGI[1026K60407]PE@@0MUiE0`1kIUd4
07aYH@@0O6aU101kKVP407]aK0@0NW=_0`1iMG8407QgM@@0MgUh101gO7/F0?ooo`00503oool407f6
R0@0Q8nA102;UiT309:PXP@0VJR[102P/;@40:Ji_@@0[<75102bb<h30;O@eP@0_=SN1030g^H40<?U
k@@0a>K^1033h>P40;kFgP<0^<oF102fcM<40;S=dP@0^LgB102kc]840;g?d`<0_]3C1030dM<40<7@
dP@0`/o@1031c<d40<79b0<0`LO51033alD40<G8a@@0a/S51039b/L40<c:aP@0cLS30`3;`kh40<Vn
^0@0a;Na1030/:P40;VXX0@0]Z:J0`2dWYH40;:LTP@0/YZ?102`Uh`40:bCQ`@0ZHj2102TRGd309n3
M`@0VGa`102CN6/408Y^HP@0PFAH101nI5T307eVG@@0OFUP101lJf@407]^I`@0Ng1[101jLVh307Ud
L@@0N7Me101gNGP407MkNaH0oooo000D0?ooo`@0OHJ81024Si4408^GV@<0TZ2R102IZ:/40:2`]0@0
Y[Vm102/`LD40;;8cP<0]m3F102lf=h40<3NiP@0`nG]1034i^h40<?Pj0@0_]KN0`2hcmH40;K=d`@0
^<gB102icM840;_>dP@0_LoC0`2nd=<40<3Ad`@0`M3B1032cm040<7<c@@0`LW80`31alD40<?7a@@0
aLS51036b<D40<W:a`@0c<[6103=b<<30<_3_P@0bKjh1034]k440<2`Z0@0^JRP102fXYX30;BNUP@0
/YbB102bVXl40;2GS0@0[9>7102YSX840:B9O@<0Wh=g102IO70409=hJ`@0RViR1021I5P407iTF@<0
OFIM101mJF0407a[I0@0NfiW101kL6/407YbKP<0NGAa101hMgD407MiN0@0Mg]k5P3oool001@0oooo
101mQXP408B?T@@0RiNI0`2BX:8409VXZ`@0X;2d102V^Kd40:c1a@@0//S>0`2gd=H40;cHgP@0`=kV
1033iNd40<CVkP@0`n3X102ne]h30;S?eP@0]/gC102hcM840;W=dP@0^lkB102mcm<30;k@d`@0`=7C
1031d=840<;?d0@0`Lc=1031bLP30<77a@@0`lO51035b<D40<K8a@@0bL[7103<b/H40<g8``<0bl>n
1039_[P40<Bg/@@0`;2X102iZ:040;JRVP<0]9jF102bW9840;:JS`@0/9N<102/ThL40:V>PP@0Y8Um
0`2OPgL409UlL0@0TgQ[102:KV84085TF0@0OVAI0`1mIUd407eYH0@0O6]T101kKVL407]`J`@0NW9^
0`1iM74407QgM@@0MgUh101gNg/F0?ooo`00503oool407f6R0@0Q8nA102;UiT309:PXP@0VJR[102P
/;@40:Ji_@@0[<75102bb<h30;O@eP@0_=SN1030g^H40<?Uk@@0a>K^1033h>P40;kFgP<0^<oF102f
cM<40;S=dP@0^LgB102kc]840;g?d`<0_]3C1030dM<40<7@dP@0`/o@1031c<d40<79b0<0`LO51033
alD40<G8a@@0a/S51039b/L40<c:aP@0cLS30`3;`kh40<Vn^0@0a;Na1030/:P40;VXX0@0]Z:J0`2d
WYH40;:LTP@0/YZ?102`Uh`40:bCQ`@0ZHj2102TRGd309n3M`@0VGa`102CN6/408Y^HP@0PFAH101n
I5T307eVG@@0OFUP101lJf@407]^I`@0Ng1[101jLVh307UdL@@0N7Me101gNGP407MkNaH0oooo000D
0?ooo`@0OXN81025T94408fIV`<0U::T102LZZd40:>c]`@0Z[c0102`a<T40;O=dP<0_=GK1032gN@4
0<OUk@@0b^Wa103;inl40<OOi`@0`=CL0`2jc]D40;W>d`@0^/kC102lcm<40;k@e0@0`=;E0`32dmH4
0<CCe@@0aM?D1035dM840<G?cP@0aL_:0`34bLL40<G9aP@0alW61039b/H40<c<a`@0clc7103?bL@3
0<k4_P@0b[jg1036]k040<6`Z0@0_JZR102kYYd30;VRV0@0]j2E102fWI840;BISP@0/9F9102/T8@4
0:R:OP<0XXAh102LOW4409EiK@@0SG1S1026J5`4089WF`<0OfMM101nJ5l407e[H`@0NfeV101kKfX4
07YaK@<0NGA`101hMW@407MiN0@0Mg]k5P3oool001@0oooo101nQhP408F@T@@0SIVK0`2DXZ@409bZ
[@@0Xk>g102Z_<040;34b@@0]lgB0`2leM/40<;Mi0@0anG]103:jO440<_Wk`@0amoW1030e=`30;[>
e@@0^LkC102jc]<40;c?d`@0_]3D1030d]D30<;CeP@0a=?E1035dm@40<GAdP@0aLo>1035blX30<C9
a`@0aLW61037bLH40<W:aP@0c<c7103?c<L40<o9a0<0c/Bn103:_[L40<Jg/0@0`K2X102mZZ840;^V
W@<0^J:H102gX9D40;JMTP@0]9V>102`UHT40:b@Q0@0Z8Yn0`2RQ7P409anL@@0UGU]102=L6<408IX
G0@0PVMK0`1oIed407iXG`@0OF]S101kKFH407]_JP@0NW5]0`1iM70407QfM0@0MgUh101gNg/F0?oo
o`00503oool407j7R0@0QI2A102=VI/309BRY0@0W:Z]102S/kL40:Zl`0@0/<C9102gcM830;cEf`@0
`]gT1037iNd40<[Yl@@0bnO_1037gnL40<3Dg0<0^/kE102ic]<40;[>d`@0_<oC102nd=@40<3Be@<0
`]?F1034dmD40<GCe0@0aM7B1035clh40<G;bP<0a<W71035bLH40<O9aP@0bL[6103<c<L40<o<a`@0
clW40`3>a;h40<Zn]`@0a[N`1031/:P40;fZXP@0^jJM0`2iXYP40;NPU@@0]YfB102dVHh40;2ER@@0
[924102XRWh30::4N0@0W7ia102ENFd408e`H`@0QVQL1022Ie/307mWG@@0OVQO101mJf<407]]IP@0
NfmZ101jLFd307UdL0@0N7Id101gNGP407MkNaH0oooo000D0?ooo`@0OXN81025T94408fIV`<0U::T
102LZZd40:>c]`@0Z[c0102`a<T40;O=dP<0_=GK1032gN@40<OUk@@0b^Wa103;inl40<OOi`@0`=CL
0`2jc]D40;W>d`@0^/kC102lcm<40;k@e0@0`=;E0`32dmH40<CCe@@0aM?D1035dM840<G?cP@0aL_:
0`34bLL40<G9aP@0alW61039b/H40<c<a`@0clc7103?bL@30<k4_P@0b[jg1036]k040<6`Z0@0_JZR
102kYYd30;VRV0@0]j2E102fWI840;BISP@0/9F9102/T8@40:R:OP<0XXAh102LOW4409EiK@@0SG1S
1026J5`4089WF`<0OfMM101nJ5l407e[H`@0NfeV101kKfX407YaK@<0NGA`101hMW@407MiN0@0Mg]k
5P3oool001@0oooo101nQhP408JATP@0SYZL0`2FXjH409j][`@0Y[Ji102^_l<40;G8c0@0_=7F0`32
f]l40<WSj@@0cncc103DkoD40=C[l@@0c>3V1031e=X30;_>e0@0^lkC102lcm<40;k@e0@0`M;F1034
e=H30<KEe`@0b=KF1039eMD40<WCd`@0b<o?1037c</30<O:b0@0alW61039b/H40<c;a`@0clc8103A
c<L40=;9a0<0d<Fn103=_kP40<Vh/@@0aK>Z1032[Z@40<2YW`<0_ZJK102lXiP40;ZOU0@0]i^?102c
UhX40;2AQ0@0Zhao0`2UQWT409n0L`@0VGa`102ALVH408Y/G`@0PfIJ0`20IU`407iXGP@0OFYR101l
K6D407Y^J0@0NW5/0`1iLg0407QfL`@0MgQg101gNg/F0?ooo`00503oool407j7R0@0QY6B102>VY`3
09JSYP@0WZf_102V][T40:jo``@0]LS<102ldMH30<;Jg`@0bN?Y103?k?<40=C_m@@0e>_a103<h>H4
0<7DfP<0^lkD102kc]<40;c?d`@0_]3D1031d]H40<CDeP<0a]GG1038e]H40<WEe@@0bM?C1038cll4
0<O<b`<0al[81037bLH40<W:aP@0c<_7103?c<P40=7<a`@0d/W40`3@aKh40<fo^0@0bKRa1035/jX4
0<:^Y0@0`:VO0`2nYY/40;bSV0@0^YnD102gVhl40;>GRP@0/964102[S7l30:F6N@@0Wh1c102IO704
095bIP@0RVaO1023IUX3081VG0@0OVQN101mJV8407a/I@@0NViX101jLF`307UcL0@0N7Ic101gN7L4
07MkNaH0oooo000D0?ooo`@0OXN81026TI8408jJW0<0UZ>V102N[Jl40:Jf^@@0[[o3102eb<`40;cA
eP<0`][O1039hnT40<o/l`@0e>oe103Djo440<cPiP@0`MCJ0`2kc]@40;_>d`@0_<oC102nd=@40<7B
eP@0a=CF0`36eML40<SFeP@0bMGE1039dm<40<S?c`@0alc;0`37b/P40<O9aP@0bL[6103<blL40<o<
b0@0dLc7103BbL@30=35_P@0cKnh1039^;440<FcZP@0`ZjT1030ZIl30;jVV`@0_:>H102jWi@40;NK
S`@0/iN:102`TH@40:^<O`<0YHIi102OP7<409UlL0@0TG9V102:K5l408=VFP<0P6IL101nJ5h407eZ
HP@0O6aU101jKVP407YaK0<0NG=`101hMW<407MhM`@0Mg]k5P3oool001@0oooo101nQhP408JATP@0
SYZL0`2FXjH409j][`@0Y[Ji102^_l<40;G8c0@0_=7F0`32f]l40<WSj@@0cncc103DkoD40=C[l@@0
c>3V1031e=X30;_>e0@0^lkC102lcm<40;k@e0@0`M;F1034e=H30<KEe`@0b=KF1039eMD40<WCd`@0
b<o?1037c</30<O:b0@0alW61039b/H40<c;a`@0clc8103Ac<L40=;9a0<0d<Fn103=_kP40<Vh/@@0
aK>Z1032[Z@40<2YW`<0_ZJK102lXiP40;ZOU0@0]i^?102cUhX40;2AQ0@0Zhao0`2UQWT409n0L`@0
VGa`102ALVH408Y/G`@0PfIJ0`20IU`407iXGP@0OFYR101lK6D407Y^J0@0NW5/0`1iLg0407QfL`@0
MgQg101gNg/F0?ooo`00503oool407n8R@@0Qi:C102@Vid309VUY`@0XJnb102Z^K`40;;3aP@0^/c@
1031e]X30<WOi0@0cnS]103GlOL40=gbm`@0f>[^103=gn<40;oAe`<0_<gC102lc]840;k?d`@0`=7D
1034dmH40<OEe`<0b]OG103<emL40<gGeP@0c=GD103;dM040<W>c0<0b<_81039b/H40<_:aP@0cL_7
103AcLP40=C>b0@0eL_40`3Ca[l40=31^@@0cKZb103:]J`40<NaY`@0aZfR0`33ZYh40<6VVP@0_Z:F
102kWY440;NIS0@0/iB6102^SX030:R8NP@0Xh=e102NOW4409EdI`@0S6eP1024HeH3085UF@@0OfMM
101mJF0407a[I0@0NVeW101iL6/307QcK`@0N7Ec101gN7L407IkNaH0oooo000D0?ooo`@0OhR91027
TY<4092KW@<0VJFW102Q[k840:Zi_0@0//?6102jc=040<7FfP<0bMoT103?j>d40=Oam`@0gO;g103H
j^h40<gOh`@0_m7G0`2lcM<40;c>dP@0_/oC1030dM@40<CCeP@0amGG0`3:emL40<cGe`@0cMOF103<
eM@40<_Ad0@0bLk<0`38blP40<W:aP@0bl[6103=blL40=7=b0@0e<k8103Ebl@30=?6_`@0d<6i103=
^[840<Ze[0@0ak6W1036[J830<>ZWP@0`JJJ102nXYH40;^NT@@0]iV<102cU8H40:j>P0<0Z8Qj102S
PgD409inL@@0UGAW102<KF0408ASEP<0PFEI101oIed407eYH0@0O6]T101jKFL407U`J`<0N7=_101h
MG<407MhM`@0MW]k5P3oool001@0oooo101oR8T408NBT`@0T9^M0`2IYJL40:6_/P@0Z[Vl102b`lH4
0;[<d0@0`MKJ0`39gn@40<oXk@@0eo7g103Ml_L40=SZkP@0cMoS102odML30;c=d`@0_<kB102ncm<4
0<3Ae0@0a=?F1037eML30<[Ge`@0c=OG103=emH40<cEe0@0bm7@1039c/`30<S;b0@0bL[6103;b/H4
0<g;a`@0dLg8103Dc/P40=G;a0<0dlJo103@`KT40<fj/P@0b[F/1037/JL40<J]XP<0`jZN1031YYX4
0;jRUP@0^ijA102gVH`40;>DQP@0[Xj00`2XR7X40:>3M@@0WWia102EM6L408a]H0@0Q6=F0`21IET4
07mWG@@0OFUP101lJf@407Y]I`@0NG1[0`1hLfl407QeL`@0MgQg101fNg/F0?ooo`00503oool407n8
R@@0Qi:C102@Vid309VUY`@0XJnb102Z^K`40;;3aP@0^/c@1031e]X30<WOi0@0cnS]103GlOL40=gb
m`@0f>[^103=gn<40;oAe`<0_<gC102lc]840;k?d`@0`=7D1034dmH40<OEe`<0b]OG103<emL40<gG
eP@0c=GD103;dM040<W>c0<0b<_81039b/H40<_:aP@0cL_7103AcLP40=C>b0@0eL_40`3Ca[l40=31
^@@0cKZb103:]J`40<NaY`@0aZfR0`33ZYh40<6VVP@0_Z:F102kWY440;NIS0@0/iB6102^SX030:R8
NP@0Xh=e102NOW4409EdI`@0S6eP1024HeH3085UF@@0OfMM101mJF0407a[I0@0NVeW101iL6/307Qc
K`@0N7Ec101gN7L407IkNaH0oooo000D0?ooo`@0OhR91029TY@409:MWP<0VjNY102U/[@40:jl_`@0
]lO91030dM@40<SKgP<0cnCX103FkO440=cdn0@0go7d103Gj>/40<_Lh0@0^lgC0`2jbm440;c=d@@0
_/kB1031d=<40<KDeP@0bmOH0`3@f]X40=;KfP@0dm[H103@emD40<gAd0@0b/k<0`39blP40<W8a0@0
blS4103>b/D40=;=a`@0e/g8103GblD30=K7`0@0e<:i103A_K<40<nh[P@0c[FZ103;/:D30<R/X0@0
aZRL1032XiL40;jOTP@0^YZ<102fUHL40;6@PP<0[8Yl102WQGL40::1L`@0V7QY102=K5h408AQE0<0
PF=G101oIE/407eWG`@0NfYR101jK6H407U_JP<0N79^101gMG8407MhMP@0MW]k5P3oool001@0oooo
101oR8T408VBU0@0TYfN0`2KYjT40:Fb]0@0[[bo102galT40<3Ae0@0b=_N0`3?i>P40=K]l@@0g?Ch
103OlO@40=OXj`@0bmcP102kcM<30;[;d@@0_<gA102nc]840<7@d`@0a]CF103;emP30=3JfP@0d]_J
103Cf]P40=3Ge@@0cM7@103:c/`30<W;b0@0bLS4103;b<@40<k:a@@0d/g7103FcLP40=O;a@<0e/O0
103D`[T40=6m/`@0ckR^103>]JX40<^`Y@<0b:bP1036Z9`40<:SU`@0_YnB102jVX`40;JEQ`@0/I22
0`2/RW`40:N5M`@0XX5c102HN6T408e/GP@0Q65D0`21HeL407mUF`@0OFMO101kJV8407Y/IP@0NFmZ
0`1hLVh407MeLP@0MgQf101fNg/F0?ooo`00503oool407n8R@@0RI:D102BWIh309^WZ@@0YK:d102^
_;l40;O7b@@0`=7D1038fmh30<oTj0@0e^ga103Lm?P40=oam0@0enS[103;g>040;_=d`<0^/_A102l
cM440;k>dP@0`M3C1036e=H40<_Gf0<0d=[J103BfmX40=?Jf0@0d=OE103=dM040<[>c0<0bL_81039
b<@40<_8a0@0c/[5103BcLL40=K=b0@0el_50`3Fal040=C2^@@0dKfc103?^:h40<jeZP@0bk2U0`38
[:040<JXW0@0`Z>G102nWi840;ZJS0@0]YF7102aT8830:b:O0@0YhEg102RPG<409QhJ@@0SFaN1024
HE@3085SE`@0OfEK101mIel407]ZHP@0NVaV101iKfX307QbKP@0MgEb101gN7H407IkNaH0oooo000D
0?ooo`@0P8V:102:TiD409BNX0<0WZV[102X];H40;:o`@@0_<_=1036e]P40<oPh`<0e^[]103Ml_H4
0>;fn@@0ioGg103Mj>/40<[Ig@@0]lW?0`2hbLh40;[:c`@0_Lc?1031cm440<KBe0@0bmGF0`3@f=L4
0=CIe`@0e=WF103@eM<40<c?c@@0b/g:0`39bLH40<O5`@@0b/K1103>b<<40=?<aP@0elg7103Ic<D3
0=W8`0@0f<Bj103D_[@40=>j[`@0dKN[103?/jL30<f_XP@0bZ^N1034YIP40<2PTP@0_Ib=102iUhP4
0;FBP`<0[ham102[QgP40:F2L`@0V7IW102;JEX408=OD0<0P65E101nI5T407aVG@@0NfUQ101iJfD4
07Q^J@<0N75]101gM78407MgMP@0MWYj5P3oool001@0oooo1020RHX408ZCU@@0U9jP0`2NZJ/40:Rd
]P@0/[o1102lbld40<KFf0@0cn3S0`3Fj^d40=gbmP@0h_Ki103WmOL40=gXj`@0b]WM102gbLl30;S9
cP@0^/[?102mc<l40<7?d@@0a];D103;eMH30=3He`@0e=WG103DfMH40=3Ed`@0c<o=103:cLX30<W9
aP@0alG1103:a/440<k8``@0dlc6103GcLL40=W<a@<0fLS0103Ha;X40=Bn]0@0dkZ_103A]j/40<nc
Y`<0cJnR103:Zih40<BUV0@0`:2B102mW8d40;VGR0@0]I:30`2_S7d40:^7N0@0YH9c102HMVL408]Y
FP@0Pem@0`20HED407iTF@@0O6IM101kJF4407U[I@@0N6iY0`1hLFd407MdLP@0MgMf101fNWXF0?oo
o`00503oool40829RP@0RY>E102DWZ0309jYZ`@0Z;Bf102b_l440;c;c@@0a]KH103?h><30=KZk@@0
gO;f103Rm_T40>Oem`@0gNS[103:fMd40;O9c`<0^<W>102jb/l40;g<c`@0`LoA1036d]@40<_EeP<0
d=SG103DfML40=CIeP@0d=GC103<cld40<[=bP<0bLW61037aL440<[6`@@0c/S3103Cc<H40=O=a`@0
fLc50`3Ib<040=S4^P@0e;jd103C^Zl40=6gZ`@0ck>W0`3=[j840<Z[WP@0a:FH1030X9840;fLS@@0
^IN8102eTX<30:n<O@@0ZhMh102UPW<409QfI`@0RfUJ1023Ge03081QE@@0OVAI101lIUd407]YH@@0
NF]U101hKVT307QaK@@0MgAb101gMgH407IjNQH0oooo000D0?ooo`@0P8V:102:TiD409BNX0<0WZV[
102X];H40;:o`@@0_<_=1036e]P40<oPh`<0e^[]103Ml_H40>;fn@@0ioGg103Mj>/40<[Ig@@0]lW?
0`2hbLh40;[:c`@0_Lc?1031cm440<KBe0@0bmGF0`3@f=L40=CIe`@0e=WF103@eM<40<c?c@@0b/g:
0`39bLH40<O5`@@0b/K1103>b<<40=?<aP@0elg7103Ic<D30=W8`0@0f<Bj103D_[@40=>j[`@0dKN[
103?/jL30<f_XP@0bZ^N1034YIP40<2PTP@0_Ib=102iUhP40;FBP`<0[ham102[QgP40:F2L`@0V7IW
102;JEX408=OD0<0P65E101nI5T407aVG@@0NfUQ101iJfD407Q^J@<0N75]101gM78407MgMP@0MWYj
5P3oool001@0oooo1020RHX408^DU@@0UInQ0`2PZj`40:^g^0@0]/?41031cm040<cKg@@0enOY0`3O
l?<40>?gnP@0i_Kh103Wl_@40=SSiP@0aMCH102baL/30;G5b`@0^<S<102lb/d40<3<cP@0a<o@1038
d]430<WBd0@0c]?A103=d]040<O=b`@0a<O51032a<830<2o_0@0`[fi1038`[d40<k6`0@0e<_5103H
c/H40=_=a@<0fl[0103Lb;d40=S0]@@0fKjb103I_:l40=NhZ`<0dK:T103=[9h40<JVV0@0`j:C102o
WHh40;bHR@@0]i>30`2bSWh40:n:N@@0ZHAc102JMVH408]WF0@0PUa>0`20Ge<407eRE`@0NfEK101j
Iel407QZI0@0MfeX0`1gL6`407IcL@@0MWMe101fNWXF0?ooo`00503oool40829RP@0RiBE102EWj43
0:2[[0@0ZkNh102f`l@40<7?d0@0c=_M103GinT30=o`l`@0hoOj103Vm_P40>Obm0@0f>?V1035e=P4
0;;5b`<0]LG;102hb<`40;c:c@@0`<c>1034cm040<SBd@<0bM;@103>dm440<gBd0@0alg;1034alD4
0<;4`P<0`;nl1032_KT40<S2_@@0c/K0103DblD40=S>aP@0flg50`3Kb/040=c8_@@0f<2e103I_[84
0=Vl[`@0ekR[0`3A/Z@40<f/WP@0aZJH1033XY<40;nMSP@0_9R9102gTh<30;:>OP@0[hYi102YQ7<4
09YfIP@0RfMH1022G4h3081OD`@0OF9G101kIE/407YWG`@0N6YT101gKFP307M`K0@0MW=a101fMgD4
07IjNQH0oooo000D0?ooo`@0P8V:102;U9D409FOX@<0X:^/102[]kP40;K3a0@0`Lo@103<fmd40=OW
j@<0go3c103SmoX40>Kfn0@0io;d103HhnH40<GDf0@0//G;0`2eaL/40;S8c0@0_<[=1030c<h40<C?
d0@0b=;A0`39d]040<kCd@@0cM;@1037cL/40<C7a@@0`/C20`30_k`40<:m^@@0b<:m103>a/040=C;
a@@0f<k6103KcLD30=_:`0@0g<Rm103H`;D40=Vn/P@0fKb_103G^:/30=6bY0@0cJbN1036YYP40<>R
T`@0_if>102lV8T40;NCP`<0/Xin102_RWT40:V4L`@0VWIV102;IeP4089LCP<0P5mC101mHUL407]U
F`@0NVMO101hJV@407M]J0<0Mg1/101fLg4407IgM@@0MWYj5P3oool001@0oooo1020RHX408^DU@@0
UInQ0`2PZj`40:^g^0@0]/?41031cm040<cKg@@0enOY0`3Ol?<40>?gnP@0i_Kh103Wl_@40=SSiP@0
aMCH102baL/30;G5b`@0^<S<102lb/d40<3<cP@0a<o@1038d]430<WBd0@0c]?A103=d]040<O=b`@0
a<O51032a<830<2o_0@0`[fi1038`[d40<k6`0@0e<_5103Hc/H40=_=a@<0fl[0103Lb;d40=S0]@@0
fKjb103I_:l40=NhZ`<0dK:T103=[9h40<JVV0@0`j:C102oWHh40;bHR@@0]i>30`2bSWh40:n:N@@0
ZHAc102JMVH408]WF0@0PUa>0`20Ge<407eRE`@0NfEK101jIel407QZI0@0MfeX0`1gL6`407IcL@@0
MWMe101fNWXF0?ooo`00503oool40869RP@0S9FF102GXJ830::/[P@0[[Vj102jaLL40<KCe0@0e>7R
103Qko030>kmoP@0jo_m103Zm_H40>O_l0@0en7S1032dMD40:o1a`<0//?8102faLT40;[8bP@0_/[;
1032c<`40<G=c@<0a/k<1038c/`40<;8a`@0_L?3102k_kh40;Zl^`<0_K^h1032_;P40<S0^`@0c/K0
103DblD40=W=aP@0flc30`3Kb;l40=_5^@@0f;fa103M_k440>2o/0@0ekRY0`3B/J840=2^W`@0b:NH
1034XY<40;nMSP@0_IR8102iU8<30;J@O`@0]8ak102]QG<409]eI@@0RVIG1021G4h307mNDP@0O65F
101jHeX407QVGP@0MfUR101fK6L307I_J`@0MW=`101fMWD407IjNQH0oooo000D0?ooo`@0PHV:102<
UIH409NQXP<0XZb^102^^KX40;[5a`@0a]?D103DhN840>7_l0<0k_gn103[nod40>[fmP@0ino`103G
hN<40<;Ae@@0[l770`2b`lP40;K5b@@0^/S:102nb//40<;<c0@0aLg=0`36c/`40<S>c0@0`/S7102m
`l<40;^o_P@0^[bk0`2m^kP40<:l^0@0b<2k103>a/040=C;a@@0fLg6103Kc<<30=_8_`@0flFi103H
_K440=fo/@@0h;n`103G^:T30=:aXP@0d:jO1038YiP40<BRT`@0_if>102mV8P40;VDP`<0]Y1o102d
S7/40:f5L`@0VgEU102:IUL4085LCP<0OeiB101lHEH407YSFP@0N6IN101gJF8407I/I`<0MVm[101f
Lg0407IfM@@0MWYj5P3oool001@0oooo1021RHX408bEUP@0Uj6R0`2R[:h40:ji^P@0^/G71036dm@4
0=CQhP@0hNo`0`3^oOh40>_ko@@0j_Kf103Wko040=OQh`@0`]7E102_`LL30;;3b0@0]/G9102jb<X4
0;k:b`@0`/c<1035cLd30<K>c0@0b<k<1032b<L40;g3``@0^knn102j_;/30;fk^0@0`[bh1038`;/4
0<k6`0@0e<_5103IcLH40=_<``<0flRo103KaKT40=Rm/@@0gKna103P_k040=NhZ@<0d[6R103@[Yl4
0<RWV0@0a::C102oWHh40;fHR0@0^IB30`2fT7l40;B<N`@0[HEc102KMFD408YVE`@0PEa>0`1oGU84
07aQEP@0NV=J101hIUh407MYHP@0MVaW0`1fKf/407IcL0@0MWIe101fNWXF0?ooo`00503oool40869
RP@0S9FF102GXJ830::/[P@0[[Vj102jaLL40<KCe0@0e>7R103Qko030>kmoP@0jo_m103Zm_H40>O_
l0@0en7S1032dMD40:o1a`<0//?8102faLT40;[8bP@0_/[;1032c<`40<G=c@<0a/k<1038c/`40<;8
a`@0_L?3102k_kh40;Zl^`<0_K^h1032_;P40<S0^`@0c/K0103DblD40=W=aP@0flc30`3Kb;l40=_5
^@@0f;fa103M_k440>2o/0@0ekRY0`3B/J840=2^W`@0b:NH1034XY<40;nMSP@0_IR8102iU8<30;J@
O`@0]8ak102]QG<409]eI@@0RVIG1021G4h307mNDP@0O65F101jHeX407QVGP@0MfUR101fK6L307I_
J`@0MW=`101fMWD407IjNQH0oooo000D0?ooo`@0PHV:102=UIH409RQXP<0Y:f^102`^[/40;g8b@@0
bmKG103Ji^H40>kin@<0m?oo103]n?T40>gdm0@0j>k]103Eg^040;k=dP@0Z[g30`2__l@40;?2a@@0
^LO8102mb<T40<39b0@0`l[90`35b/T40<G:a`@0`lO5102o`/440;bn^`@0^kZh0`2n^[H40<>l]`@0
b<2j103?aKl40=G;``@0fLc4103Lbl830=_7_@@0fL>g103G_K440=Nl[`@0f;Z/103>/J@30<b]W`@0
bJVK1031XY@40;jNS`@0_9V9102mUhH40;bDP`<0^Y5o102jSg`40:j5L`@0VWEU1028IUL4081LC@<0
OEe@101jGe@407QQF0@0MVAL101eIf4407EZI@<0MFiZ101eLVl407EfM0@0MGYi5P3oool001@0oooo
1021RHX408fEUP@0V:6R0`2T[Jh40;2j^`@0_LS9103;e]L40=[ViP@0k_Wi0`3dool40>ghn@@0kOCd
103Xk^d40=GNh0@0_/gB102Z_L<30:noa0@0/l;5102ialP40;g8b@@0`<W81033b/T30<G:b@@0aL[7
1033alD40;o2`@@0_;jk102k^[P30;jj]P@0`kbg1038`;X40<o5_`@0eL_3103Ic<@40=c;`P<0flNm
103I`kL40=Nm/@@0ekb_103H^Z`40<jaY0<0c:fO1039ZI/40<6RU0@0_Yj?102lVHT40;fGQP@0_9B3
0`2jTGl40;Z?O0@0[XEc102JMFD408QVE`@0P5a=0`1mGE0407YOE0@0N65H101fI5`407EWH@@0MFYU
0`1eKVX407EbK`@0MGId101eNWTF0?ooo`00503oool40869RP@0SIFF102HXJ830:B][P@0/;Zk102m
b<T40<_Fe`@0f^KV103^nOT30?Coo`@0kOSi103]m?@40>S^k@@0eMkP102ncM840:Zm``<0[ko4102c
`/D40;W7b0@0_LS91030bLP40<?:b@<0aL[91035b/L40<?7a@@0_l;1102l_[/40;^j^0<0_[Zf1033
_;L40<S0^P@0clFo103Ebl<40=W<a0@0g<_20`3Kakd40=W3]`@0ekfa103G_:l40=Rj[0@0c[6T0`3<
[Il40<VYV`@0`J:D102nWXl40;bIR@@0_IN6102lU8<30;ZAO`@0^Xml102^QG<409YeI@@0R6IG1020
G4d307eMD0@0NUmD101hHEP407ITG0@0MFMQ101eJVD307E^JP@0MG9_101eMW@407EjNAH0oooo000D
0?ooo`@0PHV:102=UIH409RQXP<0Y:f^102`^[/40;g8b@@0bmKG103Ji^H40>kin@<0m?oo103]n?T4
0>gdm0@0j>k]103Eg^040;k=dP@0Z[g30`2__l@40;?2a@@0^LO8102mb<T40<39b0@0`l[90`35b/T4
0<G:a`@0`lO5102o`/440;bn^`@0^kZh0`2n^[H40<>l]`@0b<2j103?aKl40=G;``@0fLc4103Lbl83
0=_7_@@0fL>g103G_K440=Nl[`@0f;Z/103>/J@30<b]W`@0bJVK1031XY@40;jNS`@0_9V9102mUhH4
0;bDP`<0^Y5o102jSg`40:j5L`@0VWEU1028IUL4081LC@<0OEe@101jGe@407QQF0@0MVAL101eIf44
07EZI@<0MFiZ101eLVl407EfM0@0MGYi5P3oool001@0oooo1022RHX408fEUP@0VJ:S0`2V[jl40;:l
_0@0`<W:103>f=P40=kXj0@0l?[j0`3^moL40>[bl`@0iN_[103OiND40<_GfP@0^<S=102W^/030:bl
`@@0/;k2102e`L<40;W2``@0_/K51032b<L30<G:a`@0alW61036al@40<;2_`@0`;nl102o_;T30<2j
]@@0a;bf1039`;T40<o6_`@0eL[2103Jbl840=c;`@<0g<Rl103K`kL40=Rn/@@0e[Z]103A]JL40<N/
W`<0a:RK1031Y9H40;bNT0@0_9^<102nVHT40;nHQP@0_iF30`2oTh040;jAO@@0[H=a102GLf<408IT
EP@0OUU:0`1kFdh407QLDP@0MUmF101dHUX407=UG`@0LfUT0`1cKFT407AaKP@0M7Ed101eNGTF0?oo
o`00503oool408:9RP@0SIFF102IXZ<30:J_[`@0/[bl1030bLX40<kHf0@0g^SX103`n_X30>kgm`@0
j_;c103Ujn/40=oUi@@0bmOJ102hb<d40:Nj`0<0[;c1102`_/840;G1``@0^L;3102na/D40<;8a`<0
aL[71037bLH40<K7a0@0`/:o1030_k`40;nl^@<0`;Ze1034_;H40<W0^@@0clJo103Eb/840=[;`P@0
g<_10`3Lb;`40=_3]`@0f;ja103F^Zd40=6eY`@0ajbO0`34Z9/40<6TUP@0_9j@102lVh`40;jIR@@0
_iR6102oUH<30;nCP0@0_Y5m102]Pg4409McH`@0QVAF101nFDX307]KCP@0N5aB101fGeH407ARFP@0
LfEO101cJF@307=]J@@0M75^101dMG@407EiNAH0oooo000D0?ooo`@0PXV:102=UIH409VRX`<0YZn_
102b_;`40<39bP@0c]SH103Nj>P40?3jnP<0k_Og103Zl_<40>G[j`@0gnGU103;emX40;S8c@@0Yk[0
0`2/_<440;2n`P@0]L73102i`/<40;k6a@@0`/S70`35b/L40<O9aP@0a/O41032`[l40<2o_0@0_kbi
0`30^[D40<Bl]P@0bL2i103?a[l40=G:`P@0f/_2103Lbl430=c8_0@0fl>g103H_[440=Jj[@@0dKFW
1037[9l30<BXV`@0`JBF102lWY040;bKS0@0_YV9102oV8H40;nEP`<0_i>0102nTGd40:f3L@@0Ug=S
1026I5H407iIBP<0Ne]>101hG58407IOEP@0M69J101cIEl407=YI0<0LfeY101dLFh407AeM0@0MGUi
5P3oool001@0oooo1022RHX408fEUP@0VJ:S0`2V[jl40;:l_0@0`<W:103>f=P40=kXj0@0l?[j0`3^
moL40>[bl`@0iN_[103OiND40<_GfP@0^<S=102W^/030:bl`@@0/;k2102e`L<40;W2``@0_/K51032
b<L30<G:a`@0alW61036al@40<;2_`@0`;nl102o_;T30<2j]@@0a;bf1039`;T40<o6_`@0eL[2103J
bl840=c;`@<0g<Rl103K`kL40=Rn/@@0e[Z]103A]JL40<N/W`<0a:RK1031Y9H40;bNT0@0_9^<102n
VHT40;nHQP@0_iF30`2oTh040;jAO@@0[H=a102GLf<408ITEP@0OUU:0`1kFdh407QLDP@0MUmF101d
HUX407=UG`@0LfUT0`1cKFT407AaKP@0M7Ed101eNGTF0?ooo`00503oool408::R`@0SYJG102JXZ<3
0:N_/0@0];bm1031b/X40=3Hf0@0gnSX103`n?P30>gdm0@0j>k^103Pi^L40=GMg`@0a=3D102d`lP4
0:Fg_@<0ZKVm102^^kd40;:l_P@0][jo102i_kh40;c0_P<0_l6n102m_k`40;bm^`@0^[Zg102j^;D4
0;^g/`<0_KJb1034^kD40<[1^P@0d<Jn103FbL440=[:`0@0g<^o0`3NbKd40=k5^0@0f[na103H^jd4
0=>fZ0@0cJnQ0`38ZI/40<BTU@@0`In@1032WXd40<:LR@@0`iZ71033V8@30<BFPP@0`99m102/PFl4
099_G`@0QFAE101lEdT307QHC0@0M5Y?101bG5<4075OF0@0LF=M101aIf83075[I`@0LW1]101cM7<4
07EiNAH0oooo000D0?ooo`@0PXZ;102>UYL409ZRX`<0Yjn`102d_;d40<7:bP@0d=SH103Oj>P40?3h
n0<0kOCd103Xk^h40>3Vi`@0eMgO1034d=@40;C3b0@0YKNm0`2Y^Kd40:jk_@@0/[bn102f_[l40;Vo
_P@0_<2n0`2o`Kh40;fo_0@0_;fk102j^[L40;Zh]@@0^kNc0`2m][840<Bk]@@0b/6j103@a[h40=K9
`@@0f/[0103Lbkl30=k9_@@0g/Fh103J_k440=Rk[@@0dkJX103=[j430<RYV`@0a:BE1031Wi040<:N
S@@0`Yb91033VXL40<>HQ0<0a9J21030TWd40:b1K`@0TVmO1025I5D407aGB@<0N5Q<101dFTl4079L
D`@0LEmH101aHed4075WHP<0LF]W101bL6d407=dL`@0MGUi5P3oool001@0oooo1022RX/408jFU`@0
VZ:S0`2W[k040;Bl_@@0`L[:103@f=P40=oXj0@0l?Sh0`3]m?@40>S^kP@0h>KW103EgMl40<C@e0@0
]<?8102U]kd30:Vi_@@0[[^m102b_;h40;Jn_`@0^Knn102l`;h30;o1_P@0_Knl102l_K/40;Zj]`@0
^[Re102k]k<30;ff/P@0a;^e103:`KX40=36_P@0e/W1103Jb/040=c;_`<0g/Vm103NaKP40=Zo/@@0
f;^]103C]ZP40<f_X@<0b:VK1034Y9D40<6OT0@0`Yj=1032W8T40<>JQ`@0`iR40`34UX840<2BO@@0
[85_102BKel408ETE@@0O5M90`1hF4`407AJC`@0LUaC101aGeP4075SG@@0LFMR0`1aJfL4079`K@@0
LgAc101eNGTF0?ooo`00503oool408::R`@0SYJG102JXZ<30:N_/0@0];bm1031b/X40=3Hf0@0gnSX
103`n?P30>gdm0@0j>k^103Pi^L40=GMg`@0a=3D102d`lP40:Fg_@<0ZKVm102^^kd40;:l_P@0][jo
102i_kh40;c0_P<0_l6n102m_k`40;bm^`@0^[Zg102j^;D40;^g/`<0_KJb1034^kD40<[1^P@0d<Jn
103FbL440=[:`0@0g<^o0`3NbKd40=k5^0@0f[na103H^jd40=>fZ0@0cJnQ0`38ZI/40<BTU@@0`In@
1032WXd40<:LR@@0`iZ71033V8@30<BFPP@0`99m102/PFl4099_G`@0QFAE101lEdT307QHC0@0M5Y?
101bG5<4075OF0@0LF=M101aIf83075[I`@0LW1]101cM7<407EiNAH0oooo000D0?ooo`@0PXZ;102>
UYL409^SX`<0Yjn`102d_;d40<;:bP@0d=SH103OinH40>kfm@<0jo7`103SjNT40=[QhP@0cmWJ1030
c<l40;30a0@0Y;Jl0`2W][X40:^g^P@0/;Vj102d^kX40;Nk^P@0^K^i0`2i^KL40;Rh]@@0^KNd102i
][840;Ze/@@0_;Jb0`31^K@40<Nn]`@0cL>l103Bakl40=O8`0@0fLVo103Kb;`30=c5^@@0g<:d103L
_k040=bm[P@0e[RX103A/Z830<j]W@@0bjRH1038Y9<40<NQS`@0aYj;1036VhP40<JJQ@<0bIV3102o
T7/40:QoK0@0TVmO1029IUL4081KC0<0M5E9101`ED/406iHD0@0KEaE101]H5X406iUH0<0KfUV101a
KV`4079cLP@0M7Uh5P3oool001@0oooo1022RX/408jFU`@0Vj>S0`2W[k040;Bl_@@0`/[:103@f=P4
0=oWiP@0k_Ke0`3[lO040>?Yj@@0f^7R103?fMX40<3<c`@0/<34102T][`30:Nf^P@0ZkNj102`^KX4
0;Bk^P@0]k^j102i^kT30;Vi]`@0^;Re102i]k@40;Vf/P@0^[Fa102l][830<6i]0@0akjg103=`k`4
0=;7_`@0elS0103IbKl40=_8_0<0g<Fi103L`[@40=bo/0@0g;f^103F^:P40=6bXP<0cZfM103;Z9P4
0<RTT`@0aj6?1036WX/40<JKR0@0aYZ50`39VH<40;n@N`@0Z7m/102BKel408UVE`@0P5]<0`1dEDT4
071EB`@0KUQ@101]G5D406ePFP@0KVEP0`1_JFH4075^K0@0LW=b101dNGPF0?ooo`00503oool408::
R`@0SYJG102KXj<30:N_/0@0];bm1032b/X40=3Hf0@0gnOV103^m_D30>_al0@0hnWY103JhN840<oI
fP@0`<c?102``<@40:Bf_0<0YkJj102[]kX40;2i^P@0];^j102g^kX40;Vk^@<0^KVg102h^;D40;Vg
]0@0^KJb102j]K440;bf/P<0`KVd1037_[L40<g3_0@0d/No103Gb<040=W9_`@0flRl0`3LaKT40=c2
]0@0g;n`103L_Jh40=JhZ0@0dK:R0`3>[Id40<^XV0@0b:BC1037XHl40<JNR`@0aY^81036VXD30<VI
P`@0_i1k102XOf`4099_G`@0RFIG1020Fd`307AEB@@0L5E;101^F50406eLE@@0KF1J101^IF0306mY
IP@0LFi/101bLg8407AiN1H0oooo000D0?ooo`@0PXZ;102>UYL409^SX`<0Yjn_102d_;`40<;9b@@0
d=OF103NiN@40>gclP<0j>k/103Pi^D40=KNgP@0b]CF102kbL`40:jn`P@0XkFj0`2U/kL40:Ve]`@0
[[Ng102b^;P40;Fi^0@0^;Zg0`2j^KH40;^i]P@0_;Zf102n^[D40<2k]P@0`[bg0`36_kT40<_2^`@0
d<Jn103Db<040=O9`0@0f/Vn103Jak/30=_5]`@0f/6c103G^jd40=JhZP@0e;FV103E/j<30=>`W`@0
dJ^I103=YiD40<^ST0@0b9j:1037W8L40<ZKQP<0c9V3102lSGP40:QmJP@0UW5P1029IED407]GB@<0
JD]0101YD4H406QDC0@0JEQA101ZGEL406]RGP<0KFQT101_KF/4075cL@@0M7Qh5P3oool001@0oooo
1022RX/408jFU`@0Vj>S0`2W[jl40;Bl_0@0`/W9103@emH40=kUi0@0kO?b0`3Xk^`40>3Vi@@0e]kN
103:e=H40;_9c0@0[[k2102S]KX30:Fc]`@0ZKFg102^]kL40;:h^0@0]KVh102h^[L30;Zi]P@0^kVf
102l^[H40;jj]@@0`;^f1032_;L30<Jo^@@0bl:k103@a[h40=C8`0@0elW0103JbKh40=[7^`<0flFg
103J`K<40=Nk[@@0e[RZ103D]JH40=FcX`<0dk2O103AZiT40<fWU@@0bj>@1038WXX40<NLQ`@0bY^6
0`3<VH<40;b=N0@0Z7eZ102FLF0408UUE@@0NeM90`1YBd0406U@AP@0J5A<101YF54406YME`@0Jf9N
0`1]J6@406m]J`@0LG=a101dN7PF0?ooo`00503oool408::R`@0SYJG102KXj<30:N_[`@0];bl1032
bLT40=3GeP@0g^GT103]lo830>S^k0@0h>KU103Fg]h40<[DeP@0^lW<102^_/840:>e^P<0YK>g102Y
]KL40:jg]`@0/[Rh102e^KP40;Rj]`<0^[Vf102k^KH40;bj]P@0_[Ze1030^kH40<:l]`<0a[ni103;
`[/40=36_P@0e<S0103GbL040=[9_P@0f/Nk0`3KaKL40=[1/`@0ek^]103F^:X40=BeYP@0eK>S0`3C
/9l40=6[V@@0cJNE103;Xi040<RNRP@0aib7103:VhH30<bIP`@0_8eh102XOFX409IaH0@0RFEE101k
EdT306U;@0@0JE16101XE4`406UHD@@0JUeG101[HUh306eXI0@0Kfe[101aLg4407AhN1H0oooo000D
0?ooo`@0PXZ;102>UYL409^SX`<0Yjn_102d_;`40<;9b@@0d=OF103NiN@40>gclP<0j>k/103Pi^D4
0=KNgP@0b]CF102kbL`40:jn`P@0XkFj0`2U/kL40:Ve]`@0[[Ng102b^;P40;Fi^0@0^;Zg0`2j^KH4
0;^i]P@0_;Zf102n^[D40<2k]P@0`[bg0`36_kT40<_2^`@0d<Jn103Db<040=O9`0@0f/Vn103Jak/3
0=_5]`@0f/6c103G^jd40=JhZP@0e;FV103E/j<30=>`W`@0dJ^I103=YiD40<^ST0@0b9j:1037W8L4
0<ZKQP<0c9V3102lSGP40:QmJP@0UW5P1029IED407]GB@<0JD]0101YD4H406QDC0@0JEQA101ZGEL4
06]RGP<0KFQT101_KF/4075cL@@0M7Qh5P3oool001@0oooo1022RX/408jFU`@0Vj:S0`2W[jl40;Bk
^`@0`LS8103?e]D40=gShP@0j_3_0`3Tj^T40=kTh`@0dm_K1037d]<40;[7b@@0[[g1102U]KX30:Fb
]P@0Z;>e102]]KH40;6g]P@0]KRf102h^KL30;^j]`@0_K^h1030_;P40<:m^@@0aKnk1038`K`30<_3
_@@0clJo103Cb<040=O;`@@0fL[0103KbKh40=c8^`<0g<Fh103L`[@40=Zn[`@0ekVZ103C/j@40<n^
W`<0cJ^J103<Z9H40<VTTP@0bJ2=1038WXT40<bMR0@0cI^60`3;V8440;V9M@@0YW]X102DKEd4089N
D0@0LU140`1QAC/4065:@@@0HTm7101SE4h406EJE@@0J61K0`1ZIV8406e/JP@0L79a101cN7PF0?oo
o`00503oool408::R`@0SYJG102KXZ<30:N_[`@0];^k1031b<P40<oFe@@0gN?R103Zl>l30>CZj@@0
g^CS103Cfm/40<OBd`@0^/O9102^_L440:Fe^P<0YK:f102X/kD40:fe]P@0/KNf102e^;H40;Ri]`<0
^kZg102m^kP40<2l^0@0`[fi1035_k/40<S1_0<0bl>m103?a[l40=?8`0@0el_1103Ib/040=_9_P@0
g<Rk0`3LaKP40=c2]0@0f[j_103G^JX40=>cY0@0cjjO0`3=ZiX40<bXUP@0bJBB1039X8d40<RNR@@0
c9f8103=VhH30<^HP@@0^HUe102VNfP409A]G@@0PUi@101bD4@30655>`@0HDY1101RCdL406=DCP@0
IEYE101XH5/306YVHP@0KFaZ101`LW4407=hN1H0oooo000D0?ooo`@0PXZ;102>UYL409^RX`<0Yjn_
102d^k/40<78b0@0cmKE103Mhn840>[`k`<0i>[Y103Ni><40=?Kf`@0am;C102jalT40:jm`@@0YKFj
0`2U/[H40:Rc]@@0[KFf102a]kH40;Fh]P@0^;Vg0`2k^[L40;fk^0@0`;bh1032_KT40<Fo^`@0b<6l
0`3;`kd40<o6_`@0dlS0103Gbl440=W:`0@0flVn103Lb;/30=c5^0@0g<:d103J_Zl40=NiZP@0dk>T
103?[Yl30<f[VP@0c:RF1039Y9840<VPS@@0b9j9103<WHP40<fKQP<0biR1102iRGD40:IkJ0@0U6eM
1022GU04079@A0<0HDDk101QBT44069?A`@0HeA>101UFUD406QPF`<0JVIR101]K6X4071bL@@0LgQh
5P3oool001@0oooo1022RX/408jFU`@0Vj:S0`2W[jl40;Bk^`@0`LS8103?e]D40=gShP@0j_3_0`3T
j^T40=kTh`@0dm_K1037d]<40;[7b@@0[[g1102U]KX30:Fb]P@0Z;>e102]]KH40;6g]P@0]KRf102h
^KL30;^j]`@0_K^h1030_;P40<:m^@@0aKnk1038`K`30<_3_@@0clJo103Cb<040=O;`@@0fL[0103K
bKh40=c8^`<0g<Fh103L`[@40=Zn[`@0ekVZ103C/j@40<n^W`<0cJ^J103<Z9H40<VTTP@0bJ2=1038
WXT40<bMR0@0cI^60`3;V8440;V9M@@0YW]X102DKEd4089ND0@0LU140`1QAC/4065:@@@0HTm7101S
E4h406EJE@@0J61K0`1ZIV8406e/JP@0L79a101cN7PF0?ooo`00503oool408::RP@0SYJF102JXZ83
0:N^[P@0];Zj1031alL40<kDd`@0fn7P103Yknd30>?Yj0@0g>;Q103AfMT40<K@d@@0^/K9102`_L44
0:Rf^P<0YK:e102W/[<40:bd]0@0/KJd102e]kD40;Vi]P<0_K^h1030_KT40<>o^`@0a/6l1039a;h4
0<c5_`<0d<S1103Cb/840=O<``@0f/g3103Lc<440=g;_`@0g/Vl0`3NakT40=k4]@@0g<2a103J^j/4
0=JfY@@0d[2P0`3?[9X40<bWU@@0bjBA103<XXd40<fPR`@0cij9103@W8H30<VEO`@0]HIa102PMV@4
08iXF0@0NUY<101YC44305Y2>0@0FD@l101KBD8405i@BP@0HEIA101TGET306QSH@@0JfYX101_LG04
079gMaH0oooo000D0?ooo`@0PXZ:102>UYH409ZRXP<0Yjj^102d^[X40<77a`@0c]CC103KhN040>W_
k@<0hnWX103Lh^440=7If@@0a]3A102ja/T40;2m`@@0Z;Jj0`2U/[D40:Nb/`@0[;Bd102a][@40;Fg
]@@0^KVf0`2m^kP40<2m^@@0`knk1036`K`40<W4_P@0c<Fo0`3@b<440=?:`P@0elc3103JcL<40=c<
`@@0gL^o103NbK`30=k7^@@0g/Be103L`;440=ZkZ`@0e[JU103B/:030<n/VP@0c:NE103;Y9440<bR
S@@0cJ2;103?WXT40=2LQP<0bIEo102eQW440:1fI0@0SVQH101jFT`406U<@@<0FT8h101IA3`405]9
@P@0GU1:101QEU4406AMF@<0J6=Q101[JVP406maL0@0LWMg5P3oool001@0oooo1022RXX408jFUP@0
VZ:R0`2W[Zh40;Bj^P@0`LO7103>e=<40=_Qh0@0jNo]0`3SjNP40=cRh@@0dMWI1036d=440;[6b@@0
/;g1102X][X30:Fb]@@0Yk:c102/];@40;6f]0@0]KNe102i^KH30;fk^0@0`;fi1033_k/40<K1_0@0
bLBn103<aKl30=38`@@0dl[2103Gc<<40=[=``@0g<c1103Mbkl40=k9_0<0g/Ni103Na;D40=c0/@@0
f[^[103F]ZD40=:`X0<0cjbJ103<YiD40<^TT@@0c::=103=X8/40<nNR@@0d9b60`39UGl40;F6L@@0
X7IT102>J5P407YJC0@0JDa10`1J@SP405U4?0@0FdU2101ND4X4065FD@@0I5eI0`1XHf4406]ZJ0@0
Kg5`101bMgLF0?ooo`00503oool408::RP@0SYJF102JXZ830:N^[P@0];Zj1031alL40<kDd`@0fn7P
103Yknd30>?Yj0@0g>;Q103AfMT40<K@d@@0^/K9102`_L440:Rf^P<0YK:e102W/[<40:bd]0@0/KJd
102e]kD40;Vi]P<0_K^h1030_KT40<>o^`@0a/6l1039a;h40<c5_`<0d<S1103Cb/840=O<``@0f/g3
103Lc<440=g;_`@0g/Vl0`3NakT40=k4]@@0g<2a103J^j/40=JfY@@0d[2P0`3?[9X40<bWU@@0bjBA
103<XXd40<fPR`@0cij9103@W8H30<VEO`@0]HIa102PMV@408iXF0@0NUY<101YC44305Y2>0@0FD@l
101KBD8405i@BP@0HEIA101TGET306QSH@@0JfYX101_LG04079gMaH0oooo000D0?ooo`@0PXV:102>
UIH409ZQX@<0YZf]102c^KT40<36a@@0cM;A103Jgmh40>O/j`<0hNGT103Jgmh40=3Ge`@0alo@102l
a/P40;>n`@@0Z[Nj0`2V/[D40:J`/P@0Zk>b102a]K<40;Jg]@@0^[Zf0`2o_KT40<>o^`@0a/:m103:
aL040<g7`P@0dLW30`3Dc<@40=S=a@@0flo6103Ncl@40=o>`P@0h<g0103Qbkd30>78^P@0hLFf103P
`K840=fm[0@0f[RW103G/j830=F_W@@0dj^H103CZ9@40=>UT0@0dj:=103DX8X40=:LQ@<0aI5k102`
PFd409abH0@0R6=D101dEDP40616?0<0DC`c101>>c@405=3?@@0F4]6101LDdh4065JE`<0IF5O101Y
JFL406i`K`@0LWMg5P3oool001@0oooo1022RHX408jEUP@0VZ6Q0`2V[Jd40;>i^@@0`<K5103=d]44
0=[OgP@0inc[0`3QiN@40=[OgP@0d=OG1037cm040;c6b0@0/kk1102Z]kX30:Jb]@@0Y[2b102[/k84
0;6e/`@0][Ne102j^[H30;nm^@@0`knk1036`[d40<[5`0@0cLO2103AbL<30=C<a0@0f<g5103KclH4
0=k?a0@0glk2103PcL040>7;_@<0hLRj103QaKH40>31/P@0gKf/103J^:L40=NcXP<0eJnM103CZiP4
0=>XU0@0djF@103CXXd40=BPRP@0dYb50`35TG/40;21K@@0W79P1028He@407AEB0@0H4Hl0`1A?3<4
04hk=0@0Dd<m101HBdH405aCCP@0HEYG0`1UHEl406UYI`@0KW1_101bMgLF0?ooo`00503oool408:9
RP@0SYFF102JXJ430:J][@@0/kVi1030a/D40<gBd@@0f]oN103Wk>/30>7Ui0@0f]oN103@emL40<O?
d0@0_<K8102c_/440:Zg^P<0Y[:e102V/;840:^c/P@0/KFc102f]kD40;Zj]P<0_kfi1033_k/40<K2
_@@0b/G0103=al840=79``<0e<c4103HcLD40=_?aP@0g/o4103Oc/840>3=`0@0hL^m0`3Qb;X40>75
]P@0h<6b103M_J`40=ZhY`@0ek>R0`3E[id40=>[V0@0djRD103CYI040=>RS@@0e:2:103BW8D30<FA
N`@0/85]102LLV0408QSE0@0M5E8101PAS`3054l<`@0CS/d101C@cd405Q;AP@0G5=>101QFUL306EQ
G`@0JFUW101^L6l4079gMaH0oooo000D0?ooo`@0PXV:102>UIH409ZQX@<0YZf]102c^KT40<36a@@0
cM;A103Jgmh40>O/j`<0hNGT103Jgmh40=3Ge`@0alo@102la/P40;>n`@@0Z[Nj0`2V/[D40:J`/P@0
Zk>b102a]K<40;Jg]@@0^[Zf0`2o_KT40<>o^`@0a/:m103:aL040<g7`P@0dLW30`3Dc<@40=S=a@@0
flo6103Ncl@40=o>`P@0h<g0103Qbkd30>78^P@0hLFf103P`K840=fm[0@0f[RW103G/j830=F_W@@0
dj^H103CZ9@40=>UT0@0dj:=103DX8X40=:LQ@<0aI5k102`PFd409abH0@0R6=D101dEDP40616?0<0
DC`c101>>c@405=3?@@0F4]6101LDdh4065JE`<0IF5O101YJFL406i`K`@0LWMg5P3oool001@0oooo
1022RHX408fEU@@0VJ2P0`2U[:`40;:h^0@0_/C3103;dLl40=SMg0@0iN[X0`3Nhn440=OLf`@0cmGE
1036c/h40;c5aP@0/kfo102Z][P30:Jb]0@0YJn`102[/[440;6e/`@0]kRe102l^kL30<6n^P@0aL6l
103:a;l40<g8`P@0dL[4103EcLD30=W?a`@0g=78103Od/P40>7BaP@0h]34103Sc/440>C<_P<0i<Zk
103TakL40>?3/P@0h;j]103N^ZP40=bfX`<0f[:N103I[YX40=R[UP@0eZNA103FY8h40=FQRP@0cYV2
0`2lRgD40:QkJ0@0U6aK101oG4h406U=@@@0E3he0`16<b/404<b;0@0Bcdh101BAd8405Q?B`@0GEQE
0`1RH5d406MWIP@0K6m^101aMWHF0?ooo`00503oool408:9RP@0SIFE102IX:030:F/[0@0/[Rh102n
a<<40<_Ac`@0f=gL103Uj^P30=kSh@@0emcK103?eMD40<K>cP@0_<G6102c_Kl40:Zf^0<0Y[:d102U
[k040:^b/@@0/KFc102g^;D40;bk]`<0`Kjj1035`K`40<[4_`@0cLS2103Ab/@40=G=a@<0fLo7103L
dLP40=oBb0@0hM;6103Rd<@40>?>`@@0i<bn0`3Tb[/40>C7]`@0hl>b103P_Zd40=jjZ0@0g;JS0`3J
/Yh40=V^VP@0f:^F103FYi440=JTSP@0eJ6:103>VH830;b;M@@0Z7]X102DK5/407mLCP@0JDe1101D
?SD304Hc:`@0@c8/101;?CP40597@P@0F4m;101MF5D3069PG@@0IfMV101/Kfh4075fMQH0oooo000D
0?ooo`@0PXV:102=UID409VPX0<0YJb/102b^;P40;k4``@0bm7?103HgM`40>GZj0<0g^?Q103Gg=/4
0<oEe@@0a/k>102laLH40;>m_`@0Z[Jh0`2V/[@40:F_/0@0Zk:a102a]K<40;Nh]@@0_;^g0`31_[X4
0<G1_0@0b/Bo103=b<840=7:a0@0eLg50`3IclL40=cAb0@0gm;8103Qd/H40>;@a0@0hlk1103Tc;h3
0>C:^`@0i<Ng103S`k840>2n[@@0g[ZX103L]Z<30=ZbWP@0fJjJ103HZiH40=JWT@@0eZB>103EXHX4
0<jIPP<0_8]e102XNfP409A/F`@0Oea>101YCD4405@n=@<0AS<[1013<R`404/m>0@0DTM2101HCd/4
05eHE@<0HV1M101WIfH406a_KP@0LGIf5P3oool001@0oooo1022RHX408fEU@@0VJ2P0`2U[:`40;:h
^0@0_/C3103;dLl40=SMg0@0iN[X0`3Nhn440=OLf`@0cmGE1036c/h40;c5aP@0/kfo102Z][P30:Jb
]0@0YJn`102[/[440;6e/`@0]kRe102l^kL30<6n^P@0aL6l103:a;l40<g8`P@0dL[4103EcLD30=W?
a`@0g=78103Od/P40>7BaP@0h]34103Sc/440>C<_P<0i<Zk103TakL40>?3/P@0h;j]103N^ZP40=bf
X`<0f[:N103I[YX40=R[UP@0eZNA103FY8h40=FQRP@0cYV20`2lRgD40:QkJ0@0U6aK101oG4h406U=
@@@0E3he0`16<b/404<b;0@0Bcdh101BAd8405Q?B`@0GEQE0`1RH5d406MWIP@0K6m^101aMWHF0?oo
o`00503oool40869RP@0SIBD102IWil30:B[Z`@0/;Nf102m`/440<W?c@@0e]_I103SinD30=gPgP@0
eM[H103>e=<40<K=c@@0_/K6102c_Kl40:^g^0<0Y[:d102U/;440:^a/0@0/[Fc102i^KD40;jl^0<0
a<2k1039a;h40<g7`@@0dL_4103Fc/H40=W@b0<0gM?:103Pe<X40>?Eb@@0iMC8103Vd/D40>K@`P@0
iljo0`3Wbk/40>K8]`@0i/Bc103T`:h40>:lZ@@0h;RU0`3O]:040=faW0@0fjbG103JZI840=ZUSP@0
eIn81038U7d30;F5L0@0X7ER1029I5@407=DA`@0GD@i1018=Bd303HW8@@0>B/V1014>3<404a3?`@0
Dda9101JEE<3061NG0@0IVIU101[KVh4075fMQH0oooo000D0?ooo`@0PHV:102=U9@409VOW`<0Y:^[
102`]kH40;g2`@@0bLo=103FfmT40>?Wi@<0gN3N103Ef]P40<kDd`@0a/g=102na/H40;>m_`@0ZkNh
0`2V/[@40:F`/@@0Zk6`102b]K<40;Vi]@@0_[bh0`34`;/40<W4_P@0cLO1103Abl@40=K>aP@0fM38
0`3MdlX40>3DbP@0hmG9103Ue<P40>KBa@@0i]32103Wc[l30>O;^`@0i/Rg103Va;<40>C0[P@0h[bY
103P^:D30=ndX0@0gK6L103K[9L40=ZYTP@0fZF>103EWhP40<RDO@<0]HE`102PMF8408UTE0@0LeA7
101MA3T404Pe;@<0=RLQ100i:bH404@h<`@0C4<o101CC4T405YED`<0H5iL101VIVD406]^KP@0LGIf
5P3oool001@0oooo1021RHX408fDU0@0VInO0`2TZj/40;2g]P@0_L;11039cld40=KKf@@0hnOU0`3M
h=h40=GJf0@0c]CC1036cLd40;k6aP@0/kfo102[]kP30:Jb]0@0YK2a102[/K040;:e/`@0^KVe102n
_;P30<C0^`@0bLBn103=al440=7;a0@0e/k6103Id<P30=gCbP@0h=C:103SeLT40>GDb0@0i];5103V
d<840>O>_`<0il^k103Vb;L40>K4/`@0i<2^103R_:T40>2hY@<0gkBP103M/I`40=^/U`@0fZVB103J
YHh40=FOR0@0b9Am0`2eQG040:1eHP@0RFAD101cE4L405e4>@@0B3D]0`0f9b4403T[9P@0A3Pc101<
@cl405=<B@@0FUEC0`1PGU`406IVI@@0Jfi^101aMWHF0?ooo`00503oool40869R@@0S9>D102HWYh3
0:>YZ@@0[kFd102k`;l40<O<b`@0e=WG103QiN830=[Ng0@0dmSF103=d]440<O=c0@0_/C4102d_Kd4
0:jg^0<0ZK:d102Y/K440:fa/0@0];Fb102k^[H40<6n^@<0al:l103<a/040=7:``@0e/k7103JdLX4
0=kDb`<0h]K=103Teld40>OHc0@0j=K9103Ye<H40>[B`P@0j/no0`3Zc;/40>W8]`@0j<Fc103W`Zl4
0>FmZP@0i;VU0`3R]J040>2aW0@0gjfG103MZI840=VSS0@0d9^41030SGL30:amJP@0UFaK101nG4h4
06M;@0@0DC/b100m;BH302dP6`@0=RXV100o=C4404Q0?@@0D4Y7101GDe4305iLF`@0I6ET101ZKFd4
071fMQH0oooo000D0?ooo`@0PHV9102<Ti@409RNWP<0XjVY102_]K@40;_0_`@0alc;103DfML40>7U
hP<0f]kL103Cf=H40<gBd@@0alg<102na<@40;Bm_@@0[[Nh0`2Y/[@40:Va/@@0[K6`102d]K840;^j
]P@0`Kji0`37`[`40<c6`0@0dL[3103Fc/L40=[AbP@0g]C;0`3Re/d40>CGc@@0imS<103Xe/T40>WD
aP@0j];2103Zckl30>[<^`@0jLRg103XaK<40>O2[`@0iKfZ103T^JD30>:eX0@0h;6L103O[IL40=fY
TP@0fJ><103@Vh@40<2=M`<0[7eZ102EK5/407iLCP@0Id]0101A>c8403d]9P<0;B0K100f:RH403le
<@@0B40m101@BTL405MCD@<0GUaK101TIF@406Y]K@@0L7If5P3oool001@0oooo1021RHT408bCU0@0
V9jN0`2SZJT40:ne]0@0^l2o1037c</40=CIe`@0hNGR0`3Jg]`40=?HeP@0cM;A1037cL`40;k4a0@0
];fm102^]kP30:Vb]0@0ZK6a102]/K040;Be/P@0^kZf1031_[T30<O2_0@0c<K0103Ab/<40=K>a`@0
f]7:103Ne</30>;Fc@@0i=O=103Wf<`40>SFb@@0jMC6103Zd/840>[?_`<0j/bk103Yb;L40>S5/`@0
il:_103U_JX40>BiY@<0h[FP103P/I`40=n]U`@0gJVB103IXh`40=2KQ0@0`8eg0`2/OFX409E/F`@0
OUa>101WBd04054k<P@0?BdV0`0]81/403HZ9P@0?cDa1018@3d4051:A`@0Ee=A0`1NG5/406AUI0@0
JVe]101`MWHF0?ooo`00503oool40869R@@0S9>D102HWYh30:>YZ@@0[kFd102k`;l40<O<b`@0e=WG
103QiN830=[Ng0@0dmSF103=d]440<O=c0@0_/C4102d_Kd40:jg^0<0ZK:d102Y/K440:fa/0@0];Fb
102k^[H40<6n^@<0al:l103<a/040=7:``@0e/k7103JdLX40=kDb`<0h]K=103Teld40>OHc0@0j=K9
103Ye<H40>[B`P@0j/no0`3Zc;/40>W8]`@0j<Fc103W`Zl40>FmZP@0i;VU0`3R]J040>2aW0@0gjfG
103MZI840=VSS0@0d9^41030SGL30:amJP@0UFaK101nG4h406M;@0@0DC/b100m;BH302dP6`@0=RXV
100o=C4404Q0?@@0D4Y7101GDe4305iLF`@0I6ET101ZKFd4071fMQH0oooo000D0?ooo`@0PHR9102<
Ti<409NMW@<0XZRW102]/k840;Vn_@@0aLW8103AeM<40=kQg`<0em_I103AeM@40<c@cP@0a/_9102n
a<<40;Nn_P@0/KRi0`2]];@40:jd/`@0/KBb102g][<40;fk]`@0a<2k0`3:aKh40=39`P@0eLk6103J
dLX40=oEc0@0hmS>0`3Wf/l40>WJcP@0jm[=103]f<X40>gFa`@0kM?3103]d;l30>c=^`@0k<Vg103Z
a[<40>W2[`@0ikjZ103V^ZD30>BfX0@0i;:L103R[YL40=jYT@@0ej69103;UWl40;R6L@<0XWIS102:
IE@407ADA`@0GD@i1015<bX4030S7P<09Q/G100b:2@403`c<0@0AChk101=B4H405EBD0<0G5]J101S
I6<406U]K@@0L7Ef5P3oool001@0oooo1021R8T408bCT`@0UifM0`2RZ:L40:fc/P@0^Kjm1035bLP4
0=7Ed`@0g^7O0`3GfmT40=7Ee0@0c=3>1036blT40;k4``@0]kjn102a^;T30:fd]0@0[[Bc102a];84
0;Nf/`@0_K^g1034`;/30<[5_P@0d<W2103Ec/H40=[AbP@0gmG<103Sf<h30>OJc`@0jM[>103[f/d4
0>gHbP@0kMK7103]dl<40>g@_`<0k<fk103/bKL40>[6/`@0jL:_103W_ZX40>JjY@<0i;JP103T/Y`4
0>:^U`@0gZVA103GXHT40<^FO`@0^8Ia0`2RMV<408YUE0@0M5A7101MA3T404Dc:P@0<2<N0`0V6aL4
038X90@0?3<`1015?S/404e8AP@0EE9@0`1LFeX406=TH`@0JFe]101`MGHF0?ooo`00503oool40868
R@@0S9>C102GWId30::XY`@0[K>b102i_[d40<G9b0@0dMGC103NhMl30=OKf@@0dMGD103<d<h40<K;
b@@0_/C3102g_[h40;6h^@<0[KBd102^];<40;6d/P@0]kJc102m^kL40<C0^`<0b/Fn103@bL840=G>
aP@0f]7:103OeL`40>?HcP<0im[?103Yf/h40>_Jc@@0kMS:103]e/L40>gC``@0kM2o0`3/cK/40>c9
]`@0j/Jc103Y`Zl40>NnZP@0i[ZU0`3T]Z040>BbW0@0hZjG103NZI440=NQR@@0biIo102hQW430:9f
H`@0RVED101dE4L405e4>@@0AC<Z100`8ah302HK5`@0<RPT100l<c0404Dn>`@0CDQ6101EDU0305aK
FP@0HfAS101YKFd4071eMQH0oooo000D0?ooo`@0PHR9102<Ti<409NMW@<0XZRW102]/k840;Vn_@@0
aLW8103AeM<40=kQg`<0em_I103AeM@40<c@cP@0a/_9102na<<40;Nn_P@0/KRi0`2]];@40:jd/`@0
/KBb102g][<40;fk]`@0a<2k0`3:aKh40=39`P@0eLk6103JdLX40=oEc0@0hmS>0`3Wf/l40>WJcP@0
jm[=103]f<X40>gFa`@0kM?3103]d;l30>c=^`@0k<Vg103Za[<40>W2[`@0ikjZ103V^ZD30>BfX0@0
i;:L103R[YL40=jYT@@0ej69103;UWl40;R6L@<0XWIS102:IE@407ADA`@0GD@i1015<bX4030S7P<0
9Q/G100b:2@403`c<0@0AChk101=B4H405EBD0<0G5]J101SI6<406U]K@@0L7Ef5P3oool001@0oooo
1020R8P408^BTP@0UIbL0`2PYZD40:^`[`@0][^j1031a/@40<gAc`@0f]gK0`3Df=H40=3Bd0@0b/k<
1036b/P40<35``@0^Kjn102e^[T30;:g]@@0/kNe102d][<40;Vh]0@0`;fh1038`[d30<k7`@@0e<c5
103JdLP40=oDc0@0i=S>103Xf/l30>_Ld0@0k]g?103`gLh40?7Jb`@0l=O7103`e<<40>oA_`<0kljl
103^b[L40>c6/`@0jl:^103Z_ZT40>RjY@<0ikJP103V/Y/40>:^UP@0gJN>103BW8@40<6>N0@0[7eY
0`2DK5/407iLC0@0Id/o101?>S0403HX8@@081HB0`0Q5a@402hV8`@0>C8_1012?CX404]7A@@0De5@
0`1JFeT4069TH`@0JFa/101_MGHF0?ooo`00503oool40828R0@0Ri:B102EW9`30:2VY@@0Zk2_102f
^kX40<76a0@0cM7?103JgM/30=CHeP@0d=;@103:c/`40<K:b0@0`<G3102i_[h40;Fj^@<0/[Ne102c
]kD40;Bf/`@0^KRd1030_KP40<S2_@<0c/O1103Dc<D40=[Ab0@0gmC<103Tf<h40>SJc`<0jmc@103^
gLl40?3McP@0lM[;103`elL40?3D``@0km6o0`3_c[`40>k:]`@0k<Jc103[`Zh40>ZnZ@@0j;ZU0`3W
]Z040>JbV`@0hZjF103MYhh40=:LQ0@0`Hih102/OFT309A/F`@0OUa<101WBcl404lj<0@0=RPQ100P
5Q83024G50@0;RHS100i<Rl4048m>P@0BdM5101CDE0305YKF@@0HVAS101YK6`406meMQH0oooo000D
0?ooo`@0P8R8102;TY8409FLW0<0X:JU102[/:l40;Jk^P@0`LK4103=dLl40=[Mf`<0e=SF103@d]04
0<[>c0@0a/[81030aL<40;Vn_P@0]KZi0`2b]kD40;>g]@@0];Jc102i^;@40<2m^0@0b<:m0`3>al44
0=C<a@@0f]78103Oe<`40>CHcP@0j=[?0`3[g=040>kMc`@0l=g>103af//40?3Ga`@0l=C3103_dKl3
0>o>_0@0k/Zg103/a[<40>_2[P@0j[jY103X^ZD30>NfX0@0i[:K103R[YH40=fWSP@0dYb41031SWP4
0:amJ@<0U6aK101nG4`406M;?`@0CcX`100f:244020F4P<08ALD100^9R<403Tb;`@0@Sdj101;AdD4
05=AD0<0FU]I101RI6<406U/K0@0KgEf5P3oool001@0oooo1020R8P408^BTP@0UIbL0`2PYZD40:^`
[`@0][^j1031a/@40<gAc`@0f]gK0`3Df=H40=3Bd0@0b/k<1036b/P40<35``@0^Kjn102e^[T30;:g
]@@0/kNe102d][<40;Vh]0@0`;fh1038`[d30<k7`@@0e<c5103JdLP40=oDc0@0i=S>103Xf/l30>_L
d0@0k]g?103`gLh40?7Jb`@0l=O7103`e<<40>oA_`<0kljl103^b[L40>c6/`@0jl:^103Z_ZT40>Rj
Y@<0ikJP103V/Y/40>:^UP@0gJN>103BW8@40<6>N0@0[7eY0`2DK5/407iLC0@0Id/o101?>S0403HX
8@@081HB0`0Q5a@402hV8`@0>C8_1012?CX404]7A@@0De5@0`1JFeT4069TH`@0JFa/101_MGHF0?oo
o`00503oool40827R0@0RY6A102DVYX309jTX`@0Z:j]102c^;H40;k2`0@0bLg;103Ef=H30=;DdP@0
cM3=1039c<T40<G8aP@0`LC2102l_kd40;Rk^@<0]kVg102g^KH40;Rh]@@0_KZf1034`;X40<c5_P<0
d/[2103IclH40=oCb@@0iMO<103Yf/l40>gMd0<0lMoA103cgm440?CNc`@0m=_;103df<L40??D``@0
l]6o0`3ac[/40?3:]P@0k/Jb103]`Zd40>bnZ@@0j[ZT0`3X]Ih40>F`V@@0h:^C103GXHT40<RDOP@0
]XE`102OM64308MSD`@0LE95101J@SL4044`:0@0:alJ100K4Ph302<K60@0;BHS100g<Bl4040l>P@0
BDM5101ADDl305UJF@@0HF=S101XK6`406meMQH0oooo000D0?ooo`@0P8N8102:TI4409BJVP<0WZBS
102X[Zd40;>h]P@0_/;01039cL/40=GHeP<0d]CB103=d<d40<W<b@@0aLS61031a<840;bo_@@0^;^i
0`2g^KL40;Ni]P@0^;Re102m^[H40<C0^P@0c<Fn0`3Bb/840=W?aP@0gm?9103Uel`40>WJc`@0kMg@
0`3agm440??Od@@0m=k?103dfl/40?CHa`@0lmC3103bdKl30?7>^`@0l<Zf103^a[840>g2[@@0k;jY
103Z^Z@30>ReWP@0iK2I103PZi<40=NQR@@0b9An102fQG0409mdH@<0Qf=C101aDTD405Y2=`@0@C0X
100[7aX401/B3P<08a/H100]9R<403La;`@0@3`j1019AdD4055AC`<0FEYI101QHf<406Q/K0@0KgEf
5P3oool001@0oooo1020QhP408ZAT@@0U9ZJ0`2NY:<40:R^[@@0/kRf102n`/040<W=b`@0eMSF0`3B
e=840<g@c@@0bLc91035b<H40<74`P@0_;nm102h^kT30;Ni]`@0]kVf102h^;D40;fj]P@0a<2j103<
aKh30=;:`P@0fLo6103OdlT40>GGc0@0jM[?103]gM030?7Od@@0lmoA103dg/l40?CKb`@0m=S7103c
e<<40?;A_`<0lLjk103`b[H40>k6/P@0kL:]103/_ZT40>ZjY0<0j;FN103U/9T40>2[T`@0ej691038
U7h40;J5L0@0WgAQ0`27He<4075BA@@0FT8g1011<2P402/O6P@06a8>0`0S6aP402dV8`@0=c4_1010
?3X404U7A@@0DE5?0`1IFUT4065SH`@0J6a/101_MGHF0?ooo`00503oool40827R0@0RY6A102DVYX3
09jTX`@0Z:j]102c^;H40;k2`0@0bLg;103Ef=H30=;DdP@0cM3=1039c<T40<G8aP@0`LC2102l_kd4
0;Rk^@<0]kVg102g^KH40;Rh]@@0_KZf1034`;X40<c5_P<0d/[2103IclH40=oCb@@0iMO<103Yf/l4
0>gMd0<0lMoA103cgm440?CNc`@0m=_;103df<L40??D``@0l]6o0`3ac[/40?3:]P@0k/Jb103]`Zd4
0>bnZ@@0j[ZT0`3X]Ih40>F`V@@0h:^C103GXHT40<RDOP@0]XE`102OM64308MSD`@0LE95101J@SL4
044`:0@0:alJ100K4Ph302<K60@0;BHS100g<Bl4040l>P@0BDM5101ADDl305UJF@@0HF=S101XK6`4
06meMQH0oooo000D0?ooo`@0OhN71029T90409:IV0<0W::Q102VZjX40;2d/`@0^[jl1034b<H40=3C
d0<0cm7>103;cLX40<O:a`@0aLK41031`l040;fo_0@0^K^h0`2h^KH40;Vi]P@0_;Zf1031_;L40<S2
^`@0d<S00`3GcL@40=kBb0@0iMK;103Zf/d40>kMc`@0l]oA0`3fhM840?WQd@@0nMo>103hg<X40?KH
aP@0mMC2103ddKh30??=^P@0lLZe103`aK440>k1[0@0k;fW103Z^J830>NdW0@0hZfF103KYXh40<jI
PP@0_8Ye102WNVL4091ZF0<0NEU:101TBCd404`g;P@0<RDO100O5a<401D=2`<081XH100[9R@403Da
;`@0?c`k1018AdD4055AD0<0FEYI101PHf<406Q/K0@0KgEf5P3oool001@0oooo101oQhL408V@T0@0
TYVH0`2LXZ440:J[ZP@0/;Bc102j_[`40<C8aP@0d=?@0`3?dLh40<_=bP@0al[71035a/@40<73`0@0
_Knl102i^kP30;Ri]P@0^KVf102l^[H40<6l]`@0b<:k103@b<030=O=a0@0g];8103Ue//40>[Jc@@0
k]g?103bgm430?KQdP@0nN7A103iglh40?SLbP@0m]S6103ee<840?CA_P<0llfj103ab[D40?35/@@0
k/6/103/_JL40>ZiXP<0ikBL103R[IH40=^VSP@0cYV2102lRWD40:MjI`@0T6YH0`1iFDX406A9?@@0
C3L^100b9Al401lG4`@05@d;0`0P6QP402/V90@0=C4_100o?3/404Q7A@@0DE5@0`1IFUT4061SH`@0
J6a/101_MGHF0?ooo`00503oool407n7Q`@0RI2@102BVIP309bRX@@0YZ^Z102`];<40;Zn_0@0a<S6
103@dm030<oAcP@0blg:1037b/L40<G6a0@0`L?0102m_k`40;Vk^0<0^;Vf102i^KH40;bj]P@0`Kbg
1038`[/40=38`0<0elg4103Nd/P40>GFb`@0j][=103^gLl40?;Od@<0m^7B103ihM440?WOcP@0n=c:
103ff<H40?GD`P@0m=6n0`3ccKX40?7:]@@0l<Fa103^`J`40>bmY`@0j[VR0`3W]9`40>:]UP@0fjJ>
103>VH840;b:M@@0YgYW102@JUP307UIBP@0I4Tm101<=bh4038U7`@07aLC100E3@/3020J60@0:bHT
100e<Bl403ll>`@0B4M5101ADE0305UJF@@0H6=S101XK6`406meMQH0oooo000D0?ooo`@0OhN71029
T90409:IV0<0W::Q102VZjX40;2d/`@0^[jl1034b<H40=3Cd0<0cm7>103;cLX40<O:a`@0aLK41031
`l040;fo_0@0^K^h0`2h^KH40;Vi]P@0_;Zf1031_;L40<S2^`@0d<S00`3GcL@40=kBb0@0iMK;103Z
f/d40>kMc`@0l]oA0`3fhM840?WQd@@0nMo>103hg<X40?KHaP@0mMC2103ddKh30??=^P@0lLZe103`
aK440>k1[0@0k;fW103Z^J830>NdW0@0hZfF103KYXh40<jIPP@0_8Ye102WNVL4091ZF0<0NEU:101T
BCd404`g;P@0<RDO100O5a<401D=2`<081XH100[9R@403Da;`@0?c`k1018AdD4055AD0<0FEYI101P
Hf<406Q/K0@0KgEf5P3oool001@0oooo101oQXL408R>S`@0TING0`2JWil40:>XY`@0[;6_102e^KP4
0;o2`0@0b<_80`3;cLX40<W:a`@0a/O41032`l440<31_P@0_;fj102i^[H30;Vi]@@0^[Ve102n^kD4
0<>m]`@0c<>k103CbL030=_>a0@0i=C8103Zf</40>oLcP@0m=o@103ghM430?_SdP@0o^?B103mh<h4
0?[LbP@0n=O5103fdl040?G@_@<0m<bh103bb;@40?34[P@0k[nY103[^Z@40>ReWP<0hk2H103KZ904
0=6MQP@0`8mi102/Of`409M_GP@0P5m?0`1ZCT4405<m<`@0>b/U100T6aL4018;2@@04@/90`0O6QP4
02XV9@@0=C8`100o?C/404Q7AP@0D55@0`1HFUX4061SH`@0Ifa]101_MGHF0?ooo`00503oool407n6
Q`@0R8j?102AUiL309ZOW`@0XjRW102//Jl40;Fi^0@0_l;01038blP30<_=bP@0bL[71036al@40<;3
`@@0`<6n102l_KX40;Vj]P<0^KVe102j^KD40;jk]@@0`kfg103<`k/40=?9`0<0flk4103Te<P40>[H
b`@0kmc>103dgm040?OQd@<0nn?B103nhm840?gPcP@0n]c:103helD40?KC`0@0mM2m0`3dc;P40?;8
]0@0l<B^103^_jT40>^jY0@0j;FN0`3S/9P40=^XT0@0dIf61030SgT40:aoK0@0UfmN1020Gdl306Y>
@@@0Dcdc100k:bD402@K5`@04P/9100A2`T301lJ60@0:RHU100e<S0403lm>`@0B4M6101@DE0305QJ
FP@0H6=S101WK6d406meMQH0oooo000D0?ooo`@0OhJ71028SXl4096GU`<0VYnO102SZ:L40:ba[`@0
]KVh102o`/040<S;b0<0blg:1039b/L40<K7a0@0`/?11030`Kh40;bm^P@0^KZf0`2i^KD40;Zi]@@0
_[^e1033_KL40<c3^`@0dlW00`3Kc/@40>CDb0@0j]S;103_g<h40?COd0@0mn7A0`3khm840?kSdP@0
oN3>103jg<X40?SGa@@0m]?0103ed;d30?C<^0@0l/Rd103`a:h40>joZ@@0jkZT103X]Ih30>>`V0@0
fjR@103AWHH40<2?N@@0[7m/102GKeh4081OC`<0JTi1101C?C<403/[9@@091/G100B2`T4014;2@<0
7aXH100Z9RD403Db<0@0?cdk1018AdH4051AD0<0F5YJ101PHf<406M/K@@0KgEf5P3oool001@0oooo
101oQXL408R>S`@0TING0`2JWil40:>XY`@0[;6_102e^KP40;o2`0@0b<_80`3;cLX40<W:a`@0a/O4
1032`l440<31_P@0_;fj102i^[H30;Vi]@@0^[Ve102n^kD40<>m]`@0c<>k103CbL030=_>a0@0i=C8
103Zf</40>oLcP@0m=o@103ghM430?_SdP@0o^?B103mh<h40?[LbP@0n=O5103fdl040?G@_@<0m<bh
103bb;@40?34[P@0k[nY103[^Z@40>ReWP<0hk2H103KZ9040=6MQP@0`8mi102/Of`409M_GP@0P5m?
0`1ZCT4405<m<`@0>b/U100T6aL4018;2@@04@/90`0O6QP402XV9@@0=C8`100o?C/404Q7AP@0D55@
0`1HFUX4061SH`@0Ifa]101_MGHF0?ooo`00503oool407j5QP@0QXf>102?UID309NMW0@0X:FT102X
[J/40;6e/`@0^Kfj1031a<430<W:a`@0alS51034aL440<71_P@0_knl102l_;P40;Rh]@<0^;Nc102i
]k840;ji]0@0`[be103:`[T40=;7_P<0gLk2103XeLL40>oIb`@0lmg>103ggll40?_Qd0<0on?@103o
hLl40?gMb`@0nmW6103ieL840?OA_P@0mLfi0`3dbKD40?;6/@@0kl:[103[_:D40>RfW`@0hk2I0`3K
ZI840=6NR0@0`i5l102`Pfl409adHP@0QV=D101`DTD305U2=`@0@S0Y100[81/401PA3`@02PH4100D
3`h301lL6P@0:bPW100e<c8403ln?@@0B4Q7101@DU4305QKF`@0H6AT101WKFd406meMQH0oooo000D
0?ooo`@0OXF61026SHh408nEU@<0UifL102PYJ@40:R]Z`@0/KFc102i_KX40<74`@<0bL[71037b<D4
0<C5`@@0`L6n102o_k`40;bl^0@0^;Re0`2h]k<40;Vg/P@0_[Vd1032_;D40<[2^@@0d/Nn0`3Mc/84
0>SEa`@0kmW;103cgLh40?OOc`@0nn7@0`3ohm040?oQc`@0oMg;103kfLH40?WE`P@0mm6n103ecKT3
0?C9]@@0l/Ja103_`Z/40>^lY@@0j;JO103S/9T30=^YTP@0dIj81033TG`40;23K`@0W7AR1026He@4
071BA@<0FD8g1012<2T402/P6`@0614?100:1P@401@?3P<07a`J100[:2L403Dc<P@0?chm1018B4L4
051BD@<0F5]K101PI6@406M]K@@0KgEf5P3oool001@0oooo101nQHH408J=SP@0SiFE0`2GWI`40:2U
Y0@0Z:f[102a]K<40;Vm^P@0`LC10`39b/L40<O8a@@0a<G11031`Kh40;no_0@0_;bh102h^;D30;Rg
/`@0^KNb102n^K@40<:l]@@0b/:i103Bakh30=g>`P@0j=G7103_fL/40??McP@0mmo?103khM030?oS
d0@0on7?103mgL/40?_IaP@0nMG2103gdKh40?G=^@<0m<Ve103ba[440>o2Z`@0jkbU103X]Yl40>>`
V@<0fjVB103AWXP40<>AO0@0/8=_102LM68408ISE0@0L5950`1I@SL4048`:@@0:b0K100H4@l400X6
10@050l>0`0O71X402/X9`@0=C<b100o?Sd404Q8A`@0D59A0`1HFe/4061TI0@0Ife]101_MGHF0?oo
o`00503oool407j5QP@0QHb<102=Ti<309FKVP@0W::Q102TZJP40:b`[P@0];Ne102k_[/30<C6`P@0
a<G11030`Kh40;jn^`@0_;bh102j^[H40;Jf/P<0][B`102h]K040;fh/P@0`K^d1037_kL40=34^`<0
fl^o103UdL<40>_Fa`@0l=W9103dflX40?SLbP<0o=g:103kflP40?WHa@@0mmC1103fdK`40?C<^0@0
l/Vd0`3aa[040>k1Z`@0j[bV103U]Il40>2`V@@0fJRB0`3?WhT40<:BO@@0/XEb102NMVD408UWE`@0
LeI9101MAC/304Hd;@@0;b@O100L5A8400/81P@01P@3100E4Q43024N7@@0;2XY100f=C@403lo?`@0
B4U9101ADe8305QLG0@0H6AU101XKFd406meMQH0oooo000D0?ooo`@0OXF61025S8`408fCT`<0UI^J
102LXZ440:BYZ0@0[;2^102d]kD40;^n^`<0a<K21034aL440<31_P@0_[jk102l_;P40;Zj]P@0][Jb
0`2f];040;Re/0@0_KRb1031^k@40<No]`@0d<Bk0`3Kbkl40>GA``@0jmK7103`fLT40?CKbP@0n=c:
0`3lgLX40?_Kb0@0nMS5103ge<440?KA_0@0m<bh103bbK@30?76/0@0k/6[103Z_:H40>FeW`@0h;2I
103IZ9830<nOR@@0`Y9m102bQG8409ifI@@0RFMG101cETT405e5>`<0AS@]100_91l401`E4P@02`P6
100610<401DB4@<08AhM100/:RT403He=0@0?clo1018BDT4055CDP<0F5aL101PI6D406Q]K@@0KgEf
5P3oool001@0oooo101nQHH408F<S0@0SI>C0`2EViX409bRX@@0Y:VX102//:h40;Bg]@@0^kjk0`34
a/840<C5`@@0`<6n102n_[/40;bl^0@0^[Zf102f][830;Jd/0@0^;F`102m^;840<6k]0@0akng103@
a;/30=_;_`@0iM73103[e/L40?3Ib@@0m=_:103hg<X30?cMbP@0nm_8103if<D40?OD`@@0m]6l103d
c;P40?;9]0<0lLJ`103^`J/40>ZlYP@0iKFO103P/9T40=VXTP<0cin91032TWd40;:5LP@0WWIU1029
IeL407=FB@@0GDDk0`16=2d402lT7`@071DB100;20H400H40`@05A8A0`0Q7Qd402`Z:@@0=SDd100o
?cl404Q9B@@0DE=B0`1HG5`4061TI@@0J6e]101_MGHF0?ooo`00503oool407j5QP@0QHb<102=Ti<3
09FKVP@0W::Q102TZJP40:b`[P@0];Ne102k_[/30<C6`P@0a<G11030`Kh40;jn^`@0_;bh102j^[H4
0;Jf/P<0][B`102h]K040;fh/P@0`K^d1037_kL40=34^`<0fl^o103UdL<40>_Fa`@0l=W9103dflX4
0?SLbP<0o=g:103kflP40?WHa@@0mmC1103fdK`40?C<^0@0l/Vd0`3aa[040>k1Z`@0j[bV103U]Il4
0>2`V@@0fJRB0`3?WhT40<:BO@@0/XEb102NMVD408UWE`@0LeI9101MAC/304Hd;@@0;b@O100L5A84
00/81P@01P@3100E4Q43024N7@@0;2XY100f=C@403lo?`@0B4U9101ADe8305QLG0@0H6AU101XKFd4
06meMQH0oooo000D0?ooo`@0OHB51024Rh/408^BT@<0TYRH102IWih40:2UY0@0YjbZ102^/[040;Fh
]P<0_;jk1030`[l40;fn^`@0^k^h102h^;D40;Jf/P@0/[:^0`2d/Zh40;Nd[`@0_;Na1031^[<40<Nn
]@@0c/>h0`3Gak`40=o<_P@0iLo0103Xd<440>gC`P@0lM?20`3ce<840??C`0@0l]2n103acKX40>o9
]@@0kLFa103[`Zd30>VnZ@@0iKVT103Q]9h40=Z]U`@0e:JA103:WHP30;nBO`@0/8Id102ONFP408]Y
FP@0MUY=101QBCl404Xh<0<0<RLQ100N61D400h;2@@00@0010091`L401LE5@<08b8Q100^;B`403Lh
=`@0@D511019Bd/4055DE0<0FEeM101QIFH406Q]KP@0KgIf5P3oool001@0oooo101mQ8D408B;R`@0
Ri:A0`2BV9P409VOWP@0X:FT102W[:X40:jb/0@0]KRf0`2l_[/40<32_`@0_Kjk102k^kP40;Rh]@@0
][Jb102b/Zh30;Bb[P@0]kB_102l]k440<6j/`@0akje103>`kP30=O7_0@0glbn103Ucl040>S@`@@0
kM?2103adl830??D`P@0lm?0103bd;h40?7=^P@0klVe103]aK440>_2[@<0jKjY103U^J@40>6dWP@0
fZfG103DYY440<ZMR0<0_i9o102`QW@409miJ0@0RfUJ101fFTd40659?`@0BSP`0`0b9b4401hH5@@0
3P/91001000400T71`@05aDE0`0S8R4402h];0@0=cPg1011@D4404U;B`@0DEAD0`1IGEd4065UIP@0
J6e^101_MWHF0?ooo`00503oool407f4Q@@0Q8^;102;TY4309:HV0@0VInN102PYJ@40:N/ZP@0[[:`
102e^;H30;bn^`@0`<:o102m_[/40;^k^0@0^;Re102f][840;:b[P<0];:^102g]:l40;bg/@@0`KZc
1037_[D40<k3^0<0elNl103Oc;h40>G?`0@0j=31103]dl840?7C`P<0lmC2103cdl040?;@_P@0lLfj
103_bKD40>g5/@@0jl:]0`3Y_ZT40>FiY0@0hKBN103J[IL40=BVT@@0bYf80`2oTWl40;26M0@0WgUX
102;JEX407IJC@@0HDTo101:>303038W8@@07QPE100>2`T4004000@02@L7100G5AD302<R8@@0;Rd/
100g>3L40451@@@0BD];101AE5@305UMG@@0HFEV101XKFh406mfMQH0oooo000D0?ooo`@0OHB51024
Rh/408^BT@<0TYRH102IWih40:2UY0@0YjbZ102^/[040;Fh]P<0_;jk1030`[l40;fn^`@0^k^h102h
^;D40;Jf/P@0/[:^0`2d/Zh40;Nd[`@0_;Na1031^[<40<Nn]@@0c/>h0`3Gak`40=o<_P@0iLo0103X
d<440>gC`P@0lM?20`3ce<840??C`0@0l]2n103acKX40>o9]@@0kLFa103[`Zd30>VnZ@@0iKVT103Q
]9h40=Z]U`@0e:JA103:WHP30;nBO`@0/8Id102ONFP408]YFP@0MUY=101QBCl404Xh<0<0<RLQ100N
61D400h;2@@00@0010091`L401LE5@<08b8Q100^;B`403Lh=`@0@D511019Bd/4055DE0<0FEeM101Q
IFH406Q]KP@0KgIf5P3oool001@0oooo101lQ8@408>:RP@0RI2@0`2@UYD409JLV`@0WJ6P102SYjH4
0:V]Z`@0[k:`0`2e]kD40;^l^@@0^[^h102g]k@40;Bd/@@0/k:_102a/:`30;>a[0@0][:/102k]Jl4
0;jg/0@0`kZa103;_[<30=;1]P@0elBg103LakT40=k7^@@0hlZj103Ub[T30>O:^@@0ilVh103VakD4
0>G3/@@0hKn]103N^ZP40=bfX`<0f[>O103F[YX40=2XU0@0bJ2=1031V8H40;N?O@<0ZhEd102KN6P4
08Y[G0@0MUa?101SC48404dl=0@0=R/V0`0P6QL4010=30@00@0010020@4400l?3`@06a/J0`0V9RH4
030a<0@0>S/j1012A4@404]=C@@0DeIF0`1JGUh4065VI`@0J6i_101_MWLF0?ooo`00503oool407b4
Q0@0PhZ:1029T903092FU@@0UYbK102MXJ040:>WYP@0ZJf[102_/[030;Fg]@@0^kbi102j^kP40;Ng
]0@0];Ba102c/Zl40;6`[0<0/k6/102f/Z`40;^e[`@0_[N`1033^[440<^n/`<0d/6f103Ga;L40=c7
^@@0g/Ni103Sb[X40>G:^@<0ilZi103WbKP40>K7]@@0iL>a103Q_jd40=jjZ0@0g;JS0`3J/il40=J^
VP@0d:RD1039X8d40<6HQP@0]hmm0`2[QG@409]hJ0@0RV]L101fG4l406=<@P@0CC`d100f:bH3020J
5`@040d<1001000400810@@03`l?100K6aX302HV9P@0<34`100j>cX40494A0@0Bde=101CEUH305YN
GP@0HFIW101XKVl406mfMaH0oooo000D0?ooo`@0O8B41023RXX408V@T0<0T9JE102FW9/409fQX0@0
XjNV102Y[J/40:nb/0<0]KNe102k_;T40;Zk^0@0]kNd102d];440;>b[`@0/K2/0`2c/J`40;Jb[0@0
^kF_102n]k040<>j/@@0bkjc0`3B`KH40=O4]`@0g<Ni103NakT40>?:^P@0iLZi0`3Wb[T40>O9^0@0
i/Ne103U`k440>6o[@@0g[ZX103L]Z<30=ZcW`@0eZjJ103@Z9@40<VPS@@0`IR6102gSgd30:^5M0@0
VgQX102:Je`407ILC`@0Hda2101=?3@403H[9P<081XG100@3@`4004000@00P41100?3`l401/K6P<0
9RHV100`<C0403Xk>P@0@TA4101;CDd405=FEP<0FUiN101QIVL406Q^K`@0KgIg5P3oool001@0oooo
101lQ8@408>:RP@0RI2@0`2@UYD409JLV`@0WJ6P102SYjH40:V]Z`@0[k:`0`2e]kD40;^l^@@0^[^h
102g]k@40;Bd/@@0/k:_102a/:`30;>a[0@0][:/102k]Jl40;jg/0@0`kZa103;_[<30=;1]P@0elBg
103LakT40=k7^@@0hlZj103Ub[T30>O:^@@0ilVh103VakD40>G3/@@0hKn]103N^ZP40=bfX`<0f[>O
103F[YX40=2XU0@0bJ2=1031V8H40;N?O@<0ZhEd102KN6P408Y[G0@0MUa?101SC48404dl=0@0=R/V
0`0P6QL4010=30@00@0010020@4400l?3`@06a/J0`0V9RH4030a<0@0>S/j1012A4@404]=C@@0DeIF
0`1JGUh4065VI`@0J6i_101_MWLF0?ooo`00503oool407b3Q0@0PXV91028SXh308fCT`@0TiVH102I
WYd409jSXP@0Y:RV102Y[:X30:ja[`@0];Jc102g^;D40;>c/0@0/;2]102`[j/40:n^ZP<0/:fY102a
[ZP40;NaZ`@0^[>/102o]Zh40<Nj/0<0bk^`103?_K440=>o/P@0eL2b103I`K840=W0/@<0f/2`103J
_Zh40=VkZ`@0e[NW103B/j840<n_WP@0c:^J0`39YYD40<>QS`@0_IZ9102eTh840:j;N`@0Y89c0`2F
MfT408IZG@@0MEeB101SCdD404ho>0@0>BlZ100S7Q/3018@3P@00P411000000400/;2`@05QHF100P
8B4302X[:`@0=3De100l?Sh404E7A`@0CE1@101DF5P305]PH0@0HVMX101YKg0406mfMaH0oooo000D
0?ooo`@0O8>41022RHT408R>SP<0SI>C102CVIP409VNW@@0WZ>R102TZ:H40:V/ZP<0[[6_102d][<4
0;Nh]@@0/k>`102`/:d40;2_Z`@0[jjZ0`2`[JT40;6^Z0@0]k6[102j/j`40;nf[P@0akZ`0`3;^k04
0<nm/@@0dknb103E`;840=W1/P@0fL2a0`3J`;040=Zn[P@0fK^[103F]jL40=:cXP@0cjnN103<ZiX3
0<VVU@@0`j6?102mVXT40;FCPP@0[X]k102TPW<309IgJ@@0QVYM101eGE8406=?A@@0CSlh100i;bX4
02<N6`<04Q0>10020@44000000@02`/;100F5QH4020Q8@<0:R/[100d=CD403`n?P@0ADM7101=D504
05AHF0<0Ff1P101RIfP406U_L0@0KgIg5P3oool001@0oooo101lPh@408:9R@@0R8j>0`2=Ti<409>I
V0@0VIjM102NXj840:BXYP@0ZJbZ0`2^/Jl40;Bf/`@0]kRe102c/k040;2`[@@0/:n[102_[ZX30;2]
Z@@0/JjX102g/J/40;Zc[0@0_kJ^1037^[030<^k/0@0ckfa103C_k840=G0/P@0fL6b103I`;430=[0
/0@0f[j^103I^j/40=JgY`@0d[>R103?[ih40<b[VP<0bJJE1033XHl40;fJR@@0]I>2102^Rg/40:B2
L`<0UWMY1026JUd407EMDP@0Hdm5101>?cP403T_:P@08ahK0`0B40h400810@@00000100;2`/401HF
5P@0824Q0`0Z:b/403@e=@@0?3hn1015AdL404e@D0@0E5QH0`1KH604069WJ0@0JFm`101_MWLF0?oo
o`00503oool407b3Q0@0PXV91028SXh308fCT`@0TiVH102IWYd409jSXP@0Y:RV102Y[:X30:ja[`@0
];Jc102g^;D40;>c/0@0/;2]102`[j/40:n^ZP<0/:fY102a[ZP40;NaZ`@0^[>/102o]Zh40<Nj/0<0
bk^`103?_K440=>o/P@0eL2b103I`K840=W0/@<0f/2`103J_Zh40=VkZ`@0e[NW103B/j840<n_WP@0
c:^J0`39YYD40<>QS`@0_IZ9102eTh840:j;N`@0Y89c0`2FMfT408IZG@@0MEeB101SCdD404ho>0@0
>BlZ100S7Q/3018@3P@00P411000000400/;2`@05QHF100P8B4302X[:`@0=3De100l?Sh404E7A`@0
CE1@101DF5P305]PH0@0HVMX101YKg0406mfMaH0oooo000D0?ooo`@0Nh>31021QhP408J<S0<0Ri6A
102@UYD409FJV@@0VYnN102OXj840:>WY@<0Z:^Y102/[Z`40;6b/0@0[Zj/102/[:T40:^[Y`@0ZZVU
0`2[ZJ@40:jZY@@0/ZfW102f[jP40;Z`Z0@0`;>Y0`31/jT40<FfZP@0b;NZ103:]j/40<bgZP@0cKNY
0`3=]JL40<^bY0@0b:nQ1035[9d40<6WV0@0_Z>D102iWXl30;FIRP@0[i>4102WS7h40:65N0@0VWia
102@MFP3089ZGP@0LUiC101RD4P404i1>`@0>c8^100Y924401HE50<010D51000004400X:2`@04a@D
100M7Qh402HW9`<0;c4a100h>SX40412@P@0B4];101?DU<405IJFP<0GF9R101SJFT406Y`L@@0L7Mh
5P3oool001@0oooo101kPh<40867R0@0QXb<0`2;TI44092FU@@0UIZI102JWih409nSXP@0XjNU0`2X
ZjT40:b^[0@0/K:`102^[Z`40:b/Z@@0Zj^W102ZZJD30:^YY0@0[ZZU102b[JL40;J_Z0@0^[2X1030
/jT30<6cZ@@0aKJZ1038]jX40<ZgZ`@0c;NZ103=]jT30<feY`@0bk:T1038[j440<F/W@@0`JNH102n
Xi@40;VNS`<0]IV:102_Th@40:N<OP@0XHEh102JOW44091eJ0<0PVYN101bGU<4069@B0@0CT4k100k
<Rh402TT8@@05QDD0`041@D400000@@02PX;100C51@401dN7P@09RLW0`0_<C4403Pj>P@0@4921018
Bd/404mBD`@0EUYJ0`1MHV8406=YJ@@0JW1a101`MgPF0?ooo`00503oool407^3P`@0PHN81026S8`3
08^AT@@0T9JE102EVYT409ZOWP@0Wj>R102SYjD30:R[Z@@0[:j/102a/[040:j^[0@0[:bY102[ZjL4
0:ZYY@<0ZjVT102^ZZD40;:]Y`@0]ZnX102j/:P40<2cZ@<0`K>Y1035]ZX40<RgZP@0b[N[103<]jX4
0<fgZ@<0cKFW103;/Z@40<R_X@@0aJbM1031YiP40;jSU0@0^Ij?0`2eVHX40:nCQ0@0Yhan102QQGP4
09YnL@@0T7EX0`22JUh4079ND`@0HU18101>@C/403/b;P@0:B@Q100F5A@300@51@@00001100:2P/4
01<D50@07AhN100V9bL302la<@@0>3Xj1010@T8404Q;B`@0Ce9C101FFUX305eRHP@0HfUY101ZL744
071gN1H0oooo000D0?ooo`@0Nh>31021QhP408J<S0<0Ri6A102@UYD409FJV@@0VYnN102OXj840:>W
Y@<0Z:^Y102/[Z`40;6b/0@0[Zj/102/[:T40:^[Y`@0ZZVU0`2[ZJ@40:jZY@@0/ZfW102f[jP40;Z`
Z0@0`;>Y0`31/jT40<FfZP@0b;NZ103:]j/40<bgZP@0cKNY0`3=]JL40<^bY0@0b:nQ1035[9d40<6W
V0@0_Z>D102iWXl30;FIRP@0[i>4102WS7h40:65N0@0VWia102@MFP3089ZGP@0LUiC101RD4P404i1
>`@0>c8^100Y924401HE50<010D51000004400X:2`@04a@D100M7Qh402HW9`<0;c4a100h>SX40412
@P@0B4];101?DU<405IJFP<0GF9R101SJFT406Y`L@@0L7Mh5P3oool001@0oooo101kPX<407n6Q`@0
Q8^;0`29Shl408fCT`@0TYNF102FViX409ZNW@@0WZ:P0`2QYJ<40:FWY@@0YjRV102WZ:D40:JWY0@0
YZJR102UY:430:JTX0@0YjBP102ZYZ040:jXX@@0/JVQ102eZj830;N[XP@0^ZfR102l[J840;j]XP@0
_ZbP102nZil30;bYW@@0^ZJJ102gXiL40;BPT`@0[i^?102[UXX40:B@Q0<0XHao102JQGT409AoM0@0
SWU^1026LVP407]XG`<0K5aD101MD4T404a3?@@0>cDb100Z:2H401TI6@@02@/<0`010P<400T:2`@0
4Q<D100K71d402@U9P@0;2h^0`0d=cL403`o?`@0A4M7101;CTl4059FEP@0F5eM0`1NI6@406AZJ`@0
JW5b101`MgPF0?ooo`00503oool407^2P`@0OhJ71024Rh/308V?S`@0SI>C102BUiH409JKVP@0VYjM
102NXZ030:6UX`@0YJNU102WZ:H40:NXY@@0YZNT102VYZ840:FTX@<0YZBP102WY:040:ZVX0@0[ZRQ
102aZJ440;F[XP<0]j^R102j[J840;b]XP@0_ZfR102n[:040;j[W`<0_:VM102jYYX40;NSU`@0]:2C
102_Vhl40:^FRP@0Y9240`2QS7l409Z5N@@0U7md102>NFh408IbJ0@0NfQO0`1/G5@405e@B@@0C4<m
100k=C8402XX9P@06ATI10092``300420`@02@X;100B4a@401/L7@@092DV100/;Rh303@g=`@0?3lo
1014AdL404]>C`@0DUIF101HGEd305iTI0@0I6Y[101ZLG84071gN1H0oooo000D0?ooo`@0Nh:3101o
QXL408B;R`<0RHn?102=Ti<409:GUP@0UY^J102JWYd409jRX0<0XJFS102UYjD40:NXYP@0YjRU102V
Yj@40:JVXP@0YJBQ0`2VY:040:NTX0@0ZZJP102^Z:440;6YX@@0]J^R0`2gZj840;Z]XP@0_:fR102n
[J840;j/X0@0_Z^O0`2lZId40;ZVVP@0]j>G102dX9<40:nKS`@0ZiJ:102TT8@30:6<O`@0VXEi102D
Og@408iiKP@0QW9X101kJ5l306aLE0@0GE19101<@cd403/e<P@0:RPV100I6AT400T;30<00@831009
2P/4018C50@06a`M100T9BH402`^;P<0=3Lg100l?cl404A7A`@0Bdi?101BEUH405QMG@<0GVAT101T
JV/406YaLP@0L7Mh5P3oool001@0oooo101jPX8407j5QP@0PXV90`26SHd408Z@T0@0SYBC102BUiH4
09FJV@@0VIfK0`2KWih409jQW`@0Wj:P102PXYl40:2QW`@0Wj2M102OWi`309jNV`@0WijJ102RWiX4
0:FPVP@0YZ2J102ZXYX30:^RV@@0[::I102^XYT40:jQV0@0[J2F102]WiD30:bNT`@0ZY^A102WV8d4
0:>DRP@0Whn5102IRX0409>4N`<0SWid1026Mfl4089dJ`@0O6iV101cIEh406IKE@<0FE1;101;AD04
03/h=@@0;2/Z100M7al400lB4`@01@L80`082@T4018D50@06adM100S9BH402/];P@0<cDf0`0j?Cd4
0454A@@0B4]<101>DU<405AIF@@0FUmP0`1PIVH406I/K@@0Jg9c101aN7TF0?ooo`00503oool407Z2
PP@0OXF61022RHT308J=S@@0RY2@102>U9<409:GUP@0UIZI102IWI/309^OWP@0WZ6O102OXZ040:2R
W`@0X:6O102OX9d409nOW0<0WYjK102OWYX40::OVP@0YJ2J102VX9X40:ZRVP<0Zj:I102/XYT40:jR
V@@0[Z6H102]X9H40:fOU@<0[9jC102ZVi440:NHS@@0XiB:102OShD409V:P0@0ThAk0`2>OW@408Ig
K`@0PWA[101lKVH407=UGP@0IU]E0`1ID4/404]5@0@0>cPe100/:bX401dO7`@03a8C10051`P300P9
2@@04Q@D100K7Ad402<U9P@0:bd^100c=CH303Xm?@@0@DA51018Bd`404iBD`@0E5UI101JGf03061V
IP@0IVa]101[LW<4075hNAH0oooo000D0?ooo`@0NX:2101nQHH408:9R@<0QXf=102:T90408jDT`@0
TYNF102EVYT409VMV`<0VinN102NXIl409nRX0@0X::O102PXIl409nPW@@0WinL0`2NWY/409nNVP@0
XYnJ102UX9X40:JPVP@0ZZ:J0`2[XYT40:bRV@@0[Z:I102^XIP40:fPUP@0[InE0`2/WY<40:ZKT@@0
YiR=102SU8X409n?Q@@0VHZ0102CQ7/308inM0@0QWM_1022M6/407a^IP@0LfEN101VFeD305U@B`@0
BdE0100k>3D402`[:P@07AlO100?4Q<400D720<020T9100B51@401/M7@@08bDV100[;Bh403<e=P<0
>Sdm1011A4D404Q;C0@0CU9C101DFET405YOH0<0H6IV101VK6d406]bL`@0LGQi5P3oool001@0oooo
101jPX8407j5QP@0PXV90`26SHd408Z@T0@0SYBC102BUiH409FJV@@0VIfK0`2KWih409jQW`@0Wj:P
102PXYl40:2QW`@0Wj2M102OWi`309jNV`@0WijJ102RWiX40:FPVP@0YZ2J102ZXYX30:^RV@@0[::I
102^XYT40:jQV0@0[J2F102]WiD30:bNT`@0ZY^A102WV8d40:>DRP@0Whn5102IRX0409>4N`<0SWid
1026Mfl4089dJ`@0O6iV101cIEh406IKE@<0FE1;101;AD0403/h=@@0;2/Z100M7al400lB4`@01@L8
0`082@T4018D50@06adM100S9BH402/];P@0<cDf0`0j?Cd40454A@@0B4]<101>DU<405AIF@@0FUmP
0`1PIVH406I/K@@0Jg9c101aN7TF0?ooo`00503oool407Z1PP@0OHB51021R8P308B;R`@0R8j>102;
TI0408jCT`@0TIJE102DV9L309JJV@@0V9^J202IW9X409VKV@@0VI^H102HVYL309RIU@@0VIRD102I
Ui<809^HT`@0WYVB0`2OV94409jGT0@0WiN?102OUXh409nES@@0WYB;0`2LTXX409V?Q`@0UXb4102B
R80408j4O@@0RGmh1023NG8307edK@@0N71Z101cJfH406aTG`@0HEYF101GDTh304a8A@@0?S`j100_
<2l4028T90@05ATI100930d400X<3@<051HF100L7Ql402@V9`@0:bh_100b=CH403Tm?@<0@4=41016
BTX404a@D@@0DUMG101HGEd405eRH`<0HVQY101WKVh406acM0@0LGQi5P3oool001@0oooo101jPH84
07f4Q@@0PHR80`24Rh/408R>SP@0Ri6@102>Ti<4096FU@@0U9RG0`2FVYT409RKVPP0VIbJ102IViT4
09VKV0@0V9ZG0`2HVID409VHU0@0VINC202KV9<409jITP<0WiRA102NUi0409nGS`@0WiJ>102OUHd4
09jDR`<0W9::102IShL409J<Q0@0TXR0102>Q7d408UoN0@0PgUb0`1mM6d407Q`JP@0Lf]V101/I5l4
065JEP@0Ee9>0`1<B4D403hl>P@0;c0_100R92@401DI6@@02@`=100:30d301@F5P@071hO100T9RL4
02/^;`@0<SDf100i?Cd30413A0@0ATY:101<D544059GE`@0F5eM101MHV<3069XJ@@0Ifi^101/Lg@4
075hNAH0oooo000D0?ooo`@0NX62101mQ8D40868R0<0Q8^;1028SXh408^AT0@0SY>C102AUYD409BH
U`<0UYZI102HViX809VLVP@0VI^I102IViP409RJU`<0V9VE102IV9@409VGT`P0ViRC102NVI8309nH
T@@0WYN@102OUhl409nFSP@0WiF=102NU8/309bBRP@0VHn7102FS8@409:8P0@0SXAm1029OgP408=i
LP<0OGA]101hL6X407=[IP@0K6AO101QFUH405MBCP<0C4Q5100n?3X402l`;`@08R@T100E6AT400T<
3@@02P`=0`0D5QH401`N7`@092HW100[;Rl4038e=P@0>Cdm0`10@d@404I:BP@0C51A101BEeL405QM
G@@0GF9S0`1RJ6T406M^KP@0K7=d101aN7TF0?ooo`00503oool407Z1PP@0OHB51021R8P308B;R`@0
R8j>102;TI0408jCT`@0TIJE102DV9L309JJV@@0V9^J202IW9X409VKV@@0VI^H102HVYL309RIU@@0
VIRD102IUi<809^HT`@0WYVB0`2OV94409jGT0@0WiN?102OUXh409nES@@0WYB;0`2LTXX409V?Q`@0
UXb4102BR80408j4O@@0RGmh1023NG8307edK@@0N71Z101cJfH406aTG`@0HEYF101GDTh304a8A@@0
?S`j100_<2l4028T90@05ATI100930d400X<3@<051HF100L7Ql402@V9`@0:bh_100b=CH403Tm?@<0
@4=41016BTX404a@D@@0DUMG101HGEd405eRH`<0HVQY101WKVh406acM0@0LGQi5P3oool001@0oooo
101iPH4407b3Q0@0OhJ70`22RHT408F;R`@0R8j>102;T90408fBTP@0SiBC0`2AUI@409:FU@@0TiNE
102DUiD409BFU@@0U9JD102CUI<309:CT0@0TI6>102@T8`4096@S0@0THn;102CShX309:>R@@0Shb6
102?RhD408n:Q0@0ShZ3102?RH8308f7P0@0RXAn1027PW/408=mN0@0OgYe101jMG4407IaK@<0LFiZ
101]JFH406]VH`@0I61L101JEU@4051>B`<0@T91100c=SD402HZ:`@06AlP100A5AH400lB4`@061XK
0`0O8R<402HY:P@0;C0a100d=cP403Xn?P@0@4A50`16BT/404a@D@@0DEIF101FFe`405]PH@@0H6EV
0`1TJV/406U_L0@0KGAe101bNGXF0?ooo`00503oool407V1P@@0O8>4101oQXL308:9R@@0QH^;1028
SXh408^@T0@0SI:B102?U9<3096EU0@0TYJE102CUiD409BGU@@0U9JE102DUY@409>ET`<0TY>@102A
THh4092@S0@0TI2<102ASh/409>?RP<0TXj9102?S8H408n;Q@@0ShZ4102?RX<408n9PP<0SHN0102:
Q7h408N2N`@0Pgeh101oNWD407YeL@@0MW5]0`1aKVX406eYIP@0JfIS101TH5`405YFE0@0D4i;0`12
@T4403<f=@@09RX[100I7b04014E5P@03a8C100H6Q/301lR8`@09RTZ100]<34403@g>0@0>Shn1010
A4D304I:B`@0C51A101AEUH405IKG0@0Ff1Q101PIFH306AZJ`@0JFm`101]M7D4079iNQH0oooo000D
0?ooo`@0NH61101lPh@407n6Q`<0PXV91025Rh/408R>SP@0Ri2@102=TY8408nDT`<0TIFD102BUYD4
09>GU@@0U9NE102DUYD409BFU0@0TiFC0`2BTi04096ASP@0T92<102AT8`4096?R`@0Thn:0`2BSXT4
08n<QP@0Sh^5102?RX@408n:P`@0ShV20`2=Qh0408Z4OP@0Qh9k1023OGP407mjM@@0NWEa101fLFd3
075^JP@0KFUV101[IV<406APG0@0FUID101@CT/30492@@@0<cHe100V:R/401TO80@04ADF100?4Q<4
01PJ6`<07b8S100V:BX402d`<@@0=3Lh100j?Sh40414A@<0ATY;101<D544055FEP@0EU]L101KH644
061UIP<0I6Y[101YKg0406edM@@0LWUj5P3oool001@0oooo101iPH4407b3Q0@0OhJ70`22RHT408F;
R`@0R8j>102;T90408fBTP@0SiBC0`2AUI@409:FU@@0TiNE102DUiD409BFU@@0U9JD102CUI<309:C
T0@0TI6>102@T8`4096@S0@0THn;102CShX309:>R@@0Shb6102?RhD408n:Q0@0ShZ3102?RH8308f7
P0@0RXAn1027PW/408=mN0@0OgYe101jMG4407IaK@<0LFiZ101]JFH406]VH`@0I61L101JEU@4051>
B`<0@T91100c=SD402HZ:`@06AlP100A5AH400lB4`@061XK0`0O8R<402HY:P@0;C0a100d=cP403Xn
?P@0@4A50`16BT/404a@D@@0DEIF101FFe`405]PH@@0H6EV0`1TJV/406U_L0@0KGAe101bNGXF0?oo
o`00503oool407V0P@@0Nh:3101nQHD30827Q`@0PhV91025Rh/408N=S@@0RHn>102;T90308bAT@@0
SI:A202>TY4408jBT0@0SY6?102=Shd308^=RP@0Rhb91028RXH408R8Q@@0R8N31028Qh8308J5P0@0
Q8=n1023PWh408:0O0@0PGmj1021OgT307imN0@0NgYe101hMg<407EdL@@0LW9^101]KF/406][J0<0
I6ET101RHf4405iOG@@0EEMF101=Cdh40495A@<0=SXk100/<C8401lV9`@05Q/L100G6Q/401dP8@@0
92LX0`0[;Rl4034e=P@0=c/l100m@D840496A`@0Ada=0`1<DE84055FE`@0EU]L101JH60405mTI@@0
HfUY0`1WKFh406]aLP@0KWEf101bNW/F0?ooo`00503oool407V0P@@0Nh:3101nQHD30827Q`@0PhV9
1025Rh/408N=S@@0RHn>102;T90308bAT@@0SI:A202>TY4408jBT0@0SY6?102=Shd308^=RP@0Rhb9
1028RXH408R8Q@@0R8N31028Qh8308J5P0@0Q8=n1023PWh408:0O0@0PGmj1021OgT307imN0@0NgYe
101hMg<407EdL@@0LW9^101]KF/406][J0<0I6ET101RHf4405iOG@@0EEMF101=Cdh40495A@<0=SXk
100/<C8401lV9`@05Q/L100G6Q/401dP8@@092LX0`0[;Rl4034e=P@0=c/l100m@D840496A`@0Ada=
0`1<DE84055FE`@0EU]L101JH60405mTI@@0HfUY0`1WKFh406]aLP@0KWEf101bNW/F0?ooo`00503o
ool407V0P@@0Nh:3101nQHD30827Q`@0PhV91025Rh/408N=S@@0RHn>102;T90308bAT@@0SI:A202>
TY4408jBT0@0SY6?102=Shd308^=RP@0Rhb91028RXH408R8Q@@0R8N31028Qh8308J5P0@0Q8=n1023
PWh408:0O0@0PGmj1021OgT307imN0@0NgYe101hMg<407EdL@@0LW9^101]KF/406][J0<0I6ET101R
Hf4405iOG@@0EEMF101=Cdh40495A@<0=SXk100/<C8401lV9`@05Q/L100G6Q/401dP8@@092LX0`0[
;Rl4034e=P@0=c/l100m@D840496A`@0Ada=0`1<DE84055FE`@0EU]L101JH60405mTI@@0HfUY0`1W
KFh406]aLP@0KWEf101bNW/F0?ooo`00503oool407V0P@@0Nh:3101nQHD30827Q`@0PhV91025Rh/4
08N=S@@0RHn>102;T90308bAT@@0SI:A202>TY4408jBT0@0SY6?102=Shd308^=RP@0Rhb91028RXH4
08R8Q@@0R8N31028Qh8308J5P0@0Q8=n1023PWh408:0O0@0PGmj1021OgT307imN0@0NgYe101hMg<4
07EdL@@0LW9^101]KF/406][J0<0I6ET101RHf4405iOG@@0EEMF101=Cdh40495A@<0=SXk100/<C84
01lV9`@05Q/L100G6Q/401dP8@@092LX0`0[;Rl4034e=P@0=c/l100m@D840496A`@0Ada=0`1<DE84
055FE`@0EU]L101JH60405mTI@@0HfUY0`1WKFh406]aLP@0KWEf101bNW/F0?ooo`00503oool407R0
P0@0NX:2101lPh@307j5QP@0P8N71022RHT408B:RP@0QX^;1027SH`308R=S@P0RHj=102:SXd408V=
S0@0RHb;1027RhT308F8QP@0P8>11020PX040822O`@0P85n101oOg/307]lN@@0MgUf101fMg@407Mh
M0@0MWMc101cMG4706mbK`@0KW5^101[KVd406Q[JP@0IFUY101SIfH305eQHP@0FemO101FFUX404mC
D`@0AT];100l@T<3038i>P@0;38c100P9BL4020T9@@09bX[100/<344038f=`<0=c/l100l@D440456
AP@0AT];101;Ce0404mDE@<0DeQI101GG5d405]QH@@0GfAU101RJ6T406I/K@<0JG1a101/Lg@4071g
N0@0LgYk5P3oool001@0oooo101hP80407Z2PP@0O8>40`1nQHH40827Q`@0PXV91024RXX408J;R`@0
Qhf<0`28SHd808V>S@@0RXj=1029SH`408V<R`@0Qh^90`25R8H40823P@@0P8:01020PWl40821OP@0
Ogmk0`1kO7T407MiMP@0MWMd101gN7@407IgL`@0LgEa1`1_LVl406iaKP@0Jfi]101XJfX406EYJ@@0
HfMV0`1MHF8405]OG`@0EUYJ101?De<404I;B`@0?4930`0b>CX402`b<`@082DW100P92D402LZ:`@0
;30a100b=SL303Lk?0@0?4511011ATH404I;B`@0Bdm@101?E5D305=HF@@0EeaM101KHF4405mTI@@0
HVQY101VK6d306U`L@@0K7=d101`MgP407=jNaH0oooo000D0?ooo`@0N820101jPX8407b3Q0<0OXF6
1020QhL408:9R@@0Q8Z:1026Rh/408N=S0<0R8f=2029SXd408Z>S@@0RHf<1029S8/408N;R@<0QHR6
1020Ph440822P0@0P89o1020PGh407moN`<0Ngai101gNGH407IgM0@0MgQd101fMg<407=eL@L0Kg9_
101^LFh406]^K@@0J6]Z101UJFT406=WIP<0GF5R101KGel405IJFP@0Ce=C1016Bd/403a2@`<0<STj
100/<S<4020U9`@082@U100W:R/402``<@@0<SHg0`0g>c`403a1@@@0@DI61016Bd/404]?D0@0CeAE
0`1CF5T405MLG@@0Ff5Q101OI6D4069XJ@@0IVa]0`1YL74406acM0@0L7Mh101cNW/F0?ooo`00503o
ool407R0P0@0NX:2101lPh@307j5QP@0P8N71022RHT408B:RP@0QX^;1027SH`308R=S@P0RHj=102:
SXd408V=S0@0RHb;1027RhT308F8QP@0P8>11020PX040822O`@0P85n101oOg/307]lN@@0MgUf101f
Mg@407MhM0@0MWMc101cMG4706mbK`@0KW5^101[KVd406Q[JP@0IFUY101SIfH305eQHP@0FemO101F
FUX404mCD`@0AT];100l@T<3038i>P@0;38c100P9BL4020T9@@09bX[100/<344038f=`<0=c/l100l
@D440456AP@0AT];101;Ce0404mDE@<0DeQI101GG5d405]QH@@0GfAU101RJ6T406I/K@<0JG1a101/
Lg@4071gN0@0LgYk5P3oool001@0oooo101hOh0407V1P@@0Nh:30`1mQ8@407j5Q@@0P8J71021QhP4
08:8R@@0PhV90`24RXX<08F:RP@0QHZ91024RHP408>7QP<0PHF3101nPX0407]nO0@0NGaj101gNWL4
07EhM@<0LWIc101aM784071cL@@0Kg9`101/L6h406]`KP<0Jg1_101/L6l406Q]K@@0Ifa/101UJV/4
06=XJ@@0GfAU0`1KHF4405IMGP@0DEMI101;D54404=8B@@0?4930`0e>S/402hb<`@0:Rl`100a=SL4
03Hk?0@0>cm0100oA4D304=8B@@0B4e=101<DE4404mEE@@0DeQI101FG5d305YPH0@0GF=T101PIVL4
06=YJP@0IVa]101YKg0306abL`@0KWEf101aN7T407=kO1H0oooo000D0?ooo`@0N7n0101iPH4407^2
P`<0OHB4101nQHD40826Q`@0PHN81022R8T408>9R@<0Q8Z:3025RXX408F:R@@0Q8V81023QhH30865
P`@0OX:0101kOW`407UlNP@0MgYg101eN7D3079fL`@0LGAb101`Lg4406mbL0@0K71^101[L6h306]`
K`@0K71_101XKFd406M/K0@0IFY[101SJ6T405mTI@<0Ff5Q101FGEh4055GF@@0Be1A1013B4T403a2
@`<0=CXk100^<S<402X_<0@0<CHg100f>c`403/o@0@0?dA50`13B4T404Q=C@@0C55A101?EED405=H
F@@0EUaM0`1JH60405eSI0@0H6IW101SJFX406I/K@@0JFm`0`1/LW<406ieMP@0LGQi101cNg`F0?oo
o`00503oool407QoP0@0NH61101kPX<307f4Q0@0OXF51020QXL40867R0@0PXR91023RHT308B:RP`0
QHZ:1025RXT408B9R0@0PhN60`21QH<407j2P0@0Ngil101iO7X407MjM`@0MGQe0`1bMW<4075dLP@0
L7=a101_LW0406a`KP@0Jg1^0`1[L6l406a`K`@0J6e]101WK6`406EZJ`@0HfQY101OI6D305]QH@@0
EUeN101AEeT404]@D@@0@dQ9100l@T<303Dj>`@0;S8c100Z;c04034f=`@0=S/l100k?d0403m4A@<0
@dQ91018CDd404aAD@@0CeEE101CF5T405ILG@<0FV1P101MHf@4061VI`@0HfUZ101VK6d406U_L0<0
K79c101^MGH4075hN@@0Lg]l5P3oool001@0oooo101gOh0407R0P@@0NX620`1kPX<407b3Q0@0OHB4
101nQHD407n6QP@0P8J60`20QhL<0867Q`@0PHJ61020QHD407n4Q0<0OH:2101kP7l407UmO0@0MGYi
101^Lg8406]aK`<0K79`101[L70406U^K@@0J6i]101XKfh406U_K`<0JFm^101XKVd406E/K0@0I6Y[
101PIfT405iUI`@0G6=T0`1IH68405ILGP@0DEMH101=DU<404A9BP@0?T=40`0k?d0403/o@@@0?dA5
1012AdT404I;C0@0BDm@101=DU<3051EEP@0DeUJ101FG5d405UOH0@0G69R101NI6D3065WJ0@0HfYZ
101VK6d406Q^K`@0JW5b101/Lg@306ieMP@0L7Mh101bNGX407AlOAH0oooo000D0?ooo`@0Mgn0101h
P84407Z1PP<0Nh:3101lPh@407f4Q0@0OXF5101oQXH40826QP<0P8N73021QhL40866QP@0P8F5101o
Q8@307f2PP@0Nh1o101iOG`407EjN@@0KW=b101[LFl306abL0@0Jg1`101YKVd406Q^K@@0J6m^101Y
Kfl306U_KP@0J6i]101UK6`406AZJ`@0H6MY101NIFL405aSI0<0FF1R101FG5h4055GF0@0CE9C1014
BDX403i3A0<0>cm0100k?d4403m4A@@0@TM91016Bd`404U?D0@0CE9C0`1@EEH405=IFP@0EUaM101I
Gf0405aRHP@0GVAU0`1QIfP406=ZJP@0IVa]101XKVl406YaLP@0K7=d0`1^MGH4071gN0@0LWUj101d
O7dF0?ooo`00503oool407MoP0@0N821101jPH8307^2P`@0O8>4101mQ8@407j5Q@@0OhJ61020QXH3
0827Q``0PHN71021QXH40825Q@@0OhB40`1mPX8407^0O`@0NGel101eNWT406icLP@0Jg5_0`1/LW04
06]`L0@0JFi]101XKVd406Q_KP@0JFm_0`1YKfh406Q^K@@0IFa/101TJV/4061WJ@@0GVEW101LHf@3
05UPHP@0EUaN101AEeP404eBD`@0A4U:100n@d@303/o@0@0>cm1100oA4D40497B@@0AT]<1019Ce04
04eBD`<0D5EF101CFEX405ILG@@0FEmP101LHV8405iTI@<0HFMX101SJVX406I/K@@0J6i_101ZLG84
06acM0<0KWEf101`MgP4079iNP@0M7am5P3oool001@0oooo101gOh0407R0P@@0NX620`1kPX<407b3
Q0@0OHB4101nQHD407n6QP@0P8J60`20QhL<0867Q`@0PHJ61020QHD407n4Q0<0OH:2101kP7l407Um
O0@0MGYi101^Lg8406]aK`<0K79`101[L70406U^K@@0J6i]101XKfh406U_K`<0JFm^101XKVd406E/
K0@0I6Y[101PIfT405iUI`@0G6=T0`1IH68405ILGP@0DEMH101=DU<404A9BP@0?T=40`0k?d0403/o
@@@0?dA51012AdT404I;C0@0BDm@101=DU<3051EEP@0DeUJ101FG5d405UOH0@0G69R101NI6D3065W
J0@0HfYZ101VK6d406Q^K`@0JW5b101/Lg@306ieMP@0L7Mh101bNGX407AlOAH0oooo000D0?ooo`@0
Mgio101hOh0407R0P@<0NH61101jPH8807^2P`@0O8>3101lPh@?07f4Q0@0OH>3101lPh<407b2PP<0
Nh60101iOgl407MmO@@0MGYj101bMgL406meM@<0K79c101WKVl406M]KP@0J6m_101WKVh406Q^KP<0
JFm_101XKfh406Q^K`@0IVe^101TJf`4069YJP@0H6MX0`1NIFL405]QH`@0DUUJ101?EEH404]AD`@0
CE9D0`1?E5D404mEEP@0DEMH101DFU/405ILG@@0F5iO101JHF8305eSI0@0GfEV101QIfP4069YJP@0
I6]/101VKFh306Q_K`@0JG1a101[LW<406acM0@0KWEf101_MgL3075hN@@0LWUj101cNg`407ElOAH0
oooo000D0?ooo`@0Mgio101hOh0407R0P@<0NH61101jPH8807^2P`@0O8>3101lPh@?07f4Q0@0OH>3
101lPh<407b2PP<0Nh60101iOgl407MmO@@0MGYj101bMgL406meM@<0K79c101WKVl406M]KP@0J6m_
101WKVh406Q^KP<0JFm_101XKfh406Q^K`@0IVe^101TJf`4069YJP@0H6MX0`1NIFL405]QH`@0DUUJ
101?EEH404]AD`@0CE9D0`1?E5D404mEEP@0DEMH101DFU/405ILG@@0F5iO101JHF8305eSI0@0GfEV
101QIfP4069YJP@0I6]/101VKFh306Q_K`@0JG1a101[LW<406acM0@0KWEf101_MgL3075hN@@0LWUj
101cNg`407ElOAH0oooo000D0?ooo`@0Mgio101hOh0407R0P@<0NH61101jPH8807^2P`@0O8>3101l
Ph@?07f4Q0@0OH>3101lPh<407b2PP<0Nh60101iOgl407MmO@@0MGYj101bMgL406meM@<0K79c101W
KVl406M]KP@0J6m_101WKVh406Q^KP<0JFm_101XKfh406Q^K`@0IVe^101TJf`4069YJP@0H6MX0`1N
IFL405]QH`@0DUUJ101?EEH404]AD`@0CE9D0`1?E5D404mEEP@0DEMH101DFU/405ILG@@0F5iO101J
HF8305eSI0@0GfEV101QIfP4069YJP@0I6]/101VKFh306Q_K`@0JG1a101[LW<406acM0@0KWEf101_
MgL3075hN@@0LWUj101cNg`407ElOAH0oooo000D0?ooo`@0Mgio101hOh0407R0P@<0NH61101jPH88
07^2P`@0O8>3101lPh@?07f4Q0@0OH>3101lPh<407b2PP<0Nh60101iOgl407MmO@@0MGYj101bMgL4
06meM@<0K79c101WKVl406M]KP@0J6m_101WKVh406Q^KP<0JFm_101XKfh406Q^K`@0IVe^101TJf`4
069YJP@0H6MX0`1NIFL405]QH`@0DUUJ101?EEH404]AD`@0CE9D0`1?E5D404mEEP@0DEMH101DFU/4
05ILG@@0F5iO101JHF8305eSI0@0GfEV101QIfP4069YJP@0I6]/101VKFh306Q_K`@0JG1a101[LW<4
06acM0@0KWEf101_MgL3075hN@@0LWUj101cNg`407ElOAH0oooo000D0?ooo`@0MWio101gOWl407Mo
P0L0N7n0101hP84<07V0P@L0NH61201jPH4807V0P@@0NH200`1hOgl407MnO`@0MWen101eO7`407Ak
N`@0LWUj0`1aN7T<06mfM`P0KWEf0`1]LgD406UaLP@0J71b101WKW0406I]K`@0IFa^101TJfd3069Z
J`@0H6MX101NIFH8065XJ@@0HVQY0`1RJFX406=ZJ`@0I6]/101UK6d406I]KP@0Ifi_101XKg0306U`
L@@0JW5b101[LW<406acM0@0KGAe101^MGH306mfM`@0L7Mh101`N7T4075iNP@0LWUj101cNW/307=k
O0@0M7am101eO7d407EmOQH0oooo000D0?ooo`@0MWio101gOWl407MoP0L0N7n0101hP84<07V0P@L0
NH61201jPH4807V0P@@0NH200`1hOgl407MnO`@0MWen101eO7`407AkN`@0LWUj0`1aN7T<06mfM`P0
KWEf0`1]LgD406UaLP@0J71b101WKW0406I]K`@0IFa^101TJfd3069ZJ`@0H6MX101NIFH8065XJ@@0
HVQY0`1RJFX406=ZJ`@0I6]/101UK6d406I]KP@0Ifi_101XKg0306U`L@@0JW5b101[LW<406acM0@0
KGAe101^MGH306mfM`@0L7Mh101`N7T4075iNP@0LWUj101cNW/307=kO0@0M7am101eO7d407EmOQH0
oooo000D0?ooo`@0MWio101gOWl407MoP0L0N7n0101hP84<07V0P@L0NH61201jPH4807V0P@@0NH20
0`1hOgl407MnO`@0MWen101eO7`407AkN`@0LWUj0`1aN7T<06mfM`P0KWEf0`1]LgD406UaLP@0J71b
101WKW0406I]K`@0IFa^101TJfd3069ZJ`@0H6MX101NIFH8065XJ@@0HVQY0`1RJFX406=ZJ`@0I6]/
101UK6d406I]KP@0Ifi_101XKg0306U`L@@0JW5b101[LW<406acM0@0KGAe101^MGH306mfM`@0L7Mh
101`N7T4075iNP@0LWUj101cNW/307=kO0@0M7am101eO7d407EmOQH0oooo000D0?ooo`@0MWio101g
OWl407MoP0L0N7n0101hP84<07V0P@L0NH61201jPH4807V0P@@0NH200`1hOgl407MnO`@0MWen101e
O7`407AkN`@0LWUj0`1aN7T<06mfM`P0KWEf0`1]LgD406UaLP@0J71b101WKW0406I]K`@0IFa^101T
Jfd3069ZJ`@0H6MX101NIFH8065XJ@@0HVQY0`1RJFX406=ZJ`@0I6]/101UK6d406I]KP@0Ifi_101X
Kg0306U`L@@0JW5b101[LW<406acM0@0KGAe101^MGH306mfM`@0L7Mh101`N7T4075iNP@0LWUj101c
NW/307=kO0@0M7am101eO7d407EmOQH0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo002K0?ooo`900000P`3oool009d0
oooo00=000000?ooo`3oool0P03oool007P0oooo0d0000030?ooo`03@000003oool0oooo0080oooo
00=000000?ooo`3oool02`3oool3@0000080oooo0T0000030?ooo`=000001@3oool00d000000oooo
0?ooo`1j0?ooo`00N03oool00d000000oooo0?ooo`030?ooo`07@000003oool0oooo0?oood000000
oooo@000000;0?ooo`06@000003oool0oooo@000003ooom00000103oool014000000oooo0?oood00
00220?ooo`00N@3oool00d000000oooo0?ooo`020?ooo`07@000003oool0oooo0?oood000000oooo
@000000;0?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0oooo@000
0880oooo001i0?ooo`03@000003oool0oooo00<0oooo00I000000?ooo`3ooom000000?oood00000<
0?ooo`=0000000@0oooo@0000400001000000`3oool3@0000880oooo001h0?ooo`03@000003ooom0
00000080oooo00=000000?oood0000000P3oool00d000000oooo@000000>0?ooo`03@000003oool0
oooo08X0oooo001i0?ooo`04@000003oool0oooo0?ooo`=000000`3oool00d000000oooo0?ooo`0<
0?ooo`900000S03oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(315) show
87.000000 12.812500 moveto
(deg) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(.) show
111.000000 12.812500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
192 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
405C6F405D70405D70405D71405E71415E71415E72415F72415F73425F73426073426074426074\
436175436175436176436276436276446277446377446377446378446378446378
446377446378446378446378446378446378446478446478456478456478446478446478446477\
446376446376446276446275436275436175436174436073436072425F71425E70
425E70425E71425F72425F72425F72425F72415E72415E72415E72415E71415E71405D71405D70\
405D70405C70405C6F
405D70405E71415E72415F7242607342607443617543617544627644637744637845647945657A\
46657A46667B47677C47687D48687E48697F486A7F486A80496A80496B80486A80
486A80496B80496B81496B80496B80496B80496C814A6C824A6D824A6D824A6D814A6D80496B7F\
496A7E486A7D48697C48687C48687B47677B47667A466578466476456274446071
445F71446174446275446276446276446175446175436175436174436074426073425F73415E72\
415E71405D70405C70
405D70415E71415F7342607443617544617644637745647946657A46667B47677D48687E48697F\
496A804A6B814A6C824B6D844C6E854C70874D70884D71894D72894E728A4E738A
4E738A4D72894D72894D72884D72884D72884D72884E72874E73874D73874D73874C72864C7084\
4B6F834B6E824B6F824C6F824C6E824C6D814B6B7F4A6A7D49687B486678466374
466274476577476579476679476579466579466579456478456377446276446275436174426073\
415F72415E71405D70
405D70415E7242607343617544627745647846657A47667B48677D49697E4A6A804B6C824B6D84\
4C6F864D70874E72894F738B50758D51768F517890527992537A93537A93527A93
527A92527A9152799152799152799051788F51778D4F768B4F758A4F75894F75894E75894E7589\
4E75894E75884E74884F74884F73874F72864E70844D6E824C6D804B6B7E4A697C
4A697C4A697D4A6A7E4A6A7E4A697E49687D48677C48667B47667A466579456378446276436175\
426073415E72405D70
405D71425F7343607444627645647846667B48677D49697E4A6B804B6C834C6E854D70874E7289\
50748B51758E527790537992547B94557D97567F9957819B58829C58829D58829C
57819B57819B57809A568098567F97567F95557E94557C92547B90547A8F53798F52798E52798E\
52798E52788E51788D52798D52788C52768B51768A5174895072864F6F834E6E82
4E6E824E6F834E6E834D6E834C6D824C6C814B6B804A6A7F49687D48677C47667A456478446276\
436175425F73415D71
415E7142607344627645637846667A48687D496A7F4B6C824C6E844D70874F728950748C51768E\
537891547B94567D96577F9958829C5A849F5B86A25D89A55E8BA75E8CA85D8BA7
5C89A45C88A25B87A15B86A05B869E5B859D5A859C5A859B59839A588297588096588096578096\
578096577F96577F95567E94567E95567D93567B91567A9054788D537488527387
5274895274895173895073884F71874E70864D6E844C6D824B6B8149697E48687C47667A456478\
446276426074415E71
415E7243607444637746657A48677D496A7F4B6C824D6E854E718850738B51768E537891557B94\
567D9758809A59829D5B85A05D88A45E8BA7608EAB6291AF6495B36597B66395B3
6190AD608FAA608EA8608DA75F8CA65F8CA55F8CA45F8CA35F8BA35E8BA25E8AA15D89A05D89A0\
5D889F5D879E5C869D5C859D5B859C5B849C5B839A5A8097587E95577C91577A90
567A91567A9155799054788E53768C51748A5072884E70854D6E834B6C814A6A7E48687C46667A\
456377436074415E72
415E7243617545647847677C49697F4B6C824D6E854E718850748B52768F547992567C95587F99\
59829C5B85A05D88A35F8BA7618EAB6391AF6595B4689AB96CA0C16B9FC06698B7
6596B36494B06494AE6493AE6493AD6493AD6494AD6494AD6495AD6495AD6495AD6494AC6493AA\
6492A96390A8638EA7628DA6618CA4608AA35F89A25E879F5D859D5C839B5B829A
5B829A5A8098597F96577D94567B9254788F53768C5173894F71864D6E844B6B8149697D47667A\
456377436175415E72
415F7244627646657A48687D4A6B814C6E844E718850748B52778F547A92577D9659809A5B839E\
5D86A25F8AA6618DAA6391AE6594B26798B7699CBC6CA1C26EA4C46BA0C0689BBA
689AB8689AB76899B6699AB5699AB5699AB5699AB4699CB56A9DB66A9FB76BA0B86BA0B86B9EB6\
6A9BB36A98B16996AF6895AD6693AC6691AB6490AA638FA9638EA8628DA7608BA5
5F89A35E87A15D859E5B829B597F97577C94557A9153778D51748A4F71864D6E834B6A8048677C\
466479446276425F72
425F7344627746667A49697F4B6D834E708650738A52768E557A92577D9659809A5B849E5E87A3\
608BA7628FAC6492B06796B5699ABA6B9EBF6DA2C36FA5C9699FC26599BB699DBD
6B9FBD6C9FBE6DA0BD6DA0BD6EA0BC6EA1BC6EA2BC6EA3BC6FA5BE70A6BF70A6BF70A6BE70A5BE\
70A3BC70A1BA6F9EB86E9CB66C9AB46A98B26996B06895B06795B16796B26695B2
6491AD628EA9618BA55F88A15D849D5A8199587D95567A9153768D5173894E70854C6C8249697E\
47667A446276425F73
425F7345637747677C4A6A804C6E844F728852758D547991577D9559809A5C849E5E88A3618CA8\
6390AC6694B16898B66B9CBB6DA0C06FA4C673AACE6DA4C7669BBD699EBF6CA1C1
6EA3C270A4C471A5C572A6C472A7C473A7C373A8C373A9C374ABC574ADC675AEC675AEC575ADC4\
75ABC375A8C174A6BF73A3BD72A0BB709DB86E9CB76C9BB76C9CB96C9EBC6B9DBC
6999B76795B26591AD638DA86089A35E859E5B819A587D9556799153768C5072884D6E844A6B80\
48677B456377425F73
42607445647848677C4B6B814E6F8651738B53778F567B94597F995C839E5E88A2618CA76490AC\
6794B26998B76C9DBC6FA1C271A5C773AACD6EA5C86AA0C36CA2C56EA3C570A5C6
72A7C874AACA76ACCB77ADCB77ADCB78ADCA78AEC978AEC978ACC678AAC579AAC579A9C379AAC3\
7AACC57AACC57AAAC378A7C176A4BF74A2BD72A0BC709FBB6F9FBC6FA1BF6FA3C3
6EA2C26C9CBA6997B46793AE648EA9618AA35E859E5B8199587C9455788F52748A4F6F854C6B80\
49687C456478426073
42607446647949687E4C6D834F718852768D557A92587E975B829C5E87A1618BA6648FAC6794B1\
6A98B76D9DBC70A2C273A7C875ABCE79B1D577AFD471A8CC71A7CA72A8CA74A9CA
76ABCC79AECF7BB1D17CB2D07DB2CF7DB2CF7DB1CE7CAFCB7CA9C57CA5C07CA1BD7BA0BB7DA4BF\
7EA9C47FABC67EACC67DABC57BA8C379A6C277A4C075A2BF73A2BF73A3C173A5C4
72A5C570A3C26E9EBB6B98B56893AE658EA86189A25E849C5A7F97577A9153768C5071874D6D82\
49687D466478436074
43607446657A4A6A7F4D6E8450738A54788F577C945A819A5D859F618AA5648EAA6793B06A98B6\
6D9DBC70A2C274A7C877ACCE7BB2D677AFD472AACE74AACD75ABCD76ABCC78ACCC
7AAFCF7DB2D380B5D581B7D582B7D484B7D382AFCB7EA5C17CA1BB7A9BB57A9DB67DA2BC7FA0BC\
81A1BB83A6C184ADC882AEC97FACC77CA9C47AA7C278A4C177A4C276A5C376A7C6
77AACA76A9C973A4C2709EBB6C98B46892AD648DA66087A05D829A597D9455788E5173894E6E83\
4A697E466579436074
43617547667A4A6B804E708652748B557991597E975C839D6088A2638DA86692AE6A97B46D9CBA\
70A1C174A7C778ACCE7BB1D47EB5D97BB2D676ACCF77ACCF78ADCF79ADCE7BAECF
7DB0D07FB3D282B5D486B8D785B2D07EA4C07B9FBA7D9EB97D9CB77D9EB97D9DB97D9BB57C9BB4\
7E9EB781A3BE86A9C487AEC983AEC980ACC67DA9C57BA7C37AA6C37AA7C57AAAC8
7AABCA7AABCA79A9C775A4C1709DB96C96B16790AA638AA35F849C5B7F9657799053748A4F6F85\
4B6A7F47657A436174
43617547667B4B6B814F708753768D577B935B80995E86A0628BA66590AC6995B26C9AB8709FBE\
73A5C578ABCD7CB2D580B7DA7FB7DA7BB2D579AED17AAED07BADCE7CADCE7EAFCF
80B0D082B0CF82AFCD81ACCB80AAC87FA9C780A8C681A7C581A7C482A8C682A8C582A8C481A8C4\
7FA5C27DA1BD7DA2BC83A9C287B0CA85B0CA82ACC87FAAC67EA9C57DAAC77DABC9
7DADCC7DAECE7CADCD7AAAC775A2BE6F9AB56A93AD658DA661869F5C8198587B9254768C507086\
4C6B8047667A436175
44617548677C4C6C8250728855788F597D965D839C6188A2648EA96893AF6C98B56F9DBC72A3C2\
76A8C97AAFD182B9DD87C0E67EB6DB77ADD07AAED07CAFD07EB0D07FAFCF80AFCE
81AECD80AAC77EA2BF7A9BB77B9CB880A3BF82A6C384A9C785ADCA86AECB86AECB86B0CE86B0CD\
85ACCA83AAC781A9C480A8C385ADC787B0CB84AEC982ACC881ACC880ACC980ADCB
80AECC7FAFCE7EAECD7BAAC878A4C1729DB86D95B0688FA86388A15E829A5A7C9355778D517187\
4C6C8148667B446175
44627649687C4D6E8352738A5679915B80985F859F638BA56791AC6B96B36E9BB972A1BF75A6C5\
78AACB7BB0D27FB5D87EB4D879ADD179ABCE7CAED07FB0CF81B0CE82AFCE83AFCD
84AECB84ACC983A9C581A4C082A2BE83A2BF84A3BF85A4C186A5C287A6C487A7C488A6C488A6C4\
87A9C786ABC784AAC682A9C681A8C484ABC686AEC985AEC984ADC983AECA83AECC
83B0CD83B1D086B6D582B1D07AA6C3759FBB6F97B26A91AA658AA360849C5B7E9556788E527288\
4D6C8148677B446175
44627649687D4E6F8453758B587B935C819A6187A1658EA86A94AF6E99B6719FBD75A4C377A9C9\
79ACCE79AED072A7CA6CA1C573A7CA7CAED080B0D083AFCF84B0CE85B0CD86AECC
87ADCA87ACC887ACC888ABC888A9C689A8C589A9C58AA9C68BABC78CABC88CABC88CABC88CABC8\
8CABC88CA9C789A6C485A3BF82A0BB82A1BC85A7C287ACC887AEC986AECA86AFCB
85AFCD85B1CE85B0CD83AECB7DA8C577A0BB7199B36C92AC668CA461859D5C7F9657798F537389\
4E6D8249677C446275
4562764A697E4F708554768D597D955E839C638AA46890AB6D97B3719DBA75A3C178A8C87BADCE\
7CB0D37CB2D67AB0D57AAED07DAFD082B2D285B3D287B2D088B1CE8AB0CD8AB0CC
8AAFCA8AAECA8CB0CC8DB1CE8DB0CC8EAECA8EAECA8FAECA90AECA90AECB91B0CC91B1CD92B0CC\
91AFCB90AECA8DACC78BA9C589A7C287A6C287A8C288ABC589AEC889AFCA88B0CB
87B0CC87B0CD87B1CE84AECA7EA8C379A1BC739AB56D93AD688DA563869E5E8097587A90537489\
4E6E8349687C446275
4563774B6A7F50718756788F5B7F9661869E668DA66B94AE709AB675A1BE79A7C57DADCC80B2D3\
82B7D983B9DC84B9DD85BADD87B9DA88B8D68AB7D58CB6D38DB5D18EB4D08FB3CF
8FB3CD8FB2CD90B2CE91B4D092B5D192B4CF93B4CF94B4D094B3CF95B3CE95B3CE96B4CF95B4CE\
94B2CD92B1CB91AEC88EABC58CA9C38BA9C38AAAC38BACC68CAFC88BAFC989AFC9
88AFCA86AFCA86AFCB86B0CD81ABC87BA3BF759CB66F95AE698EA664879F5F8198597B9154748A\
4F6E834A687C456276
4563774B6B7F5172885779905D81986388A1698FA96E97B1749EBA79A5C27DACCA81B2D285B8D9\
88BDE08AC0E48CC1E38DC0E28CBEDE8DBDDC8FBCD991BAD792BAD693B9D594B8D4
94B6D294B5D195B5D196B7D397B8D497B7D397B6D198B6D098B6D098B6D099B6CF99B5CF98B5CE\
97B4CD96B3CB94B0C992AEC690ACC28EAAC18EAAC28FADC68FAFC88DAFC88BAFC8
89AEC986ADC883ACC884AFCC83AECA7CA5C0769DB77095AE6B8FA765889F6082985B7B9155758A\
506F834A687C456276
4664784C6B80527389597B925F839A658AA36C92AC729AB577A2BE7DA9C682B1CF87B8D88BBFE0\
8FC5E692C8EA94C9EB94C5E693C2E094C0DE95BFDD96BFDC97BEDA98BEDA99BED9
9ABCD79ABBD59ABAD49BBAD49BBAD69CBBD69CBBD69CBAD59DBAD49DBAD49EBBD49EBAD39DB9D1\
9CB6CF9AB4CD98B3CB97B1C894AEC593ADC393AEC593AFC792B0C890B0C98EB0C8
8AAEC785ABC57DA5C179A4C17FAAC67EA7C1769CB67196AE6C8FA76789A06182995C7C9156758A\
506F844B697D456276
4664784D6C8154748A5A7C9361859C688DA56E95AF759DB87BA6C182AECB88B6D48DBEDE92C7E8\
97CEF09AD2F39BCFEE9BC9E79AC5E49AC3E19BC3E19CC4E09DC4E19EC4E09FC4DF
A0C3DEA0C2DCA0C0DA9FBED79FBDD7A0BED8A0BFD9A1BFD9A1C0D9A2C0D9A2BFD8A2BED6A2BDD5\
A1BBD3A0B9D09EB6CC9BB3C99AB1C899B2C898B3C997B4CA96B4CB94B4CB91B2CA
8DB1C988ADC682A8C07AA1BA7499B37499B2769AB37296AE6D90A76889A06283995D7C9257768B\
516F844B697D456276
4664784E6D8255758B5C7E9463869E6A8FA87298B179A1BB80AAC587B2CF8DBBD994C4E399CCEC\
9ED2F1A1D2F1A1CFEE9FCBEA9FC9E7A0C8E4A0C8E4A1C9E5A3C9E5A4CAE6A5CAE5
A6CAE5A6C9E3A5C7E0A5C5DDA5C3DCA5C2DAA4C1D9A4C1D8A5C1D9A5C1D9A6C1D8A6C0D8A6BFD6\
A5BED4A3BBD0A1B7CC9FB6CB9FB6CC9FB7CC9EB7CD9DB8CE9BB7CD99B7CD96B6CB
92B3CA8EB0C789ADC583A8C17EA3BC7BA0B8789CB47497AE6F91A76A8AA06484995E7D9258768B\
5270844C697D456276
4765794E6D8256768C5E7F966588A06D91AA759BB47CA4BE84ADC98CB7D393C1DF9BCBEBA2D2F3\
A7D4F5A9D4F3A8D1F0A6CFECA5CDEAA5CCE8A6CCE8A7CDE9A8CFEAAAD0ECABD1EC
ACD1EAACD0E9ACCEE6ABCBE4AAC9E1A9C7DFA9C5DDA9C4DBA9C4DAA9C4DAA9C3DAA9C2D8A9C1D7\
A8BFD4A7BDD2A6BCD1A6BCD1A5BCD1A5BDD2A4BDD2A3BCD1A1BBD09EBAD09CB8CE
98B6CD94B4CA8FB1C88AADC587ACC483A8C07DA0B77799B07192A86B8BA165859A5F7E9259778B\
5270844C697D466376
4765794F6E8357778D5F8197678AA17094AC789DB680A7C189B1CC91BBD79AC6E3A3D1F0ACDBFA\
B4DFFDB5DDF9B1D7F3ADD3EEABD1ECAAD0ECABD1ECACD1EDADD2EEAFD4EEB1D5EF
B3D6EFB3D5EDB2D3EAB1D0E7B0CDE5AECBE2ADC8DFACC7DDACC5DCADC4DBADC4DAADC4DAADC3D9\
ACC2D7ACC2D6ACC2D5ACC2D5ADC2D6ACC2D6ABC1D5A9C0D4A6BED2A4BCD1A1BBD0
9EBACF9AB8CE97B7CE92B4CC8DB1CA87ACC481A3B97A9BB17494A96D8CA167859A607E935A778B\
5370844D6A7D466376
476579506F8358788D618298698CA27296AD7BA0B984AAC48DB5CF96BFDB9FCAE6A8D4F1B3DEFA\
B9E1FCBAE0FAB7DBF5B2D6F0B0D4EEAFD3EDAFD3EDB0D3EEB2D5EEB5D7EFB7D8F0
B9D9F1B9DAF1B9DAF1B7D7EEB5D3EAB2CFE5B0CBE1AFC8DEAFC7DDB0C7DCB0C7DCB1C7DBB1C6DB\
B1C6DAB2C6DAB3C7DAB4C8DBB4C8DBB3C8DBB1C7DAAFC5D8ADC2D6AAC0D4A7BFD3
A4BDD1A1BCD19EBAD09AB9CF94B5CB8CADC385A5BA7E9CB27795AA708DA269869A627F935B788C\
5471844D6A7D466376
486579506F8359798E6283996B8DA37497AF7EA2BB88AEC792B9D39BC4DEA4CEEAACD5F0B2D9F3\
B8DDF7BBDEF7B9DBF4B5D7F1B3D5EFB2D4EDB2D3ECB4D5EEB7D8F1BBDCF5BFDFF8
C1E0F8C1DFF6BEDDF3BCDAF0B9D7EDB6D1E7B3CCE1B1C9DDB1C7DBB1C7DBB2C7DCB3C7DCB5C8DC\
B6C9DCB8CBDDBACCDEBACDDFBACCDFB9CCDEB7CADDB4C8DAB1C5D8AFC4D7ACC2D5
A9C0D3A7BFD2A5BFD2A1BED29AB8CD91AEC389A6BA819EB27996AA728EA26A879A637F935C788C\
5571844D6A7D466376
486679516F845A798E6383996C8EA47699B081A5BC8CB1C997BDD6A1C9E3AAD3EEB2DAF4BBDFF7\
C0E1F8BEDEF6BADAF2B7D7EFB5D5EDB3D3EBB3D2EAB3D2E9B5D3EAB8D6ECBDD9EE
C3DDF2C4DDF3C1DBF1BED9EEBBD8EDB7D2E7B4CBDFB2C7DBB2C6D9B3C6D9B4C7DAB6C8DBB8CADD\
BACCDEBBCCDEBCCEDFBED0E1C0D2E3BFD1E2BCCEE0B9CBDDB6C9DBB4C7D9B2C5D7
AFC3D5ACC1D3A9BFD1A3BCCD9CB6C894AFC18CA6B9849FB27C97AA748FA26C879A6480935D788B\
5571844E6A7D476376
486679516F845A798E6384996D8EA4789AB083A6BD8FB4CC9CC2DBA8CFE9B1D9F2B7DCF6B9DBF3\
BADBF1BBDBF1B9D8EFB7D5EBB6D3EAB5D2E8B4D1E6B3CFE3B1CCE0AFCADEB0CBDF
B4CDE2B7CEE3B8CEE1B6CBDEB2C7DAB1C5D8B2C6D9B2C5D7B3C4D6B3C5D7B5C6D8B7C9DABACDDD\
BDCFE0C0D0E1C4D4E5C7D7E7C7D6E6C4D3E4C1D1E2BECFE0BACCDDB7C9DAB5C7D8
B3C6D6B2C5D5B0C3D3AABDCDA1B5C598AEBF8FA7B9879FB17E97AA7690A26D889A6580935E798B\
5671844E6A7D476376
48667A516F845A798E6483986E8EA4789AB084A6BD92B5CDA2C7DFB4DCF6BEE5FFBEE0F8BDDCF3\
BCDAEFBBD8EDBAD6EBB8D4E9B6D2E7B5D1E5B5D0E4B3CDE1B1C9DBAEC6D8AAC2D4
A5BCCFA5BBCEA8BDD1ABBED1AEBFD1B0C2D3B1C3D5B2C4D5B3C4D5B3C4D4B3C4D4B4C4D4B5C3D3\
B8C5D4BFCCD9C6D3E0C8D5E3C6D4E2C8D5E4C6D5E3C1D1E1BDCEDEB9CAD9B7C7D7
B7C7D6B7C7D6B6C5D4B1C1D0A7B9C89CB0C193A9BA89A1B28098AA7790A26F889A6680925E798B\
5671844F6A7D476376
486579516E825A788C6382966D8DA27898AE84A5BB92B4CBA6CAE3B4D8F1BFE0F7C6E5FBC5E1F6\
BFDBF0BAD6EBB7D3E8B6D2E6B6D0E3B5D0E2B5D0E2B4CDDEB2C8D9AFC4D4ACC0CF
AABDCDA9BBCBA9BAC9ABBBCBADBDCCB0BFCEB1C1D1B2C2D2B3C3D2B3C2D1B3C1D0B3C0CFB2BFCF\
B2C0CFB2C1D0B4C3D1B8C6D4BBC9D7BBCAD8BBCAD8B9C8D6B8C7D4B8C7D5B9C7D5
BAC7D5BBC9D7BAC8D5B3C2D0AABDCCA1B5C596ABBB8CA2B28299AA7990A17088996780925F788A\
5771834F6A7C476376
486477516D8159778B6380956C8B9F7795AA82A1B78EAEC49CBCD3A8C7DEB2CEE4BAD5E9BDD7EB\
BAD4E9B6D2E5B6D1E4B5CFE2B5CDE0B3C9DBB2C7D7B4C9DAB5CADAB4C7D7B3C4D2
B1C0CEB0BECCAFBDCBB0BECBB0BECBB0BDCBB1BFCEB2C2D0B3C2D1B3C1CFB3C1CDB4C1CDB4C1CE\
B4C0CEB1BECCABB9C7A7B6C5ABBAC8ADBDCBB0BECCB3C1CEB7C4D0B9C5D1BAC6D2
BCC8D4BDC8D4BAC6D2B3C1CEABBCCAA3B5C499ACBB8EA3B28499A97A90A17088986780915F788A\
5771834F6A7C476375
486477506D80597589617F936B889C7492A67E9CB189A7BC94B1C69FBCD1AAC4D8B0C9DDB3CCE0\
B4CCE0B5CCDFB5CDE0B6CEE0B4CBDCB3C7D8B0C3D2AEBECCADBCC9ACBBC7A9B6C2
A5B1BDA5AFBAA6B0BBA8B1BCABB5C0AFBAC6B2BECBB3C1CEB4C2CEB4C0CCB3BFCAB5C1CBB7C3CD\
B7C3CEB5C1CDB2BECBAFBCC8AEBAC6AFBAC6B2BDC8B6C1CBB9C4CDBAC6CFBCC7D1
BEC9D3BFC9D3BBC5CFB1BDC9ABB9C5A6B6C49CAEBD90A3B28599A87A8F9F708797677F905F7789\
5770824F697B476275
4764774F6C7F577488607C90688598718EA17A97AA839FB38CA7BB95B0C39EB8CBA5BED1ABC3D6\
AEC6D9B1C8DAB4CBDDB6CCDDB5CADBB3C7D7B2C3D1AFBECBACB7C3A8B1BCA5ADB8
A4AAB3A4A9B1A5A9B1A8ADB6ADB4BFB1BBC6B4BFCBB6C1CEB6C1CDB4BFCBB2BBC7AFB8C2B0B9C2\
B6C0C7BAC4CDBAC4CDB7C1CBB6BFCAB5BFCAB7C1CAB9C3CCBBC5CEBCC5CEBDC7CF
C0C9D1BEC8D0B8C2CBB5BFC9B1BDC8ADBCC9A2B3C191A3B18598A67A8E9D708595677D8E5E7687\
566F814E697B476275
4763764E6A7E5672855E798C6681946E899C7691A47E99AB86A0B28EA6B895ADBF9CB4C6A2BACB\
A7BFD0ADC4D5B1C8D9B4CADAB5CAD9B5C8D7B3C5D3B2C1CEB0BCC8AEB8C2ACB4BE
ACB3BCACB2BAADB3BBAFB6BEB2BAC3B5BEC9B7C2CDB8C3CFB8C3CFB6C1CCB4BEC8B0BAC3ADB5BD\
AAB3BBACB6BEB3BCC4BAC2CABCC4CCBCC4CCBCC4CCBCC4CCBBC3CBBBC3CABDC5CC
BFC5CDBCC3CBB8C0C8B8BFC7B4BCC5A9B4BF9CAAB78F9FAD8395A3788C9A6E8392667B8C5D7585\
556E7F4E687A476274
4662764D697C5570835C778A637E906B8597728C9E7993A58099AA869EB08DA5B695ACBD9BB2C3\
A2B9C9A9BFCFB1C6D6B6CADAB7CBDAB6C9D8B5C7D5B5C4D1B4C2CEB3BFCAB2BDC7
B2BBC4B3BBC4B4BCC5B6BEC7B8C1CABAC3CDBBC6D0BCC7D1BBC6D1BAC5CFB8C3CCB5BFC8B2BBC4\
AFB7C0ACB4BDAAB3BBABB3BBAFB7BFB2BAC2B3BBC2B4BBC2B8BEC5BCC1C8BEC2C9
BDC1C8B9BEC5B5BAC2B2B6BFAEB2BAA4ACB698A4B08C9BA880919F7688966C808F6479895C7383\
546D7E4D6779466174
4662754C687B536E805A7486607A8C6781936E8798758D9E7B93A58299AB889EAF8EA4B496ACBC\
9EB4C4A7BCCCB0C5D3B6CAD9B8CCDAB8CBD9B8C9D6B8C8D4B8C6D1B8C5D0B8C4CF
B8C3CDB9C3CDBAC4CEBCC6CFBEC8D2BFCAD4C0CCD5C0CCD6C0CBD5BFC9D3BDC7D0BBC5CEB8C1CA\
B5BEC6B2BBC2B0B7BFAEB5BCADB4BBAFB5BBB2B7BDB5BBC0B9BDC3BCBFC5BDC1C7
BBBEC4B5B8BEAFB3B9A9AEB5A4A9B19DA5AF94A1AC8998A47C8C99728391697C8B6176855A7080\
536B7C4C6677466173
4561744B6779516C7E5771835E7788647D8E6A8293708898778D9D7D92A18297A6899EAC92A5B4\
9CAEBCA5B8C6AEC1CEB6C9D6B9CCDAB9CCD9BACBD8BBCBD7BBCBD6BCCAD5BDCAD5
BECBD5BFCBD5C1CCD6C2CDD7C4CFD8C5D0DAC6D1DBC6D1DAC5D0D9C4CFD8C3CDD5C1CAD2BEC7CE\
BCC3CBB9C0C7B6BDC3B5BBC1B5BAC0B5BABFB7BBC0BABCC1BCBDC3BEBEC3BEBEC2
BABABEB1B2B7AAACB1A3A6AC9CA1A8949BA38C96A0818E997685916D7D8A6577855E7281586D7D\
5169794B6476456072
4560734A6577506A7C556F805B7485607889667D8D6C8292718796778C9A7D919F8396A48B9EAB\
94A7B49FB0BDA8B9C5B2C3CEB8CAD6BBCDD9BCCEDABECFDBBFD0DCC1D0DBC2D0DA
C4D0DAC5D2DBC7D3DCC8D4DDCAD5DECBD6DFCCD7E0CCD7DFCBD6DECAD4DCC9D2D9C7CFD6C5CCD3\
C2C9CFBFC6CBBDC3C8BBC0C5BBBFC3BBBEC2BBBEC2BCBEC2BCBEC2BDBDC1BABABD
B1B2B6AAABAFA2A4A9999CA190949A878D947F868F76808A6E7B8667768361727F5B6E7C556A7A\
4F66774A6374455F72
4460724964764E6879536C7D5870805D7484627988687D8C6D818F738593788A977E909D8698A4\
90A1AD9AABB6A4B5C0ACBEC9B5C6D2BBCDD8BFCFDBC1D1DDC3D3DFC5D5E0C7D6E1
C9D7E1CBD8E2CDD9E2CFDBE4D0DCE5D1DDE5D1DDE5D2DCE4D2DBE3D0DAE0CFD7DECCD5DBCAD1D7\
C8CED2C5CACFC3C8CCC2C5C9C0C3C7C0C1C5BFC0C3BEBFC2BFBEC1BCBBBDB5B4B7
ACABAFA3A2A698999E8E909684878E7A7F866E747B68707866717B616F7B5C6D79576A78526776\
4D6474496173445F71
445F724862744C667751697A556C7C59707F5E7482637886697C8A6E818D7485927A8B9782929D\
8A9AA494A3ADA1AEB8ABB9C3B5C3CCBCCBD5C1D0DAC4D3DEC7D6E1CAD9E3CCDBE6
CFDDE8D1DFE9D3E1EAD5E2EBD7E3ECD8E4ECD8E4EBD8E3E9D7E0E7D6DEE4D4DBE1D2D8DDD0D5DA\
CDD1D6CBCFD2C9CCCFC7C8CBC5C6C8C3C3C5C2C1C3C1BFC0BEBBBDB8B5B7AFADAE
A4A2A599989B8E8E9283858A797C816F737A666D74616A725E69735B69745767745366734F6473\
4B6272476071435E70
435E714761734A64754E6676526978566B7A5A6E7C5D707D6274816779866E7F8A75848F7B8A94\
85939D909EA79CA9B2A9B4BDB5C1C9BECBD4C4D2DBC8D6E0CBDAE4CEDDE8D2E1EC
D5E4EFD7E6F1DAE8F2DCEAF3DEEAF3DFEAF2DFEAF0DFE9EFDEE7ECDDE4E9DAE0E5D8DCE0D5D9DC\
D2D5D9CFD1D4CDCED0CACBCDC8C8C9C7C5C6C6C2C3C3BEBFBEB9B9B6B1B1AAA6A6
9E9A9C9190918585887A7C7F6F717562676C5C61685A626A58626B55626D53626E50626F4C616F\
49606F465E6F435D6F
425E704660714961724C63734F6574526775556875586A765B6C7861707B6876816F7D8777858E\
818E978C98A198A3ABA6B0B7B4BEC5BFCAD1C6D2DACBD8E1CFDDE7D3E2ECD7E6F0
DAE9F4DEECF6E0EEF7E2EFF6E4F0F6E6F1F7E7F1F6E6EFF3E5ECEFE3E8EBE0E5E7DDE1E4DADDE0\
D7D9DBD4D5D6D1D0D1CECCCDCCC9C9C9C5C5C6C2C1C2BDBBBBB4B3AFA9A8A29D9C
9490918685867A7A7C6D6F726063675355594F5358525960515B64505D674E5D694C5E6B4A5E6C\
475D6D455D6E425C6E
425D6F445E70475F704960704C61704E627050636F52636F55646E596770616E7769757E717D86\
7B868E879198949DA3A2ABB0B0B8BEBDC6CBC8D2D9CFDAE2D4E0E8D8E5EEDDEAF2
E1EEF5E5F1F8E8F3FAEAF5FBECF6FBEEF6FBEEF5F9EDF3F6ECF0F3EAEDEFE6E9EBE3E5E6E0E0E1\
DCDCDCD9D7D7D5D2D2D2CDCDCEC9C8CAC4C2C5BEBCBEB6B4B4ACAAA7A09E999392
8A86867D7A7B6F6E7062636657595D4F52574C51574C535A4C565F4B58624A5965495A67475B69\
455B6B435C6C415C6E
415C6F435D6E455D6E475E6D495E6C4A5E6B4C5D694D5D674E5C66525F6759656C626D746B757C\
757E8480898F8C959A99A1A6A7AFB4B8BFC4C6CED2D0DADFD7E3E8DDE9EFE2EEF4
E7F3F8EBF6FAEEF8FCF1FAFEF4FBFEF5FBFDF6FAFCF4F8F9F2F4F5EFF1F1ECECEDE8E7E7E4E2E2\
E0DDDDDCD8D7D8D3D1D4CDCBCFC8C5C9C1BFC1B8B5B7AEAAAAA19E9B93918D8785
807B7A726F6F6462635555584A4C4F46494D454A50464D5546515946535D465561465764455867\
435A69425A6B415B6D
415C6E425C6D445B6C455B6A465A6947596647586447566046525A48545A515B625A636A626B71\
6B747A767F85838B8F90979B9EA4A7AEB3B5BFC4C6CED4D6D9E1E4E0E9ECE7F0F3
EDF6F8F2FAFCF5FDFEF8FEFFFAFFFFFDFFFFFDFEFEFBFBFBF8F7F6F5F2F1F1EEEDEDE9E8E8E3E2\
E3DDDCDED8D5D9D1CED3CAC7CCC3BFC4BBB6B9B0ABABA29E9D94918E8784807977
716C6C63606055535449484A3D3C3D393A3D3E434840484F424C55424F5943525E435461425665\
42586741596A405B6D
405B6D415B6C425A6A43596843576543566243535F42505A404C54424B52495258525A605A6268\
656B706F75797A8085868C9092989AA0A5A7B0B5B6C1C5C6CFD3D4DCE1E2E7ECED
F0F4F5F6FBFBF9FEFEFCFFFEFFFFFEFFFEFCFFFCF9FEFAF7FCF7F4F9F2F0F4EDEAF0E7E4ECE3DF\
E6DDD9DFD5D1D8CDC8D0C5C0C6BCB6BBB0AAADA29D9F94908F8683807875716B69
625D5C5350504543453B3A3C35353836373B393D433B434A3D48513F4C56404F5B40525F405463\
405766405869405A6C
405B6D405A6B41586841576641556340535F40505B3F4C563D48503C454A3F474C474F5450575C\
596064646A6E6F74787A7F82878C8E94999BA2A6A8B1B5B6C0C3C4CFD1D1DBDDDD
E5E7E7EDEFEDF3F4F1F7F7F3F9F7F2FAF5F0FAF3EEFAF2ECFAF0EAF7EDE6F4E8E2EFE3DDE9DCD6\
E3D5CFDCCEC8D2C5BFC8BBB5BCAFA9AEA19C9F938E8F85817E76736F68655F5A58
504C4B413E3F3534342C2B2C2A2A2D30323634393F373F473A454D3C49533D4D593E505D3F5361\
3F55653F58683F5A6C
3F5A6C3F596A3F57673F55643F53603E505D3D4D583B495339444C363E45373E433E454A474E52\
4F565A575D6162676A6F73767C80828A8E8F989C9DA6AAAAB3B7B6BFC2C2CBCCCB
D5D4D2DDDBD8E4E1DDE9E5E1EBE6E1EDE6E1EFE6E0F0E5DEF0E3DBEEE1D9EBDED5E6D8D0E1D2CA\
D9CBC3D1C2BBC7B9B2BBADA6AD9F9A9F928D8F847F7E75716D66635D57554D4948
3D3A39302E2D2523241F1D1E2322242B2E3230363C343C4437424B3947513B4B573C4F5C3D5260\
3E54643F57683F596B
3F5A6C3F58693E56663E54633D515F3C4E5B3A4A56384650364149323B4230363B34393D3D4246\
454A4E4E5356585D5F65696B7175777E81838B8E8F97999AA4A5A4B0B0AEB9B9B7
C1C0BEC8C6C3CFCCC8D5D1CCD9D4CFDAD5CFDCD4CEDCD2CCDCD0C9D9CDC5D7C9C1D3C5BDCEBFB7\
C6B7AFBCAEA7B2A49EA79994998D888A7F7B7A716D6B63605B55534B46453B3737
2C292A201E1E161313171516212225272B302D343A313B4334404A374550394A563B4D5B3C515F\
3D54643E57683F596B
3F5A6C3E58693E55653D53623C505E3A4C5938495436444E333F473039402C33382C323632383B\
3B3F4244484B4F5355595C5F6366686F72737C7E7F898B8C9596969F9F9EA7A7A5
AFAEACB7B5B1BCB9B6C0BDB9C4BFBAC6C0BAC7BFB9C6BDB7C5BBB4C3B8B1C0B4ADBCAFA8B5A9A1\
AEA19AA599939C908A918680847A75756D69665F5C57514F474342373434282627
1C1A1B110D0D100C0D18181A202226262B312B333A2F3A42333F493544503849553A4D5A3B505F\
3C53633D56673E596B
3F5A6C3E57683D55653C52613B4F5D394B5837475334434D313D462E373F292F35262A2E292C2F\
303437393C3F4145474C4F51575A5B6265666D6F70797A7A8384848C8C8C949493
9B9B99A1A19FA7A5A2ABA8A4AEAAA6AFAAA6AFAAA4AEA8A2ACA69FAAA29CA69E97A198929A918B\
9389848C827D837A7579716D6E6663615A58524D4B423F3E3431312726261C1A1B
0F0C0C0C0909131214191B1E202429252C322A333B2E3A43323F4A344450374956394D5B3B505F\
3C53633D56673E596B
3E596C3E57683C54653B52613A4F5D384B5836475333424D303D462C363E272E352024281D1F22\
2426292D303236383A3F4243484B4C5154545A5D5E6467676E6F6F7879787F8080
8586868B8B8A908F8E93919094929096939196939095928E938F8B908C888B868285807C807A76\
79736F726C696A6562605B5954514F4845443A39382E2D2D2221221515160B0B0C
0908090F0E0F1516191B1E2320262C252E352A353D2E3B4431404B344551364956384D5B3A505F\
3C53643D56683E596B
3E596C3D57683C54653B5261394F5D384B5935475433424E2F3D472C373F272F3621272C1A1D20\
18191B1F2123292B2D313536393D3E414445494B4C515353595B5B616363686A6A
6E706F737373767677797A797C7C7B7D7D7C7E7D7C7D7C7A7B7A7878767474716F6C6A6764625F\
5F5D5B59585651504F4646463D3C3D3333342828291C1D1E1313140B0A0B050202
080606101114171A1E1C2228222A302630382A36402E3C4731414D344652364A57384D5C3A5060\
3B54643D56683E596B
3E5A6C3D57693C55653B5262394F5E374C5A35485533434F303E492C394227323A222A311D2226\
15181A1416171B1E202428292D3032343638383B3D3E414345484A4B4E50525455
575A5A5B5E5F5F62626265656467676567676568676567676465656263635D5F5F585A5B525556\
4A4D4F4345473B3D3F3335372C2E302325271A1B1E101113070809020000040202
0D0D0F13171A191F241F262D232D3528333D2B39432F3E4A32434F344754364B59384E5D3A5161\
3C54653D57683E596C
3E5A6C3D57693C55663B536339505F384D5B36495733455230404C2D3B4629353E242F361F272D\
1A1F24131619121416181B1D1F2324262A2C2B2F302F3233343738383C3D3B4041
3E4345424749474C4D4A4F504D51534E53544F54554F53544D52534C51534B5053484E5244494D\
4045493A3F4333373B2A2E31202427161A1D0E111406080A0000010301020A0B0E
111418171D221C252B212B3326323B2937412D3C4730414D334552354957374C5B394F5F3A5262\
3C55663D57693E596C
3E5A6C3D586A3C56673B53643A5161384E5D364B593447553243502F3F4A2B394427343D232D35\
1E262C181E2311141710121416191B1C202220242623272926292B282D2E2C3233
2F353730373832383A353C3E383F413940423941433A41453A4145384044374044363E43333B40\
2E363B262F3420272C181F2310151A0A0E1204070A000001020102090A0E101419
161D231C242B202B3325313A2836412C3B472F404C314451344755364B59384E5D3950603B5364\
3C55673D58693E5A6C
3E5A6D3E586A3D57683C54653A526339505F374D5C354A5833475431434F2E3E4A2A394427343D\
222E361D272D181F241015180B0E100F1315171C1E1D22241E23251D22231C2224
1D232621282A242C2E232C2E222B2F252F342934392B363B2B363B2C363C2B363D2A353C28333A\
232E351D272E16202610181D091116050B0F0205070506080B0F1311171D171F26
1C262E212C3525323C2837422C3C482E404D314451334755354A59374D5C3950603A52633B5465\
3C56683D586A3E5A6D
3F5B6D3E596B3D57693C56673B54653A526239505F374D5C354A593347553143502E3F4C2B3B46\
2736402330391F2A32192229131B200E13170E131612191C161C20171E21171F22
1821241822261823271A262C1E2A31202C34202D3622303925333C26333D24313A232F38212D36\
1C2830172129101A200C151A0A101405090C070B0F0F161B151D241A242C1E2A33
22303A263540293A452C3E4A2F424F314553334857354B5A374D5D3850603A52623B54653C5667\
3D57693E596B3F5A6D
3F5B6E3E5A6C3D586B3D57693C56673B54653A5263395061374E5E364C5B344958324654304350\
2D3F4B2A3A4626364022303A1E2B3319252D131C230D161C0D161C121C22162126
15202515212617242B1A282F1D2B321D2B331D2C351D2C371D2C371E2D371E2D381D2B361C2932\
1B242D172028121A200C12170A10150F161D151F271A262F1F2C3623313C263642
293A472C3E4B2F424F314553334857354A5A364D5C384F5F3951613A53633B54653C56673D5769\
3D586A3E596C3F5B6D
3F5B6D3E5A6D3E596C3E596B3D586A3C57683C55673B54653A5363395161384F5F364D5D354B5A\
3348573145532E42502C3F4B293B4726374222323D1F2E391D2B36192732182530
1927311A29321A28311B2A321E2E3621313A23333D23333F22333F22333F22333E23333F21303C\
1B283215212916212A1A26301D2A341F2E3923333E263744293C482C3F4D2E4250
304554324857344A5A364C5C374E5E3850613952623A53643B54663C56673C57683D586A3E596B\
3E596C3E5A6D3F5B6E
3F5B6E3F5B6E3F5B6D3E5A6D3E5A6C3E596C3D596B3D586A3D57693C56683B55673B54663A5364\
395263385061374F5F354D5D344B5B3249593147562F45542E43532D42512C4150
2C41502C41502C404F2B3F4E283C4B273A4A263A48263A47263947263947253846253744243643\
273A472A3E4B2B3F4D2C414F2E43522F4554314757334A59344C5C364D5E374F60
3850613952633A53643A54663B55673C56683C57693D576A3D586A3D596B3E596C3E5A6C3E5A6D\
3F5B6D3F5B6E3F5B6E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool4041LK`P0@5e`0`10
GG44041NL@@0@Eia1011GW84045OLP@0@Emc0`12Gg<4049PL`P0@V1d2013HGD404=QMPL0@f9f1014
HWL804ASM`/0A6=h1014HgLC04ASN0P0A6Ah2015I7P704ATN0@0A6Ag2014HgH404ARMP@0A69e0`13
HWD404=QM@@0@f5d1013H7<404=PLP@0@Uma1`12GW04049NLA00@Umb2`11GW88045NL@@0@5ea1`10
GG04041LL0@0@5a_5P3oool001@0oooo1010G6l8041ML0<0@5ea1010GW44045NL@@0@Eib1011Gg84
045OL`<0@Umc1012H7<8049PM0P0@f5e1013HGH704=RMP@0A69g2014HgL;04ASN0@0A6=g4`14HgP8
04ATN0P0AFAh1`14I7P404ATM`P0A6=f1014HWH404ARM@<0@f9e1013HGD404=QM0@0@f1c1013H784
049OL@L0@Ui`1012GW4@049OLP/0@Eib2011GW44041ML@L0@5e`1010G704041LKaH0oooo000D0?oo
o`@0@5a_2010GG03041ML@@0@5ia1011GW44045NLP@0@Emb1011Gg<3049OL`@0@V1c2012H7@804=Q
M@@0@f5f1`13HWH404ARM`P0A6=g2`14HgP404ASMa<0A6=h2014I7P804ETN0L0A6Ah1014I7L804AS
MP@0A69f1014HWD304=RM@@0@f5e1013HG@404=PL`@0@f1b1012Gg47049NL0@0@Uia4012Gg8;045N
LPP0@Eia1010GG47041ML0@0@5a`1010G6lF0?ooo`00503oool4041LK`P0@5e`0`10GG44041NL@@0
@Eia1011GW84045OLP@0@Emc0`12Gg<4049PL`P0@V1d2013HGD404=QMPL0@f9f1014HWL804ASM`/0
A6=h1014HgLC04ASN0P0A6Ah2015I7P704ATN0@0A6Ag2014HgH404ARMP@0A69e0`13HWD404=QM@@0
@f5d1013H7<404=PLP@0@Uma1`12GW04049NLA00@Umb2`11GW88045NL@@0@5ea1`10GG04041LL0@0
@5a_5P3oool001@0oooo1010GG04041NL@@0@Eib0`11Gg84049PL`@0@V1d2013HGD404ARMP<0A6=g
1014HgP404ETN@@0AFEj1016IGX404IVN`@0AfMl0`17J7d404QXOP@0B6Uo1018JWl404QZP0@0BFZ0
0`19Jh0804QZP0@0BF^01019Jh4;04U[P0@0BFb1101:K88804Y]PP@0BVf10`1:KH0404U[O`@0BFYn
1018JWd404QYO0@0B6Ql0`18J7/404MWN`@0AfIj1016IGP404ITMP@0AF9d1014H74304AOL@@0A65d
1014HWD804ARMPL0A65e1013HGD404=QM0@0@f1d1012H7<4049OL`<0@Eib1011GW44041ML0@0@5a`
5P3oool001@0oooo1010GG04041NL@@0@Eib0`11Gg84049PL`@0@V1d2013HGD404ARMP<0A6=g1014
HgP404ETN@@0AFEj1016IGX404IVN`@0AfMl0`17J7d404QXOP@0B6Uo1018JWl404QZP0@0BFZ00`19
Jh0804QZP0@0BF^01019Jh4;04U[P0@0BFb1101:K88804Y]PP@0BVf10`1:KH0404U[O`@0BFYn1018
JWd404QYO0@0B6Ql0`18J7/404MWN`@0AfIj1016IGP404ITMP@0AF9d1014H74304AOL@@0A65d1014
HWD804ARMPL0A65e1013HGD404=QM0@0@f1d1012H7<4049OL`<0@Eib1011GW44041ML0@0@5a`5P3o
ool001@0oooo1010GG04041NL@@0@Eib0`11Gg84049PL`@0@V1d2013HGD404ARMP<0A6=g1014HgP4
04ETN@@0AFEj1016IGX404IVN`@0AfMl0`17J7d404QXOP@0B6Uo1018JWl404QZP0@0BFZ00`19Jh08
04QZP0@0BF^01019Jh4;04U[P0@0BFb1101:K88804Y]PP@0BVf10`1:KH0404U[O`@0BFYn1018JWd4
04QYO0@0B6Ql0`18J7/404MWN`@0AfIj1016IGP404ITMP@0AF9d1014H74304AOL@@0A65d1014HWD8
04ARMPL0A65e1013HGD404=QM0@0@f1d1012H7<4049OL`<0@Eib1011GW44041ML0@0@5a`5P3oool0
01@0oooo1010GG04041NL@@0@Eib0`11Gg84049PL`@0@V1d2013HGD404ARMP<0A6=g1014HgP404ET
N@@0AFEj1016IGX404IVN`@0AfMl0`17J7d404QXOP@0B6Uo1018JWl404QZP0@0BFZ00`19Jh0804QZ
P0@0BF^01019Jh4;04U[P0@0BFb1101:K88804Y]PP@0BVf10`1:KH0404U[O`@0BFYn1018JWd404QY
O0@0B6Ql0`18J7/404MWN`@0AfIj1016IGP404ITMP@0AF9d1014H74304AOL@@0A65d1014HWD804AR
MPL0A65e1013HGD404=QM0@0@f1d1012H7<4049OL`<0@Eib1011GW44041ML0@0@5a`5P3oool001@0
oooo1010GG04045NL@@0@Emc0`12H7@404=QM@@0A65f1014HgL404ETN@@0AVEj0`16IW/404MWO@@0
B6Qn1018JGl404UZP0@0BV^1101:K88304]]Q0@0C6j5101<L8L404e`R0@0CG69101=LXT304ibRPP0
CW>:201=LXT?04ebR0@0CW:7101>LhL804ecQ`<0C7:6101<L8@404]_P`@0Bfj2101;Kh8404a_PP<0
C6j2101<KH4404][O`@0BVYm1019J7/404QVN0@0AV=d0`16HW@404MUM`@0AfEi1017IWT404MUN@L0
AVEi1015I7P404ESM`@0A69f1014HWD404=QM0<0@V1c1011Gg84045NL@@0@5e`5P3oool001@0oooo
1010GG04045NL@@0@Emc0`12H7@404=QM@@0A65f1014HgL404ETN@@0AVEj0`16IW/404MWO@@0B6Qn
1018JGl404UZP0@0BV^1101:K88304]]Q0@0C6j5101<L8L404e`R0@0CG69101=LXT304ibRPP0CW>:
201=LXT?04ebR0@0CW:7101>LhL804ecQ`<0C7:6101<L8@404]_P`@0Bfj2101;Kh8404a_PP<0C6j2
101<KH4404][O`@0BVYm1019J7/404QVN0@0AV=d0`16HW@404MUM`@0AfEi1017IWT404MUN@L0AVEi
1015I7P404ESM`@0A69f1014HWD404=QM0<0@V1c1011Gg84045NL@@0@5e`5P3oool001@0oooo1010
GG04045NL@@0@Emc0`12H7@404=QM@@0A65f1014HgL404ETN@@0AVEj0`16IW/404MWO@@0B6Qn1018
JGl404UZP0@0BV^1101:K88304]]Q0@0C6j5101<L8L404e`R0@0CG69101=LXT304ibRPP0CW>:201=
LXT?04ebR0@0CW:7101>LhL804ecQ`<0C7:6101<L8@404]_P`@0Bfj2101;Kh8404a_PP<0C6j2101<
KH4404][O`@0BVYm1019J7/404QVN0@0AV=d0`16HW@404MUM`@0AfEi1017IWT404MUN@L0AVEi1015
I7P404ESM`@0A69f1014HWD404=QM0<0@V1c1011Gg84045NL@@0@5e`5P3oool001@0oooo1010GG04
045NL@@0@Emc0`12H7@404=QM@@0A65f1014HgL404ETN@@0AVEj0`16IW/404MWO@@0B6Qn1018JGl4
04UZP0@0BV^1101:K88304]]Q0@0C6j5101<L8L404e`R0@0CG69101=LXT304ibRPP0CW>:201=LXT?
04ebR0@0CW:7101>LhL804ecQ`<0C7:6101<L8@404]_P`@0Bfj2101;Kh8404a_PP<0C6j2101<KH44
04][O`@0BVYm1019J7/404QVN0@0AV=d0`16HW@404MUM`@0AfEi1017IWT404MUN@L0AVEi1015I7P4
04ESM`@0A69f1014HWD404=QM0<0@V1c1011Gg84045NL@@0@5e`5P3oool001@0oooo1010GG04045N
LP@0@V1c0`13HGD404ARM`@0AFAh1016IGX404MVN`@0B6Mm0`19JGh404YZP0@0Bfb2101;KH@404a_
QP@0CG27101>LXT304mcR`@0D7F=101AMXl4055hT0@0DWVB1`1CNY<4059jT`@0DWZB101BNY48059i
T@<0DWV@101AN8l4055gS@@0CgJ;101?MHX804meR@/0CWF9101>MHP404idR0@0CgB80`1?LhL404mb
QP@0CW24101=KX8404a]P0@0Bf]n1`1:JG`404YYO@P0BVYn101:JGh404UXO@<0B6Ml1018IW/404MV
NP@0AVEi1015HgP404ARMP<0@f5e1012H7<4045NLP@0@5e`5P3oool001@0oooo1010GG04045NLP@0
@V1c0`13HGD404ARM`@0AFAh1016IGX404MVN`@0B6Mm0`19JGh404YZP0@0Bfb2101;KH@404a_QP@0
CG27101>LXT304mcR`@0D7F=101AMXl4055hT0@0DWVB1`1CNY<4059jT`@0DWZB101BNY48059iT@<0
DWV@101AN8l4055gS@@0CgJ;101?MHX804meR@/0CWF9101>MHP404idR0@0CgB80`1?LhL404mbQP@0
CW24101=KX8404a]P0@0Bf]n1`1:JG`404YYO@P0BVYn101:JGh404UXO@<0B6Ml1018IW/404MVNP@0
AVEi1015HgP404ARMP<0@f5e1012H7<4045NLP@0@5e`5P3oool001@0oooo1010GG04045NLP@0@V1c
0`13HGD404ARM`@0AFAh1016IGX404MVN`@0B6Mm0`19JGh404YZP0@0Bfb2101;KH@404a_QP@0CG27
101>LXT304mcR`@0D7F=101AMXl4055hT0@0DWVB1`1CNY<4059jT`@0DWZB101BNY48059iT@<0DWV@
101AN8l4055gS@@0CgJ;101?MHX804meR@/0CWF9101>MHP404idR0@0CgB80`1?LhL404mbQP@0CW24
101=KX8404a]P0@0Bf]n1`1:JG`404YYO@P0BVYn101:JGh404UXO@<0B6Ml1018IW/404MVNP@0AVEi
1015HgP404ARMP<0@f5e1012H7<4045NLP@0@5e`5P3oool001@0oooo1010GG44049OL`@0@f1d0`14
HWH404ETN0@0AVIk1018Igd404UYOP@0BV^00`1;K8<404a^Q@@0CG27101>LXT4051dR`@0DGF>101B
Mi0305=iTP@0E7^D101EOIL405IoV@@0Eh6K101HPY`305R2W@@0F8:L201GPI/405N0VP@0EX2H0`1F
OiL405IoU@@0EGjD101EO98405AkT0@0E7Z?101CNHl;059iSP@0DWR>101AN8d4059iS@<0DWR<101B
MX/4055fRP@0DGB9101@LXH404m_P`L0CVj2101>Kh<404i^P`@0CFj3101<KH8404a/P@<0Bf^0101:
JWl404UXO@@0B6Ml1017IWX404ETN0<0A69f1013HGD4049OL`@0@Eea5P3oool001@0oooo1010GG44
049OL`@0@f1d0`14HWH404ETN0@0AVIk1018Igd404UYOP@0BV^00`1;K8<404a^Q@@0CG27101>LXT4
051dR`@0DGF>101BMi0305=iTP@0E7^D101EOIL405IoV@@0Eh6K101HPY`305R2W@@0F8:L201GPI/4
05N0VP@0EX2H0`1FOiL405IoU@@0EGjD101EO98405AkT0@0E7Z?101CNHl;059iSP@0DWR>101AN8d4
059iS@<0DWR<101BMX/4055fRP@0DGB9101@LXH404m_P`L0CVj2101>Kh<404i^P`@0CFj3101<KH84
04a/P@<0Bf^0101:JWl404UXO@@0B6Ml1017IWX404ETN0<0A69f1013HGD4049OL`@0@Eea5P3oool0
01@0oooo1010GG44049OL`@0@f1d0`14HWH404ETN0@0AVIk1018Igd404UYOP@0BV^00`1;K8<404a^
Q@@0CG27101>LXT4051dR`@0DGF>101BMi0305=iTP@0E7^D101EOIL405IoV@@0Eh6K101HPY`305R2
W@@0F8:L201GPI/405N0VP@0EX2H0`1FOiL405IoU@@0EGjD101EO98405AkT0@0E7Z?101CNHl;059i
SP@0DWR>101AN8d4059iS@<0DWR<101BMX/4055fRP@0DGB9101@LXH404m_P`L0CVj2101>Kh<404i^
P`@0CFj3101<KH8404a/P@<0Bf^0101:JWl404UXO@@0B6Ml1017IWX404ETN0<0A69f1013HGD4049O
L`@0@Eea5P3oool001@0oooo1010GG44049OL`@0@f1d0`14HWH404ETN0@0AVIk1018Igd404UYOP@0
BV^00`1;K8<404a^Q@@0CG27101>LXT4051dR`@0DGF>101BMi0305=iTP@0E7^D101EOIL405IoV@@0
Eh6K101HPY`305R2W@@0F8:L201GPI/405N0VP@0EX2H0`1FOiL405IoU@@0EGjD101EO98405AkT0@0
E7Z?101CNHl;059iSP@0DWR>101AN8d4059iS@<0DWR<101BMX/4055fRP@0DGB9101@LXH404m_P`L0
CVj2101>Kh<404i^P`@0CFj3101<KH8404a/P@<0Bf^0101:JWl404UXO@@0B6Ml1017IWX404ETN0<0
A69f1013HGD4049OL`@0@Eea5P3oool001@0oooo1011GW44049PL`@0A69f0`15HgP404IVNP@0B6Qm
1019JWl404]/PP@0C6j40`1=L8L404mbR@@0D7B<101AMXh405=hT@@0E7^D101FOIH305MoV@@0F8:L
101JQ9l405^6XP@0GHVU101NRjL305j<Z0@0GH^W101LRJ@405b8XP@0FhNQ101KQZ0305^6WP@0FhFM
101JQI`405Z5V`@0FH>J101HPYL705R0UPP0Eh2F101GOiH405MoU@@0EWjD0`1FOYD405ImT`@0EW^A
101FNY0405AhS@@0DgB8101BLhL7059dR@@0DG>9101@LhP404maQ`@0CW260`1=KX@404a]PP@0Bf^1
1019JGh404QXO0@0AfIj0`15I7P404ARMP@0@V1d1011GW4F0?ooo`00503oool4045NL@@0@V1c1014
HWH304ESN0@0AVIj1018J7d404UZO`@0Bfb2101<KX@304e`Q`@0Cg:9101@M8`4055fSP@0DgRA101D
Ni@405ImUP<0EgnI101HPY`405Z4W`@0FhJR101MRJD405j;Y`<0GXbX101MRjL405b9Y0@0G8RR101K
Qj4405^6X0<0FhJN101KQId405Z5W0@0FXFK101IPiX405R2U`L0F82F201GP9H405MoUP@0EgnE101F
OY@305InU@@0EWfC101FNi4405IjT0@0E7R=101CM8P4059cQ`L0DWB9101ALhT4051cR0@0Cg67101>
L8H304e^Q0@0C6f2101;Jh4404UYOP@0B6Ql1017IWX304ETN0@0A69f1012H7@4045NLAH0oooo000D
0?ooo`@0@Eia1012H7<404ARMP<0AF=h1016IWX404QXO@@0BFYo101;K88404a^Q0<0CG27101?LXT4
051dS0@0DGJ>101CN94405AkU0@0EWfF0`1GOiT405R2W0@0FXBO101KQZ8405f9Y@@0GX^W0`1NS:P4
05f;Y`@0G8VT101LR:8405^7X@@0FhJP0`1KQYh405^5W@@0FXFL101JQI/405V3VP@0F8:G1`1HP9H8
05N0UP@0EgnF101GOiD405InU0<0EWjE101FOI<405IkT@@0EWZ@101DN8d405=dR0@0DW>71`1BM8T4
055cR@@0D7>8101?LHL404i`QP<0CFj4101<KH8404][P@@0BFUn1018J7`404MVNP<0AFAh1014HWH4
049PM0@0@Eia5P3oool001@0oooo1011GW44049PL`@0A69f0`15HgP404IVNP@0B6Qm1019JWl404]/
PP@0C6j40`1=L8L404mbR@@0D7B<101AMXh405=hT@@0E7^D101FOIH305MoV@@0F8:L101JQ9l405^6
XP@0GHVU101NRjL305j<Z0@0GH^W101LRJ@405b8XP@0FhNQ101KQZ0305^6WP@0FhFM101JQI`405Z5
V`@0FH>J101HPYL705R0UPP0Eh2F101GOiH405MoU@@0EWjD0`1FOYD405ImT`@0EW^A101FNY0405Ah
S@@0DgB8101BLhL7059dR@@0DG>9101@LhP404maQ`@0CW260`1=KX@404a]PP@0Bf^11019JGh404QX
O0@0AfIj0`15I7P404ARMP@0@V1d1011GW4F0?ooo`00503oool4045NLP@0@f1d1014HgL304IUNP@0
B6Mm1019JWl404]/PP@0CFj5101>LHP3051cR`@0DGJ>101CN94405EkU0@0EWfG101HP9X405V2W@<0
FhFP101MR:@405j;Y`@0H8j[101RTJl406BE/`<0IINf101SUK<4066@[@@0H8nZ101PSZP4062=Y`<0
GhbV101OS:D405n<Y0@0GhbS101ORj<405j;XP@0GXZQ1`1MRJ0405f8W`@0GHNN101LQYd405b5W@<0
FhFL101KQ9`405^3VP@0FX2G101HOYD405MlT@@0EgZ@1`1FNY4405EiT0@0E7R>101CMX`4055dRP<0
D7:8101>L8D404e^P`@0Bfb1101:JWh404QXO0<0AVIj1015HgL404=PM0@0@Eib5P3oool001@0oooo
1011GW8404=PM0@0A6=g0`16IGX404QWO@@0BFYo101;K88404e^Q@@0CW680`1@Lh/4055fSP@0DgRA
101ENi@405ImU`@0F82J101IPYd305^5X0@0GHRT101NRjL4062>Z`@0HY6_101TUK<306FG]P@0HiFc
101QT:d4062?ZP@0H8jX101PSJL305n<YP@0GhbU101OS:@405n<X`@0Gh^S101NRj8405j:X@L0GHVP
101MR9l405f7WP@0G8JM101LQId305^5W0@0FhBL101KPiX405Z0U`@0F7jE101GO94405MjT0L0EWZA
101ENI0405AhSP@0DgJ<101AM8X3051bR0@0CW25101=KX<404]/P@@0BVYn1018J7`304IVNP@0AF=g
1013H7@4045NLQH0oooo000D0?ooo`@0@Eib1013H7@404ASM`<0AVEj1018Igd404UZO`@0Bfb2101=
KXD404iaR0<0D7>;101AMXh405=hT@@0EG^D101FOIL405R0VP@0FH:M0`1KQJ0405f8Y0@0GX^W101P
SZ/406:A[`@0I9Fc0`1UUkH406>E/`@0HI2]101PSjX4062>Z0@0H8fW0`1OS:H405n<Y@@0GhbT101O
S:<405n;X`@0GX^R101NRZ4705f9X0@0GHRO101MQih405b6W@@0G8FM0`1KQI`405^4W0@0Fh>J101J
P9L405QnU@@0EgbA101GNY0705IjT@@0EGV@101DN8h405=fS0@0DGB:0`1@LXP404i`Q@@0CFj3101;
K84404YZOP@0B6Ql0`16IWX404ESM`@0@f1d1011GW8F0?ooo`00503oool4045NLP@0@f1d1014HgL3
04IUNP@0B6Mm1019JWl404]/PP@0CFj5101>LHP3051cR`@0DGJ>101CN94405EkU0@0EWfG101HP9X4
05V2W@<0FhFP101MR:@405j;Y`@0H8j[101RTJl406BE/`<0IINf101SUK<4066@[@@0H8nZ101PSZP4
062=Y`<0GhbV101OS:D405n<Y0@0GhbS101ORj<405j;XP@0GXZQ1`1MRJ0405f8W`@0GHNN101LQYd4
05b5W@<0FhFL101KQ9`405^3VP@0FX2G101HOYD405MlT@@0EgZ@1`1FNY4405EiT0@0E7R>101CMX`4
055dRP<0D7:8101>L8D404e^P`@0Bfb1101:JWh404QXO0<0AVIj1015HgL404=PM0@0@Eib5P3oool0
01@0oooo1011GW8404=QM@@0AFAh0`17Ig`404UYO`@0Bfb2101=KXD404iaR0@0D7B;0`1BMXl405Ai
TP@0EWbE101HOiT405V2W0@0FhFP101MR:<305n;Y`@0HHj[101STJl406FE]0@0J9Zi101/X<4306^O
`0@0IYRg101UU[<406BD/0@0I9B^101TTjh706BC[@P0I9B]301TUJd306BD[0@0I9>Z101TTZT406>@
Z0@0HhjW101RSJH3066<Y0@0H8ZS101ORJ8405j7W`@0GHFM101LPi/705^2VP@0FX2H101IOiH405Mm
U0@0EW^B101DN8l305=fS0@0DG>9101?LHH404e^Q0@0Bf^11019JGd304MVNP@0AF=g1013HGD4045N
LQH0oooo000D0?ooo`@0@Eib1013HGD404ETN0<0AfMl1019JGl404]/PP@0CFj5101>LHP4051dR`<0
DWJ?101DNI8405IlU@@0F7nI101IPY`405^5X0@0GHRS0`1ORjL4066>Z`@0Hi6_101UUK@406RJ^@@0
K:310`1[Wl0406JH]`@0IIJc101TU;0406BD[P@0I9>^1`1TTjd806BD[@`0I9F]0`1TU:`406BCZP@0
I9:Y101ST:P406>>Y`@0HXfV0`1QS:@4062:X`@0GhVR101NQil405f5W@@0G8>K1`1KPYX405Z0V0@0
FGnF101GOI@405IkTP@0E7R?0`1CMX`4055cR@@0Cg66101=KX@404][P@@0BFUm0`17IWX404ESM`@0
@f5e1011GW8F0?ooo`00503oool4045NLP@0@f5e1015I7P304MWO0@0BFUo101;K88404e^Q@@0CW68
101@M8/3059fS`@0E7VB101FO9D405QoV@@0FH:L101KQJ0405f8X`<0Gh^W101QSZ/406>A[`@0IIFd
101XV[T406bP`@<0Jio0101VV;L406FF/`@0I9B`101TU:h406BC[PL0I9>]201TU:d<06BE[@<0I9B/
101TTjX406BBZ@@0Hi2X101SSZL406:=YP<0HHbT101PRZ<405n9XP@0GXNO101MQId405b3V`L0Fh:J
101JP9P405UoUP@0EgfD101FNi8405AhS`<0DgJ<101ALhT404maQP@0CFj4101;Jh4404UYO@<0AfIj
1015HgL404=QM@@0@Eib5P3oool001@0oooo1011GW8404=QM@@0AFAh0`17Ig`404UYO`@0Bfb2101=
KXD404iaR0@0D7B;0`1BMXl405AiTP@0EWbE101HOiT405V2W0@0FhFP101MR:<305n;Y`@0HHj[101S
TJl406FE]0@0J9Zi101/X<4306^O`0@0IYRg101UU[<406BD/0@0I9B^101TTjh706BC[@P0I9B]301T
UJd306BD[0@0I9>Z101TTZT406>@Z0@0HhjW101RSJH3066<Y0@0H8ZS101ORJ8405j7W`@0GHFM101L
Pi/705^2VP@0FX2H101IOiH405MmU0@0EW^B101DN8l305=fS0@0DG>9101?LHH404e^Q0@0Bf^11019
JGd304MVNP@0AF=g1013HGD4045NLQH0oooo000D0?ooo`@0@Emb1014HWH404IUNP<0B6Qm101:Jh44
04a^Q0@0CW68101@M8/4059gS`<0E7ZB101GOIH405V0VP@0Fh>N101MQZ8405n:YP@0HHfZ0`1STJh4
06FD/P@0IiRg101YW;`406bQ`P@0KZC40`1[X<0406RK^P@0J9Zh101XV[L406RI]P/0JIZe101YV[@4
06VL]@@0JYff101ZWkL706^P^0@0Jijf101ZVk<406ZH/@@0JIJ_101XUJd306JC[0@0IY6[101TT:X4
06>?Z@@0HhjX101RSJL4062;Y@<0GhVS101NQj4405f5WP@0Fh:K101IOiL405MlU0<0EGZA101CMhd4
055dRP@0Cg66101=KX<404]ZP0<0B6Ml1016I7T404ARMP@0@Umb5P3oool001@0oooo1011Gg8404AR
MP@0AVEj0`18J7d404Y[P@@0C6j4101>LHP4051dR`@0DWN?0`1DNY8405MmUP@0FH2J101KPih405f6
XP@0GhZV101QSJX306>A[P@0IIBb101WV;L406VL_0@0K:72101^Y<@306^P`0@0J9^j101XV[P406RJ
]`@0J9Vf2`1YV[D406VJ]0@0JIbe101ZWKH406ZO]`L0Jj2h101[W[H406ZK/`@0JYRa101YUZl406RE
[@<0IY>/101VTJ/406B@ZP@0HhnY101SSZP406:=Y`@0H8^U0`1ORJ<405j7X@@0GHFN101KPY/405Uo
U`@0EgbD0`1ENY4405=gS@@0DGB:101?LHH404e^P`@0BfZ00`18Ig`404ITN@@0A69f1012Gg8F0?oo
o`00503oool4045OLP@0A69f1016IGX304QXO@@0BV^1101<KX@404iaR0@0D7B;101BMhl305AjTP@0
EgfF101IP9X405^3WP@0GHJR101ORZH4066=ZP<0Hi6^101UU;8406NH]`@0JIbl101/XL8406jTa0<0
Jj30101XVkX406RJ^0@0J9Zg101XVKH;06VJ]@@0JIZd101YW;D406ZM]P@0JYng1`1[X;P406^N]P@0
JY^c101ZV;4406VF[`@0J9F]0`1VTj`406JAZ`@0I92Z101SSjT406>>Z0@0HXfW101PRjD305n9X`@0
GXNQ101MQIh405^2V`@0FGnG101GO9@305EjT@@0DgN=101AM8X404maQP@0CFj3101;JX0304QWO0@0
AVAi1014HWH4049OLQH0oooo000D0?ooo`@0@Emb1014HWH404IUNP<0B6Qm101:Jh4404a^Q0@0CW68
101@M8/4059gS`<0E7ZB101GOIH405V0VP@0Fh>N101MQZ8405n:YP@0HHfZ0`1STJh406FD/P@0IiRg
101YW;`406bQ`P@0KZC40`1[X<0406RK^P@0J9Zh101XV[L406RI]P/0JIZe101YV[@406VL]@@0JYff
101ZWkL706^P^0@0Jijf101ZVk<406ZH/@@0JIJ_101XUJd306JC[0@0IY6[101TT:X406>?Z@@0HhjX
101RSJL4062;Y@<0GhVS101NQj4405f5WP@0Fh:K101IOiL405MlU0<0EGZA101CMhd4055dRP@0Cg66
101=KX<404]ZP0<0B6Ml1016I7T404ARMP@0@Umb5P3oool001@0oooo1012Gg<404ARM`@0AVIj0`19
JGl404]]P`@0CW26101@LhX4059fSP@0EGZB0`1GOIH405V0VP@0FhBN101NQj<4062;Y`@0HXn/101T
T[0306NF]@@0JIZj101[W[l406fR``@0KjG9101YWl8306FI^`@0JIfm101[Wkd406bO_PP0KJ2m0`1^
X;`406jQ_0@0KZ:l101^Xk`406nU_PP0L:Jo0`1`Y[h4072U_P@0L:>l101`XKX406nN^0@0KYbf0`1/
V[@406ZH/P@0JIJ`101XUK0406NE/@@0IiJb101VUK8306BA[@@0HXjY101QRjD405n8X@@0GHBM101J
PIT305QmU@@0EWZA101CMXd4055cR@@0CW25101<K88304UYOP@0AfIj1014HWH4049OLaH0oooo000D
0?ooo`@0@Umc1014HWL404IVNP<0BFUo101;KH<404i`QP@0D7>:101BMXh405EjTP<0EgfF101IP9X4
05^4WP@0GXNS101PRjL406:?[0@0I9:`0`1WU[D406VJ^P@0Jijo101]X/<406nUb@@0JIo20`1UVK/4
06VM_@@0Jinm101/Wkh806fP_@<0KZ2l101^XK`406jR_0@0KZ>l101_YKh8072V_`<0L:Jn101`YKh4
072S_0@0L:6j101_W[P406jL]P<0K9Zd101ZV;8406VF/0@0J9F`101WUK4406NF/P@0IYFb0`1TTJd4
06:>Z@@0HH^U101OR:4405f4W@@0FX6I0`1HOID405IjT@@0DgJ=101ALhT404i`Q@@0C6b20`19JGh4
04MVNP@0A69f1012Gg<F0?ooo`00503oool4049OL`@0A69g1016IWX304UYO`@0Bff3101>L8H4051c
RP@0DWJ>101ENY8305MmUP@0FH2J101KQ9h405j7X`@0H8^W101RSj`406BB/0<0IiJe101YV[X406^N
_`@0KJ;3101_YLT406VO`P<0IIVk101YWKd406^O_@@0K9nn201]X;d306jP_0@0KZ6l101^X[`406jS
_0@0KjFn201`Y[l3072V_P@0L:Fn101`Xk`4072Q^P@0Kijh101^W;H306bJ]0@0JYRb101YU[0406RE
/0@0IiFa101WU[8406JE/P<0I96]101RSZT4066;Y@@0GhRQ101MQ9d405Z1V@<0F7fE101FNY4405=f
S@@0DG>9101>L8D404a/PP<0BFUn1017IWX404ARMP@0@Umc5P3oool001@0oooo1012Gg<404ESM`@0
AfMl0`1:JX0404a^Q0@0Cg:8101BMHd405AiT@@0EgfE0`1IP9X405b4WP@0GXRS101QS:P406>@[0@0
IYBa101XV;H306^L^`@0KJ30101_Y<H407>ZcP@0KJC7101VVkd306VN_`@0K:71101^Xl84072Ta0@0
LJG5101bY/@307:Wa0@0LjO3101cZ<<407>Y``@0M:_5101d[LH407F^aP<0MJk5101e[L@407F[``@0
MJS1101dY[l407>S_@<0LZ2k101`WKP406jL]`@0K9^g101/W;T406bN_0@0Jifl0`1YVKL406NE/P@0
II6]101SSJP40629X`@0GXFN0`1KPIX405QmU@@0EWVA101CMX`4051bR0@0CFj40`1:Jh0404QWN`@0
AF=g1012Gg<F0?ooo`00503oool4049OL`@0AF=g1017Ig`304YZP0@0C6j4101?LXP4059eS@@0E7VA
101GOID305V0VP@0G8BN101NR:<4066<Z0@0Hi2/101VU;4406RH]P<0Jibk101]X<0406nTaP@0Lj[>
101]Y<L406JK_@<0JIjo101/XL4406jS`P@0L:C4101aYLD407:Va0<0LZO4101cYl<407>X``@0LjW3
101dZlD407B]aP@0MJk60`1e[/D407F]a0@0MJ_3101eZ<4407BV_`@0Lj>m0`1bX;/4072M^0@0KYbg
101/VkL406bL^@@0K9jl101[WK`306VI]`@0IiFb101UTJd406>=Z0@0H8VS101NQIh305^1VP@0F7fE
101FNI4405=fS0@0D7:8101=KX@304Y[P0@0B6Mk1015HgL4049OLaH0oooo000D0?ooo`@0@Umc1015
HgL404MWO0<0BVZ0101<KX@404mbR0@0DWF=101DNI4405MmU@<0FH2J101LQ9h405j8X`@0HHbX101S
T:`406JD/@@0J9Rf0`1[W;/406fP`0@0KjC6101cZ/h406fTa`@0IY^m0`1YW[l406bQ`@@0KZ?2101`
Y<@4076Ua@@0LZK40`1bYl@407>W``@0LjS3101cZL<407B[a@@0M:g6101e[/H307F^a@@0MJg4101e
Zl<407FX`@@0M:Jo101cXkd307:P^`@0L9fh101^W;L406bK]`@0K9bi101/W[`406^M_0<0JIVg101W
UK8406FA[@@0HhfX101PRJ<405j5WP<0Fh6J101HOID405IiT@@0DgJ<101@LXP404e^Q0<0BV^01018
Ig/404ESM`@0@Umc5P3oool001@0oooo1012Gg<404ESM`@0AfMl0`1:JX0404a^Q0@0Cg:8101BMHd4
05AiT@@0EgfE0`1IP9X405b4WP@0GXRS101QS:P406>@[0@0IYBa101XV;H306^L^`@0KJ30101_Y<H4
07>ZcP@0KJC7101VVkd306VN_`@0K:71101^Xl84072Ta0@0LJG5101bY/@307:Wa0@0LjO3101cZ<<4
07>Y``@0M:_5101d[LH407F^aP<0MJk5101e[L@407F[``@0MJS1101dY[l407>S_@<0LZ2k101`WKP4
06jL]`@0K9^g101/W;T406bN_0@0Jifl0`1YVKL406NE/P@0II6]101SSJP40629X`@0GXFN0`1KPIX4
05QmU@@0EWVA101CMX`4051bR0@0CFj40`1:Jh0404QWN`@0AF=g1012Gg<F0?ooo`00503oool4049P
M0@0AFAh1018Ig`304][P@@0CVn6101ALh/405=gS`@0EW^D101IOiT305b3WP@0GXRR101QS:L406B@
[0@0IiBb101YV;L406bM_0<0Kj72101aYLL407>Zc@@0KZG8101ZX<<406bRa@<0KZ?5101`YLH407:W
b0@0M:[:101f[</707N]b`@0N:g:201h[/T407R/aP@0N:[5101iZ/D307VY``@0NJ[3201j[<D407ZZ
``@0N:O10`1fY;l407BR_@@0LZ2l101`Wk/406nO_0@0Kj6o101_Xl<306jR`P@0K9bj101YUk@406NC
[P@0I8jY101QRZ<305j5WP@0Fh6I101HO9@405EhS`@0DWB:101?KhD304a[P0@0BFQl1015I7P4049P
LaH0oooo000D0?ooo`@0@V1d1015I7P404QWO0<0Bf^1101>KhH4055cR`@0DgN?101FNi@405UoV@<0
G8>N101NR:84066<Y`@0I92/101WU;8406VH]`@0K9fl0`1_XL84076Ua`@0Lj[=101^YLP406ZP``@0
K:;50`1^XlD4072UaP@0LZO8101dZ/X407J/b`L0Mjg;101h[LX807R^b@@0N:c6101hZ/D407VZa@<0
NJW3101iZ/<807Z/a@@0NZ[3101hYl4307JT_`@0M::m101bX;`4072O^`@0Kinl101_XKl406nS``<0
KZ;2101/W;X406VG]0@0Ii>^101TSZT4066:X`<0GXFN101KPIT405QlU0@0EGR?101BM8X404m_Q@<0
C6^01019J7`404ETN0@0@V1c5P3oool001@0oooo1012H7@404ETN0@0B6Ml0`1;Jh4404i_QP@0DG>;
101CMhl405IkU0@0FGnI0`1LPih405j8XP@0HHbW101TT:`406ND/P@0JIRg101/WK`306nQ`P@0LJG7
101cZ/d406jUb0@0JZ33101/X/D306jSa@@0L:G6101bYlP407BZbP@0MZc;1`1g[L/407R]bPP0N:k9
101h[<H407RZa@@0NJ[50`1iZL<407VZ``P0NZc5101jZ/<407RW`@<0MZBo101dX[d407:P_0@0L9nk
101_Wk`406nQ_`@0Kj?30`1^X/8406bL^P@0JINd101WTjh406B>Z@@0HHZS0`1NQIh405^1V@@0F7bD
101EN8l4059dRP@0Cfn50`1<Jh0404UXO0@0AFAh1012H7<F0?ooo`00503oool4049PM0@0AFAh1018
Ig`304][P@@0CVn6101ALh/405=gS`@0EW^D101IOiT305b3WP@0GXRR101QS:L406B@[0@0IiBb101Y
V;L406bM_0<0Kj72101aYLL407>Zc@@0KZG8101ZX<<406bRa@<0KZ?5101`YLH407:Wb0@0M:[:101f
[</707N]b`@0N:g:201h[/T407R/aP@0N:[5101iZ/D307VY``@0NJ[3201j[<D407ZZ``@0N:O10`1f
Y;l407BR_@@0LZ2l101`Wk/406nO_0@0Kj6o101_Xl<306jR`P@0K9bj101YUk@406NC[P@0I8jY101Q
RZ<305j5WP@0Fh6I101HO9@405EhS`@0DWB:101?KhD304a[P0@0BFQl1015I7P4049PLaH0oooo000D
0?ooo`@0@V1d1016I7T404UXOP<0C6f3101?LHP4059fS@@0EGZB101HOYL405^2W0<0GXNQ101QRjH4
06B?[0@0IiBa101ZV;L406fM_0@0L:;20`1cYlP407F[cP@0NK7E101g[m@4076Xc0@0LJO:0`1bZ<X4
07BYbP@0MZ_<101i[/l407^ad@@0O;;@1`1m//l407facP@0O:o;101lZLD407bU`0@0O:6m0`1kX;/4
07fT_`@0OZW4101oZlH407j/aP@0OJ_50`1kZ<<407VV`P@0MjC0101eX[l407>R_`@0Lj?1101cYL@3
07:Ua@@0L:?2101^W[/406^H]@@0J9>^101USZP30669XP@0GXBL101JOiL405MjT@@0DgJ<101@LHL3
04e]PP@0BFQm1016I7P404=PM1H0oooo000D0?ooo`@0@V1d1016I7T404UXOP<0C6f3101?LHP4059f
S@@0EGZB101HOYL405^2W0<0GXNQ101QRjH406B?[0@0IiBa101ZV;L406fM_0@0L:;20`1cYlP407F[
cP@0NK7E101g[m@4076Xc0@0LJO:0`1bZ<X407BYbP@0MZ_<101i[/l407^ad@@0O;;@1`1m//l407fa
cP@0O:o;101lZLD407bU`0@0O:6m0`1kX;/407fT_`@0OZW4101oZlH407j/aP@0OJ_50`1kZ<<407VV
`P@0MjC0101eX[l407>R_`@0Lj?1101cYL@307:Ua@@0L:?2101^W[/406^H]@@0J9>^101USZP30669
XP@0GXBL101JOiL405MjT@@0DgJ<101@LHL304e]PP@0BFQm1016I7P404=PM1H0oooo000D0?ooo`@0
@V1d1016I7T404UXOP<0C6f3101?LHP4059fS@@0EGZB101HOYL405^2W0<0GXNQ101QRjH406B?[0@0
IiBa101ZV;L406fM_0@0L:;20`1cYlP407F[cP@0NK7E101g[m@4076Xc0@0LJO:0`1bZ<X407BYbP@0
MZ_<101i[/l407^ad@@0O;;@1`1m//l407facP@0O:o;101lZLD407bU`0@0O:6m0`1kX;/407fT_`@0
OZW4101oZlH407j/aP@0OJ_50`1kZ<<407VV`P@0MjC0101eX[l407>R_`@0Lj?1101cYL@307:Ua@@0
L:?2101^W[/406^H]@@0J9>^101USZP30669XP@0GXBL101JOiL405MjT@@0DgJ<101@LHL304e]PP@0
BFQm1016I7P404=PM1H0oooo000D0?ooo`@0@V1d1016I7T404UXOP<0C6f3101?LHP4059fS@@0EGZB
101HOYL405^2W0<0GXNQ101QRjH406B?[0@0IiBa101ZV;L406fM_0@0L:;20`1cYlP407F[cP@0NK7E
101g[m@4076Xc0@0LJO:0`1bZ<X407BYbP@0MZ_<101i[/l407^ad@@0O;;@1`1m//l407facP@0O:o;
101lZLD407bU`0@0O:6m0`1kX;/407fT_`@0OZW4101oZlH407j/aP@0OJ_50`1kZ<<407VV`P@0MjC0
101eX[l407>R_`@0Lj?1101cYL@307:Ua@@0L:?2101^W[/406^H]@@0J9>^101USZP30669XP@0GXBL
101JOiL405MjT@@0DgJ<101@LHL304e]PP@0BFQm1016I7P404=PM1H0oooo000D0?ooo`@0@f1d1016
IGX404YZO`<0CFj4101@LhX405AhS`@0EgbD101JPIX405f5W`<0HHZU101TSZX406NC/0@0JYRf101]
WK`4072R`P@0M:O80`1g[<h407^beP@0MjoD101bZ/h407BZc@@0MJ_=0`1fZl`407R/c0@0NZo?101m
/]<4082ee@@0PKOE0`22]m@408Bgd`@0PZo;101nYL4407bQ^`@0NY^e101jWKH307fR_0@0Oj2l1021
XK/408>V`@@0Q:g81022[/T307n/a`@0O:W4101jYl8407RT`@@0MjC2101fYL<407JWaP<0Mj[:101f
ZLT407>T`P@0L9jk101/V;@406RB[@<0I8fV101PQj0405f2VP@0FGfD101EN8h4055cR@<0CVj3101:
JGh404IUN@@0@f1d5P3oool001@0oooo1013H7@404IUNP@0BVYo0`1=KX@4051cRP@0E7R?101GO9@4
05Z1VP@0GHFO0`1QRZD406B>ZP@0Ii>`101ZV;H406fM_0@0L:;2101dYlP307N/cP@0Nk;F101g[m@4
07:ZcP@0M:[=101eZld307J[c0@0N:c<101j[ll407fbd`@0P;GE1021]mD308:ge0@0Q;OC1022[l/4
07jU`@@0O:6k101jVkD407ZM]P<0OJ:l101oX;`4086Q^`@0PjK11024[LP408:^b@<0Ojc7101lZL@4
07ZW`P@0N:C1101gY<8407JU``@0MZO60`1gZ/X407JYb@@0LjC2101`W[/406bH]0@0J9:]0`1TSJH4
0627X0@0GH:J101IOI@405EhSP@0DG>90`1>KX<404YYOP@0AVEi1013H7@F0?ooo`00503oool404=P
M0@0AVEj101:JWl304e^Q0@0D7>:101DN8l405MlU0@0FX6J101MQIl3066:Y@@0I8jZ101WTk0406ZH
]P@0KIfl101`X/8407BWb0<0Mjc>101k/]H407N_e0@0LZ[>101dZ/d407F[c@<0MZ_<101h[<`407Z_
c`@0OK;C1020]MD4086ge@<0P[OD1024]m<408:_b`@0OZG1101lXK/407ZK]@@0NYff0`1mX[`407nP
_0@0PJ6k1023Y/4408B]b0@0PZk90`1o[<L407bYa0@0NZO2101hY<4407NT`P@0MZG3101fYlH307NZ
bP@0MZW9101cY<84072N^`@0K9Rd101XTZd306B=YP@0H8NP101MPYX405UmU0@0EGR>101ALhT304i^
P`@0BVUn1016IGT404=PM1H0oooo000D0?ooo`@0@f1d1016IGX404YZO`<0CFj4101@LhX405AhS`@0
EgbD101JPIX405f5W`<0HHZU101TSZX406NC/0@0JYRf101]WK`4072R`P@0M:O80`1g[<h407^beP@0
MjoD101bZ/h407BZc@@0MJ_=0`1fZl`407R/c0@0NZo?101m/]<4082ee@@0PKOE0`22]m@408Bgd`@0
PZo;101nYL4407bQ^`@0NY^e101jWKH307fR_0@0Oj2l1021XK/408>V`@@0Q:g81022[/T307n/a`@0
O:W4101jYl8407RT`@@0MjC2101fYL<407JWaP<0Mj[:101fZLT407>T`P@0L9jk101/V;@406RB[@<0
I8fV101PQj0405f2VP@0FGfD101EN8h4055cR@<0CVj3101:JGh404IUN@@0@f1d5P3oool001@0oooo
1013HGD404MVNP@0BV^00`1>L8H4059dR`@0EGVA101IOYL405b3W@@0H8RR0`1SSJP406JB[P@0JYNd
101]W;X4072Q`@@0M:O7101h[<h307^ae0@0O[GI101k/]H407J/c`@0Mjc?101h[Ll307V]cP@0Njk?
101m/=0407ncdP@0P[GD1026^=L308Fbd0@0OZC0101kWkX407fN^@@0OIbg101mW[T407fM^@<0OI^e
101lVk@407jN]`@0PJ>n1026ZL@408N^b@<0Pjk91020[<H407fYa@@0NjO3101jY/<407ZWa@@0NZ[8
1`1jZlX407VYa`@0MJC1101`WKT406bF/@<0Ii2Z101SRZ<405n4W0@0FgnF101GNI0405=dRP<0Cfn5
101;JWl404MUNP@0@f5d5P3oool001@0oooo1013HGD404MVNP@0BV^00`1>L8H4059dR`@0EGVA101I
OYL405b3W@@0H8RR0`1SSJP406JB[P@0JYNd101]W;X4072Q`@@0M:O7101h[<h307^ae0@0O[GI101k
/]H407J/c`@0Mjc?101h[Ll307V]cP@0Njk?101m/=0407ncdP@0P[GD1026^=L308Fbd0@0OZC0101k
WkX407fN^@@0OIbg101mW[T407fM^@<0OI^e101lVk@407jN]`@0PJ>n1026ZL@408N^b@<0Pjk91020
[<H407fYa@@0NjO3101jY/<407ZWa@@0NZ[81`1jZlX407VYa`@0MJC1101`WKT406bF/@<0Ii2Z101S
RZ<405n4W0@0FgnF101GNI0405=dRP<0Cfn5101;JWl404MUNP@0@f5d5P3oool001@0oooo1013HGD4
04MVNP@0BV^00`1>L8H4059dR`@0EGVA101IOYL405b3W@@0H8RR0`1SSJP406JB[P@0JYNd101]W;X4
072Q`@@0M:O7101h[<h307^ae0@0O[GI101k/]H407J/c`@0Mjc?101h[Ll307V]cP@0Njk?101m/=04
07ncdP@0P[GD1026^=L308Fbd0@0OZC0101kWkX407fN^@@0OIbg101mW[T407fM^@<0OI^e101lVk@4
07jN]`@0PJ>n1026ZL@408N^b@<0Pjk91020[<H407fYa@@0NjO3101jY/<407ZWa@@0NZ[81`1jZlX4
07VYa`@0MJC1101`WKT406bF/@<0Ii2Z101SRZ<405n4W0@0FgnF101GNI0405=dRP<0Cfn5101;JWl4
04MUNP@0@f5d5P3oool001@0oooo1013HGD404MVNP@0BV^00`1>L8H4059dR`@0EGVA101IOYL405b3
W@@0H8RR0`1SSJP406JB[P@0JYNd101]W;X4072Q`@@0M:O7101h[<h307^ae0@0O[GI101k/]H407J/
c`@0Mjc?101h[Ll307V]cP@0Njk?101m/=0407ncdP@0P[GD1026^=L308Fbd0@0OZC0101kWkX407fN
^@@0OIbg101mW[T407fM^@<0OI^e101lVk@407jN]`@0PJ>n1026ZL@408N^b@<0Pjk91020[<H407fY
a@@0NjO3101jY/<407ZWa@@0NZ[81`1jZlX407VYa`@0MJC1101`WKT406bF/@<0Ii2Z101SRZ<405n4
W0@0FgnF101GNI0405=dRP<0Cfn5101;JWl404MUNP@0@f5d5P3oool001@0oooo1013HGD404MVN`@0
Bf^10`1?L8L405=fS@@0Eg^C101KP9T405j6X0@0HX^V0`1UT:`406VE/P@0K9Zh101`Wkh407>Ua@@0
N:_=101l/]D3082gfP@0OkOJ101k/]D407V^d@@0NZk@101k[Lh307b]cP@0OZo?1020/=0408:`c`@0
PZo=1021[</3082Zb0@0OjW71020Z<H4086Wa@@0PJO41022Z<H408:Xa@<0PZS41021Z<@407nU`P@0
OJ6m101mX[`408>Y`P<0Qk3:1025/<X408:/b0@0Oj[6101nZLD407fZa`@0OJ_90`1m[L`407f^cP@0
O:g=101jZ/L407FR_P@0KiZe0`1ZTjd406F=YP@0HHJO101LPIP405QkTP@0E7J<0`1@L8H404a[P0@0
AfIj1013HGDF0?ooo`00503oool404=QM@@0AfIk101;Jh4304m`Q`@0DgJ=101GNi<405^0V@@0GXJP
101RRjH306F@[0@0JIFb101/V[P4072O_P@0LjG5101hZld407bbe@<0P;OJ101o]mX407^be@@0NJkA
101j[]0407^]cP<0O:g>101n[ll4082`d0@0P[3?1022[ld4086/b`<0P:[8101oZLL4082XaP@0PJO5
1021Yl@408:XaP@0PZS50`22Z<@4086Xa0@0OjG2101mXKd407fR_0@0PjW20`27/<X408F`bP@0PZc8
101oZ/H407jYa@@0OJ[7101mZlT307f]c0@0OJk>101l[Ld407ZZa`@0MJ:n101_V[D306ZC[@@0IHfV
101QQYl405b1V0@0F7^B101DMX`3051`QP@0C6^01017IWX404=QMAH0oooo000D0?ooo`@0@f5e1017
IW/404][P@<0Cg27101CMXd405MkT`@0Fh2I101NQZ0406:;YP<0II2/101YUK8406bJ^0@0L9nn101c
YLD407R[c@@0O;;E0`20]mX407ngfP@0Nk;E101i[]4407Z^d0@0Njg>0`1l[Lh407j_c`@0P;3@1022
/<l408:_c@@0PJc;0`20Z/P407nYa`@0P:S61021YlD4086Wa0@0PZS61022Z<D308:Xa0@0PJS4101o
YL8407fQ_@@0OJ:l1023ZL8308N`bP@0QK3:1022[<P407nZaP@0OZW5101mZ/L407f[b@<0OJg<101m
[/h407b]c@@0NZ[7101eX[h406nJ]@<0JY>]101USJH40666W`@0G86H101HNi8405AfS0<0D726101<
Jh0404MVNP@0@f5e5P3oool001@0oooo1013HGD404MVN`@0Bf^10`1?L8L405=fS@@0Eg^C101KP9T4
05j6X0@0HX^V0`1UT:`406VE/P@0K9Zh101`Wkh407>Ua@@0N:_=101l/]D3082gfP@0OkOJ101k/]D4
07V^d@@0NZk@101k[Lh307b]cP@0OZo?1020/=0408:`c`@0PZo=1021[</3082Zb0@0OjW71020Z<H4
086Wa@@0PJO41022Z<H408:Xa@<0PZS41021Z<@407nU`P@0OJ6m101mX[`408>Y`P<0Qk3:1025/<X4
08:/b0@0Oj[6101nZLD407fZa`@0OJ_90`1m[L`407f^cP@0O:g=101jZ/L407FR_P@0KiZe0`1ZTjd4
06F=YP@0HHJO101LPIP405QkTP@0E7J<0`1@L8H404a[P0@0AfIj1013HGDF0?ooo`00503oool404AQ
M@@0B6Ml101<K883051bR0@0EGR?101IOIH405f3W0@0HHRR101TSZT306RC[`@0K9Re101_WK`407:S
`P@0MZS9101j[m4408:ig@<0Ql3V101n]]/407N]d0@0NZk@101l[m0407j`d0<0Ojo?1020[lh4086^
c@@0P:[7101nX[l407ZK]`<0Nibh1020Xkl408:V``@0Q:W71025[LX808J^b`<0Q[3>1026/<d408F/
bP@0Pj[71021ZL@4082X``<0QJg71027/</408B^b@@0PZc81021[<P4082/b@@0P:g;0`20[/`407n_
cP@0OZk=101kZ/P407RT`@@0LYfh0`1]UK0406R?Z0@0HhRQ101NPYX405YlT`@0EGN=0`1ALHL404a/
P@@0B6Ik1014HGDF0?ooo`00503oool404AQM@@0B6Ml101<K883051bR0@0EGR?101IOIH405f3W0@0
HHRR101TSZT306RC[`@0K9Re101_WK`407:S`P@0MZS9101j[m4408:ig@<0Ql3V101n]]/407N]d0@0
NZk@101l[m0407j`d0<0Ojo?1020[lh4086^c@@0P:[7101nX[l407ZK]`<0Nibh1020Xkl408:V``@0
Q:W71025[LX808J^b`<0Q[3>1026/<d408F/bP@0Pj[71021ZL@4082X``<0QJg71027/</408B^b@@0
PZc81021[<P4082/b@@0P:g;0`20[/`407n_cP@0OZk=101kZ/P407RT`@@0LYfh0`1]UK0406R?Z0@0
HhRQ101NPYX405YlT`@0EGN=0`1ALHL404a/P@@0B6Ik1014HGDF0?ooo`00503oool404AQM@@0B6Ml
101<K883051bR0@0EGR?101IOIH405f3W0@0HHRR101TSZT306RC[`@0K9Re101_WK`407:S`P@0MZS9
101j[m4408:ig@<0Ql3V101n]]/407N]d0@0NZk@101l[m0407j`d0<0Ojo?1020[lh4086^c@@0P:[7
101nX[l407ZK]`<0Nibh1020Xkl408:V``@0Q:W71025[LX808J^b`<0Q[3>1026/<d408F/bP@0Pj[7
1021ZL@4082X``<0QJg71027/</408B^b@@0PZc81021[<P4082/b@@0P:g;0`20[/`407n_cP@0OZk=
101kZ/P407RT`@@0LYfh0`1]UK0406R?Z0@0HhRQ101NPYX405YlT`@0EGN=0`1ALHL404a/P@@0B6Ik
1014HGDF0?ooo`00503oool404ARMP@0BFQl101=KX<3059cRP@0EWVA101KP9P405n5W`@0Hh^U101W
TJ`306^F/`@0KY^i101bXKl407FVa@@0N:[;101k/=8407nef0<0O[CH101i[M4407V[cP@0O:k@101o
/<l4086`cP<0PZo>1023[ld408B^b`@0Q:c91023ZLD4086T`0<0PZ:n1023X[l408BS_`@0QJC11026
YL8408NVa0@0QjO41`28Y/@408NYa`@0QZ_71024Z/H408:YaP<0PJS41024ZlH408J^b@@0QJk91024
[LT408>^bP@0Pjk<0`23/<d408>ad0@0Q[KE1022/M0407ZV``@0MInk0`1_Uk8406ZAZP@0IHZS101P
Q9`405]nU@@0EWR>0`1BLXP404e/P@@0B6Mk1014HGDF0?ooo`00503oool404ARMP@0BFQl101=KX<3
059cRP@0EWVA101KP9P405n5W`@0Hh^U101WTJ`306^F/`@0KY^i101bXKl407FVa@@0N:[;101k/=84
07nef0<0O[CH101i[M4407V[cP@0O:k@101o/<l4086`cP<0PZo>1023[ld408B^b`@0Q:c91023ZLD4
086T`0<0PZ:n1023X[l408BS_`@0QJC11026YL8408NVa0@0QjO41`28Y/@408NYa`@0QZ_71024Z/H4
08:YaP<0PJS41024ZlH408J^b@@0QJk91024[LT408>^bP@0Pjk<0`23/<d408>ad0@0Q[KE1022/M04
07ZV``@0MInk0`1_Uk8406ZAZP@0IHZS101PQ9`405]nU@@0EWR>0`1BLXP404e/P@@0B6Mk1014HGDF
0?ooo`00503oool404ARMP@0BFQl101=KX<3059cRP@0EWVA101KP9P405n5W`@0Hh^U101WTJ`306^F
/`@0KY^i101bXKl407FVa@@0N:[;101k/=8407nef0<0O[CH101i[M4407V[cP@0O:k@101o/<l4086`
cP<0PZo>1023[ld408B^b`@0Q:c91023ZLD4086T`0<0PZ:n1023X[l408BS_`@0QJC11026YL8408NV
a0@0QjO41`28Y/@408NYa`@0QZ_71024Z/H408:YaP<0PJS41024ZlH408J^b@@0QJk91024[LT408>^
bP@0Pjk<0`23/<d408>ad0@0Q[KE1022/M0407ZV``@0MInk0`1_Uk8406ZAZP@0IHZS101PQ9`405]n
U@@0EWR>0`1BLXP404e/P@@0B6Mk1014HGDF0?ooo`00503oool404ARMP@0BFQl101=KX<3059cRP@0
EWVA101KP9P405n5W`@0Hh^U101WTJ`306^F/`@0KY^i101bXKl407FVa@@0N:[;101k/=8407nef0<0
O[CH101i[M4407V[cP@0O:k@101o/<l4086`cP<0PZo>1023[ld408B^b`@0Q:c91023ZLD4086T`0<0
PZ:n1023X[l408BS_`@0QJC11026YL8408NVa0@0QjO41`28Y/@408NYa`@0QZ_71024Z/H408:YaP<0
PJS41024ZlH408J^b@@0QJk91024[LT408>^bP@0Pjk<0`23/<d408>ad0@0Q[KE1022/M0407ZV``@0
MInk0`1_Uk8406ZAZP@0IHZS101PQ9`405]nU@@0EWR>0`1BLXP404e/P@@0B6Mk1014HGDF0?ooo`00
503oool404ARMP@0BFQm101>Kh@305=eR`@0F7^C101LPIX40667X@@0IHjX101ZU:l306jI]P@0LInm
101eY<<407NYb@@0NJc>101i[]0407:WbP<0K:75101cYlX407b^d0@0P;3@1023[ll408B`cP<0QK3=
1026[/`408N]bPP0Qjc81028ZlP308RYaP@0RJS51029ZLD408ZYaP@0Rj_74`2<ZlP408bYa`@0RJK4
1025Xkl308:P^`@0PZ6l1025Yl8408N/b0@0Qjk91026[/X408J_b`<0QJo=1025/Lh408F`c@@0Pjk;
101mZ<D407NP^`<0LIVc101/TZ`406J<Y0@0HHFM101LOiH405MiS`<0Dg>9101>KH8404UWO0@0A69e
5P3oool001@0oooo1014HWH404UXO@@0CVn40`1CMH/405QkT`@0G86J101QQj4406F>Z0@0JYB_0`1^
VKH4076O_@@0MJC3101gZLT407V/cP@0NJk@101bYlX306bQa@@0LjO:101l[]04082`d0@0Pjo?1024
/<h308F`c@@0QZk<1027[LX808N/b0@0R:_80`28ZLH408VXa@@0RJW5102:ZLH408^[aa<0S:_8102<
ZLL408VVa0@0QJ>o0`22X;/408:Q_0@0QJO21027[<P408N^b@@0QZk:1026[l/308F_c@@0QK7>1025
/<d408>^b`@0OJS5101gX;/3076I/`@0K9:/101VS:@40665W@@0G7nF101GNHl305=cR@@0CVf21019
Ig`404ARMAH0oooo000D0?ooo`@0A69f1019J7d404i_Q0<0DgF;101HNi<405b1VP@0HHNQ101USZP4
06ZD[`<0KYVf101aWkd407FT``@0MjW9101i[<h407V^d0@0LZO:0`1/XLD407>WbP@0O:k@1020/=04
08>_c`@0Q;3>0`25/<d408J^c0@0Qjg:2027[<P408R[b0<0R:W61029Z<D408VYa@@0RZW6102;ZlLC
08b[b0@0S:W71029Y/@408FS_`<0PZ2k1022XK`408FW`P@0Qjc81027[/T408J^bP@0QZo;0`25[ld4
08FacP@0QK3=1023[//407fXa@@0Mj2k0`1aVK<406bB[0@0IXbT101QQId405aoUP@0EgV?0`1CLhT4
04i]PP@0BFMl1014HWDF0?ooo`00503oool404ARMP@0BFQm101>Kh@305=eR`@0F7^C101LPIX40667
X@@0IHjX101ZU:l306jI]P@0LInm101eY<<407NYb@@0NJc>101i[]0407:WbP<0K:75101cYlX407b^
d0@0P;3@1023[ll408B`cP<0QK3=1026[/`408N]bPP0Qjc81028ZlP308RYaP@0RJS51029ZLD408ZY
aP@0Rj_74`2<ZlP408bYa`@0RJK41025Xkl308:P^`@0PZ6l1025Yl8408N/b0@0Qjk91026[/X408J_
b`<0QJo=1025/Lh408F`c@@0Pjk;101mZ<D407NP^`<0LIVc101/TZ`406J<Y0@0HHFM101LOiH405Mi
S`<0Dg>9101>KH8404UWO0@0A69e5P3oool001@0oooo1015HWH404YYOP@0Cg250`1DMXd405UmU@@0
GX>L101SRZ@406R@Z`@0KINc0`1aWKX407FS`@@0N:S8101k[Lh407b`d`@0O;;F101j/=D307Z^d0@0
OJo@1022/]8408FcdP@0Qk;@1028/Lh308Z`c@@0R[3<102:[lX408Z^bP@0S;3<102=/Lh308f`c0P0
SZk:102?[/X4092^bP@0T:k;102A/<`3096ac@@0T[3<102A[l/4092^bP@0SJc7102;ZLD308VW`P@0
QjK21027Z<8408R[a@@0RJk81029[lX408R`b`<0Qk3<1027/<d408NacP@0Q:k:101nZ<<407VQ_0<0
LiZe101]Tjd406R=Y@@0HhJN101NP9L405QjT0<0DgB9101>KX<404UXO0@0A69e5P3oool001@0oooo
1015HWH404YYOP@0Cg250`1DMXd405UmU@@0GX>L101SRZ@406R@Z`@0KINc0`1aWKX407FS`@@0N:S8
101k[Lh407b`d`@0O;;F101j/=D307Z^d0@0OJo@1022/]8408FcdP@0Qk;@1028/Lh308Z`c@@0R[3<
102:[lX408Z^bP@0S;3<102=/Lh308f`c0P0SZk:102?[/X4092^bP@0T:k;102A/<`3096ac@@0T[3<
102A[l/4092^bP@0SJc7102;ZLD308VW`P@0QjK21027Z<8408R[a@@0RJk81029[lX408R`b`<0Qk3<
1027/<d408NacP@0Q:k:101nZ<<407VQ_0<0LiZe101]Tjd406R=Y@@0HhJN101NP9L405QjT0<0DgB9
101>KX<404UXO0@0A69e5P3oool001@0oooo1015HWH404YYOP@0Cg250`1DMXd405UmU@@0GX>L101S
RZ@406R@Z`@0KINc0`1aWKX407FS`@@0N:S8101k[Lh407b`d`@0O;;F101j/=D307Z^d0@0OJo@1022
/]8408FcdP@0Qk;@1028/Lh308Z`c@@0R[3<102:[lX408Z^bP@0S;3<102=/Lh308f`c0P0SZk:102?
[/X4092^bP@0T:k;102A/<`3096ac@@0T[3<102A[l/4092^bP@0SJc7102;ZLD308VW`P@0QjK21027
Z<8408R[a@@0RJk81029[lX408R`b`<0Qk3<1027/<d408NacP@0Q:k:101nZ<<407VQ_0<0LiZe101]
Tjd406R=Y@@0HhJN101NP9L405QjT0<0DgB9101>KX<404UXO0@0A69e5P3oool001@0oooo1015HWH4
04YYOP@0Cg250`1DMXd405UmU@@0GX>L101SRZ@406R@Z`@0KINc0`1aWKX407FS`@@0N:S8101k[Lh4
07b`d`@0O;;F101j/=D307Z^d0@0OJo@1022/]8408FcdP@0Qk;@1028/Lh308Z`c@@0R[3<102:[lX4
08Z^bP@0S;3<102=/Lh308f`c0P0SZk:102?[/X4092^bP@0T:k;102A/<`3096ac@@0T[3<102A[l/4
092^bP@0SJc7102;ZLD308VW`P@0QjK21027Z<8408R[a@@0RJk81029[lX408R`b`<0Qk3<1027/<d4
08NacP@0Q:k:101nZ<<407VQ_0<0LiZe101]Tjd406R=Y@@0HhJN101NP9L405QjT0<0DgB9101>KX<4
04UXO0@0A69e5P3oool001@0oooo1015HgL404]ZO`@0D7670`1FN8l405]oUP@0HHJN101VSJH406^D
[P@0L9Zf0`1eXKh407VWa@@0OJg<1020/]<408:gf@@0PkWL1024^Md308Fjg@@0QkWJ1028^=H408Zg
e@@0S;KC102=]M4308jdd0@0Sk??102?/ld408nbc@@0T;;>102A]=0309:ed@@0T[C?102C]<l409Bd
d0@0U;??202E/lh309Jdc`@0UKC>102D//d409:ab`@0TJk8102>ZlD308bY``@0RjW3102:Z/<408^/
aP@0S:o8102;[lT408V_b@<0R:o:1026[lX408J_b`@0Q[3=1021ZlP407^S_`<0MIbf101_UJh406V>
YP@0I8NO101OPIP405UkT@<0E7B:101?KX<404YXO0@0AF9f5P3oool001@0oooo1015HgL404]ZO`@0
D7670`1FN8l405]oUP@0HHJN101VSJH406^D[P@0L9Zf0`1eXKh407VWa@@0OJg<1020/]<408:gf@@0
PkWL1024^Md308Fjg@@0QkWJ1028^=H408Zge@@0S;KC102=]M4308jdd0@0Sk??102?/ld408nbc@@0
T;;>102A]=0309:ed@@0T[C?102C]<l409Bdd0@0U;??202E/lh309Jdc`@0UKC>102D//d409:ab`@0
TJk8102>ZlD308bY``@0RjW3102:Z/<408^/aP@0S:o8102;[lT408V_b@<0R:o:1026[lX408J_b`@0
Q[3=1021ZlP407^S_`<0MIbf101_UJh406V>YP@0I8NO101OPIP405UkT@<0E7B:101?KX<404YXO0@0
AF9f5P3oool001@0oooo1015HgL404]ZO`@0D7670`1FN8l405]oUP@0HHJN101VSJH406^D[P@0L9Zf
0`1eXKh407VWa@@0OJg<1020/]<408:gf@@0PkWL1024^Md308Fjg@@0QkWJ1028^=H408Zge@@0S;KC
102=]M4308jdd0@0Sk??102?/ld408nbc@@0T;;>102A]=0309:ed@@0T[C?102C]<l409Bdd0@0U;??
202E/lh309Jdc`@0UKC>102D//d409:ab`@0TJk8102>ZlD308bY``@0RjW3102:Z/<408^/aP@0S:o8
102;[lT408V_b@<0R:o:1026[lX408J_b`@0Q[3=1021ZlP407^S_`<0MIbf101_UJh406V>YP@0I8NO
101OPIP405UkT@<0E7B:101?KX<404YXO0@0AF9f5P3oool001@0oooo1015HgL404]ZO`@0D7670`1F
N8l405]oUP@0HHJN101VSJH406^D[P@0L9Zf0`1eXKh407VWa@@0OJg<1020/]<408:gf@@0PkWL1024
^Md308Fjg@@0QkWJ1028^=H408Zge@@0S;KC102=]M4308jdd0@0Sk??102?/ld408nbc@@0T;;>102A
]=0309:ed@@0T[C?102C]<l409Bdd0@0U;??202E/lh309Jdc`@0UKC>102D//d409:ab`@0TJk8102>
ZlD308bY``@0RjW3102:Z/<408^/aP@0S:o8102;[lT408V_b@<0R:o:1026[lX408J_b`@0Q[3=1021
ZlP407^S_`<0MIbf101_UJh406V>YP@0I8NO101OPIP405UkT@<0E7B:101?KX<404YXO0@0AF9f5P3o
ool001@0oooo1015HgL404][O`@0DG:80`1GNI0405f1V0@0HhRQ101YSjT406jG/@@0M9jj0`1iYL84
07f/bP@0PK;B1025^=T408Rmh0@0R/3T102<`N<308g0hP@0S;kN102=_M`408nlf@@0TK[G102B^]H3
09>ie@@0U;SD102D]]8409Bed@@0UKGA102F]m<309Nhe0@0UkOC102G]]4<09Rfd0@0VKK?0`2I]Ll4
09RecP@0UkC=102F/l/409B`b@@0TZk60`2@[<8408jZ`@@0SZ[2102?[LH408n_b0@0SJo8102;[lP3
08V^b@@0QZg81023[<P408B_c0@0Pjk:101lYL0307JM]`@0L9F^101[SjL406F8W`@0H8:H101KNi43
05EeRP@0D6n3101:J7`404ERMQH0oooo000D0?ooo`@0AF=g101;Jgl4055bR0<0EgV@101MPIP406>8
X@@0JHnY101^Uk4407BN^P<0NJG2101m[<X4086bdP@0QKSI1028_N0408[0i0@0S<7S0`2=`>8408bn
gP@0SKgL102?_=T4096je`@0T[[F0`2C^MD409Bhe0@0U;KB102D]M4409Fed@@0U[OC0`2G^=@409Ng
d`@0UkKA302H]]0409Vfc`<0VKG?102H]Lh409Ndc@@0U[?;102D/<T409:^aP<0T:c2102>Z/4408jZ
`P@0Sjg6102?[lP408f_b0@0Rjo80`29[/T408J]b0@0Pjc81024[l`408>^bP@0O:G00`1fWKL4072E
[P@0JhnW101UR9l40622V0@0Fg^A0`1EMHX4051_P`@0BVQl1015HWHF0?ooo`00503oool404ESM`@0
Bf]o101ALXP305MiT0@0GH6H101SR:4406V?Z@@0KYNa101dW[X307VU`P@0OJc:1021/]8408Fhf@@0
R;gP102:`>@408c1h`<0SL3R102<_]h408fmg0@0SkcI102A^]L409:jeP<0TkWE102D^=@409BfdP@0
U;GA102E]M4409Jgd`<0UkSD102G]m<409Nfd@`0V;K@102I]/l309Vec`@0V;G>102G]<d409Jcb`@0
U;39102B[/H3092/`P@0SZ[1102>Z/8408n]aP@0Sjo8102=[lP408^_b0<0RJk91026[LP408>/b0@0
Q:o<1023[/X407bU`0<0MYfg101`UJh406^?Y`@0IHRO101PPYP405]kT@<0EGF:101@Kh<404YXO0@0
AF9f5P3oool001@0oooo1015HgL404][O`@0DG:80`1GNI0405f1V0@0HhRQ101YSjT406jG/@@0M9jj
0`1iYL8407f/bP@0PK;B1025^=T408Rmh0@0R/3T102<`N<308g0hP@0S;kN102=_M`408nlf@@0TK[G
102B^]H309>ie@@0U;SD102D]]8409Bed@@0UKGA102F]m<309Nhe0@0UkOC102G]]4<09Rfd0@0VKK?
0`2I]Ll409RecP@0UkC=102F/l/409B`b@@0TZk60`2@[<8408jZ`@@0SZ[2102?[LH408n_b0@0SJo8
102;[lP308V^b@@0QZg81023[<P408B_c0@0Pjk:101lYL0307JM]`@0L9F^101[SjL406F8W`@0H8:H
101KNi4305EeRP@0D6n3101:J7`404ERMQH0oooo000D0?ooo`@0AVAh101<Jh04059cR@<0FG^B101O
PiX406F:X`@0K9:/101bV[D407NR_P<0OJW61022/Ll408Nhf0@0RkoP102?aNH409;8jP@0U<W[0`2D
aNH409?2h0@0U<3N102E_md409Jog0@0UkkJ0`2H_]X409Vnf@@0V[cG102J^mD409Zje0@0Vk[D0`2K
^]H809bkeP@0W;[E202M^]@409jke0<0W[[C102M^M4409bfc`@0V[C=102H/l/409Nab0<0U:k5102C
[L<409>^a@@0Tjo7102B/<P4092`b@@0S[380`2:[/L408F[a@@0OJG1101iY<4407nZaP@0OZO10`1f
W;H4076F[P@0K8nW101WRJ040662V@@0G7bA0`1FMHX4051_Q0@0BfUm1015HWHF0?ooo`00503oool4
04ITN0@0C6^0101BLhT305UkTP@0Gh>J101URZ<406bB[0@0LYZe101gX[h307fYaP@0P[7?1027^=P4
08^oh0@0SlGV102Bb>X409C9j`<0U<GV102C`^0409C0gP@0UKoM102F_m`409NnfP<0V;kJ102I_]T4
09Zle`@0V[_E102J^]@409^je0<0Vk[F202L^mH409bje@P0WK[D102N^m@309jjd`@0WKWA102L]/l4
09Zdc@@0V;?;102G/LP309B^a@@0Tjg3102C[/D409>_a`@0T[38102@/<T408j`b0<0RZk71025ZlD4
07fU`@@0NJC1101oZ/H407jW`@<0MYbf101aUZh406b?Y`@0IhVP101QPYT405alT@<0EWF:101@Kh@4
04]YO@@0AF9f5P3oool001@0oooo1016I7P404a[P0@0DW>90`1INi8405n3VP@0IHZS101/TZ`407:J
]@@0Mj:n0`1mZLH408:ac`@0QkSH102;_n0408o5iP@0T/SZ102DbN/309C5iP@0Tl;P102D`=h409Fo
g@@0U[oL102G_]X309RnfP@0VKkI102J_=L409Zke@@0V[[D102K^]@309^jePP0W;_F102L^]D809fj
e0@0W[_D0`2N^]<409fid@@0W;K?102J]<d409Rcb`@0Uk780`2D[/D409>]``@0Tjk5102C[lL409:`
b0@0T;39102>/<P308Z^a`@0QJ_5101mYL4407VT`@@0Oj[6101nYl4307JL]P@0LIJ^101/SjL406N9
X0@0HH:I101LO94305IeRP@0D6n4101;JGd404ERMQH0oooo000D0?ooo`@0AVAh101=K84405AdRP<0
FWbC101QQI`406R=Y@@0KYF_101eWKP407^V`@<0PZk;1028]]@408fngP@0T/OX102Gc_0409[Bl`@0
Vlo^0`2KbNL409[5i0@0V/?Q102K`n4409c4h0@0WLCQ0`2Na>0409o4g`@0X<?N102P`]`40:30fP@0
WkkG0`2O_ML40:2nf0@0X;oI102Q_mT40:70f@@0X/3I102R_mP30::neP@0X[gE102Q^m<40:2id0@0
W[K<102K/lT309Zab0@0VK;8102H/lT409NdbP@0U[C;102D]</4096bbP<0SK791028[LH408:X`0@0
NZ6j101dVK<407BI/P<0MYZc101bUZh406f@Y`@0J8VP101RPiT405elTP<0EgJ;101AKh@404]YO@@0
AF9f5P3oool001@0oooo1016I7P404e/P@@0E7B:0`1JO9<40665W0@0J8fU101^UJl407FM^0@0NjK1
0`22[//408Rfe0@0SKkN102BanP409O>l0@0V];c102Kcnh309_9i`@0V/GT102J`n4409_3h@@0W<CP
102Ma>4309k4h0@0WlCO102P`mh40:32g0@0X<3J102O_]L309nme`@0X;kH102P_mT40:6of@@0XL3I
102R`=T40::of0<0X[kF102R_MD40:6kd`@0X;W@102N]/`409^cb@<0V[78102I//P409Rcb@@0UkC:
102F]</409Bdb`@0TK;:0`2=/LT408R]aP@0PZS0101jXKX407BI/`@0M9Vb0`1fV[<407:F[P@0KI2W
101XRJ0406:3V@@0GGbB0`1GMX/4055_Q0@0BfUm1015HWHF0?ooo`00503oool404ITN0@0CFb1101D
M8X305YlT`@0HHFL101XSJD406jE[`@0MIfh101kY/4308:^b`@0R;KD102=_]h409;7j0@0Ulk`102J
d_<409_?kP<0VlWW102JaN@409[3h@@0Vl?Q102La>0409g4h@<0W/CP102Oa=l40:33gP@0X<;L102P
`=X409nne`<0WkgG102P_]P40:2of@@0XKoI102Q`=T40:;0f@@0X[oH0`2R_]H40::me@@0XK_C102P
^M0409jfc0@0Vk?90`2J/LP409Vbb0@0V;?9102G]<X409Jdb`@0U;C;102A//X308fab@@0R:g61022
Z<0407ZQ^P@0M9Vc101dVK8307JJ/`@0LYJ^101]T:L406R9X0@0HX>I101MO98305MfR`@0DFn4101;
JGd404ERMQH0oooo000D0?ooo`@0AVAh101=K84405AdRP<0FWbC101QQI`406R=Y@@0KYF_101eWKP4
07^V`@<0PZk;1028]]@408fngP@0T/OX102Gc_0409[Bl`@0Vlo^0`2KbNL409[5i0@0V/?Q102K`n44
09c4h0@0WLCQ0`2Na>0409o4g`@0X<?N102P`]`40:30fP@0WkkG0`2O_ML40:2nf0@0X;oI102Q_mT4
0:70f@@0X/3I102R_mP30::neP@0X[gE102Q^m<40:2id0@0W[K<102K/lT309Zab0@0VK;8102H/lT4
09NdbP@0U[C;102D]</4096bbP<0SK791028[LH408:X`0@0NZ6j101dVK<407BI/P<0MYZc101bUZh4
06f@Y`@0J8VP101RPiT405elTP<0EgJ;101AKh@404]YO@@0AF9f5P3oool001@0oooo1016I7P404i]
PP@0EGF;0`1LOY@406>6WP@0JXnX101bV;4407VQ^`@0P:[50`27//l408fkf@@0U<CS102Ic>`409kB
l@@0XM;a102Qcnh309o;jP@0WlWW202Pb>@40:79i@@0XlWU0`2Tb^H40:G:i@@0Y/[U102VbN<40:G7
h0@0YLGM0`2U`m`40:G2fP@0Y<7I102T`MP80:G1f@@0Y/7H0`2V`=P40:JoeP@0YKkD102S^m040:6g
c0@0WkK;0`2O]/`409ngc0@0W[O=102M^<h409^gc@@0VKO=102F]//309:cbP@0S[371029[LD408>X
`@@0OZ>l101kX;P307RL]0@0M9N^101_TJL406Z:X0@0I8BI101NOI8305QfR`@0DW24101<JGd404ER
MQH0oooo000D0?ooo`@0AVAh101>KH8405EeR`<0G7jD101SQYh406Z?Z0@0LYRa101iXK/4082Za@<0
Qk;?102=^mT409C4h`@0VLc/102Nd_440:7Bl@@0XLo^0`2ObnX409o9i`P0X<ST102QbND40:?9i@<0
Y<[V102Ub^D40:K:i@@0Y/WS102Uan040:G5g@<0YL?L102U`]X40:C1f@@0Y<7H202U`MT40:K1f0<0
Y/3H102V_mH40:Fne0@0Xk_@102Q]l`409nfb`<0WkK<102O]l`409jgc@@0WKS>102K]ld409Vgc@@0
U[K;0`2B/lX408j`a`@0RJg51023Z<4407jS_0@0Nj2h0`1hW;@407BG[P@0Ki6W101ZRZ0406B4V@@0
GWfB0`1HMX/4059`Q0@0C6Um1015HWHF0?ooo`00503oool404ITN0@0CVf2101EMH/305anU0@0HhJN
101ZSjP407:H/@@0NJ6k1020Z/D308Nbc`@0SK_I102Da><409W<k0@0W];a102Qd_440:7?kP<0Wl_Z
102ObNL80:38i0@0XLWU102SbND30:C:iP@0YL[U102Vb^D40:K9h`@0YLOP102UaMd30:G3g0@0YL;J
102T`MT40:C1f0P0YL7I102V`MP30:K0f0@0Y[oF102U_]@40:>kd0@0XKO<102O]//309nfc0@0WkO<
102N]ld409fhcP@0VkO=102I]ld409Jfb`<0T[?:102>/<L408V]a@@0PjS1101nXk`407^P^0<0N9bd
101dUjh406nAY`@0JXZP101TQ9T405imTP<0F7J;101BL8@404aYO@@0AF9f5P3oool001@0oooo1016
I7P404i]PP@0EGF;0`1LOY@406>6WP@0JXnX101bV;4407VQ^`@0P:[50`27//l408fkf@@0U<CS102I
c>`409kBl@@0XM;a102Qcnh309o;jP@0WlWW202Pb>@40:79i@@0XlWU0`2Tb^H40:G:i@@0Y/[U102V
bN<40:G7h0@0YLGM0`2U`m`40:G2fP@0Y<7I102T`MP80:G1f@@0Y/7H0`2V`=P40:JoeP@0YKkD102S
^m040:6gc0@0WkK;0`2O]/`409ngc0@0W[O=102M^<h409^gc@@0VKO=102F]//309:cbP@0S[371029
[LD408>X`@@0OZ>l101kX;P307RL]0@0M9N^101_TJL406Z:X0@0I8BI101NOI8305QfR`@0DW24101<
JGd404ERMQH0oooo000D0?ooo`@0AfEi101>KH8405IfS0<0GWnF101UR:0406fAZP@0MI^d101lY;h4
08B]b@<0S;OC102C`Ml409_;j`@0X];c102We?D40:WDl`@0Z=7`0`2Vcn`40:G=jP@0YLcX102Vc>P4
0:O=j@@0Z<oZ0`2Zd>`40:_Ak0@0[=7Z102/d>T40:c>iP@0Zl_T0`2ZbN440:W7g`@0ZLGM102Ya=/8
0:W4fP@0ZL?J0`2Y`]P40:W1e`@0Z;oD102W_M880:Jld@<0YKcA102U_M840:BmdP@0XkcA102Q^m04
09jjd0@0W;S>0`2H]/d409BdbP@0Sk78102:[LD408N/a0@0PjS00`1mX;L407NI/0@0LI:X101[Rj44
06F5VP@0GgjB0`1IMh/4059`Q0@0C6Um1016HgHF0?ooo`00503oool404MUN@@0CVf2101FMX`305io
UP@0IHRP101]TJX407FK]0@0O:Bn1024[LT308bgd`@0Tl7O102Kbn/40:;Bl`@0YmCe102Ye?<40:SA
l0<0Y/o/102UcNX40:G<j0@0Y/cX102WcNT40:S?jP<0Z]3/102[dN`40:cAjP@0[=3Y102/c^H40:_;
i0<0Z/WQ102Yaml40:W5g@@0ZLCK202Ya=X40:W3fP<0ZL;H102Y`ML40:Roe0@0YkgB202V_=430:Fl
d@@0YKgB102T_M840:>ld@@0XK_@102N^]0409bhcP<0V;K=102D]<X408nab0@0RZg51027[<@408>X
`0<0OJ2g101gVK04076BZ0@0Jh^Q101UQIX405mnTP<0FGN;101BL8@404aYO@@0AV=f5P3oool001@0
oooo1017IGT404i]PP@0EWJ<0`1NOiH406F8X0@0KI6Z101eVk@407bT_P@0Q:g90`2<]m<409?1g`@0
Vl_[102Rd_<40:ODm@@0ZMCc102XdO030:K?k0@0YLgZ102Uc>P40:K<j0@0YlgY102XcnX30:[@k0@0
Zm7/102/dNX40:c@j@@0[<kV102[bn@30:[9h@@0ZLOO102YaMd40:W4f`P0ZLCJ102Y`mX30:W2f0@0
ZL7G102X_m@40:NmdPP0Y[cA0`2U_=440:FmdP@0Y;gB102S_=440:6kd0@0W[[@102L^<h309Rfc@@0
U;C:102?/LP408Z]a@@0Qjc41023Z<0307fP]`@0MiV`101aTZP406^;X@@0IHFJ101OOY8305UgR`@0
DW24101<JGd404ISMQH0oooo000D0?ooo`@0AfEi101>KH8405IfS0<0GWnF101UR:0406fAZP@0MI^d
101lY;h408B]b@<0S;OC102C`Ml409_;j`@0X];c102We?D40:WDl`@0Z=7`0`2Vcn`40:G=jP@0YLcX
102Vc>P40:O=j@@0Z<oZ0`2Zd>`40:_Ak0@0[=7Z102/d>T40:c>iP@0Zl_T0`2ZbN440:W7g`@0ZLGM
102Ya=/80:W4fP@0ZL?J0`2Y`]P40:W1e`@0Z;oD102W_M880:Jld@<0YKcA102U_M840:BmdP@0XkcA
102Q^m0409jjd0@0W;S>0`2H]/d409BdbP@0Sk78102:[LD408N/a0@0PjS00`1mX;L407NI/0@0LI:X
101[Rj4406F5VP@0GgjB0`1IMh/4059`Q0@0C6Um1016HgHF0?ooo`00503oool404MUN@@0Cfj3101G
Mhd305n1U`@0IhZQ101`U:`407RM]P@0P:O11029/L`3096ke`@0V/KS102SdO040:cKnP@0]=om102e
gOT40;7Gl`<0[M?^102[dN`40:[@k0@0Zm7/102/dNd40:gBkP<0[mC^102aeNl40;?Fk`@0/mG]102b
dnX40;7@i`<0/<gU102^bn840:g8g`@0[<OM102/aM`40:g4f`L0[LCJ102]`mT40:c2e`@0[<;F202/
`]D30:g2eP@0[<;F102[`MD40:W0e0@0Y[kB102T_=440:6kd0<0W[[?102J^<h409NgcP@0T[C<102=
/LX408N/a0<0PJ>i101jVk4407BDZ@@0KHbQ101WQIX4061nT`<0FWN;101CL8@404eZO@@0AV=f5P3o
ool001@0oooo1017IGT404m^P`@0EgN=0`1OPIL406N:X@@0L9B/101hWKH4082W`@@0RK7<0`2A^mL4
09[6h`@0Xm7`102/foX40;COo@@0]Mgi102aeo<30:gCkP@0Zm7/102Zd>`40:_Ak0@0[=7]102]d^h3
0:oDkP@0/MG_102ce^l40;?Ek@@0/]?Z102ad>L30;3=i@@0[/_R102]b=l40:c7g@@0[<GL102]a=/7
0:g4fP@0[L?I102/`]L40:c2ePP0[<;E0`2]`]H40:c2eP@0Zl7E102Y`=@40:JndP@0Y;cA102Q^m03
09jjc`@0V[S>102G]lh409:dc0@0SK7:1027[<@3086S^@@0NY^a101dU:T406f<X@@0IhFJ101POY<3
05YgR`@0Dg24101=JWd404ISMQH0oooo000D0?ooo`@0AfEi101?KX<405MgS@<0Gh6G101WRZ44072D
[0@0N9ff1020Yl4408Vac0<0TK_G102Ja^<40:?Al0@0[=_j102dgod40;GMn@@0/MOc0`2]dnh40:_A
k0@0Z]3/102[dN`40:cAk@@0[M;^0`2_e>h40;7Ek`@0/mK_102ceNd40;;CjP@0/M3W0`2`cND40:k;
hP@0[LSO102/amd40:c5g0@0[LCK1`2]a=X40:g3f@@0[<;G102/`]H80:c2e@<0[L;F102/`]H40:_1
e@@0ZL3D102V_]840:Bld@@0XK_@0`2N^/l409ZhcP@0UkO>102B]<`408fabP@0Qjc40`21XkT407ZK
/@@0M9BY101]S:4406N5VP@0H7jC0`1JMh/405=`Q0@0CFYm1016HgHF0?ooo`00503oool404MUN@@0
Cfj3101GMhd305n1U`@0IhZQ101`U:`407RM]P@0P:O11029/L`3096ke`@0V/KS102SdO040:cKnP@0
]=om102egOT40;7Gl`<0[M?^102[dN`40:[@k0@0Zm7/102/dNd40:gBkP<0[mC^102aeNl40;?Fk`@0
/mG]102bdnX40;7@i`<0/<gU102^bn840:g8g`@0[<OM102/aM`40:g4f`L0[LCJ102]`mT40:c2e`@0
[<;F202/`]D30:g2eP@0[<;F102[`MD40:W0e0@0Y[kB102T_=440:6kd0<0W[[?102J^<h409NgcP@0
T[C<102=/LX408N/a0<0PJ>i101jVk4407BDZ@@0KHbQ101WQIX4061nT`<0FWN;101CL8@404eZO@@0
AV=f5P3oool001@0oooo1017IGT4051_P`@0F7R=0`1QPYP406V<XP@0LYJ]101kX;T408BZa0@0SKG?
0`2F_m/409o:iP@0Z=Ca102cg_X40;WQo0@0^^3j102gfoD30;;Fl0@0/=C^202_dnd40;3CkP@0/]G^
0`2eenl40;OHl0@0^MWa202if_440;OGkP<0]M?Z102bcnD40;3;h@@0[lSN102_amd80;37g0<0/LOK
102aa]/40;76fP@0//KJ102camX70;C8f`@0/lSK102aamX40:o5f0@0[L;F102Z`=@40:Nod`<0Y;gA
102Q_=4409jjd0@0V[W?102D]L/408b]``<0QJFj101nW;8407NEZP@0L8fR101YQYX4069oT`<0FgR<
101DLH@404eZO@@0AV=f5P3oool001@0oooo1017IGT4051_P`@0F7R=0`1QPYP406V<XP@0LYJ]101k
X;T408BZa0@0SKG?0`2F_m/409o:iP@0Z=Ca102cg_X40;WQo0@0^^3j102gfoD30;;Fl0@0/=C^202_
dnd40;3CkP@0/]G^0`2eenl40;OHl0@0^MWa202if_440;OGkP<0]M?Z102bcnD40;3;h@@0[lSN102_
amd80;37g0<0/LOK102aa]/40;76fP@0//KJ102camX70;C8f`@0/lSK102aamX40:o5f0@0[L;F102Z
`=@40:Nod`<0Y;gA102Q_=4409jjd0@0V[W?102D]L/408b]``<0QJFj101nW;8407NEZP@0L8fR101Y
QYX4069oT`<0FgR<101DLH@404eZO@@0AV=f5P3oool001@0oooo1017IGT4051_P`@0F7R=0`1QPYP4
06V<XP@0LYJ]101kX;T408BZa0@0SKG?0`2F_m/409o:iP@0Z=Ca102cg_X40;WQo0@0^^3j102gfoD3
0;;Fl0@0/=C^202_dnd40;3CkP@0/]G^0`2eenl40;OHl0@0^MWa202if_440;OGkP<0]M?Z102bcnD4
0;3;h@@0[lSN102_amd80;37g0<0/LOK102aa]/40;76fP@0//KJ102camX70;C8f`@0/lSK102aamX4
0:o5f0@0[L;F102Z`=@40:Nod`<0Y;gA102Q_=4409jjd0@0V[W?102D]L/408b]``<0QJFj101nW;84
07NEZP@0L8fR101YQYX4069oT`<0FgR<101DLH@404eZO@@0AV=f5P3oool001@0oooo1017IGT4051_
P`@0F7R=0`1QPYP406V<XP@0LYJ]101kX;T408BZa0@0SKG?0`2F_m/409o:iP@0Z=Ca102cg_X40;WQ
o0@0^^3j102gfoD30;;Fl0@0/=C^202_dnd40;3CkP@0/]G^0`2eenl40;OHl0@0^MWa202if_440;OG
kP<0]M?Z102bcnD40;3;h@@0[lSN102_amd80;37g0<0/LOK102aa]/40;76fP@0//KJ102camX70;C8
f`@0/lSK102aamX40:o5f0@0[L;F102Z`=@40:Nod`<0Y;gA102Q_=4409jjd0@0V[W?102D]L/408b]
``<0QJFj101nW;8407NEZP@0L8fR101YQYX4069oT`<0FgR<101DLH@404eZO@@0AV=f5P3oool001@0
oooo1018IGT4051_P`@0FGV>0`1RPiT406^=X`@0M9N_101nX[/408R^a`@0T[WC0`2Ka=h40:C>jP@0
[=G`102bfO<40;SMm`@0^mkg102ifo@30;GGl@@0/mG_102be>d40;;Ck0@0]=G^102gf?430;_Lm@@0
_moh1031h?P40<7OmP@0_]gc102lf_030;WGk@@0]]7W102cc>440;79g@P0/LOK102bam`30;?7g0@0
]LSL102fbM`40;S;g@@0^/cN102jcMl30;[<g`@0^LcN102gb]d40;C8fP@0/LGH102_a=L40:c2e@<0
ZL3C102W_m840:FodP@0XKkB102J^<d4096^``<0RJJj1021W[8407VFZP@0LXjR101ZQiX406=oT`<0
G7R<101ELH@404eZO@@0AV=f5P3oool001@0oooo1018IGT4051_P`@0FGV>0`1RPiT406^=X`@0M9N_
101nX[/408R^a`@0T[WC0`2Ka=h40:C>jP@0[=G`102bfO<40;SMm`@0^mkg102ifo@30;GGl@@0/mG_
102be>d40;;Ck0@0]=G^102gf?430;_Lm@@0_moh1031h?P40<7OmP@0_]gc102lf_030;WGk@@0]]7W
102cc>440;79g@P0/LOK102bam`30;?7g0@0]LSL102fbM`40;S;g@@0^/cN102jcMl30;[<g`@0^LcN
102gb]d40;C8fP@0/LGH102_a=L40:c2e@<0ZL3C102W_m840:FodP@0XKkB102J^<d4096^``<0RJJj
1021W[8407VFZP@0LXjR101ZQiX406=oT`<0G7R<101ELH@404eZO@@0AV=f5P3oool001@0oooo1018
IGT4051_P`@0FGV>0`1RPiT406^=X`@0M9N_101nX[/408R^a`@0T[WC0`2Ka=h40:C>jP@0[=G`102b
fO<40;SMm`@0^mkg102ifo@30;GGl@@0/mG_102be>d40;;Ck0@0]=G^102gf?430;_Lm@@0_moh1031
h?P40<7OmP@0_]gc102lf_030;WGk@@0]]7W102cc>440;79g@P0/LOK102bam`30;?7g0@0]LSL102f
bM`40;S;g@@0^/cN102jcMl30;[<g`@0^LcN102gb]d40;C8fP@0/LGH102_a=L40:c2e@<0ZL3C102W
_m840:FodP@0XKkB102J^<d4096^``<0RJJj1021W[8407VFZP@0LXjR101ZQiX406=oT`<0G7R<101E
LH@404eZO@@0AV=f5P3oool001@0oooo1018IWT4055_Q0@0FWV>0`1SPiT406b>Y0@0MYV`1021YK`4
08bab@@0UkgF0`2QbN<40:[CkP@0/][d102kgoL40<3Qn0@0_]kf102jf_830;OGk`@0]MG]102cdn/4
0;?BjP@0/m;Y102ednX30;SFk0@0_MW^1033gO840<CMl`@0`M_a102nfNh30;_Hk@@0]m;W102dbml4
0;;7f`@0//KI102ca]T40;C7fP<0]/SK102hb]d40;[<gP@0^lcN102lc]l40;k@h@<0`=;S102odN84
0;c>h0@0^L_M102fbM/40;C7f@@0//GG0`2_`mD40:c1d`@0ZKoA102S_<d409bfb0@0U:o10`2<Y[T4
08BO/P@0O9NZ101dSj8406b7VP@0I82C0`1MN8/405EaQ0@0CVYm1017HgHF0?ooo`00503oool404QV
N@@0DFn4101JNHh306>3V@@0K8jT101fVK04086U_0@0S;79102G_MH30:79h`@0Z]?^102bf_@40;_O
m`@0`>7h102ng_H40;[JlP<0]mO_102eeNd40;?Cj`@0/m;Z102cd^T40;GCjP<0^=K/102mfNh40<?M
lP@0a=gc1031fo440;kIkP<0^mS]102gd^L40;C;g`@0//OK102ba]T40;?6f@@0]<OJ0`2fb=/40;S:
g@@0^/cN102kc=h40;c>g`@0_]3Q0`30d^<40;oAhP@0_<kP102ibmd40;K9f`@0]<OI102baML30:o3
e@@0[<7C102Y_m440:>lc@@0W;K8102D[l4308bV^@@0Q9nb101lUjX407B?XP@0K8NJ101TP9<305eh
R`@0EG64101>JWd404MSMQH0oooo000D0?ooo`@0B6Ii101AKh@405YiSP<0Hh>I101/SZ@407JI/0@0
PJFl102</LT409NmeP<0XLWS102Zdnh40;;Jm0@0^mog1030hOP40;kNmP@0^][b0`2genl40;GEk@@0
/m?[102cd^X40;?Bj@@0]M?Z0`2he^`40;gIkP@0`mgb1034gO<40<7Kl@@0_]W^0`2kf>d40;OBi`@0
]<_O102bam/40;;6f@@0/lKI102damX30;K8f`@0^<[M102jc=h40;_<gP@0_<kO102nd>430<3Bh`@0
_m7R102lc^040;W;g@@0]/WK102damT40;;5e`<0[l?E102/`M<40:Vod@@0Xkc=102L]/P409B_`@<0
S:Ji1024Wk8407bGZP@0M8nR101/QiX406B0T`<0GGR;101ELH@404iZO@@0Af=f5P3oool001@0oooo
1018IWT4055_Q0@0FWV>0`1SPiT406b>Y0@0MYV`1021YK`408bab@@0UkgF0`2QbN<40:[CkP@0/][d
102kgoL40<3Qn0@0_]kf102jf_830;OGk`@0]MG]102cdn/40;?BjP@0/m;Y102ednX30;SFk0@0_MW^
1033gO840<CMl`@0`M_a102nfNh30;_Hk@@0]m;W102dbml40;;7f`@0//KI102ca]T40;C7fP<0]/SK
102hb]d40;[<gP@0^lcN102lc]l40;k@h@<0`=;S102odN840;c>h0@0^L_M102fbM/40;C7f@@0//GG
0`2_`mD40:c1d`@0ZKoA102S_<d409bfb0@0U:o10`2<Y[T408BO/P@0O9NZ101dSj8406b7VP@0I82C
0`1MN8/405EaQ0@0CVYm1017HgHF0?ooo`00503oool404QVN@@0DFn4101JNHh306>4V@@0KHjT101h
V[0408>V_@@0SkC<102L`]/30:S?j@@0/MWb102gg?H40;WKl`@0^]_a102kfo440;WHk`<0]mG[102f
dnX40;GBj0@0]=7V102ccn<40;7<h0<0[l[N102`bml40;C=hP@0]lkS102hc^440;K;gP<0//OJ102a
aMP40;;6f@@0//GG102ca=H40;?5e`@0]LKH0`2gbMX40;[=g@@0_LoP1030d>440<CDi@@0amOW0`37
e^H40<CCi0@0`M7R102ncn040;[<g@@0]lWJ102eamP30;?6eP@0//GE102``m<40:Zmc@@0XKG5102H
[[l308nW^@@0Qina101nUjX407J@XP@0KHRJ101UP9<305iiR`@0EW64101>JWd404MSMQH0oooo000D
0?ooo`@0B6Ii101AKh@405YiSP<0HhBI101]SZ@407RJ/0@0PjJm102?]<`409c2f`<0Z<oY102afO84
0;OLmP@0^M_c102jfo440;_Kl@@0^MS_0`2geN/40;KCjP@0]M;X102ddNH40;??h`@0/LcP0`2_b]h4
0;3;g`@0]<gR102gc^<40;S>h@@0]/_N0`2bamX40;75f0@0//KI102baML40;?4eP@0/lGG102ea]P3
0;O9fP@0^/gM102mcn040<3@h@@0a=CU1037enL30<OFiP@0a=?T1031dN840;k?h0@0^/cM102gbMX4
0;G7f0<0/lKF102baMD40;33d`@0Z[g=102Q]LD409R^_`<0SjNi1027Wk4407jGZP@0MY2R101]R9X4
06F0T`<0GWV;101FLH@404iZO@@0Af=f5P3oool001@0oooo1018IWT4055_Q0@0FWV>0`1SQ9T406f>
Y0@0N9Z`1023Y[d408ndc0@0W<;K0`2XcnT40;7IlP@0]mcf102ifo<40;[Kl@@0^m_a102if>l30;OE
j`@0]]?Z102ed^P40;CAiP@0/loS102ac>030:o:gP@0/<_O102dcN840;O>h`@0^<kQ102fbmh30;;7
fP@0/LGH102ba]T40;;5e`@0/lCF102caML40;G6f0<0]lWJ102jcMd40;g?h0@0`=3Q1034e>D40<OG
i`<0amKV1034dn@40<7AhP@0_/oP102jc=d40;O9fP@0]LOH0`2ca]H40;;5e@@0/<?C102Z_Ld40:6e
a@@0V:jo0`2?YkT408NO/@@0OYNZ101fT:8406f8VP@0IH2C0`1NNH/405IaQ0@0CVYm1017HgHF0?oo
o`00503oool404QVN@@0DFn4101JNHh306>4V@@0KHjT101hV[0408>V_@@0SkC<102L`]/30:S?j@@0
/MWb102gg?H40;WKl`@0^]_a102kfo440;WHk`<0]mG[102fdnX40;GBj0@0]=7V102ccn<40;7<h0<0
[l[N102`bml40;C=hP@0]lkS102hc^440;K;gP<0//OJ102aaMP40;;6f@@0//GG102ca=H40;?5e`@0
]LKH0`2gbMX40;[=g@@0_LoP1030d>440<CDi@@0amOW0`37e^H40<CCi0@0`M7R102ncn040;[<g@@0
]lWJ102eamP30;?6eP@0//GE102``m<40:Zmc@@0XKG5102H[[l308nW^@@0Qina101nUjX407J@XP@0
KHRJ101UP9<305iiR`@0EW64101>JWd404MSMQH0oooo000D0?ooo`@0B6Ij101AKh@405YiSP<0I8>H
101^SZ@407RJ/0@0Q:Jm102B]Ld40:;7g`<0]=cf102niOl40;kPn0@0_Mcc102lf^l40;_Hk@@0^]K[
0`2he>T40;KBi`@0]M7U102ed>@40;?=h@@0/LWK0`2^a]P40:[2e0@0YKc?102U^lh40:Rmd@@0ZkkA
0`2^_m440;32d`@0/L?E102ba=D40;?4e@P0/lCD0`2da=@40;G3d`@0^<GD102oc=T40<KCh0@0b=GS
0`36e>840<SEi0@0a]GS1031dN440;g>gP@0^L[I102gamL70;O7eP@0]/GD102a`M040:Nib0@0W;31
0`2CZKX408VQ/P@0P9RZ101gT:8406n8VP@0IX2B0`1NNH/405IaQ0@0CfYm1017HgHF0?ooo`00503o
ool404QVNP@0DFn4101JNHh306B3V0@0KXjT101hV[0408BV_@@0T[G=102Raml30;CLmP@0_^Go102n
h?P40;gLl`@0_=[_102kf>d40;[Fj`<0^=CY102fd^L40;GAi@@0]M3T102ccN440;79f`<0[/KH102Z
`]@40:Flc`@0YK_>102X_M440:^nd@<0[[oA102``]<40;73e@@0//CE102ca=D80;?4e0<0]<CD102e
`m<40;S5e0@0_lcI1036dn040<SEh`<0a]CR1038eN@40<KEh`@0`M7Q102mc]h40;W:f@@0]lOG1`2g
amH40;K5e0@0/L7@102W^LP409b``@<0TjVj1029XK84082HZP@0Mi2R101_R9X406J0TP<0GWV;101F
LH@404mZO@@0Af=f5P3oool001@0oooo1018IWX4055_Q0@0FWV>0`1TPiP406j>Y0@0N9Z`1024Y[d4
09:ec@@0X/OO0`2dg?H40;kUo`@0_^3h102mg?<40;cJk`@0^mS]102je^/30;SDj@@0]];W102edND4
0;G@i0@0/lgQ102abM/30:k6f0@0Z/;D102U_<l40:FkcP@0Z;gA102[_]430:jod@@0/<;C102a`mD4
0;;4e@@0/lCE202ca=@30;C4e0@0]L?C102haM@40;o<f@@0a]?P1038eN<30<KDhP@0b=GT1036eN<4
0<7Ah@@0_LkN102ib]T40;O7e`L0]lOF102faM@40;71d0@0YkW8102L/<4309>Y^P@0RJ6b1020V:X4
07N@XP@0KhRJ101VP98305iiR`@0EW64101?JWd404MSMQH0oooo000D0?ooo`@0B6Ij101AKh@405Yi
SP<0I8>H101^SZ@407RJ/0@0Q:Jm102B]Ld40:;7g`<0]=cf102niOl40;kPn0@0_Mcc102lf^l40;_H
k@@0^]K[0`2he>T40;KBi`@0]M7U102ed>@40;?=h@@0/LWK0`2^a]P40:[2e0@0YKc?102U^lh40:Rm
d@@0ZkkA0`2^_m440;32d`@0/L?E102ba=D40;?4e@P0/lCD0`2da=@40;G3d`@0^<GD102oc=T40<KC
h0@0b=GS0`36e>840<SEi0@0a]GS1031dN440;g>gP@0^L[I102gamL70;O7eP@0]/GD102a`M040:Ni
b0@0W;310`2CZKX408VQ/P@0P9RZ101gT:8406n8VP@0IX2B0`1NNH/405IaQ0@0CfYm1017HgHF0?oo
o`00503oool404QUN@@0DFj2101JN8`306>2UP@0KHfR101hV:h408BU^`@0T[C;102Vb^<30;CHl@@0
_n3g1036iO/40<GQmP@0_m_`102je^/40;OCj0<0]];V102fd><80;G@hP@0]<gN102bb=T30:o4e0@0
[<3?102Z_Ld40:Vkb`@0ZK[9102[^l/30:fmc0@0/;o>102a`M440;;2dP@0/l?B102c`]440;?1d0<0
/l3?102b_ll40;;0c`@0//7@102d`m440;S6e0<0^lWG202kb]P40;W8eP@0^<OD102hamD40;W7e@<0
^/OE102kbML40;[8e@@0/l;@102Z_L`40:6ea@<0UZ^k102<X[8408:IZP@0NI2Q101`R9T406N0TP<0
GgR:101GLH<404mZO0@0Af=f5P3oool001@0oooo1018IGT4055^PP@0FWR<0`1SPYH406f=XP@0N9R^
1024YK/409:db`@0Y/[S0`2df?440;oPm`@0a^Gk1035hOH40;oKl0@0^]K[102gdnP30;KBiP@0]]3S
202ed>840;C=gP@0//SI0`2_a=@40:c0c`@0Z[g=102Y^l/40:Vjb@@0Zk_;0`2]_L`40;2ocP@0/L7A
102b`]840;?3dP@0/l;A102c`M030;?0c`@0/[o?102b`<l40;;1d0@0]<?A102ha]@30;_9e`P0^l[H
102ib=H40;S7e0@0^<OE102iamD30;[7e@@0^lWG102jb=D40;?2d0@0Z[g<102Q]LD309J[^`@0S::b
1022VJX407V@X@@0L8RI101WP98305mhRP@0Eg63101?JW`404MSMQH0oooo000D0?ooo`@0B6Ei101A
KX8405YhS0<0Hh:F101]SJ8407RH[P@0Q:Fk102B]</40:K:h`<0]=Sa102oh?L40<KUn`@0aN7f102o
fo040;[Fj`@0]m?X0`2fd^H40;K@h`P0]M3R102dcMh40;;8f@<0[lCD102/`<l40:Zmc@@0ZK_;102Y
^/T40:^kb`<0[Kg<102`_lh40;71d@@0//;B102c`m840;?2d@@0/l7@0`2c`<l40;:oc`@0//3?102b
`M040;C3d@@0^<KD0`2kbML80;_:f0@0^LSF102ham@40;S7e@@0^LOE0`2jamD40;_9e`@0^/SE102c
`]040:Zmc0@0XKG50`2FZk/408bR/P@0PYVZ101iT:440728V@@0Ih2B0`1ON8X405MaP`@0CfYl1017
HgHF0?ooo`00503oool404QUN@@0DFj2101JN8`306>2UP@0KHfR101hV:h408BU^`@0T[C;102Vb^<3
0;CHl@@0_n3g1036iO/40<GQmP@0_m_`102je^/40;OCj0<0]];V102fd><80;G@hP@0]<gN102bb=T3
0:o4e0@0[<3?102Z_Ld40:Vkb`@0ZK[9102[^l/30:fmc0@0/;o>102a`M440;;2dP@0/l?B102c`]44
0;?1d0<0/l3?102b_ll40;;0c`@0//7@102d`m440;S6e0<0^lWG202kb]P40;W8eP@0^<OD102hamD4
0;W7e@<0^/OE102kbML40;[8e@@0/l;@102Z_L`40:6ea@<0UZ^k102<X[8408:IZP@0NI2Q101`R9T4
06N0TP<0GgR:101GLH<404mZO0@0Af=f5P3oool001@0oooo1018I7L4055]P@@0FGN;0`1SP9D406b;
W`@0MiFZ1022XKL408j^a0@0W;cC0`2Xamh40;;>i0@0^]GY102men/40;[Dj@@0]];U102fdN@30;G?
hP@0]LgP102cbM/40;;7e`@0]<WJ102eb]X30;C7e`@0/lCB102a`<h40;2nc0@0[kg;1`2`_//40;2m
b`@0/Ko>102b`]040;?2d@@0/l7?102c`Ld30;C1c@@0]<7>102d`<h40;6nc0@0ZkW7102W]/D30:^j
b0@0[Kg;102`_/`40;?1cP@0]lC@102iaM440;[6dP<0_<SD102mb=@40;[6dP@0/l7>102[_<X40:>e
a0<0VJbk102>Xk8408BIZ@@0NY2Q101`R9P406N0T@<0GgR:101GLH<404mZO0@0Af=e5P3oool001@0
oooo1018I7L4055]P@@0FGN;0`1SP9D406b;W`@0MiFZ1022XKL408j^a0@0W;cC0`2Xamh40;;>i0@0
^]GY102men/40;[Dj@@0]];U102fdN@30;G?hP@0]LgP102cbM/40;;7e`@0]<WJ102eb]X30;C7e`@0
/lCB102a`<h40;2nc0@0[kg;1`2`_//40;2mb`@0/Ko>102b`]040;?2d@@0/l7?102c`Ld30;C1c@@0
]<7>102d`<h40;6nc0@0ZkW7102W]/D30:^jb0@0[Kg;102`_/`40;?1cP@0]lC@102iaM440;[6dP<0
_<SD102mb=@40;[6dP@0/l7>102[_<X40:>ea0<0VJbk102>Xk8408BIZ@@0NY2Q101`R9P406N0T@<0
GgR:101GLH<404mZO0@0Af=e5P3oool001@0oooo1018I7L4055]P@@0FGN;0`1SP9D406b;W`@0MiFZ
1022XKL408j^a0@0W;cC0`2Xamh40;;>i0@0^]GY102men/40;[Dj@@0]];U102fdN@30;G?hP@0]LgP
102cbM/40;;7e`@0]<WJ102eb]X30;C7e`@0/lCB102a`<h40;2nc0@0[kg;1`2`_//40;2mb`@0/Ko>
102b`]040;?2d@@0/l7?102c`Ld30;C1c@@0]<7>102d`<h40;6nc0@0ZkW7102W]/D30:^jb0@0[Kg;
102`_/`40;?1cP@0]lC@102iaM440;[6dP<0_<SD102mb=@40;[6dP@0/l7>102[_<X40:>ea0<0VJbk
102>Xk8408BIZ@@0NY2Q101`R9P406N0T@<0GgR:101GLH<404mZO0@0Af=e5P3oool001@0oooo1018
I7L4055]P@@0FGN;0`1SP9D406b;W`@0MiFZ1022XKL408j^a0@0W;cC0`2Xamh40;;>i0@0^]GY102m
en/40;[Dj@@0]];U102fdN@30;G?hP@0]LgP102cbM/40;;7e`@0]<WJ102eb]X30;C7e`@0/lCB102a
`<h40;2nc0@0[kg;1`2`_//40;2mb`@0/Ko>102b`]040;?2d@@0/l7?102c`Ld30;C1c@@0]<7>102d
`<h40;6nc0@0ZkW7102W]/D30:^jb0@0[Kg;102`_/`40;?1cP@0]lC@102iaM440;[6dP<0_<SD102m
b=@40;[6dP@0/l7>102[_<X40:>ea0<0VJbk102>Xk8408BIZ@@0NY2Q101`R9P406N0T@<0GgR:101G
LH<404mZO0@0Af=e5P3oool001@0oooo1018I7L4051]P0@0FGF90`1QOi<406^8W0@0M9:V101nW;44
08VW_0@0U;760`2O_=440:[4f0@0/<WM102cc>040;C<h0@0]LcO102ecN030;K>h0@0]<_L102camP4
0;33dP@0[[k<102]_<T30:bka`@0ZKK2102U/Kd40:F_^P@0Y[2k102X/K`30:^e`0@0[k[6102b_//4
0;?1cP@0]<;>102d`<`40;>obP<0]L7;102g`ld40;O3cP@0]L7=102b_//40:nlb0<0[[[6102_^/H4
0;:mb0@0]/7;102ia<d40;[6c`@0_<OA0`2nbM<40;o9d`@0^lG?102a_LT40:^ia@@0Y[K40`2L[[d4
092S/P@0QIVX101jSil40727U`@0Ign@0`1OMhT405M`PP@0CfUk1017HWDF0?ooo`00503oool404QT
M`@0D6f0101IMHT3065oT`@0JhRL101dTZH407jL/@@0RJNl102D/LH309nld@@0Z/CH102`bMd40;?<
h0@0]<cP102ec=l40;G=h0<0]/kP102dbm`40;?7f0@0/<?B102^_/`40:flb@<0[;_7102Y]/840:Fa
_@@0YJnj102V/;/40:Ra_0<0ZkG0102_^/H40;:nb`@0/l7>102d`/h40;C0c0@0/ko:0`2e`L/40;O3
c@@0]l?>102e`Ld40;:nb`@0[kc80`2^^/H40:njaP@0/[g8102f`L/40;W4c@@0^/K?102lam430;k9
d`@0_lWC102kaLl40;6mb@@0ZkW5102V]/@309b^_@@0T:>b1025VJP407Z?W`@0L8NG101WOi0305mg
R@@0Eg22101?JG/404MRMAH0oooo000D0?ooo`@0B6Ag101@KH0405UeR@<0HGnC101[R9`407BBYP@0
OYba1029Yk`409BaaP<0WkcA102Za=P40;39g@@0/lcP102dc>040;G<g`@0]LgP0`2fc^040;C;g0@0
/lOH102``m840:jnc0@0[Kc90`2/^lL40:Vf`P@0YK6m102U[kX40:J`^`@0Z;6l0`2[]L040:njaP@0
/[k;102c`Lh40;C2cP@0]<3<102c_lX30;G1b`@0]l?=102g`lh40;G1c@@0/[k;102__<P30:jjaP@0
[k[6102b_LP40;K1b`@0^LC=102ja/l40;c7d@<0_/WC102obM<40;_5c`@0/Kg9102[^LD40:Jfa0<0
W:jm102@Xk8408FIZ0@0NXnO101`QiL406MoT0<0GgN9101GL88404mYN`@0Af9e5P3oool001@0oooo
1018I7L4051]P0@0FGF90`1QOi<406^8W0@0M9:V101nW;4408VW_0@0U;760`2O_=440:[4f0@0/<WM
102cc>040;C<h0@0]LcO102ecN030;K>h0@0]<_L102camP40;33dP@0[[k<102]_<T30:bka`@0ZKK2
102U/Kd40:F_^P@0Y[2k102X/K`30:^e`0@0[k[6102b_//40;?1cP@0]<;>102d`<`40;>obP<0]L7;
102g`ld40;O3cP@0]L7=102b_//40:nlb0<0[[[6102_^/H40;:mb0@0]/7;102ia<d40;[6c`@0_<OA
0`2nbM<40;o9d`@0^lG?102a_LT40:^ia@@0Y[K40`2L[[d4092S/P@0QIVX101jSil40727U`@0Ign@
0`1OMhT405M`PP@0CfUk1017HWDF0?ooo`00503oool404MTM`@0Cfao101GM8P3061lT0@0J8FH101a
SZ4407ZGZP@0Pinc102<Yk/309F```@0W[S;102U_]440:_3eP@0[/KI102ab=X40;C;g@<0]/cM102e
b]/40;?7e`@0//?A102__//40:bg``<0Z;6l102U[KP40:BZ/`@0Y:Va102UZK440:R]]P<0[KBo102a
^lH40;Bob`@0]/7>102f`Ld40;Bob`@0/[_70`2_^<840;2i`P@0]/37202ja<d40;O1b`<0][o:102e
_lX40;O1bP@0^L?<102kaLh40;c5cP@0_LO?0`30bM440;k8d0@0^<;;102e_lT40;6mb0@0[Kc90`2R
/l44096S/@@0QIRV101jSYd40725U@@0Igf>0`1NMXL405I_P@@0CVUk1017HWDF0?ooo`00503oool4
04MTM`@0Cfao101GM8P3061lT0@0J8FH101aSZ4407ZGZP@0Pinc102<Yk/309F```@0W[S;102U_]44
0:_3eP@0[/KI102ab=X40;C;g@<0]/cM102eb]/40;?7e`@0//?A102__//40:bg``<0Z;6l102U[KP4
0:BZ/`@0Y:Va102UZK440:R]]P<0[KBo102a^lH40;Bob`@0]/7>102f`Ld40;Bob`@0/[_70`2_^<84
0;2i`P@0]/37202ja<d40;O1b`<0][o:102e_lX40;O1bP@0^L?<102kaLh40;c5cP@0_LO?0`30bM44
0;k8d0@0^<;;102e_lT40;6mb0@0[Kc90`2R/l44096S/@@0QIRV101jSYd40725U@@0Igf>0`1NMXL4
05I_P@@0CVUk1017HWDF0?ooo`00503oool404MTM`@0Cfao101GM8P3061lT0@0J8FH101aSZ4407ZG
ZP@0Pinc102<Yk/309F```@0W[S;102U_]440:_3eP@0[/KI102ab=X40;C;g@<0]/cM102eb]/40;?7
e`@0//?A102__//40:bg``<0Z;6l102U[KP40:BZ/`@0Y:Va102UZK440:R]]P<0[KBo102a^lH40;Bo
b`@0]/7>102f`Ld40;Bob`@0/[_70`2_^<840;2i`P@0]/37202ja<d40;O1b`<0][o:102e_lX40;O1
bP@0^L?<102kaLh40;c5cP@0_LO?0`30bM440;k8d0@0^<;;102e_lT40;6mb0@0[Kc90`2R/l44096S
/@@0QIRV101jSYd40725U@@0Igf>0`1NMXL405I_P@@0CVUk1017HWDF0?ooo`00503oool404MSMP@0
CVYn101FLXD305iiS0@0IX6D101^RI`407JAY0@0OYV[1026X;8308jV^0@0UJfo102L]<H40::jb`@0
Yko@102]a=D40;78f@<0]<[J102eb]T40;G8e`@0/lGC102b`Lh40;2lb0<0[[S2102/];h40:bc_0@0
[;:j102]/k/40:nf_P<0/[[3102e_/T40;O2c@P0^<??102f`L`40;Bnb0<0/;[3102]]Kd40:Zc^`@0
[;Jn102c_<@40;[2bPl0_<C<102k`l/40;_3bP@0_LG<0`2oaLd40;c3b`@0^<38102h_lL40;Bla@@0
ZKBo0`2LZ[L408nO[@@0PiFS101hS9X406j3TP@0IW^<0`1MMHD405E^O`@0CVQj1017HW@F0?ooo`00
503oool404MSMP@0CVYn101FLXD305iiS0@0IX6D101^RI`407JAY0@0OYV[1026X;8308jV^0@0UJfo
102L]<H40::jb`@0Yko@102]a=D40;78f@<0]<[J102eb]T40;G8e`@0/lGC102b`Lh40;2lb0<0[[S2
102/];h40:bc_0@0[;:j102]/k/40:nf_P<0/[[3102e_/T40;O2c@P0^<??102f`L`40;Bnb0<0/;[3
102]]Kd40:Zc^`@0[;Jn102c_<@40;[2bPl0_<C<102k`l/40;_3bP@0_LG<0`2oaLd40;c3b`@0^<38
102h_lL40;Bla@@0ZKBo0`2LZ[L408nO[@@0PiFS101hS9X406j3TP@0IW^<0`1MMHD405E^O`@0CVQj
1017HW@F0?ooo`00503oool404MSMP@0CVYn101FLXD305iiS0@0IX6D101^RI`407JAY0@0OYV[1026
X;8308jV^0@0UJfo102L]<H40::jb`@0Yko@102]a=D40;78f@<0]<[J102eb]T40;G8e`@0/lGC102b
`Lh40;2lb0<0[[S2102/];h40:bc_0@0[;:j102]/k/40:nf_P<0/[[3102e_/T40;O2c@P0^<??102f
`L`40;Bnb0<0/;[3102]]Kd40:Zc^`@0[;Jn102c_<@40;[2bPl0_<C<102k`l/40;_3bP@0_LG<0`2o
aLd40;c3b`@0^<38102h_lL40;Bla@@0ZKBo0`2LZ[L408nO[@@0PiFS101hS9X406j3TP@0IW^<0`1M
MHD405E^O`@0CVQj1017HW@F0?ooo`00503oool404MSMP@0CVYn101FLXD305iiS0@0IX6D101^RI`4
07JAY0@0OYV[1026X;8308jV^0@0UJfo102L]<H40::jb`@0Yko@102]a=D40;78f@<0]<[J102eb]T4
0;G8e`@0/lGC102b`Lh40;2lb0<0[[S2102/];h40:bc_0@0[;:j102]/k/40:nf_P<0/[[3102e_/T4
0;O2c@P0^<??102f`L`40;Bnb0<0/;[3102]]Kd40:Zc^`@0[;Jn102c_<@40;[2bPl0_<C<102k`l/4
0;_3bP@0_LG<0`2oaLd40;c3b`@0^<38102h_lL40;Bla@@0ZKBo0`2LZ[L408nO[@@0PiFS101hS9X4
06j3TP@0IW^<0`1MMHD405E^O`@0CVQj1017HW@F0?ooo`00503oool404IRMP@0CFUl101EL8<305ag
RP@0Hgj@101[QIL407:<WP@0NI>U1020VJX308JN/0@0SJFf102E[;d409^b``@0X[W9102Y_ll40;76
eP<0]/[J102gbmX40;K9f0@0]LOE102ea=440;C2cP<0/ko:102b_LL40;:ka0@0/k_4102d_<D40;Jn
a`<0^<7:102j`ld40;_6d0@0_<OA102ka]440;[5c`@0^<?<0`2e_lP40;:ka0@0[kO0102/];d40:Zc
^`@0Zk>k0`2_]kl40;:j`P@0/k_2102d^l840;Rna@@0_<78102n`/T30;g1b0@0^Kk5102e^/840;:f
_`@0[[:j102T[;H309RT/0@0S9^X1020TIl407J8UP@0K82?101TNHT305acP`@0E6en101=IgT404IQ
M1H0oooo000D0?ooo`@0AV9f101=JG`405E`P`<0G7N:101SOY0406^5U`@0LXbN101iTjD4082IZP<0
QYj`102=YKH409F/_@@0Vk;3102R^LT40:Voc`@0/LKF0`2fb]X40;O;fP@0]/WH102eamD40;G4d@@0
]<;>0`2c_lX40;:ma`@0/[_4102c^l@40;Bla@@0][k70`2h`LX40;[3c@@0^lK@102lam440;_6d@@0
^/G?102h`l`30;Fob0@0/[_4102_]l040:bd_@@0Z[>k102[/k/30:ng_`@0/[[2102c^l840;Bk`P@0
^;k5102l`LP40;k2b@<0_L78102i_/D40;Fj`P@0/[Jo102^/[X40:B/]P<0V:B`102<VjP4082AW`@0
MXRF101/P8l406AiR@<0G7>3101DKGh404eWN@@0AV5d5P3oool001@0oooo1016HWH404eYO0@0EG23
0`1LMhX406=nT0@0JhFG101bS9h407VCY@@0P9VZ0`26W[0408fU]P@0UJbm102K//<40::ib@@0ZKo?
102aa]H30;K:fP@0]l_J102fbMP40;G7e@@0]LCA102d`/h30;>obP@0/[g7102b^l@40;>ka0@0];c5
102f_/L30;S1bP@0^/?=102ka]040;c7d@@0^lKA102jaLl40;S3c0<0]Ko8102b^l@40:ng`0@0[;Bm
102Z/k/40:^c^`<0[kNo102b^/840;>k`P@0];_2102h_/D40;c1b0@0_/;90`2m`LP40;Vna@@0]K[2
102b][l40:jb^P@0Y:bf0`2HY;0408bKZ0@0P96O101fR9H406b0S`@0I7V90`1LLh<405A]OP@0CFMi
1016HG@F0?ooo`00503oool404IRMP@0CFUl101EL8<305agRP@0Hgj@101[QIL407:<WP@0NI>U1020
VJX308JN/0@0SJFf102E[;d409^b``@0X[W9102Y_ll40;76eP<0]/[J102gbmX40;K9f0@0]LOE102e
a=440;C2cP<0/ko:102b_LL40;:ka0@0/k_4102d_<D40;Jna`<0^<7:102j`ld40;_6d0@0_<OA102k
a]440;[5c`@0^<?<0`2e_lP40;:ka0@0[kO0102/];d40:Zc^`@0Zk>k0`2_]kl40;:j`P@0/k_2102d
^l840;Rna@@0_<78102n`/T30;g1b0@0^Kk5102e^/840;:f_`@0[[:j102T[;H309RT/0@0S9^X1020
TIl407J8UP@0K82?101TNHT305acP`@0E6en101=IgT404IQM1H0oooo000D0?ooo`@0AV9e101<J7/4
05=^P0<0FWB6101PNX`406N1T`@0KXNH101eSIh407^CY@<0PYV[1028WZl408jT]0@0UZbl102N]<@4
0:Nlc0@0/<GC0`2fb]T40;S<fP@0^<_I102hbMH40;S8e0@0^<KA0`2haM040;S4c`@0^<?=102i`ld4
0;[4cP@0_<K?0`2nb=840;o:e0@0`<cE1030c=H40<3;e@@0_lWC102mam030;_5cP@0^<7:102e_/H4
0;:k`P@0/;No102^]K`30:fd^`@0[kFk102b]kd40;Fk`0@0^Kg3102l_lD40;g1a`<0^kk4102e^;h4
0:nc^@@0ZJje102TZK4409fU[`<0U:6/1029V:@407b<V@@0LX>A101YO8/4065fQ@<0FW20101CJg`4
04aVM`@0AV5c5P3oool001@0oooo1016HWD404aXN`@0Dfj00`1JM8H4061jS0@0Ih6C101^QiP407F=
WP@0Ni>U0`22VJ/408RN[`@0SZBd102F[;`409jda0@0Ykc<102`aM<30;K:f@@0^<cJ102hbmT40;S9
eP@0^<SD102ha]430;S5d0@0^<C?102h`ld40;W3c@@0^/C>102la/l30;k8dP@0_l[D1030c=D40<3<
eP@0`<_E102obM<40;g7d0<0^lG>102h`LX40;FnaP@0/[_2102`]kl40:je_0<0[KBk102_]K/40;:g
_@@0]K_0102i_L<40;boa@@0_L770`2k_/@40;Fh_P@0[k>i102Y[[D40:BY/@@0WJF_0`2DXJ`408VH
Y0@0O8bI101bPi4406UlR`@0HGJ50`1JL80405=[O0@0C6Ig1016HG<F0?ooo`00503oool404IRM@@0
C6Qk101CKX0305YdQP@0H7Z<101WPI<406j7V0@0MHfN101kTjD308:IZ`@0R9j_102>Y;@409J/_0@0
W[C4102W_<`40;35d`<0]/[I102hc=X40;S;f@@0^<WF102hb=@40;S6d@<0^<G@102ha<l40;S3c@@0
^L?=102ja<h40;c6c`<0_/SB102ob]@40<3<e@@0`<cF1030bmD40;o9d`@0_LO@0`2kaLh40;S1bP@0
]Kk6102b^l840;2g_`@0[[Fl0`2]];/40:ne^`@0/[Nm102e^l040;Vm``@0_;o5102m`LL30;^na0@0
]KRn102_/kT40:V^]@@0Y:Va102MYJl309BQ[0@0RIRT101lS9T407:3T@@0JGb;101QMXD305Y`P0@0
Df]l101<IWL404IQLaH0oooo000D0?ooo`@0AV9e101<J7/405=^P0<0FWB6101PNX`406N1T`@0KXNH
101eSIh407^CY@<0PYV[1028WZl408jT]0@0UZbl102N]<@40:Nlc0@0/<GC0`2fb]T40;S<fP@0^<_I
102hbMH40;S8e0@0^<KA0`2haM040;S4c`@0^<?=102i`ld40;[4cP@0_<K?0`2nb=840;o:e0@0`<cE
1030c=H40<3;e@@0_lWC102mam030;_5cP@0^<7:102e_/H40;:k`P@0/;No102^]K`30:fd^`@0[kFk
102b]kd40;Fk`0@0^Kg3102l_lD40;g1a`<0^kk4102e^;h40:nc^@@0ZJje102TZK4409fU[`<0U:6/
1029V:@407b<V@@0LX>A101YO8/4065fQ@<0FW20101CJg`404aVM`@0AV5c5P3oool001@0oooo1015
HG@404]WN@@0DFan0`1GLH<405igR0@0I7f>101ZPY<40728V0@0MhfM0`1mTZ4408:GYP@0RIj/102B
YK@409b^_0@0YKS6102^`Lh30;K9eP@0^LcJ102ic=T40;[;f0@0^l_G102kbmH30;c:e@@0_L[E102n
bmD40;o;e@@0`LcF1032cML30<C?f0@0aM3J1036dM/40<KAfP@0aM3I1034cmP40<?=e@<0`L[B102n
alh40;c3b`@0^L37102f_L<40;Fk`@<0]K[0102e^[l40;Nk`0@0^[c1102l_L<40;jn``@0_[k20`2j
^[h40;6b]`@0ZZba102SYZ`409bQZ0@0U9^S0`2<UZ04086>V@@0MXFA101]OHX406EgQ@@0GW:10`1H
KGd4055YN@@0BfAf1015H78F0?ooo`00503oool404EQM0@0BfMi101AK7h305MaP`@0GWN8101TOHh4
06Z2T`@0L8RH101gSId307fBX@@0PYNV1029WZ`409:U]0@0W:jl102U^<H40:k1cP<0]/WF102ic=X4
0;W<f@@0^/_H102kbmL40;_;eP<0_<[E102mb]D40;k;e@@0_l_E1031c=H40<;=e`<0a<oH1035d=X4
0<KAf`@0a]7J1035d=T40<C?f0@0`lgE0`31b]840;k7cP@0_<?;102i`<L40;Jm``@0]K_10`2e^/04
0;Fj_`@0]k_0102j_<440;bm``@0_[k3102n_/830;Zj_P@0/K:g102Z[;440:>V[0@0W:6X102DVj<3
08bFX0@0PHjI101fQI4406emRP@0IGN5101NLX4305Q]O@@0DFUi101;I7H404EPLQH0oooo000D0?oo
o`@0AF5d101;IgT4055/OP<0Eg63101NMhP406AmSP@0JX:C101`R9P407N=W@<0OI:Q1022UjH408VN
[0@0TZFd102L[[`40:FhaP@0[/7>0`2fbMH40;W<fP@0^LcI102jbmP40;_;e`@0^l_F0`2lb]D40;g:
e@@0_/_E102obmD40<7<eP@0`/gG0`34cmP40<G@fP@0a]7K1036dMX40<G@f@@0a<oH1033cMD30<7:
dP@0_/O>102l`l/40;W0a`@0][g3102e^l430;Fj`0@0]KZo102g^l040;Zl`@@0_;g3102n_/<40;jn
`P<0^[Zn102a/[L40:Z//@@0XjJ/102LXJP409BKX`<0S9JP1021SYT407J5T@@0KGf:101UMhD405ib
P@<0F6em101AJGT404]TMP@0AF1b5P3oool001@0oooo1015HG@404]WN@@0DFan0`1GLH<405igR0@0
I7f>101ZPY<40728V0@0MhfM0`1mTZ4408:GYP@0RIj/102BYK@409b^_0@0YKS6102^`Lh30;K9eP@0
^LcJ102ic=T40;[;f0@0^l_G102kbmH30;c:e@@0_L[E102nbmD40;o;e@@0`LcF1032cML30<C?f0@0
aM3J1036dM/40<KAfP@0aM3I1034cmP40<?=e@<0`L[B102nalh40;c3b`@0^L37102f_L<40;Fk`@<0
]K[0102e^[l40;Nk`0@0^[c1102l_L<40;jn``@0_[k20`2j^[h40;6b]`@0ZZba102SYZ`409bQZ0@0
U9^S0`2<UZ04086>V@@0MXFA101]OHX406EgQ@@0GW:10`1HKGd4055YN@@0BfAf1015H78F0?ooo`00
503oool404EPL`@0BVEg101@JW`305E_P0@0FgB5101PN8T406ImS@@0K8:B101aQiH307N<VP@0OI6O
1023UZ@408^NZ`@0U:Nd102O/;d40:Ria@<0//?>102hb]H40;_=f@@0_<kJ102ncm/40;o@g0<0`M3K
1032d=X40<C@fP@0aM;K1037dm`40<SDg@<0b]GN103;e]l40<cGh0@0c=OO103;e]h40<[Dg0@0bM;I
0`37cmH40<G<d`@0`/W?102oa//40;g3b0@0^l350`2k_l<80;^n`PP0_;k2102m_L440;Zj_@<0/K:f
102ZZjl40::TZ@@0VIbQ102@U9X408N=U0<0OhJ?101fP8X406ikQP@0IgJ3101QLWl405]^O0<0EFYj
101?IWL404YSM0@0AEmb5P3oool001@0oooo1015H7<404YUM`@0D6Yl0`1EKh0405]dQ@@0H7R9101V
OHd406b2TP@0LHNF0`1gS9X407fAW`@0PiJT102;WZ/409BW]0@0Wk2m102X^LD30;;3cP@0^<[F102k
cMT40;c>fP@0_/oK102od=`30<7@f`@0`]3J1034d=X40<GBf`@0am?L1038e=d30<[EgP@0bmKO103<
en040<cGg`@0bmKN103:e=`40<WBf@<0aloF1035c=<40<;9c`@0_lK;102m`lP40;_0a@<0^ko3202k
_/880;bn`P@0_Kg1102j^[d30;6b]P@0ZZ^_102RY:T409VLX@@0T9BJ1027SI@307n6S`@0MX2:101^
NhH406MfP`@0HG9o101KKW`305EZNP@0CfIg101:Hg@404EOLQH0oooo000D0?ooo`@0AF1c101:IGL4
051ZO0<0EFn0101KM8D4061hR@@0IWf=101/PY840767UP<0MhbJ101mTIl408>FY0@0Rij[102DYk@4
09n`_@@0Z;W50`2b`lh40;S:eP@0^lgI102lc]X40;k?f`@0_m3L0`31d=/40<;@fP@0a=3J1035d]/4
0<OCg0@0b=CM0`3:eMh40<_Fg`@0c=OP103<eml40<_FgP@0b]CL1039d]T30<O?eP@0aLcC1032bLl4
0;o6b`@0_L?8102k`<D30;^o``P0^kk2202l_/840;fm`@@0^[Zm0`2a/[H40:Z[[`@0XZBY102IW:44
092DVP@0QhfD0`1oQXl407J0RP@0KW^6101WMX<4065bO`@0Ffil0`1EJWX404mVM`@0BV=d1015Gg8F
0?ooo`00503oool404EPL`@0BVEg101@JW`305E_P0@0FgB5101PN8T406ImS@@0K8:B101aQiH307N<
VP@0OI6O1023UZ@408^NZ`@0U:Nd102O/;d40:Ria@<0//?>102hb]H40;_=f@@0_<kJ102ncm/40;o@
g0<0`M3K1032d=X40<C@fP@0aM;K1037dm`40<SDg@<0b]GN103;e]l40<cGh0@0c=OO103;e]h40<[D
g0@0bM;I0`37cmH40<G<d`@0`/W?102oa//40;g3b0@0^l350`2k_l<80;^n`PP0_;k2102m_L440;Zj
_@<0/K:f102ZZjl40::TZ@@0VIbQ102@U9X408N=U0<0OhJ?101fP8X406ikQP@0IgJ3101QLWl405]^
O0<0EFYj101?IWL404YSM0@0AEmb5P3oool001@0oooo1014H78404UTMP@0CVQi0`1CK7d405Q`P0@0
GGB4101RNHP406QmS0@0KH6?0`1cQI<407R:U`@0OY2M1026V:@4092Q[@@0VZ^f102T]L030:bnb@@0
]LKB102kcMP40;o?f`@0`M7M1033dml30<GEh0@0amKQ1039en440<_HhP@0cMWR103?fn@30=3Li@P0
dMgU103Bg>@40=;Kh`@0d=[P103?emh30<cEf`@0b]7G1038c]840<G:c`@0`lS<1032aLT30<33a`@0
`<75102o`<<40;jo`P@0_kk1102l^kd40;Fd]`<0[:^_102SXZH409RIWP@0SY2F1024Qhh407YoQP<0
KWAk101XL7P406IaN`@0HFmk101LKGT405MZN0<0DVMf101=I7@404UQL`@0A5ma5P3oool001@0oooo
1014H78404UTMP@0CVQi0`1CK7d405Q`P0@0GGB4101RNHP406QmS0@0KH6?0`1cQI<407R:U`@0OY2M
1026V:@4092Q[@@0VZ^f102T]L030:bnb@@0]LKB102kcMP40;o?f`@0`M7M1033dml30<GEh0@0amKQ
1039en440<_HhP@0cMWR103?fn@30=3Li@P0dMgU103Bg>@40=;Kh`@0d=[P103?emh30<cEf`@0b]7G
1038c]840<G:c`@0`lS<1032aLT30<33a`@0`<75102o`<<40;jo`P@0_kk1102l^kd40;Fd]`<0[:^_
102SXZH409RIWP@0SY2F1024Qhh407YoQP<0KWAk101XL7P406IaN`@0HFmk101LKGT405MZN0<0DVMf
101=I7@404UQL`@0A5ma5P3oool001@0oooo1014H78404UTMP@0CVQi0`1CK7d405Q`P0@0GGB4101R
NHP406QmS0@0KH6?0`1cQI<407R:U`@0OY2M1026V:@4092Q[@@0VZ^f102T]L030:bnb@@0]LKB102k
cMP40;o?f`@0`M7M1033dml30<GEh0@0amKQ1039en440<_HhP@0cMWR103?fn@30=3Li@P0dMgU103B
g>@40=;Kh`@0d=[P103?emh30<cEf`@0b]7G1038c]840<G:c`@0`lS<1032aLT30<33a`@0`<75102o
`<<40;jo`P@0_kk1102l^kd40;Fd]`<0[:^_102SXZH409RIWP@0SY2F1024Qhh407YoQP<0KWAk101X
L7P406IaN`@0HFmk101LKGT405MZN0<0DVMf101=I7@404UQL`@0A5ma5P3oool001@0oooo1014Gg84
04QRM0@0C6Ig0`1AJGX405E/O0@0FG1o101NM88406=hQP@0JGb:0`1^PHd407B5TP@0NX^G1022TYd4
08ZJY0@0U:>]102Q[[P30:^i``@0]L?<102lbmD40<7@fP@0a=?N1037e^430<[Ih`@0c=_V103?gNP4
0=7Oj@@0dn7Z103Eh^/30=OSk0@0f>C/103Hi>/40=SSj@@0en3W103Fg^@40=CKh@<0d]SM103@eMX4
0<gAeP@0bloB1039c<l40<O8b`<0aLK81033`lD40<;1``@0`Ko0102n^kd40;Re]`@0[jf^0`2TXZD4
09VHV`@0SXjB1023QHX407UlP@@0Kg=j0`1VKG@4065ZLP@0GVUc101KJG@405MWM0@0DfIc0`1?I7<4
04]RLP@0Af1a1013GW0F0?ooo`00503oool404AOLP@0B69d101<IWL3055YNP@0EFal101IL7l405id
PP@0HgR6101YO8X306j1S@@0M8FB101jRiL408:BW@@0RYZT102DXjd40:6^^0<0ZkW3102e`l`40;c;
e@@0`M3J1034dmh40<OFh@<0b]WS103<fnH40<oMj0@0dMoY103ChNX40=GRj`<0en?/103Hi>`40=ST
j`@0f>?Y103Gh>L40=KNi0@0e=_Q0`3Bf=d40=3EfP@0cM7F103;cm840<W<c`@0alS;0`35a/P40<?3
a@@0`/731031_l040;jk_@@0^;Fg102_[Jh30:BRY@@0VIRK102>SY8408>5RP@0NGb1101_LgX306I]
M0@0HFYb101NJG<405]YM0@0EfMd101CIW<304mTL`@0Bf9b1017H74404=NL1H0oooo000D0?ooo`@0
A5mb1018HW@404aVM`<0DFUj101EK7`405U`O`@0GWB2101SN8H406UlRP<0KX6=101dQI8407Z;U`@0
PY:M102:VZ@409BS[@@0XJjh0`2[^L<40;G3c0@0_<_E1031d=X40<CCgP@0amKQ0`3:fN<40<cKiP@0
cmgX103AgnT40=?QjP@0eN;[0`3Ghn`40=STk0@0f>C[103HhnT40=OPi`@0e]kT103Dfn430=;Hg@@0
d=GJ103=dMH40<_?dP@0bLc?1037b</30<G6b0@0`l?51032`L<40<6o`0@0_[^m102h]KL40:n][P<0
Y::U102IV9/408j>TP@0PhF:101iO84406mcNP<0IVed101QJW8405iYL`@0FfUd101GIg@405=VL`<0
CfAc101;HW8404MPL@@0@ei`5P3oool001@0oooo1014Gg8404QRM0@0C6Ig0`1AJGX405E/O0@0FG1o
101NM88406=hQP@0JGb:0`1^PHd407B5TP@0NX^G1022TYd408ZJY0@0U:>]102Q[[P30:^i``@0]L?<
102lbmD40<7@fP@0a=?N1037e^430<[Ih`@0c=_V103?gNP40=7Oj@@0dn7Z103Eh^/30=OSk0@0f>C/
103Hi>/40=SSj@@0en3W103Fg^@40=CKh@<0d]SM103@eMX40<gAeP@0bloB1039c<l40<O8b`<0aLK8
1033`lD40<;1``@0`Ko0102n^kd40;Re]`@0[jf^0`2TXZD409VHV`@0SXjB1023QHX407UlP@@0Kg=j
0`1VKG@4065ZLP@0GVUc101KJG@405MWM0@0DfIc0`1?I7<404]RLP@0Af1a1013GW0F0?ooo`00503o
ool404=NL@@0Af5c101:I7D304iVMP@0DVUh101FJgX405Y^O0@0GG1m101RM84306MiQP@0KWn:101e
Q8l407^:U0@0QI>M102@WZL409bY/P<0ZKBm102e`LT40;k;e0@0a=;K1038e^040<_Ji0<0c]gX103B
hN`40=GTk`@0enKa103Jj?840=cZl`<0g^[c103Oj_840=oZl0@0gnW_103Nin`40=gTj@@0f^3U0`3H
g>040=GIg0@0d]GI103?dM@40<g>d0@0b/_=0`38b<T40<O5aP@0a/;31033_[l40;ji^@@0][6a102Z
YZH309jJW0@0TI2A1025QHP407YlO`@0Kg5e101RIf`305aQJ0@0FV9Z101HHV/405ERK@@0Df9^101@
HVl304aQK`@0BF1_1016GVl404=MKaH0oooo000D0?ooo`@0@eia1017HG<404YTM@<0CVIf101BJGP4
05I[NP@0FVil101ML7d4069dP@<0IgV6101^OhX407F4S`@0NhZD1025Tid4092NY`@0W:Vb0`2Y];d4
0;G1b@@0_/_D1034d]/40<SFh0@0bm[T0`3>gNP40=;Qk0@0eNC_103Gi_440=[XlP@0g>[c0`3Nj_<4
0=oZlP@0gn[`103OjNl40=kWk0@0gNCY103Jh>D30=SLh0@0eMWL103BeMT40<oAe0@0cLk@103:bld3
0<S8b@@0alG61036`/<40<>n_`@0_[Vi102f/K440:ZVYP<0WYZL102AT94408F5R0@0NWao101_LGD4
069WK0<0G65X101JHVX405QRJ`@0EF9]101CHVh4051RK`<0C65_1019H6l404INK`@0@ee_5P3oool0
01@0oooo1013GW4404MQL`@0BVAe0`1>IWH4059YN0@0EV]j101JKW`405e`O@@0HWB10`1WNHH406io
RP@0MHB?101kRY@408FCW@@0T9jW102LZK830:Vd_@@0]L79102nbm@40<CBf`@0b=KP103;f^@30<kM
j0@0d^7/103Ei>l40=OVl@@0f^Sb103Lj_<30=kZl`@0gn[b103Oj_040=oYk`@0g^O/103Mi>T40=[P
i@<0f=cP103EfM`40=;Ef@@0cm7D103=c]040<[;c@<0b<S91037aLH40<K2``@0`kjo102n^KT40;Ja
/@@0ZZJV0`2NVY`4096@T@@0QHF8101jO7l406maM@@0HVM/0`1LHFP405YRJP@0F69[101EHVd405=R
KP@0D69_0`1<HFl404UPK`@0AUi_1013GFlF0?ooo`00503oool404=NL@@0Af5c101:I7D304iVMP@0
DVUh101FJgX405Y^O0@0GG1m101RM84306MiQP@0KWn:101eQ8l407^:U0@0QI>M102@WZL409bY/P<0
ZKBm102e`LT40;k;e0@0a=;K1038e^040<_Ji0<0c]gX103BhN`40=GTk`@0enKa103Jj?840=cZl`<0
g^[c103Oj_840=oZl0@0gnW_103Nin`40=gTj@@0f^3U0`3Hg>040=GIg0@0d]GI103?dM@40<g>d0@0
b/_=0`38b<T40<O5aP@0a/;31033_[l40;ji^@@0][6a102ZYZH309jJW0@0TI2A1025QHP407YlO`@0
Kg5e101RIf`305aQJ0@0FV9Z101HHV/405ERK@@0Df9^101@HVl304aQK`@0BF1_1016GVl404=MKaH0
oooo000D0?ooo`@0@Ui`1016H74404UQLP<0C6=c101?IG@4059WM@@0EFQe101HJWH405]/N0<0HG1k
101XMX4406mmQ`@0MhF>1021SYL408bHX@@0V:>[0`2V/;L40;Bna@@0_l[A1036d]X40<_Hh@@0cmgW
0`3Ch^`40=OVl0@0f^Wd103Nk?H40>3^m`@0h^of0`3Tl?H40>Kam`@0io7f103Vko<40>G/k`@0hnS[
103PiNL30=gQi0@0f]gP103GfM/40=CEeP@0dM3A103>c<d30<c9b@@0bLG51036`/440<:m^`@0^kBc
102_ZJP40::MW0<0U92A1026QHH407YjO0@0KFmb101PHfL405=EF@<0Ce=H101BFF04055KI0@0D5eW
101>GFT404aNJ`<0BUi/1017GFd404EMKP@0@Ua^5P3oool001@0oooo1012GW0404IPL@@0BF5b0`1<
Hg<404mUM0@0DVMe101EJ7D405QZMP@0Ffah0`1QL7/406QfP@@0Kgf7101gQHh4086>U`@0S9RQ102H
Xj/30:J`]`@0];k5102ob]440<KBfP@0bmSQ103?gNL30=?Rk0@0enK`103JjO@40=k/mP@0h>kg103R
koH30>C`mP@0i_7g103WlOH40>K_l`@0iNc_103Sj>/40>3Ui`<0gN7T103JgN040=OIf`@0e=GF103A
d=440<k<c@<0c<W91039aLD40<K2`@@0`[fk102k];<40:nYZ0@0XYfL0`2DT94408J5QP@0NWYl101]
Kg84061SI`@0DeEI0`1?DeP4059IH0@0DE]T101@GFL404iMJ@@0C5i[0`1:GV`404MMK@@0AEe^1012
G6hF0?ooo`00503oool4049NL0@0AV1a1019HG8304aSL`@0CfEd101BIgD405EXM@@0F6Yf101KK7P3
065`N`@0J7J1101_OHL407N5SP@0PHjG102<V:4409RSZ`<0Y[2g102d_/D40;o:d@@0a];J103;f>44
0<oMi`<0dn;/103Gi_040=[Ym0@0g^cf103Pk_L40>;_mP<0i?3f103VlOL40>OamP@0i^oc103Uk>l4
0>?Xj`@0h>GW0`3MhN@40=[Mh0@0emWK103DeMH40=7@d@@0c/c=0`3<bLT40<W5a@@0a/;11032_K/4
0;^d/`@0[jVX102RWI`309B@T@@0QXF6101jNW`406e_LP@0H6=W101CEET304mCF0@0DUUP101AFf@4
051MI`@0CUeY101<GV/304YNK0@0Aee]1015GFh4049LKQH0oooo000D0?ooo`@0@Ui`1016H74404UQ
LP<0C6=c101?IG@4059WM@@0EFQe101HJWH405]/N0<0HG1k101XMX4406mmQ`@0MhF>1021SYL408bH
X@@0V:>[0`2V/;L40;Bna@@0_l[A1036d]X40<_Hh@@0cmgW0`3Ch^`40=OVl0@0f^Wd103Nk?H40>3^
m`@0h^of0`3Tl?H40>Kam`@0io7f103Vko<40>G/k`@0hnS[103PiNL30=gQi0@0f]gP103GfM/40=CE
eP@0dM3A103>c<d30<c9b@@0bLG51036`/440<:m^`@0^kBc102_ZJP40::MW0<0U92A1026QHH407Yj
O0@0KFmb101PHfL405=EF@<0Ce=H101BFF04055KI0@0D5eW101>GFT404aNJ`<0BUi/1017GFd404EM
KP@0@Ua^5P3oool001@0oooo1012GFl404ANL0@0Aem`0`19H70404aQL0@0CV9`101@Hfl4059SK`@0
EFA^0`1IIg04065^M`@0JGEn101aOHH407^6SP@0Qi6H102DWJ<30::[/0@0/;Rn102ma//40<SBf@@0
cm[R103Dh>P30=SUkP@0gN[b103Qk_D40>Gan0@0j??j103ZmO/30>cfn`@0k_Kk103^mOT40>gcmP@0
k?3c103ZkNl40>KYj`<0hnGV103Ph>440=cLg0@0fMOG103Ed]840=;=c@<0c/W8103:a<840<Fn_0@0
_[Jd102d[:X40:NPWP@0VI>B0`2:QXH407ejN`@0Kfi`101RHfH405MIG@@0Ce9G0`1<DEL404aCFP@0
C5IO101;F68404YII@@0BEYW0`17FfT404EKJ`@0@ea/1011G6hF0?ooo`00503oool4049MK`@0A5i`
1017Gg0304UPL0@0C65`101>HW04051SK`@0DV=_101EI6h305UWL0@0HFig101YMGh4075mQP@0NhJ>
1027TIP409BMX`<0XZ^`102`^;h40;g6b`@0b=;I103?f^840=CPj0<0f>G^103Mj_840>7^m@@0iO7h
103XloX40>[en`<0k?Kk103^m_/40>ken@@0kO?f103/l?<40>[]k`@0i^W[0`3SiNH40>3Ph@@0g=cL
103IemL40=GBdP@0d/g=0`3>bLP40<[4`P@0aKjl102n][@40;B/ZP@0Yj2N102ITi8308Z6QP@0OGYk
101_KW04069SIP@0EeUM101?DUL304aAE`@0C5=J101<EUl404]HHP@0BUUU1019FVL304MKJ@@0AE][
1013G6`4045LKQH0oooo000D0?ooo`@0@Ue_1014GW0404MOL0<0BF1`101<HG0404iRL0@0D6=_101B
Hfl405ETKP<0FFM`101QKWL406UeOP@0LGf6101kQXh408NAV0@0U9fS0`2RZk040;2h_P@0_LK;1038
d]T40<oJhP@0e>3X0`3HiNh40=gZlP@0hNke103UlOP40>ScnP@0j_Gk0`3/m_/40>kfn`@0k_Gi103]
loH40>c`l`@0j^g_103VjN/30>?UiP@0h>3Q103Lg=`40=WGe`@0eM;B103BcLd30<k9b0@0b/C21035
_[`40;jf]0@0]:bZ102WX9h409VCTP<0RXJ6101mNW/406m^L0@0HV=V101GFEd404mBE`<0C55G101<
DeX404aFG`@0BeQR101:FFD404UJI`<0Ae]Y1015Ff/404=LK0@0@Ea^5P3oool001@0oooo1012GFl4
04ANL0@0Aem`0`19H70404aQL0@0CV9`101@Hfl4059SK`@0EFA^0`1IIg04065^M`@0JGEn101aOHH4
07^6SP@0Qi6H102DWJ<30::[/0@0/;Rn102ma//40<SBf@@0cm[R103Dh>P30=SUkP@0gN[b103Qk_D4
0>Gan0@0j??j103ZmO/30>cfn`@0k_Kk103^mOT40>gcmP@0k?3c103ZkNl40>KYj`<0hnGV103Ph>44
0=cLg0@0fMOG103Ed]840=;=c@<0c/W8103:a<840<Fn_0@0_[Jd102d[:X40:NPWP@0VI>B0`2:QXH4
07ejN`@0Kfi`101RHfH405MIG@@0Ce9G0`1<DEL404aCFP@0C5IO101;F68404YII@@0BEYW0`17FfT4
04EKJ`@0@ea/1011G6hF0?ooo`00503oool4045LK`@0@ee^1015GFh304MNK@@0BEi/101:GV/404aM
J@@0CEeW101>G6H3059OI`@0FFE/101RKG@406]eO0@0MGj41020RHl408bEVP<0VJ6V102W[k@40;Ro
a0@0a/kB103@f]l40=OSj0<0gNW_103Rk_@40>Ocn0@0joKj103^n?`40?7joP<0m?_n103enod40?Kj
o0@0m?Si103bm?D40>oal@@0k>c]0`3XinL40>CRhP@0h=gM103Lf=L40=SCd@@0e<g;0`3?b<D40<W1
_`@0`KRe102g[ZX40:ZQWP@0Vi>A102=QhD3081kNP@0LVm_101THV<405EEF0@0BTa?1016BDd304E:
D0@0ATeE1016DET404ICG@@0AUEQ1016Ef@304EHI`@0@eYY1012FV/4045KKAH0oooo000D0?ooo`@0
@Ea_1013GFh404EMKP<0Aei]1019GV`404YNJ`@0C5eY101=GFL404iLIP<0DUmW101IIF`4069]M0@0
JgEl101eOX@40829S`@0S9FJ0`2IXJH40:N_]0@0^;o41036c]840=3Jg`@0en?X0`3MjNl40>;^m0@0
io?h103[m_X40>kho0@0lO[n0`3dnoh40?Gko@@0m_[l103dn?T40?;dm@@0ko7a103/k>d30>SWi`@0
i>;R103PgMd40=cHe`@0f=?A103DcL/30<o8a@@0bL6o1031^;D40;N^ZP@0ZZ6N102KTi4408f7Q@<0
P7]j101bKfl406ARH`@0EEEH101:C4l404I9C@<0ADY@1016CED404IAF@@0AU=M1016EF4404IGI0<0
AEQW1013FVT4049JJ`@0@E]]5P3oool001@0oooo1011G6l404=MKP@0AEe^0`17GVd404UNK0@0BUi[
101<GFT404eMI`@0CUaV0`1BGfL405UUK0@0HVed101[MG`407EnQ0@0P8V?102<UIX309VQYP@0Yjnd
102h_l@40<K>dP@0d=[O103GhnP30=gYk`@0h^kd103WloP40>_fnP@0k_Sl103an_h30?CkoP@0mO_m
103fn_`40?Chn@@0l_Ce103_lO440>c/k@<0j>OW103Th^840>3Mg@@0g=SG103Hdm440=C=b`<0clS5
1039`Kl40<6h]@@0]jjZ102ZXIh409^CT@@0SHN50`20NgX4079_K`@0I69S101EEEP404Y<C`@0ATU=
0`15BU0404I=E@@0AU5I1016Ded404IEH@@0AUMT0`15F6L404=JJ@@0@UY[1011FfdF0?ooo`00503o
ool4045LK`@0@ee^1015GFh304MNK@@0BEi/101:GV/404aMJ@@0CEeW101>G6H3059OI`@0FFE/101R
KG@406]eO0@0MGj41020RHl408bEVP<0VJ6V102W[k@40;Roa0@0a/kB103@f]l40=OSj0<0gNW_103R
k_@40>Ocn0@0joKj103^n?`40?7joP<0m?_n103enod40?Kjo0@0m?Si103bm?D40>oal@@0k>c]0`3X
inL40>CRhP@0h=gM103Lf=L40=SCd@@0e<g;0`3?b<D40<W1_`@0`KRe102g[ZX40:ZQWP@0Vi>A102=
QhD3081kNP@0LVm_101THV<405EEF0@0BTa?1016BDd304E:D0@0ATeE1016DET404ICG@@0AUEQ1016
Ef@304EHI`@0@eYY1012FV/4045KKAH0oooo000D0?ooo`@0@Ea^1012G6d404AKK0<0AE]Z1016FVT4
04MIIP@0AeQT1017EV0404IBFP<0B5AJ101AFf8405YSJP@0HV]a101[M7X407IoQ@@0Ph^?0`2@Ui/4
09jTY`@0[[>e102oa<H40<kDeP@0fN7T0`3PjN`40>O`l`@0kOKh103bn_`40?GmoP@0n?ko0`3jool4
0?goo`@0oOkn103kno/40?SgmP@0mO;a103ak^d30>gYj0@0j>?R103SgM`40=kHe@@0fM7>103Cb/L3
0<c3_`@0a;^f102i/:/40:^RWP@0WIBA102>Qh@4081iM`<0LFa/101SH60405ECE0@0BDQ:100m?3d4
03Tj?@<0?T=81010B4l4049<E@@0@TmI1013DUh404=DH@<0@UIU1012F6L4045IJP@0@5]]5P3oool0
01@0oooo1011G6h4049LK@@0A5]/0`15FfX404IJJ@@0AeUV1017F6@404MFH0@0AU9J0`18E5X4055K
HP@0FV=Z101RJg4406]dNP@0MWn51023Rhl3092GV`@0WZBW102^/kD40;o4aP@0c]CF103IhN@30>3Y
k0@0io3c103]m_P40?;jo0@0mOgn103ho_l30?[oo`@0oOoo103mo_h40?_kn`@0n?Of103el_440?7^
k@<0kNWX103Xhn840>?Mg0@0g]SE103IdLh40=?:a`<0c<>o1034^kH40;V`Z`@0Zj:N102MU94408j7
Q0@0P7Ug0`1aK6`406=PH0@0EE=D1019B4X403dl?@@0>CXm0`0n@dP40418C`@0@TaE1012CeT404=B
GP@0@eAQ0`12EVD4049HI`@0@EUZ1010FfdF0?ooo`00503oool4045LKP@0@Ua]1014Ff`304EKJP@0
AUYY1017FFH404MHI0@0AeIP1016DUX304QDFP@0DE]R101JHfX4069[L@@0JgAj101fOhD408>;S`<0
T9NK102NY:L40:jc]@@0_lC6103>e=H40=WQi0<0h>W/103Wl?<40>gfn0@0l_[l103eoOh40?Sno`<0
n_oo103mool40?gnoP@0no_k103hmoH40?Gbl@@0lNk]0`3]jNP40>SShP@0hmgL103Nf=D40=WAcP@0
dl[70`3<`kl40<Bk]P@0^K2[102[XYh409fDT@@0SXN41020NGL3075/K0@0Hf1P101EDe@404U8BP@0
?C`m100i>Sd303i3B0@0@4Q?1012C5D4049?F@@0@e9N1013E643049FI@@0@UQW1011FFX4041KKAH0
oooo000D0?ooo`@0@Ea^1012G6d404AKK0<0AE]Z1016FVT404MIIP@0AeQT1017EV0404IBFP<0B5AJ
101AFf8405YSJP@0HV]a101[M7X407IoQ@@0Ph^?0`2@Ui/409jTY`@0[[>e102oa<H40<kDeP@0fN7T
0`3PjN`40>O`l`@0kOKh103bn_`40?GmoP@0n?ko0`3jool40?goo`@0oOkn103kno/40?SgmP@0mO;a
103ak^d30>gYj0@0j>?R103SgM`40=kHe@@0fM7>103Cb/L30<c3_`@0a;^f102i/:/40:^RWP@0WIBA
102>Qh@4081iM`<0LFa/101SH60405ECE0@0BDQ:100m?3d403Tj?@<0?T=81010B4l4049<E@@0@TmI
1013DUh404=DH@<0@UIU1012F6L4045IJP@0@5]]5P3oool001@0oooo1010Ffd4045KK0@0@UYZ0`13
FFP404=GI@@0@eIR1013Del4049@FP@0@4aD0`12Be8404UBF0@0DUYP101JHVP406E[L0@0KgEi101j
P8D308J<T0@0TYRJ102PYJL40;2e]P@0`LG6103?dm@30=cQhP@0inc]103`m?D40?Kkn`@0nOkn103l
ooh30?oooP@0ookl103oo?T40?kjm`@0o?Od103il_040?C]jP<0l>OT103/hml40>KMf@@0gmGA103H
cLP40=35`0<0a[bf102k/:X40:fRW@@0WiB@102?QX<4081hM@@0LF]Y0`1RGE`405=@D0@0AD=5100k
>S`403De>0@0=SLk0`0i?D<403]3BP@0?DQA100oC5H4041?F`@0@59O0`10E6<4041GIP@0@5QY1010
FV`F0?ooo`00503oool4041KK@@0@E]/1012FVX304=IJ0@0@eMU1013EV8404=CG`@0@U1J1010C5@3
049;DP@0BE9H101BFV0405YRJ0@0IF]`101_MGT407Z0Q@<0QXb@102BV9X40:2UY`@0/;Ff1031aLH4
0<oCe0<0g>7R103Wk>d40?3dm@@0m__k103io_h40?cooP<0ooon103oo_`40?oln@@0o_[g103lmo@4
0?Wbl0@0m>gZ0`3`in@40>cSg`@0i]gI103OeM440=S=b0@0d<G00`36_;H40;^`ZP@0[J:M102OU904
08n6P`@0P7Qe101aJfT3069MG0@0De1@1015@dD403/j?0@0=CDh100f=c/303Tm@`@0>d=:100mB544
03m<EP@0@4mK1010DUl3041DH`@0@5MV1010F6T4041JK1H0oooo000D0?ooo`@0@5]]1011Ff`4049J
JP<0@eUX1013EfD404=FHP@0@e=O1012D5X4041<E0<0@T]B1019DUP4059JH0@0FV9X101UJg0406me
N@@0NX250`26S90409:HVP@0X:FW102`]KH40<75aP@0cm?D0`3LhN840>O/k@@0l?Ce103fno/40?Wn
oP@0o?on0`3oooh40?ono0@0ooci103nn_L40?cgm0@0nO;`103dkNX30?3Wi0@0k>?O103VgMT40=oE
d@@0f<g8103@aL030<Jl]P@0^k2Z102]XYd409nDT0@0ShJ31020N7D4075[J@<0HUeL101CD50404E3
A@@0>cXl100e=CP403Hg>`<0>Ce3100k@dX403e8D@@0?daF1010Ce/4041BG`<0@5AS1010EfH4041H
J@@0@5Y/5P3oool001@0oooo1010Ffd4041JJ`@0@EQX0`11EfH4045EH`@0@5=O1010D5/403m<EP@0
?DQ@0`0lADX403m7C0@0AdmD101@Ee`405UPI0@0I6Y^101_M7P307YoPP@0Qhb>102DVI/40::VZ0@0
/KFf1030`l@30<oAd@@0fmgM103UinL40>g_k@@0loCa103gmo<30?WglP@0n_G`103jlnh40?[bk0@0
n_3Z103gkNH40?CXhP<0kn?M103Yg=H40>?Ec`@0g<k8103BaKl40<Rk]@<0_:nY102^XI`409nCSP@0
ShF1101nMW<406mXI@@0GeYH0`1@C4/4044n?`@0=C@d100/:b`402XZ;@@0<38f0`0d>Cl403LoA`@0
>TE=100lBE<403e=F@@0?U1M0`0oDf4403mEI@@0?eQX100oFV`F0?ooo`00503oool4041KK@@0@5Y[
1011F6P3045GIP@0@EES1010Del4041@F`@0?daF100mB50303a5BP@0?dM<1017Ce@4051GG0@0FF1T
101TJVh406mdN0<0NWn21027S8h409BIV`@0XZJX102a]KH40<33a0<0cm7A103KgMd40>GWi`@0kNo]
103cm?440?Ogl`<0nOOb103jmO040?[ckP@0n_;/103jl>X40?O]iP@0m>SR0`3_hmd40>WLeP@0hmG?
103Lc/P40=;5_`@0b;^e0`2l[jT40:jQW0@0Wi>>102?QH4407ifL`@0KfQU101OFUP3051<B`@0@Cho
100e=3@402`[;0@0:RX]100`<SH303@i?`@0=cm7100jADd403a9D`@0?DeI100nD5d303mCH@@0?eEU
100oF6P403mJK1H0oooo000D0?ooo`@0@5]]1010FV/4045HJ0<0@EMV1011EF<4041CG`@0@51K100o
C5H403e8D0<0?4E:100oAd`404M?E0@0D5ML101IH6@406AZKP@0KgAh0`1jOh8408N<SP@0U9VK102R
YZP40;6e]P@0`<?40`3?dM440=_Mg@@0iNOW103]knd40??dl@@0moOc0`3imo840?[el0@0n_?^103j
l^`40?[`jP@0mngV103dj>830>oSg@@0jMcF103SeLl40=c>b0@0d/Fo1038^kD30;b_Z@@0[Z6L102O
Thh408n5P@@0OWIc101_J6D405mJF0<0D4a;1011?Sl403Dd=0@0;2//100Z:Rd4030b=P<0=3To100g
?dL403Y5C@@0?4UC100mCET403i@G@<0?e=Q100oEFD403mHJ0@0?eY/5P3oool001@0oooo1010Ffd4
041JJ`@0@EQX0`11EfH4045EH`@0@5=O1010D5/403m<EP@0?DQ@0`0lADX403m7C0@0AdmD101@Ee`4
05UPI0@0I6Y^101_M7P307YoPP@0Qhb>102DVI/40::VZ0@0/KFf1030`l@30<oAd@@0fmgM103UinL4
0>g_k@@0loCa103gmo<30?WglP@0n_G`103jlnh40?[bk0@0n_3Z103gkNH40?CXhP<0kn?M103Yg=H4
0>?Ec`@0g<k8103BaKl40<Rk]@<0_:nY102^XI`409nCSP@0ShF1101nMW<406mXI@@0GeYH0`1@C4/4
044n?`@0=C@d100/:b`402XZ;@@0<38f0`0d>Cl403LoA`@0>TE=100lBE<403e=F@@0?U1M0`0oDf44
03mEI@@0?eQX100oFV`F0?ooo`00503oool403mJK0@0?eUZ100oEfL303mEI0@0?e=P100nD5d403e=
F0@0>dUC100iA4`303HnA@@0=ci3100nADX404M>DP@0CeIJ101GGF44069WJP<0Kg=f101lP88408Z>
S`@0V9bM102VZZX40;>g]P<0_l;2103;c</40=GDdP@0gM_H103ThMd40>WUh@<0jnKQ103]i^440>oV
h0@0l>GN103`hm/40>kQf@@0jmkE0`3Vf=040>7BbP@0fL_3103A`[/40<Ni/P@0^jfV0`2]WiX409nB
S@@0ShAo101nMG4406eVH`@0GEME101=BDP303dj>@@0<2h]100U8b@401lM7P@08b8T100[;S83030f
?0@0=3a4100g@T/403U7D@@0>d]G100lCe`303eBH0@0?UAT100oEfP403mIJaH0oooo000D0?ooo`@0
?eY/100oFFX403mGI`<0?eET100oDf0403i@G@@0?DeH100kBE<403U4C0<0=Si5100g?T<403i5BP@0
AdiB101?EUX405MMH@@0HVMZ0`1_LgH407b0PP@0RXj?102HW9d40:JZZP@0/kNf0`2o`/840<_<b`@0
eMCB103MfmP40>CQg@@0jNGQ0`3[i^440>gVh@@0knKP103`iMh40?3Sf`@0k^7I103[g]D30>KHd0@0
hM;:103Ibl<40=72^`@0akVb102k[JH30:fOVP@0Wi:=102?Q7l407ieL@@0KFIS101MEeD404e9B0<0
?CXi100`;Rd402DS90@07adN100S8R@402/^<P<0<3Hl100d?4@403M2B`@0>DMA100kBeL403a?G0<0
?E9P100nE6@403mGJ0@0?eU[5P3oool001@0oooo100oFV`403mIJP@0?eMW0`0oEF@403mCH0@0?U1M
100mCEP403]9D`@0>DA<0`0f?TD403Ln@`@0?TE:1017CU8404mFFP@0EeeQ101RIfX306mcMP@0O822
102:SXl409RLW@@0YZZZ102c]kH30;o2`P@0blc;103Ee=840=gKf0@0i>7M103YiN430>_Vh@@0kNKQ
103_i^040?3UgP@0l>?K103^hMT40>_Ne@<0i]S@103Qd/X40=W;``@0dL:k1037^K840;^]YP<0[InJ
102OTXd408n4O`@0OWEa101]IV<405eGE@@0CDU80`0m>ST4030^;@@09B<T100O7Ah402<R90@0:bhb
0`0`=S`403@lA0@0=d9;100iAe4403];E`@0?4mL0`0mDV0403iDI0@0?eMX100oFF/F0?ooo`00503o
ool403mJK0@0?eUZ100oEfL303mEI0@0?e=P100nD5d403e=F0@0>dUC100iA4`303HnA@@0=ci3100n
ADX404M>DP@0CeIJ101GGF44069WJP<0Kg=f101lP88408Z>S`@0V9bM102VZZX40;>g]P<0_l;2103;
c</40=GDdP@0gM_H103ThMd40>WUh@<0jnKQ103]i^440>oVh0@0l>GN103`hm/40>kQf@@0jmkE0`3V
f=040>7BbP@0fL_3103A`[/40<Ni/P@0^jfV0`2]WiX409nBS@@0ShAo101nMG4406eVH`@0GEME101=
BDP303dj>@@0<2h]100U8b@401lM7P@08b8T100[;S83030f?0@0=3a4100g@T/403U7D@@0>d]G100l
Ce`303eBH0@0?UAT100oEfP403mIJaH0oooo000D0?ooo`@0?eY/100oF6T403iFIP<0?UAS100mDEl4
03a>F`@0>TYF100hAU0403I1B@<0<S]2100`=S/403@i?@@0?D961015BTh404iCEP@0F5eO0`1UJF/4
075eM`@0OX63102;SXl409NIVP@0Y:FT0`2`/:h40;Vi]`@0`L2n1038a/<40<o<b0@0eM7<0`3Ie<l4
0=[Ec`@0g=C>103Ld/`40=c@b@@0fLg5103GbL430=?5_@@0c[ng1036]jl40;b^Y`@0/ZBN102WVI@3
09V=R0@0RWmk101jLFd406]SH0@0FeEC101;ATD403/g=`<0;2TZ100P7Qh401HC4`@05aDF100Q8RD4
02L[<0<0;C@j100a>d<403A0BP@0=dE@100iBUH403]=F`<0?55O100mE6@403iGJ0@0?eU[5P3oool0
01@0oooo100oFV`403mHJ@@0?UIV0`0nE6<403eAG`@0?4iK100jBUH403Q6D0@0=T590`0b>d84030f
>`@0=3Tm100m@TH404E:CP@0CU=F101HGEl306EYJ`@0LGEg101nPH<408^>S`@0UiVJ102TYJ@30;2`
[P@0^KVg1031`;h40<S6``@0clc8103EdL`30=WDc`@0f]G?103Le<h40=cBc0@0g=39103IcLD40=O9
`@<0dlFm103>_kL40<Jg[`@0_:jW102bY9h40:NIU0<0VHf8102:Og/407YaK@@0Jf=P101KEE<404]6
A@@0>cLg0`0/:BX4020N7P@05Q<C100G5AH4024R9@@09b/`0`0]=3X4034k@`@0=41:100gAE0403U:
EP@0>deK0`0lDEl403eDI0@0?UMX100oFF/F0?ooo`00503oool403mJK0@0?eQY100nEVH303iDH`@0
?E5O100lCU/403Y:EP@0>4I@100f@DT3038k@P@0<3Hk100d>Cd403e2AP@0ADY>101>DeH405QMG`<0
IFU[101aMGL407j1P`@0Rhj?102GVIX40:BUY0<0/;2^102i^KL40<70_P@0b<K3103?c<P40=GAc0<0
fMC?103JeLl40=cDcP@0g=;<103Ld<T40=W=a@@0elW10`3CaKd40<jo]`@0a[N_102l[ZL40;:TWP@0
YiVD0`2ISHP408YoN`@0NW5]101[Hf0405]ED`@0BdI5100k=cL302`Y:P@081hN100F4a<401LE5P@0
8B8U100W:c0302dd>P@0<C]3100d@4X403M5D0@0>DYF100kCE/303aAG`@0?EAT100nEfP403mIJaH0
oooo000D0?ooo`@0?eY/100oF6T403iFIP<0?UAS100mDEl403a>F`@0>TYF100hAU0403I1B@<0<S]2
100`=S/403@i?@@0?D961015BTh404iCEP@0F5eO0`1UJF/4075eM`@0OX63102;SXl409NIVP@0Y:FT
0`2`/:h40;Vi]`@0`L2n1038a/<40<o<b0@0eM7<0`3Ie<l40=[Ec`@0g=C>103Ld/`40=c@b@@0fLg5
103GbL430=?5_@@0c[ng1036]jl40;b^Y`@0/ZBN102WVI@309V=R0@0RWmk101jLFd406]SH0@0FeEC
101;ATD403/g=`<0;2TZ100P7Qh401HC4`@05aDF100Q8RD402L[<0<0;C@j100a>d<403A0BP@0=dE@
100iBUH403]=F`<0?55O100mE6@403iGJ0@0?eU[5P3oool001@0oooo100oFV`403iHJ@@0?UEU0`0m
Df8403a@GP@0>TaI100hBE@403I4CP@0<cm70`0`>D0402`c>0@0;38f100b>3/403/o@P@0A4Q;101?
DeD305ULG`@0HfIX101_LW<407anO`@0RH^<102EUYH309nOWP@0YjNU102_[Z`40;Ne/@@0_;Vf1030
_KT30<Bo^P@0a/2j1037_kT40<Jm]`@0aK^d1033^;440<2d[@<0_:nX102eZJ440:jQVP@0YIVC102L
T8X40966P0<0Q7Ye101eKFT406IOG0@0Ee5?1017@d8403Ld=0@0:2HW0`0L6Q/4014=3@@040`=100H
61X4020R9P@09R/a0`0[<cX402lj@P@0<cm9100eA50403Q9E@@0>TeJ0`0kD5l403aCH`@0?EIW100n
FF/F0?ooo`00503oool403mJK0@0?UQY100nEFD303eCHP@0?51N100jC5T403Q9E0@0=TA>100c?dL3
030i@0@0;3<h100/<SH4038h>`@0>cm21014B4/404mCE@<0FEaO101SIVP406mbL`@0O7io1029Rh`4
09FFUP<0WinN102WYjD40:n^[0@0]kFa102l^KH40<2m^@<0a;nj1036`;X40<No^@@0a[fg1035^k@4
0<>h/@@0`;B]0`2l[jP40;FYX@@0[Z6J102UVI<409b@RP@0THJ00`24NWD407E]J@@0IUmL101GDDl4
04M3@P@0=c@d100X9RL301`J6`@04@d=100@30d401PH6P@0828V100V:c4302/c>P@0;cY2100c?dT4
03E4D0@0>4UE100jCEX303]@G`@0?5=S100mEVL403iIJaH0oooo000D0?ooo`@0?eY/100nF6T403iE
I@<0?E=R100lD5h403Y<F@@0>4UD100fA4h403<oA`<0<3U0100/<cP402`b=P@0<SPk100k?d8404A8
B`@0Ce=E0`1IG5l406=VJ0@0Kg9c101lOWl408V;S0@0UIJF0`2OWih40:NWY@@0[jj/102g]K440;bi
]P@0`;fi0`34_kX40<K0^P@0akni1036_KL40<Fk]0@0`kRa1030]:d30;b_Z0@0]JVQ102^XIX40:FI
T`@0W92:102AQX0308AjM@@0MFeY101VGe`405MAC`@0Ad=2100g=3@402PV9`<071XK100A3@d4010<
3@@061PJ100P8RH402H[<@<0:c<j100_>T8403<oB@@0=DA@100hBED403Y=FP<0>e1O100lDf<403eF
I`@0?UU[5P3oool001@0oooo100oFV`403iHJ@@0?UEU0`0mDf8403a@GP@0>TaI100hBE@403I4CP@0
<cm70`0`>D0402`c>0@0;38f100b>3/403/o@P@0A4Q;101?DeD305ULG`@0HfIX101_LW<407anO`@0
RH^<102EUYH309nOWP@0YjNU102_[Z`40;Ne/@@0_;Vf1030_KT30<Bo^P@0a/2j1037_kT40<Jm]`@0
aK^d1033^;440<2d[@<0_:nX102eZJ440:jQVP@0YIVC102LT8X40966P0<0Q7Ye101eKFT406IOG0@0
Ee5?1017@d8403Ld=0@0:2HW0`0L6Q/4014=3@@040`=100H61X4020R9P@09R/a0`0[<cX402lj@P@0
<cm9100eA50403Q9E@@0>TeJ0`0kD5l403aCH`@0?EIW100nFF/F0?ooo`00503oool403mJK0@0?UMX
100mEFD303aBH@@0>dmM100iBeP403M7D`@0=4==100a?DH302hg?`@0:Ble100V:Rh402T/;`@0<3@g
100i?3l40455A`<0C4mA101GFU/4069UIP@0KFm`101iNWX408>4Q0<0S8b<102DU9<409^KV@@0XJ6O
102WYJ840:^XY0<0[ZZV102_ZZH40:nZY0@0[ZRR102/YYl40:ZRW0@0YYjG0`2QV98409ZAR`@0ThV4
102<PWd408=jM@@0NG5]0`1^IV<4065JF0@0DTe;1012?ch403@a<@@09bHV100L6Q/300l<30@030T9
100C4Q@401TK7P@082@Y100U;38302Xc>`@0;SY3100b?dX403A4D0@0=dUF100iCE/303]@G`@0?5=S
100mEVL403iIJaH0oooo000D0?ooo`@0?eY/100nEfP403eEI@<0?59Q100kCed403U;F0@0=dMC100d
@dd4034mAP<0;SLo100Y;cD402HZ;P@0:B`_100`=3L403Tl?`@0@DE70`1<Ce4405MJF`@0HVEV101]
Kg0407UjNP@0PhB40`2<S8`409BDT`@0Vi^I102QXIl40:NUXP@0ZjRT0`2^ZZH40:nZYP@0[jZT102^
Z:840:bVW`@0ZZ:L102VWYL30:6HTP@0VY6;102CRH@408b2O@@0PgYe101iLFd306iVH`@0HEYH101B
CD/4048o?P@0=34a100W9RH401`J6`<03``<100<2@T401<B50@06A/N100P92T402D/<P<0:S<k100^
>T<4038oBP@0=4A@100gBEH403U=F`<0>e1O100lDf<403eFI`@0?UU[5P3oool001@0oooo100oFV`4
03iGJ0@0?EEU0`0lDV4403]?G@@0>D]H100gAe<403A3C@@0<Ce60`0^=cl402T_=@@09RX^100Y;2l4
030d=`@0>C`o1011ADL304a?D@@0EeYK101RIFH406e_L0@0NGYj1023Q8@308b<S0@0U9BC102KViT4
0:6QW`@0YjFR102[Z:@30:jZYP@0[jZV102_ZZ@40:jXXP@0[:JO102ZXY`40:JNU`<0XIRB102JTH/4
09>9Q0@0S89m1023NWD407UaK@<0KVIS101QFUP4059=B`@0@Sln100d<C4402LV9P@071XK0`0?30`4
00`92@@04a8D100I6ah4020T:@@09B`b0`0Z<c/402hj@`@0<Sm:100dA50403M9EP@0>DeK0`0kD5l4
03aCH`@0?EIW100nFF/F0?ooo`00503oool403mJK0@0?UMX100mEFD303aBH@@0>dmM100iBeP403M7
D`@0=4==100a?DH302hg?`@0:Ble100V:Rh402T/;`@0<3@g100i?3l40455A`<0C4mA101GFU/4069U
IP@0KFm`101iNWX408>4Q0<0S8b<102DU9<409^KV@@0XJ6O102WYJ840:^XY0<0[ZZV102_ZZH40:nZ
Y0@0[ZRR102/YYl40:ZRW0@0YYjG0`2QV98409ZAR`@0ThV4102<PWd408=jM@@0NG5]0`1^IV<4065J
F0@0DTe;1012?ch403@a<@@09bHV100L6Q/300l<30@030T9100C4Q@401TK7P@082@Y100U;38302Xc
>`@0;SY3100b?dX403A4D0@0=dUF100iCE/303]@G`@0?5=S100mEVL403iIJaH0oooo000D0?ooo`@0
?UU/100nEfP403aDI@<0>e9Q100jCed403Q;F0@0=TMC100c@Td4030mAP<0;3Hn100W;SD4020T:0@0
7AlR100T9RT402d`<P@0=SPj0`0o@T<404Q;C0@0DEAD101JGEh406AWI`@0KVm_0`1hNGP407n0P0@0
QHJ6102;RhX4092?SP@0Ti6@0`2DTY0409JCT@@0UY>@102ETXh409>?R`@0T8b8102;QX8308F0O0@0
P7Yf101iLfl4079/J@@0JVER101PFeT305AAC`@0B4E4100j>CP402h];@@08R4R100E5AH400/;30<0
2@P9100?3Pl401DF6@@06ahS100P9R`402D^=@<0:SDm100^>d@40350B`@0=4EA100fBEH403Q=F`<0
>U1O100lDf@403eFJ0@0?UU[5P3oool001@0oooo100nFF`403iGJ0@0?5AU0`0kDV4403Y?G@@0>4]H
100fAe<403=2C@@0<3e60`0/=Sh402L^=@@082@X100M7b8402@V:@@0;C0b100f>3X303m2@`@0B4]<
101AE5@405YMGP@0I6MW101^Kfl307QiN0@0Oh201025QXH408^;RP@0T8n>102CTI0309BBT0@0UY>A
102FTi0409FBSP@0Thn;102@S8P408^6PP<0QH1l1020NWH407UcK`@0LVaY101ZIF84061KF@<0E55?
1018AD@403Xi>0@0;Rd]100R8B8401DE5P@02`/<0`0920T400l>3`@05AHI100K7R<4020V;0@09Bhe
0`0Z=Cd402hkA0@0<D1;100dAE4403I9EP@0>4eK0`0jD5l403aCI0@0?EIX100nFF/F0?ooo`00503o
ool403iIK0@0?UMX100lE6D303]BH@@0>TmM100hBeP403I7D`@0<d9=100`?DH302`f?P@09bhe100P
92P401dO8P@092HY100]<38403Hh>P<0?d931018Bd`4055DE0@0FUeN101TIfL406i_K`<0N7Uh101o
P80408F6QP@0Rh^:102@Shh409>AT0<0U9:@102FTi4409JCT0@0UI:>102CSh/4092<R0@0RhJ20`25
P7`4081jMP@0NG=_101bK6T406YUHP@0H5]I0`1DDDl404Q5A0@0>STh100^;Bd4028Q8P@05ADF100;
2``300T82@@03`h?100E5QT401/N8`@082H/100U;SD302Xe?@@0;S]4100a@4/403A5D@@0=TUF100h
CE/303Y@G`@0?5=T100mEVP403iIJaH0oooo000D0?ooo`@0?UU/100mEfP403aDI@<0>e9Q100iCed4
03Q;F@@0=DMD100c@Th402lmA`<0;3Lo100W;cH4024W;0@06QdP100H6A/401lQ8`@0:B/]0`0a=CH4
03Tm?P@0@DA51019Bd`4055CD`@0FE]K0`1QHf<406QZJP@0KW1_101cLg<407IfM`@0NGYi0`1lO7/4
07emO0@0OWel101mO7X407]jN0@0N7Id101dLFl306aZI`@0I69O101OGE/405UHEP@0DE1?1016ATH3
03dl?@@0<c<d100X:2T401`M7P@04a<D100;2P/400D20P<020H6100@4A@401LJ7P@0728X100R:S04
02H`>0<0:SI0100^?4L40351C@@0=4IB100fBUL403Q=G0<0>U1P100kE6@403eFJ0@0?UU[5P3oool0
01@0oooo100nFF`403eGJ0@0?5AU0`0kDV4403U?G@@0>4]I100eAe@403=2CP@0;ce70`0/=cl402L_
=P@08BL/100J7B0401PI6`@07b4S100Y:bd3034e=P@0>Cdn1011A4D404U;C0@0DE=C101IFe/3065S
H`@0J6YZ101^L6l407=cL`@0MWIg101iNWT307alN`@0OGel101nOG`407elNP@0NgYh101hMW@407Aa
K`<0K6YW101THUl405mMF`@0FEQF101AD4l404I6AP<0?C`m100c<c@402PX:@@071dN100C4a@400/:
2`@01@820`081PH4010A50@05aXN100L8RP4028Z<0@09S0h0`0Z=T0402hlA`@0<D5=100dAU8403I:
E`@0>4eL0`0jD60403]DI0@0?EIX100nFF/F0?ooo`00503oool403iIK0@0?EMX100lE6D303]BH@@0
>DmM100hBeT403E7E0@0<d9>100_?DL302`g?`@09blf100Q9b`401XM80@061TK100O8B<402T[;@<0
<CDf100i?Ch40454A@@0BD]<101ADe<405UKF`<0HF=S101XJVX406i`K`@0Lg=c101fMWL407UjN@<0
O7ak101mOG`407imO0@0OGaj101kNWP407QfM0@0M75_0`1/JVL406ARG`@0GeeK101IF5H4055@C`@0
ATI60`0m?3d403<c=0@0:2PY100L7Ah401<C50@02`X;10050P8300P61P@0414D100G6Qh401`R:0@0
8RX`100V<3P302Xf@0@0;Sa7100a@Dd403A6DP@0=TYG100hCE`303Y@H0@0>eAT100mEVP403iIJaH0
oooo000D0?ooo`@0?UU/100mEfP403aDI@<0>e9Q100iCed403Q;F@@0=DMD100c@Th402lmA`<0;3Lo
100W;cH4024W;0@06QdP100H6A/401lQ8`@0:B/]0`0a=CH403Tm?P@0@DA51019Bd`4055CD`@0FE]K
0`1QHf<406QZJP@0KW1_101cLg<407IfM`@0NGYi0`1lO7/407emO0@0OWel101mO7X407]jN0@0N7Id
101dLFl306aZI`@0I69O101OGE/405UHEP@0DE1?1016ATH303dl?@@0<c<d100X:2T401`M7P@04a<D
100;2P/400D20P<020H6100@4A@401LJ7P@0728X100R:S0402H`>0<0:SI0100^?4L40351C@@0=4IB
100fBUL403Q=G0<0>U1P100kE6@403eFJ0@0?UU[5P3oool001@0oooo100nFV`403eGJ@@0?5EU0`0k
DV8403U?GP@0=daJ100eB5D403=3C`@0<3i90`0/>D8402Lb>P@08RXa100M8RH401DH6P@051HG100K
7R0302@X:@@0;C0b100d=SP403Pk?@@0?T531015B4X304]>D0@0DUAE101GFUX405]NG`@0Gf9R101R
IFD306AWI`@0IFMW101UJ6L406EWI`@0I6EU101RHf<405eOG`<0F5YK101BEEH404Y=C`@0@dE7100k
?Cl403<e=`<0;2h`100S9BL401XK7P@0414C100720T4008000@010820`0=3@l401<G6P@06AlT100O
9Rd402<]=@@0:3<m0`0[>D<402lnBP@0<T=?100dAe@403I;F@@0>4iM0`0jDF4403aDI@@0?EMX100n
FF`F0?ooo`00503oool403iJK0@0?EMY100lEFD303]BHP@0>DmN100gC5X403E8E@@0<d=?100`?TT3
02`i@P@09c8j100R:S4401dR9P@05APJ100D5QL401/N80<092PY100]<38403@f>0@0>3/m100n@D<4
04E8BP<0Bdi@101BE5D405MJFP@0FeiO101OHV84069UI@<0I6MW101UIfL406EXI`@0IFMW101TIFD4
069SH`@0GEmO0`1HFU/4059EEP@0BTe?1013ADL403/m?`@0<cDg0`0/;S0402<U9`@06Q/N100@4A<4
00L82@@00P0010040P8300d=3`@04aLJ100I7b@401lV;@@08bde100X<cd302/i@`@0;ci:100b@dl4
03A7E0@0=T]I100hCUd303YAH@@0?5AU100mEfP403iIK1H0oooo000D0?ooo`@0?UY/100mEfT403aE
I@<0>e9R100iCeh403M<FP@0=DQE100c@dl4030nB@<0;3U2100W<SX4028Z<@@07B8V100E61X401@F
5`@06ahP0`0T:2T402d`<P@0=3Hh100h>cd403i1@`@0ADQ:0`1;CU04059DE@@0EeYJ101KGUl405mR
HP@0HVEU0`1TIfL406EWI`@0IFQW101UIfL406AUI@@0HV=S101MGel305QJF`@0DUEF101:CDl404=5
A`@0>cdo100c=CL302`^<0@08bDW100J6ah4010A4`@01`P91002000400@20P<03@d?100C5aX401TO
90@07bH]100S;CD402Pc?@<0:cU3100_?TX40393C`@0=4MD100fBeT403Q>G@<0>U5Q100lE6D403eG
J0@0?UU/5P3oool001@0oooo100nFV`403eGJ@@0?5EU0`0kDV8403U?GP@0=daJ100eB5D403=3C`@0
<3i90`0/>D8402Lb>P@08RXa100M8RH401DH6P@051HG100K7R0302@X:@@0;C0b100d=SP403Pk?@@0
?T531015B4X304]>D0@0DUAE101GFUX405]NG`@0Gf9R101RIFD306AWI`@0IFMW101UJ6L406EWI`@0
I6EU101RHf<405eOG`<0F5YK101BEEH404Y=C`@0@dE7100k?Cl403<e=`<0;2h`100S9BL401XK7P@0
414C100720T4008000@010820`0=3@l401<G6P@06AlT100O9Rd402<]=@@0:3<m0`0[>D<402lnBP@0
<T=?100dAe@403I;F@@0>4iM0`0jDF4403aDI@@0?EMX100nFF`F0?ooo`00503oool403iJK0@0?EMY
100lEFH303]CH`@0>E1O100hCE/403I9E`@0<dEB100`@4`302dkAP@0:CDn100T;cH401lW;@@06QlT
100C5QT4018D5P<061/M100O8b@402HZ;0@0:bl`100_<S<403@g>0<0>3`m100k@44403i3A@@0@TM9
1017C4d404Y?D0<0CE5C101>De@404mDE@@0Ce=D101=DU<404aAD`@0Be1C0`18CU8404A9C@@0@4E9
100j?d<403<g>`@0:Rha0`0P92L401HJ7@@03Q4D100620X400000@@00`42100:2`h3014D60@05adR
100L9B/4024[<`@09S8k100Y=d4302dlA`@0<45=100cAE8403E9E`@0=daK100iCel303YBHP@0?5EV
100mEfT403iIK1H0oooo000D0?ooo`@0?UY/100mEfT403aEIP<0>e=S100iD5l403Q=F`@0=TUG100c
AE840310C0<0;C]6100Y=Ch402@_=P@07bL]100J7b@401<F6@@04Q@F0`0H6ad401lS90@09RX/100[
;c0402lb<`@0=3Lh0`0h?3d403]0@@@0?T=51012AdT404M<C@@0BTm@0`1=DE<404iCE0@0CeAE101?
De@404eBD`@0C55C101;D5<304Q>DP@0A4U=1010ADT403Xo@`@0<cLk100Z;S43020T9`@05QXM100>
4A@400H82P@0000110030@8400X;3P<04A@H100G7B8401`U:`@08B/c100V<S/402Tg@@<0;Ca7100`
@Dd403=5DP@0=DUG100gC5/403U?G`<0>U9R100lEFH403eGJ@@0?UU/5P3oool001@0oooo100nFV`4
03eGJ@@0?5EV0`0kDf<403U@G`@0>4eK100fBEL403=5DP@0<41<0`0]>dH402Te?P@092lf100O9bd4
01XO90@04aHI100B51H301PK7@@07b<T100V:R`402/_<0@0;c8c100d=cP303Pl?@@0>d11100n@dD4
0497B@@0Ada=101:Ce0304eAD`@0CU=D101?E5D404mCE0@0CE9C101<DE<404]@D`<0B4iB1014BDd4
0415B@@0>Sm3100c=c/402X^<@<082@W100F6Qd400hA50@01PP:1000004400<10P@02P/>0`0A51P4
01LM8P@072D[100Q:c<402Hb>`@0:CM10`0]?4L40311C@@0<dEB100eBEL403M<F`@0>DmO0`0jDV84
03aEIP@0?EMY100nFF`F0?ooo`00503oool403iJK0@0?EMY100lEFH303]CH`@0>E1O100hCE/403I9
E`@0<dEB100`@4`302dkAP@0:CDn100T;cH401lW;@@06QlT100C5QT4018D5P<061/M100O8b@402HZ
;0@0:bl`100_<S<403@g>0<0>3`m100k@44403i3A@@0@TM91017C4d404Y?D0<0CE5C101>De@404mD
E@@0Ce=D101=DU<404aAD`@0Be1C0`18CU8404A9C@@0@4E9100j?d<403<g>`@0:Rha0`0P92L401HJ
7@@03Q4D100620X400000@@00`42100:2`h3014D60@05adR100L9B/4024[<`@09S8k100Y=d4302dl
A`@0<45=100cAE8403E9E`@0=daK100iCel303YBHP@0?5EV100mEfT403iIK1H0oooo000D0?ooo`@0
?UY/100mF6X403aFI`<0>e=T100jDF4403Q>G@@0=T]I100dAeD40393D0<0;cm:100[>D@402Ld?@@0
8bde100N9R`401PN8`@04A@G0`0@4Q@401HI6`@0720R100P92H402<W:@@09RT[0`0X;Bh402`b<`@0
;cDg100`=cP4038h>P@0=C`n0`0h?d4403U0@P@0>D53200j@DD403Q0A0@0=d140`0f?T<403<k@0@0
;SHk100V;c@4020W;0@061lS0`0@5AX400X>4P@010L:1000004400810P@02@X>100@51T301HM8`@0
72@[100P:c<402Da>P@0:3I1100/>dL302m0C0@0<DAA100dAeD403I;F@@0>4iM100iD60303]CI0@0
?5EW100mF6T403iJK1H0oooo000D0?ooo`@0?UY/100mF6X403aFI`<0>e=T100jDF4403Q>G@@0=T]I
100dAeD40393D0<0;cm:100[>D@402Ld?@@08bde100N9R`401PN8`@04A@G0`0@4Q@401HI6`@0720R
100P92H402<W:@@09RT[0`0X;Bh402`b<`@0;cDg100`=cP4038h>P@0=C`n0`0h?d4403U0@P@0>D53
200j@DD403Q0A0@0=d140`0f?T<403<k@0@0;SHk100V;c@4020W;0@061lS0`0@5AX400X>4P@010L:
1000004400810P@02@X>100@51T301HM8`@072@[100P:c<402Da>P@0:3I1100/>dL302m0C0@0<DAA
100dAeD403I;F@@0>4iM100iD60303]CI0@0?5EW100mF6T403iJK1H0oooo000D0?ooo`@0?UY/100m
F6X403aFI`<0>e=T100jDF4403Q>G@@0=T]I100dAeD40393D0<0;cm:100[>D@402Ld?@@08bde100N
9R`401PN8`@04A@G0`0@4Q@401HI6`@0720R100P92H402<W:@@09RT[0`0X;Bh402`b<`@0;cDg100`
=cP4038h>P@0=C`n0`0h?d4403U0@P@0>D53200j@DD403Q0A0@0=d140`0f?T<403<k@0@0;SHk100V
;c@4020W;0@061lS0`0@5AX400X>4P@010L:1000004400810P@02@X>100@51T301HM8`@072@[100P
:c<402Da>P@0:3I1100/>dL302m0C0@0<DAA100dAeD403I;F@@0>4iM100iD60303]CI0@0?5EW100m
F6T403iJK1H0oooo000D0?ooo`@0?UY/100mF6X403aFI`<0>e=T100jDF4403Q>G@@0=T]I100dAeD4
0393D0<0;cm:100[>D@402Ld?@@08bde100N9R`401PN8`@04A@G0`0@4Q@401HI6`@0720R100P92H4
02<W:@@09RT[0`0X;Bh402`b<`@0;cDg100`=cP4038h>P@0=C`n0`0h?d4403U0@P@0>D53200j@DD4
03Q0A0@0=d140`0f?T<403<k@0@0;SHk100V;c@4020W;0@061lS0`0@5AX400X>4P@010L:10000044
00810P@02@X>100@51T301HM8`@072@[100P:c<402Da>P@0:3I1100/>dL302m0C0@0<DAA100dAeD4
03I;F@@0>4iM100iD60303]CI0@0?5EW100mF6T403iJK1H0oooo000D0?ooo`@0?UY]100nF6X403eG
J0<0?5AU100jDV<403U@G`@0=deL100eBUP403=7E0<0<D=?100^?TX402XiA0@09c@m100R;SH401dW
;@@061lT0`0@5AP400/>40@03a<E100G71h401dR90@07R<U0`0M8R<401`R90@07B<V100Q:2X402@/
;P@08b`^0`0R:bl402D_=0@0:C@i200[=S/402`f?0@0:cHm0`0Z=C`402Pc>P@08bhe100M9bh401HP
9P@041PM0`094AH400D;3`@00PD710051PP400/?4`@04ALM100G7bH301`V;P@08B`e100U<S`402Pg
@P@0;3a8100^@4d30354D@@0<dME100eBUT403M=G0@0>E1P100jDV<303]DI@@0?5IX100mF6X403iJ
KAH0oooo000D0?ooo`@0?UY]100nF6X403eGJ0<0?5AU100jDV<403U@G`@0=deL100eBUP403=7E0<0
<D=?100^?TX402XiA0@09c@m100R;SH401dW;@@061lT0`0@5AP400/>40@03a<E100G71h401dR90@0
7R<U0`0M8R<401`R90@07B<V100Q:2X402@/;P@08b`^0`0R:bl402D_=0@0:C@i200[=S/402`f?0@0
:cHm0`0Z=C`402Pc>P@08bhe100M9bh401HP9P@041PM0`094AH400D;3`@00PD710051PP400/?4`@0
4ALM100G7bH301`V;P@08B`e100U<S`402Pg@P@0;3a8100^@4d30354D@@0<dME100eBUT403M=G0@0
>E1P100jDV<303]DI@@0?5IX100mF6X403iJKAH0oooo000D0?ooo`@0?UY]100nF6X403eGJ0<0?5AU
100jDV<403U@G`@0=deL100eBUP403=7E0<0<D=?100^?TX402XiA0@09c@m100R;SH401dW;@@061lT
0`0@5AP400/>40@03a<E100G71h401dR90@07R<U0`0M8R<401`R90@07B<V100Q:2X402@/;P@08b`^
0`0R:bl402D_=0@0:C@i200[=S/402`f?0@0:cHm0`0Z=C`402Pc>P@08bhe100M9bh401HP9P@041PM
0`094AH400D;3`@00PD710051PP400/?4`@04ALM100G7bH301`V;P@08B`e100U<S`402Pg@P@0;3a8
100^@4d30354D@@0<dME100eBUT403M=G0@0>E1P100jDV<303]DI@@0?5IX100mF6X403iJKAH0oooo
000D0?ooo`@0?UY]100nF6X403eGJ0<0?5AU100jDV<403U@G`@0=deL100eBUP403=7E0<0<D=?100^
?TX402XiA0@09c@m100R;SH401dW;@@061lT0`0@5AP400/>40@03a<E100G71h401dR90@07R<U0`0M
8R<401`R90@07B<V100Q:2X402@/;P@08b`^0`0R:bl402D_=0@0:C@i200[=S/402`f?0@0:cHm0`0Z
=C`402Pc>P@08bhe100M9bh401HP9P@041PM0`094AH400D;3`@00PD710051PP400/?4`@04ALM100G
7bH301`V;P@08B`e100U<S`402Pg@P@0;3a8100^@4d30354D@@0<dME100eBUT403M=G0@0>E1P100j
DV<303]DI@@0?5IX100mF6X403iJKAH0oooo000D0?ooo`@0?e]]100nFF/403eGJ@<0?5IW100kE6D4
03YBHP@0>E1O100gCE`403E:F@<0<dME100a@e0402hoC0@0:c]6100W=T0402<`>@@07bXb0`0I8RT4
01<K80@03Q<G100>4aH4018I70@05Q`P0`0G7R4401LO8P@0624T100H8RH401PS9`@06RH/0`0N:S44
020/=0@082df100R<3T402Dc?0@09S<m100T<CX302<_>0@08Bdf100L:30401LQ:@@041XP100<5AX3
00X@50@01@T<10072`l400lF6`@05AdT100J92`401hZ<`<08S0j100V=D0402TjA@@0;3i:100_@Tl4
0355D`<0<dQG100eBeX403M=G@@0>51P100jDV8403]DI@<0?5IW100mEfT403iIJ`@0?eY]5P3oool0
01@0oooo100oFfd403iIJ`@0?EMY0`0lEVL403]DI@@0>U9R100iD5l403M=G0@0=DYI0`0cAeD40353
D0@0;Sm<100[>dH402Lf@0@08c0i100O:S8301TR:@@04a/P100>4aL400hC5P@04QTL100F720301LN
8@@05alR100H8B@401PR9P@062<W100J9R`301hZ<@@082`d100P;CH4028`>@@09C<l100V<cd402@a
>P<08blh100Q;CH401`X<0@05b4Y100@6R0400`E6P<02Q0D10052@`400L;3`@03aHK100E7B@401XT
;0@07RXc0`0R<3X402He@0@0:CY5100/?TX402m2C`@0<DEC0`0cB5L403E;FP@0=deM100hD60403YB
HP@0>eAU0`0lEVL403eGJ@@0?UU[100oFVdF0?ooo`00503oool403mKK@@0?UU[100mEfT303aFI`@0
>eAU100jDV8403U@G`@0=deL100eBUT303=7E@@0<D=@100^?d`402/kAP@09cI0100S<3T401lZ<P<0
6B8Y100C6b0400hC5`@03Q<F100B6A`401HL80<05ahQ100G7b8401PQ90@0628V100H8bL401XV;0<0
7RXa100P;3@4020]=P@08S0i100U<c`402Hc?@@0934j0`0S;cP4024]=P@072P`100G8BT4010J80@0
31DJ0`0:41@400D930@01`/?100?5Q/401DM90@06R@/100N:S<3028`>P@09SE0100Y>TD402`nBP@0
;d9?100aAE<303=8E`@0=D]J100gCEd403Q@H0@0>U9R100kE6D303aFI`@0?EMY100nFF/403mJKAH0
oooo000D0?ooo`@0?e]^100nFV`403eHJ`<0?EMY100lEVL403]DI@@0>U9S100iD64403M>GP<0=TaK
100dBEP40396E0@0<4=@100]?d/402XjAP@09SI00`0R<3X401h[<`@06BD]100C72<800dF70<04Q`R
100F8BH401DP9@@05B4V100G92/401XX;`<07B/b100M:c<401d/=@P07B`g100N;CL401h]>0<07B/f
100L:C8401/T;@@05b0X100B6R0400`B5`<02Q0E100?5Qd401DO9`@06RH_100O;3H402<a?0@09SI2
0`0Y>TL402`nB`@0;d9?100aAE<403=8E`@0=DYJ0`0fCE`403Q?G`@0>E5Q100jDf<403]DI@@0?5IW
0`0mEfT403eHJP@0?UU/100oFfdF0?ooo`00503oool403mKKP@0?UY/100mF6/303eGJ@@0?5IW100k
E6D403YBH`@0>E1Q100gCUh303I<F`@0=4UH100bAU@40313D0@0;Cm;100Z>TH402Hf@0<08S0j100N
:c<401TU;@@04a`S200=5Q`3018L8P@05R4V100E82D401DQ9P@05b@[100J:2l301d[<P@07B/c100M
;3D801d/=`@07Rdg100N;CP301d[=P@072Tb100K92d401LP:0@04QXP100<4QL300X@5@@03aHM100E
7bL401XV;`@07b`f100S<C`402Hf@P<0:CY7100/?T/402m2C`@0<DEC100cB5L403E:FP<0=TeL100h
Cel403UAH@@0>U=S100kE6D403aFI`<0?EMY100mF6X403iIK0@0?e]]5P3oool001@0oooo100oFfh4
03iJK0@0?EQ[0`0mEfT403aFI`@0>eAU100jDV<403U@H@@0=diN0`0fC5/403A9F0@0<TID100`@e04
02doB`@0:SY6100V=T03028`>P@07R/c100I9Bd401<L8`P03AHL0`0B728401HQ9P@05B0U100E8BH4
01LT:`@06RP_0`0M:c8401d[<`@07B`e200M;3L401h]=`@07Rdh0`0M:cH401`Y<P@06b@]100G82P4
018J80@0318G0`0:41D400lF7@@05AlW100J9Rl401l/=P@08c4l100V=T8302TjA`@0;3i;100_@Tl4
0355D`@0<dQG100eBUX303I=G0@0>4mO100iDF4403YCH`@0>eAU100lEVL303eGJ@@0?EQZ100nFF`4
03mKKAH0oooo000D0?ooo`@0?e]^100nFV`403eHJ`<0?EMY100lEVL403]DI@@0>U9S100iD64403M>
GP<0=TaK100dBEP40396E0@0<4=@100]?d/402XjAP@09SI00`0R<3X401h[<`@06BD]100C72<800dF
70<04Q`R100F8BH401DP9@@05B4V100G92/401XX;`<07B/b100M:c<401d/=@P07B`g100N;CL401h]
>0<07B/f100L:C8401/T;@@05b0X100B6R0400`B5`<02Q0E100?5Qd401DO9`@06RH_100O;3H402<a
?0@09SI20`0Y>TL402`nB`@0;d9?100aAE<403=8E`@0=DYJ0`0fCE`403Q?G`@0>E5Q100jDf<403]D
I@@0?5IW0`0mEfT403eHJP@0?UU/100oFfdF0?ooo`00503oool403mKK@@0?UY]100nFF`303iIJ`@0
?EQZ100lEfP403aEI`@0>eAU100jDf<303UAH@@0>4mO100fCEd403E;FP@0<dQG100aAE<402i2D0<0
;3m;100Y>dL402Hg@P@08S8m100O;ST401d[=P<06BLb100H9C0401TW<@@06RTb100J:34401/Z<P<0
7Rhf100Q<CX402<c?@@08c<o200R<cl4028c?P<08c<o100Q<3`401/X<P@05B4Y100F8BX401XV<0<0
7BXd100O;ST402<c?P@09SM4100Y?4P402`oC@@0;T9@0`0`AE@40398E`@0=4YJ100fC5`403M>GP@0
>51Q0`0iDV8403YCI0@0>eAV100lEVL403aGJ0@0?EQZ0`0nFF/403iIK0@0?UY]100oFfhF0?ooo`00
503oool403mKK@@0?UY]100nFF`303iIJ`@0?EQZ100lEfP403aEI`@0>eAU100jDf<303UAH@@0>4mO
100fCEd403E;FP@0<dQG100aAE<402i2D0<0;3m;100Y>dL402Hg@P@08S8m100O;ST401d[=P<06BLb
100H9C0401TW<@@06RTb100J:34401/Z<P<07Rhf100Q<CX402<c?@@08c<o200R<cl4028c?P<08c<o
100Q<3`401/X<P@05B4Y100F8BX401XV<0<07BXd100O;ST402<c?P@09SM4100Y?4P402`oC@@0;T9@
0`0`AE@40398E`@0=4YJ100fC5`403M>GP@0>51Q0`0iDV8403YCI0@0>eAV100lEVL403aGJ0@0?EQZ
0`0nFF/403iIK0@0?UY]100oFfhF0?ooo`00503oool403mKK@@0?UY]100nFF`303iIJ`@0?EQZ100l
EfP403aEI`@0>eAU100jDf<303UAH@@0>4mO100fCEd403E;FP@0<dQG100aAE<402i2D0<0;3m;100Y
>dL402Hg@P@08S8m100O;ST401d[=P<06BLb100H9C0401TW<@@06RTb100J:34401/Z<P<07Rhf100Q
<CX402<c?@@08c<o200R<cl4028c?P<08c<o100Q<3`401/X<P@05B4Y100F8BX401XV<0<07BXd100O
;ST402<c?P@09SM4100Y?4P402`oC@@0;T9@0`0`AE@40398E`@0=4YJ100fC5`403M>GP@0>51Q0`0i
DV8403YCI0@0>eAV100lEVL403aGJ0@0?EQZ0`0nFF/403iIK0@0?UY]100oFfhF0?ooo`00503oool4
03mKK@@0?UY]100nFF`303iIJ`@0?EQZ100lEfP403aEI`@0>eAU100jDf<303UAH@@0>4mO100fCEd4
03E;FP@0<dQG100aAE<402i2D0<0;3m;100Y>dL402Hg@P@08S8m100O;ST401d[=P<06BLb100H9C04
01TW<@@06RTb100J:34401/Z<P<07Rhf100Q<CX402<c?@@08c<o200R<cl4028c?P<08c<o100Q<3`4
01/X<P@05B4Y100F8BX401XV<0<07BXd100O;ST402<c?P@09SM4100Y?4P402`oC@@0;T9@0`0`AE@4
0398E`@0=4YJ100fC5`403M>GP@0>51Q0`0iDV8403YCI0@0>eAV100lEVL403aGJ0@0?EQZ0`0nFF/4
03iIK0@0?UY]100oFfhF0?ooo`00503oool803mKKP@0?e]]0`0nFVd403iJK0@0?UU/100mFF/403eH
JP@0?EMY0`0lEVP403]EI`@0>eAV100jDf@403UBH`@0>51Q100gCel303E=G@@0=4]K100bBET40357
EP@0;dED100^@e<302e2D@`0;45@100/@4l402/oCP<0:3a;100W>TX402HjB0@09SY7200V>DL402Dh
AP<09CM4100T=T<402LjA`@0:Si;100[?dd402a1C`<0;T=B100_AE@40357E`@0<dYI100dC5`403I=
GP@0=dmP0`0hD64403UBH`@0>U=T100jE6H403]EI`@0?5IX0`0lEfT403eGJP@0?EQZ100mFF/403iI
K0@0?UY/0`0nFVd403mKK@P0?e]^5P3oool001@0oooo200oFfh403mKK@<0?UY]100nFV`403iIK0@0
?EU[100mF6X403eGJ@<0?5IX100kEFL403]DIP@0>U=T100iDV<403Q@H@@0=dmO0`0eCEd403A;F`@0
<TUI100aAeH402m5E0@0;T=C0`0]@U4<02a1D0@0;41?100[?dh302PlB`@09cY:100V>TP402HjA`P0
9SU7100U>4H302DgA0@093I3100W>TL402XnB`@0:cm=100/@Dl302i3DP@0;dED100aAeL403=:F@@0
=4aL100fCEh403M?H0<0>51Q100iDV<403YCI0@0>UAV100kEFL403aFJ0<0?5MY100mEfX403eHJP@0
?EU[100nFF`403iJK0<0?UY]100oFfd803mKKQH0oooo000D0?ooo`P0?e]^100oFfd303iJK@@0?UY/
100nFF`403eIJ`@0?EQZ100mEfT303aFJ0@0>eEW100kE6H403YCI0@0>E9S100hD64403M?G`<0=DeM
100dBe/40399F@@0<DMF100_AE@402i3D`<0;D9A300/@E0402a0C`@0:cm>0`0X?4/402LjBP@09SY8
100V>TL802HiA`@09CQ60`0U=d@402@f@`@09cY7100Z?T/402/oC@@0;45?0`0^@e8402m5E0@0<DMG
100cBUT403A<G0@0=TeN100gCf0303Q@H@@0>E9S100jDf@403YDIP@0>eEW100lEVP303aGJ@@0?EMZ
100mF6X403eIJ`@0?UU/100nFV`303iJK@@0?e]]200oFfhF0?ooo`00503oool803mKKP@0?e]]0`0n
FVd403iJK0@0?UU/100mFF/403eHJP@0?EMY0`0lEVP403]EI`@0>eAV100jDf@403UBH`@0>51Q100g
Cel303E=G@@0=4]K100bBET40357EP@0;dED100^@e<302e2D@`0;45@100/@4l402/oCP<0:3a;100W
>TX402HjB0@09SY7200V>DL402DhAP<09CM4100T=T<402LjA`@0:Si;100[?dd402a1C`<0;T=B100_
AE@40357E`@0<dYI100dC5`403I=GP@0=dmP0`0hD64403UBH`@0>U=T100jE6H403]EI`@0?5IX0`0l
EfT403eGJP@0?EQZ100mFF/403iIK0@0?UY/0`0nFVd403mKK@P0?e]^5P3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
09/0oooo0T0000230?ooo`00W@3oool00d000000oooo0?ooo`200?ooo`00N03oool2@0000080oooo
1D0000020?ooo`03@000003oool0oooo00/0oooo0d0000020?ooo`9000000`3oool3@00000D0oooo
00=000000?ooo`3oool0NP3oool007X0oooo00E000000?ooo`3oool0oooo@00000030?ooo`03@000
003ooom0000000/0oooo00I000000?ooo`3ooom000000?oood0000040?ooo`04@000003oool0oooo
@0000880oooo001i0?ooo`03@000003oool0oooo0080oooo00=000000?ooo`3oool00`3oool00d00
0000oooo0?ooo`090?ooo`05@000003oool0oooo@000003oool00d0000020?ooo`04@000003oool0
oooo@0000880oooo001j0?ooo`05@000003oool0oooo0?oood0000000`3oool2@00000d0oooo0d00
0000103ooom00000@000040000030?ooo`=00000PP3oool007P0oooo00=000000?oood0000000`3o
ool01D000000oooo0?ooo`3ooom000000100oooo00=000000?ooo`3oool0RP3oool007T0oooo00A0
00000?ooo`3oool0oooo0T0000030?ooo`=000003@3oool2@00008`0oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0250052, -0.0250052, 
  0.00365857, 0.00365857}, {{6.8125, 280.125}, {280.125, 
  6.8125}} -> {-5.43703, -3.39431, 0.260941, 0.260941}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3.9 Summary",
  FontFamily->"Times New Roman",
  FontSize->18]], "Section"],

Cell[TextData[{
  StyleBox["\t",
    FontFamily->"Times New Roman",
    FontSize->10.5],
  StyleBox[
  "This chapter has described about the color image processing techniques \
based on the linear vector space as well as classical field theory.\n\tColor \
image data are always composed of the three independent color components, \
i.e. red, green and blue. This is a clear distinction to the monochrome image \
data. The color image characteristic vectors have been obtained by combining \
the color image components without any spatial derivatives. Even though an \
original image could be exactly recovered from its second spatial \
derivatives, i.e. source density, the characteristic vectors of monochrome \
image essentially had to be deduced by means of the spatial derivatives. A \
deduction of the characteristic vectors without any vector operations is an \
extremely significant. The color image characteristic vectors are \
corresponding to the reflected light intensity vectors. This means that the \
characteristic vectors of color image have a firm physical background, so \
that it may become a useful tool for inspection, identification and \
cognition. In this chapter, we have demonstrated as a tool of nondestructive \
testing.\n\tIn chapter 2, we described the basic principle and practical \
examples of the field theory of computer graphics. This chapter has extended \
the basic principles of the field theory to the color graphics images. \n\t\
The first part has devoted to describe about the nature and application of \
this color image vector field.\n\tIn the second part, we have described the \
image processing techniques to generate the sketch and painted images. Two \
methodologies have been taken into account for the monochrome image \
generation. One has utilized a magnitude distribution of the color \
characteristic image vectors, and the other has been based on a distribution \
of the inner products between the unit directional and color image vectors. \
Combination of the sketch data of red, green and blue components has \
generated a colored sketch image. Each of the sketch components has been \
generated by means of the two-dimensional monochrome image characteristic \
vectors described in chapter 2. The color painted image has been obtained by \
combining the painted image data of the red, green and blue components.\n\tIn \
the third part, the high-resolution color images have been generated from a \
low-resolution color image. Each of the governing equations concerning with \
the red, green and blue components has been independently solved with higher \
resolution, and then a combination of their solutions has led to the \
high-resolution color images. A correlation analysis between the generated \
and exact image data has suggested that good high-resolution color images can \
be generated by the method of differential equations.\n\tFinally, we have \
generated the two types of three-dimensional color images. One is the \
shadowed lighting color image, and the other is the illusive color image. \
Because of color, both three-dimensional color images have been more \
impressive to that of  three-dimensional monochrome images.",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Times New Roman"]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["REFERENCES", "Section",
  FontFamily->"Century",
  FontSize->12]], "Subsection"],

Cell[TextData[{
  StyleBox["[1] Stephen Wolfram, ",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["The Mathematica Book",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox[
  ", 3rd ed. (Wolfram Media/Cambridge University Press, 1996).\n[2] \
J.D.Jackson, \"Classical Electrodynamics 3",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10],
  StyleBox["rd",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10,
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" Edition,\" John Wiley & Sons, New York (1998).",
    TextAlignment->Left,
    TextJustification->1,
    FontFamily->"Century",
    FontSize->10]
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 740}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{635, 632},
WindowMargins->{{0, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->29,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
ShowCellLabel->False,
StyleDefinitions -> "Textbook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 277, 9, 61, "Title"],

Cell[CellGroupData[{
Cell[2033, 64, 160, 4, 108, "Section"],
Cell[2196, 70, 3113, 49, 351, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5346, 124, 336, 12, 108, "Section"],

Cell[CellGroupData[{
Cell[5707, 140, 304, 11, 34, "Subsection"],
Cell[6014, 153, 762, 17, 58, "Text"],

Cell[CellGroupData[{
Cell[6801, 174, 227, 8, 34, "Subsubsection"],
Cell[7031, 184, 228, 7, 79, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7308, 197, 295, 11, 34, "Subsection"],
Cell[7606, 210, 347, 12, 21, "Text"],

Cell[CellGroupData[{
Cell[7978, 226, 103, 2, 34, "Subsubsection"],
Cell[8084, 230, 831, 24, 45, "Text"],
Cell[8918, 256, 463, 8, 134, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9418, 269, 107, 2, 34, "Subsubsection"],
Cell[9528, 273, 814, 24, 45, "Text"],
Cell[10345, 299, 458, 10, 120, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10840, 314, 103, 2, 34, "Subsubsection"],
Cell[10946, 318, 577, 16, 32, "Text"],
Cell[11526, 336, 502, 13, 162, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12065, 354, 103, 2, 34, "Subsubsection"],
Cell[12171, 358, 692, 17, 45, "Text"],
Cell[12866, 377, 491, 13, 162, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13394, 395, 108, 2, 34, "Subsubsection"],
Cell[13505, 399, 605, 17, 33, "Text"],
Cell[14113, 418, 139, 4, 38, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14289, 427, 108, 2, 34, "Subsubsection"],
Cell[14400, 431, 455, 13, 33, "Text"],
Cell[14858, 446, 257, 7, 59, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15152, 458, 106, 2, 34, "Subsubsection"],
Cell[15261, 462, 596, 15, 45, "Text"],
Cell[15860, 479, 545, 16, 203, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16442, 500, 109, 2, 34, "Subsubsection"],
Cell[16554, 504, 1381, 33, 102, "Text"],
Cell[17938, 539, 470, 15, 189, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18445, 559, 133, 3, 34, "Subsubsection"],
Cell[18581, 564, 281, 8, 20, "Text"],
Cell[18865, 574, 230, 5, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19132, 584, 105, 2, 34, "Subsubsection"],
Cell[19240, 588, 660, 17, 33, "Text"],
Cell[19903, 607, 390, 9, 107, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20354, 623, 204, 7, 108, "Section"],
Cell[20561, 632, 563, 15, 45, "Text"],
Cell[21127, 649, 76, 1, 24, "Input"],
Cell[21206, 652, 331, 12, 21, "Text"],
Cell[21540, 666, 207, 7, 79, "Input"],
Cell[21750, 675, 387, 12, 33, "Text"],

Cell[CellGroupData[{
Cell[22162, 691, 444, 13, 162, "Input"],
Cell[22609, 706, 460373, 7272, 294, 210863, 4186, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[483031, 7984, 104, 1, 108, "Section"],
Cell[483138, 7987, 851, 18, 81, "Text"],
Cell[483992, 8007, 229, 6, 47, "Input"],

Cell[CellGroupData[{
Cell[484246, 8017, 267, 7, 79, "Input"],

Cell[CellGroupData[{
Cell[484538, 8028, 1632607, 131636, 195, 1505700, 130064, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2117148, 139666, 3318, 108, 26, 1368, 79, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2120515, 139780, 218, 8, 34, "Subsubsection"],
Cell[2120736, 139790, 939, 22, 70, "Text"],
Cell[2121678, 139814, 475, 14, 143, "Input"],
Cell[2122156, 139830, 241, 8, 21, "Text"],
Cell[2122400, 139840, 70, 1, 24, "Input"],
Cell[2122473, 139843, 231, 8, 21, "Text"],
Cell[2122707, 139853, 191, 6, 66, "Input"],
Cell[2122901, 139861, 498, 14, 45, "Text"],

Cell[CellGroupData[{
Cell[2123424, 139879, 426, 11, 134, "Input"],

Cell[CellGroupData[{
Cell[2123875, 139894, 304744, 4505, 196, 140085, 2467, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2428622, 144401, 2649, 101, 26, 1305, 79, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[2431298, 144506, 803, 18, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2432138, 144529, 217, 8, 34, "Subsubsection"],
Cell[2432358, 144539, 327, 11, 134, "Input"],
Cell[2432688, 144552, 386, 12, 33, "Text"],
Cell[2433077, 144566, 70, 1, 24, "Input"],
Cell[2433150, 144569, 277, 8, 33, "Text"],
Cell[2433430, 144579, 188, 5, 52, "Input"],
Cell[2433621, 144586, 396, 10, 33, "Text"],

Cell[CellGroupData[{
Cell[2434042, 144600, 421, 10, 121, "Input"],

Cell[CellGroupData[{
Cell[2434488, 144614, 278846, 4185, 196, 140079, 2467, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2713337, 148801, 2649, 101, 26, 1305, 79, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[2716013, 148906, 280, 8, 33, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2716342, 148920, 111, 1, 108, "Section"],
Cell[2716456, 148923, 1289, 29, 123, "Text"],

Cell[CellGroupData[{
Cell[2717770, 148956, 270, 6, 66, "Input"],
Cell[2718043, 148964, 199, 4, 18, "Print"]
}, Open  ]],
Cell[2718257, 148971, 362, 9, 33, "Text"],
Cell[2718622, 148982, 132, 5, 35, "Input"],
Cell[2718757, 148989, 278, 10, 21, "Text"],

Cell[CellGroupData[{
Cell[2719060, 149003, 143, 4, 38, "Input"],
Cell[2719206, 149009, 597636, 8144, 294, 404169, 5750, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3316879, 157158, 116, 2, 33, "Subsection"],
Cell[3316998, 157162, 431, 12, 33, "Text"],
Cell[3317432, 157176, 374, 9, 107, "Input"],
Cell[3317809, 157187, 188, 6, 21, "Text"],

Cell[CellGroupData[{
Cell[3318022, 157197, 159, 5, 52, "Input"],
Cell[3318184, 157204, 404588, 7542, 196, 273981, 5925, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[3722787, 164749, 612, 14, 45, "Text"],
Cell[3723402, 164765, 389, 10, 121, "Input"],
Cell[3723794, 164777, 188, 6, 21, "Text"],

Cell[CellGroupData[{
Cell[3724007, 164787, 153, 4, 38, "Input"],
Cell[3724163, 164793, 420592, 7740, 196, 273983, 5925, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[4144770, 172536, 421, 11, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4145228, 172552, 111, 2, 33, "Subsection"],
Cell[4145342, 172556, 552, 15, 45, "Text"],
Cell[4145897, 172573, 129, 4, 38, "Input"],
Cell[4146029, 172579, 329, 12, 21, "Text"],

Cell[CellGroupData[{
Cell[4146383, 172595, 330, 9, 107, "Input"],
Cell[4146716, 172606, 505045, 10010, 146, 409617, 8827, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[4651776, 182619, 506, 13, 45, "Text"],

Cell[CellGroupData[{
Cell[4652307, 182636, 229, 7, 79, "Input"],
Cell[4652539, 182645, 618280, 8399, 294, 404170, 5750, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[5270834, 191047, 367, 12, 21, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5271238, 191064, 123, 2, 33, "Subsection"],
Cell[5271364, 191068, 1130, 27, 102, "Text"],
Cell[5272497, 191097, 119, 4, 38, "Input"],
Cell[5272619, 191103, 217, 7, 21, "Text"],

Cell[CellGroupData[{
Cell[5272861, 191114, 331, 10, 121, "Input"],
Cell[5273195, 191126, 450850, 9342, 146, 409660, 8829, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[5724060, 200471, 357, 12, 21, "Text"],

Cell[CellGroupData[{
Cell[5724442, 200487, 156, 5, 52, "Input"],
Cell[5724601, 200494, 506377, 7019, 294, 404213, 5752, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6231039, 207520, 108, 1, 108, "Section"],
Cell[6231150, 207523, 1271, 24, 147, "Text"],

Cell[CellGroupData[{
Cell[6232446, 207551, 286, 6, 66, "Input"],
Cell[6232735, 207559, 199, 4, 18, "Print"]
}, Open  ]],
Cell[6232949, 207566, 830, 25, 66, "Text"],

Cell[CellGroupData[{
Cell[6233804, 207595, 255, 7, 79, "Input"],
Cell[6234062, 207604, 93116, 1322, 294, 27811, 510, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[6327193, 208929, 458, 13, 32, "Text"],
Cell[6327654, 208944, 94, 1, 24, "Input"],
Cell[6327751, 208947, 908, 25, 78, "Text"],
Cell[6328662, 208974, 134, 4, 38, "Input"],
Cell[6328799, 208980, 853, 24, 57, "Text"],

Cell[CellGroupData[{
Cell[6329677, 209008, 142, 4, 38, "Input"],
Cell[6329822, 209014, 95, 2, 18, "Output"]
}, Open  ]],
Cell[6329932, 209019, 513, 14, 33, "Text"],
Cell[6330448, 209035, 595, 11, 134, "Input"],
Cell[6331046, 209048, 243, 8, 21, "Text"],

Cell[CellGroupData[{
Cell[6331314, 209060, 195, 5, 52, "Input"],
Cell[6331512, 209067, 1460159, 20090, 456, 1014899, 14587, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[7791686, 229160, 359, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[7792070, 229173, 234, 8, 33, "Subsubsection"],
Cell[7792307, 229183, 829, 24, 33, "Text"],
Cell[7793139, 229209, 249, 6, 66, "Input"],
Cell[7793391, 229217, 245, 8, 21, "Text"],

Cell[CellGroupData[{
Cell[7793661, 229229, 91, 1, 24, "Input"],
Cell[7793755, 229232, 80, 2, 18, "Output"]
}, Open  ]],
Cell[7793850, 229237, 256, 8, 21, "Text"],

Cell[CellGroupData[{
Cell[7794131, 229249, 88, 1, 24, "Input"],
Cell[7794222, 229252, 80, 2, 18, "Output"]
}, Open  ]],
Cell[7794317, 229257, 331, 9, 32, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7794697, 229272, 132, 2, 113, "Section"],
Cell[7794832, 229276, 794, 18, 78, "Text"],

Cell[CellGroupData[{
Cell[7795651, 229298, 268, 6, 66, "Input"],
Cell[7795922, 229306, 199, 4, 18, "Print"]
}, Open  ]],
Cell[7796136, 229313, 971, 19, 81, "Text"],

Cell[CellGroupData[{
Cell[7797132, 229336, 235, 8, 33, "Subsubsection"],
Cell[7797370, 229346, 453, 11, 33, "Text"],
Cell[7797826, 229359, 505, 13, 162, "Input"],
Cell[7798334, 229374, 224, 7, 21, "Text"],

Cell[CellGroupData[{
Cell[7798583, 229385, 109, 4, 38, "Input"],
Cell[7798695, 229391, 95, 2, 18, "Output"]
}, Open  ]],
Cell[7798805, 229396, 474, 11, 45, "Text"],
Cell[7799282, 229409, 233, 6, 66, "Input"],

Cell[CellGroupData[{
Cell[7799540, 229419, 192, 5, 52, "Input"],
Cell[7799735, 229426, 352048, 5581, 201, 219022, 3933, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[8151798, 235010, 693, 22, 33, "Text"],

Cell[CellGroupData[{
Cell[8152516, 235036, 96, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[8152637, 235041, 100057, 1413, 294, 27651, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[8252697, 236456, 101699, 1433, 296, 27653, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[8354399, 237891, 98196, 1390, 296, 27653, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[8452598, 239283, 100308, 1416, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[8552909, 240701, 100118, 1414, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[8653030, 242117, 101628, 1432, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[8754661, 243551, 96627, 1371, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[8851291, 244924, 100251, 1415, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8951615, 246347, 114, 2, 51, "Section"],
Cell[8951732, 246351, 939, 26, 78, "Text"],

Cell[CellGroupData[{
Cell[8952696, 246381, 246, 7, 52, "Input"],
Cell[8952945, 246390, 199, 4, 18, "Print"]
}, Open  ]],
Cell[8953159, 246397, 686, 18, 33, "Text"],

Cell[CellGroupData[{
Cell[8953870, 246419, 233, 8, 33, "Subsubsection"],
Cell[8954106, 246429, 498, 13, 33, "Text"],
Cell[8954607, 246444, 578, 14, 176, "Input"],
Cell[8955188, 246460, 206, 6, 21, "Text"],

Cell[CellGroupData[{
Cell[8955419, 246470, 88, 1, 24, "Input"],
Cell[8955510, 246473, 95, 2, 18, "Output"]
}, Open  ]],
Cell[8955620, 246478, 508, 13, 45, "Text"],
Cell[8956131, 246493, 235, 6, 66, "Input"],

Cell[CellGroupData[{
Cell[8956391, 246503, 199, 5, 52, "Input"],
Cell[8956593, 246510, 410970, 6307, 204, 218992, 3931, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[9367578, 252820, 693, 22, 42, "Text"],

Cell[CellGroupData[{
Cell[9368296, 252846, 97, 1, 32, "Input"],

Cell[CellGroupData[{
Cell[9368418, 252851, 136710, 1866, 296, 27651, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[9505131, 254719, 138259, 1885, 296, 27653, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[9643393, 256606, 138097, 1883, 296, 27653, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[9781493, 258491, 136714, 1866, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[9918210, 260359, 136989, 1869, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[10055202, 262230, 138447, 1887, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[10193652, 264119, 138261, 1885, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"],
Cell[10331916, 266006, 136681, 1865, 296, 27655, 514, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10468670, 267879, 99, 2, 52, "Section"],
Cell[10468772, 267883, 3343, 51, 532, "Text"],

Cell[CellGroupData[{
Cell[10472140, 267938, 104, 2, 38, "Subsection"],
Cell[10472247, 267942, 918, 32, 54, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

